// This file is @generated by crates/typos-vars/tests/codegen.rs
#![allow(clippy::unreadable_literal, clippy::type_complexity)]

pub type Variants = &'static [&'static str];
pub type VariantsMap = [Variants; 4];

pub fn all_categories() -> crate::CategorySet {
    crate::Category::American
        | crate::Category::BritishIse
        | crate::Category::Canadian
        | crate::Category::Australian
}

pub fn corrections(category: crate::Category, options: VariantsMap) -> &'static [&'static str] {
    match category {
        crate::Category::American => options[0],
        crate::Category::BritishIse => options[1],
        crate::Category::Canadian => options[2],
        crate::Category::Australian => options[3],
        crate::Category::BritishIze | crate::Category::Other => {
            unreachable!("{:?} is unused", category)
        }
    }
}

pub static VARS_TRIE: dictgen::DictTrie<&[(u8, &VariantsMap)]> = dictgen::DictTrie {
    root: &VARS_NODE,
    unicode: &VARS_UNICODE_TABLE,
    range: 2..=24,
};

pub static VARS_UNICODE_TABLE: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CHILDREN),
    value: None,
};

static VARS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_A_NODE),
    Some(&VARS_B_NODE),
    Some(&VARS_C_NODE),
    Some(&VARS_D_NODE),
    Some(&VARS_E_NODE),
    Some(&VARS_F_NODE),
    Some(&VARS_G_NODE),
    Some(&VARS_H_NODE),
    Some(&VARS_I_NODE),
    Some(&VARS_J_NODE),
    Some(&VARS_K_NODE),
    Some(&VARS_L_NODE),
    Some(&VARS_M_NODE),
    Some(&VARS_N_NODE),
    Some(&VARS_O_NODE),
    Some(&VARS_P_NODE),
    Some(&VARS_Q_NODE),
    Some(&VARS_R_NODE),
    Some(&VARS_S_NODE),
    Some(&VARS_T_NODE),
    Some(&VARS_U_NODE),
    Some(&VARS_V_NODE),
    Some(&VARS_W_NODE),
    None,
    Some(&VARS_Y_NODE),
    Some(&VARS_Z_NODE),
];

static VARS_Z_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_Z_CHILDREN),
    value: None,
};

pub static VARS_Z_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("affer"),
        dictgen::InsensitiveStr::Ascii("affers"),
        dictgen::InsensitiveStr::Ascii("affre"),
        dictgen::InsensitiveStr::Ascii("affres"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("eas"),
        dictgen::InsensitiveStr::Ascii("eroise"),
        dictgen::InsensitiveStr::Ascii("eroised"),
        dictgen::InsensitiveStr::Ascii("eroises"),
        dictgen::InsensitiveStr::Ascii("eroising"),
        dictgen::InsensitiveStr::Ascii("eroize"),
        dictgen::InsensitiveStr::Ascii("eroized"),
        dictgen::InsensitiveStr::Ascii("eroizes"),
        dictgen::InsensitiveStr::Ascii("eroizing"),
        dictgen::InsensitiveStr::Ascii("oaea"),
        dictgen::InsensitiveStr::Ascii("oea"),
        dictgen::InsensitiveStr::Ascii("oeae"),
        dictgen::InsensitiveStr::Ascii("oeal"),
        dictgen::InsensitiveStr::Ascii("oeas"),
        dictgen::InsensitiveStr::Ascii("oecia"),
        dictgen::InsensitiveStr::Ascii("oecium"),
        dictgen::InsensitiveStr::Ascii("onaesthesia"),
        dictgen::InsensitiveStr::Ascii("onesthesia"),
        dictgen::InsensitiveStr::Ascii("onulae"),
        dictgen::InsensitiveStr::Ascii("onule"),
        dictgen::InsensitiveStr::Ascii("ooea"),
        dictgen::InsensitiveStr::Ascii("ooeae"),
        dictgen::InsensitiveStr::Ascii("ooeal"),
        dictgen::InsensitiveStr::Ascii("ooeas"),
        dictgen::InsensitiveStr::Ascii("ooecia"),
        dictgen::InsensitiveStr::Ascii("ooecium"),
        dictgen::InsensitiveStr::Ascii("ooglea"),
        dictgen::InsensitiveStr::Ascii("oogleae"),
        dictgen::InsensitiveStr::Ascii("oogleal"),
        dictgen::InsensitiveStr::Ascii("oogleas"),
        dictgen::InsensitiveStr::Ascii("oogloea"),
        dictgen::InsensitiveStr::Ascii("oogloeae"),
        dictgen::InsensitiveStr::Ascii("oogloeal"),
        dictgen::InsensitiveStr::Ascii("oogloeas"),
        dictgen::InsensitiveStr::Ascii("ygaenid"),
        dictgen::InsensitiveStr::Ascii("ygenid"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ZAFFER_10527776117983596564)],
        &[(0b00001, &ENTRY_ZAFFERS_2686771360880865447)],
        &[(0b11010, &ENTRY_ZAFFER_10527776117983596564)],
        &[(0b11010, &ENTRY_ZAFFERS_2686771360880865447)],
        &[(0b00001, &ENTRY_ZEA_11106235456645827388)],
        &[(0b00001, &ENTRY_ZEAS_16079098418850825523)],
        &[(0b10010, &ENTRY_ZEROIZE_5851814204224675995)],
        &[(0b10010, &ENTRY_ZEROIZED_17059959399940465949)],
        &[(0b10010, &ENTRY_ZEROIZES_451395537748100839)],
        &[(0b10010, &ENTRY_ZEROIZING_17764051118899638643)],
        &[(0b01001, &ENTRY_ZEROIZE_5851814204224675995)],
        &[(0b01001, &ENTRY_ZEROIZED_17059959399940465949)],
        &[(0b01001, &ENTRY_ZEROIZES_451395537748100839)],
        &[(0b01001, &ENTRY_ZEROIZING_17764051118899638643)],
        &[(0b11010, &ENTRY_ZOEA_17148924521763695652)],
        &[
            (0b11010, &ENTRY_ZEA_11106235456645827388),
            (0b00001, &ENTRY_ZOEA_17148924521763695652),
            (0b00001, &ENTRY_ZOEA_9209140367896697417),
        ],
        &[(0b00001, &ENTRY_ZOEAE_16777813522281751943)],
        &[(0b00001, &ENTRY_ZOEAL_11452762743124231237)],
        &[
            (0b11010, &ENTRY_ZEAS_16079098418850825523),
            (0b00001, &ENTRY_ZOEAS_265178227546758074),
        ],
        &[(0b00001, &ENTRY_ZOECIA_8904526004070274154)],
        &[(0b00001, &ENTRY_ZOECIUM_16562741580002996142)],
        &[(0b11010, &ENTRY_ZONESTHESIA_3100074848208687922)],
        &[(0b00001, &ENTRY_ZONESTHESIA_3100074848208687922)],
        &[(0b11010, &ENTRY_ZONULE_1425795093078962568)],
        &[(0b00001, &ENTRY_ZONULE_1425795093078962568)],
        &[(0b11010, &ENTRY_ZOEA_9209140367896697417)],
        &[(0b11010, &ENTRY_ZOEAE_16777813522281751943)],
        &[(0b11010, &ENTRY_ZOEAL_11452762743124231237)],
        &[(0b11010, &ENTRY_ZOEAS_265178227546758074)],
        &[(0b11010, &ENTRY_ZOECIA_8904526004070274154)],
        &[(0b11010, &ENTRY_ZOECIUM_16562741580002996142)],
        &[(0b00001, &ENTRY_ZOOGLEA_5239592471376961231)],
        &[(0b00001, &ENTRY_ZOOGLEAE_8257944936060167006)],
        &[(0b00001, &ENTRY_ZOOGLEAL_12531107528650388160)],
        &[(0b00001, &ENTRY_ZOOGLEAS_1142556719691697396)],
        &[(0b11010, &ENTRY_ZOOGLEA_5239592471376961231)],
        &[(0b11010, &ENTRY_ZOOGLEAE_8257944936060167006)],
        &[(0b11010, &ENTRY_ZOOGLEAL_12531107528650388160)],
        &[(0b11010, &ENTRY_ZOOGLEAS_1142556719691697396)],
        &[(0b11010, &ENTRY_ZYGENID_18294614842044047958)],
        &[(0b00001, &ENTRY_ZYGENID_18294614842044047958)],
    ],
    range: 2..=11,
};

static VARS_Y_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_Y_CHILDREN),
    value: None,
};

pub static VARS_Y_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("odeled"),
        dictgen::InsensitiveStr::Ascii("odeler"),
        dictgen::InsensitiveStr::Ascii("odelers"),
        dictgen::InsensitiveStr::Ascii("odeling"),
        dictgen::InsensitiveStr::Ascii("odelled"),
        dictgen::InsensitiveStr::Ascii("odeller"),
        dictgen::InsensitiveStr::Ascii("odellers"),
        dictgen::InsensitiveStr::Ascii("odelling"),
        dictgen::InsensitiveStr::Ascii("oghourt"),
        dictgen::InsensitiveStr::Ascii("oghourts"),
        dictgen::InsensitiveStr::Ascii("oghurt"),
        dictgen::InsensitiveStr::Ascii("oghurts"),
        dictgen::InsensitiveStr::Ascii("ogourt"),
        dictgen::InsensitiveStr::Ascii("ogourts"),
    ],
    values: &[
        &[(0b01001, &ENTRY_YODELED_9356406298399519334)],
        &[(0b01001, &ENTRY_YODELER_285878482199218584)],
        &[(0b01001, &ENTRY_YODELERS_2440942956900301409)],
        &[(0b01001, &ENTRY_YODELING_14921433313912990218)],
        &[(0b11010, &ENTRY_YODELED_9356406298399519334)],
        &[(0b11010, &ENTRY_YODELER_285878482199218584)],
        &[(0b11010, &ENTRY_YODELERS_2440942956900301409)],
        &[(0b11010, &ENTRY_YODELING_14921433313912990218)],
        &[(0b10010, &ENTRY_YOGURT_14795287461115589482)],
        &[(0b10010, &ENTRY_YOGURTS_14006847350082938741)],
        &[(0b11010, &ENTRY_YOGURT_14795287461115589482)],
        &[(0b11010, &ENTRY_YOGURTS_14006847350082938741)],
        &[(0b01000, &ENTRY_YOGURT_14795287461115589482)],
        &[(0b01000, &ENTRY_YOGURTS_14006847350082938741)],
    ],
    range: 6..=8,
};

static VARS_W_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_W_CHILDREN),
    value: None,
};

static VARS_W_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_WA_NODE),
    None,
    None,
    None,
    Some(&VARS_WE_NODE),
    None,
    None,
    Some(&VARS_WH_NODE),
    Some(&VARS_WI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_WO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_WO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WO_CHILDREN),
    value: None,
};

pub static VARS_WO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("manisation"),
        dictgen::InsensitiveStr::Ascii("manisations"),
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("maniser"),
        dictgen::InsensitiveStr::Ascii("manisers"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manization"),
        dictgen::InsensitiveStr::Ascii("manizations"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizer"),
        dictgen::InsensitiveStr::Ascii("manizers"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("odcockise"),
        dictgen::InsensitiveStr::Ascii("odcockises"),
        dictgen::InsensitiveStr::Ascii("odcockize"),
        dictgen::InsensitiveStr::Ascii("odcockizes"),
        dictgen::InsensitiveStr::Ascii("olen"),
        dictgen::InsensitiveStr::Ascii("olenization"),
        dictgen::InsensitiveStr::Ascii("olenizations"),
        dictgen::InsensitiveStr::Ascii("olenize"),
        dictgen::InsensitiveStr::Ascii("olenizes"),
        dictgen::InsensitiveStr::Ascii("olenner"),
        dictgen::InsensitiveStr::Ascii("olennest"),
        dictgen::InsensitiveStr::Ascii("olens"),
        dictgen::InsensitiveStr::Ascii("ollen"),
        dictgen::InsensitiveStr::Ascii("ollenisation"),
        dictgen::InsensitiveStr::Ascii("ollenisations"),
        dictgen::InsensitiveStr::Ascii("ollenise"),
        dictgen::InsensitiveStr::Ascii("ollenises"),
        dictgen::InsensitiveStr::Ascii("ollenization"),
        dictgen::InsensitiveStr::Ascii("ollenizations"),
        dictgen::InsensitiveStr::Ascii("ollenize"),
        dictgen::InsensitiveStr::Ascii("ollenizes"),
        dictgen::InsensitiveStr::Ascii("ollenner"),
        dictgen::InsensitiveStr::Ascii("ollennest"),
        dictgen::InsensitiveStr::Ascii("ollens"),
        dictgen::InsensitiveStr::Ascii("rnil"),
        dictgen::InsensitiveStr::Ascii("rshiped"),
        dictgen::InsensitiveStr::Ascii("rshiper"),
        dictgen::InsensitiveStr::Ascii("rshipers"),
        dictgen::InsensitiveStr::Ascii("rshiping"),
        dictgen::InsensitiveStr::Ascii("rshipped"),
        dictgen::InsensitiveStr::Ascii("rshipper"),
        dictgen::InsensitiveStr::Ascii("rshippers"),
        dictgen::InsensitiveStr::Ascii("rshipping"),
        dictgen::InsensitiveStr::Ascii("urnil"),
    ],
    values: &[
        &[(0b10010, &ENTRY_WOMANIZATION_8388350880273651311)],
        &[(0b10010, &ENTRY_WOMANIZATIONS_13952845861350174066)],
        &[(0b10010, &ENTRY_WOMANIZE_13239637807089654458)],
        &[(0b10010, &ENTRY_WOMANIZED_13265813200914382776)],
        &[(0b10010, &ENTRY_WOMANIZER_17770185505558084902)],
        &[(0b10010, &ENTRY_WOMANIZERS_9259673447489824653)],
        &[(0b10010, &ENTRY_WOMANIZES_14963203568866144583)],
        &[(0b10010, &ENTRY_WOMANIZING_18027895621894995913)],
        &[(0b01001, &ENTRY_WOMANIZATION_8388350880273651311)],
        &[(0b01001, &ENTRY_WOMANIZATIONS_13952845861350174066)],
        &[(0b01001, &ENTRY_WOMANIZE_13239637807089654458)],
        &[(0b01001, &ENTRY_WOMANIZED_13265813200914382776)],
        &[(0b01001, &ENTRY_WOMANIZER_17770185505558084902)],
        &[(0b01001, &ENTRY_WOMANIZERS_9259673447489824653)],
        &[(0b01001, &ENTRY_WOMANIZES_14963203568866144583)],
        &[(0b01001, &ENTRY_WOMANIZING_18027895621894995913)],
        &[(0b10010, &ENTRY_WOODCOCKIZE_12359995033224465169)],
        &[(0b10010, &ENTRY_WOODCOCKIZES_12391053488008876606)],
        &[(0b01001, &ENTRY_WOODCOCKIZE_12359995033224465169)],
        &[(0b01001, &ENTRY_WOODCOCKIZES_12391053488008876606)],
        &[(0b01001, &ENTRY_WOOLEN_15717013546287576656)],
        &[(0b00001, &ENTRY_WOOLENIZATION_2116233406109851879)],
        &[(0b00001, &ENTRY_WOOLENIZATIONS_18413526449670419815)],
        &[(0b00001, &ENTRY_WOOLENIZE_3109266446842903533)],
        &[(0b00001, &ENTRY_WOOLENIZES_10986368507483676931)],
        &[(0b01001, &ENTRY_WOOLENNER_17842051069153830315)],
        &[(0b01001, &ENTRY_WOOLENNEST_10863079266692878959)],
        &[(0b01001, &ENTRY_WOOLENS_12209882553973827060)],
        &[(0b11010, &ENTRY_WOOLEN_15717013546287576656)],
        &[(0b10010, &ENTRY_WOOLENIZATION_2116233406109851879)],
        &[(0b10010, &ENTRY_WOOLENIZATIONS_18413526449670419815)],
        &[(0b10010, &ENTRY_WOOLENIZE_3109266446842903533)],
        &[(0b10010, &ENTRY_WOOLENIZES_10986368507483676931)],
        &[(0b01000, &ENTRY_WOOLENIZATION_2116233406109851879)],
        &[(0b01000, &ENTRY_WOOLENIZATIONS_18413526449670419815)],
        &[(0b01000, &ENTRY_WOOLENIZE_3109266446842903533)],
        &[(0b01000, &ENTRY_WOOLENIZES_10986368507483676931)],
        &[(0b11010, &ENTRY_WOOLENNER_17842051069153830315)],
        &[(0b11010, &ENTRY_WOOLENNEST_10863079266692878959)],
        &[(0b11010, &ENTRY_WOOLENS_12209882553973827060)],
        &[(0b00001, &ENTRY_WORNIL_7106321021868280403)],
        &[(0b00001, &ENTRY_WORSHIPED_10866326533617664853)],
        &[(0b00001, &ENTRY_WORSHIPER_4363374512340886503)],
        &[(0b00001, &ENTRY_WORSHIPERS_10535090980834134943)],
        &[(0b00001, &ENTRY_WORSHIPING_7066968947382158195)],
        &[(0b11010, &ENTRY_WORSHIPED_10866326533617664853)],
        &[(0b11010, &ENTRY_WORSHIPER_4363374512340886503)],
        &[(0b11010, &ENTRY_WORSHIPERS_10535090980834134943)],
        &[(0b11010, &ENTRY_WORSHIPING_7066968947382158195)],
        &[(0b11010, &ENTRY_WORNIL_7106321021868280403)],
    ],
    range: 4..=13,
};

static VARS_WI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WI_CHILDREN),
    value: None,
};

pub static VARS_WI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lfullier"),
        dictgen::InsensitiveStr::Ascii("lfulliest"),
        dictgen::InsensitiveStr::Ascii("lfully"),
        dictgen::InsensitiveStr::Ascii("llful"),
        dictgen::InsensitiveStr::Ascii("llfuler"),
        dictgen::InsensitiveStr::Ascii("llfulest"),
        dictgen::InsensitiveStr::Ascii("llfullier"),
        dictgen::InsensitiveStr::Ascii("llfulliest"),
        dictgen::InsensitiveStr::Ascii("llfully"),
        dictgen::InsensitiveStr::Ascii("llfulness"),
        dictgen::InsensitiveStr::Ascii("nterisation"),
        dictgen::InsensitiveStr::Ascii("nterisations"),
        dictgen::InsensitiveStr::Ascii("nterise"),
        dictgen::InsensitiveStr::Ascii("nterised"),
        dictgen::InsensitiveStr::Ascii("nterises"),
        dictgen::InsensitiveStr::Ascii("nterising"),
        dictgen::InsensitiveStr::Ascii("nterization"),
        dictgen::InsensitiveStr::Ascii("nterizations"),
        dictgen::InsensitiveStr::Ascii("nterize"),
        dictgen::InsensitiveStr::Ascii("nterized"),
        dictgen::InsensitiveStr::Ascii("nterizes"),
        dictgen::InsensitiveStr::Ascii("nterizing"),
        dictgen::InsensitiveStr::Ascii("sen"),
        dictgen::InsensitiveStr::Ascii("zen"),
    ],
    values: &[
        &[(0b11010, &ENTRY_WILLFULLIER_2697017026114247086)],
        &[(0b11010, &ENTRY_WILLFULLIEST_15153395951969058577)],
        &[(0b11010, &ENTRY_WILLFULLY_17551532991278844610)],
        &[(0b01001, &ENTRY_WILLFUL_7624543375604831885)],
        &[(0b01001, &ENTRY_WILLFULER_9723393434882898265)],
        &[(0b01001, &ENTRY_WILLFULEST_1356703166632625612)],
        &[(0b00001, &ENTRY_WILLFULLIER_2697017026114247086)],
        &[(0b00001, &ENTRY_WILLFULLIEST_15153395951969058577)],
        &[(0b00001, &ENTRY_WILLFULLY_17551532991278844610)],
        &[(0b00001, &ENTRY_WILLFULNESS_13563375725271959262)],
        &[(0b10010, &ENTRY_WINTERIZATION_7645598477678155456)],
        &[(0b10010, &ENTRY_WINTERIZATIONS_13592272727744097379)],
        &[(0b10010, &ENTRY_WINTERIZE_3955752504931726030)],
        &[(0b10010, &ENTRY_WINTERIZED_9857678671877956604)],
        &[(0b10010, &ENTRY_WINTERIZES_158574474219766318)],
        &[(0b10010, &ENTRY_WINTERIZING_11041236811279192392)],
        &[(0b01001, &ENTRY_WINTERIZATION_7645598477678155456)],
        &[(0b01001, &ENTRY_WINTERIZATIONS_13592272727744097379)],
        &[(0b01001, &ENTRY_WINTERIZE_3955752504931726030)],
        &[(0b01001, &ENTRY_WINTERIZED_9857678671877956604)],
        &[(0b01001, &ENTRY_WINTERIZES_158574474219766318)],
        &[(0b01001, &ENTRY_WINTERIZING_11041236811279192392)],
        &[(0b10010, &ENTRY_WIZEN_287155720416603669)],
        &[(0b01001, &ENTRY_WIZEN_287155720416603669)],
    ],
    range: 3..=12,
};

static VARS_WH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WH_CHILDREN),
    value: None,
};

pub static VARS_WH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iskeys"),
        dictgen::InsensitiveStr::Ascii("itmanise"),
        dictgen::InsensitiveStr::Ascii("itmanises"),
        dictgen::InsensitiveStr::Ascii("itmanize"),
        dictgen::InsensitiveStr::Ascii("itmanizes"),
    ],
    values: &[
        &[(0b01001, &ENTRY_WHISKEYS_17211820182326956376)],
        &[(0b10010, &ENTRY_WHITMANIZE_17709805677202222665)],
        &[(0b10010, &ENTRY_WHITMANIZES_2277386686370449672)],
        &[(0b01001, &ENTRY_WHITMANIZE_17709805677202222665)],
        &[(0b01001, &ENTRY_WHITMANIZES_2277386686370449672)],
    ],
    range: 6..=9,
};

static VARS_WE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WE_CHILDREN),
    value: None,
};

pub static VARS_WE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aseled"),
        dictgen::InsensitiveStr::Ascii("aseling"),
        dictgen::InsensitiveStr::Ascii("aselled"),
        dictgen::InsensitiveStr::Ascii("aselling"),
        dictgen::InsensitiveStr::Ascii("atherise"),
        dictgen::InsensitiveStr::Ascii("atherised"),
        dictgen::InsensitiveStr::Ascii("atherises"),
        dictgen::InsensitiveStr::Ascii("atherising"),
        dictgen::InsensitiveStr::Ascii("atherize"),
        dictgen::InsensitiveStr::Ascii("atherized"),
        dictgen::InsensitiveStr::Ascii("atherizes"),
        dictgen::InsensitiveStr::Ascii("atherizing"),
        dictgen::InsensitiveStr::Ascii("eviled"),
        dictgen::InsensitiveStr::Ascii("evilled"),
        dictgen::InsensitiveStr::Ascii("ftwise"),
        dictgen::InsensitiveStr::Ascii("ftwize"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("sternisation"),
        dictgen::InsensitiveStr::Ascii("sternisations"),
        dictgen::InsensitiveStr::Ascii("sternise"),
        dictgen::InsensitiveStr::Ascii("sternised"),
        dictgen::InsensitiveStr::Ascii("sternises"),
        dictgen::InsensitiveStr::Ascii("sternising"),
        dictgen::InsensitiveStr::Ascii("sternization"),
        dictgen::InsensitiveStr::Ascii("sternizations"),
        dictgen::InsensitiveStr::Ascii("sternize"),
        dictgen::InsensitiveStr::Ascii("sternized"),
        dictgen::InsensitiveStr::Ascii("sternizes"),
        dictgen::InsensitiveStr::Ascii("sternizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_WEASELED_11570315947714387529)],
        &[(0b01001, &ENTRY_WEASELING_15286296280087806597)],
        &[(0b10010, &ENTRY_WEASELED_11570315947714387529)],
        &[(0b10010, &ENTRY_WEASELING_15286296280087806597)],
        &[(0b10010, &ENTRY_WEATHERIZE_2192670928369527010)],
        &[(0b10010, &ENTRY_WEATHERIZED_7468196884834492189)],
        &[(0b10010, &ENTRY_WEATHERIZES_9985373291367274228)],
        &[(0b10010, &ENTRY_WEATHERIZING_15974867536961027368)],
        &[(0b01001, &ENTRY_WEATHERIZE_2192670928369527010)],
        &[(0b01001, &ENTRY_WEATHERIZED_7468196884834492189)],
        &[(0b01001, &ENTRY_WEATHERIZES_9985373291367274228)],
        &[(0b01001, &ENTRY_WEATHERIZING_15974867536961027368)],
        &[(0b00001, &ENTRY_WEEVILED_9823853063466769617)],
        &[(0b11010, &ENTRY_WEEVILED_9823853063466769617)],
        &[(0b10010, &ENTRY_WEFTWIZE_11468980171486281071)],
        &[(0b01001, &ENTRY_WEFTWIZE_11468980171486281071)],
        &[(0b10010, &ENTRY_WEIZE_8174776964340050680)],
        &[(0b10010, &ENTRY_WEIZED_15084246244422353791)],
        &[(0b10010, &ENTRY_WEIZES_7320958225089246727)],
        &[(0b10010, &ENTRY_WEIZING_16099137944736271359)],
        &[(0b01001, &ENTRY_WEIZE_8174776964340050680)],
        &[(0b01001, &ENTRY_WEIZED_15084246244422353791)],
        &[(0b01001, &ENTRY_WEIZES_7320958225089246727)],
        &[(0b01001, &ENTRY_WEIZING_16099137944736271359)],
        &[(0b00001, &ENTRY_WER_15853599801760131986)],
        &[(0b10010, &ENTRY_WESTERNIZATION_9450693683308242701)],
        &[(0b10010, &ENTRY_WESTERNIZATIONS_13759633497928659151)],
        &[(0b10010, &ENTRY_WESTERNIZE_18201376901512962153)],
        &[(0b10010, &ENTRY_WESTERNIZED_4777853943475506918)],
        &[(0b10010, &ENTRY_WESTERNIZES_359511446272047498)],
        &[(0b10010, &ENTRY_WESTERNIZING_6658385047324066874)],
        &[(0b01001, &ENTRY_WESTERNIZATION_9450693683308242701)],
        &[(0b01001, &ENTRY_WESTERNIZATIONS_13759633497928659151)],
        &[(0b01001, &ENTRY_WESTERNIZE_18201376901512962153)],
        &[(0b01001, &ENTRY_WESTERNIZED_4777853943475506918)],
        &[(0b01001, &ENTRY_WESTERNIZES_359511446272047498)],
        &[(0b01001, &ENTRY_WESTERNIZING_6658385047324066874)],
    ],
    range: 1..=13,
};

static VARS_WA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_WA_CHILDREN),
    value: None,
};

pub static VARS_WA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ckes"),
        dictgen::InsensitiveStr::Ascii("ckoes"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ggon"),
        dictgen::InsensitiveStr::Ascii("ggoned"),
        dictgen::InsensitiveStr::Ascii("ggoneer"),
        dictgen::InsensitiveStr::Ascii("ggoner"),
        dictgen::InsensitiveStr::Ascii("ggoners"),
        dictgen::InsensitiveStr::Ascii("ggonette"),
        dictgen::InsensitiveStr::Ascii("ggonettes"),
        dictgen::InsensitiveStr::Ascii("ggoning"),
        dictgen::InsensitiveStr::Ascii("ggons"),
        dictgen::InsensitiveStr::Ascii("gnerise"),
        dictgen::InsensitiveStr::Ascii("gnerises"),
        dictgen::InsensitiveStr::Ascii("gnerize"),
        dictgen::InsensitiveStr::Ascii("gnerizes"),
        dictgen::InsensitiveStr::Ascii("ntonise"),
        dictgen::InsensitiveStr::Ascii("ntonised"),
        dictgen::InsensitiveStr::Ascii("ntonises"),
        dictgen::InsensitiveStr::Ascii("ntonising"),
        dictgen::InsensitiveStr::Ascii("ntonize"),
        dictgen::InsensitiveStr::Ascii("ntonized"),
        dictgen::InsensitiveStr::Ascii("ntonizes"),
        dictgen::InsensitiveStr::Ascii("ntonizing"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rford"),
        dictgen::InsensitiveStr::Ascii("rfourd"),
        dictgen::InsensitiveStr::Ascii("rrantise"),
        dictgen::InsensitiveStr::Ascii("rrantize"),
        dictgen::InsensitiveStr::Ascii("rre"),
        dictgen::InsensitiveStr::Ascii("tercolor"),
        dictgen::InsensitiveStr::Ascii("tercolored"),
        dictgen::InsensitiveStr::Ascii("tercoloring"),
        dictgen::InsensitiveStr::Ascii("tercolorist"),
        dictgen::InsensitiveStr::Ascii("tercolorists"),
        dictgen::InsensitiveStr::Ascii("tercolors"),
        dictgen::InsensitiveStr::Ascii("tercolour"),
        dictgen::InsensitiveStr::Ascii("tercoloured"),
        dictgen::InsensitiveStr::Ascii("tercolouring"),
        dictgen::InsensitiveStr::Ascii("tercolourist"),
        dictgen::InsensitiveStr::Ascii("tercolourists"),
        dictgen::InsensitiveStr::Ascii("tercolours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_WACKES_12738481748744727840)],
        &[(0b11010, &ENTRY_WACKES_12738481748744727840)],
        &[(0b11010, &ENTRY_WER_15853599801760131986)],
        &[(0b10010, &ENTRY_WAGON_9175179404225633205)],
        &[(0b10010, &ENTRY_WAGONED_11373672045286783138)],
        &[(0b11010, &ENTRY_WAGONEER_17408093464143438026)],
        &[(0b10010, &ENTRY_WAGONER_7174401894558856152)],
        &[(0b10010, &ENTRY_WAGONERS_8328342185970927143)],
        &[(0b10010, &ENTRY_WAGONETTE_10106097158675362196)],
        &[(0b10010, &ENTRY_WAGONETTES_18300454369865577574)],
        &[(0b10010, &ENTRY_WAGONING_6834423535434103369)],
        &[(0b10010, &ENTRY_WAGONS_16296021619075314226)],
        &[(0b10010, &ENTRY_WAGNERIZE_6840934791092236521)],
        &[(0b10010, &ENTRY_WAGNERIZES_8895003839461059816)],
        &[(0b01001, &ENTRY_WAGNERIZE_6840934791092236521)],
        &[(0b01001, &ENTRY_WAGNERIZES_8895003839461059816)],
        &[(0b10010, &ENTRY_WANTONIZE_14427284173321750170)],
        &[(0b10010, &ENTRY_WANTONIZED_15092244368516355065)],
        &[(0b10010, &ENTRY_WANTONIZES_8102013437087314845)],
        &[(0b10010, &ENTRY_WANTONIZING_11612419212222365365)],
        &[(0b01001, &ENTRY_WANTONIZE_14427284173321750170)],
        &[(0b01001, &ENTRY_WANTONIZED_15092244368516355065)],
        &[(0b01001, &ENTRY_WANTONIZES_8102013437087314845)],
        &[(0b01001, &ENTRY_WANTONIZING_11612419212222365365)],
        &[(0b00001, &ENTRY_WARER_124002938733117158)],
        &[(0b00001, &ENTRY_WARFORD_9070503211126736019)],
        &[(0b11010, &ENTRY_WARFORD_9070503211126736019)],
        &[(0b10010, &ENTRY_WARRANTIZE_12531974386933132943)],
        &[(0b01001, &ENTRY_WARRANTIZE_12531974386933132943)],
        &[(0b11010, &ENTRY_WARER_124002938733117158)],
        &[(0b11001, &ENTRY_WATERCOLOR_14626819058358461476)],
        &[(0b11001, &ENTRY_WATERCOLORED_6965422467906206000)],
        &[(0b11001, &ENTRY_WATERCOLORING_10355406009413574616)],
        &[(0b00001, &ENTRY_WATERCOLORIST_98941858503965450)],
        &[(0b00001, &ENTRY_WATERCOLORISTS_8716481806936659758)],
        &[(0b11001, &ENTRY_WATERCOLORS_8321231076259173473)],
        &[(0b11010, &ENTRY_WATERCOLOR_14626819058358461476)],
        &[(0b11010, &ENTRY_WATERCOLORED_6965422467906206000)],
        &[(0b11010, &ENTRY_WATERCOLORING_10355406009413574616)],
        &[(0b11010, &ENTRY_WATERCOLORIST_98941858503965450)],
        &[(0b11010, &ENTRY_WATERCOLORISTS_8716481806936659758)],
        &[(0b11010, &ENTRY_WATERCOLORS_8321231076259173473)],
    ],
    range: 2..=13,
};

static VARS_V_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_V_CHILDREN),
    value: None,
};

static VARS_V_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_VA_NODE),
    None,
    None,
    None,
    Some(&VARS_VE_NODE),
    None,
    None,
    None,
    Some(&VARS_VI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_VU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VU_CHILDREN),
    value: None,
};

pub static VARS_VU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lcanisable"),
        dictgen::InsensitiveStr::Ascii("lcanisabler"),
        dictgen::InsensitiveStr::Ascii("lcanisables"),
        dictgen::InsensitiveStr::Ascii("lcanisablest"),
        dictgen::InsensitiveStr::Ascii("lcanisate"),
        dictgen::InsensitiveStr::Ascii("lcanisates"),
        dictgen::InsensitiveStr::Ascii("lcanisation"),
        dictgen::InsensitiveStr::Ascii("lcanisations"),
        dictgen::InsensitiveStr::Ascii("lcanise"),
        dictgen::InsensitiveStr::Ascii("lcanised"),
        dictgen::InsensitiveStr::Ascii("lcaniser"),
        dictgen::InsensitiveStr::Ascii("lcanisers"),
        dictgen::InsensitiveStr::Ascii("lcanises"),
        dictgen::InsensitiveStr::Ascii("lcanising"),
        dictgen::InsensitiveStr::Ascii("lcanizable"),
        dictgen::InsensitiveStr::Ascii("lcanizabler"),
        dictgen::InsensitiveStr::Ascii("lcanizables"),
        dictgen::InsensitiveStr::Ascii("lcanizablest"),
        dictgen::InsensitiveStr::Ascii("lcanizate"),
        dictgen::InsensitiveStr::Ascii("lcanizates"),
        dictgen::InsensitiveStr::Ascii("lcanization"),
        dictgen::InsensitiveStr::Ascii("lcanizations"),
        dictgen::InsensitiveStr::Ascii("lcanize"),
        dictgen::InsensitiveStr::Ascii("lcanized"),
        dictgen::InsensitiveStr::Ascii("lcanizer"),
        dictgen::InsensitiveStr::Ascii("lcanizers"),
        dictgen::InsensitiveStr::Ascii("lcanizes"),
        dictgen::InsensitiveStr::Ascii("lcanizing"),
        dictgen::InsensitiveStr::Ascii("lgarisation"),
        dictgen::InsensitiveStr::Ascii("lgarisations"),
        dictgen::InsensitiveStr::Ascii("lgarise"),
        dictgen::InsensitiveStr::Ascii("lgarised"),
        dictgen::InsensitiveStr::Ascii("lgariser"),
        dictgen::InsensitiveStr::Ascii("lgarisers"),
        dictgen::InsensitiveStr::Ascii("lgarises"),
        dictgen::InsensitiveStr::Ascii("lgarising"),
        dictgen::InsensitiveStr::Ascii("lgarization"),
        dictgen::InsensitiveStr::Ascii("lgarizations"),
        dictgen::InsensitiveStr::Ascii("lgarize"),
        dictgen::InsensitiveStr::Ascii("lgarized"),
        dictgen::InsensitiveStr::Ascii("lgarizer"),
        dictgen::InsensitiveStr::Ascii("lgarizers"),
        dictgen::InsensitiveStr::Ascii("lgarizes"),
        dictgen::InsensitiveStr::Ascii("lgarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VULCANIZABLE_3568502198024878932)],
        &[(0b10010, &ENTRY_VULCANIZABLER_4054424358397582656)],
        &[(0b10010, &ENTRY_VULCANIZABLES_8379629917557167700)],
        &[(0b10010, &ENTRY_VULCANIZABLEST_6459505877444949673)],
        &[(0b10010, &ENTRY_VULCANIZATE_4795671622025524378)],
        &[(0b10010, &ENTRY_VULCANIZATES_16942202816352460180)],
        &[(0b10010, &ENTRY_VULCANIZATION_3258864381780829761)],
        &[(0b10010, &ENTRY_VULCANIZATIONS_12614859722986396332)],
        &[(0b10010, &ENTRY_VULCANIZE_977902884734413931)],
        &[(0b10010, &ENTRY_VULCANIZED_15788444725575758612)],
        &[(0b10010, &ENTRY_VULCANIZER_3777087061043675341)],
        &[(0b10010, &ENTRY_VULCANIZERS_4164062164915178108)],
        &[(0b10010, &ENTRY_VULCANIZES_18094247566727839218)],
        &[(0b10010, &ENTRY_VULCANIZING_16179329893471043275)],
        &[(0b01001, &ENTRY_VULCANIZABLE_3568502198024878932)],
        &[(0b01001, &ENTRY_VULCANIZABLER_4054424358397582656)],
        &[(0b01001, &ENTRY_VULCANIZABLES_8379629917557167700)],
        &[(0b01001, &ENTRY_VULCANIZABLEST_6459505877444949673)],
        &[(0b01001, &ENTRY_VULCANIZATE_4795671622025524378)],
        &[(0b01001, &ENTRY_VULCANIZATES_16942202816352460180)],
        &[(0b01001, &ENTRY_VULCANIZATION_3258864381780829761)],
        &[(0b01001, &ENTRY_VULCANIZATIONS_12614859722986396332)],
        &[(0b01001, &ENTRY_VULCANIZE_977902884734413931)],
        &[(0b01001, &ENTRY_VULCANIZED_15788444725575758612)],
        &[(0b01001, &ENTRY_VULCANIZER_3777087061043675341)],
        &[(0b01001, &ENTRY_VULCANIZERS_4164062164915178108)],
        &[(0b01001, &ENTRY_VULCANIZES_18094247566727839218)],
        &[(0b01001, &ENTRY_VULCANIZING_16179329893471043275)],
        &[(0b10010, &ENTRY_VULGARIZATION_9399086175034751352)],
        &[(0b10010, &ENTRY_VULGARIZATIONS_17269033887487645821)],
        &[(0b10010, &ENTRY_VULGARIZE_3593216075985714450)],
        &[(0b10010, &ENTRY_VULGARIZED_16682935641229034184)],
        &[(0b10010, &ENTRY_VULGARIZER_11079564505577982456)],
        &[(0b10010, &ENTRY_VULGARIZERS_1013773146928265577)],
        &[(0b10010, &ENTRY_VULGARIZES_1421269681767890441)],
        &[(0b10010, &ENTRY_VULGARIZING_8957250676888139808)],
        &[(0b01001, &ENTRY_VULGARIZATION_9399086175034751352)],
        &[(0b01001, &ENTRY_VULGARIZATIONS_17269033887487645821)],
        &[(0b01001, &ENTRY_VULGARIZE_3593216075985714450)],
        &[(0b01001, &ENTRY_VULGARIZED_16682935641229034184)],
        &[(0b01001, &ENTRY_VULGARIZER_11079564505577982456)],
        &[(0b01001, &ENTRY_VULGARIZERS_1013773146928265577)],
        &[(0b01001, &ENTRY_VULGARIZES_1421269681767890441)],
        &[(0b01001, &ENTRY_VULGARIZING_8957250676888139808)],
    ],
    range: 7..=12,
};

static VARS_VO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VO_CHILDREN),
    value: None,
};

static VARS_VO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_VOC_NODE),
    None,
    Some(&VARS_VOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VOL_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VOW_NODE),
    None,
    None,
    None,
];

static VARS_VOW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VOW_CHILDREN),
    value: None,
};

pub static VARS_VOW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VOWELIZATION_989128645335163882)],
        &[(0b10010, &ENTRY_VOWELIZATIONS_5803231980451353684)],
        &[(0b10010, &ENTRY_VOWELIZE_18108634882497063258)],
        &[(0b10010, &ENTRY_VOWELIZED_10046225650144601473)],
        &[(0b10010, &ENTRY_VOWELIZES_10478314626294200903)],
        &[(0b10010, &ENTRY_VOWELIZING_1774578233754681336)],
        &[(0b01001, &ENTRY_VOWELIZATION_989128645335163882)],
        &[(0b01001, &ENTRY_VOWELIZATIONS_5803231980451353684)],
        &[(0b01001, &ENTRY_VOWELIZE_18108634882497063258)],
        &[(0b01001, &ENTRY_VOWELIZED_10046225650144601473)],
        &[(0b01001, &ENTRY_VOWELIZES_10478314626294200903)],
        &[(0b01001, &ENTRY_VOWELIZING_1774578233754681336)],
    ],
    range: 5..=10,
};

static VARS_VOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VOL_CHILDREN),
    value: None,
};

pub static VARS_VOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atilisable"),
        dictgen::InsensitiveStr::Ascii("atilisabler"),
        dictgen::InsensitiveStr::Ascii("atilisables"),
        dictgen::InsensitiveStr::Ascii("atilisablest"),
        dictgen::InsensitiveStr::Ascii("atilisation"),
        dictgen::InsensitiveStr::Ascii("atilisations"),
        dictgen::InsensitiveStr::Ascii("atilise"),
        dictgen::InsensitiveStr::Ascii("atilised"),
        dictgen::InsensitiveStr::Ascii("atiliser"),
        dictgen::InsensitiveStr::Ascii("atilisers"),
        dictgen::InsensitiveStr::Ascii("atilises"),
        dictgen::InsensitiveStr::Ascii("atilising"),
        dictgen::InsensitiveStr::Ascii("atilizable"),
        dictgen::InsensitiveStr::Ascii("atilizabler"),
        dictgen::InsensitiveStr::Ascii("atilizables"),
        dictgen::InsensitiveStr::Ascii("atilizablest"),
        dictgen::InsensitiveStr::Ascii("atilization"),
        dictgen::InsensitiveStr::Ascii("atilizations"),
        dictgen::InsensitiveStr::Ascii("atilize"),
        dictgen::InsensitiveStr::Ascii("atilized"),
        dictgen::InsensitiveStr::Ascii("atilizer"),
        dictgen::InsensitiveStr::Ascii("atilizers"),
        dictgen::InsensitiveStr::Ascii("atilizes"),
        dictgen::InsensitiveStr::Ascii("atilizing"),
        dictgen::InsensitiveStr::Ascii("canisation"),
        dictgen::InsensitiveStr::Ascii("canisations"),
        dictgen::InsensitiveStr::Ascii("canise"),
        dictgen::InsensitiveStr::Ascii("canised"),
        dictgen::InsensitiveStr::Ascii("canises"),
        dictgen::InsensitiveStr::Ascii("canising"),
        dictgen::InsensitiveStr::Ascii("canization"),
        dictgen::InsensitiveStr::Ascii("canizations"),
        dictgen::InsensitiveStr::Ascii("canize"),
        dictgen::InsensitiveStr::Ascii("canized"),
        dictgen::InsensitiveStr::Ascii("canizes"),
        dictgen::InsensitiveStr::Ascii("canizing"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VOLATILIZABLE_14191734210917893484)],
        &[(0b10010, &ENTRY_VOLATILIZABLER_10970801449329037349)],
        &[(0b10010, &ENTRY_VOLATILIZABLES_3387142756898266550)],
        &[(0b10010, &ENTRY_VOLATILIZABLEST_9951102031117910204)],
        &[(0b10010, &ENTRY_VOLATILIZATION_2524869946541654890)],
        &[(0b10010, &ENTRY_VOLATILIZATIONS_2738963093881521684)],
        &[(0b10010, &ENTRY_VOLATILIZE_12701439457008031789)],
        &[(0b10010, &ENTRY_VOLATILIZED_162413967292134988)],
        &[(0b10010, &ENTRY_VOLATILIZER_15355427557723391751)],
        &[(0b10010, &ENTRY_VOLATILIZERS_8351703320828050913)],
        &[(0b10010, &ENTRY_VOLATILIZES_1469470071448453292)],
        &[(0b10010, &ENTRY_VOLATILIZING_4582472073708524953)],
        &[(0b01001, &ENTRY_VOLATILIZABLE_14191734210917893484)],
        &[(0b01001, &ENTRY_VOLATILIZABLER_10970801449329037349)],
        &[(0b01001, &ENTRY_VOLATILIZABLES_3387142756898266550)],
        &[(0b01001, &ENTRY_VOLATILIZABLEST_9951102031117910204)],
        &[(0b01001, &ENTRY_VOLATILIZATION_2524869946541654890)],
        &[(0b01001, &ENTRY_VOLATILIZATIONS_2738963093881521684)],
        &[(0b01001, &ENTRY_VOLATILIZE_12701439457008031789)],
        &[(0b01001, &ENTRY_VOLATILIZED_162413967292134988)],
        &[(0b01001, &ENTRY_VOLATILIZER_15355427557723391751)],
        &[(0b01001, &ENTRY_VOLATILIZERS_8351703320828050913)],
        &[(0b01001, &ENTRY_VOLATILIZES_1469470071448453292)],
        &[(0b01001, &ENTRY_VOLATILIZING_4582472073708524953)],
        &[(0b10010, &ENTRY_VOLCANIZATION_15208079623603218405)],
        &[(0b10010, &ENTRY_VOLCANIZATIONS_11922563203603211916)],
        &[(0b10010, &ENTRY_VOLCANIZE_5966901671703511868)],
        &[(0b10010, &ENTRY_VOLCANIZED_7340807631500965062)],
        &[(0b10010, &ENTRY_VOLCANIZES_8125520318354745094)],
        &[(0b10010, &ENTRY_VOLCANIZING_17170908759013088769)],
        &[(0b01001, &ENTRY_VOLCANIZATION_15208079623603218405)],
        &[(0b01001, &ENTRY_VOLCANIZATIONS_11922563203603211916)],
        &[(0b01001, &ENTRY_VOLCANIZE_5966901671703511868)],
        &[(0b01001, &ENTRY_VOLCANIZED_7340807631500965062)],
        &[(0b01001, &ENTRY_VOLCANIZES_8125520318354745094)],
        &[(0b01001, &ENTRY_VOLCANIZING_17170908759013088769)],
        &[(0b10010, &ENTRY_VOLTIZE_7549036914115473442)],
        &[(0b10010, &ENTRY_VOLTIZES_16866957908997653386)],
        &[(0b01001, &ENTRY_VOLTIZE_7549036914115473442)],
        &[(0b01001, &ENTRY_VOLTIZES_16866957908997653386)],
    ],
    range: 4..=12,
};

static VARS_VOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VOE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_VE_18321759983148480762)]),
};

pub static VARS_VOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_VOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VOC_CHILDREN),
    value: None,
};

pub static VARS_VOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VOCALIZATION_16299156444456516020)],
        &[(0b10010, &ENTRY_VOCALIZATIONS_6540912521590792850)],
        &[(0b10010, &ENTRY_VOCALIZE_1522162759221483083)],
        &[(0b10010, &ENTRY_VOCALIZED_18024346592150936448)],
        &[(0b10010, &ENTRY_VOCALIZER_12799422523009315217)],
        &[(0b10010, &ENTRY_VOCALIZERS_5083157038348945833)],
        &[(0b10010, &ENTRY_VOCALIZES_1880412935306735877)],
        &[(0b10010, &ENTRY_VOCALIZING_6361847323758753459)],
        &[(0b01001, &ENTRY_VOCALIZATION_16299156444456516020)],
        &[(0b01001, &ENTRY_VOCALIZATIONS_6540912521590792850)],
        &[(0b01001, &ENTRY_VOCALIZE_1522162759221483083)],
        &[(0b01001, &ENTRY_VOCALIZED_18024346592150936448)],
        &[(0b01001, &ENTRY_VOCALIZER_12799422523009315217)],
        &[(0b01001, &ENTRY_VOCALIZERS_5083157038348945833)],
        &[(0b01001, &ENTRY_VOCALIZES_1880412935306735877)],
        &[(0b01001, &ENTRY_VOCALIZING_6361847323758753459)],
        &[(0b10010, &ENTRY_VOCATIONALIZATION_5843882192252215451)],
        &[(0b10010, &ENTRY_VOCATIONALIZATIONS_12760103465092649332)],
        &[(0b10010, &ENTRY_VOCATIONALIZE_11565960507105247770)],
        &[(0b10010, &ENTRY_VOCATIONALIZES_9469137790249815859)],
        &[(0b01001, &ENTRY_VOCATIONALIZATION_5843882192252215451)],
        &[(0b01001, &ENTRY_VOCATIONALIZATIONS_12760103465092649332)],
        &[(0b01001, &ENTRY_VOCATIONALIZE_11565960507105247770)],
        &[(0b01001, &ENTRY_VOCATIONALIZES_9469137790249815859)],
    ],
    range: 5..=15,
};

static VARS_VI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VI_CHILDREN),
    value: None,
};

static VARS_VI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_VIA_NODE),
    None,
    Some(&VARS_VIC_NODE),
    Some(&VARS_VID_NODE),
    Some(&VARS_VIE_NODE),
    None,
    Some(&VARS_VIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_VIL_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VIR_NODE),
    Some(&VARS_VIS_NODE),
    Some(&VARS_VIT_NODE),
    None,
    Some(&VARS_VIV_NODE),
    None,
    None,
    None,
    Some(&VARS_VIZ_NODE),
];

static VARS_VIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIZ_CHILDREN),
    value: None,
};

pub static VARS_VIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ard"),
        dictgen::InsensitiveStr::Ascii("ards"),
        dictgen::InsensitiveStr::Ascii("ied"),
        dictgen::InsensitiveStr::Ascii("ies"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
    ],
    values: &[
        &[(0b01001, &ENTRY_VIZARD_10999789749375739354)],
        &[(0b01001, &ENTRY_VIZARDS_6967258731291371717)],
        &[(0b01001, &ENTRY_VIZIED_7049215544631748789)],
        &[(0b01001, &ENTRY_VIZIES_2932586557445870650)],
        &[(0b10011, &ENTRY_VISOR_11952253766687812439)],
        &[(0b10011, &ENTRY_VISORS_161131917315397622)],
    ],
    range: 2..=4,
};

static VARS_VIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIV_CHILDREN),
    value: None,
};

pub static VARS_VIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andier"),
        dictgen::InsensitiveStr::Ascii("andire"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("errinae"),
        dictgen::InsensitiveStr::Ascii("errine"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("res"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VIVANDIER_12659384511325353809)],
        &[(0b11010, &ENTRY_VIVANDIER_12659384511325353809)],
        &[(0b00001, &ENTRY_VIVER_3159459969980561998)],
        &[(0b11010, &ENTRY_VIVERRINE_4631118611455296151)],
        &[(0b00001, &ENTRY_VIVERRINE_4631118611455296151)],
        &[(0b00001, &ENTRY_VIVERS_1304906869884388477)],
        &[(0b11010, &ENTRY_VIVER_3159459969980561998)],
        &[(0b11010, &ENTRY_VIVERS_1304906869884388477)],
    ],
    range: 2..=7,
};

static VARS_VIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIT_CHILDREN),
    value: None,
};

pub static VARS_VIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alisingly"),
        dictgen::InsensitiveStr::Ascii("alisings"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("alizingly"),
        dictgen::InsensitiveStr::Ascii("alizings"),
        dictgen::InsensitiveStr::Ascii("aminisation"),
        dictgen::InsensitiveStr::Ascii("aminise"),
        dictgen::InsensitiveStr::Ascii("aminised"),
        dictgen::InsensitiveStr::Ascii("aminises"),
        dictgen::InsensitiveStr::Ascii("aminising"),
        dictgen::InsensitiveStr::Ascii("aminization"),
        dictgen::InsensitiveStr::Ascii("aminize"),
        dictgen::InsensitiveStr::Ascii("aminized"),
        dictgen::InsensitiveStr::Ascii("aminizes"),
        dictgen::InsensitiveStr::Ascii("aminizing"),
        dictgen::InsensitiveStr::Ascii("riolisable"),
        dictgen::InsensitiveStr::Ascii("riolisables"),
        dictgen::InsensitiveStr::Ascii("riolisation"),
        dictgen::InsensitiveStr::Ascii("riolisations"),
        dictgen::InsensitiveStr::Ascii("riolise"),
        dictgen::InsensitiveStr::Ascii("riolised"),
        dictgen::InsensitiveStr::Ascii("rioliser"),
        dictgen::InsensitiveStr::Ascii("riolisers"),
        dictgen::InsensitiveStr::Ascii("riolises"),
        dictgen::InsensitiveStr::Ascii("riolising"),
        dictgen::InsensitiveStr::Ascii("riolizable"),
        dictgen::InsensitiveStr::Ascii("riolizables"),
        dictgen::InsensitiveStr::Ascii("riolization"),
        dictgen::InsensitiveStr::Ascii("riolizations"),
        dictgen::InsensitiveStr::Ascii("riolize"),
        dictgen::InsensitiveStr::Ascii("riolized"),
        dictgen::InsensitiveStr::Ascii("riolizer"),
        dictgen::InsensitiveStr::Ascii("riolizers"),
        dictgen::InsensitiveStr::Ascii("riolizes"),
        dictgen::InsensitiveStr::Ascii("riolizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VITALIZATION_11563378875657312422)],
        &[(0b10010, &ENTRY_VITALIZATIONS_18199586670931656342)],
        &[(0b10010, &ENTRY_VITALIZE_14767623916291210585)],
        &[(0b10010, &ENTRY_VITALIZED_5879957138765444190)],
        &[(0b10010, &ENTRY_VITALIZER_11015449244036225995)],
        &[(0b10010, &ENTRY_VITALIZERS_4676040118864720970)],
        &[(0b10010, &ENTRY_VITALIZES_6574062411877117887)],
        &[(0b10010, &ENTRY_VITALIZING_1172441218463801200)],
        &[(0b10010, &ENTRY_VITALIZINGLY_17977921766837363551)],
        &[(0b10010, &ENTRY_VITALIZINGS_7993175705382773400)],
        &[(0b01001, &ENTRY_VITALIZATION_11563378875657312422)],
        &[(0b01001, &ENTRY_VITALIZATIONS_18199586670931656342)],
        &[(0b01001, &ENTRY_VITALIZE_14767623916291210585)],
        &[(0b01001, &ENTRY_VITALIZED_5879957138765444190)],
        &[(0b01001, &ENTRY_VITALIZER_11015449244036225995)],
        &[(0b01001, &ENTRY_VITALIZERS_4676040118864720970)],
        &[(0b01001, &ENTRY_VITALIZES_6574062411877117887)],
        &[(0b01001, &ENTRY_VITALIZING_1172441218463801200)],
        &[(0b01001, &ENTRY_VITALIZINGLY_17977921766837363551)],
        &[(0b01001, &ENTRY_VITALIZINGS_7993175705382773400)],
        &[(0b10010, &ENTRY_VITAMINIZATION_4345576685277511178)],
        &[(0b10010, &ENTRY_VITAMINIZE_3815155023809780843)],
        &[(0b10010, &ENTRY_VITAMINIZED_11070966012909977792)],
        &[(0b10010, &ENTRY_VITAMINIZES_11610615403175719091)],
        &[(0b10010, &ENTRY_VITAMINIZING_14433390025156461290)],
        &[(0b01001, &ENTRY_VITAMINIZATION_4345576685277511178)],
        &[(0b01001, &ENTRY_VITAMINIZE_3815155023809780843)],
        &[(0b01001, &ENTRY_VITAMINIZED_11070966012909977792)],
        &[(0b01001, &ENTRY_VITAMINIZES_11610615403175719091)],
        &[(0b01001, &ENTRY_VITAMINIZING_14433390025156461290)],
        &[(0b10010, &ENTRY_VITRIOLIZABLE_10128808547473444732)],
        &[(0b10010, &ENTRY_VITRIOLIZABLES_6495066641769157690)],
        &[(0b10010, &ENTRY_VITRIOLIZATION_12177216141601047223)],
        &[(0b10010, &ENTRY_VITRIOLIZATIONS_12059310110149895869)],
        &[(0b10010, &ENTRY_VITRIOLIZE_16677616817185174970)],
        &[(0b10010, &ENTRY_VITRIOLIZED_726289364433095774)],
        &[(0b10010, &ENTRY_VITRIOLIZER_1822506942241343764)],
        &[(0b10010, &ENTRY_VITRIOLIZERS_1786300307817004832)],
        &[(0b10010, &ENTRY_VITRIOLIZES_12629386703569894013)],
        &[(0b10010, &ENTRY_VITRIOLIZING_9645904006126235201)],
        &[(0b01001, &ENTRY_VITRIOLIZABLE_10128808547473444732)],
        &[(0b01001, &ENTRY_VITRIOLIZABLES_6495066641769157690)],
        &[(0b01001, &ENTRY_VITRIOLIZATION_12177216141601047223)],
        &[(0b01001, &ENTRY_VITRIOLIZATIONS_12059310110149895869)],
        &[(0b01001, &ENTRY_VITRIOLIZE_16677616817185174970)],
        &[(0b01001, &ENTRY_VITRIOLIZED_726289364433095774)],
        &[(0b01001, &ENTRY_VITRIOLIZER_1822506942241343764)],
        &[(0b01001, &ENTRY_VITRIOLIZERS_1786300307817004832)],
        &[(0b01001, &ENTRY_VITRIOLIZES_12629386703569894013)],
        &[(0b01001, &ENTRY_VITRIOLIZING_9645904006126235201)],
    ],
    range: 5..=12,
};

static VARS_VIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIS_CHILDREN),
    value: None,
};

pub static VARS_VIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ard"),
        dictgen::InsensitiveStr::Ascii("ards"),
        dictgen::InsensitiveStr::Ascii("ied"),
        dictgen::InsensitiveStr::Ascii("ies"),
        dictgen::InsensitiveStr::Ascii("ionise"),
        dictgen::InsensitiveStr::Ascii("ionises"),
        dictgen::InsensitiveStr::Ascii("ionize"),
        dictgen::InsensitiveStr::Ascii("ionizes"),
        dictgen::InsensitiveStr::Ascii("ualisable"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualiser"),
        dictgen::InsensitiveStr::Ascii("ualisers"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualizable"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizer"),
        dictgen::InsensitiveStr::Ascii("ualizers"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VIZARD_10999789749375739354)],
        &[(0b10010, &ENTRY_VIZARDS_6967258731291371717)],
        &[(0b10010, &ENTRY_VIZIED_7049215544631748789)],
        &[(0b10010, &ENTRY_VIZIES_2932586557445870650)],
        &[(0b10010, &ENTRY_VISIONIZE_3799273824415270214)],
        &[(0b10010, &ENTRY_VISIONIZES_18286863748296097590)],
        &[(0b01001, &ENTRY_VISIONIZE_3799273824415270214)],
        &[(0b01001, &ENTRY_VISIONIZES_18286863748296097590)],
        &[(0b10010, &ENTRY_VISUALIZABLE_7962038464582692957)],
        &[(0b10010, &ENTRY_VISUALIZATION_18445006641756380637)],
        &[(0b10010, &ENTRY_VISUALIZATIONS_14330999670741801492)],
        &[(0b10010, &ENTRY_VISUALIZE_14218254075459395624)],
        &[(0b10010, &ENTRY_VISUALIZED_4913836830057768977)],
        &[(0b10010, &ENTRY_VISUALIZER_6771531166983832662)],
        &[(0b10010, &ENTRY_VISUALIZERS_5162859868708280179)],
        &[(0b10010, &ENTRY_VISUALIZES_1129887224614498129)],
        &[(0b10010, &ENTRY_VISUALIZING_8411182104988658747)],
        &[(0b01001, &ENTRY_VISUALIZABLE_7962038464582692957)],
        &[(0b01001, &ENTRY_VISUALIZATION_18445006641756380637)],
        &[(0b01001, &ENTRY_VISUALIZATIONS_14330999670741801492)],
        &[(0b01001, &ENTRY_VISUALIZE_14218254075459395624)],
        &[(0b01001, &ENTRY_VISUALIZED_4913836830057768977)],
        &[(0b01001, &ENTRY_VISUALIZER_6771531166983832662)],
        &[(0b01001, &ENTRY_VISUALIZERS_5162859868708280179)],
        &[(0b01001, &ENTRY_VISUALIZES_1129887224614498129)],
        &[(0b01001, &ENTRY_VISUALIZING_8411182104988658747)],
    ],
    range: 3..=11,
};

static VARS_VIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIR_CHILDREN),
    value: None,
};

pub static VARS_VIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemias"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("tualisation"),
        dictgen::InsensitiveStr::Ascii("tualise"),
        dictgen::InsensitiveStr::Ascii("tualises"),
        dictgen::InsensitiveStr::Ascii("tualization"),
        dictgen::InsensitiveStr::Ascii("tualize"),
        dictgen::InsensitiveStr::Ascii("tualizes"),
        dictgen::InsensitiveStr::Ascii("tuosoes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_VIREMIA_1841488076881209053)],
        &[(0b11010, &ENTRY_VIREMIAS_7267662670115422503)],
        &[(0b11010, &ENTRY_VIREMIC_6601391614385695738)],
        &[(0b11010, &ENTRY_VIER_10758602254813181277)],
        &[(0b00001, &ENTRY_VIREMIA_1841488076881209053)],
        &[(0b00001, &ENTRY_VIREMIAS_7267662670115422503)],
        &[(0b00001, &ENTRY_VIREMIC_6601391614385695738)],
        &[(0b11010, &ENTRY_VIERS_10473285009744197700)],
        &[(0b10010, &ENTRY_VIRILIZATION_17984148691371003559)],
        &[(0b10010, &ENTRY_VIRILIZATIONS_2259339284050725137)],
        &[(0b10010, &ENTRY_VIRILIZED_14042124459396072676)],
        &[(0b10010, &ENTRY_VIRILIZING_3864311870427123549)],
        &[(0b01001, &ENTRY_VIRILIZATION_17984148691371003559)],
        &[(0b01001, &ENTRY_VIRILIZATIONS_2259339284050725137)],
        &[(0b01001, &ENTRY_VIRILIZED_14042124459396072676)],
        &[(0b01001, &ENTRY_VIRILIZING_3864311870427123549)],
        &[(0b11010, &ENTRY_VIRTUALIZATION_8096145334874168940)],
        &[(0b10010, &ENTRY_VIRTUALIZE_5037242355249715652)],
        &[(0b10010, &ENTRY_VIRTUALIZES_1664114726545811102)],
        &[(0b00001, &ENTRY_VIRTUALIZATION_8096145334874168940)],
        &[(0b01001, &ENTRY_VIRTUALIZE_5037242355249715652)],
        &[(0b01001, &ENTRY_VIRTUALIZES_1664114726545811102)],
        &[(0b00001, &ENTRY_VIRTUOSI_6032024204705561293)],
    ],
    range: 1..=11,
};

static VARS_VIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIL_CHILDREN),
    value: None,
};

pub static VARS_VIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lagisation"),
        dictgen::InsensitiveStr::Ascii("lagisations"),
        dictgen::InsensitiveStr::Ascii("lagization"),
        dictgen::InsensitiveStr::Ascii("lagizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VILLAGIZATION_3904516988221777458)],
        &[(0b10010, &ENTRY_VILLAGIZATIONS_11494631120078954743)],
        &[(0b01001, &ENTRY_VILLAGIZATION_3904516988221777458)],
        &[(0b01001, &ENTRY_VILLAGIZATIONS_11494631120078954743)],
    ],
    range: 10..=11,
};

static VARS_VIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIG_CHILDREN),
    value: None,
};

pub static VARS_VIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_VIGOR_4255508283031723378)],
        &[(0b00001, &ENTRY_VIGORLESS_8298894391042086723)],
        &[(0b11001, &ENTRY_VIGORS_7078003063773531029)],
        &[(0b11010, &ENTRY_VIGOR_4255508283031723378)],
        &[(0b11010, &ENTRY_VIGORLESS_8298894391042086723)],
        &[(0b11010, &ENTRY_VIGORS_7078003063773531029)],
    ],
    range: 2..=7,
};

static VARS_VIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIE_CHILDREN),
    value: None,
};

pub static VARS_VIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("tnamisation"),
        dictgen::InsensitiveStr::Ascii("tnamise"),
        dictgen::InsensitiveStr::Ascii("tnamised"),
        dictgen::InsensitiveStr::Ascii("tnamises"),
        dictgen::InsensitiveStr::Ascii("tnamising"),
        dictgen::InsensitiveStr::Ascii("tnamization"),
        dictgen::InsensitiveStr::Ascii("tnamize"),
        dictgen::InsensitiveStr::Ascii("tnamized"),
        dictgen::InsensitiveStr::Ascii("tnamizes"),
        dictgen::InsensitiveStr::Ascii("tnamizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VIER_10758602254813181277)],
        &[(0b00001, &ENTRY_VIERS_10473285009744197700)],
        &[(0b10010, &ENTRY_VIETNAMIZATION_4722543635437789217)],
        &[(0b10010, &ENTRY_VIETNAMIZE_14928666003292211538)],
        &[(0b10010, &ENTRY_VIETNAMIZED_4541312385379938819)],
        &[(0b10010, &ENTRY_VIETNAMIZES_8386876976890033192)],
        &[(0b10010, &ENTRY_VIETNAMIZING_9657833441293397796)],
        &[(0b01001, &ENTRY_VIETNAMIZATION_4722543635437789217)],
        &[(0b01001, &ENTRY_VIETNAMIZE_14928666003292211538)],
        &[(0b01001, &ENTRY_VIETNAMIZED_4541312385379938819)],
        &[(0b01001, &ENTRY_VIETNAMIZES_8386876976890033192)],
        &[(0b01001, &ENTRY_VIETNAMIZING_9657833441293397796)],
    ],
    range: 1..=11,
};

static VARS_VID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VID_CHILDREN),
    value: None,
};

pub static VARS_VID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eodisk"),
        dictgen::InsensitiveStr::Ascii("eodisks"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VIDEODISC_4085471265875741194)],
        &[(0b00001, &ENTRY_VIDEODISCS_8893076495672262384)],
    ],
    range: 6..=7,
};

static VARS_VIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIC_CHILDREN),
    value: None,
};

pub static VARS_VIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("timisable"),
        dictgen::InsensitiveStr::Ascii("timisables"),
        dictgen::InsensitiveStr::Ascii("timisation"),
        dictgen::InsensitiveStr::Ascii("timisations"),
        dictgen::InsensitiveStr::Ascii("timise"),
        dictgen::InsensitiveStr::Ascii("timised"),
        dictgen::InsensitiveStr::Ascii("timiser"),
        dictgen::InsensitiveStr::Ascii("timisers"),
        dictgen::InsensitiveStr::Ascii("timises"),
        dictgen::InsensitiveStr::Ascii("timising"),
        dictgen::InsensitiveStr::Ascii("timizable"),
        dictgen::InsensitiveStr::Ascii("timizables"),
        dictgen::InsensitiveStr::Ascii("timization"),
        dictgen::InsensitiveStr::Ascii("timizations"),
        dictgen::InsensitiveStr::Ascii("timize"),
        dictgen::InsensitiveStr::Ascii("timized"),
        dictgen::InsensitiveStr::Ascii("timizer"),
        dictgen::InsensitiveStr::Ascii("timizers"),
        dictgen::InsensitiveStr::Ascii("timizes"),
        dictgen::InsensitiveStr::Ascii("timizing"),
        dictgen::InsensitiveStr::Ascii("torianise"),
        dictgen::InsensitiveStr::Ascii("torianises"),
        dictgen::InsensitiveStr::Ascii("torianize"),
        dictgen::InsensitiveStr::Ascii("torianizes"),
        dictgen::InsensitiveStr::Ascii("tualage"),
        dictgen::InsensitiveStr::Ascii("tualages"),
        dictgen::InsensitiveStr::Ascii("tualed"),
        dictgen::InsensitiveStr::Ascii("tualer"),
        dictgen::InsensitiveStr::Ascii("tualers"),
        dictgen::InsensitiveStr::Ascii("tualess"),
        dictgen::InsensitiveStr::Ascii("tualing"),
        dictgen::InsensitiveStr::Ascii("tuallage"),
        dictgen::InsensitiveStr::Ascii("tuallages"),
        dictgen::InsensitiveStr::Ascii("tualled"),
        dictgen::InsensitiveStr::Ascii("tualler"),
        dictgen::InsensitiveStr::Ascii("tuallers"),
        dictgen::InsensitiveStr::Ascii("tualless"),
        dictgen::InsensitiveStr::Ascii("tualling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VICTIMIZABLE_17859456941815780193)],
        &[(0b10010, &ENTRY_VICTIMIZABLES_1207522680409246759)],
        &[(0b10010, &ENTRY_VICTIMIZATION_13826269504308493839)],
        &[(0b10010, &ENTRY_VICTIMIZATIONS_14899906545794033733)],
        &[(0b10010, &ENTRY_VICTIMIZE_14299551425382354965)],
        &[(0b10010, &ENTRY_VICTIMIZED_12606813743201188153)],
        &[(0b10010, &ENTRY_VICTIMIZER_13906638213650914285)],
        &[(0b10010, &ENTRY_VICTIMIZERS_13260960052208526566)],
        &[(0b10010, &ENTRY_VICTIMIZES_7043365108562081976)],
        &[(0b10010, &ENTRY_VICTIMIZING_2146280365921517894)],
        &[(0b01001, &ENTRY_VICTIMIZABLE_17859456941815780193)],
        &[(0b01001, &ENTRY_VICTIMIZABLES_1207522680409246759)],
        &[(0b01001, &ENTRY_VICTIMIZATION_13826269504308493839)],
        &[(0b01001, &ENTRY_VICTIMIZATIONS_14899906545794033733)],
        &[(0b01001, &ENTRY_VICTIMIZE_14299551425382354965)],
        &[(0b01001, &ENTRY_VICTIMIZED_12606813743201188153)],
        &[(0b01001, &ENTRY_VICTIMIZER_13906638213650914285)],
        &[(0b01001, &ENTRY_VICTIMIZERS_13260960052208526566)],
        &[(0b01001, &ENTRY_VICTIMIZES_7043365108562081976)],
        &[(0b01001, &ENTRY_VICTIMIZING_2146280365921517894)],
        &[(0b10010, &ENTRY_VICTORIANIZE_6350658122976337243)],
        &[(0b10010, &ENTRY_VICTORIANIZES_10077169725694243555)],
        &[(0b01001, &ENTRY_VICTORIANIZE_6350658122976337243)],
        &[(0b01001, &ENTRY_VICTORIANIZES_10077169725694243555)],
        &[(0b00001, &ENTRY_VICTUALAGE_11748837061098354479)],
        &[(0b00001, &ENTRY_VICTUALAGES_1602498729217236921)],
        &[(0b00001, &ENTRY_VICTUALED_3906018588064117729)],
        &[(0b00001, &ENTRY_VICTUALER_6754560860965136910)],
        &[(0b00001, &ENTRY_VICTUALERS_3647699329720955367)],
        &[(0b00001, &ENTRY_VICTUALESS_4554391893102998851)],
        &[(0b00001, &ENTRY_VICTUALING_14956768953788562589)],
        &[(0b11010, &ENTRY_VICTUALAGE_11748837061098354479)],
        &[(0b11010, &ENTRY_VICTUALAGES_1602498729217236921)],
        &[(0b11010, &ENTRY_VICTUALED_3906018588064117729)],
        &[(0b11010, &ENTRY_VICTUALER_6754560860965136910)],
        &[(0b11010, &ENTRY_VICTUALERS_3647699329720955367)],
        &[(0b11010, &ENTRY_VICTUALESS_4554391893102998851)],
        &[(0b11010, &ENTRY_VICTUALING_14956768953788562589)],
    ],
    range: 6..=11,
};

static VARS_VIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VIA_CHILDREN),
    value: None,
};

pub static VARS_VIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VIALED_9232052728666801517)],
        &[(0b00001, &ENTRY_VIALING_4586545000054977864)],
        &[(0b11010, &ENTRY_VIALED_9232052728666801517)],
        &[(0b11010, &ENTRY_VIALING_4586545000054977864)],
    ],
    range: 3..=5,
};

static VARS_VE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_VE_18321759983148480762)]),
};

static VARS_VE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_VEC_NODE),
    None,
    Some(&VARS_VEE_NODE),
    None,
    Some(&VARS_VEG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_VEL_NODE),
    None,
    Some(&VARS_VEN_NODE),
    None,
    None,
    None,
    Some(&VARS_VER_NODE),
    Some(&VARS_VES_NODE),
    Some(&VARS_VET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_VET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VET_CHILDREN),
    value: None,
};

pub static VARS_VET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("eranise"),
        dictgen::InsensitiveStr::Ascii("eranises"),
        dictgen::InsensitiveStr::Ascii("eranize"),
        dictgen::InsensitiveStr::Ascii("eranizes"),
        dictgen::InsensitiveStr::Ascii("oer"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VETER_13843276293183836593)],
        &[(0b10010, &ENTRY_VETERANIZE_9438252469704632209)],
        &[(0b10010, &ENTRY_VETERANIZES_11256585660882985870)],
        &[(0b01001, &ENTRY_VETERANIZE_9438252469704632209)],
        &[(0b01001, &ENTRY_VETERANIZES_11256585660882985870)],
        &[(0b11010, &ENTRY_VETER_13843276293183836593)],
    ],
    range: 2..=8,
};

static VARS_VES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VES_CHILDREN),
    value: None,
};

pub static VARS_VES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iculae"),
        dictgen::InsensitiveStr::Ascii("icule"),
        dictgen::InsensitiveStr::Ascii("tryise"),
        dictgen::InsensitiveStr::Ascii("tryises"),
        dictgen::InsensitiveStr::Ascii("tryize"),
        dictgen::InsensitiveStr::Ascii("tryizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_VESICULE_13319860871922937249)],
        &[(0b00001, &ENTRY_VESICULE_13319860871922937249)],
        &[(0b10010, &ENTRY_VESTRYIZE_2427050586639943215)],
        &[(0b10010, &ENTRY_VESTRYIZES_2842047993646822066)],
        &[(0b01001, &ENTRY_VESTRYIZE_2427050586639943215)],
        &[(0b01001, &ENTRY_VESTRYIZES_2842047993646822066)],
    ],
    range: 5..=7,
};

static VARS_VER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VER_CHILDREN),
    value: None,
};

pub static VARS_VER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("balisation"),
        dictgen::InsensitiveStr::Ascii("balisations"),
        dictgen::InsensitiveStr::Ascii("balise"),
        dictgen::InsensitiveStr::Ascii("balised"),
        dictgen::InsensitiveStr::Ascii("baliser"),
        dictgen::InsensitiveStr::Ascii("balisers"),
        dictgen::InsensitiveStr::Ascii("balises"),
        dictgen::InsensitiveStr::Ascii("balising"),
        dictgen::InsensitiveStr::Ascii("balization"),
        dictgen::InsensitiveStr::Ascii("balizations"),
        dictgen::InsensitiveStr::Ascii("balize"),
        dictgen::InsensitiveStr::Ascii("balized"),
        dictgen::InsensitiveStr::Ascii("balizer"),
        dictgen::InsensitiveStr::Ascii("balizers"),
        dictgen::InsensitiveStr::Ascii("balizes"),
        dictgen::InsensitiveStr::Ascii("balizing"),
        dictgen::InsensitiveStr::Ascii("ey"),
        dictgen::InsensitiveStr::Ascii("meiled"),
        dictgen::InsensitiveStr::Ascii("meiles"),
        dictgen::InsensitiveStr::Ascii("meiling"),
        dictgen::InsensitiveStr::Ascii("meilled"),
        dictgen::InsensitiveStr::Ascii("meilles"),
        dictgen::InsensitiveStr::Ascii("meilling"),
        dictgen::InsensitiveStr::Ascii("milionise"),
        dictgen::InsensitiveStr::Ascii("milionises"),
        dictgen::InsensitiveStr::Ascii("milionize"),
        dictgen::InsensitiveStr::Ascii("milionizes"),
        dictgen::InsensitiveStr::Ascii("nacularisation"),
        dictgen::InsensitiveStr::Ascii("nacularisations"),
        dictgen::InsensitiveStr::Ascii("nacularise"),
        dictgen::InsensitiveStr::Ascii("nacularised"),
        dictgen::InsensitiveStr::Ascii("nacularises"),
        dictgen::InsensitiveStr::Ascii("nacularising"),
        dictgen::InsensitiveStr::Ascii("nacularization"),
        dictgen::InsensitiveStr::Ascii("nacularizations"),
        dictgen::InsensitiveStr::Ascii("nacularize"),
        dictgen::InsensitiveStr::Ascii("nacularized"),
        dictgen::InsensitiveStr::Ascii("nacularizes"),
        dictgen::InsensitiveStr::Ascii("nacularizing"),
        dictgen::InsensitiveStr::Ascii("nalisation"),
        dictgen::InsensitiveStr::Ascii("nalisations"),
        dictgen::InsensitiveStr::Ascii("nalise"),
        dictgen::InsensitiveStr::Ascii("nalised"),
        dictgen::InsensitiveStr::Ascii("nalises"),
        dictgen::InsensitiveStr::Ascii("nalising"),
        dictgen::InsensitiveStr::Ascii("nalization"),
        dictgen::InsensitiveStr::Ascii("nalizations"),
        dictgen::InsensitiveStr::Ascii("nalize"),
        dictgen::InsensitiveStr::Ascii("nalized"),
        dictgen::InsensitiveStr::Ascii("nalizes"),
        dictgen::InsensitiveStr::Ascii("nalizing"),
        dictgen::InsensitiveStr::Ascii("sicolor"),
        dictgen::InsensitiveStr::Ascii("sicolorate"),
        dictgen::InsensitiveStr::Ascii("sicolored"),
        dictgen::InsensitiveStr::Ascii("sicolorous"),
        dictgen::InsensitiveStr::Ascii("sicolour"),
        dictgen::InsensitiveStr::Ascii("sicolourate"),
        dictgen::InsensitiveStr::Ascii("sicoloured"),
        dictgen::InsensitiveStr::Ascii("sicolourous"),
        dictgen::InsensitiveStr::Ascii("sionise"),
        dictgen::InsensitiveStr::Ascii("sionises"),
        dictgen::InsensitiveStr::Ascii("sionize"),
        dictgen::InsensitiveStr::Ascii("sionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VERBALIZATION_1606887602703040047)],
        &[(0b10010, &ENTRY_VERBALIZATIONS_10614435035631184613)],
        &[(0b10010, &ENTRY_VERBALIZE_8914927163486915483)],
        &[(0b10010, &ENTRY_VERBALIZED_3584116992871405343)],
        &[(0b10010, &ENTRY_VERBALIZER_5476531062608223227)],
        &[(0b10010, &ENTRY_VERBALIZERS_13686674633988019779)],
        &[(0b10010, &ENTRY_VERBALIZES_9773922676702933955)],
        &[(0b10010, &ENTRY_VERBALIZING_4674155461307593201)],
        &[(0b01001, &ENTRY_VERBALIZATION_1606887602703040047)],
        &[(0b01001, &ENTRY_VERBALIZATIONS_10614435035631184613)],
        &[(0b01001, &ENTRY_VERBALIZE_8914927163486915483)],
        &[(0b01001, &ENTRY_VERBALIZED_3584116992871405343)],
        &[(0b01001, &ENTRY_VERBALIZER_5476531062608223227)],
        &[(0b01001, &ENTRY_VERBALIZERS_13686674633988019779)],
        &[(0b01001, &ENTRY_VERBALIZES_9773922676702933955)],
        &[(0b01001, &ENTRY_VERBALIZING_4674155461307593201)],
        &[(0b11010, &ENTRY_VEERY_7871806231150043123)],
        &[(0b00001, &ENTRY_VERMEILED_3870685009631656496)],
        &[(0b00001, &ENTRY_VERMEILES_6091101275731102631)],
        &[(0b00001, &ENTRY_VERMEILING_16263718376783682636)],
        &[(0b11010, &ENTRY_VERMEILED_3870685009631656496)],
        &[(0b11010, &ENTRY_VERMEILES_6091101275731102631)],
        &[(0b11010, &ENTRY_VERMEILING_16263718376783682636)],
        &[(0b10010, &ENTRY_VERMILIONIZE_1285328019998267214)],
        &[(0b10010, &ENTRY_VERMILIONIZES_12599262771675475462)],
        &[(0b01001, &ENTRY_VERMILIONIZE_1285328019998267214)],
        &[(0b01001, &ENTRY_VERMILIONIZES_12599262771675475462)],
        &[(0b10010, &ENTRY_VERNACULARIZATION_8027917640062920182)],
        &[(0b10010, &ENTRY_VERNACULARIZATIONS_14415525320546941498)],
        &[(0b10010, &ENTRY_VERNACULARIZE_12667767946887279081)],
        &[(0b10010, &ENTRY_VERNACULARIZED_12492141793786233950)],
        &[(0b10010, &ENTRY_VERNACULARIZES_15960776775823268746)],
        &[(0b10010, &ENTRY_VERNACULARIZING_10081295290347631824)],
        &[(0b01001, &ENTRY_VERNACULARIZATION_8027917640062920182)],
        &[(0b01001, &ENTRY_VERNACULARIZATIONS_14415525320546941498)],
        &[(0b01001, &ENTRY_VERNACULARIZE_12667767946887279081)],
        &[(0b01001, &ENTRY_VERNACULARIZED_12492141793786233950)],
        &[(0b01001, &ENTRY_VERNACULARIZES_15960776775823268746)],
        &[(0b01001, &ENTRY_VERNACULARIZING_10081295290347631824)],
        &[(0b10010, &ENTRY_VERNALIZATION_11355184477337865623)],
        &[(0b10010, &ENTRY_VERNALIZATIONS_4660850075716999699)],
        &[(0b10010, &ENTRY_VERNALIZE_12962724599289195261)],
        &[(0b10010, &ENTRY_VERNALIZED_10973377624262151914)],
        &[(0b10010, &ENTRY_VERNALIZES_5256099709798243477)],
        &[(0b10010, &ENTRY_VERNALIZING_10128158728667959931)],
        &[(0b01001, &ENTRY_VERNALIZATION_11355184477337865623)],
        &[(0b01001, &ENTRY_VERNALIZATIONS_4660850075716999699)],
        &[(0b01001, &ENTRY_VERNALIZE_12962724599289195261)],
        &[(0b01001, &ENTRY_VERNALIZED_10973377624262151914)],
        &[(0b01001, &ENTRY_VERNALIZES_5256099709798243477)],
        &[(0b01001, &ENTRY_VERNALIZING_10128158728667959931)],
        &[(0b00001, &ENTRY_VERSICOLOR_1583338907759165683)],
        &[(0b00001, &ENTRY_VERSICOLORATE_1213108598258359303)],
        &[(0b00001, &ENTRY_VERSICOLORED_8698649720277268404)],
        &[(0b00001, &ENTRY_VERSICOLOROUS_17729000221904743199)],
        &[(0b11010, &ENTRY_VERSICOLOR_1583338907759165683)],
        &[(0b11010, &ENTRY_VERSICOLORATE_1213108598258359303)],
        &[(0b11010, &ENTRY_VERSICOLORED_8698649720277268404)],
        &[(0b11010, &ENTRY_VERSICOLOROUS_17729000221904743199)],
        &[(0b10010, &ENTRY_VERSIONIZE_13036102572385152608)],
        &[(0b10010, &ENTRY_VERSIONIZES_14825603837161816590)],
        &[(0b01001, &ENTRY_VERSIONIZE_13036102572385152608)],
        &[(0b01001, &ENTRY_VERSIONIZES_14825603837161816590)],
    ],
    range: 2..=15,
};

static VARS_VEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEN_CHILDREN),
    value: None,
};

pub static VARS_VEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("der"),
        dictgen::InsensitiveStr::Ascii("ders"),
        dictgen::InsensitiveStr::Ascii("omisation"),
        dictgen::InsensitiveStr::Ascii("omisations"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omization"),
        dictgen::InsensitiveStr::Ascii("omizations"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
        dictgen::InsensitiveStr::Ascii("triloquise"),
        dictgen::InsensitiveStr::Ascii("triloquised"),
        dictgen::InsensitiveStr::Ascii("triloquises"),
        dictgen::InsensitiveStr::Ascii("triloquising"),
        dictgen::InsensitiveStr::Ascii("triloquize"),
        dictgen::InsensitiveStr::Ascii("triloquized"),
        dictgen::InsensitiveStr::Ascii("triloquizes"),
        dictgen::InsensitiveStr::Ascii("triloquizing"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VENALIZATION_2122570152538799298)],
        &[(0b10010, &ENTRY_VENALIZATIONS_2118690871234046077)],
        &[(0b10010, &ENTRY_VENALIZE_17116259915286472347)],
        &[(0b10010, &ENTRY_VENALIZES_17850293216838309236)],
        &[(0b01001, &ENTRY_VENALIZATION_2122570152538799298)],
        &[(0b01001, &ENTRY_VENALIZATIONS_2118690871234046077)],
        &[(0b01001, &ENTRY_VENALIZE_17116259915286472347)],
        &[(0b01001, &ENTRY_VENALIZES_17850293216838309236)],
        &[(0b00001, &ENTRY_VENDOR_2662061828917411576)],
        &[(0b00001, &ENTRY_VENDORS_995846644620124863)],
        &[(0b10010, &ENTRY_VENOMIZATION_15358943620485615148)],
        &[(0b10010, &ENTRY_VENOMIZATIONS_15701983704376518542)],
        &[(0b10010, &ENTRY_VENOMIZE_18257057476761108930)],
        &[(0b10010, &ENTRY_VENOMIZES_16197925629249240457)],
        &[(0b01001, &ENTRY_VENOMIZATION_15358943620485615148)],
        &[(0b01001, &ENTRY_VENOMIZATIONS_15701983704376518542)],
        &[(0b01001, &ENTRY_VENOMIZE_18257057476761108930)],
        &[(0b01001, &ENTRY_VENOMIZES_16197925629249240457)],
        &[(0b00001, &ENTRY_VENTER_10510516635110887923)],
        &[(0b00001, &ENTRY_VENTERS_5205786364593283296)],
        &[(0b11010, &ENTRY_VENTER_10510516635110887923)],
        &[(0b11010, &ENTRY_VENTERS_5205786364593283296)],
        &[(0b10010, &ENTRY_VENTRILOQUIZE_7278912386074535832)],
        &[(0b10010, &ENTRY_VENTRILOQUIZED_17464849051904807365)],
        &[(0b10010, &ENTRY_VENTRILOQUIZES_7366719022132000191)],
        &[(0b10010, &ENTRY_VENTRILOQUIZING_16373058130648158850)],
        &[(0b01001, &ENTRY_VENTRILOQUIZE_7278912386074535832)],
        &[(0b01001, &ENTRY_VENTRILOQUIZED_17464849051904807365)],
        &[(0b01001, &ENTRY_VENTRILOQUIZES_7366719022132000191)],
        &[(0b01001, &ENTRY_VENTRILOQUIZING_16373058130648158850)],
        &[(0b11010, &ENTRY_VENULE_16081436179391149786)],
        &[(0b00001, &ENTRY_VENULE_16081436179391149786)],
    ],
    range: 3..=12,
};

static VARS_VEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEL_CHILDREN),
    value: None,
};

pub static VARS_VEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arisation"),
        dictgen::InsensitiveStr::Ascii("arisations"),
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arization"),
        dictgen::InsensitiveStr::Ascii("arizations"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VELARIZATION_1403990956820502853)],
        &[(0b10010, &ENTRY_VELARIZATIONS_14651119125598343114)],
        &[(0b10010, &ENTRY_VELARIZE_4143880025810776209)],
        &[(0b10010, &ENTRY_VELARIZED_17587151593626429889)],
        &[(0b10010, &ENTRY_VELARIZES_7541885077312241167)],
        &[(0b10010, &ENTRY_VELARIZING_10043182753015176040)],
        &[(0b01001, &ENTRY_VELARIZATION_1403990956820502853)],
        &[(0b01001, &ENTRY_VELARIZATIONS_14651119125598343114)],
        &[(0b01001, &ENTRY_VELARIZE_4143880025810776209)],
        &[(0b01001, &ENTRY_VELARIZED_17587151593626429889)],
        &[(0b01001, &ENTRY_VELARIZES_7541885077312241167)],
        &[(0b01001, &ENTRY_VELARIZING_10043182753015176040)],
    ],
    range: 5..=10,
};

static VARS_VEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEG_CHILDREN),
    value: None,
};

pub static VARS_VEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etablise"),
        dictgen::InsensitiveStr::Ascii("etablises"),
        dictgen::InsensitiveStr::Ascii("etablize"),
        dictgen::InsensitiveStr::Ascii("etablizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VEGETABLIZE_15652329865549979869)],
        &[(0b10010, &ENTRY_VEGETABLIZES_6567628138079375237)],
        &[(0b01001, &ENTRY_VEGETABLIZE_15652329865549979869)],
        &[(0b01001, &ENTRY_VEGETABLIZES_6567628138079375237)],
    ],
    range: 8..=9,
};

static VARS_VEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEE_CHILDREN),
    value: None,
};

pub static VARS_VEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ry")],
    values: &[&[(0b00001, &ENTRY_VEERY_7871806231150043123)]],
    range: 2..=2,
};

static VARS_VEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VEC_CHILDREN),
    value: None,
};

pub static VARS_VEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("torisable"),
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("toriser"),
        dictgen::InsensitiveStr::Ascii("torisered"),
        dictgen::InsensitiveStr::Ascii("torisering"),
        dictgen::InsensitiveStr::Ascii("torisers"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torising"),
        dictgen::InsensitiveStr::Ascii("torizable"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizer"),
        dictgen::InsensitiveStr::Ascii("torizered"),
        dictgen::InsensitiveStr::Ascii("torizering"),
        dictgen::InsensitiveStr::Ascii("torizers"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("torizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VECTORIZABLE_4166695678492588499)],
        &[(0b10010, &ENTRY_VECTORIZATION_9106141310054062019)],
        &[(0b10010, &ENTRY_VECTORIZATIONS_465401059387640876)],
        &[(0b10010, &ENTRY_VECTORIZE_13096018160775133343)],
        &[(0b10010, &ENTRY_VECTORIZED_13224707387286509209)],
        &[(0b10010, &ENTRY_VECTORIZER_12091376211856766051)],
        &[(0b10010, &ENTRY_VECTORIZERED_9703684870141080163)],
        &[(0b10010, &ENTRY_VECTORIZERING_15878663610053146444)],
        &[(0b10010, &ENTRY_VECTORIZERS_9835891468155617)],
        &[(0b10010, &ENTRY_VECTORIZES_7917294144821648305)],
        &[(0b10010, &ENTRY_VECTORIZING_9538566325910673128)],
        &[(0b01001, &ENTRY_VECTORIZABLE_4166695678492588499)],
        &[(0b01001, &ENTRY_VECTORIZATION_9106141310054062019)],
        &[(0b01001, &ENTRY_VECTORIZATIONS_465401059387640876)],
        &[(0b01001, &ENTRY_VECTORIZE_13096018160775133343)],
        &[(0b01001, &ENTRY_VECTORIZED_13224707387286509209)],
        &[(0b01001, &ENTRY_VECTORIZER_12091376211856766051)],
        &[(0b01001, &ENTRY_VECTORIZERED_9703684870141080163)],
        &[(0b01001, &ENTRY_VECTORIZERING_15878663610053146444)],
        &[(0b01001, &ENTRY_VECTORIZERS_9835891468155617)],
        &[(0b01001, &ENTRY_VECTORIZES_7917294144821648305)],
        &[(0b01001, &ENTRY_VECTORIZING_9538566325910673128)],
    ],
    range: 6..=11,
};

static VARS_VA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VA_CHILDREN),
    value: None,
};

static VARS_VA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_VAA_NODE),
    None,
    Some(&VARS_VAC_NODE),
    None,
    None,
    None,
    Some(&VARS_VAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_VAL_NODE),
    Some(&VARS_VAM_NODE),
    Some(&VARS_VAN_NODE),
    None,
    Some(&VARS_VAP_NODE),
    None,
    Some(&VARS_VAR_NODE),
    Some(&VARS_VAS_NODE),
    Some(&VARS_VAT_NODE),
    None,
    Some(&VARS_VAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_VAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAV_CHILDREN),
    value: None,
};

pub static VARS_VAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("asor"),
        dictgen::InsensitiveStr::Ascii("asors"),
        dictgen::InsensitiveStr::Ascii("asour"),
        dictgen::InsensitiveStr::Ascii("asours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VAVASOR_6555930671551149776)],
        &[(0b00001, &ENTRY_VAVASORS_10746634756989528594)],
        &[(0b11010, &ENTRY_VAVASOR_6555930671551149776)],
        &[(0b11010, &ENTRY_VAVASORS_10746634756989528594)],
    ],
    range: 4..=6,
};

static VARS_VAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAT_CHILDREN),
    value: None,
};

pub static VARS_VAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icanisation"),
        dictgen::InsensitiveStr::Ascii("icanisations"),
        dictgen::InsensitiveStr::Ascii("icanise"),
        dictgen::InsensitiveStr::Ascii("icanises"),
        dictgen::InsensitiveStr::Ascii("icanization"),
        dictgen::InsensitiveStr::Ascii("icanizations"),
        dictgen::InsensitiveStr::Ascii("icanize"),
        dictgen::InsensitiveStr::Ascii("icanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VATICANIZATION_12565515839826698578)],
        &[(0b10010, &ENTRY_VATICANIZATIONS_15982356743750740824)],
        &[(0b10010, &ENTRY_VATICANIZE_13749277718192631537)],
        &[(0b10010, &ENTRY_VATICANIZES_16071718452803582750)],
        &[(0b01001, &ENTRY_VATICANIZATION_12565515839826698578)],
        &[(0b01001, &ENTRY_VATICANIZATIONS_15982356743750740824)],
        &[(0b01001, &ENTRY_VATICANIZE_13749277718192631537)],
        &[(0b01001, &ENTRY_VATICANIZES_16071718452803582750)],
    ],
    range: 7..=12,
};

static VARS_VAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAS_CHILDREN),
    value: None,
};

pub static VARS_VAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cularisation"),
        dictgen::InsensitiveStr::Ascii("cularisations"),
        dictgen::InsensitiveStr::Ascii("cularise"),
        dictgen::InsensitiveStr::Ascii("cularised"),
        dictgen::InsensitiveStr::Ascii("cularises"),
        dictgen::InsensitiveStr::Ascii("cularising"),
        dictgen::InsensitiveStr::Ascii("cularization"),
        dictgen::InsensitiveStr::Ascii("cularizations"),
        dictgen::InsensitiveStr::Ascii("cularize"),
        dictgen::InsensitiveStr::Ascii("cularized"),
        dictgen::InsensitiveStr::Ascii("cularizes"),
        dictgen::InsensitiveStr::Ascii("cularizing"),
        dictgen::InsensitiveStr::Ascii("ectomise"),
        dictgen::InsensitiveStr::Ascii("ectomised"),
        dictgen::InsensitiveStr::Ascii("ectomising"),
        dictgen::InsensitiveStr::Ascii("ectomize"),
        dictgen::InsensitiveStr::Ascii("ectomized"),
        dictgen::InsensitiveStr::Ascii("ectomizing"),
        dictgen::InsensitiveStr::Ascii("salisation"),
        dictgen::InsensitiveStr::Ascii("salise"),
        dictgen::InsensitiveStr::Ascii("salised"),
        dictgen::InsensitiveStr::Ascii("salises"),
        dictgen::InsensitiveStr::Ascii("salising"),
        dictgen::InsensitiveStr::Ascii("salization"),
        dictgen::InsensitiveStr::Ascii("salize"),
        dictgen::InsensitiveStr::Ascii("salized"),
        dictgen::InsensitiveStr::Ascii("salizes"),
        dictgen::InsensitiveStr::Ascii("salizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VASCULARIZATION_7798251772115817237)],
        &[(0b10010, &ENTRY_VASCULARIZATIONS_8910282637625326095)],
        &[(0b10010, &ENTRY_VASCULARIZE_5629782517352109818)],
        &[(0b10010, &ENTRY_VASCULARIZED_207387324778454868)],
        &[(0b10010, &ENTRY_VASCULARIZES_8060078253096737319)],
        &[(0b10010, &ENTRY_VASCULARIZING_13278299349432868928)],
        &[(0b01001, &ENTRY_VASCULARIZATION_7798251772115817237)],
        &[(0b01001, &ENTRY_VASCULARIZATIONS_8910282637625326095)],
        &[(0b01001, &ENTRY_VASCULARIZE_5629782517352109818)],
        &[(0b01001, &ENTRY_VASCULARIZED_207387324778454868)],
        &[(0b01001, &ENTRY_VASCULARIZES_8060078253096737319)],
        &[(0b01001, &ENTRY_VASCULARIZING_13278299349432868928)],
        &[(0b10010, &ENTRY_VASECTOMIZE_15454430706811576633)],
        &[(0b10010, &ENTRY_VASECTOMIZED_8925568978830732205)],
        &[(0b10010, &ENTRY_VASECTOMIZING_8116057054186241693)],
        &[(0b01001, &ENTRY_VASECTOMIZE_15454430706811576633)],
        &[(0b01001, &ENTRY_VASECTOMIZED_8925568978830732205)],
        &[(0b01001, &ENTRY_VASECTOMIZING_8116057054186241693)],
        &[(0b10010, &ENTRY_VASSALIZATION_7460874923683642348)],
        &[(0b10010, &ENTRY_VASSALIZE_8451924336001983191)],
        &[(0b10010, &ENTRY_VASSALIZED_10083471569803078316)],
        &[(0b10010, &ENTRY_VASSALIZES_4617029144268849855)],
        &[(0b10010, &ENTRY_VASSALIZING_12622050688866231311)],
        &[(0b01001, &ENTRY_VASSALIZATION_7460874923683642348)],
        &[(0b01001, &ENTRY_VASSALIZE_8451924336001983191)],
        &[(0b01001, &ENTRY_VASSALIZED_10083471569803078316)],
        &[(0b01001, &ENTRY_VASSALIZES_4617029144268849855)],
        &[(0b01001, &ENTRY_VASSALIZING_12622050688866231311)],
    ],
    range: 6..=13,
};

static VARS_VAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAR_CHILDREN),
    value: None,
};

pub static VARS_VAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icolored"),
        dictgen::InsensitiveStr::Ascii("icoloredder"),
        dictgen::InsensitiveStr::Ascii("icoloreddest"),
        dictgen::InsensitiveStr::Ascii("icoloreds"),
        dictgen::InsensitiveStr::Ascii("icolorous"),
        dictgen::InsensitiveStr::Ascii("icoloured"),
        dictgen::InsensitiveStr::Ascii("icolouredder"),
        dictgen::InsensitiveStr::Ascii("icoloureddest"),
        dictgen::InsensitiveStr::Ascii("icoloureds"),
        dictgen::InsensitiveStr::Ascii("icolourous"),
    ],
    values: &[
        &[(0b01001, &ENTRY_VARICOLORED_1171542226285534602)],
        &[(0b01001, &ENTRY_VARICOLOREDDER_9075851730556261800)],
        &[(0b01001, &ENTRY_VARICOLOREDDEST_1560912123897475014)],
        &[(0b01001, &ENTRY_VARICOLOREDS_5399234029222855053)],
        &[(0b00001, &ENTRY_VARICOLOROUS_2090604475004912852)],
        &[(0b11010, &ENTRY_VARICOLORED_1171542226285534602)],
        &[(0b11010, &ENTRY_VARICOLOREDDER_9075851730556261800)],
        &[(0b11010, &ENTRY_VARICOLOREDDEST_1560912123897475014)],
        &[(0b11010, &ENTRY_VARICOLOREDS_5399234029222855053)],
        &[(0b11010, &ENTRY_VARICOLOROUS_2090604475004912852)],
    ],
    range: 8..=13,
};

static VARS_VAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VAP_CHILDREN),
    value: None,
};

static VARS_VAP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VAPO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_VAPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_VAPO_CHILDREN),
    value: None,
};

static VARS_VAPO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_VAPOR_NODE),
    None,
    None,
    Some(&VARS_VAPOU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_VAPOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAPOU_CHILDREN),
    value: None,
};

pub static VARS_VAPOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rabilities"),
        dictgen::InsensitiveStr::Ascii("rability"),
        dictgen::InsensitiveStr::Ascii("rable"),
        dictgen::InsensitiveStr::Ascii("rables"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("rescent"),
        dictgen::InsensitiveStr::Ascii("rier"),
        dictgen::InsensitiveStr::Ascii("riest"),
        dictgen::InsensitiveStr::Ascii("rific"),
        dictgen::InsensitiveStr::Ascii("rimeter"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("ringly"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("rish"),
        dictgen::InsensitiveStr::Ascii("risher"),
        dictgen::InsensitiveStr::Ascii("rishest"),
        dictgen::InsensitiveStr::Ascii("rishness"),
        dictgen::InsensitiveStr::Ascii("rishnesses"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesses"),
        dictgen::InsensitiveStr::Ascii("rlike"),
        dictgen::InsensitiveStr::Ascii("rlikes"),
        dictgen::InsensitiveStr::Ascii("rose"),
        dictgen::InsensitiveStr::Ascii("rously"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("rware"),
        dictgen::InsensitiveStr::Ascii("ry"),
    ],
    values: &[
        &[(0b11010, &ENTRY_VAPOR_15613919849286651309)],
        &[(0b11010, &ENTRY_VAPORABILITIES_2583412300863683415)],
        &[(0b11010, &ENTRY_VAPORABILITY_11761050574300823550)],
        &[(0b11010, &ENTRY_VAPORABLE_9307386414591158227)],
        &[(0b11010, &ENTRY_VAPORABLES_8806153105556416814)],
        &[(0b11010, &ENTRY_VAPORED_9964696878149356362)],
        &[(0b11010, &ENTRY_VAPORER_1067720005826649650)],
        &[(0b11010, &ENTRY_VAPORERS_9040022998985997095)],
        &[(0b11010, &ENTRY_VAPORESCENT_811521758895005989)],
        &[(0b11010, &ENTRY_VAPORIER_5924457613655889706)],
        &[(0b11010, &ENTRY_VAPORIEST_16771875045269754013)],
        &[(0b11010, &ENTRY_VAPORIFIC_16729671073785623946)],
        &[(0b11010, &ENTRY_VAPORIMETER_12463044510053318843)],
        &[(0b11010, &ENTRY_VAPORING_5632349647366369914)],
        &[(0b11010, &ENTRY_VAPORINGLY_18193996619433734220)],
        &[(0b11010, &ENTRY_VAPORINGS_4745851328181075614)],
        &[(0b11010, &ENTRY_VAPORISH_4151648633909268593)],
        &[(0b11010, &ENTRY_VAPORISHER_7217019342243877633)],
        &[(0b11010, &ENTRY_VAPORISHEST_12551478444608603779)],
        &[(0b11010, &ENTRY_VAPORISHNESS_18298682645615478389)],
        &[(0b11010, &ENTRY_VAPORISHNESSES_3346265753722413365)],
        &[(0b11010, &ENTRY_VAPORLESS_9180001548778190890)],
        &[(0b11010, &ENTRY_VAPORLESSES_9449123748147448331)],
        &[(0b11010, &ENTRY_VAPORLIKE_4304234079758020864)],
        &[(0b11010, &ENTRY_VAPORLIKES_17513958557622792273)],
        &[(0b11010, &ENTRY_VAPOROSE_941229128135609892)],
        &[(0b11010, &ENTRY_VAPOROUSLY_10099688633493703963)],
        &[(0b11010, &ENTRY_VAPORS_9486200942177396366)],
        &[(0b11010, &ENTRY_VAPORWARE_2722248098855884375)],
        &[(0b11010, &ENTRY_VAPORY_5997890858470358305)],
    ],
    range: 1..=10,
};

static VARS_VAPOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAPOR_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_VAPOR_15613919849286651309)]),
};

pub static VARS_VAPOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilities"),
        dictgen::InsensitiveStr::Ascii("ability"),
        dictgen::InsensitiveStr::Ascii("able"),
        dictgen::InsensitiveStr::Ascii("ables"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("escent"),
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("iest"),
        dictgen::InsensitiveStr::Ascii("ific"),
        dictgen::InsensitiveStr::Ascii("imeter"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ingly"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("isable"),
        dictgen::InsensitiveStr::Ascii("isabler"),
        dictgen::InsensitiveStr::Ascii("isables"),
        dictgen::InsensitiveStr::Ascii("isablest"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("isers"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ish"),
        dictgen::InsensitiveStr::Ascii("isher"),
        dictgen::InsensitiveStr::Ascii("ishest"),
        dictgen::InsensitiveStr::Ascii("ishness"),
        dictgen::InsensitiveStr::Ascii("ishnesses"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("izable"),
        dictgen::InsensitiveStr::Ascii("izabler"),
        dictgen::InsensitiveStr::Ascii("izables"),
        dictgen::InsensitiveStr::Ascii("izablest"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("izers"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("less"),
        dictgen::InsensitiveStr::Ascii("lesses"),
        dictgen::InsensitiveStr::Ascii("like"),
        dictgen::InsensitiveStr::Ascii("likes"),
        dictgen::InsensitiveStr::Ascii("ose"),
        dictgen::InsensitiveStr::Ascii("ously"),
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("ware"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b00001, &ENTRY_VAPORABILITIES_2583412300863683415)],
        &[(0b00001, &ENTRY_VAPORABILITY_11761050574300823550)],
        &[(0b00001, &ENTRY_VAPORABLE_9307386414591158227)],
        &[(0b00001, &ENTRY_VAPORABLES_8806153105556416814)],
        &[(0b11001, &ENTRY_VAPORED_9964696878149356362)],
        &[(0b00001, &ENTRY_VAPORER_1067720005826649650)],
        &[(0b00001, &ENTRY_VAPORERS_9040022998985997095)],
        &[(0b00001, &ENTRY_VAPORESCENT_811521758895005989)],
        &[(0b00001, &ENTRY_VAPORIER_5924457613655889706)],
        &[(0b00001, &ENTRY_VAPORIEST_16771875045269754013)],
        &[(0b00001, &ENTRY_VAPORIFIC_16729671073785623946)],
        &[(0b00001, &ENTRY_VAPORIMETER_12463044510053318843)],
        &[(0b11001, &ENTRY_VAPORING_5632349647366369914)],
        &[(0b00001, &ENTRY_VAPORINGLY_18193996619433734220)],
        &[(0b11001, &ENTRY_VAPORINGS_4745851328181075614)],
        &[(0b10010, &ENTRY_VAPORIZABLE_1284750919722519568)],
        &[(0b10010, &ENTRY_VAPORIZABLER_330384219459697531)],
        &[(0b10010, &ENTRY_VAPORIZABLES_8570559686466416467)],
        &[(0b10010, &ENTRY_VAPORIZABLEST_16063759849633059522)],
        &[(0b10010, &ENTRY_VAPORIZATION_6624016776962610799)],
        &[(0b10010, &ENTRY_VAPORIZATIONS_3616017509956798175)],
        &[(0b10010, &ENTRY_VAPORIZE_7074947866923787432)],
        &[(0b10010, &ENTRY_VAPORIZED_4100382952590684636)],
        &[(0b10010, &ENTRY_VAPORIZER_8052635902096901156)],
        &[(0b10010, &ENTRY_VAPORIZERS_9656279687545559604)],
        &[(0b10010, &ENTRY_VAPORIZES_12186280109418449105)],
        &[(0b00001, &ENTRY_VAPORISH_4151648633909268593)],
        &[(0b00001, &ENTRY_VAPORISHER_7217019342243877633)],
        &[(0b00001, &ENTRY_VAPORISHEST_12551478444608603779)],
        &[(0b00001, &ENTRY_VAPORISHNESS_18298682645615478389)],
        &[(0b00001, &ENTRY_VAPORISHNESSES_3346265753722413365)],
        &[(0b10010, &ENTRY_VAPORIZING_11720449073985132085)],
        &[(0b01001, &ENTRY_VAPORIZABLE_1284750919722519568)],
        &[(0b01001, &ENTRY_VAPORIZABLER_330384219459697531)],
        &[(0b01001, &ENTRY_VAPORIZABLES_8570559686466416467)],
        &[(0b01001, &ENTRY_VAPORIZABLEST_16063759849633059522)],
        &[(0b01001, &ENTRY_VAPORIZATION_6624016776962610799)],
        &[(0b01001, &ENTRY_VAPORIZATIONS_3616017509956798175)],
        &[(0b01001, &ENTRY_VAPORIZE_7074947866923787432)],
        &[(0b01001, &ENTRY_VAPORIZED_4100382952590684636)],
        &[(0b01001, &ENTRY_VAPORIZER_8052635902096901156)],
        &[(0b01001, &ENTRY_VAPORIZERS_9656279687545559604)],
        &[(0b01001, &ENTRY_VAPORIZES_12186280109418449105)],
        &[(0b01001, &ENTRY_VAPORIZING_11720449073985132085)],
        &[(0b00001, &ENTRY_VAPORLESS_9180001548778190890)],
        &[(0b00001, &ENTRY_VAPORLESSES_9449123748147448331)],
        &[(0b00001, &ENTRY_VAPORLIKE_4304234079758020864)],
        &[(0b00001, &ENTRY_VAPORLIKES_17513958557622792273)],
        &[(0b00001, &ENTRY_VAPOROSE_941229128135609892)],
        &[(0b00001, &ENTRY_VAPOROUSLY_10099688633493703963)],
        &[(0b11001, &ENTRY_VAPORS_9486200942177396366)],
        &[(0b01001, &ENTRY_VAPORWARE_2722248098855884375)],
        &[(0b00001, &ENTRY_VAPORY_5997890858470358305)],
    ],
    range: 1..=9,
};

static VARS_VAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAN_CHILDREN),
    value: None,
};

pub static VARS_VAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dalisation"),
        dictgen::InsensitiveStr::Ascii("dalisations"),
        dictgen::InsensitiveStr::Ascii("dalise"),
        dictgen::InsensitiveStr::Ascii("dalised"),
        dictgen::InsensitiveStr::Ascii("dalises"),
        dictgen::InsensitiveStr::Ascii("dalising"),
        dictgen::InsensitiveStr::Ascii("dalization"),
        dictgen::InsensitiveStr::Ascii("dalizations"),
        dictgen::InsensitiveStr::Ascii("dalize"),
        dictgen::InsensitiveStr::Ascii("dalized"),
        dictgen::InsensitiveStr::Ascii("dalizes"),
        dictgen::InsensitiveStr::Ascii("dalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VANDALIZATION_321326720704663358)],
        &[(0b10010, &ENTRY_VANDALIZATIONS_12533411033790274385)],
        &[(0b10010, &ENTRY_VANDALIZE_13852377148508595432)],
        &[(0b10010, &ENTRY_VANDALIZED_6584048774266312596)],
        &[(0b10010, &ENTRY_VANDALIZES_950444592106680495)],
        &[(0b10010, &ENTRY_VANDALIZING_15674911687333824137)],
        &[(0b01001, &ENTRY_VANDALIZATION_321326720704663358)],
        &[(0b01001, &ENTRY_VANDALIZATIONS_12533411033790274385)],
        &[(0b01001, &ENTRY_VANDALIZE_13852377148508595432)],
        &[(0b01001, &ENTRY_VANDALIZED_6584048774266312596)],
        &[(0b01001, &ENTRY_VANDALIZES_950444592106680495)],
        &[(0b01001, &ENTRY_VANDALIZING_15674911687333824137)],
    ],
    range: 6..=11,
};

static VARS_VAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAM_CHILDREN),
    value: None,
};

pub static VARS_VAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("pirise"),
        dictgen::InsensitiveStr::Ascii("pirised"),
        dictgen::InsensitiveStr::Ascii("pirises"),
        dictgen::InsensitiveStr::Ascii("pirising"),
        dictgen::InsensitiveStr::Ascii("pirize"),
        dictgen::InsensitiveStr::Ascii("pirized"),
        dictgen::InsensitiveStr::Ascii("pirizes"),
        dictgen::InsensitiveStr::Ascii("pirizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VAMPIRIZE_2148156304906706014)],
        &[(0b10010, &ENTRY_VAMPIRIZED_1331377974704440897)],
        &[(0b10010, &ENTRY_VAMPIRIZES_15605173529611826568)],
        &[(0b10010, &ENTRY_VAMPIRIZING_5067863975594369914)],
        &[(0b01001, &ENTRY_VAMPIRIZE_2148156304906706014)],
        &[(0b01001, &ENTRY_VAMPIRIZED_1331377974704440897)],
        &[(0b01001, &ENTRY_VAMPIRIZES_15605173529611826568)],
        &[(0b01001, &ENTRY_VAMPIRIZING_5067863975594369914)],
    ],
    range: 6..=8,
};

static VARS_VAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAL_CHILDREN),
    value: None,
};

pub static VARS_VAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("orousness"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourousness"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("vulae"),
        dictgen::InsensitiveStr::Ascii("vule"),
    ],
    values: &[
        &[(0b11001, &ENTRY_VALOR_10559677046210656064)],
        &[(0b10010, &ENTRY_VALORIZATION_10419740603004179298)],
        &[(0b10010, &ENTRY_VALORIZATIONS_5550580571650748675)],
        &[(0b10010, &ENTRY_VALORIZE_18286588028207921541)],
        &[(0b10010, &ENTRY_VALORIZED_16812452574506000724)],
        &[(0b10010, &ENTRY_VALORIZES_12702735390304257487)],
        &[(0b10010, &ENTRY_VALORIZING_6868515530721861819)],
        &[(0b01001, &ENTRY_VALORIZATION_10419740603004179298)],
        &[(0b01001, &ENTRY_VALORIZATIONS_5550580571650748675)],
        &[(0b01001, &ENTRY_VALORIZE_18286588028207921541)],
        &[(0b01001, &ENTRY_VALORIZED_16812452574506000724)],
        &[(0b01001, &ENTRY_VALORIZES_12702735390304257487)],
        &[(0b01001, &ENTRY_VALORIZING_6868515530721861819)],
        &[(0b00001, &ENTRY_VALOROUSNESS_4012556260769975737)],
        &[(0b11001, &ENTRY_VALORS_12937983727743095167)],
        &[(0b11010, &ENTRY_VALOR_10559677046210656064)],
        &[(0b11010, &ENTRY_VALOROUSNESS_4012556260769975737)],
        &[(0b11010, &ENTRY_VALORS_12937983727743095167)],
        &[(0b11010, &ENTRY_VALVULE_7068032189967732165)],
        &[(0b00001, &ENTRY_VALVULE_7068032189967732165)],
    ],
    range: 2..=10,
};

static VARS_VAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAG_CHILDREN),
    value: None,
};

pub static VARS_VAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abondise"),
        dictgen::InsensitiveStr::Ascii("abondised"),
        dictgen::InsensitiveStr::Ascii("abondiser"),
        dictgen::InsensitiveStr::Ascii("abondisers"),
        dictgen::InsensitiveStr::Ascii("abondises"),
        dictgen::InsensitiveStr::Ascii("abondising"),
        dictgen::InsensitiveStr::Ascii("abondize"),
        dictgen::InsensitiveStr::Ascii("abondized"),
        dictgen::InsensitiveStr::Ascii("abondizer"),
        dictgen::InsensitiveStr::Ascii("abondizers"),
        dictgen::InsensitiveStr::Ascii("abondizes"),
        dictgen::InsensitiveStr::Ascii("abondizing"),
        dictgen::InsensitiveStr::Ascii("inulae"),
        dictgen::InsensitiveStr::Ascii("inule"),
        dictgen::InsensitiveStr::Ascii("rantise"),
        dictgen::InsensitiveStr::Ascii("rantises"),
        dictgen::InsensitiveStr::Ascii("rantize"),
        dictgen::InsensitiveStr::Ascii("rantizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VAGABONDIZE_11652184056860982029)],
        &[(0b10010, &ENTRY_VAGABONDIZED_8460203338144902596)],
        &[(0b10010, &ENTRY_VAGABONDIZER_3037058975526630888)],
        &[(0b10010, &ENTRY_VAGABONDIZERS_14944892011725033494)],
        &[(0b10010, &ENTRY_VAGABONDIZES_15618104026782170568)],
        &[(0b10010, &ENTRY_VAGABONDIZING_14715875291944757403)],
        &[(0b01001, &ENTRY_VAGABONDIZE_11652184056860982029)],
        &[(0b01001, &ENTRY_VAGABONDIZED_8460203338144902596)],
        &[(0b01001, &ENTRY_VAGABONDIZER_3037058975526630888)],
        &[(0b01001, &ENTRY_VAGABONDIZERS_14944892011725033494)],
        &[(0b01001, &ENTRY_VAGABONDIZES_15618104026782170568)],
        &[(0b01001, &ENTRY_VAGABONDIZING_14715875291944757403)],
        &[(0b11010, &ENTRY_VAGINULE_15009785862152351808)],
        &[(0b00001, &ENTRY_VAGINULE_15009785862152351808)],
        &[(0b10010, &ENTRY_VAGRANTIZE_18388633313665953145)],
        &[(0b10010, &ENTRY_VAGRANTIZES_9039456281230433333)],
        &[(0b01001, &ENTRY_VAGRANTIZE_18388633313665953145)],
        &[(0b01001, &ENTRY_VAGRANTIZES_9039456281230433333)],
    ],
    range: 5..=10,
};

static VARS_VAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAC_CHILDREN),
    value: None,
};

pub static VARS_VAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cinisation"),
        dictgen::InsensitiveStr::Ascii("cinisations"),
        dictgen::InsensitiveStr::Ascii("cinization"),
        dictgen::InsensitiveStr::Ascii("cinizations"),
        dictgen::InsensitiveStr::Ascii("uolisation"),
        dictgen::InsensitiveStr::Ascii("uolisations"),
        dictgen::InsensitiveStr::Ascii("uolization"),
        dictgen::InsensitiveStr::Ascii("uolizations"),
        dictgen::InsensitiveStr::Ascii("uumise"),
        dictgen::InsensitiveStr::Ascii("uumised"),
        dictgen::InsensitiveStr::Ascii("uumises"),
        dictgen::InsensitiveStr::Ascii("uumising"),
        dictgen::InsensitiveStr::Ascii("uumize"),
        dictgen::InsensitiveStr::Ascii("uumized"),
        dictgen::InsensitiveStr::Ascii("uumizes"),
        dictgen::InsensitiveStr::Ascii("uumizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_VACCINIZATION_14920485206127408398)],
        &[(0b10010, &ENTRY_VACCINIZATIONS_7439925486752573538)],
        &[(0b01001, &ENTRY_VACCINIZATION_14920485206127408398)],
        &[(0b01001, &ENTRY_VACCINIZATIONS_7439925486752573538)],
        &[(0b10010, &ENTRY_VACUOLIZATION_13858163343008163773)],
        &[(0b10010, &ENTRY_VACUOLIZATIONS_2613605802168870716)],
        &[(0b01001, &ENTRY_VACUOLIZATION_13858163343008163773)],
        &[(0b01001, &ENTRY_VACUOLIZATIONS_2613605802168870716)],
        &[(0b10010, &ENTRY_VACUUMIZE_14138660867202341090)],
        &[(0b10010, &ENTRY_VACUUMIZED_694297391266218663)],
        &[(0b10010, &ENTRY_VACUUMIZES_3651190374182064680)],
        &[(0b10010, &ENTRY_VACUUMIZING_16587783276915840565)],
        &[(0b01001, &ENTRY_VACUUMIZE_14138660867202341090)],
        &[(0b01001, &ENTRY_VACUUMIZED_694297391266218663)],
        &[(0b01001, &ENTRY_VACUUMIZES_3651190374182064680)],
        &[(0b01001, &ENTRY_VACUUMIZING_16587783276915840565)],
    ],
    range: 6..=11,
};

static VARS_VAA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_VAA_CHILDREN),
    value: None,
};

pub static VARS_VAA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gmaer"),
        dictgen::InsensitiveStr::Ascii("gmer"),
    ],
    values: &[
        &[(0b11010, &ENTRY_VAAGMER_9352026066170753042)],
        &[(0b00001, &ENTRY_VAAGMER_9352026066170753042)],
    ],
    range: 4..=5,
};

static VARS_U_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_U_CHILDREN),
    value: None,
};

static VARS_U_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UL_NODE),
    None,
    Some(&VARS_UN_NODE),
    None,
    Some(&VARS_UP_NODE),
    None,
    Some(&VARS_UR_NODE),
    Some(&VARS_US_NODE),
    Some(&VARS_UT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UT_CHILDREN),
    value: None,
};

pub static VARS_UT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilisabilities"),
        dictgen::InsensitiveStr::Ascii("ilisability"),
        dictgen::InsensitiveStr::Ascii("ilisable"),
        dictgen::InsensitiveStr::Ascii("ilisables"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("iliser"),
        dictgen::InsensitiveStr::Ascii("ilisers"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilitarianise"),
        dictgen::InsensitiveStr::Ascii("ilitarianised"),
        dictgen::InsensitiveStr::Ascii("ilitarianises"),
        dictgen::InsensitiveStr::Ascii("ilitarianising"),
        dictgen::InsensitiveStr::Ascii("ilitarianize"),
        dictgen::InsensitiveStr::Ascii("ilitarianized"),
        dictgen::InsensitiveStr::Ascii("ilitarianizes"),
        dictgen::InsensitiveStr::Ascii("ilitarianizing"),
        dictgen::InsensitiveStr::Ascii("ilizabilities"),
        dictgen::InsensitiveStr::Ascii("ilizability"),
        dictgen::InsensitiveStr::Ascii("ilizable"),
        dictgen::InsensitiveStr::Ascii("ilizables"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizer"),
        dictgen::InsensitiveStr::Ascii("ilizers"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("opianise"),
        dictgen::InsensitiveStr::Ascii("opianised"),
        dictgen::InsensitiveStr::Ascii("opianiser"),
        dictgen::InsensitiveStr::Ascii("opianisers"),
        dictgen::InsensitiveStr::Ascii("opianises"),
        dictgen::InsensitiveStr::Ascii("opianising"),
        dictgen::InsensitiveStr::Ascii("opianize"),
        dictgen::InsensitiveStr::Ascii("opianized"),
        dictgen::InsensitiveStr::Ascii("opianizer"),
        dictgen::InsensitiveStr::Ascii("opianizers"),
        dictgen::InsensitiveStr::Ascii("opianizes"),
        dictgen::InsensitiveStr::Ascii("opianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UTILIZABILITIES_2397151207630807999)],
        &[(0b10010, &ENTRY_UTILIZABILITY_8225222995731560442)],
        &[(0b10010, &ENTRY_UTILIZABLE_657706566869914036)],
        &[(0b10010, &ENTRY_UTILIZABLES_2699823619654292368)],
        &[(0b10010, &ENTRY_UTILIZATION_10923497997585510620)],
        &[(0b10010, &ENTRY_UTILIZATIONS_4724972587409135598)],
        &[(0b10010, &ENTRY_UTILIZE_1012773511652592330)],
        &[(0b10010, &ENTRY_UTILIZED_2804070747550195319)],
        &[(0b10010, &ENTRY_UTILIZER_15218673503685600046)],
        &[(0b10010, &ENTRY_UTILIZERS_7682889880042432556)],
        &[(0b10010, &ENTRY_UTILIZES_10186051414736400981)],
        &[(0b10010, &ENTRY_UTILIZING_14247990373114335405)],
        &[(0b10010, &ENTRY_UTILITARIANIZE_8297351043834511620)],
        &[(0b10010, &ENTRY_UTILITARIANIZED_17327794031594514233)],
        &[(0b10010, &ENTRY_UTILITARIANIZES_2918689411948086849)],
        &[(0b10010, &ENTRY_UTILITARIANIZING_11871648364295177065)],
        &[(0b01001, &ENTRY_UTILITARIANIZE_8297351043834511620)],
        &[(0b01001, &ENTRY_UTILITARIANIZED_17327794031594514233)],
        &[(0b01001, &ENTRY_UTILITARIANIZES_2918689411948086849)],
        &[(0b01001, &ENTRY_UTILITARIANIZING_11871648364295177065)],
        &[(0b01001, &ENTRY_UTILIZABILITIES_2397151207630807999)],
        &[(0b01001, &ENTRY_UTILIZABILITY_8225222995731560442)],
        &[(0b01001, &ENTRY_UTILIZABLE_657706566869914036)],
        &[(0b01001, &ENTRY_UTILIZABLES_2699823619654292368)],
        &[(0b01001, &ENTRY_UTILIZATION_10923497997585510620)],
        &[(0b01001, &ENTRY_UTILIZATIONS_4724972587409135598)],
        &[(0b01001, &ENTRY_UTILIZE_1012773511652592330)],
        &[(0b01001, &ENTRY_UTILIZED_2804070747550195319)],
        &[(0b01001, &ENTRY_UTILIZER_15218673503685600046)],
        &[(0b01001, &ENTRY_UTILIZERS_7682889880042432556)],
        &[(0b01001, &ENTRY_UTILIZES_10186051414736400981)],
        &[(0b01001, &ENTRY_UTILIZING_14247990373114335405)],
        &[(0b10010, &ENTRY_UTOPIANIZE_15231068506782111828)],
        &[(0b10010, &ENTRY_UTOPIANIZED_13362099296694661562)],
        &[(0b10010, &ENTRY_UTOPIANIZER_810034931952875575)],
        &[(0b10010, &ENTRY_UTOPIANIZERS_17092121582482431024)],
        &[(0b10010, &ENTRY_UTOPIANIZES_17399145312143334553)],
        &[(0b10010, &ENTRY_UTOPIANIZING_4126566720003715520)],
        &[(0b01001, &ENTRY_UTOPIANIZE_15231068506782111828)],
        &[(0b01001, &ENTRY_UTOPIANIZED_13362099296694661562)],
        &[(0b01001, &ENTRY_UTOPIANIZER_810034931952875575)],
        &[(0b01001, &ENTRY_UTOPIANIZERS_17092121582482431024)],
        &[(0b01001, &ENTRY_UTOPIANIZES_17399145312143334553)],
        &[(0b01001, &ENTRY_UTOPIANIZING_4126566720003715520)],
    ],
    range: 5..=14,
};

static VARS_US_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_US_CHILDREN),
    value: None,
};

pub static VARS_US_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("eability")],
    values: &[&[(0b00001, &ENTRY_USABILITY_2409309504889002778)]],
    range: 8..=8,
};

static VARS_UR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UR_CHILDREN),
    value: None,
};

pub static VARS_UR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemias"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("alitisation"),
        dictgen::InsensitiveStr::Ascii("alitisations"),
        dictgen::InsensitiveStr::Ascii("alitise"),
        dictgen::InsensitiveStr::Ascii("alitised"),
        dictgen::InsensitiveStr::Ascii("alitises"),
        dictgen::InsensitiveStr::Ascii("alitising"),
        dictgen::InsensitiveStr::Ascii("alitization"),
        dictgen::InsensitiveStr::Ascii("alitizations"),
        dictgen::InsensitiveStr::Ascii("alitize"),
        dictgen::InsensitiveStr::Ascii("alitized"),
        dictgen::InsensitiveStr::Ascii("alitizes"),
        dictgen::InsensitiveStr::Ascii("alitizing"),
        dictgen::InsensitiveStr::Ascii("ataemia"),
        dictgen::InsensitiveStr::Ascii("atemia"),
        dictgen::InsensitiveStr::Ascii("banisation"),
        dictgen::InsensitiveStr::Ascii("banisations"),
        dictgen::InsensitiveStr::Ascii("banise"),
        dictgen::InsensitiveStr::Ascii("banised"),
        dictgen::InsensitiveStr::Ascii("banises"),
        dictgen::InsensitiveStr::Ascii("banising"),
        dictgen::InsensitiveStr::Ascii("banization"),
        dictgen::InsensitiveStr::Ascii("banizations"),
        dictgen::InsensitiveStr::Ascii("banize"),
        dictgen::InsensitiveStr::Ascii("banized"),
        dictgen::InsensitiveStr::Ascii("banizes"),
        dictgen::InsensitiveStr::Ascii("banizing"),
        dictgen::InsensitiveStr::Ascii("edema"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("ethrorrhea"),
        dictgen::InsensitiveStr::Ascii("ethrorrhoea"),
        dictgen::InsensitiveStr::Ascii("icaemia"),
        dictgen::InsensitiveStr::Ascii("icaemic"),
        dictgen::InsensitiveStr::Ascii("icemia"),
        dictgen::InsensitiveStr::Ascii("icemic"),
        dictgen::InsensitiveStr::Ascii("inaemia"),
        dictgen::InsensitiveStr::Ascii("inaemic"),
        dictgen::InsensitiveStr::Ascii("inemia"),
        dictgen::InsensitiveStr::Ascii("inemic"),
        dictgen::InsensitiveStr::Ascii("oedema"),
        dictgen::InsensitiveStr::Ascii("ohaematin"),
        dictgen::InsensitiveStr::Ascii("ohematin"),
        dictgen::InsensitiveStr::Ascii("ophaein"),
        dictgen::InsensitiveStr::Ascii("ophein"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UREMIA_5689969777449555427)],
        &[(0b10010, &ENTRY_UREMIAS_922769604822503284)],
        &[(0b10010, &ENTRY_UREMIC_16730857995062547325)],
        &[(0b10010, &ENTRY_URALITIZATION_9224301311774971881)],
        &[(0b10010, &ENTRY_URALITIZATIONS_4694547628568956579)],
        &[(0b10010, &ENTRY_URALITIZE_16749000206864918007)],
        &[(0b10010, &ENTRY_URALITIZED_7976389324622529761)],
        &[(0b10010, &ENTRY_URALITIZES_2908475727458579535)],
        &[(0b10010, &ENTRY_URALITIZING_1776329728839479360)],
        &[(0b01001, &ENTRY_URALITIZATION_9224301311774971881)],
        &[(0b01001, &ENTRY_URALITIZATIONS_4694547628568956579)],
        &[(0b01001, &ENTRY_URALITIZE_16749000206864918007)],
        &[(0b01001, &ENTRY_URALITIZED_7976389324622529761)],
        &[(0b01001, &ENTRY_URALITIZES_2908475727458579535)],
        &[(0b01001, &ENTRY_URALITIZING_1776329728839479360)],
        &[(0b11010, &ENTRY_URATEMIA_5405625611324090705)],
        &[(0b00001, &ENTRY_URATEMIA_5405625611324090705)],
        &[(0b10010, &ENTRY_URBANIZATION_13167682870250962044)],
        &[(0b10010, &ENTRY_URBANIZATIONS_714857663098149035)],
        &[(0b10010, &ENTRY_URBANIZE_13821147474427946226)],
        &[(0b10010, &ENTRY_URBANIZED_14020698925707626324)],
        &[(0b10010, &ENTRY_URBANIZES_3740663614137143534)],
        &[(0b10010, &ENTRY_URBANIZING_6731820196250704237)],
        &[(0b01001, &ENTRY_URBANIZATION_13167682870250962044)],
        &[(0b01001, &ENTRY_URBANIZATIONS_714857663098149035)],
        &[(0b01001, &ENTRY_URBANIZE_13821147474427946226)],
        &[(0b01001, &ENTRY_URBANIZED_14020698925707626324)],
        &[(0b01001, &ENTRY_URBANIZES_3740663614137143534)],
        &[(0b01001, &ENTRY_URBANIZING_6731820196250704237)],
        &[(0b00001, &ENTRY_UREDEMA_959978479087452280)],
        &[(0b01001, &ENTRY_UREMIA_5689969777449555427)],
        &[(0b01001, &ENTRY_UREMIAS_922769604822503284)],
        &[(0b01001, &ENTRY_UREMIC_16730857995062547325)],
        &[(0b00001, &ENTRY_URETHRORRHEA_465812257833285712)],
        &[(0b11010, &ENTRY_URETHRORRHEA_465812257833285712)],
        &[(0b11010, &ENTRY_URICEMIA_735304459969707353)],
        &[(0b11010, &ENTRY_URICEMIC_4538463089231912762)],
        &[(0b00001, &ENTRY_URICEMIA_735304459969707353)],
        &[(0b00001, &ENTRY_URICEMIC_4538463089231912762)],
        &[(0b11010, &ENTRY_URINEMIA_14477903106053677801)],
        &[(0b11010, &ENTRY_URINEMIC_3826715010964749488)],
        &[(0b00001, &ENTRY_URINEMIA_14477903106053677801)],
        &[(0b00001, &ENTRY_URINEMIC_3826715010964749488)],
        &[(0b11010, &ENTRY_UREDEMA_959978479087452280)],
        &[(0b11010, &ENTRY_UROHEMATIN_18414252065450864526)],
        &[(0b00001, &ENTRY_UROHEMATIN_18414252065450864526)],
        &[(0b11010, &ENTRY_UROPHEIN_4036494320759732075)],
        &[(0b00001, &ENTRY_UROPHEIN_4036494320759732075)],
    ],
    range: 4..=12,
};

static VARS_UP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UP_CHILDREN),
    value: None,
};

pub static VARS_UP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("draft"),
        dictgen::InsensitiveStr::Ascii("drafts"),
        dictgen::InsensitiveStr::Ascii("draught"),
        dictgen::InsensitiveStr::Ascii("draughts"),
    ],
    values: &[
        &[(0b01001, &ENTRY_UPDRAFT_14478591919041764288)],
        &[(0b01001, &ENTRY_UPDRAFTS_15724500159329907899)],
        &[(0b11010, &ENTRY_UPDRAFT_14478591919041764288)],
        &[(0b11010, &ENTRY_UPDRAFTS_15724500159329907899)],
    ],
    range: 5..=8,
};

static VARS_UN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UN_CHILDREN),
    value: None,
};

static VARS_UN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNA_NODE),
    Some(&VARS_UNB_NODE),
    Some(&VARS_UNC_NODE),
    Some(&VARS_UND_NODE),
    Some(&VARS_UNE_NODE),
    Some(&VARS_UNF_NODE),
    Some(&VARS_UNG_NODE),
    Some(&VARS_UNH_NODE),
    Some(&VARS_UNI_NODE),
    Some(&VARS_UNJ_NODE),
    Some(&VARS_UNK_NODE),
    Some(&VARS_UNL_NODE),
    Some(&VARS_UNM_NODE),
    Some(&VARS_UNN_NODE),
    Some(&VARS_UNO_NODE),
    Some(&VARS_UNP_NODE),
    Some(&VARS_UNQ_NODE),
    Some(&VARS_UNR_NODE),
    Some(&VARS_UNS_NODE),
    Some(&VARS_UNT_NODE),
    Some(&VARS_UNU_NODE),
    Some(&VARS_UNV_NODE),
    Some(&VARS_UNW_NODE),
    None,
    None,
    None,
];

static VARS_UNW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNW_CHILDREN),
    value: None,
};

pub static VARS_UNW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esternised"),
        dictgen::InsensitiveStr::Ascii("esterniseds"),
        dictgen::InsensitiveStr::Ascii("esternized"),
        dictgen::InsensitiveStr::Ascii("esternizeds"),
        dictgen::InsensitiveStr::Ascii("omanise"),
        dictgen::InsensitiveStr::Ascii("omanised"),
        dictgen::InsensitiveStr::Ascii("omanises"),
        dictgen::InsensitiveStr::Ascii("omanize"),
        dictgen::InsensitiveStr::Ascii("omanized"),
        dictgen::InsensitiveStr::Ascii("omanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNWESTERNIZED_2338020082584820680)],
        &[(0b10010, &ENTRY_UNWESTERNIZEDS_8372650994230810456)],
        &[(0b01001, &ENTRY_UNWESTERNIZED_2338020082584820680)],
        &[(0b01001, &ENTRY_UNWESTERNIZEDS_8372650994230810456)],
        &[(0b10010, &ENTRY_UNWOMANIZE_11304497579761163173)],
        &[(0b10010, &ENTRY_UNWOMANIZED_9669879163918865323)],
        &[(0b10010, &ENTRY_UNWOMANIZES_6959542966143151702)],
        &[(0b01001, &ENTRY_UNWOMANIZE_11304497579761163173)],
        &[(0b01001, &ENTRY_UNWOMANIZED_9669879163918865323)],
        &[(0b01001, &ENTRY_UNWOMANIZES_6959542966143151702)],
    ],
    range: 7..=11,
};

static VARS_UNV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNV_CHILDREN),
    value: None,
};

pub static VARS_UNV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aporised"),
        dictgen::InsensitiveStr::Ascii("aporiseds"),
        dictgen::InsensitiveStr::Ascii("aporized"),
        dictgen::InsensitiveStr::Ascii("aporizeds"),
        dictgen::InsensitiveStr::Ascii("ectorisable"),
        dictgen::InsensitiveStr::Ascii("ectorizable"),
        dictgen::InsensitiveStr::Ascii("erbalised"),
        dictgen::InsensitiveStr::Ascii("erbalized"),
        dictgen::InsensitiveStr::Ascii("ictimised"),
        dictgen::InsensitiveStr::Ascii("ictimized"),
        dictgen::InsensitiveStr::Ascii("isualised"),
        dictgen::InsensitiveStr::Ascii("isualisedder"),
        dictgen::InsensitiveStr::Ascii("isualiseddest"),
        dictgen::InsensitiveStr::Ascii("isualized"),
        dictgen::InsensitiveStr::Ascii("isualizedder"),
        dictgen::InsensitiveStr::Ascii("isualizeddest"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italiseds"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizeds"),
        dictgen::InsensitiveStr::Ascii("itriolised"),
        dictgen::InsensitiveStr::Ascii("itrioliseds"),
        dictgen::InsensitiveStr::Ascii("itriolized"),
        dictgen::InsensitiveStr::Ascii("itriolizeds"),
        dictgen::InsensitiveStr::Ascii("ocalised"),
        dictgen::InsensitiveStr::Ascii("ocalisedder"),
        dictgen::InsensitiveStr::Ascii("ocaliseddest"),
        dictgen::InsensitiveStr::Ascii("ocaliseds"),
        dictgen::InsensitiveStr::Ascii("ocalized"),
        dictgen::InsensitiveStr::Ascii("ocalizedder"),
        dictgen::InsensitiveStr::Ascii("ocalizeddest"),
        dictgen::InsensitiveStr::Ascii("ocalizeds"),
        dictgen::InsensitiveStr::Ascii("olatilise"),
        dictgen::InsensitiveStr::Ascii("olatilised"),
        dictgen::InsensitiveStr::Ascii("olatilisedder"),
        dictgen::InsensitiveStr::Ascii("olatiliseddest"),
        dictgen::InsensitiveStr::Ascii("olatilises"),
        dictgen::InsensitiveStr::Ascii("olatilize"),
        dictgen::InsensitiveStr::Ascii("olatilized"),
        dictgen::InsensitiveStr::Ascii("olatilizedder"),
        dictgen::InsensitiveStr::Ascii("olatilizeddest"),
        dictgen::InsensitiveStr::Ascii("olatilizes"),
        dictgen::InsensitiveStr::Ascii("ulcanised"),
        dictgen::InsensitiveStr::Ascii("ulcanisedder"),
        dictgen::InsensitiveStr::Ascii("ulcaniseddest"),
        dictgen::InsensitiveStr::Ascii("ulcaniseds"),
        dictgen::InsensitiveStr::Ascii("ulcanized"),
        dictgen::InsensitiveStr::Ascii("ulcanizedder"),
        dictgen::InsensitiveStr::Ascii("ulcanizeddest"),
        dictgen::InsensitiveStr::Ascii("ulcanizeds"),
        dictgen::InsensitiveStr::Ascii("ulgarise"),
        dictgen::InsensitiveStr::Ascii("ulgarised"),
        dictgen::InsensitiveStr::Ascii("ulgarises"),
        dictgen::InsensitiveStr::Ascii("ulgarising"),
        dictgen::InsensitiveStr::Ascii("ulgarize"),
        dictgen::InsensitiveStr::Ascii("ulgarized"),
        dictgen::InsensitiveStr::Ascii("ulgarizes"),
        dictgen::InsensitiveStr::Ascii("ulgarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNVAPORIZED_16545025727542113291)],
        &[(0b10010, &ENTRY_UNVAPORIZEDS_986543555659572827)],
        &[(0b01001, &ENTRY_UNVAPORIZED_16545025727542113291)],
        &[(0b01001, &ENTRY_UNVAPORIZEDS_986543555659572827)],
        &[(0b10010, &ENTRY_UNVECTORIZABLE_18305744060207565163)],
        &[(0b01001, &ENTRY_UNVECTORIZABLE_18305744060207565163)],
        &[(0b10010, &ENTRY_UNVERBALIZED_16856369756877096411)],
        &[(0b01001, &ENTRY_UNVERBALIZED_16856369756877096411)],
        &[(0b10010, &ENTRY_UNVICTIMIZED_13829704510461931485)],
        &[(0b01001, &ENTRY_UNVICTIMIZED_13829704510461931485)],
        &[(0b10010, &ENTRY_UNVISUALIZED_2776258560824841456)],
        &[(0b10010, &ENTRY_UNVISUALIZEDDER_13256531491156210059)],
        &[(0b10010, &ENTRY_UNVISUALIZEDDEST_6777836850065797871)],
        &[(0b01001, &ENTRY_UNVISUALIZED_2776258560824841456)],
        &[(0b01001, &ENTRY_UNVISUALIZEDDER_13256531491156210059)],
        &[(0b01001, &ENTRY_UNVISUALIZEDDEST_6777836850065797871)],
        &[(0b10010, &ENTRY_UNVITALIZED_11823193045588642198)],
        &[(0b10010, &ENTRY_UNVITALIZEDS_10697536110994369157)],
        &[(0b01001, &ENTRY_UNVITALIZED_11823193045588642198)],
        &[(0b01001, &ENTRY_UNVITALIZEDS_10697536110994369157)],
        &[(0b10010, &ENTRY_UNVITRIOLIZED_15668418284843563695)],
        &[(0b10010, &ENTRY_UNVITRIOLIZEDS_12617332440469592487)],
        &[(0b01001, &ENTRY_UNVITRIOLIZED_15668418284843563695)],
        &[(0b01001, &ENTRY_UNVITRIOLIZEDS_12617332440469592487)],
        &[(0b10010, &ENTRY_UNVOCALIZED_14849265082296142302)],
        &[(0b10010, &ENTRY_UNVOCALIZEDDER_8782052029072763726)],
        &[(0b10010, &ENTRY_UNVOCALIZEDDEST_16264288867545903555)],
        &[(0b10010, &ENTRY_UNVOCALIZEDS_16873526062784100267)],
        &[(0b01001, &ENTRY_UNVOCALIZED_14849265082296142302)],
        &[(0b01001, &ENTRY_UNVOCALIZEDDER_8782052029072763726)],
        &[(0b01001, &ENTRY_UNVOCALIZEDDEST_16264288867545903555)],
        &[(0b01001, &ENTRY_UNVOCALIZEDS_16873526062784100267)],
        &[(0b10010, &ENTRY_UNVOLATILIZE_5958705215773329402)],
        &[(0b10010, &ENTRY_UNVOLATILIZED_7055569159550394451)],
        &[(0b10010, &ENTRY_UNVOLATILIZEDDER_17937975853559322294)],
        &[(0b10010, &ENTRY_UNVOLATILIZEDDEST_14571877913455730099)],
        &[(0b10010, &ENTRY_UNVOLATILIZES_11043825585956014572)],
        &[(0b01001, &ENTRY_UNVOLATILIZE_5958705215773329402)],
        &[(0b01001, &ENTRY_UNVOLATILIZED_7055569159550394451)],
        &[(0b01001, &ENTRY_UNVOLATILIZEDDER_17937975853559322294)],
        &[(0b01001, &ENTRY_UNVOLATILIZEDDEST_14571877913455730099)],
        &[(0b01001, &ENTRY_UNVOLATILIZES_11043825585956014572)],
        &[(0b10010, &ENTRY_UNVULCANIZED_8687515356006252413)],
        &[(0b10010, &ENTRY_UNVULCANIZEDDER_15357474347454753550)],
        &[(0b10010, &ENTRY_UNVULCANIZEDDEST_3232274294131053531)],
        &[(0b10010, &ENTRY_UNVULCANIZEDS_1169880674497437033)],
        &[(0b01001, &ENTRY_UNVULCANIZED_8687515356006252413)],
        &[(0b01001, &ENTRY_UNVULCANIZEDDER_15357474347454753550)],
        &[(0b01001, &ENTRY_UNVULCANIZEDDEST_3232274294131053531)],
        &[(0b01001, &ENTRY_UNVULCANIZEDS_1169880674497437033)],
        &[(0b10010, &ENTRY_UNVULGARIZE_3818104634120863405)],
        &[(0b10010, &ENTRY_UNVULGARIZED_501333356952951895)],
        &[(0b10010, &ENTRY_UNVULGARIZES_4085302381557242262)],
        &[(0b10010, &ENTRY_UNVULGARIZING_6203485172128713465)],
        &[(0b01001, &ENTRY_UNVULGARIZE_3818104634120863405)],
        &[(0b01001, &ENTRY_UNVULGARIZED_501333356952951895)],
        &[(0b01001, &ENTRY_UNVULGARIZES_4085302381557242262)],
        &[(0b01001, &ENTRY_UNVULGARIZING_6203485172128713465)],
    ],
    range: 8..=14,
};

static VARS_UNU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNU_CHILDREN),
    value: None,
};

pub static VARS_UNU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilisable"),
        dictgen::InsensitiveStr::Ascii("tilisables"),
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tilizable"),
        dictgen::InsensitiveStr::Ascii("tilizables"),
        dictgen::InsensitiveStr::Ascii("tilized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNUTILIZABLE_9039802547895734958)],
        &[(0b10010, &ENTRY_UNUTILIZABLES_12203087951077580837)],
        &[(0b10010, &ENTRY_UNUTILIZED_6004715330369766853)],
        &[(0b01001, &ENTRY_UNUTILIZABLE_9039802547895734958)],
        &[(0b01001, &ENTRY_UNUTILIZABLES_12203087951077580837)],
        &[(0b01001, &ENTRY_UNUTILIZED_6004715330369766853)],
    ],
    range: 7..=10,
};

static VARS_UNT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNT_CHILDREN),
    value: None,
};

pub static VARS_UNT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("antalised"),
        dictgen::InsensitiveStr::Ascii("antalisedder"),
        dictgen::InsensitiveStr::Ascii("antaliseddest"),
        dictgen::InsensitiveStr::Ascii("antalising"),
        dictgen::InsensitiveStr::Ascii("antalisinger"),
        dictgen::InsensitiveStr::Ascii("antalisingest"),
        dictgen::InsensitiveStr::Ascii("antalisings"),
        dictgen::InsensitiveStr::Ascii("antalized"),
        dictgen::InsensitiveStr::Ascii("antalizedder"),
        dictgen::InsensitiveStr::Ascii("antalizeddest"),
        dictgen::InsensitiveStr::Ascii("antalizing"),
        dictgen::InsensitiveStr::Ascii("antalizinger"),
        dictgen::InsensitiveStr::Ascii("antalizingest"),
        dictgen::InsensitiveStr::Ascii("antalizings"),
        dictgen::InsensitiveStr::Ascii("artarised"),
        dictgen::InsensitiveStr::Ascii("artariseds"),
        dictgen::InsensitiveStr::Ascii("artarized"),
        dictgen::InsensitiveStr::Ascii("artarizeds"),
        dictgen::InsensitiveStr::Ascii("echnicalise"),
        dictgen::InsensitiveStr::Ascii("echnicalises"),
        dictgen::InsensitiveStr::Ascii("echnicalize"),
        dictgen::InsensitiveStr::Ascii("echnicalizes"),
        dictgen::InsensitiveStr::Ascii("emporising"),
        dictgen::InsensitiveStr::Ascii("emporisings"),
        dictgen::InsensitiveStr::Ascii("emporizing"),
        dictgen::InsensitiveStr::Ascii("emporizings"),
        dictgen::InsensitiveStr::Ascii("errorised"),
        dictgen::InsensitiveStr::Ascii("errorized"),
        dictgen::InsensitiveStr::Ascii("heorisable"),
        dictgen::InsensitiveStr::Ascii("heorisables"),
        dictgen::InsensitiveStr::Ascii("heorizable"),
        dictgen::InsensitiveStr::Ascii("heorizables"),
        dictgen::InsensitiveStr::Ascii("rammeled"),
        dictgen::InsensitiveStr::Ascii("rammeledder"),
        dictgen::InsensitiveStr::Ascii("rammeleddest"),
        dictgen::InsensitiveStr::Ascii("rammelled"),
        dictgen::InsensitiveStr::Ascii("rammelledder"),
        dictgen::InsensitiveStr::Ascii("rammelleddest"),
        dictgen::InsensitiveStr::Ascii("ranquilised"),
        dictgen::InsensitiveStr::Ascii("ranquilized"),
        dictgen::InsensitiveStr::Ascii("ranquillise"),
        dictgen::InsensitiveStr::Ascii("ranquillised"),
        dictgen::InsensitiveStr::Ascii("ranquillize"),
        dictgen::InsensitiveStr::Ascii("ranquillized"),
        dictgen::InsensitiveStr::Ascii("yrannised"),
        dictgen::InsensitiveStr::Ascii("yrannized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNTANTALIZED_6826245574739736260)],
        &[(0b10010, &ENTRY_UNTANTALIZEDDER_4818289569312071640)],
        &[(0b10010, &ENTRY_UNTANTALIZEDDEST_17808161070361053815)],
        &[(0b10010, &ENTRY_UNTANTALIZING_9378536861335914621)],
        &[(0b10010, &ENTRY_UNTANTALIZINGER_434726785421024269)],
        &[(0b10010, &ENTRY_UNTANTALIZINGEST_14310803913056649148)],
        &[(0b10010, &ENTRY_UNTANTALIZINGS_16007088557356417459)],
        &[(0b01001, &ENTRY_UNTANTALIZED_6826245574739736260)],
        &[(0b01001, &ENTRY_UNTANTALIZEDDER_4818289569312071640)],
        &[(0b01001, &ENTRY_UNTANTALIZEDDEST_17808161070361053815)],
        &[(0b01001, &ENTRY_UNTANTALIZING_9378536861335914621)],
        &[(0b01001, &ENTRY_UNTANTALIZINGER_434726785421024269)],
        &[(0b01001, &ENTRY_UNTANTALIZINGEST_14310803913056649148)],
        &[(0b01001, &ENTRY_UNTANTALIZINGS_16007088557356417459)],
        &[(0b10010, &ENTRY_UNTARTARIZED_9979924217571095451)],
        &[(0b10010, &ENTRY_UNTARTARIZEDS_2508207556036622208)],
        &[(0b01001, &ENTRY_UNTARTARIZED_9979924217571095451)],
        &[(0b01001, &ENTRY_UNTARTARIZEDS_2508207556036622208)],
        &[(0b10010, &ENTRY_UNTECHNICALIZE_7661502502654407908)],
        &[(0b10010, &ENTRY_UNTECHNICALIZES_12316354131512359)],
        &[(0b01001, &ENTRY_UNTECHNICALIZE_7661502502654407908)],
        &[(0b01001, &ENTRY_UNTECHNICALIZES_12316354131512359)],
        &[(0b10010, &ENTRY_UNTEMPORIZING_10262279498666537398)],
        &[(0b10010, &ENTRY_UNTEMPORIZINGS_10863617418556326800)],
        &[(0b01001, &ENTRY_UNTEMPORIZING_10262279498666537398)],
        &[(0b01001, &ENTRY_UNTEMPORIZINGS_10863617418556326800)],
        &[(0b10010, &ENTRY_UNTERRORIZED_11223502884976171489)],
        &[(0b01001, &ENTRY_UNTERRORIZED_11223502884976171489)],
        &[(0b10010, &ENTRY_UNTHEORIZABLE_240618649580760361)],
        &[(0b10010, &ENTRY_UNTHEORIZABLES_13870769123827938921)],
        &[(0b01001, &ENTRY_UNTHEORIZABLE_240618649580760361)],
        &[(0b01001, &ENTRY_UNTHEORIZABLES_13870769123827938921)],
        &[(0b00001, &ENTRY_UNTRAMMELED_549579090643891681)],
        &[(0b00001, &ENTRY_UNTRAMMELEDDER_378198885203754532)],
        &[(0b00001, &ENTRY_UNTRAMMELEDDEST_15285162208707661637)],
        &[(0b11010, &ENTRY_UNTRAMMELED_549579090643891681)],
        &[(0b11010, &ENTRY_UNTRAMMELEDDER_378198885203754532)],
        &[(0b11010, &ENTRY_UNTRAMMELEDDEST_15285162208707661637)],
        &[(0b10010, &ENTRY_UNTRANQUILIZED_14631448086878067814)],
        &[(0b01001, &ENTRY_UNTRANQUILIZED_14631448086878067814)],
        &[(0b10010, &ENTRY_UNTRANQUILLIZE_528996477809981689)],
        &[(0b10010, &ENTRY_UNTRANQUILLIZED_3970525452077680048)],
        &[(0b01001, &ENTRY_UNTRANQUILLIZE_528996477809981689)],
        &[(0b01001, &ENTRY_UNTRANQUILLIZED_3970525452077680048)],
        &[(0b10010, &ENTRY_UNTYRANNIZED_8862669867305834720)],
        &[(0b01001, &ENTRY_UNTYRANNIZED_8862669867305834720)],
    ],
    range: 8..=13,
};

static VARS_UNS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNS_CHILDREN),
    value: None,
};

static VARS_UNS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNSA_NODE),
    None,
    Some(&VARS_UNSC_NODE),
    None,
    Some(&VARS_UNSE_NODE),
    None,
    None,
    Some(&VARS_UNSH_NODE),
    Some(&VARS_UNSI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNSO_NODE),
    Some(&VARS_UNSP_NODE),
    None,
    None,
    None,
    Some(&VARS_UNST_NODE),
    Some(&VARS_UNSU_NODE),
    None,
    None,
    None,
    Some(&VARS_UNSY_NODE),
    None,
];

static VARS_UNSY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNSY_CHILDREN),
    value: None,
};

static VARS_UNSY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNSYM_NODE),
    Some(&VARS_UNSYN_NODE),
    None,
    Some(&VARS_UNSYP_NODE),
    None,
    None,
    Some(&VARS_UNSYS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNSYS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSYS_CHILDREN),
    value: None,
};

pub static VARS_UNSYS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tematised"),
        dictgen::InsensitiveStr::Ascii("tematisedder"),
        dictgen::InsensitiveStr::Ascii("tematiseddest"),
        dictgen::InsensitiveStr::Ascii("tematisedly"),
        dictgen::InsensitiveStr::Ascii("tematising"),
        dictgen::InsensitiveStr::Ascii("tematisinger"),
        dictgen::InsensitiveStr::Ascii("tematisingest"),
        dictgen::InsensitiveStr::Ascii("tematized"),
        dictgen::InsensitiveStr::Ascii("tematizedder"),
        dictgen::InsensitiveStr::Ascii("tematizeddest"),
        dictgen::InsensitiveStr::Ascii("tematizedly"),
        dictgen::InsensitiveStr::Ascii("tematizing"),
        dictgen::InsensitiveStr::Ascii("tematizinger"),
        dictgen::InsensitiveStr::Ascii("tematizingest"),
        dictgen::InsensitiveStr::Ascii("temisable"),
        dictgen::InsensitiveStr::Ascii("temisables"),
        dictgen::InsensitiveStr::Ascii("temizable"),
        dictgen::InsensitiveStr::Ascii("temizables"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSYSTEMATIZED_14502428691598864878)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZEDDER_9189788093098370830)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZEDDEST_1207211808530410942)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZEDLY_4862881584760401398)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZING_14753078560276504217)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZINGER_15925085597038328684)],
        &[(0b10010, &ENTRY_UNSYSTEMATIZINGEST_5589507975482695103)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZED_14502428691598864878)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZEDDER_9189788093098370830)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZEDDEST_1207211808530410942)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZEDLY_4862881584760401398)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZING_14753078560276504217)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZINGER_15925085597038328684)],
        &[(0b01001, &ENTRY_UNSYSTEMATIZINGEST_5589507975482695103)],
        &[(0b10010, &ENTRY_UNSYSTEMIZABLE_6445655941220298236)],
        &[(0b10010, &ENTRY_UNSYSTEMIZABLES_11770476614828889053)],
        &[(0b01001, &ENTRY_UNSYSTEMIZABLE_6445655941220298236)],
        &[(0b01001, &ENTRY_UNSYSTEMIZABLES_11770476614828889053)],
    ],
    range: 9..=13,
};

static VARS_UNSYP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSYP_CHILDREN),
    value: None,
};

pub static VARS_UNSYP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hon"),
        dictgen::InsensitiveStr::Ascii("hons"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNSIPHON_8751298592164441841)],
        &[(0b11010, &ENTRY_UNSIPHONS_6487069638314844152)],
    ],
    range: 3..=4,
};

static VARS_UNSYN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSYN_CHILDREN),
    value: None,
};

pub static VARS_UNSYN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chronised"),
        dictgen::InsensitiveStr::Ascii("chronisedder"),
        dictgen::InsensitiveStr::Ascii("chroniseddest"),
        dictgen::InsensitiveStr::Ascii("chronized"),
        dictgen::InsensitiveStr::Ascii("chronizedder"),
        dictgen::InsensitiveStr::Ascii("chronizeddest"),
        dictgen::InsensitiveStr::Ascii("thesised"),
        dictgen::InsensitiveStr::Ascii("thesisedder"),
        dictgen::InsensitiveStr::Ascii("thesiseddest"),
        dictgen::InsensitiveStr::Ascii("thesized"),
        dictgen::InsensitiveStr::Ascii("thesizedder"),
        dictgen::InsensitiveStr::Ascii("thesizeddest"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSYNCHRONIZED_15906225482447601414)],
        &[(0b10010, &ENTRY_UNSYNCHRONIZEDDER_17711872826708633465)],
        &[(0b10010, &ENTRY_UNSYNCHRONIZEDDEST_8914833530283816809)],
        &[(0b01001, &ENTRY_UNSYNCHRONIZED_15906225482447601414)],
        &[(0b01001, &ENTRY_UNSYNCHRONIZEDDER_17711872826708633465)],
        &[(0b01001, &ENTRY_UNSYNCHRONIZEDDEST_8914833530283816809)],
        &[(0b10010, &ENTRY_UNSYNTHESIZED_873390520484748283)],
        &[(0b10010, &ENTRY_UNSYNTHESIZEDDER_47988453461239108)],
        &[(0b10010, &ENTRY_UNSYNTHESIZEDDEST_7437594407505325426)],
        &[(0b01001, &ENTRY_UNSYNTHESIZED_873390520484748283)],
        &[(0b01001, &ENTRY_UNSYNTHESIZEDDER_47988453461239108)],
        &[(0b01001, &ENTRY_UNSYNTHESIZEDDEST_7437594407505325426)],
    ],
    range: 8..=13,
};

static VARS_UNSYM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSYM_CHILDREN),
    value: None,
};

pub static VARS_UNSYM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bolised"),
        dictgen::InsensitiveStr::Ascii("bolisedder"),
        dictgen::InsensitiveStr::Ascii("boliseddest"),
        dictgen::InsensitiveStr::Ascii("bolized"),
        dictgen::InsensitiveStr::Ascii("bolizedder"),
        dictgen::InsensitiveStr::Ascii("bolizeddest"),
        dictgen::InsensitiveStr::Ascii("metrised"),
        dictgen::InsensitiveStr::Ascii("metriseds"),
        dictgen::InsensitiveStr::Ascii("metrized"),
        dictgen::InsensitiveStr::Ascii("metrizeds"),
        dictgen::InsensitiveStr::Ascii("pathisabilities"),
        dictgen::InsensitiveStr::Ascii("pathisability"),
        dictgen::InsensitiveStr::Ascii("pathisable"),
        dictgen::InsensitiveStr::Ascii("pathisables"),
        dictgen::InsensitiveStr::Ascii("pathised"),
        dictgen::InsensitiveStr::Ascii("pathisedder"),
        dictgen::InsensitiveStr::Ascii("pathiseddest"),
        dictgen::InsensitiveStr::Ascii("pathising"),
        dictgen::InsensitiveStr::Ascii("pathisinger"),
        dictgen::InsensitiveStr::Ascii("pathisingest"),
        dictgen::InsensitiveStr::Ascii("pathisinglier"),
        dictgen::InsensitiveStr::Ascii("pathisingliest"),
        dictgen::InsensitiveStr::Ascii("pathisingly"),
        dictgen::InsensitiveStr::Ascii("pathisings"),
        dictgen::InsensitiveStr::Ascii("pathizabilities"),
        dictgen::InsensitiveStr::Ascii("pathizability"),
        dictgen::InsensitiveStr::Ascii("pathizable"),
        dictgen::InsensitiveStr::Ascii("pathizables"),
        dictgen::InsensitiveStr::Ascii("pathized"),
        dictgen::InsensitiveStr::Ascii("pathizedder"),
        dictgen::InsensitiveStr::Ascii("pathizeddest"),
        dictgen::InsensitiveStr::Ascii("pathizing"),
        dictgen::InsensitiveStr::Ascii("pathizinger"),
        dictgen::InsensitiveStr::Ascii("pathizingest"),
        dictgen::InsensitiveStr::Ascii("pathizinglier"),
        dictgen::InsensitiveStr::Ascii("pathizingliest"),
        dictgen::InsensitiveStr::Ascii("pathizingly"),
        dictgen::InsensitiveStr::Ascii("pathizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSYMBOLIZED_4998866146418175348)],
        &[(0b10010, &ENTRY_UNSYMBOLIZEDDER_2693121694591055898)],
        &[(0b10010, &ENTRY_UNSYMBOLIZEDDEST_5688633199932414339)],
        &[(0b01001, &ENTRY_UNSYMBOLIZED_4998866146418175348)],
        &[(0b01001, &ENTRY_UNSYMBOLIZEDDER_2693121694591055898)],
        &[(0b01001, &ENTRY_UNSYMBOLIZEDDEST_5688633199932414339)],
        &[(0b10010, &ENTRY_UNSYMMETRIZED_2416221991577506354)],
        &[(0b10010, &ENTRY_UNSYMMETRIZEDS_17526612862547781039)],
        &[(0b01001, &ENTRY_UNSYMMETRIZED_2416221991577506354)],
        &[(0b01001, &ENTRY_UNSYMMETRIZEDS_17526612862547781039)],
        &[(0b10010, &ENTRY_UNSYMPATHIZABILITIES_5599344496922194828)],
        &[(0b10010, &ENTRY_UNSYMPATHIZABILITY_15552727085219653687)],
        &[(0b10010, &ENTRY_UNSYMPATHIZABLE_6116127447209370164)],
        &[(0b10010, &ENTRY_UNSYMPATHIZABLES_6750873272065181147)],
        &[(0b10010, &ENTRY_UNSYMPATHIZED_7172788372988396436)],
        &[(0b10010, &ENTRY_UNSYMPATHIZEDDER_12857460593078230378)],
        &[(0b10010, &ENTRY_UNSYMPATHIZEDDEST_11795335826469372906)],
        &[(0b10010, &ENTRY_UNSYMPATHIZING_8602889408813208422)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGER_4506075109833611910)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGEST_13474971300491840553)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGLIER_7139683093102134643)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGLIEST_6904483674657551040)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGLY_10367834800272884249)],
        &[(0b10010, &ENTRY_UNSYMPATHIZINGS_4389760301799797231)],
        &[(0b01001, &ENTRY_UNSYMPATHIZABILITIES_5599344496922194828)],
        &[(0b01001, &ENTRY_UNSYMPATHIZABILITY_15552727085219653687)],
        &[(0b01001, &ENTRY_UNSYMPATHIZABLE_6116127447209370164)],
        &[(0b01001, &ENTRY_UNSYMPATHIZABLES_6750873272065181147)],
        &[(0b01001, &ENTRY_UNSYMPATHIZED_7172788372988396436)],
        &[(0b01001, &ENTRY_UNSYMPATHIZEDDER_12857460593078230378)],
        &[(0b01001, &ENTRY_UNSYMPATHIZEDDEST_11795335826469372906)],
        &[(0b01001, &ENTRY_UNSYMPATHIZING_8602889408813208422)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGER_4506075109833611910)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGEST_13474971300491840553)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGLIER_7139683093102134643)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGLIEST_6904483674657551040)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGLY_10367834800272884249)],
        &[(0b01001, &ENTRY_UNSYMPATHIZINGS_4389760301799797231)],
    ],
    range: 7..=15,
};

static VARS_UNSU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSU_CHILDREN),
    value: None,
};

pub static VARS_UNSU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bsidised"),
        dictgen::InsensitiveStr::Ascii("bsidized"),
        dictgen::InsensitiveStr::Ascii("bstantialise"),
        dictgen::InsensitiveStr::Ascii("bstantialised"),
        dictgen::InsensitiveStr::Ascii("bstantialises"),
        dictgen::InsensitiveStr::Ascii("bstantialising"),
        dictgen::InsensitiveStr::Ascii("bstantialize"),
        dictgen::InsensitiveStr::Ascii("bstantialized"),
        dictgen::InsensitiveStr::Ascii("bstantializes"),
        dictgen::InsensitiveStr::Ascii("bstantializing"),
        dictgen::InsensitiveStr::Ascii("ccorable"),
        dictgen::InsensitiveStr::Ascii("ccorables"),
        dictgen::InsensitiveStr::Ascii("ccored"),
        dictgen::InsensitiveStr::Ascii("ccourable"),
        dictgen::InsensitiveStr::Ascii("ccourables"),
        dictgen::InsensitiveStr::Ascii("ccoured"),
        dictgen::InsensitiveStr::Ascii("lphurised"),
        dictgen::InsensitiveStr::Ascii("lphuriseds"),
        dictgen::InsensitiveStr::Ascii("lphurized"),
        dictgen::InsensitiveStr::Ascii("lphurizeds"),
        dictgen::InsensitiveStr::Ascii("mmarisable"),
        dictgen::InsensitiveStr::Ascii("mmarised"),
        dictgen::InsensitiveStr::Ascii("mmarisedder"),
        dictgen::InsensitiveStr::Ascii("mmariseddest"),
        dictgen::InsensitiveStr::Ascii("mmarizable"),
        dictgen::InsensitiveStr::Ascii("mmarized"),
        dictgen::InsensitiveStr::Ascii("mmarizedder"),
        dictgen::InsensitiveStr::Ascii("mmarizeddest"),
        dictgen::InsensitiveStr::Ascii("pernaturalise"),
        dictgen::InsensitiveStr::Ascii("pernaturalised"),
        dictgen::InsensitiveStr::Ascii("pernaturalises"),
        dictgen::InsensitiveStr::Ascii("pernaturalize"),
        dictgen::InsensitiveStr::Ascii("pernaturalized"),
        dictgen::InsensitiveStr::Ascii("pernaturalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSUBSIDIZED_8506816544552198394)],
        &[(0b01001, &ENTRY_UNSUBSIDIZED_8506816544552198394)],
        &[(0b10010, &ENTRY_UNSUBSTANTIALIZE_18383570451437119535)],
        &[(0b10010, &ENTRY_UNSUBSTANTIALIZED_16036110466855036195)],
        &[(0b10010, &ENTRY_UNSUBSTANTIALIZES_16871510027185551366)],
        &[(0b10010, &ENTRY_UNSUBSTANTIALIZING_2121724985901297893)],
        &[(0b01001, &ENTRY_UNSUBSTANTIALIZE_18383570451437119535)],
        &[(0b01001, &ENTRY_UNSUBSTANTIALIZED_16036110466855036195)],
        &[(0b01001, &ENTRY_UNSUBSTANTIALIZES_16871510027185551366)],
        &[(0b01001, &ENTRY_UNSUBSTANTIALIZING_2121724985901297893)],
        &[(0b00001, &ENTRY_UNSUCCORABLE_12673763242696709684)],
        &[(0b00001, &ENTRY_UNSUCCORABLES_739989955870419064)],
        &[(0b00001, &ENTRY_UNSUCCORED_2160594171074318544)],
        &[(0b11010, &ENTRY_UNSUCCORABLE_12673763242696709684)],
        &[(0b11010, &ENTRY_UNSUCCORABLES_739989955870419064)],
        &[(0b11010, &ENTRY_UNSUCCORED_2160594171074318544)],
        &[(0b10010, &ENTRY_UNSULPHURIZED_4398458517942042949)],
        &[(0b10010, &ENTRY_UNSULPHURIZEDS_10925557470603907058)],
        &[(0b01001, &ENTRY_UNSULPHURIZED_4398458517942042949)],
        &[(0b01001, &ENTRY_UNSULPHURIZEDS_10925557470603907058)],
        &[(0b10010, &ENTRY_UNSUMMARIZABLE_4893860010982930453)],
        &[(0b10010, &ENTRY_UNSUMMARIZED_836436980612704819)],
        &[(0b10010, &ENTRY_UNSUMMARIZEDDER_17857459577512226536)],
        &[(0b10010, &ENTRY_UNSUMMARIZEDDEST_13958313582918609397)],
        &[(0b01001, &ENTRY_UNSUMMARIZABLE_4893860010982930453)],
        &[(0b01001, &ENTRY_UNSUMMARIZED_836436980612704819)],
        &[(0b01001, &ENTRY_UNSUMMARIZEDDER_17857459577512226536)],
        &[(0b01001, &ENTRY_UNSUMMARIZEDDEST_13958313582918609397)],
        &[(0b10010, &ENTRY_UNSUPERNATURALIZE_11379677666614455606)],
        &[(0b10010, &ENTRY_UNSUPERNATURALIZED_13742104250862639914)],
        &[(0b10010, &ENTRY_UNSUPERNATURALIZES_11514791653627540421)],
        &[(0b01001, &ENTRY_UNSUPERNATURALIZE_11379677666614455606)],
        &[(0b01001, &ENTRY_UNSUPERNATURALIZED_13742104250862639914)],
        &[(0b01001, &ENTRY_UNSUPERNATURALIZES_11514791653627540421)],
    ],
    range: 6..=14,
};

static VARS_UNST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNST_CHILDREN),
    value: None,
};

pub static VARS_UNST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilised"),
        dictgen::InsensitiveStr::Ascii("abilising"),
        dictgen::InsensitiveStr::Ascii("abilized"),
        dictgen::InsensitiveStr::Ascii("abilizing"),
        dictgen::InsensitiveStr::Ascii("andardisable"),
        dictgen::InsensitiveStr::Ascii("andardised"),
        dictgen::InsensitiveStr::Ascii("andardisedder"),
        dictgen::InsensitiveStr::Ascii("andardiseddest"),
        dictgen::InsensitiveStr::Ascii("andardizable"),
        dictgen::InsensitiveStr::Ascii("andardized"),
        dictgen::InsensitiveStr::Ascii("andardizedder"),
        dictgen::InsensitiveStr::Ascii("andardizeddest"),
        dictgen::InsensitiveStr::Ascii("erilised"),
        dictgen::InsensitiveStr::Ascii("erilized"),
        dictgen::InsensitiveStr::Ascii("igmatised"),
        dictgen::InsensitiveStr::Ascii("igmatisedder"),
        dictgen::InsensitiveStr::Ascii("igmatiseddest"),
        dictgen::InsensitiveStr::Ascii("igmatiseds"),
        dictgen::InsensitiveStr::Ascii("igmatized"),
        dictgen::InsensitiveStr::Ascii("igmatizedder"),
        dictgen::InsensitiveStr::Ascii("igmatizeddest"),
        dictgen::InsensitiveStr::Ascii("igmatizeds"),
        dictgen::InsensitiveStr::Ascii("oicise"),
        dictgen::InsensitiveStr::Ascii("oicises"),
        dictgen::InsensitiveStr::Ascii("oicize"),
        dictgen::InsensitiveStr::Ascii("oicizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSTABILIZED_1384046979087471144)],
        &[(0b10010, &ENTRY_UNSTABILIZING_9105210657283981291)],
        &[(0b01001, &ENTRY_UNSTABILIZED_1384046979087471144)],
        &[(0b01001, &ENTRY_UNSTABILIZING_9105210657283981291)],
        &[(0b10010, &ENTRY_UNSTANDARDIZABLE_3986051184822450887)],
        &[(0b10010, &ENTRY_UNSTANDARDIZED_1272352641434012090)],
        &[(0b10010, &ENTRY_UNSTANDARDIZEDDER_3995682174766736068)],
        &[(0b10010, &ENTRY_UNSTANDARDIZEDDEST_11035827645803141662)],
        &[(0b01001, &ENTRY_UNSTANDARDIZABLE_3986051184822450887)],
        &[(0b01001, &ENTRY_UNSTANDARDIZED_1272352641434012090)],
        &[(0b01001, &ENTRY_UNSTANDARDIZEDDER_3995682174766736068)],
        &[(0b01001, &ENTRY_UNSTANDARDIZEDDEST_11035827645803141662)],
        &[(0b10010, &ENTRY_UNSTERILIZED_13156342258367971107)],
        &[(0b01001, &ENTRY_UNSTERILIZED_13156342258367971107)],
        &[(0b10010, &ENTRY_UNSTIGMATIZED_8147628030660872313)],
        &[(0b10010, &ENTRY_UNSTIGMATIZEDDER_12103644335044897212)],
        &[(0b10010, &ENTRY_UNSTIGMATIZEDDEST_5756983753240929122)],
        &[(0b10010, &ENTRY_UNSTIGMATIZEDS_179009940195529442)],
        &[(0b01001, &ENTRY_UNSTIGMATIZED_8147628030660872313)],
        &[(0b01001, &ENTRY_UNSTIGMATIZEDDER_12103644335044897212)],
        &[(0b01001, &ENTRY_UNSTIGMATIZEDDEST_5756983753240929122)],
        &[(0b01001, &ENTRY_UNSTIGMATIZEDS_179009940195529442)],
        &[(0b10010, &ENTRY_UNSTOICIZE_15130563685517702536)],
        &[(0b10010, &ENTRY_UNSTOICIZES_3633881140952142304)],
        &[(0b01001, &ENTRY_UNSTOICIZE_15130563685517702536)],
        &[(0b01001, &ENTRY_UNSTOICIZES_3633881140952142304)],
    ],
    range: 6..=14,
};

static VARS_UNSP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSP_CHILDREN),
    value: None,
};

pub static VARS_UNSP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecialised"),
        dictgen::InsensitiveStr::Ascii("ecialisedder"),
        dictgen::InsensitiveStr::Ascii("ecialiseddest"),
        dictgen::InsensitiveStr::Ascii("ecialising"),
        dictgen::InsensitiveStr::Ascii("ecialisinger"),
        dictgen::InsensitiveStr::Ascii("ecialisingest"),
        dictgen::InsensitiveStr::Ascii("ecialized"),
        dictgen::InsensitiveStr::Ascii("ecializedder"),
        dictgen::InsensitiveStr::Ascii("ecializeddest"),
        dictgen::InsensitiveStr::Ascii("ecializing"),
        dictgen::InsensitiveStr::Ascii("ecializinger"),
        dictgen::InsensitiveStr::Ascii("ecializingest"),
        dictgen::InsensitiveStr::Ascii("ecterlike"),
        dictgen::InsensitiveStr::Ascii("ecterlikes"),
        dictgen::InsensitiveStr::Ascii("ectrelike"),
        dictgen::InsensitiveStr::Ascii("ectrelikes"),
        dictgen::InsensitiveStr::Ascii("iritualise"),
        dictgen::InsensitiveStr::Ascii("iritualised"),
        dictgen::InsensitiveStr::Ascii("iritualises"),
        dictgen::InsensitiveStr::Ascii("iritualising"),
        dictgen::InsensitiveStr::Ascii("iritualize"),
        dictgen::InsensitiveStr::Ascii("iritualized"),
        dictgen::InsensitiveStr::Ascii("iritualizes"),
        dictgen::InsensitiveStr::Ascii("iritualizing"),
        dictgen::InsensitiveStr::Ascii("lendorous"),
        dictgen::InsensitiveStr::Ascii("lendorously"),
        dictgen::InsensitiveStr::Ascii("lendourous"),
        dictgen::InsensitiveStr::Ascii("lendourously"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSPECIALIZED_16921915094468110795)],
        &[(0b10010, &ENTRY_UNSPECIALIZEDDER_14482979627473921525)],
        &[(0b10010, &ENTRY_UNSPECIALIZEDDEST_7579806759888561816)],
        &[(0b10010, &ENTRY_UNSPECIALIZING_870209529926883549)],
        &[(0b10010, &ENTRY_UNSPECIALIZINGER_10541176028877396187)],
        &[(0b10010, &ENTRY_UNSPECIALIZINGEST_13963040120295765584)],
        &[(0b01001, &ENTRY_UNSPECIALIZED_16921915094468110795)],
        &[(0b01001, &ENTRY_UNSPECIALIZEDDER_14482979627473921525)],
        &[(0b01001, &ENTRY_UNSPECIALIZEDDEST_7579806759888561816)],
        &[(0b01001, &ENTRY_UNSPECIALIZING_870209529926883549)],
        &[(0b01001, &ENTRY_UNSPECIALIZINGER_10541176028877396187)],
        &[(0b01001, &ENTRY_UNSPECIALIZINGEST_13963040120295765584)],
        &[(0b00001, &ENTRY_UNSPECTERLIKE_15729881691571605322)],
        &[(0b00001, &ENTRY_UNSPECTERLIKES_12569940984145654311)],
        &[(0b11010, &ENTRY_UNSPECTERLIKE_15729881691571605322)],
        &[(0b11010, &ENTRY_UNSPECTERLIKES_12569940984145654311)],
        &[(0b10010, &ENTRY_UNSPIRITUALIZE_5916555052861323400)],
        &[(0b10010, &ENTRY_UNSPIRITUALIZED_13793878683851952015)],
        &[(0b10010, &ENTRY_UNSPIRITUALIZES_13159558072175914180)],
        &[(0b10010, &ENTRY_UNSPIRITUALIZING_17178897114095131956)],
        &[(0b01001, &ENTRY_UNSPIRITUALIZE_5916555052861323400)],
        &[(0b01001, &ENTRY_UNSPIRITUALIZED_13793878683851952015)],
        &[(0b01001, &ENTRY_UNSPIRITUALIZES_13159558072175914180)],
        &[(0b01001, &ENTRY_UNSPIRITUALIZING_17178897114095131956)],
        &[(0b00001, &ENTRY_UNSPLENDOROUS_15638368483821854285)],
        &[(0b00001, &ENTRY_UNSPLENDOROUSLY_11800106086712842867)],
        &[(0b11010, &ENTRY_UNSPLENDOROUS_15638368483821854285)],
        &[(0b11010, &ENTRY_UNSPLENDOROUSLY_11800106086712842867)],
    ],
    range: 9..=13,
};

static VARS_UNSO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSO_CHILDREN),
    value: None,
};

pub static VARS_UNSO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cialised"),
        dictgen::InsensitiveStr::Ascii("cialisedder"),
        dictgen::InsensitiveStr::Ascii("cialiseddest"),
        dictgen::InsensitiveStr::Ascii("cialising"),
        dictgen::InsensitiveStr::Ascii("cialized"),
        dictgen::InsensitiveStr::Ascii("cializedder"),
        dictgen::InsensitiveStr::Ascii("cializeddest"),
        dictgen::InsensitiveStr::Ascii("cializing"),
        dictgen::InsensitiveStr::Ascii("lemnise"),
        dictgen::InsensitiveStr::Ascii("lemnised"),
        dictgen::InsensitiveStr::Ascii("lemnisedder"),
        dictgen::InsensitiveStr::Ascii("lemniseddest"),
        dictgen::InsensitiveStr::Ascii("lemnises"),
        dictgen::InsensitiveStr::Ascii("lemnize"),
        dictgen::InsensitiveStr::Ascii("lemnized"),
        dictgen::InsensitiveStr::Ascii("lemnizedder"),
        dictgen::InsensitiveStr::Ascii("lemnizeddest"),
        dictgen::InsensitiveStr::Ascii("lemnizes"),
        dictgen::InsensitiveStr::Ascii("mber"),
        dictgen::InsensitiveStr::Ascii("mberly"),
        dictgen::InsensitiveStr::Ascii("mberness"),
        dictgen::InsensitiveStr::Ascii("mbre"),
        dictgen::InsensitiveStr::Ascii("mbrely"),
        dictgen::InsensitiveStr::Ascii("mbreness"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSOCIALIZED_3496138542165260759)],
        &[(0b10010, &ENTRY_UNSOCIALIZEDDER_10880141521153969743)],
        &[(0b10010, &ENTRY_UNSOCIALIZEDDEST_4448774529600758329)],
        &[(0b10010, &ENTRY_UNSOCIALIZING_8509052272131880502)],
        &[(0b01001, &ENTRY_UNSOCIALIZED_3496138542165260759)],
        &[(0b01001, &ENTRY_UNSOCIALIZEDDER_10880141521153969743)],
        &[(0b01001, &ENTRY_UNSOCIALIZEDDEST_4448774529600758329)],
        &[(0b01001, &ENTRY_UNSOCIALIZING_8509052272131880502)],
        &[(0b10010, &ENTRY_UNSOLEMNIZE_17754689905088315837)],
        &[(0b10010, &ENTRY_UNSOLEMNIZED_13405781150896516414)],
        &[(0b10010, &ENTRY_UNSOLEMNIZEDDER_12639019762331536413)],
        &[(0b10010, &ENTRY_UNSOLEMNIZEDDEST_9414390961190285845)],
        &[(0b10010, &ENTRY_UNSOLEMNIZES_3236564255173918334)],
        &[(0b01001, &ENTRY_UNSOLEMNIZE_17754689905088315837)],
        &[(0b01001, &ENTRY_UNSOLEMNIZED_13405781150896516414)],
        &[(0b01001, &ENTRY_UNSOLEMNIZEDDER_12639019762331536413)],
        &[(0b01001, &ENTRY_UNSOLEMNIZEDDEST_9414390961190285845)],
        &[(0b01001, &ENTRY_UNSOLEMNIZES_3236564255173918334)],
        &[(0b00001, &ENTRY_UNSOMBER_9849015273292267538)],
        &[(0b00001, &ENTRY_UNSOMBERLY_3720066922443442116)],
        &[(0b00001, &ENTRY_UNSOMBERNESS_5229571241405215642)],
        &[(0b11010, &ENTRY_UNSOMBER_9849015273292267538)],
        &[(0b11010, &ENTRY_UNSOMBERLY_3720066922443442116)],
        &[(0b11010, &ENTRY_UNSOMBERNESS_5229571241405215642)],
    ],
    range: 4..=12,
};

static VARS_UNSI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSI_CHILDREN),
    value: None,
};

pub static VARS_UNSI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gnalised"),
        dictgen::InsensitiveStr::Ascii("gnalisedder"),
        dictgen::InsensitiveStr::Ascii("gnaliseddest"),
        dictgen::InsensitiveStr::Ascii("gnaliseds"),
        dictgen::InsensitiveStr::Ascii("gnalized"),
        dictgen::InsensitiveStr::Ascii("gnalizedder"),
        dictgen::InsensitiveStr::Ascii("gnalizeddest"),
        dictgen::InsensitiveStr::Ascii("gnalizeds"),
        dictgen::InsensitiveStr::Ascii("phon"),
        dictgen::InsensitiveStr::Ascii("phons"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSIGNALIZED_18072380712584870147)],
        &[(0b10010, &ENTRY_UNSIGNALIZEDDER_2263217046824972534)],
        &[(0b10010, &ENTRY_UNSIGNALIZEDDEST_14758681485610426786)],
        &[(0b10010, &ENTRY_UNSIGNALIZEDS_8158537188065551521)],
        &[(0b01001, &ENTRY_UNSIGNALIZED_18072380712584870147)],
        &[(0b01001, &ENTRY_UNSIGNALIZEDDER_2263217046824972534)],
        &[(0b01001, &ENTRY_UNSIGNALIZEDDEST_14758681485610426786)],
        &[(0b01001, &ENTRY_UNSIGNALIZEDS_8158537188065551521)],
        &[(0b00001, &ENTRY_UNSIPHON_8751298592164441841)],
        &[(0b00001, &ENTRY_UNSIPHONS_6487069638314844152)],
    ],
    range: 4..=12,
};

static VARS_UNSH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSH_CHILDREN),
    value: None,
};

pub static VARS_UNSH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("oed"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNSHED_1748678126240642191)],
        &[(0b11010, &ENTRY_UNSHED_1748678126240642191)],
    ],
    range: 2..=3,
};

static VARS_UNSE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSE_CHILDREN),
    value: None,
};

pub static VARS_UNSE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctarianise"),
        dictgen::InsensitiveStr::Ascii("ctarianises"),
        dictgen::InsensitiveStr::Ascii("ctarianize"),
        dictgen::InsensitiveStr::Ascii("ctarianizes"),
        dictgen::InsensitiveStr::Ascii("ctionalised"),
        dictgen::InsensitiveStr::Ascii("ctionalized"),
        dictgen::InsensitiveStr::Ascii("cularise"),
        dictgen::InsensitiveStr::Ascii("cularised"),
        dictgen::InsensitiveStr::Ascii("cularisedder"),
        dictgen::InsensitiveStr::Ascii("culariseddest"),
        dictgen::InsensitiveStr::Ascii("cularises"),
        dictgen::InsensitiveStr::Ascii("cularize"),
        dictgen::InsensitiveStr::Ascii("cularized"),
        dictgen::InsensitiveStr::Ascii("cularizedder"),
        dictgen::InsensitiveStr::Ascii("cularizeddest"),
        dictgen::InsensitiveStr::Ascii("cularizes"),
        dictgen::InsensitiveStr::Ascii("nsitise"),
        dictgen::InsensitiveStr::Ascii("nsitised"),
        dictgen::InsensitiveStr::Ascii("nsitises"),
        dictgen::InsensitiveStr::Ascii("nsitising"),
        dictgen::InsensitiveStr::Ascii("nsitize"),
        dictgen::InsensitiveStr::Ascii("nsitized"),
        dictgen::InsensitiveStr::Ascii("nsitizes"),
        dictgen::InsensitiveStr::Ascii("nsitizing"),
        dictgen::InsensitiveStr::Ascii("nsualise"),
        dictgen::InsensitiveStr::Ascii("nsualised"),
        dictgen::InsensitiveStr::Ascii("nsualises"),
        dictgen::InsensitiveStr::Ascii("nsualising"),
        dictgen::InsensitiveStr::Ascii("nsualize"),
        dictgen::InsensitiveStr::Ascii("nsualized"),
        dictgen::InsensitiveStr::Ascii("nsualizes"),
        dictgen::InsensitiveStr::Ascii("nsualizing"),
        dictgen::InsensitiveStr::Ascii("ntimentalise"),
        dictgen::InsensitiveStr::Ascii("ntimentalised"),
        dictgen::InsensitiveStr::Ascii("ntimentalises"),
        dictgen::InsensitiveStr::Ascii("ntimentalize"),
        dictgen::InsensitiveStr::Ascii("ntimentalized"),
        dictgen::InsensitiveStr::Ascii("ntimentalizes"),
        dictgen::InsensitiveStr::Ascii("pulcher"),
        dictgen::InsensitiveStr::Ascii("pulchered"),
        dictgen::InsensitiveStr::Ascii("pulchers"),
        dictgen::InsensitiveStr::Ascii("pulchre"),
        dictgen::InsensitiveStr::Ascii("pulchred"),
        dictgen::InsensitiveStr::Ascii("pulchres"),
        dictgen::InsensitiveStr::Ascii("rialised"),
        dictgen::InsensitiveStr::Ascii("rialized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSECTARIANIZE_8896277406677200944)],
        &[(0b10010, &ENTRY_UNSECTARIANIZES_17346999740171237029)],
        &[(0b01001, &ENTRY_UNSECTARIANIZE_8896277406677200944)],
        &[(0b01001, &ENTRY_UNSECTARIANIZES_17346999740171237029)],
        &[(0b10010, &ENTRY_UNSECTIONALIZED_5425065226264728201)],
        &[(0b01001, &ENTRY_UNSECTIONALIZED_5425065226264728201)],
        &[(0b10010, &ENTRY_UNSECULARIZE_5214216027332443223)],
        &[(0b10010, &ENTRY_UNSECULARIZED_14903658695506748830)],
        &[(0b10010, &ENTRY_UNSECULARIZEDDER_11676957079943780409)],
        &[(0b10010, &ENTRY_UNSECULARIZEDDEST_2864881942285944778)],
        &[(0b10010, &ENTRY_UNSECULARIZES_9891479802659859412)],
        &[(0b01001, &ENTRY_UNSECULARIZE_5214216027332443223)],
        &[(0b01001, &ENTRY_UNSECULARIZED_14903658695506748830)],
        &[(0b01001, &ENTRY_UNSECULARIZEDDER_11676957079943780409)],
        &[(0b01001, &ENTRY_UNSECULARIZEDDEST_2864881942285944778)],
        &[(0b01001, &ENTRY_UNSECULARIZES_9891479802659859412)],
        &[(0b10010, &ENTRY_UNSENSITIZE_10205463848604074076)],
        &[(0b10010, &ENTRY_UNSENSITIZED_7794134976310825921)],
        &[(0b10010, &ENTRY_UNSENSITIZES_5803069635824140326)],
        &[(0b10010, &ENTRY_UNSENSITIZING_5882427315960709496)],
        &[(0b01001, &ENTRY_UNSENSITIZE_10205463848604074076)],
        &[(0b01001, &ENTRY_UNSENSITIZED_7794134976310825921)],
        &[(0b01001, &ENTRY_UNSENSITIZES_5803069635824140326)],
        &[(0b01001, &ENTRY_UNSENSITIZING_5882427315960709496)],
        &[(0b10010, &ENTRY_UNSENSUALIZE_15769041899106603358)],
        &[(0b10010, &ENTRY_UNSENSUALIZED_32054534269141140)],
        &[(0b10010, &ENTRY_UNSENSUALIZES_12397866517645397490)],
        &[(0b10010, &ENTRY_UNSENSUALIZING_1812813256933634221)],
        &[(0b01001, &ENTRY_UNSENSUALIZE_15769041899106603358)],
        &[(0b01001, &ENTRY_UNSENSUALIZED_32054534269141140)],
        &[(0b01001, &ENTRY_UNSENSUALIZES_12397866517645397490)],
        &[(0b01001, &ENTRY_UNSENSUALIZING_1812813256933634221)],
        &[(0b10010, &ENTRY_UNSENTIMENTALIZE_5597748571008194983)],
        &[(0b10010, &ENTRY_UNSENTIMENTALIZED_6565195653528439940)],
        &[(0b10010, &ENTRY_UNSENTIMENTALIZES_9475174647404255643)],
        &[(0b01001, &ENTRY_UNSENTIMENTALIZE_5597748571008194983)],
        &[(0b01001, &ENTRY_UNSENTIMENTALIZED_6565195653528439940)],
        &[(0b01001, &ENTRY_UNSENTIMENTALIZES_9475174647404255643)],
        &[(0b00001, &ENTRY_UNSEPULCHER_3660018467990610478)],
        &[(0b00001, &ENTRY_UNSEPULCHERED_728988728789570667)],
        &[(0b00001, &ENTRY_UNSEPULCHERS_1679319036273540108)],
        &[(0b11010, &ENTRY_UNSEPULCHER_3660018467990610478)],
        &[(0b11010, &ENTRY_UNSEPULCHERED_728988728789570667)],
        &[(0b11010, &ENTRY_UNSEPULCHERS_1679319036273540108)],
        &[(0b10010, &ENTRY_UNSERIALIZED_14154792643266589843)],
        &[(0b01001, &ENTRY_UNSERIALIZED_14154792643266589843)],
    ],
    range: 7..=13,
};

static VARS_UNSC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSC_CHILDREN),
    value: None,
};

pub static VARS_UNSC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andalise"),
        dictgen::InsensitiveStr::Ascii("andalised"),
        dictgen::InsensitiveStr::Ascii("andalisedder"),
        dictgen::InsensitiveStr::Ascii("andaliseddest"),
        dictgen::InsensitiveStr::Ascii("andalises"),
        dictgen::InsensitiveStr::Ascii("andalize"),
        dictgen::InsensitiveStr::Ascii("andalized"),
        dictgen::InsensitiveStr::Ascii("andalizedder"),
        dictgen::InsensitiveStr::Ascii("andalizeddest"),
        dictgen::InsensitiveStr::Ascii("andalizes"),
        dictgen::InsensitiveStr::Ascii("epter"),
        dictgen::InsensitiveStr::Ascii("eptered"),
        dictgen::InsensitiveStr::Ascii("epteredder"),
        dictgen::InsensitiveStr::Ascii("eptereddest"),
        dictgen::InsensitiveStr::Ascii("epters"),
        dictgen::InsensitiveStr::Ascii("eptre"),
        dictgen::InsensitiveStr::Ascii("eptred"),
        dictgen::InsensitiveStr::Ascii("eptredder"),
        dictgen::InsensitiveStr::Ascii("eptreddest"),
        dictgen::InsensitiveStr::Ascii("eptres"),
        dictgen::InsensitiveStr::Ascii("hematised"),
        dictgen::InsensitiveStr::Ascii("hematisedder"),
        dictgen::InsensitiveStr::Ascii("hematiseddest"),
        dictgen::InsensitiveStr::Ascii("hematiseds"),
        dictgen::InsensitiveStr::Ascii("hematized"),
        dictgen::InsensitiveStr::Ascii("hematizedder"),
        dictgen::InsensitiveStr::Ascii("hematizeddest"),
        dictgen::InsensitiveStr::Ascii("hematizeds"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("rutinised"),
        dictgen::InsensitiveStr::Ascii("rutinisedder"),
        dictgen::InsensitiveStr::Ascii("rutiniseddest"),
        dictgen::InsensitiveStr::Ascii("rutinising"),
        dictgen::InsensitiveStr::Ascii("rutinisinger"),
        dictgen::InsensitiveStr::Ascii("rutinisingest"),
        dictgen::InsensitiveStr::Ascii("rutinisinglier"),
        dictgen::InsensitiveStr::Ascii("rutinisingliest"),
        dictgen::InsensitiveStr::Ascii("rutinisingly"),
        dictgen::InsensitiveStr::Ascii("rutinized"),
        dictgen::InsensitiveStr::Ascii("rutinizedder"),
        dictgen::InsensitiveStr::Ascii("rutinizeddest"),
        dictgen::InsensitiveStr::Ascii("rutinizing"),
        dictgen::InsensitiveStr::Ascii("rutinizinger"),
        dictgen::InsensitiveStr::Ascii("rutinizingest"),
        dictgen::InsensitiveStr::Ascii("rutinizinglier"),
        dictgen::InsensitiveStr::Ascii("rutinizingliest"),
        dictgen::InsensitiveStr::Ascii("rutinizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNSCANDALIZE_520505661327966431)],
        &[(0b10010, &ENTRY_UNSCANDALIZED_8152094708030261523)],
        &[(0b10010, &ENTRY_UNSCANDALIZEDDER_16598075610375338334)],
        &[(0b10010, &ENTRY_UNSCANDALIZEDDEST_10751215903020225937)],
        &[(0b10010, &ENTRY_UNSCANDALIZES_17840125261680020227)],
        &[(0b01001, &ENTRY_UNSCANDALIZE_520505661327966431)],
        &[(0b01001, &ENTRY_UNSCANDALIZED_8152094708030261523)],
        &[(0b01001, &ENTRY_UNSCANDALIZEDDER_16598075610375338334)],
        &[(0b01001, &ENTRY_UNSCANDALIZEDDEST_10751215903020225937)],
        &[(0b01001, &ENTRY_UNSCANDALIZES_17840125261680020227)],
        &[(0b00001, &ENTRY_UNSCEPTER_12310705858970392134)],
        &[(0b00001, &ENTRY_UNSCEPTERED_13340295677500887608)],
        &[(0b00001, &ENTRY_UNSCEPTEREDDER_2376849210254288587)],
        &[(0b00001, &ENTRY_UNSCEPTEREDDEST_13269872785173189124)],
        &[(0b00001, &ENTRY_UNSCEPTERS_3877189759939193522)],
        &[(0b11010, &ENTRY_UNSCEPTER_12310705858970392134)],
        &[(0b11010, &ENTRY_UNSCEPTERED_13340295677500887608)],
        &[(0b11010, &ENTRY_UNSCEPTEREDDER_2376849210254288587)],
        &[(0b11010, &ENTRY_UNSCEPTEREDDEST_13269872785173189124)],
        &[(0b11010, &ENTRY_UNSCEPTERS_3877189759939193522)],
        &[(0b10010, &ENTRY_UNSCHEMATIZED_15829880150892985637)],
        &[(0b10010, &ENTRY_UNSCHEMATIZEDDER_4716532793392136205)],
        &[(0b10010, &ENTRY_UNSCHEMATIZEDDEST_12088700656751368211)],
        &[(0b10010, &ENTRY_UNSCHEMATIZEDS_298126258475951987)],
        &[(0b01001, &ENTRY_UNSCHEMATIZED_15829880150892985637)],
        &[(0b01001, &ENTRY_UNSCHEMATIZEDDER_4716532793392136205)],
        &[(0b01001, &ENTRY_UNSCHEMATIZEDDEST_12088700656751368211)],
        &[(0b01001, &ENTRY_UNSCHEMATIZEDS_298126258475951987)],
        &[(0b00001, &ENTRY_UNSCORED_14510217564861462498)],
        &[(0b00001, &ENTRY_UNSCORING_7857262218542359235)],
        &[(0b11010, &ENTRY_UNSCORED_14510217564861462498)],
        &[(0b11010, &ENTRY_UNSCORING_7857262218542359235)],
        &[(0b10010, &ENTRY_UNSCRUTINIZED_4499174384647942184)],
        &[(0b10010, &ENTRY_UNSCRUTINIZEDDER_14564478170521424195)],
        &[(0b10010, &ENTRY_UNSCRUTINIZEDDEST_16503621375052442349)],
        &[(0b10010, &ENTRY_UNSCRUTINIZING_12963862895980253271)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGER_4340449043412100187)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGEST_9456217512411188422)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGLIER_16918089062255487129)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGLIEST_4936819005717689952)],
        &[(0b10010, &ENTRY_UNSCRUTINIZINGLY_5893546295582674444)],
        &[(0b01001, &ENTRY_UNSCRUTINIZED_4499174384647942184)],
        &[(0b01001, &ENTRY_UNSCRUTINIZEDDER_14564478170521424195)],
        &[(0b01001, &ENTRY_UNSCRUTINIZEDDEST_16503621375052442349)],
        &[(0b01001, &ENTRY_UNSCRUTINIZING_12963862895980253271)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGER_4340449043412100187)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGEST_9456217512411188422)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGLIER_16918089062255487129)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGLIEST_4936819005717689952)],
        &[(0b01001, &ENTRY_UNSCRUTINIZINGLY_5893546295582674444)],
    ],
    range: 4..=15,
};

static VARS_UNSA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNSA_CHILDREN),
    value: None,
};

pub static VARS_UNSA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bered"),
        dictgen::InsensitiveStr::Ascii("beredder"),
        dictgen::InsensitiveStr::Ascii("bereddest"),
        dictgen::InsensitiveStr::Ascii("bred"),
        dictgen::InsensitiveStr::Ascii("bredder"),
        dictgen::InsensitiveStr::Ascii("breddest"),
        dictgen::InsensitiveStr::Ascii("tirisable"),
        dictgen::InsensitiveStr::Ascii("tirise"),
        dictgen::InsensitiveStr::Ascii("tirised"),
        dictgen::InsensitiveStr::Ascii("tirisedder"),
        dictgen::InsensitiveStr::Ascii("tiriseddest"),
        dictgen::InsensitiveStr::Ascii("tirises"),
        dictgen::InsensitiveStr::Ascii("tirizable"),
        dictgen::InsensitiveStr::Ascii("tirize"),
        dictgen::InsensitiveStr::Ascii("tirized"),
        dictgen::InsensitiveStr::Ascii("tirizedder"),
        dictgen::InsensitiveStr::Ascii("tirizeddest"),
        dictgen::InsensitiveStr::Ascii("tirizes"),
        dictgen::InsensitiveStr::Ascii("vored"),
        dictgen::InsensitiveStr::Ascii("voredder"),
        dictgen::InsensitiveStr::Ascii("voreddest"),
        dictgen::InsensitiveStr::Ascii("voredly"),
        dictgen::InsensitiveStr::Ascii("voredness"),
        dictgen::InsensitiveStr::Ascii("vorier"),
        dictgen::InsensitiveStr::Ascii("vories"),
        dictgen::InsensitiveStr::Ascii("voriest"),
        dictgen::InsensitiveStr::Ascii("vorilier"),
        dictgen::InsensitiveStr::Ascii("vorilies"),
        dictgen::InsensitiveStr::Ascii("voriliest"),
        dictgen::InsensitiveStr::Ascii("vorily"),
        dictgen::InsensitiveStr::Ascii("voriness"),
        dictgen::InsensitiveStr::Ascii("vorinesses"),
        dictgen::InsensitiveStr::Ascii("vory"),
        dictgen::InsensitiveStr::Ascii("voured"),
        dictgen::InsensitiveStr::Ascii("vouredder"),
        dictgen::InsensitiveStr::Ascii("voureddest"),
        dictgen::InsensitiveStr::Ascii("vouredly"),
        dictgen::InsensitiveStr::Ascii("vouredness"),
        dictgen::InsensitiveStr::Ascii("vourier"),
        dictgen::InsensitiveStr::Ascii("vouries"),
        dictgen::InsensitiveStr::Ascii("vouriest"),
        dictgen::InsensitiveStr::Ascii("vourilier"),
        dictgen::InsensitiveStr::Ascii("vourilies"),
        dictgen::InsensitiveStr::Ascii("vouriliest"),
        dictgen::InsensitiveStr::Ascii("vourily"),
        dictgen::InsensitiveStr::Ascii("vouriness"),
        dictgen::InsensitiveStr::Ascii("vourinesses"),
        dictgen::InsensitiveStr::Ascii("voury"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNSABERED_7177981977292168575)],
        &[(0b00001, &ENTRY_UNSABEREDDER_1732672318778523343)],
        &[(0b00001, &ENTRY_UNSABEREDDEST_4361858810448422047)],
        &[(0b11010, &ENTRY_UNSABERED_7177981977292168575)],
        &[(0b11010, &ENTRY_UNSABEREDDER_1732672318778523343)],
        &[(0b11010, &ENTRY_UNSABEREDDEST_4361858810448422047)],
        &[(0b10010, &ENTRY_UNSATIRIZABLE_11743121723677468480)],
        &[(0b10010, &ENTRY_UNSATIRIZE_34395718428272863)],
        &[(0b10010, &ENTRY_UNSATIRIZED_13793588944367095442)],
        &[(0b10010, &ENTRY_UNSATIRIZEDDER_11457550322600274631)],
        &[(0b10010, &ENTRY_UNSATIRIZEDDEST_4126847310419402743)],
        &[(0b10010, &ENTRY_UNSATIRIZES_13382097901467533418)],
        &[(0b01001, &ENTRY_UNSATIRIZABLE_11743121723677468480)],
        &[(0b01001, &ENTRY_UNSATIRIZE_34395718428272863)],
        &[(0b01001, &ENTRY_UNSATIRIZED_13793588944367095442)],
        &[(0b01001, &ENTRY_UNSATIRIZEDDER_11457550322600274631)],
        &[(0b01001, &ENTRY_UNSATIRIZEDDEST_4126847310419402743)],
        &[(0b01001, &ENTRY_UNSATIRIZES_13382097901467533418)],
        &[(0b00001, &ENTRY_UNSAVORED_835718759607657454)],
        &[(0b00001, &ENTRY_UNSAVOREDDER_9689868158053003438)],
        &[(0b00001, &ENTRY_UNSAVOREDDEST_9031970620246286024)],
        &[(0b00001, &ENTRY_UNSAVOREDLY_8889339578327024203)],
        &[(0b00001, &ENTRY_UNSAVOREDNESS_8894397023697955452)],
        &[(0b01001, &ENTRY_UNSAVORIER_11499851903563622390)],
        &[(0b01001, &ENTRY_UNSAVORIES_564856304299168322)],
        &[(0b01001, &ENTRY_UNSAVORIEST_4272222949170545033)],
        &[(0b00001, &ENTRY_UNSAVORILIER_17795073319281436965)],
        &[(0b00001, &ENTRY_UNSAVORILIES_2379987631293155666)],
        &[(0b00001, &ENTRY_UNSAVORILIEST_10649069445986118122)],
        &[(0b00001, &ENTRY_UNSAVORILY_10670667337623880247)],
        &[(0b00001, &ENTRY_UNSAVORINESS_16734401353949800250)],
        &[(0b00001, &ENTRY_UNSAVORINESSES_8712909678084814914)],
        &[(0b01001, &ENTRY_UNSAVORY_5814802780012802033)],
        &[(0b11010, &ENTRY_UNSAVORED_835718759607657454)],
        &[(0b11010, &ENTRY_UNSAVOREDDER_9689868158053003438)],
        &[(0b11010, &ENTRY_UNSAVOREDDEST_9031970620246286024)],
        &[(0b11010, &ENTRY_UNSAVOREDLY_8889339578327024203)],
        &[(0b11010, &ENTRY_UNSAVOREDNESS_8894397023697955452)],
        &[(0b11010, &ENTRY_UNSAVORIER_11499851903563622390)],
        &[(0b11010, &ENTRY_UNSAVORIES_564856304299168322)],
        &[(0b11010, &ENTRY_UNSAVORIEST_4272222949170545033)],
        &[(0b11010, &ENTRY_UNSAVORILIER_17795073319281436965)],
        &[(0b11010, &ENTRY_UNSAVORILIES_2379987631293155666)],
        &[(0b11010, &ENTRY_UNSAVORILIEST_10649069445986118122)],
        &[(0b11010, &ENTRY_UNSAVORILY_10670667337623880247)],
        &[(0b11010, &ENTRY_UNSAVORINESS_16734401353949800250)],
        &[(0b11010, &ENTRY_UNSAVORINESSES_8712909678084814914)],
        &[(0b11010, &ENTRY_UNSAVORY_5814802780012802033)],
    ],
    range: 4..=11,
};

static VARS_UNR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNR_CHILDREN),
    value: None,
};

static VARS_UNR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNRA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNRE_NODE),
    None,
    None,
    None,
    Some(&VARS_UNRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNRU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRU_CHILDREN),
    value: None,
};

pub static VARS_UNRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moredder"),
        dictgen::InsensitiveStr::Ascii("moreddest"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mouredder"),
        dictgen::InsensitiveStr::Ascii("moureddest"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNRUMORED_11945081100528914083)],
        &[(0b00001, &ENTRY_UNRUMOREDDER_1235386211719339229)],
        &[(0b00001, &ENTRY_UNRUMOREDDEST_10653958198865026338)],
        &[(0b11010, &ENTRY_UNRUMORED_11945081100528914083)],
        &[(0b11010, &ENTRY_UNRUMOREDDER_1235386211719339229)],
        &[(0b11010, &ENTRY_UNRUMOREDDEST_10653958198865026338)],
    ],
    range: 5..=10,
};

static VARS_UNRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRO_CHILDREN),
    value: None,
};

pub static VARS_UNRO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manticised"),
        dictgen::InsensitiveStr::Ascii("manticisedder"),
        dictgen::InsensitiveStr::Ascii("manticiseddest"),
        dictgen::InsensitiveStr::Ascii("manticiseds"),
        dictgen::InsensitiveStr::Ascii("manticized"),
        dictgen::InsensitiveStr::Ascii("manticizedder"),
        dictgen::InsensitiveStr::Ascii("manticizeddest"),
        dictgen::InsensitiveStr::Ascii("manticizeds"),
        dictgen::InsensitiveStr::Ascii("yalised"),
        dictgen::InsensitiveStr::Ascii("yaliseds"),
        dictgen::InsensitiveStr::Ascii("yalized"),
        dictgen::InsensitiveStr::Ascii("yalizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNROMANIZED_3332586790919173959)],
        &[(0b01001, &ENTRY_UNROMANIZED_3332586790919173959)],
        &[(0b10010, &ENTRY_UNROMANTICIZED_12323250999848162828)],
        &[(0b10010, &ENTRY_UNROMANTICIZEDDER_7880803665433466684)],
        &[(0b10010, &ENTRY_UNROMANTICIZEDDEST_4366413467561211143)],
        &[(0b10010, &ENTRY_UNROMANTICIZEDS_6905411968539131627)],
        &[(0b01001, &ENTRY_UNROMANTICIZED_12323250999848162828)],
        &[(0b01001, &ENTRY_UNROMANTICIZEDDER_7880803665433466684)],
        &[(0b01001, &ENTRY_UNROMANTICIZEDDEST_4366413467561211143)],
        &[(0b01001, &ENTRY_UNROMANTICIZEDS_6905411968539131627)],
        &[(0b10010, &ENTRY_UNROYALIZED_463331773464183743)],
        &[(0b10010, &ENTRY_UNROYALIZEDS_18166484644206892914)],
        &[(0b01001, &ENTRY_UNROYALIZED_463331773464183743)],
        &[(0b01001, &ENTRY_UNROYALIZEDS_18166484644206892914)],
    ],
    range: 7..=14,
};

static VARS_UNRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRI_CHILDREN),
    value: None,
};

pub static VARS_UNRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("valed"),
        dictgen::InsensitiveStr::Ascii("valedder"),
        dictgen::InsensitiveStr::Ascii("valeddest"),
        dictgen::InsensitiveStr::Ascii("valled"),
        dictgen::InsensitiveStr::Ascii("valledder"),
        dictgen::InsensitiveStr::Ascii("valleddest"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNRIVALED_7117684569657820456)],
        &[(0b00001, &ENTRY_UNRIVALEDDER_4770647244445881329)],
        &[(0b00001, &ENTRY_UNRIVALEDDEST_6685390969368773151)],
        &[(0b11010, &ENTRY_UNRIVALED_7117684569657820456)],
        &[(0b11010, &ENTRY_UNRIVALEDDER_4770647244445881329)],
        &[(0b11010, &ENTRY_UNRIVALEDDEST_6685390969368773151)],
    ],
    range: 5..=10,
};

static VARS_UNRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRE_CHILDREN),
    value: None,
};

pub static VARS_UNRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisables"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alisings"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alizables"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("alizings"),
        dictgen::InsensitiveStr::Ascii("cognisable"),
        dictgen::InsensitiveStr::Ascii("cognisabler"),
        dictgen::InsensitiveStr::Ascii("cognisablest"),
        dictgen::InsensitiveStr::Ascii("cognisably"),
        dictgen::InsensitiveStr::Ascii("cognised"),
        dictgen::InsensitiveStr::Ascii("cognising"),
        dictgen::InsensitiveStr::Ascii("cognisingly"),
        dictgen::InsensitiveStr::Ascii("cognizable"),
        dictgen::InsensitiveStr::Ascii("cognizabler"),
        dictgen::InsensitiveStr::Ascii("cognizablest"),
        dictgen::InsensitiveStr::Ascii("cognizably"),
        dictgen::InsensitiveStr::Ascii("cognized"),
        dictgen::InsensitiveStr::Ascii("cognizing"),
        dictgen::InsensitiveStr::Ascii("cognizingly"),
        dictgen::InsensitiveStr::Ascii("connoitered"),
        dictgen::InsensitiveStr::Ascii("connoiteredder"),
        dictgen::InsensitiveStr::Ascii("connoitereddest"),
        dictgen::InsensitiveStr::Ascii("connoitereds"),
        dictgen::InsensitiveStr::Ascii("connoitred"),
        dictgen::InsensitiveStr::Ascii("connoitredder"),
        dictgen::InsensitiveStr::Ascii("connoitreddest"),
        dictgen::InsensitiveStr::Ascii("connoitreds"),
        dictgen::InsensitiveStr::Ascii("gularised"),
        dictgen::InsensitiveStr::Ascii("gularized"),
        dictgen::InsensitiveStr::Ascii("organised"),
        dictgen::InsensitiveStr::Ascii("organisedder"),
        dictgen::InsensitiveStr::Ascii("organiseddest"),
        dictgen::InsensitiveStr::Ascii("organized"),
        dictgen::InsensitiveStr::Ascii("organizedder"),
        dictgen::InsensitiveStr::Ascii("organizeddest"),
        dictgen::InsensitiveStr::Ascii("velationise"),
        dictgen::InsensitiveStr::Ascii("velationises"),
        dictgen::InsensitiveStr::Ascii("velationize"),
        dictgen::InsensitiveStr::Ascii("velationizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNREALIZABLE_7427131823977755851)],
        &[(0b10010, &ENTRY_UNREALIZABLES_9314641022749638380)],
        &[(0b10010, &ENTRY_UNREALIZE_13658903213229006471)],
        &[(0b10010, &ENTRY_UNREALIZED_17404817653704661257)],
        &[(0b10010, &ENTRY_UNREALIZES_5730139003901729864)],
        &[(0b10010, &ENTRY_UNREALIZING_16148636932622971777)],
        &[(0b10010, &ENTRY_UNREALIZINGS_15326868678672664338)],
        &[(0b01001, &ENTRY_UNREALIZABLE_7427131823977755851)],
        &[(0b01001, &ENTRY_UNREALIZABLES_9314641022749638380)],
        &[(0b01001, &ENTRY_UNREALIZE_13658903213229006471)],
        &[(0b01001, &ENTRY_UNREALIZED_17404817653704661257)],
        &[(0b01001, &ENTRY_UNREALIZES_5730139003901729864)],
        &[(0b01001, &ENTRY_UNREALIZING_16148636932622971777)],
        &[(0b01001, &ENTRY_UNREALIZINGS_15326868678672664338)],
        &[(0b10010, &ENTRY_UNRECOGNIZABLE_13177594232205592621)],
        &[(0b10010, &ENTRY_UNRECOGNIZABLER_15443328521804403575)],
        &[(0b10010, &ENTRY_UNRECOGNIZABLEST_11700300065072913162)],
        &[(0b10010, &ENTRY_UNRECOGNIZABLY_12498741757123655980)],
        &[(0b10010, &ENTRY_UNRECOGNIZED_15339742215625954957)],
        &[(0b10010, &ENTRY_UNRECOGNIZING_15165523388753258920)],
        &[(0b10010, &ENTRY_UNRECOGNIZINGLY_2227023476747181630)],
        &[(0b01001, &ENTRY_UNRECOGNIZABLE_13177594232205592621)],
        &[(0b01001, &ENTRY_UNRECOGNIZABLER_15443328521804403575)],
        &[(0b01001, &ENTRY_UNRECOGNIZABLEST_11700300065072913162)],
        &[(0b01001, &ENTRY_UNRECOGNIZABLY_12498741757123655980)],
        &[(0b01001, &ENTRY_UNRECOGNIZED_15339742215625954957)],
        &[(0b01001, &ENTRY_UNRECOGNIZING_15165523388753258920)],
        &[(0b01001, &ENTRY_UNRECOGNIZINGLY_2227023476747181630)],
        &[(0b00001, &ENTRY_UNRECONNOITERED_7020570262194740993)],
        &[(0b00001, &ENTRY_UNRECONNOITEREDDER_6824132526297537617)],
        &[(0b00001, &ENTRY_UNRECONNOITEREDDEST_14662375144067296424)],
        &[(0b00001, &ENTRY_UNRECONNOITEREDS_10144374598602641365)],
        &[(0b11010, &ENTRY_UNRECONNOITERED_7020570262194740993)],
        &[(0b11010, &ENTRY_UNRECONNOITEREDDER_6824132526297537617)],
        &[(0b11010, &ENTRY_UNRECONNOITEREDDEST_14662375144067296424)],
        &[(0b11010, &ENTRY_UNRECONNOITEREDS_10144374598602641365)],
        &[(0b10010, &ENTRY_UNREGULARIZED_8237418541509267985)],
        &[(0b01001, &ENTRY_UNREGULARIZED_8237418541509267985)],
        &[(0b10010, &ENTRY_UNREORGANIZED_15237002088977221645)],
        &[(0b10010, &ENTRY_UNREORGANIZEDDER_6817535441462629186)],
        &[(0b10010, &ENTRY_UNREORGANIZEDDEST_16921729744186143176)],
        &[(0b01001, &ENTRY_UNREORGANIZED_15237002088977221645)],
        &[(0b01001, &ENTRY_UNREORGANIZEDDER_6817535441462629186)],
        &[(0b01001, &ENTRY_UNREORGANIZEDDEST_16921729744186143176)],
        &[(0b10010, &ENTRY_UNREVELATIONIZE_17021292236492045263)],
        &[(0b10010, &ENTRY_UNREVELATIONIZES_8974203434399731612)],
        &[(0b01001, &ENTRY_UNREVELATIONIZE_17021292236492045263)],
        &[(0b01001, &ENTRY_UNREVELATIONIZES_8974203434399731612)],
    ],
    range: 5..=15,
};

static VARS_UNRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNRA_CHILDREN),
    value: None,
};

pub static VARS_UNRA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dicalise"),
        dictgen::InsensitiveStr::Ascii("dicalises"),
        dictgen::InsensitiveStr::Ascii("dicalize"),
        dictgen::InsensitiveStr::Ascii("dicalizes"),
        dictgen::InsensitiveStr::Ascii("ncored"),
        dictgen::InsensitiveStr::Ascii("ncoredder"),
        dictgen::InsensitiveStr::Ascii("ncoreddest"),
        dictgen::InsensitiveStr::Ascii("ncoreds"),
        dictgen::InsensitiveStr::Ascii("ncorous"),
        dictgen::InsensitiveStr::Ascii("ncoured"),
        dictgen::InsensitiveStr::Ascii("ncouredder"),
        dictgen::InsensitiveStr::Ascii("ncoureddest"),
        dictgen::InsensitiveStr::Ascii("ncoureds"),
        dictgen::InsensitiveStr::Ascii("ncourous"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("veled"),
        dictgen::InsensitiveStr::Ascii("veler"),
        dictgen::InsensitiveStr::Ascii("velers"),
        dictgen::InsensitiveStr::Ascii("veling"),
        dictgen::InsensitiveStr::Ascii("velled"),
        dictgen::InsensitiveStr::Ascii("veller"),
        dictgen::InsensitiveStr::Ascii("vellers"),
        dictgen::InsensitiveStr::Ascii("velling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNRADICALIZE_2815754936703483818)],
        &[(0b10010, &ENTRY_UNRADICALIZES_16426285436597116329)],
        &[(0b01001, &ENTRY_UNRADICALIZE_2815754936703483818)],
        &[(0b01001, &ENTRY_UNRADICALIZES_16426285436597116329)],
        &[(0b00001, &ENTRY_UNRANCORED_9184272533577547039)],
        &[(0b00001, &ENTRY_UNRANCOREDDER_6348621930598869186)],
        &[(0b00001, &ENTRY_UNRANCOREDDEST_16686379430125720872)],
        &[(0b00001, &ENTRY_UNRANCOREDS_12103687684487901758)],
        &[(0b00001, &ENTRY_UNRANCOROUS_18064074306523619211)],
        &[(0b11010, &ENTRY_UNRANCORED_9184272533577547039)],
        &[(0b11010, &ENTRY_UNRANCOREDDER_6348621930598869186)],
        &[(0b11010, &ENTRY_UNRANCOREDDEST_16686379430125720872)],
        &[(0b11010, &ENTRY_UNRANCOREDS_12103687684487901758)],
        &[(0b11010, &ENTRY_UNRANCOROUS_18064074306523619211)],
        &[(0b10010, &ENTRY_UNRATIONALIZED_16144188304714101879)],
        &[(0b10010, &ENTRY_UNRATIONALIZING_10416615276147328253)],
        &[(0b01001, &ENTRY_UNRATIONALIZED_16144188304714101879)],
        &[(0b01001, &ENTRY_UNRATIONALIZING_10416615276147328253)],
        &[(0b00001, &ENTRY_UNRAVELED_8531790293658379223)],
        &[(0b00001, &ENTRY_UNRAVELER_4944599394654130396)],
        &[(0b00001, &ENTRY_UNRAVELERS_9836540518095344389)],
        &[(0b00001, &ENTRY_UNRAVELING_17073861557040957443)],
        &[(0b11010, &ENTRY_UNRAVELED_8531790293658379223)],
        &[(0b11010, &ENTRY_UNRAVELER_4944599394654130396)],
        &[(0b11010, &ENTRY_UNRAVELERS_9836540518095344389)],
        &[(0b11010, &ENTRY_UNRAVELING_17073861557040957443)],
    ],
    range: 5..=11,
};

static VARS_UNQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNQ_CHILDREN),
    value: None,
};

pub static VARS_UNQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uantised"),
        dictgen::InsensitiveStr::Ascii("uantized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNQUANTIZED_11052817945473923658)],
        &[(0b01001, &ENTRY_UNQUANTIZED_11052817945473923658)],
    ],
    range: 8..=8,
};

static VARS_UNP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNP_CHILDREN),
    value: None,
};

static VARS_UNP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNPA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNPE_NODE),
    None,
    None,
    Some(&VARS_UNPH_NODE),
    Some(&VARS_UNPI_NODE),
    None,
    None,
    Some(&VARS_UNPL_NODE),
    None,
    None,
    Some(&VARS_UNPO_NODE),
    None,
    None,
    Some(&VARS_UNPR_NODE),
    None,
    None,
    Some(&VARS_UNPU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNPU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPU_CHILDREN),
    value: None,
};

pub static VARS_UNPU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blicised"),
        dictgen::InsensitiveStr::Ascii("blicized"),
        dictgen::InsensitiveStr::Ascii("lverise"),
        dictgen::InsensitiveStr::Ascii("lverised"),
        dictgen::InsensitiveStr::Ascii("lverisedder"),
        dictgen::InsensitiveStr::Ascii("lveriseddest"),
        dictgen::InsensitiveStr::Ascii("lverises"),
        dictgen::InsensitiveStr::Ascii("lverize"),
        dictgen::InsensitiveStr::Ascii("lverized"),
        dictgen::InsensitiveStr::Ascii("lverizedder"),
        dictgen::InsensitiveStr::Ascii("lverizeddest"),
        dictgen::InsensitiveStr::Ascii("lverizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPUBLICIZED_2598075486221782263)],
        &[(0b01001, &ENTRY_UNPUBLICIZED_2598075486221782263)],
        &[(0b10010, &ENTRY_UNPULVERIZE_1829206909657688086)],
        &[(0b10010, &ENTRY_UNPULVERIZED_14085892621205036357)],
        &[(0b10010, &ENTRY_UNPULVERIZEDDER_54420185367589206)],
        &[(0b10010, &ENTRY_UNPULVERIZEDDEST_9757737756185024283)],
        &[(0b10010, &ENTRY_UNPULVERIZES_36833523357457577)],
        &[(0b01001, &ENTRY_UNPULVERIZE_1829206909657688086)],
        &[(0b01001, &ENTRY_UNPULVERIZED_14085892621205036357)],
        &[(0b01001, &ENTRY_UNPULVERIZEDDER_54420185367589206)],
        &[(0b01001, &ENTRY_UNPULVERIZEDDEST_9757737756185024283)],
        &[(0b01001, &ENTRY_UNPULVERIZES_36833523357457577)],
    ],
    range: 7..=12,
};

static VARS_UNPR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPR_CHILDREN),
    value: None,
};

pub static VARS_UNPR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("acticed"),
        dictgen::InsensitiveStr::Ascii("acticedder"),
        dictgen::InsensitiveStr::Ascii("acticeddest"),
        dictgen::InsensitiveStr::Ascii("actised"),
        dictgen::InsensitiveStr::Ascii("actisedder"),
        dictgen::InsensitiveStr::Ascii("actiseddest"),
        dictgen::InsensitiveStr::Ascii("eceptively"),
        dictgen::InsensitiveStr::Ascii("essurised"),
        dictgen::InsensitiveStr::Ascii("essurized"),
        dictgen::InsensitiveStr::Ascii("otestantise"),
        dictgen::InsensitiveStr::Ascii("otestantised"),
        dictgen::InsensitiveStr::Ascii("otestantises"),
        dictgen::InsensitiveStr::Ascii("otestantising"),
        dictgen::InsensitiveStr::Ascii("otestantize"),
        dictgen::InsensitiveStr::Ascii("otestantized"),
        dictgen::InsensitiveStr::Ascii("otestantizes"),
        dictgen::InsensitiveStr::Ascii("otestantizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_UNPRACTICED_9353245174446259318)],
        &[(0b01001, &ENTRY_UNPRACTICEDDER_6992033786330144479)],
        &[(0b01001, &ENTRY_UNPRACTICEDDEST_15053947325497824834)],
        &[(0b11010, &ENTRY_UNPRACTICED_9353245174446259318)],
        &[(0b11010, &ENTRY_UNPRACTICEDDER_6992033786330144479)],
        &[(0b11010, &ENTRY_UNPRACTICEDDEST_15053947325497824834)],
        &[(0b11010, &ENTRY_UNPERCEPTIVELY_16674495345486986764)],
        &[(0b10010, &ENTRY_UNPRESSURIZED_1643527799717908100)],
        &[(0b01001, &ENTRY_UNPRESSURIZED_1643527799717908100)],
        &[(0b10010, &ENTRY_UNPROTESTANTIZE_5090310073731327645)],
        &[(0b10010, &ENTRY_UNPROTESTANTIZED_6820017680334554701)],
        &[(0b10010, &ENTRY_UNPROTESTANTIZES_5207108080017394469)],
        &[(0b10010, &ENTRY_UNPROTESTANTIZING_2472019232653798522)],
        &[(0b01001, &ENTRY_UNPROTESTANTIZE_5090310073731327645)],
        &[(0b01001, &ENTRY_UNPROTESTANTIZED_6820017680334554701)],
        &[(0b01001, &ENTRY_UNPROTESTANTIZES_5207108080017394469)],
        &[(0b01001, &ENTRY_UNPROTESTANTIZING_2472019232653798522)],
    ],
    range: 7..=13,
};

static VARS_UNPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPO_CHILDREN),
    value: None,
};

pub static VARS_UNPO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eticised"),
        dictgen::InsensitiveStr::Ascii("eticisedder"),
        dictgen::InsensitiveStr::Ascii("eticiseddest"),
        dictgen::InsensitiveStr::Ascii("eticiseds"),
        dictgen::InsensitiveStr::Ascii("eticized"),
        dictgen::InsensitiveStr::Ascii("eticizedder"),
        dictgen::InsensitiveStr::Ascii("eticizeddest"),
        dictgen::InsensitiveStr::Ascii("eticizeds"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("larisable"),
        dictgen::InsensitiveStr::Ascii("larisables"),
        dictgen::InsensitiveStr::Ascii("larised"),
        dictgen::InsensitiveStr::Ascii("larisedder"),
        dictgen::InsensitiveStr::Ascii("lariseddest"),
        dictgen::InsensitiveStr::Ascii("lariseds"),
        dictgen::InsensitiveStr::Ascii("larizable"),
        dictgen::InsensitiveStr::Ascii("larizables"),
        dictgen::InsensitiveStr::Ascii("larized"),
        dictgen::InsensitiveStr::Ascii("larizedder"),
        dictgen::InsensitiveStr::Ascii("larizeddest"),
        dictgen::InsensitiveStr::Ascii("larizeds"),
        dictgen::InsensitiveStr::Ascii("lymerised"),
        dictgen::InsensitiveStr::Ascii("lymerisedder"),
        dictgen::InsensitiveStr::Ascii("lymeriseddest"),
        dictgen::InsensitiveStr::Ascii("lymeriseds"),
        dictgen::InsensitiveStr::Ascii("lymerized"),
        dictgen::InsensitiveStr::Ascii("lymerizedder"),
        dictgen::InsensitiveStr::Ascii("lymerizeddest"),
        dictgen::InsensitiveStr::Ascii("lymerizeds"),
        dictgen::InsensitiveStr::Ascii("pularise"),
        dictgen::InsensitiveStr::Ascii("pularised"),
        dictgen::InsensitiveStr::Ascii("pularises"),
        dictgen::InsensitiveStr::Ascii("pularize"),
        dictgen::InsensitiveStr::Ascii("pularized"),
        dictgen::InsensitiveStr::Ascii("pularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPOETICIZED_15341478924184758286)],
        &[(0b10010, &ENTRY_UNPOETICIZEDDER_12735195907627961200)],
        &[(0b10010, &ENTRY_UNPOETICIZEDDEST_7053597514693691953)],
        &[(0b10010, &ENTRY_UNPOETICIZEDS_16917648203731599677)],
        &[(0b01001, &ENTRY_UNPOETICIZED_15341478924184758286)],
        &[(0b01001, &ENTRY_UNPOETICIZEDDER_12735195907627961200)],
        &[(0b01001, &ENTRY_UNPOETICIZEDDEST_7053597514693691953)],
        &[(0b01001, &ENTRY_UNPOETICIZEDS_16917648203731599677)],
        &[(0b10010, &ENTRY_UNPOETIZE_14681941329003224540)],
        &[(0b10010, &ENTRY_UNPOETIZED_2934206354212163480)],
        &[(0b10010, &ENTRY_UNPOETIZES_11474052031789009067)],
        &[(0b01001, &ENTRY_UNPOETIZE_14681941329003224540)],
        &[(0b01001, &ENTRY_UNPOETIZED_2934206354212163480)],
        &[(0b01001, &ENTRY_UNPOETIZES_11474052031789009067)],
        &[(0b10010, &ENTRY_UNPOLARIZABLE_2655531584986495323)],
        &[(0b10010, &ENTRY_UNPOLARIZABLES_4705929238062186499)],
        &[(0b10010, &ENTRY_UNPOLARIZED_1673168216555793217)],
        &[(0b10010, &ENTRY_UNPOLARIZEDDER_1873291145002664328)],
        &[(0b10010, &ENTRY_UNPOLARIZEDDEST_6022870955853565151)],
        &[(0b10010, &ENTRY_UNPOLARIZEDS_12480635500313856290)],
        &[(0b01001, &ENTRY_UNPOLARIZABLE_2655531584986495323)],
        &[(0b01001, &ENTRY_UNPOLARIZABLES_4705929238062186499)],
        &[(0b01001, &ENTRY_UNPOLARIZED_1673168216555793217)],
        &[(0b01001, &ENTRY_UNPOLARIZEDDER_1873291145002664328)],
        &[(0b01001, &ENTRY_UNPOLARIZEDDEST_6022870955853565151)],
        &[(0b01001, &ENTRY_UNPOLARIZEDS_12480635500313856290)],
        &[(0b10010, &ENTRY_UNPOLYMERIZED_13019897518101040085)],
        &[(0b10010, &ENTRY_UNPOLYMERIZEDDER_17288114785409523400)],
        &[(0b10010, &ENTRY_UNPOLYMERIZEDDEST_16854986311676403228)],
        &[(0b10010, &ENTRY_UNPOLYMERIZEDS_9720144018872629191)],
        &[(0b01001, &ENTRY_UNPOLYMERIZED_13019897518101040085)],
        &[(0b01001, &ENTRY_UNPOLYMERIZEDDER_17288114785409523400)],
        &[(0b01001, &ENTRY_UNPOLYMERIZEDDEST_16854986311676403228)],
        &[(0b01001, &ENTRY_UNPOLYMERIZEDS_9720144018872629191)],
        &[(0b10010, &ENTRY_UNPOPULARIZE_14649336472865355252)],
        &[(0b10010, &ENTRY_UNPOPULARIZED_76466767521665438)],
        &[(0b10010, &ENTRY_UNPOPULARIZES_1388212767604412165)],
        &[(0b01001, &ENTRY_UNPOPULARIZE_14649336472865355252)],
        &[(0b01001, &ENTRY_UNPOPULARIZED_76466767521665438)],
        &[(0b01001, &ENTRY_UNPOPULARIZES_1388212767604412165)],
    ],
    range: 5..=13,
};

static VARS_UNPL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPL_CHILDREN),
    value: None,
};

pub static VARS_UNPL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agiarised"),
        dictgen::InsensitiveStr::Ascii("agiarisedder"),
        dictgen::InsensitiveStr::Ascii("agiariseddest"),
        dictgen::InsensitiveStr::Ascii("agiariseds"),
        dictgen::InsensitiveStr::Ascii("agiarized"),
        dictgen::InsensitiveStr::Ascii("agiarizedder"),
        dictgen::InsensitiveStr::Ascii("agiarizeddest"),
        dictgen::InsensitiveStr::Ascii("agiarizeds"),
        dictgen::InsensitiveStr::Ascii("uralised"),
        dictgen::InsensitiveStr::Ascii("uralized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPLAGIARIZED_9590657773070630082)],
        &[(0b10010, &ENTRY_UNPLAGIARIZEDDER_2962770941163506588)],
        &[(0b10010, &ENTRY_UNPLAGIARIZEDDEST_3104273454326165318)],
        &[(0b10010, &ENTRY_UNPLAGIARIZEDS_17313414421594015377)],
        &[(0b01001, &ENTRY_UNPLAGIARIZED_9590657773070630082)],
        &[(0b01001, &ENTRY_UNPLAGIARIZEDDER_2962770941163506588)],
        &[(0b01001, &ENTRY_UNPLAGIARIZEDDEST_3104273454326165318)],
        &[(0b01001, &ENTRY_UNPLAGIARIZEDS_17313414421594015377)],
        &[(0b10010, &ENTRY_UNPLURALIZED_5984694540050844180)],
        &[(0b01001, &ENTRY_UNPLURALIZED_5984694540050844180)],
    ],
    range: 8..=13,
};

static VARS_UNPI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPI_CHILDREN),
    value: None,
};

pub static VARS_UNPI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctorialise"),
        dictgen::InsensitiveStr::Ascii("ctorialised"),
        dictgen::InsensitiveStr::Ascii("ctorialising"),
        dictgen::InsensitiveStr::Ascii("ctorialize"),
        dictgen::InsensitiveStr::Ascii("ctorialized"),
        dictgen::InsensitiveStr::Ascii("ctorializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPICTORIALIZE_8534139020030241947)],
        &[(0b10010, &ENTRY_UNPICTORIALIZED_4786628385029481651)],
        &[(0b10010, &ENTRY_UNPICTORIALIZING_13381639932561913300)],
        &[(0b01001, &ENTRY_UNPICTORIALIZE_8534139020030241947)],
        &[(0b01001, &ENTRY_UNPICTORIALIZED_4786628385029481651)],
        &[(0b01001, &ENTRY_UNPICTORIALIZING_13381639932561913300)],
    ],
    range: 10..=12,
};

static VARS_UNPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPH_CHILDREN),
    value: None,
};

pub static VARS_UNPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilosophise"),
        dictgen::InsensitiveStr::Ascii("ilosophised"),
        dictgen::InsensitiveStr::Ascii("ilosophises"),
        dictgen::InsensitiveStr::Ascii("ilosophize"),
        dictgen::InsensitiveStr::Ascii("ilosophized"),
        dictgen::InsensitiveStr::Ascii("ilosophizes"),
        dictgen::InsensitiveStr::Ascii("osphatised"),
        dictgen::InsensitiveStr::Ascii("osphatisedder"),
        dictgen::InsensitiveStr::Ascii("osphatiseddest"),
        dictgen::InsensitiveStr::Ascii("osphatiseds"),
        dictgen::InsensitiveStr::Ascii("osphatized"),
        dictgen::InsensitiveStr::Ascii("osphatizedder"),
        dictgen::InsensitiveStr::Ascii("osphatizeddest"),
        dictgen::InsensitiveStr::Ascii("osphatizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPHILOSOPHIZE_15409606515006527524)],
        &[(0b10010, &ENTRY_UNPHILOSOPHIZED_4478449938288203539)],
        &[(0b10010, &ENTRY_UNPHILOSOPHIZES_9638452344711758586)],
        &[(0b01001, &ENTRY_UNPHILOSOPHIZE_15409606515006527524)],
        &[(0b01001, &ENTRY_UNPHILOSOPHIZED_4478449938288203539)],
        &[(0b01001, &ENTRY_UNPHILOSOPHIZES_9638452344711758586)],
        &[(0b10010, &ENTRY_UNPHOSPHATIZED_6698185802257295415)],
        &[(0b10010, &ENTRY_UNPHOSPHATIZEDDER_8344177484520626925)],
        &[(0b10010, &ENTRY_UNPHOSPHATIZEDDEST_7712221667803666231)],
        &[(0b10010, &ENTRY_UNPHOSPHATIZEDS_14190092196126111453)],
        &[(0b01001, &ENTRY_UNPHOSPHATIZED_6698185802257295415)],
        &[(0b01001, &ENTRY_UNPHOSPHATIZEDDER_8344177484520626925)],
        &[(0b01001, &ENTRY_UNPHOSPHATIZEDDEST_7712221667803666231)],
        &[(0b01001, &ENTRY_UNPHOSPHATIZEDS_14190092196126111453)],
    ],
    range: 10..=14,
};

static VARS_UNPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPE_CHILDREN),
    value: None,
};

pub static VARS_UNPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nalised"),
        dictgen::InsensitiveStr::Ascii("nalisedder"),
        dictgen::InsensitiveStr::Ascii("naliseddest"),
        dictgen::InsensitiveStr::Ascii("nalized"),
        dictgen::InsensitiveStr::Ascii("nalizedder"),
        dictgen::InsensitiveStr::Ascii("nalizeddest"),
        dictgen::InsensitiveStr::Ascii("rceptively"),
        dictgen::InsensitiveStr::Ascii("rsonalised"),
        dictgen::InsensitiveStr::Ascii("rsonalising"),
        dictgen::InsensitiveStr::Ascii("rsonalized"),
        dictgen::InsensitiveStr::Ascii("rsonalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPENALIZED_2142967108305186126)],
        &[(0b10010, &ENTRY_UNPENALIZEDDER_8199987065212676092)],
        &[(0b10010, &ENTRY_UNPENALIZEDDEST_9469524353322915881)],
        &[(0b01001, &ENTRY_UNPENALIZED_2142967108305186126)],
        &[(0b01001, &ENTRY_UNPENALIZEDDER_8199987065212676092)],
        &[(0b01001, &ENTRY_UNPENALIZEDDEST_9469524353322915881)],
        &[(0b00001, &ENTRY_UNPERCEPTIVELY_16674495345486986764)],
        &[(0b10010, &ENTRY_UNPERSONALIZED_10430124302522011652)],
        &[(0b10010, &ENTRY_UNPERSONALIZING_15562446084747354495)],
        &[(0b01001, &ENTRY_UNPERSONALIZED_10430124302522011652)],
        &[(0b01001, &ENTRY_UNPERSONALIZING_15562446084747354495)],
    ],
    range: 7..=11,
};

static VARS_UNPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNPA_CHILDREN),
    value: None,
};

static VARS_UNPA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNPAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_UNPAL_NODE),
    None,
    Some(&VARS_UNPAN_NODE),
    None,
    None,
    None,
    Some(&VARS_UNPAR_NODE),
    Some(&VARS_UNPAS_NODE),
    Some(&VARS_UNPAT_NODE),
    Some(&VARS_UNPAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNPAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAU_CHILDREN),
    value: None,
};

pub static VARS_UNPAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("perised"),
        dictgen::InsensitiveStr::Ascii("periseds"),
        dictgen::InsensitiveStr::Ascii("perized"),
        dictgen::InsensitiveStr::Ascii("perizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPAUPERIZED_9404943598594952727)],
        &[(0b10010, &ENTRY_UNPAUPERIZEDS_13074066262081440105)],
        &[(0b01001, &ENTRY_UNPAUPERIZED_9404943598594952727)],
        &[(0b01001, &ENTRY_UNPAUPERIZEDS_13074066262081440105)],
    ],
    range: 7..=8,
};

static VARS_UNPAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAT_CHILDREN),
    value: None,
};

pub static VARS_UNPAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ronisable"),
        dictgen::InsensitiveStr::Ascii("ronisabler"),
        dictgen::InsensitiveStr::Ascii("ronisables"),
        dictgen::InsensitiveStr::Ascii("ronisablest"),
        dictgen::InsensitiveStr::Ascii("ronised"),
        dictgen::InsensitiveStr::Ascii("ronising"),
        dictgen::InsensitiveStr::Ascii("ronizable"),
        dictgen::InsensitiveStr::Ascii("ronizabler"),
        dictgen::InsensitiveStr::Ascii("ronizables"),
        dictgen::InsensitiveStr::Ascii("ronizablest"),
        dictgen::InsensitiveStr::Ascii("ronized"),
        dictgen::InsensitiveStr::Ascii("ronizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPATRONIZABLE_1362396864066933771)],
        &[(0b10010, &ENTRY_UNPATRONIZABLER_14355011026327328507)],
        &[(0b10010, &ENTRY_UNPATRONIZABLES_5259054875641739571)],
        &[(0b10010, &ENTRY_UNPATRONIZABLEST_16700885895853046350)],
        &[(0b10010, &ENTRY_UNPATRONIZED_6212197640341804006)],
        &[(0b10010, &ENTRY_UNPATRONIZING_315514134828674594)],
        &[(0b01001, &ENTRY_UNPATRONIZABLE_1362396864066933771)],
        &[(0b01001, &ENTRY_UNPATRONIZABLER_14355011026327328507)],
        &[(0b01001, &ENTRY_UNPATRONIZABLES_5259054875641739571)],
        &[(0b01001, &ENTRY_UNPATRONIZABLEST_16700885895853046350)],
        &[(0b01001, &ENTRY_UNPATRONIZED_6212197640341804006)],
        &[(0b01001, &ENTRY_UNPATRONIZING_315514134828674594)],
    ],
    range: 7..=11,
};

static VARS_UNPAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAS_CHILDREN),
    value: None,
};

pub static VARS_UNPAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("teurised"),
        dictgen::InsensitiveStr::Ascii("teurized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPASTEURIZED_6016657477118674821)],
        &[(0b01001, &ENTRY_UNPASTEURIZED_6016657477118674821)],
    ],
    range: 8..=8,
};

static VARS_UNPAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAR_CHILDREN),
    value: None,
};

pub static VARS_UNPAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agonised"),
        dictgen::InsensitiveStr::Ascii("agoniseds"),
        dictgen::InsensitiveStr::Ascii("agonized"),
        dictgen::InsensitiveStr::Ascii("agonizeds"),
        dictgen::InsensitiveStr::Ascii("alysed"),
        dictgen::InsensitiveStr::Ascii("alysedder"),
        dictgen::InsensitiveStr::Ascii("alyseddest"),
        dictgen::InsensitiveStr::Ascii("alyseds"),
        dictgen::InsensitiveStr::Ascii("alyzed"),
        dictgen::InsensitiveStr::Ascii("alyzedder"),
        dictgen::InsensitiveStr::Ascii("alyzeddest"),
        dictgen::InsensitiveStr::Ascii("alyzeds"),
        dictgen::InsensitiveStr::Ascii("ameterised"),
        dictgen::InsensitiveStr::Ascii("ameterized"),
        dictgen::InsensitiveStr::Ascii("ametrised"),
        dictgen::InsensitiveStr::Ascii("ametrized"),
        dictgen::InsensitiveStr::Ascii("celed"),
        dictgen::InsensitiveStr::Ascii("celedder"),
        dictgen::InsensitiveStr::Ascii("celeddest"),
        dictgen::InsensitiveStr::Ascii("celled"),
        dictgen::InsensitiveStr::Ascii("celledder"),
        dictgen::InsensitiveStr::Ascii("celleddest"),
        dictgen::InsensitiveStr::Ascii("enthesised"),
        dictgen::InsensitiveStr::Ascii("enthesized"),
        dictgen::InsensitiveStr::Ascii("ticularised"),
        dictgen::InsensitiveStr::Ascii("ticularisedder"),
        dictgen::InsensitiveStr::Ascii("ticulariseddest"),
        dictgen::InsensitiveStr::Ascii("ticulariseds"),
        dictgen::InsensitiveStr::Ascii("ticularising"),
        dictgen::InsensitiveStr::Ascii("ticularisinger"),
        dictgen::InsensitiveStr::Ascii("ticularisingest"),
        dictgen::InsensitiveStr::Ascii("ticularisings"),
        dictgen::InsensitiveStr::Ascii("ticularized"),
        dictgen::InsensitiveStr::Ascii("ticularizedder"),
        dictgen::InsensitiveStr::Ascii("ticularizeddest"),
        dictgen::InsensitiveStr::Ascii("ticularizeds"),
        dictgen::InsensitiveStr::Ascii("ticularizing"),
        dictgen::InsensitiveStr::Ascii("ticularizinger"),
        dictgen::InsensitiveStr::Ascii("ticularizingest"),
        dictgen::InsensitiveStr::Ascii("ticularizings"),
        dictgen::InsensitiveStr::Ascii("tisan"),
        dictgen::InsensitiveStr::Ascii("tizan"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPARAGONIZED_11641249067400700762)],
        &[(0b10010, &ENTRY_UNPARAGONIZEDS_8828912894163008040)],
        &[(0b01001, &ENTRY_UNPARAGONIZED_11641249067400700762)],
        &[(0b01001, &ENTRY_UNPARAGONIZEDS_8828912894163008040)],
        &[(0b11010, &ENTRY_UNPARALYZED_14384393398387787974)],
        &[(0b11010, &ENTRY_UNPARALYZEDDER_10074788125617493696)],
        &[(0b11010, &ENTRY_UNPARALYZEDDEST_8559985515751356281)],
        &[(0b11010, &ENTRY_UNPARALYZEDS_17113201865707449563)],
        &[(0b00001, &ENTRY_UNPARALYZED_14384393398387787974)],
        &[(0b00001, &ENTRY_UNPARALYZEDDER_10074788125617493696)],
        &[(0b00001, &ENTRY_UNPARALYZEDDEST_8559985515751356281)],
        &[(0b00001, &ENTRY_UNPARALYZEDS_17113201865707449563)],
        &[(0b10010, &ENTRY_UNPARAMETERIZED_10261143125001624802)],
        &[(0b01001, &ENTRY_UNPARAMETERIZED_10261143125001624802)],
        &[(0b10010, &ENTRY_UNPARAMETRIZED_37046481284940289)],
        &[(0b01001, &ENTRY_UNPARAMETRIZED_37046481284940289)],
        &[(0b00001, &ENTRY_UNPARCELED_1373494415685202599)],
        &[(0b00001, &ENTRY_UNPARCELEDDER_3319549837550214831)],
        &[(0b00001, &ENTRY_UNPARCELEDDEST_4383492122712518630)],
        &[(0b11010, &ENTRY_UNPARCELED_1373494415685202599)],
        &[(0b11010, &ENTRY_UNPARCELEDDER_3319549837550214831)],
        &[(0b11010, &ENTRY_UNPARCELEDDEST_4383492122712518630)],
        &[(0b10010, &ENTRY_UNPARENTHESIZED_18235036996914091846)],
        &[(0b01001, &ENTRY_UNPARENTHESIZED_18235036996914091846)],
        &[(0b10010, &ENTRY_UNPARTICULARIZED_10369241482954824333)],
        &[(0b10010, &ENTRY_UNPARTICULARIZEDDER_14810130530234822946)],
        &[(0b10010, &ENTRY_UNPARTICULARIZEDDEST_12461674155327065922)],
        &[(0b10010, &ENTRY_UNPARTICULARIZEDS_7009295388737864374)],
        &[(0b10010, &ENTRY_UNPARTICULARIZING_17075351876595992224)],
        &[(0b10010, &ENTRY_UNPARTICULARIZINGER_1405745460438104009)],
        &[(0b10010, &ENTRY_UNPARTICULARIZINGEST_12469995634183150832)],
        &[(0b10010, &ENTRY_UNPARTICULARIZINGS_12061998009550281971)],
        &[(0b01001, &ENTRY_UNPARTICULARIZED_10369241482954824333)],
        &[(0b01001, &ENTRY_UNPARTICULARIZEDDER_14810130530234822946)],
        &[(0b01001, &ENTRY_UNPARTICULARIZEDDEST_12461674155327065922)],
        &[(0b01001, &ENTRY_UNPARTICULARIZEDS_7009295388737864374)],
        &[(0b01001, &ENTRY_UNPARTICULARIZING_17075351876595992224)],
        &[(0b01001, &ENTRY_UNPARTICULARIZINGER_1405745460438104009)],
        &[(0b01001, &ENTRY_UNPARTICULARIZINGEST_12469995634183150832)],
        &[(0b01001, &ENTRY_UNPARTICULARIZINGS_12061998009550281971)],
        &[(0b10010, &ENTRY_UNPARTIZAN_4088887390151350638)],
        &[(0b01001, &ENTRY_UNPARTIZAN_4088887390151350638)],
    ],
    range: 5..=15,
};

static VARS_UNPAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAN_CHILDREN),
    value: None,
};

pub static VARS_UNPAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("egyrised"),
        dictgen::InsensitiveStr::Ascii("egyrized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPANEGYRIZED_12330222380120284751)],
        &[(0b01001, &ENTRY_UNPANEGYRIZED_12330222380120284751)],
    ],
    range: 8..=8,
};

static VARS_UNPAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAL_CHILDREN),
    value: None,
};

pub static VARS_UNPAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isaded"),
        dictgen::InsensitiveStr::Ascii("isadoed"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNPALISADED_1035644440444378203)],
        &[(0b11010, &ENTRY_UNPALISADED_1035644440444378203)],
    ],
    range: 6..=7,
};

static VARS_UNPAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNPAG_CHILDREN),
    value: None,
};

pub static VARS_UNPAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNPAGANIZE_10797468704092625272)],
        &[(0b10010, &ENTRY_UNPAGANIZES_1814932462765931021)],
        &[(0b01001, &ENTRY_UNPAGANIZE_10797468704092625272)],
        &[(0b01001, &ENTRY_UNPAGANIZES_1814932462765931021)],
    ],
    range: 5..=6,
};

static VARS_UNO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNO_CHILDREN),
    value: None,
};

pub static VARS_UNO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ptimise"),
        dictgen::InsensitiveStr::Ascii("ptimised"),
        dictgen::InsensitiveStr::Ascii("ptimises"),
        dictgen::InsensitiveStr::Ascii("ptimising"),
        dictgen::InsensitiveStr::Ascii("ptimize"),
        dictgen::InsensitiveStr::Ascii("ptimized"),
        dictgen::InsensitiveStr::Ascii("ptimizes"),
        dictgen::InsensitiveStr::Ascii("ptimizing"),
        dictgen::InsensitiveStr::Ascii("rganisable"),
        dictgen::InsensitiveStr::Ascii("rganisabler"),
        dictgen::InsensitiveStr::Ascii("rganisables"),
        dictgen::InsensitiveStr::Ascii("rganisablest"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganisedly"),
        dictgen::InsensitiveStr::Ascii("rganisedness"),
        dictgen::InsensitiveStr::Ascii("rganizable"),
        dictgen::InsensitiveStr::Ascii("rganizabler"),
        dictgen::InsensitiveStr::Ascii("rganizables"),
        dictgen::InsensitiveStr::Ascii("rganizablest"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganized"),
        dictgen::InsensitiveStr::Ascii("rganizedly"),
        dictgen::InsensitiveStr::Ascii("rganizedness"),
        dictgen::InsensitiveStr::Ascii("xidisable"),
        dictgen::InsensitiveStr::Ascii("xidisabler"),
        dictgen::InsensitiveStr::Ascii("xidisables"),
        dictgen::InsensitiveStr::Ascii("xidisablest"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidisedder"),
        dictgen::InsensitiveStr::Ascii("xidiseddest"),
        dictgen::InsensitiveStr::Ascii("xidizable"),
        dictgen::InsensitiveStr::Ascii("xidizabler"),
        dictgen::InsensitiveStr::Ascii("xidizables"),
        dictgen::InsensitiveStr::Ascii("xidizablest"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizedder"),
        dictgen::InsensitiveStr::Ascii("xidizeddest"),
        dictgen::InsensitiveStr::Ascii("xygenised"),
        dictgen::InsensitiveStr::Ascii("xygeniseds"),
        dictgen::InsensitiveStr::Ascii("xygenized"),
        dictgen::InsensitiveStr::Ascii("xygenizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNOPTIMIZE_8337218810202803852)],
        &[(0b10010, &ENTRY_UNOPTIMIZED_16059827780503939479)],
        &[(0b10010, &ENTRY_UNOPTIMIZES_5417054465029431224)],
        &[(0b10010, &ENTRY_UNOPTIMIZING_3167927648308310550)],
        &[(0b01001, &ENTRY_UNOPTIMIZE_8337218810202803852)],
        &[(0b01001, &ENTRY_UNOPTIMIZED_16059827780503939479)],
        &[(0b01001, &ENTRY_UNOPTIMIZES_5417054465029431224)],
        &[(0b01001, &ENTRY_UNOPTIMIZING_3167927648308310550)],
        &[(0b10010, &ENTRY_UNORGANIZABLE_11245437451639231261)],
        &[(0b10010, &ENTRY_UNORGANIZABLER_2651332250209161850)],
        &[(0b10010, &ENTRY_UNORGANIZABLES_14263543529684744487)],
        &[(0b10010, &ENTRY_UNORGANIZABLEST_13952098891985641540)],
        &[(0b10010, &ENTRY_UNORGANIZE_16055712748344908044)],
        &[(0b10010, &ENTRY_UNORGANIZED_8287041392290100911)],
        &[(0b10010, &ENTRY_UNORGANIZEDLY_17706812563099018840)],
        &[(0b10010, &ENTRY_UNORGANIZEDNESS_5163887181546451097)],
        &[(0b01001, &ENTRY_UNORGANIZABLE_11245437451639231261)],
        &[(0b01001, &ENTRY_UNORGANIZABLER_2651332250209161850)],
        &[(0b01001, &ENTRY_UNORGANIZABLES_14263543529684744487)],
        &[(0b01001, &ENTRY_UNORGANIZABLEST_13952098891985641540)],
        &[(0b01001, &ENTRY_UNORGANIZE_16055712748344908044)],
        &[(0b01001, &ENTRY_UNORGANIZED_8287041392290100911)],
        &[(0b01001, &ENTRY_UNORGANIZEDLY_17706812563099018840)],
        &[(0b01001, &ENTRY_UNORGANIZEDNESS_5163887181546451097)],
        &[(0b10010, &ENTRY_UNOXIDIZABLE_16109933882822047402)],
        &[(0b10010, &ENTRY_UNOXIDIZABLER_5359355858057190803)],
        &[(0b10010, &ENTRY_UNOXIDIZABLES_17595850679261895025)],
        &[(0b10010, &ENTRY_UNOXIDIZABLEST_6591525985530653060)],
        &[(0b10010, &ENTRY_UNOXIDIZED_9470542236784645015)],
        &[(0b10010, &ENTRY_UNOXIDIZEDDER_6144115144136830447)],
        &[(0b10010, &ENTRY_UNOXIDIZEDDEST_14507693636430734653)],
        &[(0b01001, &ENTRY_UNOXIDIZABLE_16109933882822047402)],
        &[(0b01001, &ENTRY_UNOXIDIZABLER_5359355858057190803)],
        &[(0b01001, &ENTRY_UNOXIDIZABLES_17595850679261895025)],
        &[(0b01001, &ENTRY_UNOXIDIZABLEST_6591525985530653060)],
        &[(0b01001, &ENTRY_UNOXIDIZED_9470542236784645015)],
        &[(0b01001, &ENTRY_UNOXIDIZEDDER_6144115144136830447)],
        &[(0b01001, &ENTRY_UNOXIDIZEDDEST_14507693636430734653)],
        &[(0b10010, &ENTRY_UNOXYGENIZED_6875578357957209997)],
        &[(0b10010, &ENTRY_UNOXYGENIZEDS_14660262551929716023)],
        &[(0b01001, &ENTRY_UNOXYGENIZED_6875578357957209997)],
        &[(0b01001, &ENTRY_UNOXYGENIZEDS_14660262551929716023)],
    ],
    range: 7..=12,
};

static VARS_UNN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNN_CHILDREN),
    value: None,
};

static VARS_UNN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNNA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNNE_NODE),
    None,
    None,
    None,
    Some(&VARS_UNNI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNNO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNNO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNNO_CHILDREN),
    value: None,
};

pub static VARS_UNNO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncolorables"),
        dictgen::InsensitiveStr::Ascii("ncolorablies"),
        dictgen::InsensitiveStr::Ascii("ncolorably"),
        dictgen::InsensitiveStr::Ascii("ncolourables"),
        dictgen::InsensitiveStr::Ascii("ncolourablies"),
        dictgen::InsensitiveStr::Ascii("ncolourably"),
        dictgen::InsensitiveStr::Ascii("rmalise"),
        dictgen::InsensitiveStr::Ascii("rmalised"),
        dictgen::InsensitiveStr::Ascii("rmalisedder"),
        dictgen::InsensitiveStr::Ascii("rmaliseddest"),
        dictgen::InsensitiveStr::Ascii("rmalises"),
        dictgen::InsensitiveStr::Ascii("rmalising"),
        dictgen::InsensitiveStr::Ascii("rmalisinger"),
        dictgen::InsensitiveStr::Ascii("rmalisingest"),
        dictgen::InsensitiveStr::Ascii("rmalize"),
        dictgen::InsensitiveStr::Ascii("rmalized"),
        dictgen::InsensitiveStr::Ascii("rmalizedder"),
        dictgen::InsensitiveStr::Ascii("rmalizeddest"),
        dictgen::InsensitiveStr::Ascii("rmalizes"),
        dictgen::InsensitiveStr::Ascii("rmalizing"),
        dictgen::InsensitiveStr::Ascii("rmalizinger"),
        dictgen::InsensitiveStr::Ascii("rmalizingest"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNNONCOLORABLES_11603706591378503372)],
        &[(0b00001, &ENTRY_UNNONCOLORABLIES_9150435717670160252)],
        &[(0b00001, &ENTRY_UNNONCOLORABLY_5346203888294556991)],
        &[(0b11010, &ENTRY_UNNONCOLORABLES_11603706591378503372)],
        &[(0b11010, &ENTRY_UNNONCOLORABLIES_9150435717670160252)],
        &[(0b11010, &ENTRY_UNNONCOLORABLY_5346203888294556991)],
        &[(0b10010, &ENTRY_UNNORMALIZE_14634692936439819346)],
        &[(0b10010, &ENTRY_UNNORMALIZED_17182616854570086003)],
        &[(0b10010, &ENTRY_UNNORMALIZEDDER_6088928097619406702)],
        &[(0b10010, &ENTRY_UNNORMALIZEDDEST_11709516950586687994)],
        &[(0b10010, &ENTRY_UNNORMALIZES_10633086048818529153)],
        &[(0b10010, &ENTRY_UNNORMALIZING_1754876569648213763)],
        &[(0b10010, &ENTRY_UNNORMALIZINGER_15099376100231731467)],
        &[(0b10010, &ENTRY_UNNORMALIZINGEST_247021487053357560)],
        &[(0b01001, &ENTRY_UNNORMALIZE_14634692936439819346)],
        &[(0b01001, &ENTRY_UNNORMALIZED_17182616854570086003)],
        &[(0b01001, &ENTRY_UNNORMALIZEDDER_6088928097619406702)],
        &[(0b01001, &ENTRY_UNNORMALIZEDDEST_11709516950586687994)],
        &[(0b01001, &ENTRY_UNNORMALIZES_10633086048818529153)],
        &[(0b01001, &ENTRY_UNNORMALIZING_1754876569648213763)],
        &[(0b01001, &ENTRY_UNNORMALIZINGER_15099376100231731467)],
        &[(0b01001, &ENTRY_UNNORMALIZINGEST_247021487053357560)],
    ],
    range: 7..=13,
};

static VARS_UNNI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNNI_CHILDREN),
    value: None,
};

pub static VARS_UNNI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("trogenised"),
        dictgen::InsensitiveStr::Ascii("trogenisedder"),
        dictgen::InsensitiveStr::Ascii("trogeniseddest"),
        dictgen::InsensitiveStr::Ascii("trogeniseds"),
        dictgen::InsensitiveStr::Ascii("trogenized"),
        dictgen::InsensitiveStr::Ascii("trogenizedder"),
        dictgen::InsensitiveStr::Ascii("trogenizeddest"),
        dictgen::InsensitiveStr::Ascii("trogenizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNNITROGENIZED_9970825803449823138)],
        &[(0b10010, &ENTRY_UNNITROGENIZEDDER_15494417655163954478)],
        &[(0b10010, &ENTRY_UNNITROGENIZEDDEST_14262521068869718443)],
        &[(0b10010, &ENTRY_UNNITROGENIZEDS_16716966430076186540)],
        &[(0b01001, &ENTRY_UNNITROGENIZED_9970825803449823138)],
        &[(0b01001, &ENTRY_UNNITROGENIZEDDER_15494417655163954478)],
        &[(0b01001, &ENTRY_UNNITROGENIZEDDEST_14262521068869718443)],
        &[(0b01001, &ENTRY_UNNITROGENIZEDS_16716966430076186540)],
    ],
    range: 10..=14,
};

static VARS_UNNE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNNE_CHILDREN),
    value: None,
};

pub static VARS_UNNE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ighbored"),
        dictgen::InsensitiveStr::Ascii("ighborlier"),
        dictgen::InsensitiveStr::Ascii("ighborliest"),
        dictgen::InsensitiveStr::Ascii("ighborlike"),
        dictgen::InsensitiveStr::Ascii("ighborlikes"),
        dictgen::InsensitiveStr::Ascii("ighborliness"),
        dictgen::InsensitiveStr::Ascii("ighborlinesses"),
        dictgen::InsensitiveStr::Ascii("ighborly"),
        dictgen::InsensitiveStr::Ascii("ighboured"),
        dictgen::InsensitiveStr::Ascii("ighbourlier"),
        dictgen::InsensitiveStr::Ascii("ighbourliest"),
        dictgen::InsensitiveStr::Ascii("ighbourlike"),
        dictgen::InsensitiveStr::Ascii("ighbourlikes"),
        dictgen::InsensitiveStr::Ascii("ighbourliness"),
        dictgen::InsensitiveStr::Ascii("ighbourlinesses"),
        dictgen::InsensitiveStr::Ascii("ighbourly"),
        dictgen::InsensitiveStr::Ascii("utralise"),
        dictgen::InsensitiveStr::Ascii("utralised"),
        dictgen::InsensitiveStr::Ascii("utralising"),
        dictgen::InsensitiveStr::Ascii("utralize"),
        dictgen::InsensitiveStr::Ascii("utralized"),
        dictgen::InsensitiveStr::Ascii("utralizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNNEIGHBORED_17137517992514420389)],
        &[(0b00001, &ENTRY_UNNEIGHBORLIER_16702491867279586093)],
        &[(0b00001, &ENTRY_UNNEIGHBORLIEST_12419433861097517248)],
        &[(0b00001, &ENTRY_UNNEIGHBORLIKE_10218446635184503929)],
        &[(0b00001, &ENTRY_UNNEIGHBORLIKES_4354261620124645883)],
        &[(0b00001, &ENTRY_UNNEIGHBORLINESS_1038976996631322927)],
        &[(0b00001, &ENTRY_UNNEIGHBORLINESSES_10829695068225729738)],
        &[(0b00001, &ENTRY_UNNEIGHBORLY_14423135391726748415)],
        &[(0b11010, &ENTRY_UNNEIGHBORED_17137517992514420389)],
        &[(0b11010, &ENTRY_UNNEIGHBORLIER_16702491867279586093)],
        &[(0b11010, &ENTRY_UNNEIGHBORLIEST_12419433861097517248)],
        &[(0b11010, &ENTRY_UNNEIGHBORLIKE_10218446635184503929)],
        &[(0b11010, &ENTRY_UNNEIGHBORLIKES_4354261620124645883)],
        &[(0b11010, &ENTRY_UNNEIGHBORLINESS_1038976996631322927)],
        &[(0b11010, &ENTRY_UNNEIGHBORLINESSES_10829695068225729738)],
        &[(0b11010, &ENTRY_UNNEIGHBORLY_14423135391726748415)],
        &[(0b10010, &ENTRY_UNNEUTRALIZE_4698429815634199128)],
        &[(0b10010, &ENTRY_UNNEUTRALIZED_10386359248112453405)],
        &[(0b10010, &ENTRY_UNNEUTRALIZING_4249099403406146838)],
        &[(0b01001, &ENTRY_UNNEUTRALIZE_4698429815634199128)],
        &[(0b01001, &ENTRY_UNNEUTRALIZED_10386359248112453405)],
        &[(0b01001, &ENTRY_UNNEUTRALIZING_4249099403406146838)],
    ],
    range: 8..=15,
};

static VARS_UNNA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNNA_CHILDREN),
    value: None,
};

pub static VARS_UNNA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalisedder"),
        dictgen::InsensitiveStr::Ascii("tionaliseddest"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizedder"),
        dictgen::InsensitiveStr::Ascii("tionalizeddest"),
        dictgen::InsensitiveStr::Ascii("turalisable"),
        dictgen::InsensitiveStr::Ascii("turalisables"),
        dictgen::InsensitiveStr::Ascii("turalise"),
        dictgen::InsensitiveStr::Ascii("turalised"),
        dictgen::InsensitiveStr::Ascii("turalises"),
        dictgen::InsensitiveStr::Ascii("turalising"),
        dictgen::InsensitiveStr::Ascii("turalizable"),
        dictgen::InsensitiveStr::Ascii("turalizables"),
        dictgen::InsensitiveStr::Ascii("turalize"),
        dictgen::InsensitiveStr::Ascii("turalized"),
        dictgen::InsensitiveStr::Ascii("turalizes"),
        dictgen::InsensitiveStr::Ascii("turalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNNATIONALIZED_17413125925681224817)],
        &[(0b10010, &ENTRY_UNNATIONALIZEDDER_16819534566496048883)],
        &[(0b10010, &ENTRY_UNNATIONALIZEDDEST_6627375631914479221)],
        &[(0b01001, &ENTRY_UNNATIONALIZED_17413125925681224817)],
        &[(0b01001, &ENTRY_UNNATIONALIZEDDER_16819534566496048883)],
        &[(0b01001, &ENTRY_UNNATIONALIZEDDEST_6627375631914479221)],
        &[(0b10010, &ENTRY_UNNATURALIZABLE_11245054765720939783)],
        &[(0b10010, &ENTRY_UNNATURALIZABLES_15331368327954336002)],
        &[(0b10010, &ENTRY_UNNATURALIZE_8515448021724973747)],
        &[(0b10010, &ENTRY_UNNATURALIZED_12904128484572003805)],
        &[(0b10010, &ENTRY_UNNATURALIZES_15417405462560090882)],
        &[(0b10010, &ENTRY_UNNATURALIZING_8059644534756052716)],
        &[(0b01001, &ENTRY_UNNATURALIZABLE_11245054765720939783)],
        &[(0b01001, &ENTRY_UNNATURALIZABLES_15331368327954336002)],
        &[(0b01001, &ENTRY_UNNATURALIZE_8515448021724973747)],
        &[(0b01001, &ENTRY_UNNATURALIZED_12904128484572003805)],
        &[(0b01001, &ENTRY_UNNATURALIZES_15417405462560090882)],
        &[(0b01001, &ENTRY_UNNATURALIZING_8059644534756052716)],
    ],
    range: 8..=14,
};

static VARS_UNM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNM_CHILDREN),
    value: None,
};

static VARS_UNM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNMA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNME_NODE),
    None,
    None,
    None,
    Some(&VARS_UNMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNMO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNMU_NODE),
    None,
    None,
    None,
    Some(&VARS_UNMY_NODE),
    None,
];

static VARS_UNMY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMY_CHILDREN),
    value: None,
};

pub static VARS_UNMY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sticise"),
        dictgen::InsensitiveStr::Ascii("sticised"),
        dictgen::InsensitiveStr::Ascii("sticises"),
        dictgen::InsensitiveStr::Ascii("sticising"),
        dictgen::InsensitiveStr::Ascii("sticize"),
        dictgen::InsensitiveStr::Ascii("sticized"),
        dictgen::InsensitiveStr::Ascii("sticizes"),
        dictgen::InsensitiveStr::Ascii("sticizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMYSTICIZE_6752614279344741289)],
        &[(0b10010, &ENTRY_UNMYSTICIZED_3871960656463594608)],
        &[(0b10010, &ENTRY_UNMYSTICIZES_593169946783893980)],
        &[(0b10010, &ENTRY_UNMYSTICIZING_7832774330196959394)],
        &[(0b01001, &ENTRY_UNMYSTICIZE_6752614279344741289)],
        &[(0b01001, &ENTRY_UNMYSTICIZED_3871960656463594608)],
        &[(0b01001, &ENTRY_UNMYSTICIZES_593169946783893980)],
        &[(0b01001, &ENTRY_UNMYSTICIZING_7832774330196959394)],
    ],
    range: 7..=9,
};

static VARS_UNMU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMU_CHILDREN),
    value: None,
};

pub static VARS_UNMU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nicipalised"),
        dictgen::InsensitiveStr::Ascii("nicipalisedder"),
        dictgen::InsensitiveStr::Ascii("nicipaliseddest"),
        dictgen::InsensitiveStr::Ascii("nicipaliseds"),
        dictgen::InsensitiveStr::Ascii("nicipalized"),
        dictgen::InsensitiveStr::Ascii("nicipalizedder"),
        dictgen::InsensitiveStr::Ascii("nicipalizeddest"),
        dictgen::InsensitiveStr::Ascii("nicipalizeds"),
        dictgen::InsensitiveStr::Ascii("tualised"),
        dictgen::InsensitiveStr::Ascii("tualisedder"),
        dictgen::InsensitiveStr::Ascii("tualiseddest"),
        dictgen::InsensitiveStr::Ascii("tualiseds"),
        dictgen::InsensitiveStr::Ascii("tualized"),
        dictgen::InsensitiveStr::Ascii("tualizedder"),
        dictgen::InsensitiveStr::Ascii("tualizeddest"),
        dictgen::InsensitiveStr::Ascii("tualizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMUNICIPALIZED_11558570840724190274)],
        &[(0b10010, &ENTRY_UNMUNICIPALIZEDDER_308188906530115010)],
        &[(0b10010, &ENTRY_UNMUNICIPALIZEDDEST_17406856610278064067)],
        &[(0b10010, &ENTRY_UNMUNICIPALIZEDS_10306483843849279865)],
        &[(0b01001, &ENTRY_UNMUNICIPALIZED_11558570840724190274)],
        &[(0b01001, &ENTRY_UNMUNICIPALIZEDDER_308188906530115010)],
        &[(0b01001, &ENTRY_UNMUNICIPALIZEDDEST_17406856610278064067)],
        &[(0b01001, &ENTRY_UNMUNICIPALIZEDS_10306483843849279865)],
        &[(0b10010, &ENTRY_UNMUTUALIZED_3987921361376909408)],
        &[(0b10010, &ENTRY_UNMUTUALIZEDDER_15475671606898414830)],
        &[(0b10010, &ENTRY_UNMUTUALIZEDDEST_9840735398085807516)],
        &[(0b10010, &ENTRY_UNMUTUALIZEDS_11478246322803926821)],
        &[(0b01001, &ENTRY_UNMUTUALIZED_3987921361376909408)],
        &[(0b01001, &ENTRY_UNMUTUALIZEDDER_15475671606898414830)],
        &[(0b01001, &ENTRY_UNMUTUALIZEDDEST_9840735398085807516)],
        &[(0b01001, &ENTRY_UNMUTUALIZEDS_11478246322803926821)],
    ],
    range: 8..=15,
};

static VARS_UNMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMO_CHILDREN),
    value: None,
};

pub static VARS_UNMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilised"),
        dictgen::InsensitiveStr::Ascii("bilisedder"),
        dictgen::InsensitiveStr::Ascii("biliseddest"),
        dictgen::InsensitiveStr::Ascii("biliseds"),
        dictgen::InsensitiveStr::Ascii("bilized"),
        dictgen::InsensitiveStr::Ascii("bilizedder"),
        dictgen::InsensitiveStr::Ascii("bilizeddest"),
        dictgen::InsensitiveStr::Ascii("bilizeds"),
        dictgen::InsensitiveStr::Ascii("dernise"),
        dictgen::InsensitiveStr::Ascii("dernised"),
        dictgen::InsensitiveStr::Ascii("dernisedder"),
        dictgen::InsensitiveStr::Ascii("derniseddest"),
        dictgen::InsensitiveStr::Ascii("dernises"),
        dictgen::InsensitiveStr::Ascii("dernize"),
        dictgen::InsensitiveStr::Ascii("dernized"),
        dictgen::InsensitiveStr::Ascii("dernizedder"),
        dictgen::InsensitiveStr::Ascii("dernizeddest"),
        dictgen::InsensitiveStr::Ascii("dernizes"),
        dictgen::InsensitiveStr::Ascii("nopolise"),
        dictgen::InsensitiveStr::Ascii("nopolised"),
        dictgen::InsensitiveStr::Ascii("nopolisedder"),
        dictgen::InsensitiveStr::Ascii("nopoliseddest"),
        dictgen::InsensitiveStr::Ascii("nopolises"),
        dictgen::InsensitiveStr::Ascii("nopolising"),
        dictgen::InsensitiveStr::Ascii("nopolisinger"),
        dictgen::InsensitiveStr::Ascii("nopolisingest"),
        dictgen::InsensitiveStr::Ascii("nopolisings"),
        dictgen::InsensitiveStr::Ascii("nopolize"),
        dictgen::InsensitiveStr::Ascii("nopolized"),
        dictgen::InsensitiveStr::Ascii("nopolizedder"),
        dictgen::InsensitiveStr::Ascii("nopolizeddest"),
        dictgen::InsensitiveStr::Ascii("nopolizes"),
        dictgen::InsensitiveStr::Ascii("nopolizing"),
        dictgen::InsensitiveStr::Ascii("nopolizinger"),
        dictgen::InsensitiveStr::Ascii("nopolizingest"),
        dictgen::InsensitiveStr::Ascii("nopolizings"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralisinger"),
        dictgen::InsensitiveStr::Ascii("ralisingest"),
        dictgen::InsensitiveStr::Ascii("ralisings"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
        dictgen::InsensitiveStr::Ascii("ralizinger"),
        dictgen::InsensitiveStr::Ascii("ralizingest"),
        dictgen::InsensitiveStr::Ascii("ralizings"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("torisedder"),
        dictgen::InsensitiveStr::Ascii("toriseddest"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizedder"),
        dictgen::InsensitiveStr::Ascii("torizeddest"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMOBILIZED_8792915223828792882)],
        &[(0b10010, &ENTRY_UNMOBILIZEDDER_13885990523982700388)],
        &[(0b10010, &ENTRY_UNMOBILIZEDDEST_16430132456615956501)],
        &[(0b10010, &ENTRY_UNMOBILIZEDS_2823498892381128223)],
        &[(0b01001, &ENTRY_UNMOBILIZED_8792915223828792882)],
        &[(0b01001, &ENTRY_UNMOBILIZEDDER_13885990523982700388)],
        &[(0b01001, &ENTRY_UNMOBILIZEDDEST_16430132456615956501)],
        &[(0b01001, &ENTRY_UNMOBILIZEDS_2823498892381128223)],
        &[(0b10010, &ENTRY_UNMODERNIZE_12047442119533678951)],
        &[(0b10010, &ENTRY_UNMODERNIZED_12442385813229323597)],
        &[(0b10010, &ENTRY_UNMODERNIZEDDER_17177773102034890156)],
        &[(0b10010, &ENTRY_UNMODERNIZEDDEST_6107579015702829368)],
        &[(0b10010, &ENTRY_UNMODERNIZES_16814040681635851958)],
        &[(0b01001, &ENTRY_UNMODERNIZE_12047442119533678951)],
        &[(0b01001, &ENTRY_UNMODERNIZED_12442385813229323597)],
        &[(0b01001, &ENTRY_UNMODERNIZEDDER_17177773102034890156)],
        &[(0b01001, &ENTRY_UNMODERNIZEDDEST_6107579015702829368)],
        &[(0b01001, &ENTRY_UNMODERNIZES_16814040681635851958)],
        &[(0b10010, &ENTRY_UNMONOPOLIZE_8209609104862396740)],
        &[(0b10010, &ENTRY_UNMONOPOLIZED_15103252142985776491)],
        &[(0b10010, &ENTRY_UNMONOPOLIZEDDER_367444066669166581)],
        &[(0b10010, &ENTRY_UNMONOPOLIZEDDEST_11036465831290540300)],
        &[(0b10010, &ENTRY_UNMONOPOLIZES_8604670551607021504)],
        &[(0b10010, &ENTRY_UNMONOPOLIZING_780658382091540167)],
        &[(0b10010, &ENTRY_UNMONOPOLIZINGER_8082734413560432137)],
        &[(0b10010, &ENTRY_UNMONOPOLIZINGEST_16940303846507911638)],
        &[(0b10010, &ENTRY_UNMONOPOLIZINGS_2368394829208842158)],
        &[(0b01001, &ENTRY_UNMONOPOLIZE_8209609104862396740)],
        &[(0b01001, &ENTRY_UNMONOPOLIZED_15103252142985776491)],
        &[(0b01001, &ENTRY_UNMONOPOLIZEDDER_367444066669166581)],
        &[(0b01001, &ENTRY_UNMONOPOLIZEDDEST_11036465831290540300)],
        &[(0b01001, &ENTRY_UNMONOPOLIZES_8604670551607021504)],
        &[(0b01001, &ENTRY_UNMONOPOLIZING_780658382091540167)],
        &[(0b01001, &ENTRY_UNMONOPOLIZINGER_8082734413560432137)],
        &[(0b01001, &ENTRY_UNMONOPOLIZINGEST_16940303846507911638)],
        &[(0b01001, &ENTRY_UNMONOPOLIZINGS_2368394829208842158)],
        &[(0b10010, &ENTRY_UNMORALIZE_5811178603962947867)],
        &[(0b10010, &ENTRY_UNMORALIZED_1809019658766145871)],
        &[(0b10010, &ENTRY_UNMORALIZES_2054617732298010888)],
        &[(0b10010, &ENTRY_UNMORALIZING_1635343207643393146)],
        &[(0b10010, &ENTRY_UNMORALIZINGER_2630621700200103097)],
        &[(0b10010, &ENTRY_UNMORALIZINGEST_10371338958162242360)],
        &[(0b10010, &ENTRY_UNMORALIZINGS_13530220804505456674)],
        &[(0b01001, &ENTRY_UNMORALIZE_5811178603962947867)],
        &[(0b01001, &ENTRY_UNMORALIZED_1809019658766145871)],
        &[(0b01001, &ENTRY_UNMORALIZES_2054617732298010888)],
        &[(0b01001, &ENTRY_UNMORALIZING_1635343207643393146)],
        &[(0b01001, &ENTRY_UNMORALIZINGER_2630621700200103097)],
        &[(0b01001, &ENTRY_UNMORALIZINGEST_10371338958162242360)],
        &[(0b01001, &ENTRY_UNMORALIZINGS_13530220804505456674)],
        &[(0b10010, &ENTRY_UNMOTORIZED_6782143677493579372)],
        &[(0b10010, &ENTRY_UNMOTORIZEDDER_4737848326164812310)],
        &[(0b10010, &ENTRY_UNMOTORIZEDDEST_15245325937655928512)],
        &[(0b01001, &ENTRY_UNMOTORIZED_6782143677493579372)],
        &[(0b01001, &ENTRY_UNMOTORIZEDDER_4737848326164812310)],
        &[(0b01001, &ENTRY_UNMOTORIZEDDEST_15245325937655928512)],
    ],
    range: 6..=13,
};

static VARS_UNMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMI_CHILDREN),
    value: None,
};

pub static VARS_UNMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("litarised"),
        dictgen::InsensitiveStr::Ascii("litarized"),
        dictgen::InsensitiveStr::Ascii("neralised"),
        dictgen::InsensitiveStr::Ascii("neralisedder"),
        dictgen::InsensitiveStr::Ascii("neraliseddest"),
        dictgen::InsensitiveStr::Ascii("neraliseds"),
        dictgen::InsensitiveStr::Ascii("neralized"),
        dictgen::InsensitiveStr::Ascii("neralizedder"),
        dictgen::InsensitiveStr::Ascii("neralizeddest"),
        dictgen::InsensitiveStr::Ascii("neralizeds"),
        dictgen::InsensitiveStr::Ascii("nimised"),
        dictgen::InsensitiveStr::Ascii("nimisedder"),
        dictgen::InsensitiveStr::Ascii("nimiseddest"),
        dictgen::InsensitiveStr::Ascii("nimising"),
        dictgen::InsensitiveStr::Ascii("nimized"),
        dictgen::InsensitiveStr::Ascii("nimizedder"),
        dictgen::InsensitiveStr::Ascii("nimizeddest"),
        dictgen::InsensitiveStr::Ascii("nimizing"),
        dictgen::InsensitiveStr::Ascii("ssionised"),
        dictgen::InsensitiveStr::Ascii("ssioniseds"),
        dictgen::InsensitiveStr::Ascii("ssionized"),
        dictgen::InsensitiveStr::Ascii("ssionizeds"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMILITARIZED_583903044185013301)],
        &[(0b01001, &ENTRY_UNMILITARIZED_583903044185013301)],
        &[(0b10010, &ENTRY_UNMINERALIZED_13805636642989384132)],
        &[(0b10010, &ENTRY_UNMINERALIZEDDER_15629225524896238795)],
        &[(0b10010, &ENTRY_UNMINERALIZEDDEST_9301755093437071771)],
        &[(0b10010, &ENTRY_UNMINERALIZEDS_14328671455943502679)],
        &[(0b01001, &ENTRY_UNMINERALIZED_13805636642989384132)],
        &[(0b01001, &ENTRY_UNMINERALIZEDDER_15629225524896238795)],
        &[(0b01001, &ENTRY_UNMINERALIZEDDEST_9301755093437071771)],
        &[(0b01001, &ENTRY_UNMINERALIZEDS_14328671455943502679)],
        &[(0b10010, &ENTRY_UNMINIMIZED_2413573858255300069)],
        &[(0b10010, &ENTRY_UNMINIMIZEDDER_10273703457324240806)],
        &[(0b10010, &ENTRY_UNMINIMIZEDDEST_2442440839355809588)],
        &[(0b10010, &ENTRY_UNMINIMIZING_14406353280475862221)],
        &[(0b01001, &ENTRY_UNMINIMIZED_2413573858255300069)],
        &[(0b01001, &ENTRY_UNMINIMIZEDDER_10273703457324240806)],
        &[(0b01001, &ENTRY_UNMINIMIZEDDEST_2442440839355809588)],
        &[(0b01001, &ENTRY_UNMINIMIZING_14406353280475862221)],
        &[(0b10010, &ENTRY_UNMISSIONIZED_8479883138336012141)],
        &[(0b10010, &ENTRY_UNMISSIONIZEDS_10090086707555908231)],
        &[(0b01001, &ENTRY_UNMISSIONIZED_8479883138336012141)],
        &[(0b01001, &ENTRY_UNMISSIONIZEDS_10090086707555908231)],
        &[(0b00001, &ENTRY_UNMITER_1266556994873335198)],
        &[(0b00001, &ENTRY_UNMITERS_8651507553417273017)],
        &[(0b11010, &ENTRY_UNMITER_1266556994873335198)],
        &[(0b11010, &ENTRY_UNMITERS_8651507553417273017)],
    ],
    range: 3..=13,
};

static VARS_UNME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNME_CHILDREN),
    value: None,
};

pub static VARS_UNME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chanise"),
        dictgen::InsensitiveStr::Ascii("chanised"),
        dictgen::InsensitiveStr::Ascii("chanises"),
        dictgen::InsensitiveStr::Ascii("chanising"),
        dictgen::InsensitiveStr::Ascii("chanize"),
        dictgen::InsensitiveStr::Ascii("chanized"),
        dictgen::InsensitiveStr::Ascii("chanizes"),
        dictgen::InsensitiveStr::Ascii("chanizing"),
        dictgen::InsensitiveStr::Ascii("diaeval"),
        dictgen::InsensitiveStr::Ascii("diatised"),
        dictgen::InsensitiveStr::Ascii("diatiseds"),
        dictgen::InsensitiveStr::Ascii("diatized"),
        dictgen::InsensitiveStr::Ascii("diatizeds"),
        dictgen::InsensitiveStr::Ascii("dieval"),
        dictgen::InsensitiveStr::Ascii("lodised"),
        dictgen::InsensitiveStr::Ascii("lodized"),
        dictgen::InsensitiveStr::Ascii("morialised"),
        dictgen::InsensitiveStr::Ascii("morialisedder"),
        dictgen::InsensitiveStr::Ascii("morialiseddest"),
        dictgen::InsensitiveStr::Ascii("morialiseds"),
        dictgen::InsensitiveStr::Ascii("morialized"),
        dictgen::InsensitiveStr::Ascii("morializedder"),
        dictgen::InsensitiveStr::Ascii("morializeddest"),
        dictgen::InsensitiveStr::Ascii("morializeds"),
        dictgen::InsensitiveStr::Ascii("morised"),
        dictgen::InsensitiveStr::Ascii("morized"),
        dictgen::InsensitiveStr::Ascii("rcerised"),
        dictgen::InsensitiveStr::Ascii("rceriseds"),
        dictgen::InsensitiveStr::Ascii("rcerized"),
        dictgen::InsensitiveStr::Ascii("rcerizeds"),
        dictgen::InsensitiveStr::Ascii("smerise"),
        dictgen::InsensitiveStr::Ascii("smerised"),
        dictgen::InsensitiveStr::Ascii("smerisedder"),
        dictgen::InsensitiveStr::Ascii("smeriseddest"),
        dictgen::InsensitiveStr::Ascii("smerises"),
        dictgen::InsensitiveStr::Ascii("smerize"),
        dictgen::InsensitiveStr::Ascii("smerized"),
        dictgen::InsensitiveStr::Ascii("smerizedder"),
        dictgen::InsensitiveStr::Ascii("smerizeddest"),
        dictgen::InsensitiveStr::Ascii("smerizes"),
        dictgen::InsensitiveStr::Ascii("talized"),
        dictgen::InsensitiveStr::Ascii("talizeds"),
        dictgen::InsensitiveStr::Ascii("tallised"),
        dictgen::InsensitiveStr::Ascii("talliseds"),
        dictgen::InsensitiveStr::Ascii("tallized"),
        dictgen::InsensitiveStr::Ascii("tallizeds"),
        dictgen::InsensitiveStr::Ascii("thodised"),
        dictgen::InsensitiveStr::Ascii("thodisedder"),
        dictgen::InsensitiveStr::Ascii("thodiseddest"),
        dictgen::InsensitiveStr::Ascii("thodiseds"),
        dictgen::InsensitiveStr::Ascii("thodising"),
        dictgen::InsensitiveStr::Ascii("thodisinger"),
        dictgen::InsensitiveStr::Ascii("thodisingest"),
        dictgen::InsensitiveStr::Ascii("thodisings"),
        dictgen::InsensitiveStr::Ascii("thodized"),
        dictgen::InsensitiveStr::Ascii("thodizedder"),
        dictgen::InsensitiveStr::Ascii("thodizeddest"),
        dictgen::InsensitiveStr::Ascii("thodizeds"),
        dictgen::InsensitiveStr::Ascii("thodizing"),
        dictgen::InsensitiveStr::Ascii("thodizinger"),
        dictgen::InsensitiveStr::Ascii("thodizingest"),
        dictgen::InsensitiveStr::Ascii("thodizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMECHANIZE_11190176714541551865)],
        &[(0b10010, &ENTRY_UNMECHANIZED_4269395601940403385)],
        &[(0b10010, &ENTRY_UNMECHANIZES_165760147883759220)],
        &[(0b10010, &ENTRY_UNMECHANIZING_506881294102189838)],
        &[(0b01001, &ENTRY_UNMECHANIZE_11190176714541551865)],
        &[(0b01001, &ENTRY_UNMECHANIZED_4269395601940403385)],
        &[(0b01001, &ENTRY_UNMECHANIZES_165760147883759220)],
        &[(0b01001, &ENTRY_UNMECHANIZING_506881294102189838)],
        &[(0b11010, &ENTRY_UNMEDIEVAL_15136839068156180300)],
        &[(0b10010, &ENTRY_UNMEDIATIZED_2290392514230277768)],
        &[(0b10010, &ENTRY_UNMEDIATIZEDS_1136374808671187759)],
        &[(0b01001, &ENTRY_UNMEDIATIZED_2290392514230277768)],
        &[(0b01001, &ENTRY_UNMEDIATIZEDS_1136374808671187759)],
        &[(0b00001, &ENTRY_UNMEDIEVAL_15136839068156180300)],
        &[(0b10010, &ENTRY_UNMELODIZED_6500550653004535054)],
        &[(0b01001, &ENTRY_UNMELODIZED_6500550653004535054)],
        &[(0b10010, &ENTRY_UNMEMORIALIZED_6600017525226329095)],
        &[(0b10010, &ENTRY_UNMEMORIALIZEDDER_10743801469581680168)],
        &[(0b10010, &ENTRY_UNMEMORIALIZEDDEST_13083723319671530750)],
        &[(0b10010, &ENTRY_UNMEMORIALIZEDS_14410279063249438063)],
        &[(0b01001, &ENTRY_UNMEMORIALIZED_6600017525226329095)],
        &[(0b01001, &ENTRY_UNMEMORIALIZEDDER_10743801469581680168)],
        &[(0b01001, &ENTRY_UNMEMORIALIZEDDEST_13083723319671530750)],
        &[(0b01001, &ENTRY_UNMEMORIALIZEDS_14410279063249438063)],
        &[(0b10010, &ENTRY_UNMEMORIZED_14626006795396178705)],
        &[(0b01001, &ENTRY_UNMEMORIZED_14626006795396178705)],
        &[(0b10010, &ENTRY_UNMERCERIZED_5852682934764830097)],
        &[(0b10010, &ENTRY_UNMERCERIZEDS_401622175139065596)],
        &[(0b01001, &ENTRY_UNMERCERIZED_5852682934764830097)],
        &[(0b01001, &ENTRY_UNMERCERIZEDS_401622175139065596)],
        &[(0b10010, &ENTRY_UNMESMERIZE_14813961012908823827)],
        &[(0b10010, &ENTRY_UNMESMERIZED_15728753808617264765)],
        &[(0b10010, &ENTRY_UNMESMERIZEDDER_2203744214809621680)],
        &[(0b10010, &ENTRY_UNMESMERIZEDDEST_6656931439181344486)],
        &[(0b10010, &ENTRY_UNMESMERIZES_18225538558952151368)],
        &[(0b01001, &ENTRY_UNMESMERIZE_14813961012908823827)],
        &[(0b01001, &ENTRY_UNMESMERIZED_15728753808617264765)],
        &[(0b01001, &ENTRY_UNMESMERIZEDDER_2203744214809621680)],
        &[(0b01001, &ENTRY_UNMESMERIZEDDEST_6656931439181344486)],
        &[(0b01001, &ENTRY_UNMESMERIZES_18225538558952151368)],
        &[(0b00001, &ENTRY_UNMETALIZED_14653098959762201949)],
        &[(0b00001, &ENTRY_UNMETALIZEDS_3049138545470459904)],
        &[(0b10010, &ENTRY_UNMETALIZED_14653098959762201949)],
        &[(0b10010, &ENTRY_UNMETALIZEDS_3049138545470459904)],
        &[(0b01000, &ENTRY_UNMETALIZED_14653098959762201949)],
        &[(0b01000, &ENTRY_UNMETALIZEDS_3049138545470459904)],
        &[(0b10010, &ENTRY_UNMETHODIZED_2715309362450077299)],
        &[(0b10010, &ENTRY_UNMETHODIZEDDER_14167275580698305003)],
        &[(0b10010, &ENTRY_UNMETHODIZEDDEST_5772600382723646544)],
        &[(0b10010, &ENTRY_UNMETHODIZEDS_10683531682808152372)],
        &[(0b10010, &ENTRY_UNMETHODIZING_4738341700288635217)],
        &[(0b10010, &ENTRY_UNMETHODIZINGER_3360650520164951225)],
        &[(0b10010, &ENTRY_UNMETHODIZINGEST_7025390942240350340)],
        &[(0b10010, &ENTRY_UNMETHODIZINGS_15327848455170179924)],
        &[(0b01001, &ENTRY_UNMETHODIZED_2715309362450077299)],
        &[(0b01001, &ENTRY_UNMETHODIZEDDER_14167275580698305003)],
        &[(0b01001, &ENTRY_UNMETHODIZEDDEST_5772600382723646544)],
        &[(0b01001, &ENTRY_UNMETHODIZEDS_10683531682808152372)],
        &[(0b01001, &ENTRY_UNMETHODIZING_4738341700288635217)],
        &[(0b01001, &ENTRY_UNMETHODIZINGER_3360650520164951225)],
        &[(0b01001, &ENTRY_UNMETHODIZINGEST_7025390942240350340)],
        &[(0b01001, &ENTRY_UNMETHODIZINGS_15327848455170179924)],
    ],
    range: 6..=14,
};

static VARS_UNMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNMA_CHILDREN),
    value: None,
};

pub static VARS_UNMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cadamised"),
        dictgen::InsensitiveStr::Ascii("cadamized"),
        dictgen::InsensitiveStr::Ascii("gnetised"),
        dictgen::InsensitiveStr::Ascii("gnetisedder"),
        dictgen::InsensitiveStr::Ascii("gnetiseddest"),
        dictgen::InsensitiveStr::Ascii("gnetiseds"),
        dictgen::InsensitiveStr::Ascii("gnetized"),
        dictgen::InsensitiveStr::Ascii("gnetizedder"),
        dictgen::InsensitiveStr::Ascii("gnetizeddest"),
        dictgen::InsensitiveStr::Ascii("gnetizeds"),
        dictgen::InsensitiveStr::Ascii("terialised"),
        dictgen::InsensitiveStr::Ascii("terialized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNMACADAMIZED_17474698526570727920)],
        &[(0b01001, &ENTRY_UNMACADAMIZED_17474698526570727920)],
        &[(0b10010, &ENTRY_UNMAGNETIZED_15659278602348180756)],
        &[(0b10010, &ENTRY_UNMAGNETIZEDDER_15921026948300347060)],
        &[(0b10010, &ENTRY_UNMAGNETIZEDDEST_9811017267349487901)],
        &[(0b10010, &ENTRY_UNMAGNETIZEDS_18035379637239565234)],
        &[(0b01001, &ENTRY_UNMAGNETIZED_15659278602348180756)],
        &[(0b01001, &ENTRY_UNMAGNETIZEDDER_15921026948300347060)],
        &[(0b01001, &ENTRY_UNMAGNETIZEDDEST_9811017267349487901)],
        &[(0b01001, &ENTRY_UNMAGNETIZEDS_18035379637239565234)],
        &[(0b10010, &ENTRY_UNMATERIALIZED_2222039272937406727)],
        &[(0b01001, &ENTRY_UNMATERIALIZED_2222039272937406727)],
    ],
    range: 8..=12,
};

static VARS_UNL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNL_CHILDREN),
    value: None,
};

static VARS_UNL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNLA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNLE_NODE),
    None,
    None,
    None,
    Some(&VARS_UNLI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNLO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNLO_CHILDREN),
    value: None,
};

pub static VARS_UNLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("calisable"),
        dictgen::InsensitiveStr::Ascii("calisabler"),
        dictgen::InsensitiveStr::Ascii("calisables"),
        dictgen::InsensitiveStr::Ascii("calisablest"),
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calised"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calising"),
        dictgen::InsensitiveStr::Ascii("calizable"),
        dictgen::InsensitiveStr::Ascii("calizabler"),
        dictgen::InsensitiveStr::Ascii("calizables"),
        dictgen::InsensitiveStr::Ascii("calizablest"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calized"),
        dictgen::InsensitiveStr::Ascii("calizes"),
        dictgen::InsensitiveStr::Ascii("calizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNLOCALIZABLE_9968738969162630281)],
        &[(0b10010, &ENTRY_UNLOCALIZABLER_1057258441085295588)],
        &[(0b10010, &ENTRY_UNLOCALIZABLES_11709528533561573241)],
        &[(0b10010, &ENTRY_UNLOCALIZABLEST_15276491984146533505)],
        &[(0b10010, &ENTRY_UNLOCALIZE_13492036293954003927)],
        &[(0b10010, &ENTRY_UNLOCALIZED_13119882870487585082)],
        &[(0b10010, &ENTRY_UNLOCALIZES_3658083138206741140)],
        &[(0b10010, &ENTRY_UNLOCALIZING_11595539427192644971)],
        &[(0b01001, &ENTRY_UNLOCALIZABLE_9968738969162630281)],
        &[(0b01001, &ENTRY_UNLOCALIZABLER_1057258441085295588)],
        &[(0b01001, &ENTRY_UNLOCALIZABLES_11709528533561573241)],
        &[(0b01001, &ENTRY_UNLOCALIZABLEST_15276491984146533505)],
        &[(0b01001, &ENTRY_UNLOCALIZE_13492036293954003927)],
        &[(0b01001, &ENTRY_UNLOCALIZED_13119882870487585082)],
        &[(0b01001, &ENTRY_UNLOCALIZES_3658083138206741140)],
        &[(0b01001, &ENTRY_UNLOCALIZING_11595539427192644971)],
    ],
    range: 6..=11,
};

static VARS_UNLI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNLI_CHILDREN),
    value: None,
};

pub static VARS_UNLI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("beralised"),
        dictgen::InsensitiveStr::Ascii("beralisedder"),
        dictgen::InsensitiveStr::Ascii("beraliseddest"),
        dictgen::InsensitiveStr::Ascii("beralized"),
        dictgen::InsensitiveStr::Ascii("beralizedder"),
        dictgen::InsensitiveStr::Ascii("beralizeddest"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("teralised"),
        dictgen::InsensitiveStr::Ascii("teralized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNLIBERALIZED_10969839816283449452)],
        &[(0b10010, &ENTRY_UNLIBERALIZEDDER_15315614160099270434)],
        &[(0b10010, &ENTRY_UNLIBERALIZEDDEST_13889596379187644396)],
        &[(0b01001, &ENTRY_UNLIBERALIZED_10969839816283449452)],
        &[(0b01001, &ENTRY_UNLIBERALIZEDDER_15315614160099270434)],
        &[(0b01001, &ENTRY_UNLIBERALIZEDDEST_13889596379187644396)],
        &[(0b10010, &ENTRY_UNLIONIZED_16819690612045451722)],
        &[(0b01001, &ENTRY_UNLIONIZED_16819690612045451722)],
        &[(0b10010, &ENTRY_UNLITERALIZED_5582864502376513867)],
        &[(0b01001, &ENTRY_UNLITERALIZED_5582864502376513867)],
    ],
    range: 6..=13,
};

static VARS_UNLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNLE_CHILDREN),
    value: None,
};

pub static VARS_UNLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arnt"),
        dictgen::InsensitiveStr::Ascii("galised"),
        dictgen::InsensitiveStr::Ascii("galisedder"),
        dictgen::InsensitiveStr::Ascii("galiseddest"),
        dictgen::InsensitiveStr::Ascii("galized"),
        dictgen::InsensitiveStr::Ascii("galizedder"),
        dictgen::InsensitiveStr::Ascii("galizeddest"),
        dictgen::InsensitiveStr::Ascii("veled"),
        dictgen::InsensitiveStr::Ascii("veling"),
        dictgen::InsensitiveStr::Ascii("velled"),
        dictgen::InsensitiveStr::Ascii("velling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNLEARNED_9662354567541580896)],
        &[(0b10010, &ENTRY_UNLEGALIZED_11280366291234483355)],
        &[(0b10010, &ENTRY_UNLEGALIZEDDER_6121814624457190630)],
        &[(0b10010, &ENTRY_UNLEGALIZEDDEST_1908746545075061751)],
        &[(0b01001, &ENTRY_UNLEGALIZED_11280366291234483355)],
        &[(0b01001, &ENTRY_UNLEGALIZEDDER_6121814624457190630)],
        &[(0b01001, &ENTRY_UNLEGALIZEDDEST_1908746545075061751)],
        &[(0b00001, &ENTRY_UNLEVELED_13198441829918947958)],
        &[(0b00001, &ENTRY_UNLEVELING_8030863631176281003)],
        &[(0b11010, &ENTRY_UNLEVELED_13198441829918947958)],
        &[(0b11010, &ENTRY_UNLEVELING_8030863631176281003)],
    ],
    range: 4..=11,
};

static VARS_UNLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNLA_CHILDREN),
    value: None,
};

pub static VARS_UNLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("beled"),
        dictgen::InsensitiveStr::Ascii("beledder"),
        dictgen::InsensitiveStr::Ascii("beleddest"),
        dictgen::InsensitiveStr::Ascii("belled"),
        dictgen::InsensitiveStr::Ascii("belledder"),
        dictgen::InsensitiveStr::Ascii("belleddest"),
        dictgen::InsensitiveStr::Ascii("bialise"),
        dictgen::InsensitiveStr::Ascii("bialised"),
        dictgen::InsensitiveStr::Ascii("bialises"),
        dictgen::InsensitiveStr::Ascii("bialising"),
        dictgen::InsensitiveStr::Ascii("bialize"),
        dictgen::InsensitiveStr::Ascii("bialized"),
        dictgen::InsensitiveStr::Ascii("bializes"),
        dictgen::InsensitiveStr::Ascii("bializing"),
        dictgen::InsensitiveStr::Ascii("borable"),
        dictgen::InsensitiveStr::Ascii("borables"),
        dictgen::InsensitiveStr::Ascii("bored"),
        dictgen::InsensitiveStr::Ascii("boredder"),
        dictgen::InsensitiveStr::Ascii("boreddest"),
        dictgen::InsensitiveStr::Ascii("boring"),
        dictgen::InsensitiveStr::Ascii("boringer"),
        dictgen::InsensitiveStr::Ascii("boringest"),
        dictgen::InsensitiveStr::Ascii("borings"),
        dictgen::InsensitiveStr::Ascii("bourable"),
        dictgen::InsensitiveStr::Ascii("bourables"),
        dictgen::InsensitiveStr::Ascii("boured"),
        dictgen::InsensitiveStr::Ascii("bouredder"),
        dictgen::InsensitiveStr::Ascii("boureddest"),
        dictgen::InsensitiveStr::Ascii("bouring"),
        dictgen::InsensitiveStr::Ascii("bouringer"),
        dictgen::InsensitiveStr::Ascii("bouringest"),
        dictgen::InsensitiveStr::Ascii("bourings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNLABELED_11329682996906852666)],
        &[(0b00001, &ENTRY_UNLABELEDDER_12664387197615721853)],
        &[(0b00001, &ENTRY_UNLABELEDDEST_10069015802563086742)],
        &[(0b11010, &ENTRY_UNLABELED_11329682996906852666)],
        &[(0b11010, &ENTRY_UNLABELEDDER_12664387197615721853)],
        &[(0b11010, &ENTRY_UNLABELEDDEST_10069015802563086742)],
        &[(0b10010, &ENTRY_UNLABIALIZE_217736053462734651)],
        &[(0b10010, &ENTRY_UNLABIALIZED_3984566951140164532)],
        &[(0b10010, &ENTRY_UNLABIALIZES_5567127362436352005)],
        &[(0b10010, &ENTRY_UNLABIALIZING_6104103553465648864)],
        &[(0b01001, &ENTRY_UNLABIALIZE_217736053462734651)],
        &[(0b01001, &ENTRY_UNLABIALIZED_3984566951140164532)],
        &[(0b01001, &ENTRY_UNLABIALIZES_5567127362436352005)],
        &[(0b01001, &ENTRY_UNLABIALIZING_6104103553465648864)],
        &[(0b00001, &ENTRY_UNLABORABLE_917849914005923474)],
        &[(0b00001, &ENTRY_UNLABORABLES_6698240791463419426)],
        &[(0b00001, &ENTRY_UNLABORED_16469902531770188672)],
        &[(0b00001, &ENTRY_UNLABOREDDER_11699946147571417125)],
        &[(0b00001, &ENTRY_UNLABOREDDEST_1362587359789372781)],
        &[(0b00001, &ENTRY_UNLABORING_4591372183864637896)],
        &[(0b00001, &ENTRY_UNLABORINGER_6365954446709867985)],
        &[(0b00001, &ENTRY_UNLABORINGEST_1473791691960115175)],
        &[(0b00001, &ENTRY_UNLABORINGS_4425858704820356556)],
        &[(0b11010, &ENTRY_UNLABORABLE_917849914005923474)],
        &[(0b11010, &ENTRY_UNLABORABLES_6698240791463419426)],
        &[(0b11010, &ENTRY_UNLABORED_16469902531770188672)],
        &[(0b11010, &ENTRY_UNLABOREDDER_11699946147571417125)],
        &[(0b11010, &ENTRY_UNLABOREDDEST_1362587359789372781)],
        &[(0b11010, &ENTRY_UNLABORING_4591372183864637896)],
        &[(0b11010, &ENTRY_UNLABORINGER_6365954446709867985)],
        &[(0b11010, &ENTRY_UNLABORINGEST_1473791691960115175)],
        &[(0b11010, &ENTRY_UNLABORINGS_4425858704820356556)],
    ],
    range: 5..=10,
};

static VARS_UNK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNK_CHILDREN),
    value: None,
};

pub static VARS_UNK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enneled"),
        dictgen::InsensitiveStr::Ascii("enneling"),
        dictgen::InsensitiveStr::Ascii("ennelled"),
        dictgen::InsensitiveStr::Ascii("ennelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNKENNELED_3312308653646352421)],
        &[(0b00001, &ENTRY_UNKENNELING_10813411767613768190)],
        &[(0b11010, &ENTRY_UNKENNELED_3312308653646352421)],
        &[(0b11010, &ENTRY_UNKENNELING_10813411767613768190)],
    ],
    range: 7..=9,
};

static VARS_UNJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNJ_CHILDREN),
    value: None,
};

pub static VARS_UNJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eopardised"),
        dictgen::InsensitiveStr::Ascii("eopardized"),
        dictgen::InsensitiveStr::Ascii("ournalised"),
        dictgen::InsensitiveStr::Ascii("ournalized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNJEOPARDIZED_13875602294611166238)],
        &[(0b01001, &ENTRY_UNJEOPARDIZED_13875602294611166238)],
        &[(0b10010, &ENTRY_UNJOURNALIZED_7826187459873218620)],
        &[(0b01001, &ENTRY_UNJOURNALIZED_7826187459873218620)],
    ],
    range: 10..=10,
};

static VARS_UNI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNI_CHILDREN),
    value: None,
};

static VARS_UNI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_UNIC_NODE),
    Some(&VARS_UNID_NODE),
    None,
    Some(&VARS_UNIF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNIL_NODE),
    Some(&VARS_UNIM_NODE),
    Some(&VARS_UNIN_NODE),
    Some(&VARS_UNIO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_UNIT_NODE),
    None,
    Some(&VARS_UNIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_UNIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIV_CHILDREN),
    value: None,
};

pub static VARS_UNIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ersalisation"),
        dictgen::InsensitiveStr::Ascii("ersalisations"),
        dictgen::InsensitiveStr::Ascii("ersalise"),
        dictgen::InsensitiveStr::Ascii("ersalised"),
        dictgen::InsensitiveStr::Ascii("ersaliser"),
        dictgen::InsensitiveStr::Ascii("ersalisers"),
        dictgen::InsensitiveStr::Ascii("ersalises"),
        dictgen::InsensitiveStr::Ascii("ersalising"),
        dictgen::InsensitiveStr::Ascii("ersalization"),
        dictgen::InsensitiveStr::Ascii("ersalizations"),
        dictgen::InsensitiveStr::Ascii("ersalize"),
        dictgen::InsensitiveStr::Ascii("ersalized"),
        dictgen::InsensitiveStr::Ascii("ersalizer"),
        dictgen::InsensitiveStr::Ascii("ersalizers"),
        dictgen::InsensitiveStr::Ascii("ersalizes"),
        dictgen::InsensitiveStr::Ascii("ersalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIVERSALIZATION_9796721220313365644)],
        &[(0b10010, &ENTRY_UNIVERSALIZATIONS_18379991359571582461)],
        &[(0b10010, &ENTRY_UNIVERSALIZE_3144285012366914544)],
        &[(0b10010, &ENTRY_UNIVERSALIZED_3359716000611655342)],
        &[(0b10010, &ENTRY_UNIVERSALIZER_15363421758448558519)],
        &[(0b10010, &ENTRY_UNIVERSALIZERS_10160828143436328394)],
        &[(0b10010, &ENTRY_UNIVERSALIZES_5744703348821395274)],
        &[(0b10010, &ENTRY_UNIVERSALIZING_3081768953979402863)],
        &[(0b01001, &ENTRY_UNIVERSALIZATION_9796721220313365644)],
        &[(0b01001, &ENTRY_UNIVERSALIZATIONS_18379991359571582461)],
        &[(0b01001, &ENTRY_UNIVERSALIZE_3144285012366914544)],
        &[(0b01001, &ENTRY_UNIVERSALIZED_3359716000611655342)],
        &[(0b01001, &ENTRY_UNIVERSALIZER_15363421758448558519)],
        &[(0b01001, &ENTRY_UNIVERSALIZERS_10160828143436328394)],
        &[(0b01001, &ENTRY_UNIVERSALIZES_5744703348821395274)],
        &[(0b01001, &ENTRY_UNIVERSALIZING_3081768953979402863)],
    ],
    range: 8..=13,
};

static VARS_UNIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIT_CHILDREN),
    value: None,
};

pub static VARS_UNIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alicised"),
        dictgen::InsensitiveStr::Ascii("alicized"),
        dictgen::InsensitiveStr::Ascii("arianise"),
        dictgen::InsensitiveStr::Ascii("arianises"),
        dictgen::InsensitiveStr::Ascii("arianize"),
        dictgen::InsensitiveStr::Ascii("arianizes"),
        dictgen::InsensitiveStr::Ascii("emised"),
        dictgen::InsensitiveStr::Ascii("emized"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNITALICIZED_4803411370795702968)],
        &[(0b01001, &ENTRY_UNITALICIZED_4803411370795702968)],
        &[(0b10010, &ENTRY_UNITARIANIZE_11972012307902630006)],
        &[(0b10010, &ENTRY_UNITARIANIZES_3299086072898342977)],
        &[(0b01001, &ENTRY_UNITARIANIZE_11972012307902630006)],
        &[(0b01001, &ENTRY_UNITARIANIZES_3299086072898342977)],
        &[(0b10010, &ENTRY_UNITEMIZED_4057716424445166287)],
        &[(0b01001, &ENTRY_UNITEMIZED_4057716424445166287)],
        &[(0b10010, &ENTRY_UNITIZATION_18446645945229573845)],
        &[(0b10010, &ENTRY_UNITIZATIONS_11931524709956438375)],
        &[(0b10010, &ENTRY_UNITIZE_15650295066694421044)],
        &[(0b10010, &ENTRY_UNITIZED_3014655947841823471)],
        &[(0b10010, &ENTRY_UNITIZES_11137940003038331316)],
        &[(0b10010, &ENTRY_UNITIZING_14503461086641416326)],
        &[(0b01001, &ENTRY_UNITIZATION_18446645945229573845)],
        &[(0b01001, &ENTRY_UNITIZATIONS_11931524709956438375)],
        &[(0b01001, &ENTRY_UNITIZE_15650295066694421044)],
        &[(0b01001, &ENTRY_UNITIZED_3014655947841823471)],
        &[(0b01001, &ENTRY_UNITIZES_11137940003038331316)],
        &[(0b01001, &ENTRY_UNITIZING_14503461086641416326)],
    ],
    range: 3..=9,
};

static VARS_UNIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIO_CHILDREN),
    value: None,
};

pub static VARS_UNIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIONIZATION_7581063025295044509)],
        &[(0b10010, &ENTRY_UNIONIZATIONS_14252170992346338262)],
        &[(0b10010, &ENTRY_UNIONIZE_5473899911122601155)],
        &[(0b10010, &ENTRY_UNIONIZED_15115860277830672338)],
        &[(0b10010, &ENTRY_UNIONIZER_7597490110750505710)],
        &[(0b10010, &ENTRY_UNIONIZERS_5139286031818390886)],
        &[(0b10010, &ENTRY_UNIONIZES_15451870011342312257)],
        &[(0b10010, &ENTRY_UNIONIZING_13986959004042777567)],
        &[(0b01001, &ENTRY_UNIONIZATION_7581063025295044509)],
        &[(0b01001, &ENTRY_UNIONIZATIONS_14252170992346338262)],
        &[(0b01001, &ENTRY_UNIONIZE_5473899911122601155)],
        &[(0b01001, &ENTRY_UNIONIZED_15115860277830672338)],
        &[(0b01001, &ENTRY_UNIONIZER_7597490110750505710)],
        &[(0b01001, &ENTRY_UNIONIZERS_5139286031818390886)],
        &[(0b01001, &ENTRY_UNIONIZES_15451870011342312257)],
        &[(0b01001, &ENTRY_UNIONIZING_13986959004042777567)],
    ],
    range: 4..=9,
};

static VARS_UNIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIN_CHILDREN),
    value: None,
};

pub static VARS_UNIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dividualise"),
        dictgen::InsensitiveStr::Ascii("dividualised"),
        dictgen::InsensitiveStr::Ascii("dividualises"),
        dictgen::InsensitiveStr::Ascii("dividualize"),
        dictgen::InsensitiveStr::Ascii("dividualized"),
        dictgen::InsensitiveStr::Ascii("dividualizes"),
        dictgen::InsensitiveStr::Ascii("dustrialised"),
        dictgen::InsensitiveStr::Ascii("dustrialiseds"),
        dictgen::InsensitiveStr::Ascii("dustrialized"),
        dictgen::InsensitiveStr::Ascii("dustrializeds"),
        dictgen::InsensitiveStr::Ascii("itialisable"),
        dictgen::InsensitiveStr::Ascii("itialised"),
        dictgen::InsensitiveStr::Ascii("itializable"),
        dictgen::InsensitiveStr::Ascii("itialized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNINDIVIDUALIZE_2549502263365684965)],
        &[(0b10010, &ENTRY_UNINDIVIDUALIZED_10177440970236663663)],
        &[(0b10010, &ENTRY_UNINDIVIDUALIZES_4576420283626985656)],
        &[(0b01001, &ENTRY_UNINDIVIDUALIZE_2549502263365684965)],
        &[(0b01001, &ENTRY_UNINDIVIDUALIZED_10177440970236663663)],
        &[(0b01001, &ENTRY_UNINDIVIDUALIZES_4576420283626985656)],
        &[(0b10010, &ENTRY_UNINDUSTRIALIZED_11443997120471272739)],
        &[(0b10010, &ENTRY_UNINDUSTRIALIZEDS_11481755961805717216)],
        &[(0b01001, &ENTRY_UNINDUSTRIALIZED_11443997120471272739)],
        &[(0b01001, &ENTRY_UNINDUSTRIALIZEDS_11481755961805717216)],
        &[(0b10010, &ENTRY_UNINITIALIZABLE_11628725753710848165)],
        &[(0b10010, &ENTRY_UNINITIALIZED_7444780362077778288)],
        &[(0b01001, &ENTRY_UNINITIALIZABLE_11628725753710848165)],
        &[(0b01001, &ENTRY_UNINITIALIZED_7444780362077778288)],
    ],
    range: 9..=13,
};

static VARS_UNIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIM_CHILDREN),
    value: None,
};

pub static VARS_UNIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mortalise"),
        dictgen::InsensitiveStr::Ascii("mortalised"),
        dictgen::InsensitiveStr::Ascii("mortalises"),
        dictgen::InsensitiveStr::Ascii("mortalize"),
        dictgen::InsensitiveStr::Ascii("mortalized"),
        dictgen::InsensitiveStr::Ascii("mortalizes"),
        dictgen::InsensitiveStr::Ascii("munised"),
        dictgen::InsensitiveStr::Ascii("munized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIMMORTALIZE_3846660396067631341)],
        &[(0b10010, &ENTRY_UNIMMORTALIZED_13628471993003828487)],
        &[(0b10010, &ENTRY_UNIMMORTALIZES_16459195990493376386)],
        &[(0b01001, &ENTRY_UNIMMORTALIZE_3846660396067631341)],
        &[(0b01001, &ENTRY_UNIMMORTALIZED_13628471993003828487)],
        &[(0b01001, &ENTRY_UNIMMORTALIZES_16459195990493376386)],
        &[(0b10010, &ENTRY_UNIMMUNIZED_15421817966409765637)],
        &[(0b01001, &ENTRY_UNIMMUNIZED_15421817966409765637)],
    ],
    range: 7..=10,
};

static VARS_UNIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIL_CHILDREN),
    value: None,
};

pub static VARS_UNIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ateralisation"),
        dictgen::InsensitiveStr::Ascii("ateralisations"),
        dictgen::InsensitiveStr::Ascii("ateralise"),
        dictgen::InsensitiveStr::Ascii("ateralises"),
        dictgen::InsensitiveStr::Ascii("ateralization"),
        dictgen::InsensitiveStr::Ascii("ateralizations"),
        dictgen::InsensitiveStr::Ascii("ateralize"),
        dictgen::InsensitiveStr::Ascii("ateralizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNILATERALIZATION_7642348548145928002)],
        &[(0b10010, &ENTRY_UNILATERALIZATIONS_3537291387881487266)],
        &[(0b10010, &ENTRY_UNILATERALIZE_4208361192869727001)],
        &[(0b10010, &ENTRY_UNILATERALIZES_13328450924130846629)],
        &[(0b01001, &ENTRY_UNILATERALIZATION_7642348548145928002)],
        &[(0b01001, &ENTRY_UNILATERALIZATIONS_3537291387881487266)],
        &[(0b01001, &ENTRY_UNILATERALIZE_4208361192869727001)],
        &[(0b01001, &ENTRY_UNILATERALIZES_13328450924130846629)],
    ],
    range: 9..=14,
};

static VARS_UNIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIF_CHILDREN),
    value: None,
};

pub static VARS_UNIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ormisation"),
        dictgen::InsensitiveStr::Ascii("ormisations"),
        dictgen::InsensitiveStr::Ascii("ormise"),
        dictgen::InsensitiveStr::Ascii("ormised"),
        dictgen::InsensitiveStr::Ascii("ormises"),
        dictgen::InsensitiveStr::Ascii("ormising"),
        dictgen::InsensitiveStr::Ascii("ormization"),
        dictgen::InsensitiveStr::Ascii("ormizations"),
        dictgen::InsensitiveStr::Ascii("ormize"),
        dictgen::InsensitiveStr::Ascii("ormized"),
        dictgen::InsensitiveStr::Ascii("ormizes"),
        dictgen::InsensitiveStr::Ascii("ormizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIFORMIZATION_6928779719483130632)],
        &[(0b10010, &ENTRY_UNIFORMIZATIONS_5553647000162520280)],
        &[(0b10010, &ENTRY_UNIFORMIZE_3224156171185377609)],
        &[(0b10010, &ENTRY_UNIFORMIZED_14730906052407110280)],
        &[(0b10010, &ENTRY_UNIFORMIZES_5570715002596396628)],
        &[(0b10010, &ENTRY_UNIFORMIZING_9818028196564001512)],
        &[(0b01001, &ENTRY_UNIFORMIZATION_6928779719483130632)],
        &[(0b01001, &ENTRY_UNIFORMIZATIONS_5553647000162520280)],
        &[(0b01001, &ENTRY_UNIFORMIZE_3224156171185377609)],
        &[(0b01001, &ENTRY_UNIFORMIZED_14730906052407110280)],
        &[(0b01001, &ENTRY_UNIFORMIZES_5570715002596396628)],
        &[(0b01001, &ENTRY_UNIFORMIZING_9818028196564001512)],
    ],
    range: 6..=11,
};

static VARS_UNID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNID_CHILDREN),
    value: None,
};

pub static VARS_UNID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealised"),
        dictgen::InsensitiveStr::Ascii("ealisedder"),
        dictgen::InsensitiveStr::Ascii("ealiseddest"),
        dictgen::InsensitiveStr::Ascii("ealized"),
        dictgen::InsensitiveStr::Ascii("ealizedder"),
        dictgen::InsensitiveStr::Ascii("ealizeddest"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olisedder"),
        dictgen::InsensitiveStr::Ascii("oliseddest"),
        dictgen::InsensitiveStr::Ascii("oliseds"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizedder"),
        dictgen::InsensitiveStr::Ascii("olizeddest"),
        dictgen::InsensitiveStr::Ascii("olizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNIDEALIZED_11116714704594641479)],
        &[(0b10010, &ENTRY_UNIDEALIZEDDER_15335158507099491677)],
        &[(0b10010, &ENTRY_UNIDEALIZEDDEST_9073505704713365354)],
        &[(0b01001, &ENTRY_UNIDEALIZED_11116714704594641479)],
        &[(0b01001, &ENTRY_UNIDEALIZEDDER_15335158507099491677)],
        &[(0b01001, &ENTRY_UNIDEALIZEDDEST_9073505704713365354)],
        &[(0b10010, &ENTRY_UNIDOLIZED_7746581993758703110)],
        &[(0b10010, &ENTRY_UNIDOLIZEDDER_9054539920726947230)],
        &[(0b10010, &ENTRY_UNIDOLIZEDDEST_11902819922448078654)],
        &[(0b10010, &ENTRY_UNIDOLIZEDS_6305662893482523010)],
        &[(0b01001, &ENTRY_UNIDOLIZED_7746581993758703110)],
        &[(0b01001, &ENTRY_UNIDOLIZEDDER_9054539920726947230)],
        &[(0b01001, &ENTRY_UNIDOLIZEDDEST_11902819922448078654)],
        &[(0b01001, &ENTRY_UNIDOLIZEDS_6305662893482523010)],
    ],
    range: 6..=11,
};

static VARS_UNIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNIC_CHILDREN),
    value: None,
};

pub static VARS_UNIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olorate"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("olorous"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olourate"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olourous"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNICOLOR_17123726217698406043)],
        &[(0b00001, &ENTRY_UNICOLORATE_7320982531251878580)],
        &[(0b00001, &ENTRY_UNICOLORED_15371219763539897842)],
        &[(0b00001, &ENTRY_UNICOLOROUS_9217819624867642093)],
        &[(0b11010, &ENTRY_UNICOLOR_17123726217698406043)],
        &[(0b11010, &ENTRY_UNICOLORATE_7320982531251878580)],
        &[(0b11010, &ENTRY_UNICOLORED_15371219763539897842)],
        &[(0b11010, &ENTRY_UNICOLOROUS_9217819624867642093)],
    ],
    range: 4..=8,
};

static VARS_UNH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNH_CHILDREN),
    value: None,
};

static VARS_UNH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNHA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNHE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNHO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNHU_NODE),
    None,
    None,
    None,
    Some(&VARS_UNHY_NODE),
    None,
];

static VARS_UNHY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHY_CHILDREN),
    value: None,
};

pub static VARS_UNHY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("drolysed"),
        dictgen::InsensitiveStr::Ascii("drolyseds"),
        dictgen::InsensitiveStr::Ascii("drolyzed"),
        dictgen::InsensitiveStr::Ascii("drolyzeds"),
        dictgen::InsensitiveStr::Ascii("pnotisable"),
        dictgen::InsensitiveStr::Ascii("pnotisabler"),
        dictgen::InsensitiveStr::Ascii("pnotisables"),
        dictgen::InsensitiveStr::Ascii("pnotisablest"),
        dictgen::InsensitiveStr::Ascii("pnotise"),
        dictgen::InsensitiveStr::Ascii("pnotised"),
        dictgen::InsensitiveStr::Ascii("pnotises"),
        dictgen::InsensitiveStr::Ascii("pnotising"),
        dictgen::InsensitiveStr::Ascii("pnotizable"),
        dictgen::InsensitiveStr::Ascii("pnotizabler"),
        dictgen::InsensitiveStr::Ascii("pnotizables"),
        dictgen::InsensitiveStr::Ascii("pnotizablest"),
        dictgen::InsensitiveStr::Ascii("pnotize"),
        dictgen::InsensitiveStr::Ascii("pnotized"),
        dictgen::InsensitiveStr::Ascii("pnotizes"),
        dictgen::InsensitiveStr::Ascii("pnotizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNHYDROLYZED_1605839220238398471)],
        &[(0b11010, &ENTRY_UNHYDROLYZEDS_13681238840583454957)],
        &[(0b00001, &ENTRY_UNHYDROLYZED_1605839220238398471)],
        &[(0b00001, &ENTRY_UNHYDROLYZEDS_13681238840583454957)],
        &[(0b10010, &ENTRY_UNHYPNOTIZABLE_12677113158391463458)],
        &[(0b10010, &ENTRY_UNHYPNOTIZABLER_8308231553591337285)],
        &[(0b10010, &ENTRY_UNHYPNOTIZABLES_2781823676708254865)],
        &[(0b10010, &ENTRY_UNHYPNOTIZABLEST_18105363756532886213)],
        &[(0b10010, &ENTRY_UNHYPNOTIZE_3076842320349928553)],
        &[(0b10010, &ENTRY_UNHYPNOTIZED_6987621846242827839)],
        &[(0b10010, &ENTRY_UNHYPNOTIZES_11386726980321406907)],
        &[(0b10010, &ENTRY_UNHYPNOTIZING_14708134202663666466)],
        &[(0b01001, &ENTRY_UNHYPNOTIZABLE_12677113158391463458)],
        &[(0b01001, &ENTRY_UNHYPNOTIZABLER_8308231553591337285)],
        &[(0b01001, &ENTRY_UNHYPNOTIZABLES_2781823676708254865)],
        &[(0b01001, &ENTRY_UNHYPNOTIZABLEST_18105363756532886213)],
        &[(0b01001, &ENTRY_UNHYPNOTIZE_3076842320349928553)],
        &[(0b01001, &ENTRY_UNHYPNOTIZED_6987621846242827839)],
        &[(0b01001, &ENTRY_UNHYPNOTIZES_11386726980321406907)],
        &[(0b01001, &ENTRY_UNHYPNOTIZING_14708134202663666466)],
    ],
    range: 7..=12,
};

static VARS_UNHU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHU_CHILDREN),
    value: None,
};

pub static VARS_UNHU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moredder"),
        dictgen::InsensitiveStr::Ascii("moreddest"),
        dictgen::InsensitiveStr::Ascii("morous"),
        dictgen::InsensitiveStr::Ascii("morously"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mouredder"),
        dictgen::InsensitiveStr::Ascii("moureddest"),
        dictgen::InsensitiveStr::Ascii("mourous"),
        dictgen::InsensitiveStr::Ascii("mourously"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNHUMANIZE_12854121833055078969)],
        &[(0b10010, &ENTRY_UNHUMANIZED_17662506078275203924)],
        &[(0b10010, &ENTRY_UNHUMANIZES_17954053753304169532)],
        &[(0b10010, &ENTRY_UNHUMANIZING_9429149451831438072)],
        &[(0b01001, &ENTRY_UNHUMANIZE_12854121833055078969)],
        &[(0b01001, &ENTRY_UNHUMANIZED_17662506078275203924)],
        &[(0b01001, &ENTRY_UNHUMANIZES_17954053753304169532)],
        &[(0b01001, &ENTRY_UNHUMANIZING_9429149451831438072)],
        &[(0b00001, &ENTRY_UNHUMORED_18084787621051692653)],
        &[(0b00001, &ENTRY_UNHUMOREDDER_18307311026638177281)],
        &[(0b00001, &ENTRY_UNHUMOREDDEST_7064789414378776056)],
        &[(0b00001, &ENTRY_UNHUMOROUS_2057333796189652890)],
        &[(0b00001, &ENTRY_UNHUMOROUSLY_16491216367858199459)],
        &[(0b11010, &ENTRY_UNHUMORED_18084787621051692653)],
        &[(0b11010, &ENTRY_UNHUMOREDDER_18307311026638177281)],
        &[(0b11010, &ENTRY_UNHUMOREDDEST_7064789414378776056)],
        &[(0b11010, &ENTRY_UNHUMOROUS_2057333796189652890)],
        &[(0b11010, &ENTRY_UNHUMOROUSLY_16491216367858199459)],
    ],
    range: 5..=10,
};

static VARS_UNHO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHO_CHILDREN),
    value: None,
};

pub static VARS_UNHO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("norable"),
        dictgen::InsensitiveStr::Ascii("norables"),
        dictgen::InsensitiveStr::Ascii("norablies"),
        dictgen::InsensitiveStr::Ascii("norably"),
        dictgen::InsensitiveStr::Ascii("nored"),
        dictgen::InsensitiveStr::Ascii("noredder"),
        dictgen::InsensitiveStr::Ascii("noreddest"),
        dictgen::InsensitiveStr::Ascii("nourable"),
        dictgen::InsensitiveStr::Ascii("nourables"),
        dictgen::InsensitiveStr::Ascii("nourablies"),
        dictgen::InsensitiveStr::Ascii("nourably"),
        dictgen::InsensitiveStr::Ascii("noured"),
        dictgen::InsensitiveStr::Ascii("nouredder"),
        dictgen::InsensitiveStr::Ascii("noureddest"),
        dictgen::InsensitiveStr::Ascii("useled"),
        dictgen::InsensitiveStr::Ascii("uselled"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNHONORABLE_1330850809715602086)],
        &[(0b00001, &ENTRY_UNHONORABLES_5002839830632485659)],
        &[(0b00001, &ENTRY_UNHONORABLIES_7582286055767508232)],
        &[(0b00001, &ENTRY_UNHONORABLY_18210830341929676608)],
        &[(0b00001, &ENTRY_UNHONORED_5460665573065748506)],
        &[(0b00001, &ENTRY_UNHONOREDDER_1452869734187004448)],
        &[(0b00001, &ENTRY_UNHONOREDDEST_6950228220672261606)],
        &[(0b11010, &ENTRY_UNHONORABLE_1330850809715602086)],
        &[(0b11010, &ENTRY_UNHONORABLES_5002839830632485659)],
        &[(0b11010, &ENTRY_UNHONORABLIES_7582286055767508232)],
        &[(0b11010, &ENTRY_UNHONORABLY_18210830341929676608)],
        &[(0b11010, &ENTRY_UNHONORED_5460665573065748506)],
        &[(0b11010, &ENTRY_UNHONOREDDER_1452869734187004448)],
        &[(0b11010, &ENTRY_UNHONOREDDEST_6950228220672261606)],
        &[(0b00001, &ENTRY_UNHOUSELED_8799017796220250092)],
        &[(0b11010, &ENTRY_UNHOUSELED_8799017796220250092)],
    ],
    range: 5..=10,
};

static VARS_UNHE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHE_CHILDREN),
    value: None,
};

pub static VARS_UNHE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("roise"),
        dictgen::InsensitiveStr::Ascii("roises"),
        dictgen::InsensitiveStr::Ascii("roize"),
        dictgen::InsensitiveStr::Ascii("roizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNHEROIZE_16852054084869741483)],
        &[(0b10010, &ENTRY_UNHEROIZES_18067699959238416206)],
        &[(0b01001, &ENTRY_UNHEROIZE_16852054084869741483)],
        &[(0b01001, &ENTRY_UNHEROIZES_18067699959238416206)],
    ],
    range: 5..=6,
};

static VARS_UNHA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNHA_CHILDREN),
    value: None,
};

pub static VARS_UNHA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rbor"),
        dictgen::InsensitiveStr::Ascii("rbored"),
        dictgen::InsensitiveStr::Ascii("rbour"),
        dictgen::InsensitiveStr::Ascii("rboured"),
        dictgen::InsensitiveStr::Ascii("rmonise"),
        dictgen::InsensitiveStr::Ascii("rmonised"),
        dictgen::InsensitiveStr::Ascii("rmonises"),
        dictgen::InsensitiveStr::Ascii("rmonising"),
        dictgen::InsensitiveStr::Ascii("rmonize"),
        dictgen::InsensitiveStr::Ascii("rmonized"),
        dictgen::InsensitiveStr::Ascii("rmonizes"),
        dictgen::InsensitiveStr::Ascii("rmonizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNHARBOR_1889127797014206122)],
        &[(0b00001, &ENTRY_UNHARBORED_15652861429904710912)],
        &[(0b11010, &ENTRY_UNHARBOR_1889127797014206122)],
        &[(0b11010, &ENTRY_UNHARBORED_15652861429904710912)],
        &[(0b10010, &ENTRY_UNHARMONIZE_14159372496346198461)],
        &[(0b10010, &ENTRY_UNHARMONIZED_3681921261857978250)],
        &[(0b10010, &ENTRY_UNHARMONIZES_13473655128913265796)],
        &[(0b10010, &ENTRY_UNHARMONIZING_3698746930961588812)],
        &[(0b01001, &ENTRY_UNHARMONIZE_14159372496346198461)],
        &[(0b01001, &ENTRY_UNHARMONIZED_3681921261857978250)],
        &[(0b01001, &ENTRY_UNHARMONIZES_13473655128913265796)],
        &[(0b01001, &ENTRY_UNHARMONIZING_3698746930961588812)],
    ],
    range: 4..=9,
};

static VARS_UNG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNG_CHILDREN),
    value: None,
};

pub static VARS_UNG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alvanised"),
        dictgen::InsensitiveStr::Ascii("alvaniseds"),
        dictgen::InsensitiveStr::Ascii("alvanized"),
        dictgen::InsensitiveStr::Ascii("alvanizeds"),
        dictgen::InsensitiveStr::Ascii("elatinisable"),
        dictgen::InsensitiveStr::Ascii("elatinisables"),
        dictgen::InsensitiveStr::Ascii("elatinised"),
        dictgen::InsensitiveStr::Ascii("elatiniseds"),
        dictgen::InsensitiveStr::Ascii("elatinizable"),
        dictgen::InsensitiveStr::Ascii("elatinizables"),
        dictgen::InsensitiveStr::Ascii("elatinized"),
        dictgen::InsensitiveStr::Ascii("elatinizeds"),
        dictgen::InsensitiveStr::Ascii("eneralised"),
        dictgen::InsensitiveStr::Ascii("eneralisedder"),
        dictgen::InsensitiveStr::Ascii("eneraliseddest"),
        dictgen::InsensitiveStr::Ascii("eneralising"),
        dictgen::InsensitiveStr::Ascii("eneralized"),
        dictgen::InsensitiveStr::Ascii("eneralizedder"),
        dictgen::InsensitiveStr::Ascii("eneralizeddest"),
        dictgen::InsensitiveStr::Ascii("eneralizing"),
        dictgen::InsensitiveStr::Ascii("entilise"),
        dictgen::InsensitiveStr::Ascii("entilises"),
        dictgen::InsensitiveStr::Ascii("entilize"),
        dictgen::InsensitiveStr::Ascii("entilizes"),
        dictgen::InsensitiveStr::Ascii("entlemanise"),
        dictgen::InsensitiveStr::Ascii("entlemanises"),
        dictgen::InsensitiveStr::Ascii("entlemanize"),
        dictgen::InsensitiveStr::Ascii("entlemanizes"),
        dictgen::InsensitiveStr::Ascii("lamourous"),
        dictgen::InsensitiveStr::Ascii("lamourously"),
        dictgen::InsensitiveStr::Ascii("ospelised"),
        dictgen::InsensitiveStr::Ascii("ospeliseds"),
        dictgen::InsensitiveStr::Ascii("ospelized"),
        dictgen::InsensitiveStr::Ascii("ospelizeds"),
        dictgen::InsensitiveStr::Ascii("raphitised"),
        dictgen::InsensitiveStr::Ascii("raphitiseds"),
        dictgen::InsensitiveStr::Ascii("raphitized"),
        dictgen::InsensitiveStr::Ascii("raphitizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNGALVANIZED_3840316573651324942)],
        &[(0b10010, &ENTRY_UNGALVANIZEDS_4906872843938668122)],
        &[(0b01001, &ENTRY_UNGALVANIZED_3840316573651324942)],
        &[(0b01001, &ENTRY_UNGALVANIZEDS_4906872843938668122)],
        &[(0b10010, &ENTRY_UNGELATINIZABLE_429611291989316452)],
        &[(0b10010, &ENTRY_UNGELATINIZABLES_4045588807998071406)],
        &[(0b10010, &ENTRY_UNGELATINIZED_9064237700681920871)],
        &[(0b10010, &ENTRY_UNGELATINIZEDS_16589417897484720231)],
        &[(0b01001, &ENTRY_UNGELATINIZABLE_429611291989316452)],
        &[(0b01001, &ENTRY_UNGELATINIZABLES_4045588807998071406)],
        &[(0b01001, &ENTRY_UNGELATINIZED_9064237700681920871)],
        &[(0b01001, &ENTRY_UNGELATINIZEDS_16589417897484720231)],
        &[(0b10010, &ENTRY_UNGENERALIZED_304645846605712294)],
        &[(0b10010, &ENTRY_UNGENERALIZEDDER_9404932562611412518)],
        &[(0b10010, &ENTRY_UNGENERALIZEDDEST_10234603051627457134)],
        &[(0b10010, &ENTRY_UNGENERALIZING_3627958036075317148)],
        &[(0b01001, &ENTRY_UNGENERALIZED_304645846605712294)],
        &[(0b01001, &ENTRY_UNGENERALIZEDDER_9404932562611412518)],
        &[(0b01001, &ENTRY_UNGENERALIZEDDEST_10234603051627457134)],
        &[(0b01001, &ENTRY_UNGENERALIZING_3627958036075317148)],
        &[(0b10010, &ENTRY_UNGENTILIZE_1682666321562915658)],
        &[(0b10010, &ENTRY_UNGENTILIZES_1989929300659612547)],
        &[(0b01001, &ENTRY_UNGENTILIZE_1682666321562915658)],
        &[(0b01001, &ENTRY_UNGENTILIZES_1989929300659612547)],
        &[(0b10010, &ENTRY_UNGENTLEMANIZE_6616841421363856905)],
        &[(0b10010, &ENTRY_UNGENTLEMANIZES_5000225273049339991)],
        &[(0b01001, &ENTRY_UNGENTLEMANIZE_6616841421363856905)],
        &[(0b01001, &ENTRY_UNGENTLEMANIZES_5000225273049339991)],
        &[(0b11010, &ENTRY_UNGLAMOROUS_11551883381104018739)],
        &[(0b11010, &ENTRY_UNGLAMOROUSLY_12722711669948552620)],
        &[(0b10010, &ENTRY_UNGOSPELIZED_7916023896723661075)],
        &[(0b10010, &ENTRY_UNGOSPELIZEDS_12370376811231680007)],
        &[(0b01001, &ENTRY_UNGOSPELIZED_7916023896723661075)],
        &[(0b01001, &ENTRY_UNGOSPELIZEDS_12370376811231680007)],
        &[(0b10010, &ENTRY_UNGRAPHITIZED_9140840362551120713)],
        &[(0b10010, &ENTRY_UNGRAPHITIZEDS_17567383968087162591)],
        &[(0b01001, &ENTRY_UNGRAPHITIZED_9140840362551120713)],
        &[(0b01001, &ENTRY_UNGRAPHITIZEDS_17567383968087162591)],
    ],
    range: 8..=14,
};

static VARS_UNF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNF_CHILDREN),
    value: None,
};

static VARS_UNF_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNFA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNFE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNFL_NODE),
    None,
    None,
    Some(&VARS_UNFO_NODE),
    None,
    None,
    Some(&VARS_UNFR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNFR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFR_CHILDREN),
    value: None,
};

pub static VARS_UNFR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aternised"),
        dictgen::InsensitiveStr::Ascii("aternising"),
        dictgen::InsensitiveStr::Ascii("aternisings"),
        dictgen::InsensitiveStr::Ascii("aternized"),
        dictgen::InsensitiveStr::Ascii("aternizing"),
        dictgen::InsensitiveStr::Ascii("aternizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNFRATERNIZED_15391653689494557711)],
        &[(0b10010, &ENTRY_UNFRATERNIZING_11945792457598246703)],
        &[(0b10010, &ENTRY_UNFRATERNIZINGS_443815508621461535)],
        &[(0b01001, &ENTRY_UNFRATERNIZED_15391653689494557711)],
        &[(0b01001, &ENTRY_UNFRATERNIZING_11945792457598246703)],
        &[(0b01001, &ENTRY_UNFRATERNIZINGS_443815508621461535)],
    ],
    range: 9..=11,
};

static VARS_UNFO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFO_CHILDREN),
    value: None,
};

pub static VARS_UNFO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rmalised"),
        dictgen::InsensitiveStr::Ascii("rmalisedder"),
        dictgen::InsensitiveStr::Ascii("rmaliseddest"),
        dictgen::InsensitiveStr::Ascii("rmalized"),
        dictgen::InsensitiveStr::Ascii("rmalizedder"),
        dictgen::InsensitiveStr::Ascii("rmalizeddest"),
        dictgen::InsensitiveStr::Ascii("ssilised"),
        dictgen::InsensitiveStr::Ascii("ssilisedder"),
        dictgen::InsensitiveStr::Ascii("ssiliseddest"),
        dictgen::InsensitiveStr::Ascii("ssiliseds"),
        dictgen::InsensitiveStr::Ascii("ssilized"),
        dictgen::InsensitiveStr::Ascii("ssilizedder"),
        dictgen::InsensitiveStr::Ascii("ssilizeddest"),
        dictgen::InsensitiveStr::Ascii("ssilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNFORMALIZED_10947362983293799260)],
        &[(0b10010, &ENTRY_UNFORMALIZEDDER_16826016574168323811)],
        &[(0b10010, &ENTRY_UNFORMALIZEDDEST_14745966789505381148)],
        &[(0b01001, &ENTRY_UNFORMALIZED_10947362983293799260)],
        &[(0b01001, &ENTRY_UNFORMALIZEDDER_16826016574168323811)],
        &[(0b01001, &ENTRY_UNFORMALIZEDDEST_14745966789505381148)],
        &[(0b10010, &ENTRY_UNFOSSILIZED_1644345316811460331)],
        &[(0b10010, &ENTRY_UNFOSSILIZEDDER_9873397475242687877)],
        &[(0b10010, &ENTRY_UNFOSSILIZEDDEST_11985032009736222005)],
        &[(0b10010, &ENTRY_UNFOSSILIZEDS_11821803111813998857)],
        &[(0b01001, &ENTRY_UNFOSSILIZED_1644345316811460331)],
        &[(0b01001, &ENTRY_UNFOSSILIZEDDER_9873397475242687877)],
        &[(0b01001, &ENTRY_UNFOSSILIZEDDEST_11985032009736222005)],
        &[(0b01001, &ENTRY_UNFOSSILIZEDS_11821803111813998857)],
    ],
    range: 8..=12,
};

static VARS_UNFL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFL_CHILDREN),
    value: None,
};

pub static VARS_UNFL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avored"),
        dictgen::InsensitiveStr::Ascii("avoredder"),
        dictgen::InsensitiveStr::Ascii("avoreddest"),
        dictgen::InsensitiveStr::Ascii("avorous"),
        dictgen::InsensitiveStr::Ascii("avoured"),
        dictgen::InsensitiveStr::Ascii("avouredder"),
        dictgen::InsensitiveStr::Ascii("avoureddest"),
        dictgen::InsensitiveStr::Ascii("avourous"),
    ],
    values: &[
        &[(0b11001, &ENTRY_UNFLAVORED_7704639512615468125)],
        &[(0b11001, &ENTRY_UNFLAVOREDDER_10493652523700310738)],
        &[(0b11001, &ENTRY_UNFLAVOREDDEST_1414059801540499482)],
        &[(0b00001, &ENTRY_UNFLAVOROUS_16935211748591593605)],
        &[(0b11010, &ENTRY_UNFLAVORED_7704639512615468125)],
        &[(0b11010, &ENTRY_UNFLAVOREDDER_10493652523700310738)],
        &[(0b11010, &ENTRY_UNFLAVOREDDEST_1414059801540499482)],
        &[(0b11010, &ENTRY_UNFLAVOROUS_16935211748591593605)],
    ],
    range: 6..=11,
};

static VARS_UNFE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFE_CHILDREN),
    value: None,
};

pub static VARS_UNFE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minise"),
        dictgen::InsensitiveStr::Ascii("minised"),
        dictgen::InsensitiveStr::Ascii("minising"),
        dictgen::InsensitiveStr::Ascii("minize"),
        dictgen::InsensitiveStr::Ascii("minized"),
        dictgen::InsensitiveStr::Ascii("minizing"),
        dictgen::InsensitiveStr::Ascii("rtilisable"),
        dictgen::InsensitiveStr::Ascii("rtilisabler"),
        dictgen::InsensitiveStr::Ascii("rtilisables"),
        dictgen::InsensitiveStr::Ascii("rtilisablest"),
        dictgen::InsensitiveStr::Ascii("rtilised"),
        dictgen::InsensitiveStr::Ascii("rtilisedder"),
        dictgen::InsensitiveStr::Ascii("rtiliseddest"),
        dictgen::InsensitiveStr::Ascii("rtilising"),
        dictgen::InsensitiveStr::Ascii("rtilizable"),
        dictgen::InsensitiveStr::Ascii("rtilizabler"),
        dictgen::InsensitiveStr::Ascii("rtilizables"),
        dictgen::InsensitiveStr::Ascii("rtilizablest"),
        dictgen::InsensitiveStr::Ascii("rtilized"),
        dictgen::InsensitiveStr::Ascii("rtilizedder"),
        dictgen::InsensitiveStr::Ascii("rtilizeddest"),
        dictgen::InsensitiveStr::Ascii("rtilizing"),
        dictgen::InsensitiveStr::Ascii("udalise"),
        dictgen::InsensitiveStr::Ascii("udalised"),
        dictgen::InsensitiveStr::Ascii("udalises"),
        dictgen::InsensitiveStr::Ascii("udalising"),
        dictgen::InsensitiveStr::Ascii("udalize"),
        dictgen::InsensitiveStr::Ascii("udalized"),
        dictgen::InsensitiveStr::Ascii("udalizes"),
        dictgen::InsensitiveStr::Ascii("udalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNFEMINIZE_17213280328995954348)],
        &[(0b10010, &ENTRY_UNFEMINIZED_3027631822761516755)],
        &[(0b10010, &ENTRY_UNFEMINIZING_16839714662136031968)],
        &[(0b01001, &ENTRY_UNFEMINIZE_17213280328995954348)],
        &[(0b01001, &ENTRY_UNFEMINIZED_3027631822761516755)],
        &[(0b01001, &ENTRY_UNFEMINIZING_16839714662136031968)],
        &[(0b10010, &ENTRY_UNFERTILIZABLE_17486342932318545605)],
        &[(0b10010, &ENTRY_UNFERTILIZABLER_7824528564028868183)],
        &[(0b10010, &ENTRY_UNFERTILIZABLES_2276591821562054261)],
        &[(0b10010, &ENTRY_UNFERTILIZABLEST_13686866561865228741)],
        &[(0b10010, &ENTRY_UNFERTILIZED_8536659073895846486)],
        &[(0b10010, &ENTRY_UNFERTILIZEDDER_8970939762495254103)],
        &[(0b10010, &ENTRY_UNFERTILIZEDDEST_3987712837886027136)],
        &[(0b10010, &ENTRY_UNFERTILIZING_18219334417771825481)],
        &[(0b01001, &ENTRY_UNFERTILIZABLE_17486342932318545605)],
        &[(0b01001, &ENTRY_UNFERTILIZABLER_7824528564028868183)],
        &[(0b01001, &ENTRY_UNFERTILIZABLES_2276591821562054261)],
        &[(0b01001, &ENTRY_UNFERTILIZABLEST_13686866561865228741)],
        &[(0b01001, &ENTRY_UNFERTILIZED_8536659073895846486)],
        &[(0b01001, &ENTRY_UNFERTILIZEDDER_8970939762495254103)],
        &[(0b01001, &ENTRY_UNFERTILIZEDDEST_3987712837886027136)],
        &[(0b01001, &ENTRY_UNFERTILIZING_18219334417771825481)],
        &[(0b10010, &ENTRY_UNFEUDALIZE_14691232336692814883)],
        &[(0b10010, &ENTRY_UNFEUDALIZED_11117493394291645590)],
        &[(0b10010, &ENTRY_UNFEUDALIZES_5103523048575728973)],
        &[(0b10010, &ENTRY_UNFEUDALIZING_3182932192190349634)],
        &[(0b01001, &ENTRY_UNFEUDALIZE_14691232336692814883)],
        &[(0b01001, &ENTRY_UNFEUDALIZED_11117493394291645590)],
        &[(0b01001, &ENTRY_UNFEUDALIZES_5103523048575728973)],
        &[(0b01001, &ENTRY_UNFEUDALIZING_3182932192190349634)],
    ],
    range: 6..=12,
};

static VARS_UNFA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNFA_CHILDREN),
    value: None,
};

pub static VARS_UNFA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("miliarised"),
        dictgen::InsensitiveStr::Ascii("miliarisedder"),
        dictgen::InsensitiveStr::Ascii("miliariseddest"),
        dictgen::InsensitiveStr::Ascii("miliarized"),
        dictgen::InsensitiveStr::Ascii("miliarizedder"),
        dictgen::InsensitiveStr::Ascii("miliarizeddest"),
        dictgen::InsensitiveStr::Ascii("vorable"),
        dictgen::InsensitiveStr::Ascii("vorableness"),
        dictgen::InsensitiveStr::Ascii("vorablenesses"),
        dictgen::InsensitiveStr::Ascii("vorabler"),
        dictgen::InsensitiveStr::Ascii("vorables"),
        dictgen::InsensitiveStr::Ascii("vorablest"),
        dictgen::InsensitiveStr::Ascii("vorablier"),
        dictgen::InsensitiveStr::Ascii("vorabliest"),
        dictgen::InsensitiveStr::Ascii("vorably"),
        dictgen::InsensitiveStr::Ascii("vored"),
        dictgen::InsensitiveStr::Ascii("voredder"),
        dictgen::InsensitiveStr::Ascii("voreddest"),
        dictgen::InsensitiveStr::Ascii("voring"),
        dictgen::InsensitiveStr::Ascii("voringer"),
        dictgen::InsensitiveStr::Ascii("voringest"),
        dictgen::InsensitiveStr::Ascii("vorings"),
        dictgen::InsensitiveStr::Ascii("vorite"),
        dictgen::InsensitiveStr::Ascii("voriter"),
        dictgen::InsensitiveStr::Ascii("vorites"),
        dictgen::InsensitiveStr::Ascii("voritest"),
        dictgen::InsensitiveStr::Ascii("vourable"),
        dictgen::InsensitiveStr::Ascii("vourableness"),
        dictgen::InsensitiveStr::Ascii("vourablenesses"),
        dictgen::InsensitiveStr::Ascii("vourabler"),
        dictgen::InsensitiveStr::Ascii("vourables"),
        dictgen::InsensitiveStr::Ascii("vourablest"),
        dictgen::InsensitiveStr::Ascii("vourablier"),
        dictgen::InsensitiveStr::Ascii("vourabliest"),
        dictgen::InsensitiveStr::Ascii("vourably"),
        dictgen::InsensitiveStr::Ascii("voured"),
        dictgen::InsensitiveStr::Ascii("vouredder"),
        dictgen::InsensitiveStr::Ascii("voureddest"),
        dictgen::InsensitiveStr::Ascii("vouring"),
        dictgen::InsensitiveStr::Ascii("vouringer"),
        dictgen::InsensitiveStr::Ascii("vouringest"),
        dictgen::InsensitiveStr::Ascii("vourings"),
        dictgen::InsensitiveStr::Ascii("vourite"),
        dictgen::InsensitiveStr::Ascii("vouriter"),
        dictgen::InsensitiveStr::Ascii("vourites"),
        dictgen::InsensitiveStr::Ascii("vouritest"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNFAMILIARIZED_8539267182006341403)],
        &[(0b10010, &ENTRY_UNFAMILIARIZEDDER_13089042195024096822)],
        &[(0b10010, &ENTRY_UNFAMILIARIZEDDEST_4018673522303778898)],
        &[(0b01001, &ENTRY_UNFAMILIARIZED_8539267182006341403)],
        &[(0b01001, &ENTRY_UNFAMILIARIZEDDER_13089042195024096822)],
        &[(0b01001, &ENTRY_UNFAMILIARIZEDDEST_4018673522303778898)],
        &[(0b11001, &ENTRY_UNFAVORABLE_8233532032007631727)],
        &[(0b11001, &ENTRY_UNFAVORABLENESS_11828384935093784234)],
        &[(0b11001, &ENTRY_UNFAVORABLENESSES_6196655711715423789)],
        &[(0b11001, &ENTRY_UNFAVORABLER_7526512460280153322)],
        &[(0b11001, &ENTRY_UNFAVORABLES_6371240244863361092)],
        &[(0b11001, &ENTRY_UNFAVORABLEST_10537368209740978427)],
        &[(0b11001, &ENTRY_UNFAVORABLIER_9564967346867026046)],
        &[(0b11001, &ENTRY_UNFAVORABLIEST_17311907542528170719)],
        &[(0b11001, &ENTRY_UNFAVORABLY_13214726587411166355)],
        &[(0b11001, &ENTRY_UNFAVORED_8089880807159401110)],
        &[(0b11001, &ENTRY_UNFAVOREDDER_6939782924396346672)],
        &[(0b11001, &ENTRY_UNFAVOREDDEST_9219340201172922449)],
        &[(0b11001, &ENTRY_UNFAVORING_14241568587543696910)],
        &[(0b11001, &ENTRY_UNFAVORINGER_3557197515106588733)],
        &[(0b11001, &ENTRY_UNFAVORINGEST_12052226034286952177)],
        &[(0b11001, &ENTRY_UNFAVORINGS_16058515457408679487)],
        &[(0b11001, &ENTRY_UNFAVORITE_9275402982305749708)],
        &[(0b11001, &ENTRY_UNFAVORITER_3433053368739550354)],
        &[(0b11001, &ENTRY_UNFAVORITES_8192113054989661952)],
        &[(0b11001, &ENTRY_UNFAVORITEST_5653472480878764002)],
        &[(0b11010, &ENTRY_UNFAVORABLE_8233532032007631727)],
        &[(0b11010, &ENTRY_UNFAVORABLENESS_11828384935093784234)],
        &[(0b11010, &ENTRY_UNFAVORABLENESSES_6196655711715423789)],
        &[(0b11010, &ENTRY_UNFAVORABLER_7526512460280153322)],
        &[(0b11010, &ENTRY_UNFAVORABLES_6371240244863361092)],
        &[(0b11010, &ENTRY_UNFAVORABLEST_10537368209740978427)],
        &[(0b11010, &ENTRY_UNFAVORABLIER_9564967346867026046)],
        &[(0b11010, &ENTRY_UNFAVORABLIEST_17311907542528170719)],
        &[(0b11010, &ENTRY_UNFAVORABLY_13214726587411166355)],
        &[(0b11010, &ENTRY_UNFAVORED_8089880807159401110)],
        &[(0b11010, &ENTRY_UNFAVOREDDER_6939782924396346672)],
        &[(0b11010, &ENTRY_UNFAVOREDDEST_9219340201172922449)],
        &[(0b11010, &ENTRY_UNFAVORING_14241568587543696910)],
        &[(0b11010, &ENTRY_UNFAVORINGER_3557197515106588733)],
        &[(0b11010, &ENTRY_UNFAVORINGEST_12052226034286952177)],
        &[(0b11010, &ENTRY_UNFAVORINGS_16058515457408679487)],
        &[(0b11010, &ENTRY_UNFAVORITE_9275402982305749708)],
        &[(0b11010, &ENTRY_UNFAVORITER_3433053368739550354)],
        &[(0b11010, &ENTRY_UNFAVORITES_8192113054989661952)],
        &[(0b11010, &ENTRY_UNFAVORITEST_5653472480878764002)],
    ],
    range: 5..=14,
};

static VARS_UNE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNE_CHILDREN),
    value: None,
};

pub static VARS_UNE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("conomising"),
        dictgen::InsensitiveStr::Ascii("conomizing"),
        dictgen::InsensitiveStr::Ascii("namored"),
        dictgen::InsensitiveStr::Ascii("namoredder"),
        dictgen::InsensitiveStr::Ascii("namoreddest"),
        dictgen::InsensitiveStr::Ascii("namoreds"),
        dictgen::InsensitiveStr::Ascii("namoured"),
        dictgen::InsensitiveStr::Ascii("namouredder"),
        dictgen::InsensitiveStr::Ascii("namoureddest"),
        dictgen::InsensitiveStr::Ascii("namoureds"),
        dictgen::InsensitiveStr::Ascii("ndeavored"),
        dictgen::InsensitiveStr::Ascii("ndeavoured"),
        dictgen::InsensitiveStr::Ascii("nergised"),
        dictgen::InsensitiveStr::Ascii("nergiseds"),
        dictgen::InsensitiveStr::Ascii("nergized"),
        dictgen::InsensitiveStr::Ascii("nergizeds"),
        dictgen::InsensitiveStr::Ascii("pitomised"),
        dictgen::InsensitiveStr::Ascii("pitomisedder"),
        dictgen::InsensitiveStr::Ascii("pitomiseddest"),
        dictgen::InsensitiveStr::Ascii("pitomized"),
        dictgen::InsensitiveStr::Ascii("pitomizedder"),
        dictgen::InsensitiveStr::Ascii("pitomizeddest"),
        dictgen::InsensitiveStr::Ascii("qualed"),
        dictgen::InsensitiveStr::Ascii("qualedder"),
        dictgen::InsensitiveStr::Ascii("qualeddest"),
        dictgen::InsensitiveStr::Ascii("qualise"),
        dictgen::InsensitiveStr::Ascii("qualised"),
        dictgen::InsensitiveStr::Ascii("qualises"),
        dictgen::InsensitiveStr::Ascii("qualising"),
        dictgen::InsensitiveStr::Ascii("qualize"),
        dictgen::InsensitiveStr::Ascii("qualized"),
        dictgen::InsensitiveStr::Ascii("qualizes"),
        dictgen::InsensitiveStr::Ascii("qualizing"),
        dictgen::InsensitiveStr::Ascii("qualled"),
        dictgen::InsensitiveStr::Ascii("qualledder"),
        dictgen::InsensitiveStr::Ascii("qualleddest"),
        dictgen::InsensitiveStr::Ascii("ulogised"),
        dictgen::InsensitiveStr::Ascii("ulogisedder"),
        dictgen::InsensitiveStr::Ascii("ulogiseddest"),
        dictgen::InsensitiveStr::Ascii("ulogiseds"),
        dictgen::InsensitiveStr::Ascii("ulogized"),
        dictgen::InsensitiveStr::Ascii("ulogizedder"),
        dictgen::InsensitiveStr::Ascii("ulogizeddest"),
        dictgen::InsensitiveStr::Ascii("ulogizeds"),
        dictgen::InsensitiveStr::Ascii("vangelised"),
        dictgen::InsensitiveStr::Ascii("vangelisedder"),
        dictgen::InsensitiveStr::Ascii("vangeliseddest"),
        dictgen::InsensitiveStr::Ascii("vangeliseds"),
        dictgen::InsensitiveStr::Ascii("vangelized"),
        dictgen::InsensitiveStr::Ascii("vangelizedder"),
        dictgen::InsensitiveStr::Ascii("vangelizeddest"),
        dictgen::InsensitiveStr::Ascii("vangelizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNECONOMIZING_15613959143050410767)],
        &[(0b01001, &ENTRY_UNECONOMIZING_15613959143050410767)],
        &[(0b00001, &ENTRY_UNENAMORED_8361050364159923006)],
        &[(0b00001, &ENTRY_UNENAMOREDDER_5033547920430041938)],
        &[(0b00001, &ENTRY_UNENAMOREDDEST_5114505485270249696)],
        &[(0b00001, &ENTRY_UNENAMOREDS_16806991213706982613)],
        &[(0b11010, &ENTRY_UNENAMORED_8361050364159923006)],
        &[(0b11010, &ENTRY_UNENAMOREDDER_5033547920430041938)],
        &[(0b11010, &ENTRY_UNENAMOREDDEST_5114505485270249696)],
        &[(0b11010, &ENTRY_UNENAMOREDS_16806991213706982613)],
        &[(0b00001, &ENTRY_UNENDEAVORED_7066291353915558991)],
        &[(0b11010, &ENTRY_UNENDEAVORED_7066291353915558991)],
        &[(0b10010, &ENTRY_UNENERGIZED_1765957718558496954)],
        &[(0b10010, &ENTRY_UNENERGIZEDS_9257032612298922872)],
        &[(0b01001, &ENTRY_UNENERGIZED_1765957718558496954)],
        &[(0b01001, &ENTRY_UNENERGIZEDS_9257032612298922872)],
        &[(0b10010, &ENTRY_UNEPITOMIZED_14848321193589314772)],
        &[(0b10010, &ENTRY_UNEPITOMIZEDDER_14282657736379387619)],
        &[(0b10010, &ENTRY_UNEPITOMIZEDDEST_17830262776297478282)],
        &[(0b01001, &ENTRY_UNEPITOMIZED_14848321193589314772)],
        &[(0b01001, &ENTRY_UNEPITOMIZEDDER_14282657736379387619)],
        &[(0b01001, &ENTRY_UNEPITOMIZEDDEST_17830262776297478282)],
        &[(0b00001, &ENTRY_UNEQUALED_10272049179921241581)],
        &[(0b00001, &ENTRY_UNEQUALEDDER_8399677671352964156)],
        &[(0b00001, &ENTRY_UNEQUALEDDEST_12126395105891544493)],
        &[(0b10010, &ENTRY_UNEQUALIZE_12397832983269467070)],
        &[(0b10010, &ENTRY_UNEQUALIZED_11229527678135642111)],
        &[(0b10010, &ENTRY_UNEQUALIZES_11516811173212612864)],
        &[(0b10010, &ENTRY_UNEQUALIZING_7314201456915686327)],
        &[(0b01001, &ENTRY_UNEQUALIZE_12397832983269467070)],
        &[(0b01001, &ENTRY_UNEQUALIZED_11229527678135642111)],
        &[(0b01001, &ENTRY_UNEQUALIZES_11516811173212612864)],
        &[(0b01001, &ENTRY_UNEQUALIZING_7314201456915686327)],
        &[(0b11010, &ENTRY_UNEQUALED_10272049179921241581)],
        &[(0b11010, &ENTRY_UNEQUALEDDER_8399677671352964156)],
        &[(0b11010, &ENTRY_UNEQUALEDDEST_12126395105891544493)],
        &[(0b10010, &ENTRY_UNEULOGIZED_8625593682318183902)],
        &[(0b10010, &ENTRY_UNEULOGIZEDDER_500502998937424952)],
        &[(0b10010, &ENTRY_UNEULOGIZEDDEST_15902188274770789074)],
        &[(0b10010, &ENTRY_UNEULOGIZEDS_9618091862575439629)],
        &[(0b01001, &ENTRY_UNEULOGIZED_8625593682318183902)],
        &[(0b01001, &ENTRY_UNEULOGIZEDDER_500502998937424952)],
        &[(0b01001, &ENTRY_UNEULOGIZEDDEST_15902188274770789074)],
        &[(0b01001, &ENTRY_UNEULOGIZEDS_9618091862575439629)],
        &[(0b10010, &ENTRY_UNEVANGELIZED_17902646883952932702)],
        &[(0b10010, &ENTRY_UNEVANGELIZEDDER_14389146019253414049)],
        &[(0b10010, &ENTRY_UNEVANGELIZEDDEST_11919291498979551119)],
        &[(0b10010, &ENTRY_UNEVANGELIZEDS_4997587800538848322)],
        &[(0b01001, &ENTRY_UNEVANGELIZED_17902646883952932702)],
        &[(0b01001, &ENTRY_UNEVANGELIZEDDER_14389146019253414049)],
        &[(0b01001, &ENTRY_UNEVANGELIZEDDEST_11919291498979551119)],
        &[(0b01001, &ENTRY_UNEVANGELIZEDS_4997587800538848322)],
    ],
    range: 6..=14,
};

static VARS_UND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UND_CHILDREN),
    value: None,
};

static VARS_UND_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_UNDE_NODE),
    None,
    None,
    None,
    Some(&VARS_UNDI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNDR_NODE),
    None,
    None,
    Some(&VARS_UNDU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNDU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDU_CHILDREN),
    value: None,
};

pub static VARS_UNDU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDUALIZE_12388450838585691212)],
        &[(0b10010, &ENTRY_UNDUALIZES_16398535363456366813)],
        &[(0b01001, &ENTRY_UNDUALIZE_12388450838585691212)],
        &[(0b01001, &ENTRY_UNDUALIZES_16398535363456366813)],
    ],
    range: 5..=6,
};

static VARS_UNDR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDR_CHILDREN),
    value: None,
};

pub static VARS_UNDR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amatisable"),
        dictgen::InsensitiveStr::Ascii("amatisabler"),
        dictgen::InsensitiveStr::Ascii("amatisables"),
        dictgen::InsensitiveStr::Ascii("amatisablest"),
        dictgen::InsensitiveStr::Ascii("amatised"),
        dictgen::InsensitiveStr::Ascii("amatiseds"),
        dictgen::InsensitiveStr::Ascii("amatizable"),
        dictgen::InsensitiveStr::Ascii("amatizabler"),
        dictgen::InsensitiveStr::Ascii("amatizables"),
        dictgen::InsensitiveStr::Ascii("amatizablest"),
        dictgen::InsensitiveStr::Ascii("amatized"),
        dictgen::InsensitiveStr::Ascii("amatizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDRAMATIZABLE_16417239684975540746)],
        &[(0b10010, &ENTRY_UNDRAMATIZABLER_17183761443356610462)],
        &[(0b10010, &ENTRY_UNDRAMATIZABLES_1761059456444333869)],
        &[(0b10010, &ENTRY_UNDRAMATIZABLEST_10351333071010784123)],
        &[(0b10010, &ENTRY_UNDRAMATIZED_10630343306514025585)],
        &[(0b10010, &ENTRY_UNDRAMATIZEDS_12222872129614232202)],
        &[(0b01001, &ENTRY_UNDRAMATIZABLE_16417239684975540746)],
        &[(0b01001, &ENTRY_UNDRAMATIZABLER_17183761443356610462)],
        &[(0b01001, &ENTRY_UNDRAMATIZABLES_1761059456444333869)],
        &[(0b01001, &ENTRY_UNDRAMATIZABLEST_10351333071010784123)],
        &[(0b01001, &ENTRY_UNDRAMATIZED_10630343306514025585)],
        &[(0b01001, &ENTRY_UNDRAMATIZEDS_12222872129614232202)],
    ],
    range: 8..=12,
};

static VARS_UNDI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDI_CHILDREN),
    value: None,
};

pub static VARS_UNDI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alysed"),
        dictgen::InsensitiveStr::Ascii("alyseds"),
        dictgen::InsensitiveStr::Ascii("alyzed"),
        dictgen::InsensitiveStr::Ascii("alyzeds"),
        dictgen::InsensitiveStr::Ascii("phthongise"),
        dictgen::InsensitiveStr::Ascii("phthongises"),
        dictgen::InsensitiveStr::Ascii("phthongize"),
        dictgen::InsensitiveStr::Ascii("phthongizes"),
        dictgen::InsensitiveStr::Ascii("scolored"),
        dictgen::InsensitiveStr::Ascii("scoloredder"),
        dictgen::InsensitiveStr::Ascii("scoloreddest"),
        dictgen::InsensitiveStr::Ascii("scoloreds"),
        dictgen::InsensitiveStr::Ascii("scoloured"),
        dictgen::InsensitiveStr::Ascii("scolouredder"),
        dictgen::InsensitiveStr::Ascii("scoloureddest"),
        dictgen::InsensitiveStr::Ascii("scoloureds"),
        dictgen::InsensitiveStr::Ascii("shonored"),
        dictgen::InsensitiveStr::Ascii("shonoured"),
        dictgen::InsensitiveStr::Ascii("sorganised"),
        dictgen::InsensitiveStr::Ascii("sorganized"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNDIALYZED_4239031886129441255)],
        &[(0b11010, &ENTRY_UNDIALYZEDS_15673303853485275568)],
        &[(0b00001, &ENTRY_UNDIALYZED_4239031886129441255)],
        &[(0b00001, &ENTRY_UNDIALYZEDS_15673303853485275568)],
        &[(0b10010, &ENTRY_UNDIPHTHONGIZE_2160275447408384699)],
        &[(0b10010, &ENTRY_UNDIPHTHONGIZES_919729037221686149)],
        &[(0b01001, &ENTRY_UNDIPHTHONGIZE_2160275447408384699)],
        &[(0b01001, &ENTRY_UNDIPHTHONGIZES_919729037221686149)],
        &[(0b00001, &ENTRY_UNDISCOLORED_16617222672466412819)],
        &[(0b00001, &ENTRY_UNDISCOLOREDDER_12948233388857516182)],
        &[(0b00001, &ENTRY_UNDISCOLOREDDEST_588122864294200189)],
        &[(0b00001, &ENTRY_UNDISCOLOREDS_10674456259381646580)],
        &[(0b11010, &ENTRY_UNDISCOLORED_16617222672466412819)],
        &[(0b11010, &ENTRY_UNDISCOLOREDDER_12948233388857516182)],
        &[(0b11010, &ENTRY_UNDISCOLOREDDEST_588122864294200189)],
        &[(0b11010, &ENTRY_UNDISCOLOREDS_10674456259381646580)],
        &[(0b00001, &ENTRY_UNDISHONORED_10570919707421545123)],
        &[(0b11010, &ENTRY_UNDISHONORED_10570919707421545123)],
        &[(0b10010, &ENTRY_UNDISORGANIZED_2987622726902566022)],
        &[(0b01001, &ENTRY_UNDISORGANIZED_2987622726902566022)],
    ],
    range: 6..=13,
};

static VARS_UNDE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNDE_CHILDREN),
    value: None,
};

static VARS_UNDE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNDEF_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_UNDEM_NODE),
    Some(&VARS_UNDEN_NODE),
    None,
    None,
    None,
    Some(&VARS_UNDER_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNDER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNDER_CHILDREN),
    value: None,
};

static VARS_UNDER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_UNDERC_NODE),
    None,
    Some(&VARS_UNDERE_NODE),
    None,
    Some(&VARS_UNDERG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_UNDERL_NODE),
    None,
    None,
    Some(&VARS_UNDERO_NODE),
    Some(&VARS_UNDERP_NODE),
    None,
    Some(&VARS_UNDERR_NODE),
    Some(&VARS_UNDERS_NODE),
    None,
    Some(&VARS_UNDERU_NODE),
    Some(&VARS_UNDERV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_UNDERV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERV_CHILDREN),
    value: None,
};

pub static VARS_UNDERV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italiseds"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERVITALIZED_15030486633106066661)],
        &[(0b10010, &ENTRY_UNDERVITALIZEDS_7837775855116374233)],
        &[(0b01001, &ENTRY_UNDERVITALIZED_15030486633106066661)],
        &[(0b01001, &ENTRY_UNDERVITALIZEDS_7837775855116374233)],
    ],
    range: 8..=9,
};

static VARS_UNDERU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERU_CHILDREN),
    value: None,
};

pub static VARS_UNDERU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilisations"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilising"),
        dictgen::InsensitiveStr::Ascii("tilization"),
        dictgen::InsensitiveStr::Ascii("tilizations"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilized"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
        dictgen::InsensitiveStr::Ascii("tilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERUTILIZATION_5223118652036751167)],
        &[(0b10010, &ENTRY_UNDERUTILIZATIONS_2736156761561305874)],
        &[(0b10010, &ENTRY_UNDERUTILIZE_1115904263636509242)],
        &[(0b10010, &ENTRY_UNDERUTILIZED_6777172924330394476)],
        &[(0b10010, &ENTRY_UNDERUTILIZES_3826812380680667876)],
        &[(0b10010, &ENTRY_UNDERUTILIZING_13709312952006497089)],
        &[(0b01001, &ENTRY_UNDERUTILIZATION_5223118652036751167)],
        &[(0b01001, &ENTRY_UNDERUTILIZATIONS_2736156761561305874)],
        &[(0b01001, &ENTRY_UNDERUTILIZE_1115904263636509242)],
        &[(0b01001, &ENTRY_UNDERUTILIZED_6777172924330394476)],
        &[(0b01001, &ENTRY_UNDERUTILIZES_3826812380680667876)],
        &[(0b01001, &ENTRY_UNDERUTILIZING_13709312952006497089)],
    ],
    range: 6..=11,
};

static VARS_UNDERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERS_CHILDREN),
    value: None,
};

pub static VARS_UNDERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avior"),
        dictgen::InsensitiveStr::Ascii("aviors"),
        dictgen::InsensitiveStr::Ascii("aviour"),
        dictgen::InsensitiveStr::Ascii("aviours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNDERSAVIOR_7434958491263890564)],
        &[(0b00001, &ENTRY_UNDERSAVIORS_10984132115349151011)],
        &[(0b11010, &ENTRY_UNDERSAVIOR_7434958491263890564)],
        &[(0b11010, &ENTRY_UNDERSAVIORS_10984132115349151011)],
    ],
    range: 5..=7,
};

static VARS_UNDERR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERR_CHILDREN),
    value: None,
};

pub static VARS_UNDERR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealised"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealising"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealized"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
        dictgen::InsensitiveStr::Ascii("ealizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERREALIZE_7092158884515094974)],
        &[(0b10010, &ENTRY_UNDERREALIZED_18033081021006552359)],
        &[(0b10010, &ENTRY_UNDERREALIZES_2029819726682856248)],
        &[(0b10010, &ENTRY_UNDERREALIZING_17755667674781640335)],
        &[(0b01001, &ENTRY_UNDERREALIZE_7092158884515094974)],
        &[(0b01001, &ENTRY_UNDERREALIZED_18033081021006552359)],
        &[(0b01001, &ENTRY_UNDERREALIZES_2029819726682856248)],
        &[(0b01001, &ENTRY_UNDERREALIZING_17755667674781640335)],
    ],
    range: 6..=8,
};

static VARS_UNDERP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERP_CHILDREN),
    value: None,
};

pub static VARS_UNDERP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERPRIZE_5508380942697361246)],
        &[(0b10010, &ENTRY_UNDERPRIZED_10416331611131826895)],
        &[(0b10010, &ENTRY_UNDERPRIZES_6377465244834486670)],
        &[(0b10010, &ENTRY_UNDERPRIZING_17802343668144879352)],
        &[(0b01001, &ENTRY_UNDERPRIZE_5508380942697361246)],
        &[(0b01001, &ENTRY_UNDERPRIZED_10416331611131826895)],
        &[(0b01001, &ENTRY_UNDERPRIZES_6377465244834486670)],
        &[(0b01001, &ENTRY_UNDERPRIZING_17802343668144879352)],
    ],
    range: 4..=6,
};

static VARS_UNDERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERO_CHILDREN),
    value: None,
};

pub static VARS_UNDERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERORGANIZATION_7400455363911340000)],
        &[(0b10010, &ENTRY_UNDERORGANIZATIONS_10335581416606425325)],
        &[(0b01001, &ENTRY_UNDERORGANIZATION_7400455363911340000)],
        &[(0b01001, &ENTRY_UNDERORGANIZATIONS_10335581416606425325)],
        &[(0b10010, &ENTRY_UNDEROXIDIZE_6485083535977243452)],
        &[(0b10010, &ENTRY_UNDEROXIDIZED_9530283666542091132)],
        &[(0b10010, &ENTRY_UNDEROXIDIZES_11400908621570551704)],
        &[(0b10010, &ENTRY_UNDEROXIDIZING_7229227794588570973)],
        &[(0b01001, &ENTRY_UNDEROXIDIZE_6485083535977243452)],
        &[(0b01001, &ENTRY_UNDEROXIDIZED_9530283666542091132)],
        &[(0b01001, &ENTRY_UNDEROXIDIZES_11400908621570551704)],
        &[(0b01001, &ENTRY_UNDEROXIDIZING_7229227794588570973)],
    ],
    range: 6..=12,
};

static VARS_UNDERL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERL_CHILDREN),
    value: None,
};

pub static VARS_UNDERL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aborer"),
        dictgen::InsensitiveStr::Ascii("aborers"),
        dictgen::InsensitiveStr::Ascii("abourer"),
        dictgen::InsensitiveStr::Ascii("abourers"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNDERLABORER_3694933881204703688)],
        &[(0b00001, &ENTRY_UNDERLABORERS_9021923481724217322)],
        &[(0b11010, &ENTRY_UNDERLABORER_3694933881204703688)],
        &[(0b11010, &ENTRY_UNDERLABORERS_9021923481724217322)],
    ],
    range: 6..=8,
};

static VARS_UNDERG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERG_CHILDREN),
    value: None,
};

pub static VARS_UNDERG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oer"),
        dictgen::InsensitiveStr::Ascii("ore"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNDERGOER_9429829714211980631)],
        &[(0b11010, &ENTRY_UNDERGOER_9429829714211980631)],
    ],
    range: 3..=3,
};

static VARS_UNDERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERE_CHILDREN),
    value: None,
};

pub static VARS_UNDERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasised"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasising"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasized"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("mphasizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDEREMPHASIZE_16005848787441654782)],
        &[(0b10010, &ENTRY_UNDEREMPHASIZED_13287064872491391347)],
        &[(0b10010, &ENTRY_UNDEREMPHASIZES_12584850145350891996)],
        &[(0b10010, &ENTRY_UNDEREMPHASIZING_6499426514394882956)],
        &[(0b01001, &ENTRY_UNDEREMPHASIZE_16005848787441654782)],
        &[(0b01001, &ENTRY_UNDEREMPHASIZED_13287064872491391347)],
        &[(0b01001, &ENTRY_UNDEREMPHASIZES_12584850145350891996)],
        &[(0b01001, &ENTRY_UNDEREMPHASIZING_6499426514394882956)],
    ],
    range: 8..=10,
};

static VARS_UNDERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDERC_CHILDREN),
    value: None,
};

pub static VARS_UNDERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apitalisation"),
        dictgen::InsensitiveStr::Ascii("apitalisations"),
        dictgen::InsensitiveStr::Ascii("apitalise"),
        dictgen::InsensitiveStr::Ascii("apitalised"),
        dictgen::InsensitiveStr::Ascii("apitalises"),
        dictgen::InsensitiveStr::Ascii("apitalising"),
        dictgen::InsensitiveStr::Ascii("apitalization"),
        dictgen::InsensitiveStr::Ascii("apitalizations"),
        dictgen::InsensitiveStr::Ascii("apitalize"),
        dictgen::InsensitiveStr::Ascii("apitalized"),
        dictgen::InsensitiveStr::Ascii("apitalizes"),
        dictgen::InsensitiveStr::Ascii("apitalizing"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olorings"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olourings"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDERCAPITALIZATION_10660193274275293366)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZATIONS_15182325328537661657)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZE_16023499620792084738)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZED_4628390293054794377)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZES_3303618473551057315)],
        &[(0b10010, &ENTRY_UNDERCAPITALIZING_16232808968195990904)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZATION_10660193274275293366)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZATIONS_15182325328537661657)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZE_16023499620792084738)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZED_4628390293054794377)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZES_3303618473551057315)],
        &[(0b01001, &ENTRY_UNDERCAPITALIZING_16232808968195990904)],
        &[(0b00001, &ENTRY_UNDERCOLOR_8519534420778344085)],
        &[(0b00001, &ENTRY_UNDERCOLORED_17422644742945532202)],
        &[(0b00001, &ENTRY_UNDERCOLORING_7781389003709580079)],
        &[(0b00001, &ENTRY_UNDERCOLORINGS_10087184255355441121)],
        &[(0b00001, &ENTRY_UNDERCOLORS_6190629777654495448)],
        &[(0b11010, &ENTRY_UNDERCOLOR_8519534420778344085)],
        &[(0b11010, &ENTRY_UNDERCOLORED_17422644742945532202)],
        &[(0b11010, &ENTRY_UNDERCOLORING_7781389003709580079)],
        &[(0b11010, &ENTRY_UNDERCOLORINGS_10087184255355441121)],
        &[(0b11010, &ENTRY_UNDERCOLORS_6190629777654495448)],
    ],
    range: 4..=14,
};

static VARS_UNDEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDEN_CHILDREN),
    value: None,
};

pub static VARS_UNDEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ominationalise"),
        dictgen::InsensitiveStr::Ascii("ominationalises"),
        dictgen::InsensitiveStr::Ascii("ominationalize"),
        dictgen::InsensitiveStr::Ascii("ominationalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDENOMINATIONALIZE_6740738141836952680)],
        &[(0b10010, &ENTRY_UNDENOMINATIONALIZES_3120796019381704993)],
        &[(0b01001, &ENTRY_UNDENOMINATIONALIZE_6740738141836952680)],
        &[(0b01001, &ENTRY_UNDENOMINATIONALIZES_3120796019381704993)],
    ],
    range: 14..=15,
};

static VARS_UNDEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDEM_CHILDREN),
    value: None,
};

pub static VARS_UNDEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnetisable"),
        dictgen::InsensitiveStr::Ascii("agnetisables"),
        dictgen::InsensitiveStr::Ascii("agnetizable"),
        dictgen::InsensitiveStr::Ascii("agnetizables"),
        dictgen::InsensitiveStr::Ascii("ocratisation"),
        dictgen::InsensitiveStr::Ascii("ocratise"),
        dictgen::InsensitiveStr::Ascii("ocratised"),
        dictgen::InsensitiveStr::Ascii("ocratises"),
        dictgen::InsensitiveStr::Ascii("ocratising"),
        dictgen::InsensitiveStr::Ascii("ocratization"),
        dictgen::InsensitiveStr::Ascii("ocratize"),
        dictgen::InsensitiveStr::Ascii("ocratized"),
        dictgen::InsensitiveStr::Ascii("ocratizes"),
        dictgen::InsensitiveStr::Ascii("ocratizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNDEMAGNETIZABLE_15252782349141238446)],
        &[(0b10010, &ENTRY_UNDEMAGNETIZABLES_5686795504114325763)],
        &[(0b01001, &ENTRY_UNDEMAGNETIZABLE_15252782349141238446)],
        &[(0b01001, &ENTRY_UNDEMAGNETIZABLES_5686795504114325763)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZATION_1985548670847944255)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZE_1034629020769539043)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZED_2117183159769210163)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZES_5725888909225905299)],
        &[(0b10010, &ENTRY_UNDEMOCRATIZING_4527096256498077472)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZATION_1985548670847944255)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZE_1034629020769539043)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZED_2117183159769210163)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZES_5725888909225905299)],
        &[(0b01001, &ENTRY_UNDEMOCRATIZING_4527096256498077472)],
    ],
    range: 8..=12,
};

static VARS_UNDEF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNDEF_CHILDREN),
    value: None,
};

pub static VARS_UNDEF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ence"),
        dictgen::InsensitiveStr::Ascii("ences"),
        dictgen::InsensitiveStr::Ascii("ense"),
        dictgen::InsensitiveStr::Ascii("enses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNDEFENSE_1506818606399848606)],
        &[(0b11010, &ENTRY_UNDEFENSES_5387761130135332933)],
        &[(0b00001, &ENTRY_UNDEFENSE_1506818606399848606)],
        &[(0b00001, &ENTRY_UNDEFENSES_5387761130135332933)],
    ],
    range: 4..=5,
};

static VARS_UNC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNC_CHILDREN),
    value: None,
};

static VARS_UNC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_UNCA_NODE),
    None,
    None,
    None,
    Some(&VARS_UNCE_NODE),
    None,
    None,
    Some(&VARS_UNCH_NODE),
    Some(&VARS_UNCI_NODE),
    None,
    None,
    Some(&VARS_UNCL_NODE),
    None,
    None,
    Some(&VARS_UNCO_NODE),
    None,
    None,
    Some(&VARS_UNCR_NODE),
    None,
    None,
    Some(&VARS_UNCU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNCU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCU_CHILDREN),
    value: None,
};

pub static VARS_UNCU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rricularised"),
        dictgen::InsensitiveStr::Ascii("rriculariseds"),
        dictgen::InsensitiveStr::Ascii("rricularized"),
        dictgen::InsensitiveStr::Ascii("rricularizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCURRICULARIZED_1510394198207258931)],
        &[(0b10010, &ENTRY_UNCURRICULARIZEDS_8615810342283576503)],
        &[(0b01001, &ENTRY_UNCURRICULARIZED_1510394198207258931)],
        &[(0b01001, &ENTRY_UNCURRICULARIZEDS_8615810342283576503)],
    ],
    range: 12..=13,
};

static VARS_UNCR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCR_CHILDREN),
    value: None,
};

pub static VARS_UNCR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iticisable"),
        dictgen::InsensitiveStr::Ascii("iticisabler"),
        dictgen::InsensitiveStr::Ascii("iticisables"),
        dictgen::InsensitiveStr::Ascii("iticisablest"),
        dictgen::InsensitiveStr::Ascii("iticisably"),
        dictgen::InsensitiveStr::Ascii("iticised"),
        dictgen::InsensitiveStr::Ascii("iticising"),
        dictgen::InsensitiveStr::Ascii("iticisingly"),
        dictgen::InsensitiveStr::Ascii("iticizable"),
        dictgen::InsensitiveStr::Ascii("iticizabler"),
        dictgen::InsensitiveStr::Ascii("iticizables"),
        dictgen::InsensitiveStr::Ascii("iticizablest"),
        dictgen::InsensitiveStr::Ascii("iticizably"),
        dictgen::InsensitiveStr::Ascii("iticized"),
        dictgen::InsensitiveStr::Ascii("iticizing"),
        dictgen::InsensitiveStr::Ascii("iticizingly"),
        dictgen::InsensitiveStr::Ascii("ystallisabilities"),
        dictgen::InsensitiveStr::Ascii("ystallisability"),
        dictgen::InsensitiveStr::Ascii("ystallisable"),
        dictgen::InsensitiveStr::Ascii("ystallisabler"),
        dictgen::InsensitiveStr::Ascii("ystallisables"),
        dictgen::InsensitiveStr::Ascii("ystallisablest"),
        dictgen::InsensitiveStr::Ascii("ystallised"),
        dictgen::InsensitiveStr::Ascii("ystallizabilities"),
        dictgen::InsensitiveStr::Ascii("ystallizability"),
        dictgen::InsensitiveStr::Ascii("ystallizable"),
        dictgen::InsensitiveStr::Ascii("ystallizabler"),
        dictgen::InsensitiveStr::Ascii("ystallizables"),
        dictgen::InsensitiveStr::Ascii("ystallizablest"),
        dictgen::InsensitiveStr::Ascii("ystallized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCRITICIZABLE_11373327800791333419)],
        &[(0b10010, &ENTRY_UNCRITICIZABLER_12547491203255935586)],
        &[(0b10010, &ENTRY_UNCRITICIZABLES_12700073615320281916)],
        &[(0b10010, &ENTRY_UNCRITICIZABLEST_4607318644536802423)],
        &[(0b10010, &ENTRY_UNCRITICIZABLY_5679899333014793182)],
        &[(0b10010, &ENTRY_UNCRITICIZED_2911120484028704139)],
        &[(0b10010, &ENTRY_UNCRITICIZING_11997178515445821682)],
        &[(0b10010, &ENTRY_UNCRITICIZINGLY_8633111293350941138)],
        &[(0b01001, &ENTRY_UNCRITICIZABLE_11373327800791333419)],
        &[(0b01001, &ENTRY_UNCRITICIZABLER_12547491203255935586)],
        &[(0b01001, &ENTRY_UNCRITICIZABLES_12700073615320281916)],
        &[(0b01001, &ENTRY_UNCRITICIZABLEST_4607318644536802423)],
        &[(0b01001, &ENTRY_UNCRITICIZABLY_5679899333014793182)],
        &[(0b01001, &ENTRY_UNCRITICIZED_2911120484028704139)],
        &[(0b01001, &ENTRY_UNCRITICIZING_11997178515445821682)],
        &[(0b01001, &ENTRY_UNCRITICIZINGLY_8633111293350941138)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABILITIES_17690728856956585473)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABILITY_11525239910591863121)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABLE_896206698167723642)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABLER_16849085510473534176)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABLES_5618943405184002759)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZABLEST_5988044069876666615)],
        &[(0b10010, &ENTRY_UNCRYSTALLIZED_2777096876542409868)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABILITIES_17690728856956585473)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABILITY_11525239910591863121)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABLE_896206698167723642)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABLER_16849085510473534176)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABLES_5618943405184002759)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZABLEST_5988044069876666615)],
        &[(0b01001, &ENTRY_UNCRYSTALLIZED_2777096876542409868)],
    ],
    range: 8..=17,
};

static VARS_UNCO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCO_CHILDREN),
    value: None,
};

pub static VARS_UNCO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gnisable"),
        dictgen::InsensitiveStr::Ascii("gnizable"),
        dictgen::InsensitiveStr::Ascii("lonise"),
        dictgen::InsensitiveStr::Ascii("lonised"),
        dictgen::InsensitiveStr::Ascii("lonises"),
        dictgen::InsensitiveStr::Ascii("lonising"),
        dictgen::InsensitiveStr::Ascii("lonize"),
        dictgen::InsensitiveStr::Ascii("lonized"),
        dictgen::InsensitiveStr::Ascii("lonizes"),
        dictgen::InsensitiveStr::Ascii("lonizing"),
        dictgen::InsensitiveStr::Ascii("lorable"),
        dictgen::InsensitiveStr::Ascii("lorabler"),
        dictgen::InsensitiveStr::Ascii("lorables"),
        dictgen::InsensitiveStr::Ascii("lorablest"),
        dictgen::InsensitiveStr::Ascii("lorablier"),
        dictgen::InsensitiveStr::Ascii("lorablies"),
        dictgen::InsensitiveStr::Ascii("lorabliest"),
        dictgen::InsensitiveStr::Ascii("lorably"),
        dictgen::InsensitiveStr::Ascii("lored"),
        dictgen::InsensitiveStr::Ascii("loredder"),
        dictgen::InsensitiveStr::Ascii("loreddest"),
        dictgen::InsensitiveStr::Ascii("loredlier"),
        dictgen::InsensitiveStr::Ascii("loredliest"),
        dictgen::InsensitiveStr::Ascii("loredly"),
        dictgen::InsensitiveStr::Ascii("loredness"),
        dictgen::InsensitiveStr::Ascii("lorednesses"),
        dictgen::InsensitiveStr::Ascii("loreds"),
        dictgen::InsensitiveStr::Ascii("lourable"),
        dictgen::InsensitiveStr::Ascii("lourabler"),
        dictgen::InsensitiveStr::Ascii("lourables"),
        dictgen::InsensitiveStr::Ascii("lourablest"),
        dictgen::InsensitiveStr::Ascii("lourablier"),
        dictgen::InsensitiveStr::Ascii("lourablies"),
        dictgen::InsensitiveStr::Ascii("lourabliest"),
        dictgen::InsensitiveStr::Ascii("lourably"),
        dictgen::InsensitiveStr::Ascii("loured"),
        dictgen::InsensitiveStr::Ascii("louredder"),
        dictgen::InsensitiveStr::Ascii("loureddest"),
        dictgen::InsensitiveStr::Ascii("louredlier"),
        dictgen::InsensitiveStr::Ascii("louredliest"),
        dictgen::InsensitiveStr::Ascii("louredly"),
        dictgen::InsensitiveStr::Ascii("louredness"),
        dictgen::InsensitiveStr::Ascii("lourednesses"),
        dictgen::InsensitiveStr::Ascii("loureds"),
        dictgen::InsensitiveStr::Ascii("ncerted"),
        dictgen::InsensitiveStr::Ascii("ncreted"),
        dictgen::InsensitiveStr::Ascii("nventionalise"),
        dictgen::InsensitiveStr::Ascii("nventionalises"),
        dictgen::InsensitiveStr::Ascii("nventionalize"),
        dictgen::InsensitiveStr::Ascii("nventionalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCOGNIZABLE_8427011542426523053)],
        &[(0b01001, &ENTRY_UNCOGNIZABLE_8427011542426523053)],
        &[(0b10010, &ENTRY_UNCOLONIZE_4719662676234790116)],
        &[(0b10010, &ENTRY_UNCOLONIZED_14464259688836318286)],
        &[(0b10010, &ENTRY_UNCOLONIZES_9719326327721062003)],
        &[(0b10010, &ENTRY_UNCOLONIZING_15664887216370082580)],
        &[(0b01001, &ENTRY_UNCOLONIZE_4719662676234790116)],
        &[(0b01001, &ENTRY_UNCOLONIZED_14464259688836318286)],
        &[(0b01001, &ENTRY_UNCOLONIZES_9719326327721062003)],
        &[(0b01001, &ENTRY_UNCOLONIZING_15664887216370082580)],
        &[(0b00001, &ENTRY_UNCOLORABLE_16859002938981914415)],
        &[(0b00001, &ENTRY_UNCOLORABLER_1677263340221600893)],
        &[(0b00001, &ENTRY_UNCOLORABLES_3510625143099969360)],
        &[(0b00001, &ENTRY_UNCOLORABLEST_7640890717461053308)],
        &[(0b00001, &ENTRY_UNCOLORABLIER_15894133128738876679)],
        &[(0b00001, &ENTRY_UNCOLORABLIES_11097679658499545820)],
        &[(0b00001, &ENTRY_UNCOLORABLIEST_11422798475250273761)],
        &[(0b00001, &ENTRY_UNCOLORABLY_6941577112469631446)],
        &[(0b11001, &ENTRY_UNCOLORED_11161437304186875893)],
        &[(0b11001, &ENTRY_UNCOLOREDDER_44322368202115976)],
        &[(0b11001, &ENTRY_UNCOLOREDDEST_15878875459057574341)],
        &[(0b00001, &ENTRY_UNCOLOREDLIER_6703103262670401501)],
        &[(0b00001, &ENTRY_UNCOLOREDLIEST_12675741818469230732)],
        &[(0b00001, &ENTRY_UNCOLOREDLY_16713739233776863755)],
        &[(0b00001, &ENTRY_UNCOLOREDNESS_16507195530617886306)],
        &[(0b00001, &ENTRY_UNCOLOREDNESSES_7712224291050878796)],
        &[(0b11001, &ENTRY_UNCOLOREDS_8597280883372836480)],
        &[(0b11010, &ENTRY_UNCOLORABLE_16859002938981914415)],
        &[(0b11010, &ENTRY_UNCOLORABLER_1677263340221600893)],
        &[(0b11010, &ENTRY_UNCOLORABLES_3510625143099969360)],
        &[(0b11010, &ENTRY_UNCOLORABLEST_7640890717461053308)],
        &[(0b11010, &ENTRY_UNCOLORABLIER_15894133128738876679)],
        &[(0b11010, &ENTRY_UNCOLORABLIES_11097679658499545820)],
        &[(0b11010, &ENTRY_UNCOLORABLIEST_11422798475250273761)],
        &[(0b11010, &ENTRY_UNCOLORABLY_6941577112469631446)],
        &[(0b11010, &ENTRY_UNCOLORED_11161437304186875893)],
        &[(0b11010, &ENTRY_UNCOLOREDDER_44322368202115976)],
        &[(0b11010, &ENTRY_UNCOLOREDDEST_15878875459057574341)],
        &[(0b11010, &ENTRY_UNCOLOREDLIER_6703103262670401501)],
        &[(0b11010, &ENTRY_UNCOLOREDLIEST_12675741818469230732)],
        &[(0b11010, &ENTRY_UNCOLOREDLY_16713739233776863755)],
        &[(0b11010, &ENTRY_UNCOLOREDNESS_16507195530617886306)],
        &[(0b11010, &ENTRY_UNCOLOREDNESSES_7712224291050878796)],
        &[(0b11010, &ENTRY_UNCOLOREDS_8597280883372836480)],
        &[(0b00001, &ENTRY_UNCONCERTED_6095497230856593489)],
        &[(0b11010, &ENTRY_UNCONCERTED_6095497230856593489)],
        &[(0b10010, &ENTRY_UNCONVENTIONALIZE_7485202036270814256)],
        &[(0b10010, &ENTRY_UNCONVENTIONALIZES_1804902019330246754)],
        &[(0b01001, &ENTRY_UNCONVENTIONALIZE_7485202036270814256)],
        &[(0b01001, &ENTRY_UNCONVENTIONALIZES_1804902019330246754)],
    ],
    range: 5..=14,
};

static VARS_UNCL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCL_CHILDREN),
    value: None,
};

pub static VARS_UNCL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ericalise"),
        dictgen::InsensitiveStr::Ascii("ericalises"),
        dictgen::InsensitiveStr::Ascii("ericalize"),
        dictgen::InsensitiveStr::Ascii("ericalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCLERICALIZE_5058403399765937609)],
        &[(0b10010, &ENTRY_UNCLERICALIZES_8000982562629252294)],
        &[(0b01001, &ENTRY_UNCLERICALIZE_5058403399765937609)],
        &[(0b01001, &ENTRY_UNCLERICALIZES_8000982562629252294)],
    ],
    range: 9..=10,
};

static VARS_UNCI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCI_CHILDREN),
    value: None,
};

pub static VARS_UNCI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rcularised"),
        dictgen::InsensitiveStr::Ascii("rcularisedder"),
        dictgen::InsensitiveStr::Ascii("rculariseddest"),
        dictgen::InsensitiveStr::Ascii("rculariseds"),
        dictgen::InsensitiveStr::Ascii("rcularized"),
        dictgen::InsensitiveStr::Ascii("rcularizedder"),
        dictgen::InsensitiveStr::Ascii("rcularizeddest"),
        dictgen::InsensitiveStr::Ascii("rcularizeds"),
        dictgen::InsensitiveStr::Ascii("vilisable"),
        dictgen::InsensitiveStr::Ascii("vilisabler"),
        dictgen::InsensitiveStr::Ascii("vilisables"),
        dictgen::InsensitiveStr::Ascii("vilisablest"),
        dictgen::InsensitiveStr::Ascii("vilise"),
        dictgen::InsensitiveStr::Ascii("vilised"),
        dictgen::InsensitiveStr::Ascii("vilisedly"),
        dictgen::InsensitiveStr::Ascii("vilisedness"),
        dictgen::InsensitiveStr::Ascii("vilises"),
        dictgen::InsensitiveStr::Ascii("vilizable"),
        dictgen::InsensitiveStr::Ascii("vilizabler"),
        dictgen::InsensitiveStr::Ascii("vilizables"),
        dictgen::InsensitiveStr::Ascii("vilizablest"),
        dictgen::InsensitiveStr::Ascii("vilize"),
        dictgen::InsensitiveStr::Ascii("vilized"),
        dictgen::InsensitiveStr::Ascii("vilizedly"),
        dictgen::InsensitiveStr::Ascii("vilizedness"),
        dictgen::InsensitiveStr::Ascii("vilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCIRCULARIZED_1673876733486569108)],
        &[(0b10010, &ENTRY_UNCIRCULARIZEDDER_13401377351716086368)],
        &[(0b10010, &ENTRY_UNCIRCULARIZEDDEST_9951597685170363487)],
        &[(0b10010, &ENTRY_UNCIRCULARIZEDS_1250844431562273063)],
        &[(0b01001, &ENTRY_UNCIRCULARIZED_1673876733486569108)],
        &[(0b01001, &ENTRY_UNCIRCULARIZEDDER_13401377351716086368)],
        &[(0b01001, &ENTRY_UNCIRCULARIZEDDEST_9951597685170363487)],
        &[(0b01001, &ENTRY_UNCIRCULARIZEDS_1250844431562273063)],
        &[(0b10010, &ENTRY_UNCIVILIZABLE_5359864439117880170)],
        &[(0b10010, &ENTRY_UNCIVILIZABLER_5349352586984667487)],
        &[(0b10010, &ENTRY_UNCIVILIZABLES_5534726098220309871)],
        &[(0b10010, &ENTRY_UNCIVILIZABLEST_7329790362151161087)],
        &[(0b10010, &ENTRY_UNCIVILIZE_16379895937239654425)],
        &[(0b10010, &ENTRY_UNCIVILIZED_7166539918987564819)],
        &[(0b10010, &ENTRY_UNCIVILIZEDLY_13183249970870160815)],
        &[(0b10010, &ENTRY_UNCIVILIZEDNESS_13286745087730550691)],
        &[(0b10010, &ENTRY_UNCIVILIZES_4114315705302110845)],
        &[(0b01001, &ENTRY_UNCIVILIZABLE_5359864439117880170)],
        &[(0b01001, &ENTRY_UNCIVILIZABLER_5349352586984667487)],
        &[(0b01001, &ENTRY_UNCIVILIZABLES_5534726098220309871)],
        &[(0b01001, &ENTRY_UNCIVILIZABLEST_7329790362151161087)],
        &[(0b01001, &ENTRY_UNCIVILIZE_16379895937239654425)],
        &[(0b01001, &ENTRY_UNCIVILIZED_7166539918987564819)],
        &[(0b01001, &ENTRY_UNCIVILIZEDLY_13183249970870160815)],
        &[(0b01001, &ENTRY_UNCIVILIZEDNESS_13286745087730550691)],
        &[(0b01001, &ENTRY_UNCIVILIZES_4114315705302110845)],
    ],
    range: 6..=14,
};

static VARS_UNCH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCH_CHILDREN),
    value: None,
};

pub static VARS_UNCH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aracterised"),
        dictgen::InsensitiveStr::Ascii("aracterisedder"),
        dictgen::InsensitiveStr::Ascii("aracteriseddest"),
        dictgen::InsensitiveStr::Ascii("aracterized"),
        dictgen::InsensitiveStr::Ascii("aracterizedder"),
        dictgen::InsensitiveStr::Ascii("aracterizeddest"),
        dictgen::InsensitiveStr::Ascii("astisable"),
        dictgen::InsensitiveStr::Ascii("astised"),
        dictgen::InsensitiveStr::Ascii("astizable"),
        dictgen::InsensitiveStr::Ascii("astized"),
        dictgen::InsensitiveStr::Ascii("loridised"),
        dictgen::InsensitiveStr::Ascii("loridiseds"),
        dictgen::InsensitiveStr::Ascii("loridized"),
        dictgen::InsensitiveStr::Ascii("loridizeds"),
        dictgen::InsensitiveStr::Ascii("ristianise"),
        dictgen::InsensitiveStr::Ascii("ristianised"),
        dictgen::InsensitiveStr::Ascii("ristianises"),
        dictgen::InsensitiveStr::Ascii("ristianising"),
        dictgen::InsensitiveStr::Ascii("ristianize"),
        dictgen::InsensitiveStr::Ascii("ristianized"),
        dictgen::InsensitiveStr::Ascii("ristianizes"),
        dictgen::InsensitiveStr::Ascii("ristianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCHARACTERIZED_16956353213909858293)],
        &[(0b10010, &ENTRY_UNCHARACTERIZEDDER_9630905361449944494)],
        &[(0b10010, &ENTRY_UNCHARACTERIZEDDEST_12996144895873850714)],
        &[(0b01001, &ENTRY_UNCHARACTERIZED_16956353213909858293)],
        &[(0b01001, &ENTRY_UNCHARACTERIZEDDER_9630905361449944494)],
        &[(0b01001, &ENTRY_UNCHARACTERIZEDDEST_12996144895873850714)],
        &[(0b10010, &ENTRY_UNCHASTIZABLE_9875729189061084670)],
        &[(0b10010, &ENTRY_UNCHASTIZED_4193981014376295283)],
        &[(0b01001, &ENTRY_UNCHASTIZABLE_9875729189061084670)],
        &[(0b01001, &ENTRY_UNCHASTIZED_4193981014376295283)],
        &[(0b10010, &ENTRY_UNCHLORIDIZED_16671439068894580937)],
        &[(0b10010, &ENTRY_UNCHLORIDIZEDS_14218178409370978541)],
        &[(0b01001, &ENTRY_UNCHLORIDIZED_16671439068894580937)],
        &[(0b01001, &ENTRY_UNCHLORIDIZEDS_14218178409370978541)],
        &[(0b10010, &ENTRY_UNCHRISTIANIZE_60148917993740076)],
        &[(0b10010, &ENTRY_UNCHRISTIANIZED_13080855627488192760)],
        &[(0b10010, &ENTRY_UNCHRISTIANIZES_9247340614604210077)],
        &[(0b10010, &ENTRY_UNCHRISTIANIZING_16239590731316126727)],
        &[(0b01001, &ENTRY_UNCHRISTIANIZE_60148917993740076)],
        &[(0b01001, &ENTRY_UNCHRISTIANIZED_13080855627488192760)],
        &[(0b01001, &ENTRY_UNCHRISTIANIZES_9247340614604210077)],
        &[(0b01001, &ENTRY_UNCHRISTIANIZING_16239590731316126727)],
    ],
    range: 7..=15,
};

static VARS_UNCE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCE_CHILDREN),
    value: None,
};

pub static VARS_UNCE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lestialised"),
        dictgen::InsensitiveStr::Ascii("lestialiseds"),
        dictgen::InsensitiveStr::Ascii("lestialized"),
        dictgen::InsensitiveStr::Ascii("lestializeds"),
        dictgen::InsensitiveStr::Ascii("nter"),
        dictgen::InsensitiveStr::Ascii("ntralised"),
        dictgen::InsensitiveStr::Ascii("ntralized"),
        dictgen::InsensitiveStr::Ascii("ntre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNCELESTIALIZED_17943151837268803496)],
        &[(0b10010, &ENTRY_UNCELESTIALIZEDS_2449557772093094129)],
        &[(0b01001, &ENTRY_UNCELESTIALIZED_17943151837268803496)],
        &[(0b01001, &ENTRY_UNCELESTIALIZEDS_2449557772093094129)],
        &[(0b00001, &ENTRY_UNCENTER_15807123308053109883)],
        &[(0b10010, &ENTRY_UNCENTRALIZED_3375219947813958573)],
        &[(0b01001, &ENTRY_UNCENTRALIZED_3375219947813958573)],
        &[(0b11010, &ENTRY_UNCENTER_15807123308053109883)],
    ],
    range: 4..=12,
};

static VARS_UNCA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNCA_CHILDREN),
    value: None,
};

pub static VARS_UNCA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nceled"),
        dictgen::InsensitiveStr::Ascii("nceledder"),
        dictgen::InsensitiveStr::Ascii("nceleddest"),
        dictgen::InsensitiveStr::Ascii("ndor"),
        dictgen::InsensitiveStr::Ascii("ndour"),
        dictgen::InsensitiveStr::Ascii("nonisation"),
        dictgen::InsensitiveStr::Ascii("nonise"),
        dictgen::InsensitiveStr::Ascii("nonised"),
        dictgen::InsensitiveStr::Ascii("nonises"),
        dictgen::InsensitiveStr::Ascii("nonising"),
        dictgen::InsensitiveStr::Ascii("nonization"),
        dictgen::InsensitiveStr::Ascii("nonize"),
        dictgen::InsensitiveStr::Ascii("nonized"),
        dictgen::InsensitiveStr::Ascii("nonizes"),
        dictgen::InsensitiveStr::Ascii("nonizing"),
        dictgen::InsensitiveStr::Ascii("ntonised"),
        dictgen::InsensitiveStr::Ascii("ntoniseds"),
        dictgen::InsensitiveStr::Ascii("ntonized"),
        dictgen::InsensitiveStr::Ascii("ntonizeds"),
        dictgen::InsensitiveStr::Ascii("pitalised"),
        dictgen::InsensitiveStr::Ascii("pitalisedder"),
        dictgen::InsensitiveStr::Ascii("pitaliseddest"),
        dictgen::InsensitiveStr::Ascii("pitalized"),
        dictgen::InsensitiveStr::Ascii("pitalizedder"),
        dictgen::InsensitiveStr::Ascii("pitalizeddest"),
        dictgen::InsensitiveStr::Ascii("ramelised"),
        dictgen::InsensitiveStr::Ascii("ramelized"),
        dictgen::InsensitiveStr::Ascii("techised"),
        dictgen::InsensitiveStr::Ascii("techisedness"),
        dictgen::InsensitiveStr::Ascii("techiseds"),
        dictgen::InsensitiveStr::Ascii("techized"),
        dictgen::InsensitiveStr::Ascii("techizedness"),
        dictgen::InsensitiveStr::Ascii("techizeds"),
        dictgen::InsensitiveStr::Ascii("tegorised"),
        dictgen::InsensitiveStr::Ascii("tegorisedder"),
        dictgen::InsensitiveStr::Ascii("tegoriseddest"),
        dictgen::InsensitiveStr::Ascii("tegorized"),
        dictgen::InsensitiveStr::Ascii("tegorizedder"),
        dictgen::InsensitiveStr::Ascii("tegorizeddest"),
        dictgen::InsensitiveStr::Ascii("tholicise"),
        dictgen::InsensitiveStr::Ascii("tholicised"),
        dictgen::InsensitiveStr::Ascii("tholicises"),
        dictgen::InsensitiveStr::Ascii("tholicising"),
        dictgen::InsensitiveStr::Ascii("tholicize"),
        dictgen::InsensitiveStr::Ascii("tholicized"),
        dictgen::InsensitiveStr::Ascii("tholicizes"),
        dictgen::InsensitiveStr::Ascii("tholicizing"),
        dictgen::InsensitiveStr::Ascii("uterised"),
        dictgen::InsensitiveStr::Ascii("uteriseds"),
        dictgen::InsensitiveStr::Ascii("uterized"),
        dictgen::InsensitiveStr::Ascii("uterizeds"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNCANCELED_14881575187258887119)],
        &[(0b00001, &ENTRY_UNCANCELEDDER_846969059949847342)],
        &[(0b00001, &ENTRY_UNCANCELEDDEST_16688600251952129306)],
        &[(0b00001, &ENTRY_UNCANDOR_1117487908276698433)],
        &[(0b11010, &ENTRY_UNCANDOR_1117487908276698433)],
        &[(0b10010, &ENTRY_UNCANONIZATION_17424198936114457720)],
        &[(0b10010, &ENTRY_UNCANONIZE_8078618209055157420)],
        &[(0b10010, &ENTRY_UNCANONIZED_5538989722513762511)],
        &[(0b10010, &ENTRY_UNCANONIZES_12153715475418673041)],
        &[(0b10010, &ENTRY_UNCANONIZING_3397483964901532622)],
        &[(0b01001, &ENTRY_UNCANONIZATION_17424198936114457720)],
        &[(0b01001, &ENTRY_UNCANONIZE_8078618209055157420)],
        &[(0b01001, &ENTRY_UNCANONIZED_5538989722513762511)],
        &[(0b01001, &ENTRY_UNCANONIZES_12153715475418673041)],
        &[(0b01001, &ENTRY_UNCANONIZING_3397483964901532622)],
        &[(0b10010, &ENTRY_UNCANTONIZED_13456997538693547290)],
        &[(0b10010, &ENTRY_UNCANTONIZEDS_8748104113894653041)],
        &[(0b01001, &ENTRY_UNCANTONIZED_13456997538693547290)],
        &[(0b01001, &ENTRY_UNCANTONIZEDS_8748104113894653041)],
        &[(0b10010, &ENTRY_UNCAPITALIZED_15771287396524776391)],
        &[(0b10010, &ENTRY_UNCAPITALIZEDDER_11516986249977719685)],
        &[(0b10010, &ENTRY_UNCAPITALIZEDDEST_3372925540955398768)],
        &[(0b01001, &ENTRY_UNCAPITALIZED_15771287396524776391)],
        &[(0b01001, &ENTRY_UNCAPITALIZEDDER_11516986249977719685)],
        &[(0b01001, &ENTRY_UNCAPITALIZEDDEST_3372925540955398768)],
        &[(0b10010, &ENTRY_UNCARAMELIZED_14866858801643238047)],
        &[(0b01001, &ENTRY_UNCARAMELIZED_14866858801643238047)],
        &[(0b10010, &ENTRY_UNCATECHIZED_12604807844777819037)],
        &[(0b10010, &ENTRY_UNCATECHIZEDNESS_15422372585260862674)],
        &[(0b10010, &ENTRY_UNCATECHIZEDS_13859045064739112709)],
        &[(0b01001, &ENTRY_UNCATECHIZED_12604807844777819037)],
        &[(0b01001, &ENTRY_UNCATECHIZEDNESS_15422372585260862674)],
        &[(0b01001, &ENTRY_UNCATECHIZEDS_13859045064739112709)],
        &[(0b10010, &ENTRY_UNCATEGORIZED_12671663981711527617)],
        &[(0b10010, &ENTRY_UNCATEGORIZEDDER_15434842518722062137)],
        &[(0b10010, &ENTRY_UNCATEGORIZEDDEST_1757102059002802404)],
        &[(0b01001, &ENTRY_UNCATEGORIZED_12671663981711527617)],
        &[(0b01001, &ENTRY_UNCATEGORIZEDDER_15434842518722062137)],
        &[(0b01001, &ENTRY_UNCATEGORIZEDDEST_1757102059002802404)],
        &[(0b10010, &ENTRY_UNCATHOLICIZE_8425737943401304561)],
        &[(0b10010, &ENTRY_UNCATHOLICIZED_17722391494998523342)],
        &[(0b10010, &ENTRY_UNCATHOLICIZES_8958496403317373578)],
        &[(0b10010, &ENTRY_UNCATHOLICIZING_9453674520447775815)],
        &[(0b01001, &ENTRY_UNCATHOLICIZE_8425737943401304561)],
        &[(0b01001, &ENTRY_UNCATHOLICIZED_17722391494998523342)],
        &[(0b01001, &ENTRY_UNCATHOLICIZES_8958496403317373578)],
        &[(0b01001, &ENTRY_UNCATHOLICIZING_9453674520447775815)],
        &[(0b10010, &ENTRY_UNCAUTERIZED_13512404213504423195)],
        &[(0b10010, &ENTRY_UNCAUTERIZEDS_10677799308952420016)],
        &[(0b01001, &ENTRY_UNCAUTERIZED_13512404213504423195)],
        &[(0b01001, &ENTRY_UNCAUTERIZEDS_10677799308952420016)],
    ],
    range: 4..=13,
};

static VARS_UNB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNB_CHILDREN),
    value: None,
};

pub static VARS_UNB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptised"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptising"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptized"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
        dictgen::InsensitiveStr::Ascii("aptizing"),
        dictgen::InsensitiveStr::Ascii("arbarise"),
        dictgen::InsensitiveStr::Ascii("arbarised"),
        dictgen::InsensitiveStr::Ascii("arbarising"),
        dictgen::InsensitiveStr::Ascii("arbarize"),
        dictgen::InsensitiveStr::Ascii("arbarized"),
        dictgen::InsensitiveStr::Ascii("arbarizing"),
        dictgen::InsensitiveStr::Ascii("arricaded"),
        dictgen::InsensitiveStr::Ascii("arricadoed"),
        dictgen::InsensitiveStr::Ascii("astardised"),
        dictgen::InsensitiveStr::Ascii("astardisedder"),
        dictgen::InsensitiveStr::Ascii("astardiseddest"),
        dictgen::InsensitiveStr::Ascii("astardized"),
        dictgen::InsensitiveStr::Ascii("astardizedder"),
        dictgen::InsensitiveStr::Ascii("astardizeddest"),
        dictgen::InsensitiveStr::Ascii("rutalise"),
        dictgen::InsensitiveStr::Ascii("rutalised"),
        dictgen::InsensitiveStr::Ascii("rutalises"),
        dictgen::InsensitiveStr::Ascii("rutalising"),
        dictgen::InsensitiveStr::Ascii("rutalize"),
        dictgen::InsensitiveStr::Ascii("rutalized"),
        dictgen::InsensitiveStr::Ascii("rutalizes"),
        dictgen::InsensitiveStr::Ascii("rutalizing"),
        dictgen::InsensitiveStr::Ascii("rutise"),
        dictgen::InsensitiveStr::Ascii("rutised"),
        dictgen::InsensitiveStr::Ascii("rutises"),
        dictgen::InsensitiveStr::Ascii("rutising"),
        dictgen::InsensitiveStr::Ascii("rutize"),
        dictgen::InsensitiveStr::Ascii("rutized"),
        dictgen::InsensitiveStr::Ascii("rutizes"),
        dictgen::InsensitiveStr::Ascii("rutizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNBAPTIZE_18045749488616509181)],
        &[(0b10010, &ENTRY_UNBAPTIZED_2750609897609115804)],
        &[(0b10010, &ENTRY_UNBAPTIZES_5860001137786586819)],
        &[(0b10010, &ENTRY_UNBAPTIZING_369890182023136394)],
        &[(0b01001, &ENTRY_UNBAPTIZE_18045749488616509181)],
        &[(0b01001, &ENTRY_UNBAPTIZED_2750609897609115804)],
        &[(0b01001, &ENTRY_UNBAPTIZES_5860001137786586819)],
        &[(0b01001, &ENTRY_UNBAPTIZING_369890182023136394)],
        &[(0b10010, &ENTRY_UNBARBARIZE_85759814966596838)],
        &[(0b10010, &ENTRY_UNBARBARIZED_4163251566640502972)],
        &[(0b10010, &ENTRY_UNBARBARIZING_10525570028182827286)],
        &[(0b01001, &ENTRY_UNBARBARIZE_85759814966596838)],
        &[(0b01001, &ENTRY_UNBARBARIZED_4163251566640502972)],
        &[(0b01001, &ENTRY_UNBARBARIZING_10525570028182827286)],
        &[(0b00001, &ENTRY_UNBARRICADED_12195279117302305039)],
        &[(0b11010, &ENTRY_UNBARRICADED_12195279117302305039)],
        &[(0b10010, &ENTRY_UNBASTARDIZED_13342112361958904470)],
        &[(0b10010, &ENTRY_UNBASTARDIZEDDER_6714666111533384003)],
        &[(0b10010, &ENTRY_UNBASTARDIZEDDEST_5748524649962490826)],
        &[(0b01001, &ENTRY_UNBASTARDIZED_13342112361958904470)],
        &[(0b01001, &ENTRY_UNBASTARDIZEDDER_6714666111533384003)],
        &[(0b01001, &ENTRY_UNBASTARDIZEDDEST_5748524649962490826)],
        &[(0b10010, &ENTRY_UNBRUTALIZE_18223840863792260272)],
        &[(0b10010, &ENTRY_UNBRUTALIZED_6338937456842490293)],
        &[(0b10010, &ENTRY_UNBRUTALIZES_4127817782461372270)],
        &[(0b10010, &ENTRY_UNBRUTALIZING_12933117214333059837)],
        &[(0b01001, &ENTRY_UNBRUTALIZE_18223840863792260272)],
        &[(0b01001, &ENTRY_UNBRUTALIZED_6338937456842490293)],
        &[(0b01001, &ENTRY_UNBRUTALIZES_4127817782461372270)],
        &[(0b01001, &ENTRY_UNBRUTALIZING_12933117214333059837)],
        &[(0b10010, &ENTRY_UNBRUTIZE_10482956505266389513)],
        &[(0b10010, &ENTRY_UNBRUTIZED_18292720994739659985)],
        &[(0b10010, &ENTRY_UNBRUTIZES_12365008004715490849)],
        &[(0b10010, &ENTRY_UNBRUTIZING_8068018278771694293)],
        &[(0b01001, &ENTRY_UNBRUTIZE_10482956505266389513)],
        &[(0b01001, &ENTRY_UNBRUTIZED_18292720994739659985)],
        &[(0b01001, &ENTRY_UNBRUTIZES_12365008004715490849)],
        &[(0b01001, &ENTRY_UNBRUTIZING_8068018278771694293)],
    ],
    range: 6..=14,
};

static VARS_UNA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_UNA_CHILDREN),
    value: None,
};

static VARS_UNA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_UNAC_NODE),
    None,
    None,
    None,
    Some(&VARS_UNAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_UNAL_NODE),
    Some(&VARS_UNAM_NODE),
    Some(&VARS_UNAN_NODE),
    None,
    Some(&VARS_UNAP_NODE),
    None,
    Some(&VARS_UNAR_NODE),
    None,
    None,
    Some(&VARS_UNAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_UNAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAU_CHILDREN),
    value: None,
};

pub static VARS_UNAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thorise"),
        dictgen::InsensitiveStr::Ascii("thorised"),
        dictgen::InsensitiveStr::Ascii("thorisedder"),
        dictgen::InsensitiveStr::Ascii("thoriseddest"),
        dictgen::InsensitiveStr::Ascii("thorisedly"),
        dictgen::InsensitiveStr::Ascii("thorisedness"),
        dictgen::InsensitiveStr::Ascii("thorises"),
        dictgen::InsensitiveStr::Ascii("thorize"),
        dictgen::InsensitiveStr::Ascii("thorized"),
        dictgen::InsensitiveStr::Ascii("thorizedder"),
        dictgen::InsensitiveStr::Ascii("thorizeddest"),
        dictgen::InsensitiveStr::Ascii("thorizedly"),
        dictgen::InsensitiveStr::Ascii("thorizedness"),
        dictgen::InsensitiveStr::Ascii("thorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNAUTHORIZE_17373059611637260636)],
        &[(0b10010, &ENTRY_UNAUTHORIZED_18330969128189680958)],
        &[(0b10010, &ENTRY_UNAUTHORIZEDDER_4146956705318297921)],
        &[(0b10010, &ENTRY_UNAUTHORIZEDDEST_5230199240119912096)],
        &[(0b10010, &ENTRY_UNAUTHORIZEDLY_1756944536540360350)],
        &[(0b10010, &ENTRY_UNAUTHORIZEDNESS_13848901931254124796)],
        &[(0b10010, &ENTRY_UNAUTHORIZES_15223481987545098919)],
        &[(0b01001, &ENTRY_UNAUTHORIZE_17373059611637260636)],
        &[(0b01001, &ENTRY_UNAUTHORIZED_18330969128189680958)],
        &[(0b01001, &ENTRY_UNAUTHORIZEDDER_4146956705318297921)],
        &[(0b01001, &ENTRY_UNAUTHORIZEDDEST_5230199240119912096)],
        &[(0b01001, &ENTRY_UNAUTHORIZEDLY_1756944536540360350)],
        &[(0b01001, &ENTRY_UNAUTHORIZEDNESS_13848901931254124796)],
        &[(0b01001, &ENTRY_UNAUTHORIZES_15223481987545098919)],
    ],
    range: 7..=12,
};

static VARS_UNAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAR_CHILDREN),
    value: None,
};

pub static VARS_UNAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bored"),
        dictgen::InsensitiveStr::Ascii("boured"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moredder"),
        dictgen::InsensitiveStr::Ascii("moreddest"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mouredder"),
        dictgen::InsensitiveStr::Ascii("moureddest"),
    ],
    values: &[
        &[(0b00001, &ENTRY_UNARBORED_10962513521010356596)],
        &[(0b11010, &ENTRY_UNARBORED_10962513521010356596)],
        &[(0b00001, &ENTRY_UNARMORED_4540020611443646355)],
        &[(0b00001, &ENTRY_UNARMOREDDER_4175485372914136238)],
        &[(0b00001, &ENTRY_UNARMOREDDEST_3012270770178515043)],
        &[(0b11010, &ENTRY_UNARMORED_4540020611443646355)],
        &[(0b11010, &ENTRY_UNARMOREDDER_4175485372914136238)],
        &[(0b11010, &ENTRY_UNARMOREDDEST_3012270770178515043)],
    ],
    range: 5..=10,
};

static VARS_UNAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAP_CHILDREN),
    value: None,
};

pub static VARS_UNAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ologising"),
        dictgen::InsensitiveStr::Ascii("ologizing"),
        dictgen::InsensitiveStr::Ascii("ostatised"),
        dictgen::InsensitiveStr::Ascii("ostatiseds"),
        dictgen::InsensitiveStr::Ascii("ostatized"),
        dictgen::InsensitiveStr::Ascii("ostatizeds"),
        dictgen::InsensitiveStr::Ascii("petising"),
        dictgen::InsensitiveStr::Ascii("petisinger"),
        dictgen::InsensitiveStr::Ascii("petisingest"),
        dictgen::InsensitiveStr::Ascii("petisinglier"),
        dictgen::InsensitiveStr::Ascii("petisingliest"),
        dictgen::InsensitiveStr::Ascii("petisingly"),
        dictgen::InsensitiveStr::Ascii("petizing"),
        dictgen::InsensitiveStr::Ascii("petizinger"),
        dictgen::InsensitiveStr::Ascii("petizingest"),
        dictgen::InsensitiveStr::Ascii("petizinglier"),
        dictgen::InsensitiveStr::Ascii("petizingliest"),
        dictgen::InsensitiveStr::Ascii("petizingly"),
        dictgen::InsensitiveStr::Ascii("prised"),
        dictgen::InsensitiveStr::Ascii("prized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNAPOLOGIZING_8820499902965244314)],
        &[(0b01001, &ENTRY_UNAPOLOGIZING_8820499902965244314)],
        &[(0b10010, &ENTRY_UNAPOSTATIZED_8707752890756536689)],
        &[(0b10010, &ENTRY_UNAPOSTATIZEDS_14669408928414139662)],
        &[(0b01001, &ENTRY_UNAPOSTATIZED_8707752890756536689)],
        &[(0b01001, &ENTRY_UNAPOSTATIZEDS_14669408928414139662)],
        &[(0b10010, &ENTRY_UNAPPETIZING_12749343422231568734)],
        &[(0b10010, &ENTRY_UNAPPETIZINGER_11663943688244312711)],
        &[(0b10010, &ENTRY_UNAPPETIZINGEST_15811327206418622113)],
        &[(0b10010, &ENTRY_UNAPPETIZINGLIER_5194460014263105886)],
        &[(0b10010, &ENTRY_UNAPPETIZINGLIEST_13095442457868536397)],
        &[(0b10010, &ENTRY_UNAPPETIZINGLY_4396083271756728101)],
        &[(0b01001, &ENTRY_UNAPPETIZING_12749343422231568734)],
        &[(0b01001, &ENTRY_UNAPPETIZINGER_11663943688244312711)],
        &[(0b01001, &ENTRY_UNAPPETIZINGEST_15811327206418622113)],
        &[(0b01001, &ENTRY_UNAPPETIZINGLIER_5194460014263105886)],
        &[(0b01001, &ENTRY_UNAPPETIZINGLIEST_13095442457868536397)],
        &[(0b01001, &ENTRY_UNAPPETIZINGLY_4396083271756728101)],
        &[(0b10010, &ENTRY_UNAPPRIZED_6119477476012909356)],
        &[(0b01001, &ENTRY_UNAPPRIZED_6119477476012909356)],
    ],
    range: 6..=13,
};

static VARS_UNAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAN_CHILDREN),
    value: None,
};

pub static VARS_UNAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("alysable"),
        dictgen::InsensitiveStr::Ascii("alysed"),
        dictgen::InsensitiveStr::Ascii("alyzable"),
        dictgen::InsensitiveStr::Ascii("alyzed"),
        dictgen::InsensitiveStr::Ascii("atomisable"),
        dictgen::InsensitiveStr::Ascii("atomised"),
        dictgen::InsensitiveStr::Ascii("atomizable"),
        dictgen::InsensitiveStr::Ascii("atomized"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("imalised"),
        dictgen::InsensitiveStr::Ascii("imaliseds"),
        dictgen::InsensitiveStr::Ascii("imalized"),
        dictgen::InsensitiveStr::Ascii("imalizeds"),
        dictgen::InsensitiveStr::Ascii("tagonisable"),
        dictgen::InsensitiveStr::Ascii("tagonisabler"),
        dictgen::InsensitiveStr::Ascii("tagonisables"),
        dictgen::InsensitiveStr::Ascii("tagonisablest"),
        dictgen::InsensitiveStr::Ascii("tagonised"),
        dictgen::InsensitiveStr::Ascii("tagonisedder"),
        dictgen::InsensitiveStr::Ascii("tagoniseddest"),
        dictgen::InsensitiveStr::Ascii("tagonising"),
        dictgen::InsensitiveStr::Ascii("tagonisinger"),
        dictgen::InsensitiveStr::Ascii("tagonisingest"),
        dictgen::InsensitiveStr::Ascii("tagonizable"),
        dictgen::InsensitiveStr::Ascii("tagonizabler"),
        dictgen::InsensitiveStr::Ascii("tagonizables"),
        dictgen::InsensitiveStr::Ascii("tagonizablest"),
        dictgen::InsensitiveStr::Ascii("tagonized"),
        dictgen::InsensitiveStr::Ascii("tagonizedder"),
        dictgen::InsensitiveStr::Ascii("tagonizeddest"),
        dictgen::InsensitiveStr::Ascii("tagonizing"),
        dictgen::InsensitiveStr::Ascii("tagonizinger"),
        dictgen::InsensitiveStr::Ascii("tagonizingest"),
    ],
    values: &[
        &[(0b11010, &ENTRY_UNANEMIC_6804040153460031597)],
        &[(0b10010, &ENTRY_UNANALYZABLE_10015139257021178435)],
        &[(0b10010, &ENTRY_UNANALYZED_16500188544214906359)],
        &[(0b01001, &ENTRY_UNANALYZABLE_10015139257021178435)],
        &[(0b01001, &ENTRY_UNANALYZED_16500188544214906359)],
        &[(0b10010, &ENTRY_UNANATOMIZABLE_12621927696529831665)],
        &[(0b10010, &ENTRY_UNANATOMIZED_6061766559393631360)],
        &[(0b01001, &ENTRY_UNANATOMIZABLE_12621927696529831665)],
        &[(0b01001, &ENTRY_UNANATOMIZED_6061766559393631360)],
        &[(0b00001, &ENTRY_UNANEMIC_6804040153460031597)],
        &[(0b10010, &ENTRY_UNANIMALIZED_2409683454989613456)],
        &[(0b10010, &ENTRY_UNANIMALIZEDS_12083863725694904084)],
        &[(0b01001, &ENTRY_UNANIMALIZED_2409683454989613456)],
        &[(0b01001, &ENTRY_UNANIMALIZEDS_12083863725694904084)],
        &[(0b10010, &ENTRY_UNANTAGONIZABLE_8940938838594676762)],
        &[(0b10010, &ENTRY_UNANTAGONIZABLER_341535602186309075)],
        &[(0b10010, &ENTRY_UNANTAGONIZABLES_2731043692553771550)],
        &[(0b10010, &ENTRY_UNANTAGONIZABLEST_17345953185101673573)],
        &[(0b10010, &ENTRY_UNANTAGONIZED_3298227429647689925)],
        &[(0b10010, &ENTRY_UNANTAGONIZEDDER_17407737658502114220)],
        &[(0b10010, &ENTRY_UNANTAGONIZEDDEST_15019402780215712074)],
        &[(0b10010, &ENTRY_UNANTAGONIZING_3465462232208147407)],
        &[(0b10010, &ENTRY_UNANTAGONIZINGER_15671658988108179272)],
        &[(0b10010, &ENTRY_UNANTAGONIZINGEST_5785945012122373004)],
        &[(0b01001, &ENTRY_UNANTAGONIZABLE_8940938838594676762)],
        &[(0b01001, &ENTRY_UNANTAGONIZABLER_341535602186309075)],
        &[(0b01001, &ENTRY_UNANTAGONIZABLES_2731043692553771550)],
        &[(0b01001, &ENTRY_UNANTAGONIZABLEST_17345953185101673573)],
        &[(0b01001, &ENTRY_UNANTAGONIZED_3298227429647689925)],
        &[(0b01001, &ENTRY_UNANTAGONIZEDDER_17407737658502114220)],
        &[(0b01001, &ENTRY_UNANTAGONIZEDDEST_15019402780215712074)],
        &[(0b01001, &ENTRY_UNANTAGONIZING_3465462232208147407)],
        &[(0b01001, &ENTRY_UNANTAGONIZINGER_15671658988108179272)],
        &[(0b01001, &ENTRY_UNANTAGONIZINGEST_5785945012122373004)],
    ],
    range: 4..=13,
};

static VARS_UNAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAM_CHILDREN),
    value: None,
};

pub static VARS_UNAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ortisation"),
        dictgen::InsensitiveStr::Ascii("ortisations"),
        dictgen::InsensitiveStr::Ascii("ortised"),
        dictgen::InsensitiveStr::Ascii("ortization"),
        dictgen::InsensitiveStr::Ascii("ortizations"),
        dictgen::InsensitiveStr::Ascii("ortized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNAMORTIZATION_12146076887735696880)],
        &[(0b10010, &ENTRY_UNAMORTIZATIONS_11801391438115116167)],
        &[(0b10010, &ENTRY_UNAMORTIZED_13451896776472967546)],
        &[(0b01001, &ENTRY_UNAMORTIZATION_12146076887735696880)],
        &[(0b01001, &ENTRY_UNAMORTIZATIONS_11801391438115116167)],
        &[(0b01001, &ENTRY_UNAMORTIZED_13451896776472967546)],
    ],
    range: 7..=11,
};

static VARS_UNAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAL_CHILDREN),
    value: None,
};

pub static VARS_UNAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("coholised"),
        dictgen::InsensitiveStr::Ascii("coholisedder"),
        dictgen::InsensitiveStr::Ascii("coholiseddest"),
        dictgen::InsensitiveStr::Ascii("coholiseds"),
        dictgen::InsensitiveStr::Ascii("coholized"),
        dictgen::InsensitiveStr::Ascii("coholizedder"),
        dictgen::InsensitiveStr::Ascii("coholizeddest"),
        dictgen::InsensitiveStr::Ascii("coholizeds"),
        dictgen::InsensitiveStr::Ascii("phabetised"),
        dictgen::InsensitiveStr::Ascii("phabetized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNALCOHOLIZED_12462545574552694750)],
        &[(0b10010, &ENTRY_UNALCOHOLIZEDDER_7254338354970976974)],
        &[(0b10010, &ENTRY_UNALCOHOLIZEDDEST_3929868538999714538)],
        &[(0b10010, &ENTRY_UNALCOHOLIZEDS_3779587450961636557)],
        &[(0b01001, &ENTRY_UNALCOHOLIZED_12462545574552694750)],
        &[(0b01001, &ENTRY_UNALCOHOLIZEDDER_7254338354970976974)],
        &[(0b01001, &ENTRY_UNALCOHOLIZEDDEST_3929868538999714538)],
        &[(0b01001, &ENTRY_UNALCOHOLIZEDS_3779587450961636557)],
        &[(0b10010, &ENTRY_UNALPHABETIZED_785154054192050580)],
        &[(0b01001, &ENTRY_UNALPHABETIZED_785154054192050580)],
    ],
    range: 9..=13,
};

static VARS_UNAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAG_CHILDREN),
    value: None,
};

pub static VARS_UNAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNAGONIZE_6084501682979547918)],
        &[(0b01001, &ENTRY_UNAGONIZE_6084501682979547918)],
    ],
    range: 5..=5,
};

static VARS_UNAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UNAC_CHILDREN),
    value: None,
};

pub static VARS_UNAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("climatised"),
        dictgen::InsensitiveStr::Ascii("climatized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_UNACCLIMATIZED_1969571864517774602)],
        &[(0b01001, &ENTRY_UNACCLIMATIZED_1969571864517774602)],
    ],
    range: 10..=10,
};

static VARS_UL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_UL_CHILDREN),
    value: None,
};

pub static VARS_UL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tracentraliser"),
        dictgen::InsensitiveStr::Ascii("tracentralisers"),
        dictgen::InsensitiveStr::Ascii("tracentralizer"),
        dictgen::InsensitiveStr::Ascii("tracentralizers"),
        dictgen::InsensitiveStr::Ascii("trahonorable"),
        dictgen::InsensitiveStr::Ascii("trahonorables"),
        dictgen::InsensitiveStr::Ascii("trahonourable"),
        dictgen::InsensitiveStr::Ascii("trahonourables"),
        dictgen::InsensitiveStr::Ascii("traspecialisation"),
        dictgen::InsensitiveStr::Ascii("traspecialisations"),
        dictgen::InsensitiveStr::Ascii("traspecialization"),
        dictgen::InsensitiveStr::Ascii("traspecializations"),
        dictgen::InsensitiveStr::Ascii("trastandardisation"),
        dictgen::InsensitiveStr::Ascii("trastandardisations"),
        dictgen::InsensitiveStr::Ascii("trastandardization"),
        dictgen::InsensitiveStr::Ascii("trastandardizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ULTRACENTRALIZER_1386087884281857470)],
        &[(0b10010, &ENTRY_ULTRACENTRALIZERS_15801856694895216516)],
        &[(0b01001, &ENTRY_ULTRACENTRALIZER_1386087884281857470)],
        &[(0b01001, &ENTRY_ULTRACENTRALIZERS_15801856694895216516)],
        &[(0b00001, &ENTRY_ULTRAHONORABLE_17802324312727593194)],
        &[(0b00001, &ENTRY_ULTRAHONORABLES_9342789915681610564)],
        &[(0b11010, &ENTRY_ULTRAHONORABLE_17802324312727593194)],
        &[(0b11010, &ENTRY_ULTRAHONORABLES_9342789915681610564)],
        &[(0b10010, &ENTRY_ULTRASPECIALIZATION_14780888503862218576)],
        &[(0b10010, &ENTRY_ULTRASPECIALIZATIONS_14936216708962453732)],
        &[(0b01001, &ENTRY_ULTRASPECIALIZATION_14780888503862218576)],
        &[(0b01001, &ENTRY_ULTRASPECIALIZATIONS_14936216708962453732)],
        &[(0b10010, &ENTRY_ULTRASTANDARDIZATION_7616606161431137542)],
        &[(0b10010, &ENTRY_ULTRASTANDARDIZATIONS_12958573872619861416)],
        &[(0b01001, &ENTRY_ULTRASTANDARDIZATION_7616606161431137542)],
        &[(0b01001, &ENTRY_ULTRASTANDARDIZATIONS_12958573872619861416)],
    ],
    range: 12..=19,
};

static VARS_T_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_T_CHILDREN),
    value: None,
};

static VARS_T_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_TA_NODE),
    None,
    None,
    None,
    Some(&VARS_TE_NODE),
    None,
    None,
    Some(&VARS_TH_NODE),
    Some(&VARS_TI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TO_NODE),
    None,
    None,
    Some(&VARS_TR_NODE),
    Some(&VARS_TS_NODE),
    None,
    Some(&VARS_TU_NODE),
    None,
    Some(&VARS_TW_NODE),
    None,
    Some(&VARS_TY_NODE),
    Some(&VARS_TZ_NODE),
];

static VARS_TZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TZ_CHILDREN),
    value: None,
};

pub static VARS_TZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ar"),
        dictgen::InsensitiveStr::Ascii("ars"),
    ],
    values: &[
        &[(0b10011, &ENTRY_CZAR_11030798322432903782)],
        &[(0b10011, &ENTRY_CZARS_6668028309318935455)],
    ],
    range: 2..=3,
};

static VARS_TY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TY_CHILDREN),
    value: None,
};

pub static VARS_TY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lerise"),
        dictgen::InsensitiveStr::Ascii("lerises"),
        dictgen::InsensitiveStr::Ascii("lerize"),
        dictgen::InsensitiveStr::Ascii("lerizes"),
        dictgen::InsensitiveStr::Ascii("phaemia"),
        dictgen::InsensitiveStr::Ascii("phemia"),
        dictgen::InsensitiveStr::Ascii("phlenteritis"),
        dictgen::InsensitiveStr::Ascii("phloenteritis"),
        dictgen::InsensitiveStr::Ascii("phoaemia"),
        dictgen::InsensitiveStr::Ascii("phoemia"),
        dictgen::InsensitiveStr::Ascii("rannise"),
        dictgen::InsensitiveStr::Ascii("rannised"),
        dictgen::InsensitiveStr::Ascii("ranniser"),
        dictgen::InsensitiveStr::Ascii("rannisers"),
        dictgen::InsensitiveStr::Ascii("rannises"),
        dictgen::InsensitiveStr::Ascii("rannising"),
        dictgen::InsensitiveStr::Ascii("rannisinglier"),
        dictgen::InsensitiveStr::Ascii("rannisingliest"),
        dictgen::InsensitiveStr::Ascii("rannisingly"),
        dictgen::InsensitiveStr::Ascii("rannisings"),
        dictgen::InsensitiveStr::Ascii("rannize"),
        dictgen::InsensitiveStr::Ascii("rannized"),
        dictgen::InsensitiveStr::Ascii("rannizer"),
        dictgen::InsensitiveStr::Ascii("rannizers"),
        dictgen::InsensitiveStr::Ascii("rannizes"),
        dictgen::InsensitiveStr::Ascii("rannizing"),
        dictgen::InsensitiveStr::Ascii("rannizinglier"),
        dictgen::InsensitiveStr::Ascii("rannizingliest"),
        dictgen::InsensitiveStr::Ascii("rannizingly"),
        dictgen::InsensitiveStr::Ascii("rannizings"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("reo"),
        dictgen::InsensitiveStr::Ascii("reos"),
        dictgen::InsensitiveStr::Ascii("res"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TYLERIZE_6772047772391841205)],
        &[(0b10010, &ENTRY_TYLERIZES_3930431350093885314)],
        &[(0b01001, &ENTRY_TYLERIZE_6772047772391841205)],
        &[(0b01001, &ENTRY_TYLERIZES_3930431350093885314)],
        &[(0b11010, &ENTRY_TYPHEMIA_3949405273592839759)],
        &[
            (0b00001, &ENTRY_TYPHEMIA_3949405273592839759),
            (0b00001, &ENTRY_TYPHEMIA_436328357437921093),
        ],
        &[(0b00001, &ENTRY_TYPHLENTERITIS_16701047769348734014)],
        &[(0b11010, &ENTRY_TYPHLENTERITIS_16701047769348734014)],
        &[(0b11010, &ENTRY_TYPHOEMIA_16341888230675161250)],
        &[
            (0b11010, &ENTRY_TYPHEMIA_436328357437921093),
            (0b00001, &ENTRY_TYPHOEMIA_16341888230675161250),
        ],
        &[(0b10010, &ENTRY_TYRANNIZE_402218976726854223)],
        &[(0b10010, &ENTRY_TYRANNIZED_1941892499943366434)],
        &[(0b10010, &ENTRY_TYRANNIZER_1371535188483909389)],
        &[(0b10010, &ENTRY_TYRANNIZERS_13060284352391993246)],
        &[(0b10010, &ENTRY_TYRANNIZES_10925886797003891936)],
        &[(0b10010, &ENTRY_TYRANNIZING_18363984835873871108)],
        &[(0b10010, &ENTRY_TYRANNIZINGLIER_7411912687837897273)],
        &[(0b10010, &ENTRY_TYRANNIZINGLIEST_13299239458699844336)],
        &[(0b10010, &ENTRY_TYRANNIZINGLY_387905432645898165)],
        &[(0b10010, &ENTRY_TYRANNIZINGS_8912279495006406317)],
        &[(0b01001, &ENTRY_TYRANNIZE_402218976726854223)],
        &[(0b01001, &ENTRY_TYRANNIZED_1941892499943366434)],
        &[(0b01001, &ENTRY_TYRANNIZER_1371535188483909389)],
        &[(0b01001, &ENTRY_TYRANNIZERS_13060284352391993246)],
        &[(0b01001, &ENTRY_TYRANNIZES_10925886797003891936)],
        &[(0b01001, &ENTRY_TYRANNIZING_18363984835873871108)],
        &[(0b01001, &ENTRY_TYRANNIZINGLIER_7411912687837897273)],
        &[(0b01001, &ENTRY_TYRANNIZINGLIEST_13299239458699844336)],
        &[(0b01001, &ENTRY_TYRANNIZINGLY_387905432645898165)],
        &[(0b01001, &ENTRY_TYRANNIZINGS_8912279495006406317)],
        &[(0b10010, &ENTRY_TIRE_17853768187298953050)],
        &[(0b00001, &ENTRY_TYRO_1396628122702945602)],
        &[(0b00001, &ENTRY_TYROS_4063138644213636346)],
        &[(0b10010, &ENTRY_TIRES_13233982026064511360)],
    ],
    range: 2..=14,
};

static VARS_TW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TW_CHILDREN),
    value: None,
};

pub static VARS_TW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("iers"),
        dictgen::InsensitiveStr::Ascii("ire"),
        dictgen::InsensitiveStr::Ascii("ires"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TWIER_17943274413772224375)],
        &[(0b00001, &ENTRY_TWIERS_466316859651799693)],
        &[(0b11010, &ENTRY_TWIER_17943274413772224375)],
        &[(0b11010, &ENTRY_TWIERS_466316859651799693)],
    ],
    range: 3..=4,
};

static VARS_TU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TU_CHILDREN),
    value: None,
};

static VARS_TU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_TUB_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TUL_NODE),
    Some(&VARS_TUM_NODE),
    Some(&VARS_TUN_NODE),
    None,
    None,
    None,
    Some(&VARS_TUR_NODE),
    Some(&VARS_TUS_NODE),
    Some(&VARS_TUT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_TUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUT_CHILDREN),
    value: None,
};

pub static VARS_TUT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elae"),
        dictgen::InsensitiveStr::Ascii("ele"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TUTELE_16207284368064157603)],
        &[(0b00001, &ENTRY_TUTELE_16207284368064157603)],
        &[(0b10010, &ENTRY_TUTORIZATION_7186477482613526154)],
        &[(0b10010, &ENTRY_TUTORIZATIONS_8014516646889352337)],
        &[(0b10010, &ENTRY_TUTORIZE_5415313587641112365)],
        &[(0b10010, &ENTRY_TUTORIZED_14661527617907051055)],
        &[(0b10010, &ENTRY_TUTORIZES_5000989116733816697)],
        &[(0b10010, &ENTRY_TUTORIZING_17098833328892189609)],
        &[(0b01001, &ENTRY_TUTORIZATION_7186477482613526154)],
        &[(0b01001, &ENTRY_TUTORIZATIONS_8014516646889352337)],
        &[(0b01001, &ENTRY_TUTORIZE_5415313587641112365)],
        &[(0b01001, &ENTRY_TUTORIZED_14661527617907051055)],
        &[(0b01001, &ENTRY_TUTORIZES_5000989116733816697)],
        &[(0b01001, &ENTRY_TUTORIZING_17098833328892189609)],
    ],
    range: 3..=10,
};

static VARS_TUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUS_CHILDREN),
    value: None,
};

pub static VARS_TUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("canise"),
        dictgen::InsensitiveStr::Ascii("canises"),
        dictgen::InsensitiveStr::Ascii("canize"),
        dictgen::InsensitiveStr::Ascii("canizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TUSCANIZE_7918803889059096084)],
        &[(0b10010, &ENTRY_TUSCANIZES_9646687590900186948)],
        &[(0b01001, &ENTRY_TUSCANIZE_7918803889059096084)],
        &[(0b01001, &ENTRY_TUSCANIZES_9646687590900186948)],
    ],
    range: 6..=7,
};

static VARS_TUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUR_CHILDREN),
    value: None,
};

pub static VARS_TUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dinae"),
        dictgen::InsensitiveStr::Ascii("dine"),
        dictgen::InsensitiveStr::Ascii("kicise"),
        dictgen::InsensitiveStr::Ascii("kicised"),
        dictgen::InsensitiveStr::Ascii("kicises"),
        dictgen::InsensitiveStr::Ascii("kicising"),
        dictgen::InsensitiveStr::Ascii("kicize"),
        dictgen::InsensitiveStr::Ascii("kicized"),
        dictgen::InsensitiveStr::Ascii("kicizes"),
        dictgen::InsensitiveStr::Ascii("kicizing"),
        dictgen::InsensitiveStr::Ascii("kise"),
        dictgen::InsensitiveStr::Ascii("kises"),
        dictgen::InsensitiveStr::Ascii("kize"),
        dictgen::InsensitiveStr::Ascii("kizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TURDINE_8495216946259189004)],
        &[(0b00001, &ENTRY_TURDINE_8495216946259189004)],
        &[(0b10010, &ENTRY_TURKICIZE_12952219324449295324)],
        &[(0b10010, &ENTRY_TURKICIZED_16551093534484123400)],
        &[(0b10010, &ENTRY_TURKICIZES_4184526349077657623)],
        &[(0b10010, &ENTRY_TURKICIZING_11437686965760445130)],
        &[(0b01001, &ENTRY_TURKICIZE_12952219324449295324)],
        &[(0b01001, &ENTRY_TURKICIZED_16551093534484123400)],
        &[(0b01001, &ENTRY_TURKICIZES_4184526349077657623)],
        &[(0b01001, &ENTRY_TURKICIZING_11437686965760445130)],
        &[(0b10010, &ENTRY_TURKIZE_8515585059262136896)],
        &[(0b10010, &ENTRY_TURKIZES_3728749434026795951)],
        &[(0b01001, &ENTRY_TURKIZE_8515585059262136896)],
        &[(0b01001, &ENTRY_TURKIZES_3728749434026795951)],
    ],
    range: 4..=8,
};

static VARS_TUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUN_CHILDREN),
    value: None,
};

pub static VARS_TUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("neled"),
        dictgen::InsensitiveStr::Ascii("neler"),
        dictgen::InsensitiveStr::Ascii("nelers"),
        dictgen::InsensitiveStr::Ascii("neling"),
        dictgen::InsensitiveStr::Ascii("nelings"),
        dictgen::InsensitiveStr::Ascii("nelled"),
        dictgen::InsensitiveStr::Ascii("neller"),
        dictgen::InsensitiveStr::Ascii("nellers"),
        dictgen::InsensitiveStr::Ascii("nelling"),
        dictgen::InsensitiveStr::Ascii("nellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TUNNELED_886730683006426004)],
        &[(0b00001, &ENTRY_TUNNELER_6084737649073030916)],
        &[(0b00001, &ENTRY_TUNNELERS_3199139734449894765)],
        &[(0b00001, &ENTRY_TUNNELING_155358793735796240)],
        &[(0b00001, &ENTRY_TUNNELINGS_14762533053987563131)],
        &[(0b11010, &ENTRY_TUNNELED_886730683006426004)],
        &[(0b11010, &ENTRY_TUNNELER_6084737649073030916)],
        &[(0b11010, &ENTRY_TUNNELERS_3199139734449894765)],
        &[(0b11010, &ENTRY_TUNNELING_155358793735796240)],
        &[(0b11010, &ENTRY_TUNNELINGS_14762533053987563131)],
    ],
    range: 5..=8,
};

static VARS_TUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUM_CHILDREN),
    value: None,
};

pub static VARS_TUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_TUMOR_15198008231736842579)],
        &[(0b00001, &ENTRY_TUMORED_9530760269255205454)],
        &[(0b11001, &ENTRY_TUMORS_4506585513408357434)],
        &[(0b11010, &ENTRY_TUMOR_15198008231736842579)],
        &[(0b11010, &ENTRY_TUMORED_9530760269255205454)],
        &[(0b11010, &ENTRY_TUMORS_4506585513408357434)],
    ],
    range: 2..=5,
};

static VARS_TUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUL_CHILDREN),
    value: None,
};

pub static VARS_TUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("araemia"),
        dictgen::InsensitiveStr::Ascii("araemias"),
        dictgen::InsensitiveStr::Ascii("araemic"),
        dictgen::InsensitiveStr::Ascii("aremia"),
        dictgen::InsensitiveStr::Ascii("aremias"),
        dictgen::InsensitiveStr::Ascii("aremic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TULAREMIA_111069766982320509)],
        &[(0b11010, &ENTRY_TULAREMIAS_14187869169219863030)],
        &[(0b11010, &ENTRY_TULAREMIC_7746109038589986442)],
        &[(0b01001, &ENTRY_TULAREMIA_111069766982320509)],
        &[(0b01001, &ENTRY_TULAREMIAS_14187869169219863030)],
        &[(0b00001, &ENTRY_TULAREMIC_7746109038589986442)],
    ],
    range: 6..=8,
};

static VARS_TUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TUB_CHILDREN),
    value: None,
};

pub static VARS_TUB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ercularisation"),
        dictgen::InsensitiveStr::Ascii("ercularise"),
        dictgen::InsensitiveStr::Ascii("ercularised"),
        dictgen::InsensitiveStr::Ascii("ercularising"),
        dictgen::InsensitiveStr::Ascii("ercularization"),
        dictgen::InsensitiveStr::Ascii("ercularize"),
        dictgen::InsensitiveStr::Ascii("ercularized"),
        dictgen::InsensitiveStr::Ascii("ercularizing"),
        dictgen::InsensitiveStr::Ascii("erculinisation"),
        dictgen::InsensitiveStr::Ascii("erculinisations"),
        dictgen::InsensitiveStr::Ascii("erculinise"),
        dictgen::InsensitiveStr::Ascii("erculinised"),
        dictgen::InsensitiveStr::Ascii("erculinises"),
        dictgen::InsensitiveStr::Ascii("erculinising"),
        dictgen::InsensitiveStr::Ascii("erculinization"),
        dictgen::InsensitiveStr::Ascii("erculinizations"),
        dictgen::InsensitiveStr::Ascii("erculinize"),
        dictgen::InsensitiveStr::Ascii("erculinized"),
        dictgen::InsensitiveStr::Ascii("erculinizes"),
        dictgen::InsensitiveStr::Ascii("erculinizing"),
        dictgen::InsensitiveStr::Ascii("erculisation"),
        dictgen::InsensitiveStr::Ascii("erculisations"),
        dictgen::InsensitiveStr::Ascii("erculise"),
        dictgen::InsensitiveStr::Ascii("erculised"),
        dictgen::InsensitiveStr::Ascii("erculises"),
        dictgen::InsensitiveStr::Ascii("erculising"),
        dictgen::InsensitiveStr::Ascii("erculization"),
        dictgen::InsensitiveStr::Ascii("erculizations"),
        dictgen::InsensitiveStr::Ascii("erculize"),
        dictgen::InsensitiveStr::Ascii("erculized"),
        dictgen::InsensitiveStr::Ascii("erculizes"),
        dictgen::InsensitiveStr::Ascii("erculizing"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("ulisation"),
        dictgen::InsensitiveStr::Ascii("ulisations"),
        dictgen::InsensitiveStr::Ascii("ulization"),
        dictgen::InsensitiveStr::Ascii("ulizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TUBERCULARIZATION_15542666046560010756)],
        &[(0b10010, &ENTRY_TUBERCULARIZE_2157217058313355699)],
        &[(0b10010, &ENTRY_TUBERCULARIZED_12286997214844537953)],
        &[(0b10010, &ENTRY_TUBERCULARIZING_3929944679702207874)],
        &[(0b01001, &ENTRY_TUBERCULARIZATION_15542666046560010756)],
        &[(0b01001, &ENTRY_TUBERCULARIZE_2157217058313355699)],
        &[(0b01001, &ENTRY_TUBERCULARIZED_12286997214844537953)],
        &[(0b01001, &ENTRY_TUBERCULARIZING_3929944679702207874)],
        &[(0b10010, &ENTRY_TUBERCULINIZATION_11797962637301639092)],
        &[(0b10010, &ENTRY_TUBERCULINIZATIONS_10141244678936649951)],
        &[(0b10010, &ENTRY_TUBERCULINIZE_15333531702912733903)],
        &[(0b10010, &ENTRY_TUBERCULINIZED_10816352629411587290)],
        &[(0b10010, &ENTRY_TUBERCULINIZES_13921009254488053820)],
        &[(0b10010, &ENTRY_TUBERCULINIZING_8221476597985863464)],
        &[(0b01001, &ENTRY_TUBERCULINIZATION_11797962637301639092)],
        &[(0b01001, &ENTRY_TUBERCULINIZATIONS_10141244678936649951)],
        &[(0b01001, &ENTRY_TUBERCULINIZE_15333531702912733903)],
        &[(0b01001, &ENTRY_TUBERCULINIZED_10816352629411587290)],
        &[(0b01001, &ENTRY_TUBERCULINIZES_13921009254488053820)],
        &[(0b01001, &ENTRY_TUBERCULINIZING_8221476597985863464)],
        &[(0b10010, &ENTRY_TUBERCULIZATION_12296149150456268539)],
        &[(0b10010, &ENTRY_TUBERCULIZATIONS_14781828629520022038)],
        &[(0b10010, &ENTRY_TUBERCULIZE_3450991821098593135)],
        &[(0b10010, &ENTRY_TUBERCULIZED_10329102836270681912)],
        &[(0b10010, &ENTRY_TUBERCULIZES_1677879746778356818)],
        &[(0b10010, &ENTRY_TUBERCULIZING_2357271713174376242)],
        &[(0b01001, &ENTRY_TUBERCULIZATION_12296149150456268539)],
        &[(0b01001, &ENTRY_TUBERCULIZATIONS_14781828629520022038)],
        &[(0b01001, &ENTRY_TUBERCULIZE_3450991821098593135)],
        &[(0b01001, &ENTRY_TUBERCULIZED_10329102836270681912)],
        &[(0b01001, &ENTRY_TUBERCULIZES_1677879746778356818)],
        &[(0b01001, &ENTRY_TUBERCULIZING_2357271713174376242)],
        &[(0b10010, &ENTRY_TUBERIZATION_10556809563684052487)],
        &[(0b10010, &ENTRY_TUBERIZATIONS_215616275751404145)],
        &[(0b10010, &ENTRY_TUBERIZE_865480950163325912)],
        &[(0b10010, &ENTRY_TUBERIZES_15708878588683938276)],
        &[(0b01001, &ENTRY_TUBERIZATION_10556809563684052487)],
        &[(0b01001, &ENTRY_TUBERIZATIONS_215616275751404145)],
        &[(0b01001, &ENTRY_TUBERIZE_865480950163325912)],
        &[(0b01001, &ENTRY_TUBERIZES_15708878588683938276)],
        &[(0b10010, &ENTRY_TUBULIZATION_12430780901128768431)],
        &[(0b10010, &ENTRY_TUBULIZATIONS_10015790438190867364)],
        &[(0b01001, &ENTRY_TUBULIZATION_12430780901128768431)],
        &[(0b01001, &ENTRY_TUBULIZATIONS_10015790438190867364)],
    ],
    range: 5..=15,
};

static VARS_TS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TS_CHILDREN),
    value: None,
};

pub static VARS_TS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oris"),
        dictgen::InsensitiveStr::Ascii("ouris"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TSORIS_14425139026522279430)],
        &[(0b11010, &ENTRY_TSORIS_14425139026522279430)],
    ],
    range: 4..=5,
};

static VARS_TR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TR_CHILDREN),
    value: None,
};

static VARS_TR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_TRA_NODE),
    None,
    None,
    None,
    Some(&VARS_TRE_NODE),
    None,
    None,
    None,
    Some(&VARS_TRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRU_NODE),
    None,
    None,
    None,
    Some(&VARS_TRY_NODE),
    None,
];

static VARS_TRY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRY_CHILDREN),
    value: None,
};

pub static VARS_TRY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("psinise"),
        dictgen::InsensitiveStr::Ascii("psinises"),
        dictgen::InsensitiveStr::Ascii("psinize"),
        dictgen::InsensitiveStr::Ascii("psinizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRYPSINIZE_11310311969110258138)],
        &[(0b10010, &ENTRY_TRYPSINIZES_9989364682025433845)],
        &[(0b01001, &ENTRY_TRYPSINIZE_11310311969110258138)],
        &[(0b01001, &ENTRY_TRYPSINIZES_9989364682025433845)],
    ],
    range: 7..=8,
};

static VARS_TRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRU_CHILDREN),
    value: None,
};

pub static VARS_TRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("benise"),
        dictgen::InsensitiveStr::Ascii("benised"),
        dictgen::InsensitiveStr::Ascii("benises"),
        dictgen::InsensitiveStr::Ascii("benising"),
        dictgen::InsensitiveStr::Ascii("benize"),
        dictgen::InsensitiveStr::Ascii("benized"),
        dictgen::InsensitiveStr::Ascii("benizes"),
        dictgen::InsensitiveStr::Ascii("benizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRUBENIZE_1720084137174182623)],
        &[(0b10010, &ENTRY_TRUBENIZED_12138523136394636595)],
        &[(0b10010, &ENTRY_TRUBENIZES_11904727106928842123)],
        &[(0b10010, &ENTRY_TRUBENIZING_6752069478438390648)],
        &[(0b01001, &ENTRY_TRUBENIZE_1720084137174182623)],
        &[(0b01001, &ENTRY_TRUBENIZED_12138523136394636595)],
        &[(0b01001, &ENTRY_TRUBENIZES_11904727106928842123)],
        &[(0b01001, &ENTRY_TRUBENIZING_6752069478438390648)],
    ],
    range: 6..=8,
};

static VARS_TRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRO_CHILDREN),
    value: None,
};

pub static VARS_TRO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("llied"),
        dictgen::InsensitiveStr::Ascii("llies"),
        dictgen::InsensitiveStr::Ascii("lly"),
        dictgen::InsensitiveStr::Ascii("llying"),
        dictgen::InsensitiveStr::Ascii("paeolin"),
        dictgen::InsensitiveStr::Ascii("peolin"),
        dictgen::InsensitiveStr::Ascii("picalisation"),
        dictgen::InsensitiveStr::Ascii("picalisations"),
        dictgen::InsensitiveStr::Ascii("picalise"),
        dictgen::InsensitiveStr::Ascii("picalised"),
        dictgen::InsensitiveStr::Ascii("picalises"),
        dictgen::InsensitiveStr::Ascii("picalising"),
        dictgen::InsensitiveStr::Ascii("picalization"),
        dictgen::InsensitiveStr::Ascii("picalizations"),
        dictgen::InsensitiveStr::Ascii("picalize"),
        dictgen::InsensitiveStr::Ascii("picalized"),
        dictgen::InsensitiveStr::Ascii("picalizes"),
        dictgen::InsensitiveStr::Ascii("picalizing"),
        dictgen::InsensitiveStr::Ascii("weled"),
        dictgen::InsensitiveStr::Ascii("weler"),
        dictgen::InsensitiveStr::Ascii("welers"),
        dictgen::InsensitiveStr::Ascii("weling"),
        dictgen::InsensitiveStr::Ascii("welled"),
        dictgen::InsensitiveStr::Ascii("weller"),
        dictgen::InsensitiveStr::Ascii("wellers"),
        dictgen::InsensitiveStr::Ascii("welling"),
    ],
    values: &[
        &[(0b01001, &ENTRY_TROLLEYED_16320990397285120378)],
        &[(0b01001, &ENTRY_TROLLEYS_18263143595174364530)],
        &[(0b01001, &ENTRY_TROLLEY_1793317771282721854)],
        &[(0b01001, &ENTRY_TROLLEYING_637696503258459274)],
        &[(0b11010, &ENTRY_TROPEOLIN_13501077771486427288)],
        &[(0b00001, &ENTRY_TROPEOLIN_13501077771486427288)],
        &[(0b10010, &ENTRY_TROPICALIZATION_280149473467881406)],
        &[(0b10010, &ENTRY_TROPICALIZATIONS_11359261593866683979)],
        &[(0b10010, &ENTRY_TROPICALIZE_12627151915334844007)],
        &[(0b10010, &ENTRY_TROPICALIZED_12626126161696724783)],
        &[(0b10010, &ENTRY_TROPICALIZES_10180779904224473997)],
        &[(0b10010, &ENTRY_TROPICALIZING_17779530954870328562)],
        &[(0b01001, &ENTRY_TROPICALIZATION_280149473467881406)],
        &[(0b01001, &ENTRY_TROPICALIZATIONS_11359261593866683979)],
        &[(0b01001, &ENTRY_TROPICALIZE_12627151915334844007)],
        &[(0b01001, &ENTRY_TROPICALIZED_12626126161696724783)],
        &[(0b01001, &ENTRY_TROPICALIZES_10180779904224473997)],
        &[(0b01001, &ENTRY_TROPICALIZING_17779530954870328562)],
        &[(0b00001, &ENTRY_TROWELED_4799678352682284187)],
        &[(0b00001, &ENTRY_TROWELER_16575642105606421144)],
        &[(0b00001, &ENTRY_TROWELERS_3014176820808259829)],
        &[(0b00001, &ENTRY_TROWELING_15187396834118954225)],
        &[(0b11010, &ENTRY_TROWELED_4799678352682284187)],
        &[(0b11010, &ENTRY_TROWELER_16575642105606421144)],
        &[(0b11010, &ENTRY_TROWELERS_3014176820808259829)],
        &[(0b11010, &ENTRY_TROWELING_15187396834118954225)],
    ],
    range: 3..=13,
};

static VARS_TRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TRI_CHILDREN),
    value: None,
};

static VARS_TRI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_TRIA_NODE),
    None,
    Some(&VARS_TRIC_NODE),
    None,
    Some(&VARS_TRIE_NODE),
    Some(&VARS_TRIF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRIL_NODE),
    Some(&VARS_TRIM_NODE),
    None,
    Some(&VARS_TRIO_NODE),
    Some(&VARS_TRIP_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_TRIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIV_CHILDREN),
    value: None,
};

pub static VARS_TRIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRIVIALIZATION_15415473767815002378)],
        &[(0b10010, &ENTRY_TRIVIALIZATIONS_7001355469538203417)],
        &[(0b10010, &ENTRY_TRIVIALIZE_18242589362817679930)],
        &[(0b10010, &ENTRY_TRIVIALIZED_7658877615119170597)],
        &[(0b10010, &ENTRY_TRIVIALIZES_12098662311152290426)],
        &[(0b10010, &ENTRY_TRIVIALIZING_11202764572056711533)],
        &[(0b01001, &ENTRY_TRIVIALIZATION_15415473767815002378)],
        &[(0b01001, &ENTRY_TRIVIALIZATIONS_7001355469538203417)],
        &[(0b01001, &ENTRY_TRIVIALIZE_18242589362817679930)],
        &[(0b01001, &ENTRY_TRIVIALIZED_7658877615119170597)],
        &[(0b01001, &ENTRY_TRIVIALIZES_12098662311152290426)],
        &[(0b01001, &ENTRY_TRIVIALIZING_11202764572056711533)],
    ],
    range: 6..=11,
};

static VARS_TRIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIP_CHILDREN),
    value: None,
};

pub static VARS_TRIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ylaean"),
        dictgen::InsensitiveStr::Ascii("ylean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TRIPYLEAN_10875065225907680531)],
        &[(0b00001, &ENTRY_TRIPYLEAN_10875065225907680531)],
    ],
    range: 5..=6,
};

static VARS_TRIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIO_CHILDREN),
    value: None,
};

pub static VARS_TRIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecious"),
        dictgen::InsensitiveStr::Ascii("eciously"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TRIECIOUS_13315610863197702350)],
        &[(0b11010, &ENTRY_TRIECIOUSLY_8350175444262968317)],
    ],
    range: 6..=8,
};

static VARS_TRIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIM_CHILDREN),
    value: None,
};

pub static VARS_TRIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRIMERIZATION_12375953829418021021)],
        &[(0b10010, &ENTRY_TRIMERIZATIONS_1022726125043168815)],
        &[(0b01001, &ENTRY_TRIMERIZATION_12375953829418021021)],
        &[(0b01001, &ENTRY_TRIMERIZATIONS_1022726125043168815)],
    ],
    range: 9..=10,
};

static VARS_TRIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIL_CHILDREN),
    value: None,
};

pub static VARS_TRIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lionise"),
        dictgen::InsensitiveStr::Ascii("lionises"),
        dictgen::InsensitiveStr::Ascii("lionize"),
        dictgen::InsensitiveStr::Ascii("lionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRILLIONIZE_2061247672357509542)],
        &[(0b10010, &ENTRY_TRILLIONIZES_10650478618693827922)],
        &[(0b01001, &ENTRY_TRILLIONIZE_2061247672357509542)],
        &[(0b01001, &ENTRY_TRILLIONIZES_10650478618693827922)],
    ],
    range: 7..=8,
};

static VARS_TRIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIF_CHILDREN),
    value: None,
};

pub static VARS_TRIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("luoride"),
        dictgen::InsensitiveStr::Ascii("luouride"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TRIFLUORIDE_7068061211011145761)],
        &[(0b11010, &ENTRY_TRIFLUORIDE_7068061211011145761)],
    ],
    range: 7..=8,
};

static VARS_TRIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIE_CHILDREN),
    value: None,
};

pub static VARS_TRIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("ciously"),
        dictgen::InsensitiveStr::Ascii("ne"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TRIECIOUS_13315610863197702350)],
        &[(0b00001, &ENTRY_TRIECIOUSLY_8350175444262968317)],
        &[(0b00001, &ENTRY_TRIENE_15794998642666208471)],
    ],
    range: 2..=7,
};

static VARS_TRIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIC_CHILDREN),
    value: None,
};

pub static VARS_TRIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hinisation"),
        dictgen::InsensitiveStr::Ascii("hinisations"),
        dictgen::InsensitiveStr::Ascii("hinise"),
        dictgen::InsensitiveStr::Ascii("hinised"),
        dictgen::InsensitiveStr::Ascii("hinises"),
        dictgen::InsensitiveStr::Ascii("hinising"),
        dictgen::InsensitiveStr::Ascii("hinization"),
        dictgen::InsensitiveStr::Ascii("hinizations"),
        dictgen::InsensitiveStr::Ascii("hinize"),
        dictgen::InsensitiveStr::Ascii("hinized"),
        dictgen::InsensitiveStr::Ascii("hinizes"),
        dictgen::InsensitiveStr::Ascii("hinizing"),
        dictgen::InsensitiveStr::Ascii("hlorethylene"),
        dictgen::InsensitiveStr::Ascii("hlorethylenes"),
        dictgen::InsensitiveStr::Ascii("hloroethylene"),
        dictgen::InsensitiveStr::Ascii("hloroethylenes"),
        dictgen::InsensitiveStr::Ascii("hotomise"),
        dictgen::InsensitiveStr::Ascii("hotomised"),
        dictgen::InsensitiveStr::Ascii("hotomises"),
        dictgen::InsensitiveStr::Ascii("hotomising"),
        dictgen::InsensitiveStr::Ascii("hotomize"),
        dictgen::InsensitiveStr::Ascii("hotomized"),
        dictgen::InsensitiveStr::Ascii("hotomizes"),
        dictgen::InsensitiveStr::Ascii("hotomizing"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRICHINIZATION_17095496984757617228)],
        &[(0b10010, &ENTRY_TRICHINIZATIONS_12374290002608454472)],
        &[(0b10010, &ENTRY_TRICHINIZE_5574846251210958831)],
        &[(0b10010, &ENTRY_TRICHINIZED_17644488673613289890)],
        &[(0b10010, &ENTRY_TRICHINIZES_1344045113327285956)],
        &[(0b10010, &ENTRY_TRICHINIZING_3545688560394153529)],
        &[(0b01001, &ENTRY_TRICHINIZATION_17095496984757617228)],
        &[(0b01001, &ENTRY_TRICHINIZATIONS_12374290002608454472)],
        &[(0b01001, &ENTRY_TRICHINIZE_5574846251210958831)],
        &[(0b01001, &ENTRY_TRICHINIZED_17644488673613289890)],
        &[(0b01001, &ENTRY_TRICHINIZES_1344045113327285956)],
        &[(0b01001, &ENTRY_TRICHINIZING_3545688560394153529)],
        &[(0b00001, &ENTRY_TRICHLORETHYLENE_9901005590441640862)],
        &[(0b00001, &ENTRY_TRICHLORETHYLENES_15772099121722073798)],
        &[(0b11010, &ENTRY_TRICHLORETHYLENE_9901005590441640862)],
        &[(0b11010, &ENTRY_TRICHLORETHYLENES_15772099121722073798)],
        &[(0b10010, &ENTRY_TRICHOTOMIZE_854533418810743207)],
        &[(0b10010, &ENTRY_TRICHOTOMIZED_3347768583083276490)],
        &[(0b10010, &ENTRY_TRICHOTOMIZES_17276637113087926760)],
        &[(0b10010, &ENTRY_TRICHOTOMIZING_4094867634668496821)],
        &[(0b01001, &ENTRY_TRICHOTOMIZE_854533418810743207)],
        &[(0b01001, &ENTRY_TRICHOTOMIZED_3347768583083276490)],
        &[(0b01001, &ENTRY_TRICHOTOMIZES_17276637113087926760)],
        &[(0b01001, &ENTRY_TRICHOTOMIZING_4094867634668496821)],
        &[(0b00001, &ENTRY_TRICOLOR_29934386578088381)],
        &[(0b00001, &ENTRY_TRICOLORED_14625827355822839152)],
        &[(0b00001, &ENTRY_TRICOLORS_5653354569553256367)],
        &[(0b11010, &ENTRY_TRICOLOR_29934386578088381)],
        &[(0b11010, &ENTRY_TRICOLORED_14625827355822839152)],
        &[(0b11010, &ENTRY_TRICOLORS_5653354569553256367)],
    ],
    range: 4..=14,
};

static VARS_TRIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRIA_CHILDREN),
    value: None,
};

pub static VARS_TRIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ene"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("ngularisation"),
        dictgen::InsensitiveStr::Ascii("ngularisations"),
        dictgen::InsensitiveStr::Ascii("ngularise"),
        dictgen::InsensitiveStr::Ascii("ngularised"),
        dictgen::InsensitiveStr::Ascii("ngularises"),
        dictgen::InsensitiveStr::Ascii("ngularising"),
        dictgen::InsensitiveStr::Ascii("ngularization"),
        dictgen::InsensitiveStr::Ascii("ngularizations"),
        dictgen::InsensitiveStr::Ascii("ngularize"),
        dictgen::InsensitiveStr::Ascii("ngularized"),
        dictgen::InsensitiveStr::Ascii("ngularizes"),
        dictgen::InsensitiveStr::Ascii("ngularizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TRIENE_15794998642666208471)],
        &[(0b00001, &ENTRY_TRIALED_10113550628054960808)],
        &[(0b00001, &ENTRY_TRIALING_6397065983321001404)],
        &[(0b10010, &ENTRY_TRIALIZATION_15902543461546982351)],
        &[(0b01001, &ENTRY_TRIALIZATION_15902543461546982351)],
        &[(0b11010, &ENTRY_TRIALED_10113550628054960808)],
        &[(0b11010, &ENTRY_TRIALING_6397065983321001404)],
        &[(0b10010, &ENTRY_TRIANGULARIZATION_5170297502596499934)],
        &[(0b10010, &ENTRY_TRIANGULARIZATIONS_9175876927610339412)],
        &[(0b10010, &ENTRY_TRIANGULARIZE_6075796262826371207)],
        &[(0b10010, &ENTRY_TRIANGULARIZED_8399601922283134135)],
        &[(0b10010, &ENTRY_TRIANGULARIZES_2309859741267387471)],
        &[(0b10010, &ENTRY_TRIANGULARIZING_6298865978999024428)],
        &[(0b01001, &ENTRY_TRIANGULARIZATION_5170297502596499934)],
        &[(0b01001, &ENTRY_TRIANGULARIZATIONS_9175876927610339412)],
        &[(0b01001, &ENTRY_TRIANGULARIZE_6075796262826371207)],
        &[(0b01001, &ENTRY_TRIANGULARIZED_8399601922283134135)],
        &[(0b01001, &ENTRY_TRIANGULARIZES_2309859741267387471)],
        &[(0b01001, &ENTRY_TRIANGULARIZING_6298865978999024428)],
    ],
    range: 3..=14,
};

static VARS_TRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRE_CHILDREN),
    value: None,
};

pub static VARS_TRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("f"),
        dictgen::InsensitiveStr::Ascii("ma"),
        dictgen::InsensitiveStr::Ascii("matic"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TERF_3510176223973213714)],
        &[(0b11010, &ENTRY_TERMA_12658799001593884461)],
        &[(0b11010, &ENTRY_TERMATIC_575294056877958757)],
        &[(0b11010, &ENTRY_TERTS_15921222583797171907)],
    ],
    range: 1..=5,
};

static VARS_TRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TRA_CHILDREN),
    value: None,
};

static VARS_TRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_TRAB_NODE),
    Some(&VARS_TRAC_NODE),
    Some(&VARS_TRAD_NODE),
    None,
    None,
    Some(&VARS_TRAG_NODE),
    None,
    Some(&VARS_TRAI_NODE),
    None,
    None,
    None,
    Some(&VARS_TRAM_NODE),
    Some(&VARS_TRAN_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRAU_NODE),
    Some(&VARS_TRAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_TRAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAV_CHILDREN),
    value: None,
};

pub static VARS_TRAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
        dictgen::InsensitiveStr::Ascii("elog"),
        dictgen::InsensitiveStr::Ascii("elogs"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TRAVELED_7471204723840738059)],
        &[(0b00001, &ENTRY_TRAVELER_13674641254214006714)],
        &[(0b00001, &ENTRY_TRAVELERS_534480827925386728)],
        &[(0b00001, &ENTRY_TRAVELING_15330546315886302191)],
        &[(0b00001, &ENTRY_TRAVELINGS_4473114144843360272)],
        &[(0b11010, &ENTRY_TRAVELED_7471204723840738059)],
        &[(0b11010, &ENTRY_TRAVELER_13674641254214006714)],
        &[(0b11010, &ENTRY_TRAVELERS_534480827925386728)],
        &[(0b11010, &ENTRY_TRAVELING_15330546315886302191)],
        &[(0b11010, &ENTRY_TRAVELINGS_4473114144843360272)],
        &[(0b00001, &ENTRY_TRAVELOGUE_9832945069166970827)],
        &[(0b00001, &ENTRY_TRAVELOGUES_4261693774497596751)],
    ],
    range: 4..=7,
};

static VARS_TRAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAU_CHILDREN),
    value: None,
};

pub static VARS_TRAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matisations"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matizations"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRAUMATIZATION_3746681776679931423)],
        &[(0b10010, &ENTRY_TRAUMATIZATIONS_7417106584297477223)],
        &[(0b10010, &ENTRY_TRAUMATIZE_8649856127609129608)],
        &[(0b10010, &ENTRY_TRAUMATIZED_7431966359976446213)],
        &[(0b10010, &ENTRY_TRAUMATIZES_4330104088006808909)],
        &[(0b10010, &ENTRY_TRAUMATIZING_2918929651955345564)],
        &[(0b01001, &ENTRY_TRAUMATIZATION_3746681776679931423)],
        &[(0b01001, &ENTRY_TRAUMATIZATIONS_7417106584297477223)],
        &[(0b01001, &ENTRY_TRAUMATIZE_8649856127609129608)],
        &[(0b01001, &ENTRY_TRAUMATIZED_7431966359976446213)],
        &[(0b01001, &ENTRY_TRAUMATIZES_4330104088006808909)],
        &[(0b01001, &ENTRY_TRAUMATIZING_2918929651955345564)],
    ],
    range: 6..=11,
};

static VARS_TRAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TRAN_CHILDREN),
    value: None,
};

static VARS_TRAN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TRANQ_NODE),
    None,
    Some(&VARS_TRANS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_TRANS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRANS_CHILDREN),
    value: None,
};

pub static VARS_TRANS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cendentalisation"),
        dictgen::InsensitiveStr::Ascii("cendentalise"),
        dictgen::InsensitiveStr::Ascii("cendentalised"),
        dictgen::InsensitiveStr::Ascii("cendentalises"),
        dictgen::InsensitiveStr::Ascii("cendentalising"),
        dictgen::InsensitiveStr::Ascii("cendentalization"),
        dictgen::InsensitiveStr::Ascii("cendentalize"),
        dictgen::InsensitiveStr::Ascii("cendentalized"),
        dictgen::InsensitiveStr::Ascii("cendentalizes"),
        dictgen::InsensitiveStr::Ascii("cendentalizing"),
        dictgen::InsensitiveStr::Ascii("color"),
        dictgen::InsensitiveStr::Ascii("coloration"),
        dictgen::InsensitiveStr::Ascii("colorations"),
        dictgen::InsensitiveStr::Ascii("colorrer"),
        dictgen::InsensitiveStr::Ascii("colorrest"),
        dictgen::InsensitiveStr::Ascii("colour"),
        dictgen::InsensitiveStr::Ascii("colouration"),
        dictgen::InsensitiveStr::Ascii("colourations"),
        dictgen::InsensitiveStr::Ascii("colourer"),
        dictgen::InsensitiveStr::Ascii("colourest"),
        dictgen::InsensitiveStr::Ascii("istorisation"),
        dictgen::InsensitiveStr::Ascii("istorisations"),
        dictgen::InsensitiveStr::Ascii("istorise"),
        dictgen::InsensitiveStr::Ascii("istorised"),
        dictgen::InsensitiveStr::Ascii("istorises"),
        dictgen::InsensitiveStr::Ascii("istorising"),
        dictgen::InsensitiveStr::Ascii("istorization"),
        dictgen::InsensitiveStr::Ascii("istorizations"),
        dictgen::InsensitiveStr::Ascii("istorize"),
        dictgen::InsensitiveStr::Ascii("istorized"),
        dictgen::InsensitiveStr::Ascii("istorizes"),
        dictgen::InsensitiveStr::Ascii("istorizing"),
        dictgen::InsensitiveStr::Ascii("parentise"),
        dictgen::InsensitiveStr::Ascii("parentises"),
        dictgen::InsensitiveStr::Ascii("parentize"),
        dictgen::InsensitiveStr::Ascii("parentizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRANSCENDENTALIZATION_16279978221157892606)],
        &[(0b10010, &ENTRY_TRANSCENDENTALIZE_12477449740073762039)],
        &[(0b10010, &ENTRY_TRANSCENDENTALIZED_1811227647892991582)],
        &[(0b10010, &ENTRY_TRANSCENDENTALIZES_256586495310370731)],
        &[(0b10010, &ENTRY_TRANSCENDENTALIZING_1803732975904952155)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZATION_16279978221157892606)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZE_12477449740073762039)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZED_1811227647892991582)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZES_256586495310370731)],
        &[(0b01001, &ENTRY_TRANSCENDENTALIZING_1803732975904952155)],
        &[(0b00001, &ENTRY_TRANSCOLOR_3566969815815539331)],
        &[(0b00001, &ENTRY_TRANSCOLORATION_343129450671874835)],
        &[(0b00001, &ENTRY_TRANSCOLORATIONS_16758395443174056843)],
        &[(0b00001, &ENTRY_TRANSCOLORRER_4795645889162012189)],
        &[(0b00001, &ENTRY_TRANSCOLORREST_13178604266626958240)],
        &[(0b11010, &ENTRY_TRANSCOLOR_3566969815815539331)],
        &[(0b11010, &ENTRY_TRANSCOLORATION_343129450671874835)],
        &[(0b11010, &ENTRY_TRANSCOLORATIONS_16758395443174056843)],
        &[(0b11010, &ENTRY_TRANSCOLORRER_4795645889162012189)],
        &[(0b11010, &ENTRY_TRANSCOLORREST_13178604266626958240)],
        &[(0b10010, &ENTRY_TRANSISTORIZATION_1936290593265769427)],
        &[(0b10010, &ENTRY_TRANSISTORIZATIONS_15440922126340456777)],
        &[(0b10010, &ENTRY_TRANSISTORIZE_14955480539617938425)],
        &[(0b10010, &ENTRY_TRANSISTORIZED_15135482287551822492)],
        &[(0b10010, &ENTRY_TRANSISTORIZES_1343939411237171803)],
        &[(0b10010, &ENTRY_TRANSISTORIZING_10767950521341986252)],
        &[(0b01001, &ENTRY_TRANSISTORIZATION_1936290593265769427)],
        &[(0b01001, &ENTRY_TRANSISTORIZATIONS_15440922126340456777)],
        &[(0b01001, &ENTRY_TRANSISTORIZE_14955480539617938425)],
        &[(0b01001, &ENTRY_TRANSISTORIZED_15135482287551822492)],
        &[(0b01001, &ENTRY_TRANSISTORIZES_1343939411237171803)],
        &[(0b01001, &ENTRY_TRANSISTORIZING_10767950521341986252)],
        &[(0b10010, &ENTRY_TRANSPARENTIZE_1817106363462334768)],
        &[(0b10010, &ENTRY_TRANSPARENTIZES_9410899145545451286)],
        &[(0b01001, &ENTRY_TRANSPARENTIZE_1817106363462334768)],
        &[(0b01001, &ENTRY_TRANSPARENTIZES_9410899145545451286)],
    ],
    range: 5..=16,
};

static VARS_TRANQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRANQ_CHILDREN),
    value: None,
};

pub static VARS_TRANQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uilisation"),
        dictgen::InsensitiveStr::Ascii("uilisations"),
        dictgen::InsensitiveStr::Ascii("uilisingly"),
        dictgen::InsensitiveStr::Ascii("uilization"),
        dictgen::InsensitiveStr::Ascii("uilizations"),
        dictgen::InsensitiveStr::Ascii("uilize"),
        dictgen::InsensitiveStr::Ascii("uilized"),
        dictgen::InsensitiveStr::Ascii("uilizer"),
        dictgen::InsensitiveStr::Ascii("uilizers"),
        dictgen::InsensitiveStr::Ascii("uilizes"),
        dictgen::InsensitiveStr::Ascii("uilizing"),
        dictgen::InsensitiveStr::Ascii("uilizingly"),
        dictgen::InsensitiveStr::Ascii("uilizings"),
        dictgen::InsensitiveStr::Ascii("uillisation"),
        dictgen::InsensitiveStr::Ascii("uillisations"),
        dictgen::InsensitiveStr::Ascii("uillise"),
        dictgen::InsensitiveStr::Ascii("uillised"),
        dictgen::InsensitiveStr::Ascii("uilliser"),
        dictgen::InsensitiveStr::Ascii("uillisers"),
        dictgen::InsensitiveStr::Ascii("uillises"),
        dictgen::InsensitiveStr::Ascii("uillising"),
        dictgen::InsensitiveStr::Ascii("uillisingly"),
        dictgen::InsensitiveStr::Ascii("uillisings"),
        dictgen::InsensitiveStr::Ascii("uillities"),
        dictgen::InsensitiveStr::Ascii("uillity"),
        dictgen::InsensitiveStr::Ascii("uillization"),
        dictgen::InsensitiveStr::Ascii("uillizations"),
        dictgen::InsensitiveStr::Ascii("uillize"),
        dictgen::InsensitiveStr::Ascii("uillized"),
        dictgen::InsensitiveStr::Ascii("uillizer"),
        dictgen::InsensitiveStr::Ascii("uillizers"),
        dictgen::InsensitiveStr::Ascii("uillizes"),
        dictgen::InsensitiveStr::Ascii("uillizing"),
        dictgen::InsensitiveStr::Ascii("uillizingly"),
        dictgen::InsensitiveStr::Ascii("uillizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRANQUILIZATION_14846255753979813760)],
        &[(0b10010, &ENTRY_TRANQUILIZATIONS_17619573841316216935)],
        &[(0b10010, &ENTRY_TRANQUILIZINGLY_556670129841874355)],
        &[(0b01001, &ENTRY_TRANQUILIZATION_14846255753979813760)],
        &[(0b01001, &ENTRY_TRANQUILIZATIONS_17619573841316216935)],
        &[(0b01001, &ENTRY_TRANQUILIZE_10282286664857910461)],
        &[(0b01001, &ENTRY_TRANQUILIZED_8802666398177881938)],
        &[(0b01001, &ENTRY_TRANQUILIZER_2761665163152313094)],
        &[(0b01001, &ENTRY_TRANQUILIZERS_17103334183302096096)],
        &[(0b01001, &ENTRY_TRANQUILIZES_59757620788033573)],
        &[(0b01001, &ENTRY_TRANQUILIZING_13850716228820534198)],
        &[(0b01001, &ENTRY_TRANQUILIZINGLY_556670129841874355)],
        &[(0b01001, &ENTRY_TRANQUILIZINGS_2266773302059369088)],
        &[(0b10010, &ENTRY_TRANQUILLIZATION_11946857030526310268)],
        &[(0b10010, &ENTRY_TRANQUILLIZATIONS_4263826721380617410)],
        &[(0b11010, &ENTRY_TRANQUILIZE_10282286664857910461)],
        &[(0b11010, &ENTRY_TRANQUILIZED_8802666398177881938)],
        &[(0b11010, &ENTRY_TRANQUILIZER_2761665163152313094)],
        &[(0b11010, &ENTRY_TRANQUILIZERS_17103334183302096096)],
        &[(0b11010, &ENTRY_TRANQUILIZES_59757620788033573)],
        &[(0b11010, &ENTRY_TRANQUILIZING_13850716228820534198)],
        &[(0b10010, &ENTRY_TRANQUILLIZINGLY_14381964317822750722)],
        &[(0b11010, &ENTRY_TRANQUILIZINGS_2266773302059369088)],
        &[(0b10011, &ENTRY_TRANQUILITIES_16195163391619170068)],
        &[(0b10011, &ENTRY_TRANQUILITY_8540551709960885595)],
        &[(0b01001, &ENTRY_TRANQUILLIZATION_11946857030526310268)],
        &[(0b01001, &ENTRY_TRANQUILLIZATIONS_4263826721380617410)],
        &[(0b01001, &ENTRY_TRANQUILIZE_10282286664857910461)],
        &[(0b01001, &ENTRY_TRANQUILIZED_8802666398177881938)],
        &[(0b01001, &ENTRY_TRANQUILIZER_2761665163152313094)],
        &[(0b01001, &ENTRY_TRANQUILIZERS_17103334183302096096)],
        &[(0b01001, &ENTRY_TRANQUILIZES_59757620788033573)],
        &[(0b01001, &ENTRY_TRANQUILIZING_13850716228820534198)],
        &[(0b01001, &ENTRY_TRANQUILLIZINGLY_14381964317822750722)],
        &[(0b01001, &ENTRY_TRANQUILIZINGS_2266773302059369088)],
    ],
    range: 6..=12,
};

static VARS_TRAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAM_CHILDREN),
    value: None,
};

pub static VARS_TRAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("meled"),
        dictgen::InsensitiveStr::Ascii("meler"),
        dictgen::InsensitiveStr::Ascii("melers"),
        dictgen::InsensitiveStr::Ascii("meling"),
        dictgen::InsensitiveStr::Ascii("melled"),
        dictgen::InsensitiveStr::Ascii("meller"),
        dictgen::InsensitiveStr::Ascii("mellers"),
        dictgen::InsensitiveStr::Ascii("melling"),
    ],
    values: &[
        &[(0b01001, &ENTRY_TRAMMELED_7321238481699131765)],
        &[(0b00001, &ENTRY_TRAMMELER_1286061836358212954)],
        &[(0b00001, &ENTRY_TRAMMELERS_8202463777486458185)],
        &[(0b01001, &ENTRY_TRAMMELING_2641971254351085893)],
        &[(0b11010, &ENTRY_TRAMMELED_7321238481699131765)],
        &[(0b11010, &ENTRY_TRAMMELER_1286061836358212954)],
        &[(0b11010, &ENTRY_TRAMMELERS_8202463777486458185)],
        &[(0b11010, &ENTRY_TRAMMELING_2641971254351085893)],
    ],
    range: 5..=7,
};

static VARS_TRAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAI_CHILDREN),
    value: None,
};

pub static VARS_TRAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRAITORIZE_551131030474656423)],
        &[(0b10010, &ENTRY_TRAITORIZES_16161164434011189838)],
        &[(0b01001, &ENTRY_TRAITORIZE_551131030474656423)],
        &[(0b01001, &ENTRY_TRAITORIZES_16161164434011189838)],
    ],
    range: 6..=7,
};

static VARS_TRAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAG_CHILDREN),
    value: None,
};

pub static VARS_TRAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icolored"),
        dictgen::InsensitiveStr::Ascii("icoloured"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRAGICIZE_957780290072315119)],
        &[(0b10010, &ENTRY_TRAGICIZES_17519202874941904760)],
        &[(0b01001, &ENTRY_TRAGICIZE_957780290072315119)],
        &[(0b01001, &ENTRY_TRAGICIZES_17519202874941904760)],
        &[(0b00001, &ENTRY_TRAGICOLORED_13278772284942211165)],
        &[(0b11010, &ENTRY_TRAGICOLORED_13278772284942211165)],
    ],
    range: 5..=9,
};

static VARS_TRAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAD_CHILDREN),
    value: None,
};

pub static VARS_TRAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itionalise"),
        dictgen::InsensitiveStr::Ascii("itionalised"),
        dictgen::InsensitiveStr::Ascii("itionalises"),
        dictgen::InsensitiveStr::Ascii("itionalize"),
        dictgen::InsensitiveStr::Ascii("itionalized"),
        dictgen::InsensitiveStr::Ascii("itionalizes"),
        dictgen::InsensitiveStr::Ascii("itionise"),
        dictgen::InsensitiveStr::Ascii("itionises"),
        dictgen::InsensitiveStr::Ascii("itionize"),
        dictgen::InsensitiveStr::Ascii("itionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRADITIONALIZE_4898176225220743845)],
        &[(0b10010, &ENTRY_TRADITIONALIZED_2635338649308214147)],
        &[(0b10010, &ENTRY_TRADITIONALIZES_17884375175492170718)],
        &[(0b01001, &ENTRY_TRADITIONALIZE_4898176225220743845)],
        &[(0b01001, &ENTRY_TRADITIONALIZED_2635338649308214147)],
        &[(0b01001, &ENTRY_TRADITIONALIZES_17884375175492170718)],
        &[(0b10010, &ENTRY_TRADITIONIZE_11047234467125040571)],
        &[(0b10010, &ENTRY_TRADITIONIZES_18011235531342430501)],
        &[(0b01001, &ENTRY_TRADITIONIZE_11047234467125040571)],
        &[(0b01001, &ENTRY_TRADITIONIZES_18011235531342430501)],
    ],
    range: 8..=11,
};

static VARS_TRAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAC_CHILDREN),
    value: None,
};

pub static VARS_TRAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TRACTORIZATION_3823073726188841416)],
        &[(0b10010, &ENTRY_TRACTORIZATIONS_18210642849375336921)],
        &[(0b10010, &ENTRY_TRACTORIZE_12965430895282931565)],
        &[(0b10010, &ENTRY_TRACTORIZES_5631147609434218207)],
        &[(0b01001, &ENTRY_TRACTORIZATION_3823073726188841416)],
        &[(0b01001, &ENTRY_TRACTORIZATIONS_18210642849375336921)],
        &[(0b01001, &ENTRY_TRACTORIZE_12965430895282931565)],
        &[(0b01001, &ENTRY_TRACTORIZES_5631147609434218207)],
    ],
    range: 6..=11,
};

static VARS_TRAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TRAB_CHILDREN),
    value: None,
};

pub static VARS_TRAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eatae"),
        dictgen::InsensitiveStr::Ascii("eate"),
        dictgen::InsensitiveStr::Ascii("eculae"),
        dictgen::InsensitiveStr::Ascii("ecule"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TRABEATE_475272284513241921)],
        &[(0b00001, &ENTRY_TRABEATE_475272284513241921)],
        &[(0b11010, &ENTRY_TRABECULE_4746018401275580221)],
        &[(0b00001, &ENTRY_TRABECULE_4746018401275580221)],
    ],
    range: 4..=6,
};

static VARS_TO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TO_CHILDREN),
    value: None,
};

static VARS_TO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_TON_NODE),
    None,
    Some(&VARS_TOP_NODE),
    None,
    Some(&VARS_TOR_NODE),
    None,
    Some(&VARS_TOT_NODE),
    Some(&VARS_TOU_NODE),
    None,
    Some(&VARS_TOW_NODE),
    Some(&VARS_TOX_NODE),
    None,
    None,
];

static VARS_TOX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOX_CHILDREN),
    value: None,
};

pub static VARS_TOX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemias"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("anaemia"),
        dictgen::InsensitiveStr::Ascii("anemia"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("icaemia"),
        dictgen::InsensitiveStr::Ascii("icemia"),
        dictgen::InsensitiveStr::Ascii("icohaemia"),
        dictgen::InsensitiveStr::Ascii("icohemia"),
        dictgen::InsensitiveStr::Ascii("ihaemia"),
        dictgen::InsensitiveStr::Ascii("ihemia"),
        dictgen::InsensitiveStr::Ascii("inaemia"),
        dictgen::InsensitiveStr::Ascii("inemia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TOXEMIA_13728114455609378495)],
        &[(0b10010, &ENTRY_TOXEMIAS_16145092731975598632)],
        &[(0b10010, &ENTRY_TOXEMIC_3847368103673580332)],
        &[(0b11010, &ENTRY_TOXANEMIA_5092978943692773401)],
        &[(0b00001, &ENTRY_TOXANEMIA_5092978943692773401)],
        &[(0b11001, &ENTRY_TOXEMIA_13728114455609378495)],
        &[(0b11001, &ENTRY_TOXEMIAS_16145092731975598632)],
        &[(0b11001, &ENTRY_TOXEMIC_3847368103673580332)],
        &[(0b11010, &ENTRY_TOXICEMIA_3221713968588738388)],
        &[(0b00001, &ENTRY_TOXICEMIA_3221713968588738388)],
        &[(0b11010, &ENTRY_TOXICOHEMIA_1510663382315935096)],
        &[(0b00001, &ENTRY_TOXICOHEMIA_1510663382315935096)],
        &[(0b11010, &ENTRY_TOXIHEMIA_17949081455236710796)],
        &[(0b00001, &ENTRY_TOXIHEMIA_17949081455236710796)],
        &[(0b11010, &ENTRY_TOXINEMIA_4067816496926950076)],
        &[(0b00001, &ENTRY_TOXINEMIA_4067816496926950076)],
    ],
    range: 4..=9,
};

static VARS_TOW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOW_CHILDREN),
    value: None,
};

pub static VARS_TOW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TOWELED_15166488210792177793)],
        &[(0b00001, &ENTRY_TOWELING_4481362776063713769)],
        &[(0b00001, &ENTRY_TOWELINGS_6911217900542580416)],
        &[(0b11010, &ENTRY_TOWELED_15166488210792177793)],
        &[(0b11010, &ENTRY_TOWELING_4481362776063713769)],
        &[(0b11010, &ENTRY_TOWELINGS_6911217900542580416)],
    ],
    range: 4..=7,
};

static VARS_TOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOU_CHILDREN),
    value: None,
};

pub static VARS_TOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ret"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TORET_14642122393715101008)],
        &[(0b10010, &ENTRY_TOURIZE_4416339355326535837)],
        &[(0b10010, &ENTRY_TOURIZES_16287459104895480818)],
        &[(0b01001, &ENTRY_TOURIZE_4416339355326535837)],
        &[(0b01001, &ENTRY_TOURIZES_16287459104895480818)],
    ],
    range: 3..=5,
};

static VARS_TOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOT_CHILDREN),
    value: None,
};

pub static VARS_TOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("aler"),
        dictgen::InsensitiveStr::Ascii("alers"),
        dictgen::InsensitiveStr::Ascii("aling"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alisator"),
        dictgen::InsensitiveStr::Ascii("alisators"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alitarianise"),
        dictgen::InsensitiveStr::Ascii("alitarianize"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alizator"),
        dictgen::InsensitiveStr::Ascii("alizators"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("aller"),
        dictgen::InsensitiveStr::Ascii("allers"),
        dictgen::InsensitiveStr::Ascii("alling"),
        dictgen::InsensitiveStr::Ascii("emisation"),
        dictgen::InsensitiveStr::Ascii("emisations"),
        dictgen::InsensitiveStr::Ascii("emization"),
        dictgen::InsensitiveStr::Ascii("emizations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TOTALED_6013017983757467705)],
        &[(0b00001, &ENTRY_TOTALER_10727979907060022636)],
        &[(0b00001, &ENTRY_TOTALERS_3867797254055796802)],
        &[(0b00001, &ENTRY_TOTALING_9913720993762819432)],
        &[(0b10010, &ENTRY_TOTALIZATION_3221716119411894800)],
        &[(0b10010, &ENTRY_TOTALIZATIONS_16093531371594133063)],
        &[(0b11010, &ENTRY_TOTALIZATOR_8226180587584060233)],
        &[(0b11010, &ENTRY_TOTALIZATORS_8640164609623735800)],
        &[(0b10010, &ENTRY_TOTALIZE_2473362082375699734)],
        &[(0b10010, &ENTRY_TOTALIZED_13767793031901840125)],
        &[(0b10010, &ENTRY_TOTALIZER_10517738673224079027)],
        &[(0b10010, &ENTRY_TOTALIZERS_15548921713961085912)],
        &[(0b10010, &ENTRY_TOTALIZES_6721705970426925276)],
        &[(0b10010, &ENTRY_TOTALIZING_11500628009269088151)],
        &[(0b10010, &ENTRY_TOTALITARIANIZE_8599233737485608940)],
        &[(0b01001, &ENTRY_TOTALITARIANIZE_8599233737485608940)],
        &[(0b01001, &ENTRY_TOTALIZATION_3221716119411894800)],
        &[(0b01001, &ENTRY_TOTALIZATIONS_16093531371594133063)],
        &[(0b00001, &ENTRY_TOTALIZATOR_8226180587584060233)],
        &[(0b00001, &ENTRY_TOTALIZATORS_8640164609623735800)],
        &[(0b01001, &ENTRY_TOTALIZE_2473362082375699734)],
        &[(0b01001, &ENTRY_TOTALIZED_13767793031901840125)],
        &[(0b01001, &ENTRY_TOTALIZER_10517738673224079027)],
        &[(0b01001, &ENTRY_TOTALIZERS_15548921713961085912)],
        &[(0b01001, &ENTRY_TOTALIZES_6721705970426925276)],
        &[(0b01001, &ENTRY_TOTALIZING_11500628009269088151)],
        &[(0b11010, &ENTRY_TOTALED_6013017983757467705)],
        &[(0b11010, &ENTRY_TOTALER_10727979907060022636)],
        &[(0b11010, &ENTRY_TOTALERS_3867797254055796802)],
        &[(0b11010, &ENTRY_TOTALING_9913720993762819432)],
        &[(0b10010, &ENTRY_TOTEMIZATION_17547511589554648221)],
        &[(0b10010, &ENTRY_TOTEMIZATIONS_4524480269908097645)],
        &[(0b01001, &ENTRY_TOTEMIZATION_17547511589554648221)],
        &[(0b01001, &ENTRY_TOTEMIZATIONS_4524480269908097645)],
    ],
    range: 4..=12,
};

static VARS_TOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOR_CHILDREN),
    value: None,
};

pub static VARS_TOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("porise"),
        dictgen::InsensitiveStr::Ascii("porises"),
        dictgen::InsensitiveStr::Ascii("porize"),
        dictgen::InsensitiveStr::Ascii("porizes"),
        dictgen::InsensitiveStr::Ascii("yise"),
        dictgen::InsensitiveStr::Ascii("yises"),
        dictgen::InsensitiveStr::Ascii("yize"),
        dictgen::InsensitiveStr::Ascii("yizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TORET_14642122393715101008)],
        &[(0b10010, &ENTRY_TORPORIZE_18297824631247427015)],
        &[(0b10010, &ENTRY_TORPORIZES_7515131355757541341)],
        &[(0b01001, &ENTRY_TORPORIZE_18297824631247427015)],
        &[(0b01001, &ENTRY_TORPORIZES_7515131355757541341)],
        &[(0b10010, &ENTRY_TORYIZE_10210463142410101593)],
        &[(0b10010, &ENTRY_TORYIZES_2714307057530869042)],
        &[(0b01001, &ENTRY_TORYIZE_10210463142410101593)],
        &[(0b01001, &ENTRY_TORYIZES_2714307057530869042)],
    ],
    range: 2..=7,
};

static VARS_TOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TOP_CHILDREN),
    value: None,
};

pub static VARS_TOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TOPESTHESIA_9952864993680466403)],
        &[(0b00001, &ENTRY_TOPESTHESIA_9952864993680466403)],
    ],
    range: 8..=9,
};

static VARS_TON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TON_CHILDREN),
    value: None,
};

pub static VARS_TON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TONICIZE_2289940295082319741)],
        &[(0b10010, &ENTRY_TONICIZES_17805405285162444673)],
        &[(0b01001, &ENTRY_TONICIZE_2289940295082319741)],
        &[(0b01001, &ENTRY_TONICIZES_17805405285162444673)],
    ],
    range: 5..=6,
};

static VARS_TI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TI_CHILDREN),
    value: None,
};

pub static VARS_TI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dbit"),
        dictgen::InsensitiveStr::Ascii("dbits"),
        dictgen::InsensitiveStr::Ascii("llford"),
        dictgen::InsensitiveStr::Ascii("llfourd"),
        dictgen::InsensitiveStr::Ascii("monise"),
        dictgen::InsensitiveStr::Ascii("monised"),
        dictgen::InsensitiveStr::Ascii("monises"),
        dictgen::InsensitiveStr::Ascii("monising"),
        dictgen::InsensitiveStr::Ascii("monize"),
        dictgen::InsensitiveStr::Ascii("monized"),
        dictgen::InsensitiveStr::Ascii("monizes"),
        dictgen::InsensitiveStr::Ascii("monizing"),
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mour"),
        dictgen::InsensitiveStr::Ascii("nseled"),
        dictgen::InsensitiveStr::Ascii("nselier"),
        dictgen::InsensitiveStr::Ascii("nseliest"),
        dictgen::InsensitiveStr::Ascii("nseling"),
        dictgen::InsensitiveStr::Ascii("nselled"),
        dictgen::InsensitiveStr::Ascii("nsellier"),
        dictgen::InsensitiveStr::Ascii("nselliest"),
        dictgen::InsensitiveStr::Ascii("nselling"),
        dictgen::InsensitiveStr::Ascii("tbit"),
        dictgen::InsensitiveStr::Ascii("tbits"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
        dictgen::InsensitiveStr::Ascii("ttuped"),
        dictgen::InsensitiveStr::Ascii("ttuping"),
        dictgen::InsensitiveStr::Ascii("ttupped"),
        dictgen::InsensitiveStr::Ascii("ttupping"),
        dictgen::InsensitiveStr::Ascii("ttuppy"),
        dictgen::InsensitiveStr::Ascii("ttupy"),
    ],
    values: &[
        &[(0b01001, &ENTRY_TIDBIT_14858433395468188521)],
        &[(0b01001, &ENTRY_TIDBITS_8862313789168390887)],
        &[(0b00001, &ENTRY_TILLFORD_13927963203563990910)],
        &[(0b11010, &ENTRY_TILLFORD_13927963203563990910)],
        &[(0b10010, &ENTRY_TIMONIZE_4384316048230541265)],
        &[(0b10010, &ENTRY_TIMONIZED_3807325960951210177)],
        &[(0b10010, &ENTRY_TIMONIZES_16589660513575137498)],
        &[(0b10010, &ENTRY_TIMONIZING_13953660282542190706)],
        &[(0b01001, &ENTRY_TIMONIZE_4384316048230541265)],
        &[(0b01001, &ENTRY_TIMONIZED_3807325960951210177)],
        &[(0b01001, &ENTRY_TIMONIZES_16589660513575137498)],
        &[(0b01001, &ENTRY_TIMONIZING_13953660282542190706)],
        &[(0b00001, &ENTRY_TIMOR_2867687196301196005)],
        &[(0b11010, &ENTRY_TIMOR_2867687196301196005)],
        &[(0b01001, &ENTRY_TINSELED_9574695065168366382)],
        &[(0b00001, &ENTRY_TINSELIER_17862744387346717732)],
        &[(0b00001, &ENTRY_TINSELIEST_10796385662191046623)],
        &[(0b01001, &ENTRY_TINSELING_15422200188036739484)],
        &[(0b11010, &ENTRY_TINSELED_9574695065168366382)],
        &[(0b11010, &ENTRY_TINSELIER_17862744387346717732)],
        &[(0b11010, &ENTRY_TINSELIEST_10796385662191046623)],
        &[(0b11010, &ENTRY_TINSELING_15422200188036739484)],
        &[(0b10011, &ENTRY_TIDBIT_14858433395468188521)],
        &[(0b10011, &ENTRY_TIDBITS_8862313789168390887)],
        &[(0b01001, &ENTRY_TITER_3432959079810131995)],
        &[(0b01001, &ENTRY_TITERS_16256818623137143269)],
        &[(0b11010, &ENTRY_TITER_3432959079810131995)],
        &[(0b11010, &ENTRY_TITERS_16256818623137143269)],
        &[(0b00001, &ENTRY_TITTUPED_18032143166294150502)],
        &[(0b00001, &ENTRY_TITTUPING_5945965916177916410)],
        &[(0b11010, &ENTRY_TITTUPED_18032143166294150502)],
        &[(0b11010, &ENTRY_TITTUPING_5945965916177916410)],
        &[(0b11010, &ENTRY_TITTUPY_1440027282222835899)],
        &[(0b00001, &ENTRY_TITTUPY_1440027282222835899)],
    ],
    range: 3..=9,
};

static VARS_TH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TH_CHILDREN),
    value: None,
};

static VARS_TH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_THA_NODE),
    None,
    None,
    None,
    Some(&VARS_THE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_THR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_THY_NODE),
    None,
];

static VARS_THY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THY_CHILDREN),
    value: None,
};

pub static VARS_THY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mectomise"),
        dictgen::InsensitiveStr::Ascii("mectomize"),
        dictgen::InsensitiveStr::Ascii("roidectomised"),
        dictgen::InsensitiveStr::Ascii("roidectomized"),
        dictgen::InsensitiveStr::Ascii("roidisation"),
        dictgen::InsensitiveStr::Ascii("roidisations"),
        dictgen::InsensitiveStr::Ascii("roidization"),
        dictgen::InsensitiveStr::Ascii("roidizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_THYMECTOMIZE_9188848309665571694)],
        &[(0b01001, &ENTRY_THYMECTOMIZE_9188848309665571694)],
        &[(0b10010, &ENTRY_THYROIDECTOMIZED_18037313633331374041)],
        &[(0b01001, &ENTRY_THYROIDECTOMIZED_18037313633331374041)],
        &[(0b10010, &ENTRY_THYROIDIZATION_6148181864988263565)],
        &[(0b10010, &ENTRY_THYROIDIZATIONS_15147067345688634277)],
        &[(0b01001, &ENTRY_THYROIDIZATION_6148181864988263565)],
        &[(0b01001, &ENTRY_THYROIDIZATIONS_15147067345688634277)],
    ],
    range: 9..=13,
};

static VARS_THR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THR_CHILDREN),
    value: None,
};

pub static VARS_THR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eap"),
        dictgen::InsensitiveStr::Ascii("eeness"),
        dictgen::InsensitiveStr::Ascii("eenesses"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("u"),
        dictgen::InsensitiveStr::Ascii("uway"),
        dictgen::InsensitiveStr::Ascii("uways"),
    ],
    values: &[
        &[(0b11010, &ENTRY_THERAP_12439233534474368057)],
        &[(0b11010, &ENTRY_THERENESS_15920110764314066574)],
        &[(0b11010, &ENTRY_THERENESSES_12088887261810562814)],
        &[(0b10010, &ENTRY_THRONIZE_6821227400136957234)],
        &[(0b10010, &ENTRY_THRONIZES_12549201774820221034)],
        &[(0b01001, &ENTRY_THRONIZE_6821227400136957234)],
        &[(0b01001, &ENTRY_THRONIZES_12549201774820221034)],
        &[(0b00001, &ENTRY_THROUGH_13450103710029067577)],
        &[(0b10011, &ENTRY_THRUWAY_8791794387715289057)],
        &[(0b10011, &ENTRY_THRUWAYS_949399170587990036)],
    ],
    range: 1..=8,
};

static VARS_THE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_THE_CHILDREN),
    value: None,
};

static VARS_THE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_THEA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_THEO_NODE),
    None,
    None,
    Some(&VARS_THER_NODE),
    Some(&VARS_THES_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_THES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THES_CHILDREN),
    value: None,
};

pub static VARS_THES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mothetae"),
        dictgen::InsensitiveStr::Ascii("mothete"),
    ],
    values: &[
        &[(0b11010, &ENTRY_THESMOTHETE_5962250708932328706)],
        &[(0b00001, &ENTRY_THESMOTHETE_5962250708932328706)],
    ],
    range: 7..=8,
};

static VARS_THER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THER_CHILDREN),
    value: None,
};

pub static VARS_THER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ap"),
        dictgen::InsensitiveStr::Ascii("eness"),
        dictgen::InsensitiveStr::Ascii("enesses"),
        dictgen::InsensitiveStr::Ascii("mae"),
        dictgen::InsensitiveStr::Ascii("malisation"),
        dictgen::InsensitiveStr::Ascii("malisations"),
        dictgen::InsensitiveStr::Ascii("malise"),
        dictgen::InsensitiveStr::Ascii("malised"),
        dictgen::InsensitiveStr::Ascii("malises"),
        dictgen::InsensitiveStr::Ascii("malising"),
        dictgen::InsensitiveStr::Ascii("malization"),
        dictgen::InsensitiveStr::Ascii("malizations"),
        dictgen::InsensitiveStr::Ascii("malize"),
        dictgen::InsensitiveStr::Ascii("malized"),
        dictgen::InsensitiveStr::Ascii("malizes"),
        dictgen::InsensitiveStr::Ascii("malizing"),
        dictgen::InsensitiveStr::Ascii("me"),
        dictgen::InsensitiveStr::Ascii("mesthesia"),
        dictgen::InsensitiveStr::Ascii("moanaesthesia"),
        dictgen::InsensitiveStr::Ascii("moanaesthesias"),
        dictgen::InsensitiveStr::Ascii("moanesthesia"),
        dictgen::InsensitiveStr::Ascii("moanesthesias"),
        dictgen::InsensitiveStr::Ascii("mometerise"),
        dictgen::InsensitiveStr::Ascii("mometerises"),
        dictgen::InsensitiveStr::Ascii("mometerize"),
        dictgen::InsensitiveStr::Ascii("mometerizes"),
        dictgen::InsensitiveStr::Ascii("mopolymerisation"),
        dictgen::InsensitiveStr::Ascii("mopolymerisations"),
        dictgen::InsensitiveStr::Ascii("mopolymerization"),
        dictgen::InsensitiveStr::Ascii("mopolymerizations"),
        dictgen::InsensitiveStr::Ascii("mosiphon"),
        dictgen::InsensitiveStr::Ascii("mosiphons"),
        dictgen::InsensitiveStr::Ascii("mosyphon"),
        dictgen::InsensitiveStr::Ascii("mosyphons"),
    ],
    values: &[
        &[(0b00001, &ENTRY_THERAP_12439233534474368057)],
        &[(0b00001, &ENTRY_THERENESS_15920110764314066574)],
        &[(0b00001, &ENTRY_THERENESSES_12088887261810562814)],
        &[(0b11010, &ENTRY_THERME_8882059819611896240)],
        &[(0b10010, &ENTRY_THERMALIZATION_7024136436456711519)],
        &[(0b10010, &ENTRY_THERMALIZATIONS_14303369656181821634)],
        &[(0b10010, &ENTRY_THERMALIZE_953829933095771497)],
        &[(0b10010, &ENTRY_THERMALIZED_691663227486729890)],
        &[(0b10010, &ENTRY_THERMALIZES_14481137627377672474)],
        &[(0b10010, &ENTRY_THERMALIZING_8673243577457624256)],
        &[(0b01001, &ENTRY_THERMALIZATION_7024136436456711519)],
        &[(0b01001, &ENTRY_THERMALIZATIONS_14303369656181821634)],
        &[(0b01001, &ENTRY_THERMALIZE_953829933095771497)],
        &[(0b01001, &ENTRY_THERMALIZED_691663227486729890)],
        &[(0b01001, &ENTRY_THERMALIZES_14481137627377672474)],
        &[(0b01001, &ENTRY_THERMALIZING_8673243577457624256)],
        &[(0b00001, &ENTRY_THERME_8882059819611896240)],
        &[(0b00001, &ENTRY_THERMESTHESIA_11561525220243242262)],
        &[(0b11010, &ENTRY_THERMOANESTHESIA_4092307643640683807)],
        &[(0b11010, &ENTRY_THERMOANESTHESIAS_1807836102271064111)],
        &[(0b00001, &ENTRY_THERMOANESTHESIA_4092307643640683807)],
        &[(0b00001, &ENTRY_THERMOANESTHESIAS_1807836102271064111)],
        &[(0b10010, &ENTRY_THERMOMETERIZE_15998653899602520685)],
        &[(0b10010, &ENTRY_THERMOMETERIZES_10840283776322209379)],
        &[(0b01001, &ENTRY_THERMOMETERIZE_15998653899602520685)],
        &[(0b01001, &ENTRY_THERMOMETERIZES_10840283776322209379)],
        &[(0b10010, &ENTRY_THERMOPOLYMERIZATION_10433431029598912285)],
        &[(0b10010, &ENTRY_THERMOPOLYMERIZATIONS_3651245684619525553)],
        &[(0b01001, &ENTRY_THERMOPOLYMERIZATION_10433431029598912285)],
        &[(0b01001, &ENTRY_THERMOPOLYMERIZATIONS_3651245684619525553)],
        &[(0b00001, &ENTRY_THERMOSIPHON_9621111130028620625)],
        &[(0b00001, &ENTRY_THERMOSIPHONS_179083683317180105)],
        &[(0b11010, &ENTRY_THERMOSIPHON_9621111130028620625)],
        &[(0b11010, &ENTRY_THERMOSIPHONS_179083683317180105)],
    ],
    range: 2..=17,
};

static VARS_THEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THEO_CHILDREN),
    value: None,
};

pub static VARS_THEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("logisation"),
        dictgen::InsensitiveStr::Ascii("logisations"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logiser"),
        dictgen::InsensitiveStr::Ascii("logisers"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logization"),
        dictgen::InsensitiveStr::Ascii("logizations"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizer"),
        dictgen::InsensitiveStr::Ascii("logizers"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("noe"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("risers"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizer"),
        dictgen::InsensitiveStr::Ascii("rizers"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
        dictgen::InsensitiveStr::Ascii("sophise"),
        dictgen::InsensitiveStr::Ascii("sophised"),
        dictgen::InsensitiveStr::Ascii("sophises"),
        dictgen::InsensitiveStr::Ascii("sophising"),
        dictgen::InsensitiveStr::Ascii("sophize"),
        dictgen::InsensitiveStr::Ascii("sophized"),
        dictgen::InsensitiveStr::Ascii("sophizes"),
        dictgen::InsensitiveStr::Ascii("sophizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_THEOLOGIZATION_3184169504141390704)],
        &[(0b10010, &ENTRY_THEOLOGIZATIONS_1637833144071496386)],
        &[(0b10010, &ENTRY_THEOLOGIZE_7414032072871637264)],
        &[(0b10010, &ENTRY_THEOLOGIZED_15275657420605826847)],
        &[(0b10010, &ENTRY_THEOLOGIZER_18105337442480749750)],
        &[(0b10010, &ENTRY_THEOLOGIZERS_16421415494739610563)],
        &[(0b10010, &ENTRY_THEOLOGIZES_6187402845034207250)],
        &[(0b10010, &ENTRY_THEOLOGIZING_1522552502275961571)],
        &[(0b01001, &ENTRY_THEOLOGIZATION_3184169504141390704)],
        &[(0b01001, &ENTRY_THEOLOGIZATIONS_1637833144071496386)],
        &[(0b01001, &ENTRY_THEOLOGIZE_7414032072871637264)],
        &[(0b01001, &ENTRY_THEOLOGIZED_15275657420605826847)],
        &[(0b01001, &ENTRY_THEOLOGIZER_18105337442480749750)],
        &[(0b01001, &ENTRY_THEOLOGIZERS_16421415494739610563)],
        &[(0b01001, &ENTRY_THEOLOGIZES_6187402845034207250)],
        &[(0b01001, &ENTRY_THEOLOGIZING_1522552502275961571)],
        &[(0b00001, &ENTRY_THEONE_13907392324350936871)],
        &[(0b11010, &ENTRY_THEONE_13907392324350936871)],
        &[(0b10010, &ENTRY_THEORIZATION_16280749314428462916)],
        &[(0b10010, &ENTRY_THEORIZATIONS_1710707944075838400)],
        &[(0b10010, &ENTRY_THEORIZE_16592272841946174715)],
        &[(0b10010, &ENTRY_THEORIZED_12643356280684289637)],
        &[(0b10010, &ENTRY_THEORIZER_11654654415951381825)],
        &[(0b10010, &ENTRY_THEORIZERS_17644565410392015986)],
        &[(0b10010, &ENTRY_THEORIZES_1097471905147904168)],
        &[(0b10010, &ENTRY_THEORIZING_10670219570353826885)],
        &[(0b01001, &ENTRY_THEORIZATION_16280749314428462916)],
        &[(0b01001, &ENTRY_THEORIZATIONS_1710707944075838400)],
        &[(0b01001, &ENTRY_THEORIZE_16592272841946174715)],
        &[(0b01001, &ENTRY_THEORIZED_12643356280684289637)],
        &[(0b01001, &ENTRY_THEORIZER_11654654415951381825)],
        &[(0b01001, &ENTRY_THEORIZERS_17644565410392015986)],
        &[(0b01001, &ENTRY_THEORIZES_1097471905147904168)],
        &[(0b01001, &ENTRY_THEORIZING_10670219570353826885)],
        &[(0b10010, &ENTRY_THEOSOPHIZE_7321146857183593825)],
        &[(0b10010, &ENTRY_THEOSOPHIZED_16449992798183475453)],
        &[(0b10010, &ENTRY_THEOSOPHIZES_1158826125232789362)],
        &[(0b10010, &ENTRY_THEOSOPHIZING_16087803010212187991)],
        &[(0b01001, &ENTRY_THEOSOPHIZE_7321146857183593825)],
        &[(0b01001, &ENTRY_THEOSOPHIZED_16449992798183475453)],
        &[(0b01001, &ENTRY_THEOSOPHIZES_1158826125232789362)],
        &[(0b01001, &ENTRY_THEOSOPHIZING_16087803010212187991)],
    ],
    range: 2..=11,
};

static VARS_THEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THEA_CHILDREN),
    value: None,
};

pub static VARS_THEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tergoer"),
        dictgen::InsensitiveStr::Ascii("tergoers"),
        dictgen::InsensitiveStr::Ascii("tergoing"),
        dictgen::InsensitiveStr::Ascii("tergoings"),
        dictgen::InsensitiveStr::Ascii("terless"),
        dictgen::InsensitiveStr::Ascii("terlesses"),
        dictgen::InsensitiveStr::Ascii("terlike"),
        dictgen::InsensitiveStr::Ascii("terlikes"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tregoer"),
        dictgen::InsensitiveStr::Ascii("tregoers"),
        dictgen::InsensitiveStr::Ascii("tregoing"),
        dictgen::InsensitiveStr::Ascii("tregoings"),
        dictgen::InsensitiveStr::Ascii("treless"),
        dictgen::InsensitiveStr::Ascii("trelesses"),
        dictgen::InsensitiveStr::Ascii("trelike"),
        dictgen::InsensitiveStr::Ascii("trelikes"),
        dictgen::InsensitiveStr::Ascii("tres"),
        dictgen::InsensitiveStr::Ascii("tricalisation"),
        dictgen::InsensitiveStr::Ascii("tricalisations"),
        dictgen::InsensitiveStr::Ascii("tricalise"),
        dictgen::InsensitiveStr::Ascii("tricalised"),
        dictgen::InsensitiveStr::Ascii("tricalises"),
        dictgen::InsensitiveStr::Ascii("tricalising"),
        dictgen::InsensitiveStr::Ascii("tricalization"),
        dictgen::InsensitiveStr::Ascii("tricalizations"),
        dictgen::InsensitiveStr::Ascii("tricalize"),
        dictgen::InsensitiveStr::Ascii("tricalized"),
        dictgen::InsensitiveStr::Ascii("tricalizes"),
        dictgen::InsensitiveStr::Ascii("tricalizing"),
        dictgen::InsensitiveStr::Ascii("tricise"),
        dictgen::InsensitiveStr::Ascii("tricised"),
        dictgen::InsensitiveStr::Ascii("tricises"),
        dictgen::InsensitiveStr::Ascii("tricising"),
        dictgen::InsensitiveStr::Ascii("tricize"),
        dictgen::InsensitiveStr::Ascii("tricized"),
        dictgen::InsensitiveStr::Ascii("tricizes"),
        dictgen::InsensitiveStr::Ascii("tricizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_THEATER_14872060673613944088)],
        &[(0b00001, &ENTRY_THEATERGOER_12049893135886436399)],
        &[(0b00001, &ENTRY_THEATERGOERS_8549242292576792477)],
        &[(0b00001, &ENTRY_THEATERGOING_9036609633778609239)],
        &[(0b00001, &ENTRY_THEATERGOINGS_6740435645328474541)],
        &[(0b00001, &ENTRY_THEATERLESS_6418669943810866547)],
        &[(0b00001, &ENTRY_THEATERLESSES_4394383213563812217)],
        &[(0b00001, &ENTRY_THEATERLIKE_8843571728412345332)],
        &[(0b00001, &ENTRY_THEATERLIKES_14410484446681772640)],
        &[(0b01001, &ENTRY_THEATERS_8074723073047846943)],
        &[(0b11010, &ENTRY_THEATER_14872060673613944088)],
        &[(0b11010, &ENTRY_THEATERGOER_12049893135886436399)],
        &[(0b11010, &ENTRY_THEATERGOERS_8549242292576792477)],
        &[(0b11010, &ENTRY_THEATERGOING_9036609633778609239)],
        &[(0b11010, &ENTRY_THEATERGOINGS_6740435645328474541)],
        &[(0b11010, &ENTRY_THEATERLESS_6418669943810866547)],
        &[(0b11010, &ENTRY_THEATERLESSES_4394383213563812217)],
        &[(0b11010, &ENTRY_THEATERLIKE_8843571728412345332)],
        &[(0b11010, &ENTRY_THEATERLIKES_14410484446681772640)],
        &[(0b11010, &ENTRY_THEATERS_8074723073047846943)],
        &[(0b10010, &ENTRY_THEATRICALIZATION_8726932104691046566)],
        &[(0b10010, &ENTRY_THEATRICALIZATIONS_568370628365365537)],
        &[(0b10010, &ENTRY_THEATRICALIZE_7863949736369468171)],
        &[(0b10010, &ENTRY_THEATRICALIZED_1546831350777799151)],
        &[(0b10010, &ENTRY_THEATRICALIZES_16567523932139571310)],
        &[(0b10010, &ENTRY_THEATRICALIZING_4463754121398572674)],
        &[(0b01001, &ENTRY_THEATRICALIZATION_8726932104691046566)],
        &[(0b01001, &ENTRY_THEATRICALIZATIONS_568370628365365537)],
        &[(0b01001, &ENTRY_THEATRICALIZE_7863949736369468171)],
        &[(0b01001, &ENTRY_THEATRICALIZED_1546831350777799151)],
        &[(0b01001, &ENTRY_THEATRICALIZES_16567523932139571310)],
        &[(0b01001, &ENTRY_THEATRICALIZING_4463754121398572674)],
        &[(0b10010, &ENTRY_THEATRICIZE_14394131727190869494)],
        &[(0b10010, &ENTRY_THEATRICIZED_14255451360235022416)],
        &[(0b10010, &ENTRY_THEATRICIZES_6355456595406057113)],
        &[(0b10010, &ENTRY_THEATRICIZING_9815086289375498796)],
        &[(0b01001, &ENTRY_THEATRICIZE_14394131727190869494)],
        &[(0b01001, &ENTRY_THEATRICIZED_14255451360235022416)],
        &[(0b01001, &ENTRY_THEATRICIZES_6355456595406057113)],
        &[(0b01001, &ENTRY_THEATRICIZING_9815086289375498796)],
    ],
    range: 3..=14,
};

static VARS_THA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_THA_CHILDREN),
    value: None,
};

pub static VARS_THA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lamocele"),
        dictgen::InsensitiveStr::Ascii("lamocoele"),
        dictgen::InsensitiveStr::Ascii("lassaemia"),
        dictgen::InsensitiveStr::Ascii("lassaemias"),
        dictgen::InsensitiveStr::Ascii("lassaemic"),
        dictgen::InsensitiveStr::Ascii("lassemia"),
        dictgen::InsensitiveStr::Ascii("lassemias"),
        dictgen::InsensitiveStr::Ascii("lassemic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_THALAMOCELE_5766303350223704636)],
        &[(0b11010, &ENTRY_THALAMOCELE_5766303350223704636)],
        &[(0b11010, &ENTRY_THALASSEMIA_11647657111797513703)],
        &[(0b11010, &ENTRY_THALASSEMIAS_2823805934181113644)],
        &[(0b11010, &ENTRY_THALASSEMIC_4524955441481070676)],
        &[(0b00001, &ENTRY_THALASSEMIA_11647657111797513703)],
        &[(0b00001, &ENTRY_THALASSEMIAS_2823805934181113644)],
        &[(0b00001, &ENTRY_THALASSEMIC_4524955441481070676)],
    ],
    range: 8..=10,
};

static VARS_TE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_TE_16963694388719213938)]),
};

static VARS_TE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_TEA_NODE),
    Some(&VARS_TEB_NODE),
    Some(&VARS_TEC_NODE),
    None,
    Some(&VARS_TEE_NODE),
    None,
    Some(&VARS_TEG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_TEL_NODE),
    Some(&VARS_TEM_NODE),
    Some(&VARS_TEN_NODE),
    None,
    None,
    None,
    Some(&VARS_TER_NODE),
    Some(&VARS_TES_NODE),
    Some(&VARS_TET_NODE),
    Some(&VARS_TEU_NODE),
    None,
    None,
    Some(&VARS_TEX_NODE),
    None,
    None,
];

static VARS_TEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEX_CHILDREN),
    value: None,
};

pub static VARS_TEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TEXTURIZE_2101736980791874876)],
        &[(0b10010, &ENTRY_TEXTURIZED_13270620706415686595)],
        &[(0b10010, &ENTRY_TEXTURIZES_9031143232768038726)],
        &[(0b10010, &ENTRY_TEXTURIZING_12707124326299442433)],
        &[(0b01001, &ENTRY_TEXTURIZE_2101736980791874876)],
        &[(0b01001, &ENTRY_TEXTURIZED_13270620706415686595)],
        &[(0b01001, &ENTRY_TEXTURIZES_9031143232768038726)],
        &[(0b01001, &ENTRY_TEXTURIZING_12707124326299442433)],
    ],
    range: 6..=8,
};

static VARS_TEU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEU_CHILDREN),
    value: None,
};

pub static VARS_TEU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tonisation"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonised"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonising"),
        dictgen::InsensitiveStr::Ascii("tonization"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonized"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
        dictgen::InsensitiveStr::Ascii("tonizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TEUTONIZATION_15254944975373981632)],
        &[(0b10010, &ENTRY_TEUTONIZE_2326197985184920584)],
        &[(0b10010, &ENTRY_TEUTONIZED_10064813533808905253)],
        &[(0b10010, &ENTRY_TEUTONIZES_3149749243463447607)],
        &[(0b10010, &ENTRY_TEUTONIZING_1726928371121949281)],
        &[(0b01001, &ENTRY_TEUTONIZATION_15254944975373981632)],
        &[(0b01001, &ENTRY_TEUTONIZE_2326197985184920584)],
        &[(0b01001, &ENTRY_TEUTONIZED_10064813533808905253)],
        &[(0b01001, &ENTRY_TEUTONIZES_3149749243463447607)],
        &[(0b01001, &ENTRY_TEUTONIZING_1726928371121949281)],
    ],
    range: 6..=10,
};

static VARS_TET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TET_CHILDREN),
    value: None,
};

pub static VARS_TET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("rachlorethylene"),
        dictgen::InsensitiveStr::Ascii("rachlorethylenes"),
        dictgen::InsensitiveStr::Ascii("rachloroethylene"),
        dictgen::InsensitiveStr::Ascii("rachloroethylenes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TETANIZATION_577138016465980211)],
        &[(0b10010, &ENTRY_TETANIZATIONS_9830716338275193986)],
        &[(0b10010, &ENTRY_TETANIZE_13125818857178721563)],
        &[(0b10010, &ENTRY_TETANIZED_8313685340295551426)],
        &[(0b10010, &ENTRY_TETANIZES_18159463373230991034)],
        &[(0b10010, &ENTRY_TETANIZING_3169895590113377680)],
        &[(0b01001, &ENTRY_TETANIZATION_577138016465980211)],
        &[(0b01001, &ENTRY_TETANIZATIONS_9830716338275193986)],
        &[(0b01001, &ENTRY_TETANIZE_13125818857178721563)],
        &[(0b01001, &ENTRY_TETANIZED_8313685340295551426)],
        &[(0b01001, &ENTRY_TETANIZES_18159463373230991034)],
        &[(0b01001, &ENTRY_TETANIZING_3169895590113377680)],
        &[(0b00001, &ENTRY_TETRACHLORETHYLENE_12592700145144546851)],
        &[(0b00001, &ENTRY_TETRACHLORETHYLENES_3697002620069360563)],
        &[(0b11010, &ENTRY_TETRACHLORETHYLENE_12592700145144546851)],
        &[(0b11010, &ENTRY_TETRACHLORETHYLENES_3697002620069360563)],
    ],
    range: 5..=17,
};

static VARS_TES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TES_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_TES_5634224708893959490)]),
};

pub static VARS_TES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("timonialisation"),
        dictgen::InsensitiveStr::Ascii("timonialisations"),
        dictgen::InsensitiveStr::Ascii("timonialise"),
        dictgen::InsensitiveStr::Ascii("timonialised"),
        dictgen::InsensitiveStr::Ascii("timonialiser"),
        dictgen::InsensitiveStr::Ascii("timonialisers"),
        dictgen::InsensitiveStr::Ascii("timonialises"),
        dictgen::InsensitiveStr::Ascii("timonialising"),
        dictgen::InsensitiveStr::Ascii("timonialization"),
        dictgen::InsensitiveStr::Ascii("timonializations"),
        dictgen::InsensitiveStr::Ascii("timonialize"),
        dictgen::InsensitiveStr::Ascii("timonialized"),
        dictgen::InsensitiveStr::Ascii("timonializer"),
        dictgen::InsensitiveStr::Ascii("timonializers"),
        dictgen::InsensitiveStr::Ascii("timonializes"),
        dictgen::InsensitiveStr::Ascii("timonializing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TESTE_7681162770005306000)],
        &[(0b00001, &ENTRY_TESTE_7681162770005306000)],
        &[(0b10010, &ENTRY_TESTIMONIALIZATION_1997898483350721704)],
        &[(0b10010, &ENTRY_TESTIMONIALIZATIONS_10414109904662561931)],
        &[(0b10010, &ENTRY_TESTIMONIALIZE_18040418696714895280)],
        &[(0b10010, &ENTRY_TESTIMONIALIZED_12777074233080067891)],
        &[(0b10010, &ENTRY_TESTIMONIALIZER_5001418100017709831)],
        &[(0b10010, &ENTRY_TESTIMONIALIZERS_13860732262187670713)],
        &[(0b10010, &ENTRY_TESTIMONIALIZES_10551210801248918911)],
        &[(0b10010, &ENTRY_TESTIMONIALIZING_3438847121414565242)],
        &[(0b01001, &ENTRY_TESTIMONIALIZATION_1997898483350721704)],
        &[(0b01001, &ENTRY_TESTIMONIALIZATIONS_10414109904662561931)],
        &[(0b01001, &ENTRY_TESTIMONIALIZE_18040418696714895280)],
        &[(0b01001, &ENTRY_TESTIMONIALIZED_12777074233080067891)],
        &[(0b01001, &ENTRY_TESTIMONIALIZER_5001418100017709831)],
        &[(0b01001, &ENTRY_TESTIMONIALIZERS_13860732262187670713)],
        &[(0b01001, &ENTRY_TESTIMONIALIZES_10551210801248918911)],
        &[(0b01001, &ENTRY_TESTIMONIALIZING_3438847121414565242)],
    ],
    range: 2..=16,
};

static VARS_TER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TER_CHILDREN),
    value: None,
};

pub static VARS_TER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("f"),
        dictgen::InsensitiveStr::Ascii("ma"),
        dictgen::InsensitiveStr::Ascii("matic"),
        dictgen::InsensitiveStr::Ascii("minalisation"),
        dictgen::InsensitiveStr::Ascii("minalisations"),
        dictgen::InsensitiveStr::Ascii("minalised"),
        dictgen::InsensitiveStr::Ascii("minaliseds"),
        dictgen::InsensitiveStr::Ascii("minalization"),
        dictgen::InsensitiveStr::Ascii("minalizations"),
        dictgen::InsensitiveStr::Ascii("minalized"),
        dictgen::InsensitiveStr::Ascii("minalizeds"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("rae"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("restrialise"),
        dictgen::InsensitiveStr::Ascii("restrialises"),
        dictgen::InsensitiveStr::Ascii("restrialize"),
        dictgen::InsensitiveStr::Ascii("restrializes"),
        dictgen::InsensitiveStr::Ascii("ritorialisation"),
        dictgen::InsensitiveStr::Ascii("ritorialisations"),
        dictgen::InsensitiveStr::Ascii("ritorialise"),
        dictgen::InsensitiveStr::Ascii("ritorialised"),
        dictgen::InsensitiveStr::Ascii("ritorialises"),
        dictgen::InsensitiveStr::Ascii("ritorialising"),
        dictgen::InsensitiveStr::Ascii("ritorialization"),
        dictgen::InsensitiveStr::Ascii("ritorializations"),
        dictgen::InsensitiveStr::Ascii("ritorialize"),
        dictgen::InsensitiveStr::Ascii("ritorialized"),
        dictgen::InsensitiveStr::Ascii("ritorializes"),
        dictgen::InsensitiveStr::Ascii("ritorializing"),
        dictgen::InsensitiveStr::Ascii("rorisation"),
        dictgen::InsensitiveStr::Ascii("rorisations"),
        dictgen::InsensitiveStr::Ascii("rorise"),
        dictgen::InsensitiveStr::Ascii("rorised"),
        dictgen::InsensitiveStr::Ascii("roriser"),
        dictgen::InsensitiveStr::Ascii("rorisers"),
        dictgen::InsensitiveStr::Ascii("rorises"),
        dictgen::InsensitiveStr::Ascii("rorising"),
        dictgen::InsensitiveStr::Ascii("rorization"),
        dictgen::InsensitiveStr::Ascii("rorizations"),
        dictgen::InsensitiveStr::Ascii("rorize"),
        dictgen::InsensitiveStr::Ascii("rorized"),
        dictgen::InsensitiveStr::Ascii("rorizer"),
        dictgen::InsensitiveStr::Ascii("rorizers"),
        dictgen::InsensitiveStr::Ascii("rorizes"),
        dictgen::InsensitiveStr::Ascii("rorizing"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TEERS_11547310098132473650)],
        &[(0b00001, &ENTRY_TERF_3510176223973213714)],
        &[(0b00001, &ENTRY_TERMA_12658799001593884461)],
        &[(0b00001, &ENTRY_TERMATIC_575294056877958757)],
        &[(0b10010, &ENTRY_TERMINALIZATION_14611052621641252685)],
        &[(0b10010, &ENTRY_TERMINALIZATIONS_654995620005875057)],
        &[(0b10010, &ENTRY_TERMINALIZED_12792925211824477703)],
        &[(0b10010, &ENTRY_TERMINALIZEDS_7787606091951730758)],
        &[(0b01001, &ENTRY_TERMINALIZATION_14611052621641252685)],
        &[(0b01001, &ENTRY_TERMINALIZATIONS_654995620005875057)],
        &[(0b01001, &ENTRY_TERMINALIZED_12792925211824477703)],
        &[(0b01001, &ENTRY_TERMINALIZEDS_7787606091951730758)],
        &[(0b10010, &ENTRY_TERNIZE_2124050956550290721)],
        &[(0b10010, &ENTRY_TERNIZES_3262666584819248556)],
        &[(0b01001, &ENTRY_TERNIZE_2124050956550290721)],
        &[(0b01001, &ENTRY_TERNIZES_3262666584819248556)],
        &[(0b11010, &ENTRY_TERRE_8819349438187415807)],
        &[(0b00001, &ENTRY_TERRE_8819349438187415807)],
        &[(0b10010, &ENTRY_TERRESTRIALIZE_6347253160507775588)],
        &[(0b10010, &ENTRY_TERRESTRIALIZES_6624949095978395018)],
        &[(0b01001, &ENTRY_TERRESTRIALIZE_6347253160507775588)],
        &[(0b01001, &ENTRY_TERRESTRIALIZES_6624949095978395018)],
        &[(0b10010, &ENTRY_TERRITORIALIZATION_13612272693653351235)],
        &[(0b10010, &ENTRY_TERRITORIALIZATIONS_3176885729614090958)],
        &[(0b10010, &ENTRY_TERRITORIALIZE_7097746563170584866)],
        &[(0b10010, &ENTRY_TERRITORIALIZED_18010704841888125903)],
        &[(0b10010, &ENTRY_TERRITORIALIZES_8896187296510093610)],
        &[(0b10010, &ENTRY_TERRITORIALIZING_7836091817301256528)],
        &[(0b01001, &ENTRY_TERRITORIALIZATION_13612272693653351235)],
        &[(0b01001, &ENTRY_TERRITORIALIZATIONS_3176885729614090958)],
        &[(0b01001, &ENTRY_TERRITORIALIZE_7097746563170584866)],
        &[(0b01001, &ENTRY_TERRITORIALIZED_18010704841888125903)],
        &[(0b01001, &ENTRY_TERRITORIALIZES_8896187296510093610)],
        &[(0b01001, &ENTRY_TERRITORIALIZING_7836091817301256528)],
        &[(0b10010, &ENTRY_TERRORIZATION_12053144759218452192)],
        &[(0b10010, &ENTRY_TERRORIZATIONS_18287886849231369087)],
        &[(0b10010, &ENTRY_TERRORIZE_2182645348231356537)],
        &[(0b10010, &ENTRY_TERRORIZED_12855863820908113709)],
        &[(0b10010, &ENTRY_TERRORIZER_3790900356919417060)],
        &[(0b10010, &ENTRY_TERRORIZERS_15764303900614300931)],
        &[(0b10010, &ENTRY_TERRORIZES_7590151466698739569)],
        &[(0b10010, &ENTRY_TERRORIZING_13104103423474029961)],
        &[(0b01001, &ENTRY_TERRORIZATION_12053144759218452192)],
        &[(0b01001, &ENTRY_TERRORIZATIONS_18287886849231369087)],
        &[(0b01001, &ENTRY_TERRORIZE_2182645348231356537)],
        &[(0b01001, &ENTRY_TERRORIZED_12855863820908113709)],
        &[(0b01001, &ENTRY_TERRORIZER_3790900356919417060)],
        &[(0b01001, &ENTRY_TERRORIZERS_15764303900614300931)],
        &[(0b01001, &ENTRY_TERRORIZES_7590151466698739569)],
        &[(0b01001, &ENTRY_TERRORIZING_13104103423474029961)],
        &[(0b00001, &ENTRY_TERTS_15921222583797171907)],
    ],
    range: 1..=16,
};

static VARS_TEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEN_CHILDREN),
    value: None,
};

pub static VARS_TEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("derisation"),
        dictgen::InsensitiveStr::Ascii("derisations"),
        dictgen::InsensitiveStr::Ascii("derise"),
        dictgen::InsensitiveStr::Ascii("derised"),
        dictgen::InsensitiveStr::Ascii("deriser"),
        dictgen::InsensitiveStr::Ascii("derisers"),
        dictgen::InsensitiveStr::Ascii("derises"),
        dictgen::InsensitiveStr::Ascii("derising"),
        dictgen::InsensitiveStr::Ascii("derization"),
        dictgen::InsensitiveStr::Ascii("derizations"),
        dictgen::InsensitiveStr::Ascii("derize"),
        dictgen::InsensitiveStr::Ascii("derized"),
        dictgen::InsensitiveStr::Ascii("derizer"),
        dictgen::InsensitiveStr::Ascii("derizers"),
        dictgen::InsensitiveStr::Ascii("derizes"),
        dictgen::InsensitiveStr::Ascii("derizing"),
        dictgen::InsensitiveStr::Ascii("driled"),
        dictgen::InsensitiveStr::Ascii("drilled"),
        dictgen::InsensitiveStr::Ascii("ementisation"),
        dictgen::InsensitiveStr::Ascii("ementisations"),
        dictgen::InsensitiveStr::Ascii("ementise"),
        dictgen::InsensitiveStr::Ascii("ementises"),
        dictgen::InsensitiveStr::Ascii("ementization"),
        dictgen::InsensitiveStr::Ascii("ementizations"),
        dictgen::InsensitiveStr::Ascii("ementize"),
        dictgen::InsensitiveStr::Ascii("ementizes"),
        dictgen::InsensitiveStr::Ascii("ia"),
        dictgen::InsensitiveStr::Ascii("iacidal"),
        dictgen::InsensitiveStr::Ascii("iacide"),
        dictgen::InsensitiveStr::Ascii("iacides"),
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("iafuge"),
        dictgen::InsensitiveStr::Ascii("iafuges"),
        dictgen::InsensitiveStr::Ascii("ias"),
        dictgen::InsensitiveStr::Ascii("iases"),
        dictgen::InsensitiveStr::Ascii("iasis"),
        dictgen::InsensitiveStr::Ascii("ioid"),
        dictgen::InsensitiveStr::Ascii("thmeter"),
        dictgen::InsensitiveStr::Ascii("thmetre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TENDERIZATION_15153457077426481235)],
        &[(0b10010, &ENTRY_TENDERIZATIONS_759776932056624247)],
        &[(0b10010, &ENTRY_TENDERIZE_14583554302804750450)],
        &[(0b10010, &ENTRY_TENDERIZED_4549753286584063824)],
        &[(0b10010, &ENTRY_TENDERIZER_9543130259232111639)],
        &[(0b10010, &ENTRY_TENDERIZERS_2243522742396370113)],
        &[(0b10010, &ENTRY_TENDERIZES_8106466981215709305)],
        &[(0b10010, &ENTRY_TENDERIZING_18364924414460195974)],
        &[(0b01001, &ENTRY_TENDERIZATION_15153457077426481235)],
        &[(0b01001, &ENTRY_TENDERIZATIONS_759776932056624247)],
        &[(0b01001, &ENTRY_TENDERIZE_14583554302804750450)],
        &[(0b01001, &ENTRY_TENDERIZED_4549753286584063824)],
        &[(0b01001, &ENTRY_TENDERIZER_9543130259232111639)],
        &[(0b01001, &ENTRY_TENDERIZERS_2243522742396370113)],
        &[(0b01001, &ENTRY_TENDERIZES_8106466981215709305)],
        &[(0b01001, &ENTRY_TENDERIZING_18364924414460195974)],
        &[(0b00001, &ENTRY_TENDRILED_18038918814565810183)],
        &[(0b11010, &ENTRY_TENDRILED_18038918814565810183)],
        &[(0b10010, &ENTRY_TENEMENTIZATION_14600199269437804256)],
        &[(0b10010, &ENTRY_TENEMENTIZATIONS_3755446656409966534)],
        &[(0b10010, &ENTRY_TENEMENTIZE_17197876287592266522)],
        &[(0b10010, &ENTRY_TENEMENTIZES_2276031239379735921)],
        &[(0b01001, &ENTRY_TENEMENTIZATION_14600199269437804256)],
        &[(0b01001, &ENTRY_TENEMENTIZATIONS_3755446656409966534)],
        &[(0b01001, &ENTRY_TENEMENTIZE_17197876287592266522)],
        &[(0b01001, &ENTRY_TENEMENTIZES_2276031239379735921)],
        &[(0b00001, &ENTRY_TENIA_6242231905882591005)],
        &[(0b00001, &ENTRY_TENIACIDAL_11024692641878915165)],
        &[(0b00001, &ENTRY_TENIACIDE_8144045073011901293)],
        &[(0b00001, &ENTRY_TENIACIDES_9867987590675969789)],
        &[(0b00001, &ENTRY_TENIAE_14899975197394248907)],
        &[(0b00001, &ENTRY_TENIAFUGE_535975770678901901)],
        &[(0b00001, &ENTRY_TENIAFUGES_5656721164722933651)],
        &[(0b00001, &ENTRY_TENIAS_16745934458285507889)],
        &[(0b00001, &ENTRY_TENIASES_4934007100111357532)],
        &[(0b00001, &ENTRY_TENIASIS_7229408385178515529)],
        &[(0b00001, &ENTRY_TENIOID_11942386963829586985)],
        &[(0b00001, &ENTRY_TENTHMETER_17561130154323386893)],
        &[(0b11010, &ENTRY_TENTHMETER_17561130154323386893)],
    ],
    range: 2..=13,
};

static VARS_TEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEM_CHILDREN),
    value: None,
};

pub static VARS_TEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("plise"),
        dictgen::InsensitiveStr::Ascii("plises"),
        dictgen::InsensitiveStr::Ascii("plize"),
        dictgen::InsensitiveStr::Ascii("plizes"),
        dictgen::InsensitiveStr::Ascii("poralise"),
        dictgen::InsensitiveStr::Ascii("poralised"),
        dictgen::InsensitiveStr::Ascii("poralises"),
        dictgen::InsensitiveStr::Ascii("poralising"),
        dictgen::InsensitiveStr::Ascii("poralize"),
        dictgen::InsensitiveStr::Ascii("poralized"),
        dictgen::InsensitiveStr::Ascii("poralizes"),
        dictgen::InsensitiveStr::Ascii("poralizing"),
        dictgen::InsensitiveStr::Ascii("porisation"),
        dictgen::InsensitiveStr::Ascii("porisations"),
        dictgen::InsensitiveStr::Ascii("porise"),
        dictgen::InsensitiveStr::Ascii("porised"),
        dictgen::InsensitiveStr::Ascii("poriser"),
        dictgen::InsensitiveStr::Ascii("porisers"),
        dictgen::InsensitiveStr::Ascii("porises"),
        dictgen::InsensitiveStr::Ascii("porising"),
        dictgen::InsensitiveStr::Ascii("porisinglier"),
        dictgen::InsensitiveStr::Ascii("porisingliest"),
        dictgen::InsensitiveStr::Ascii("porisingly"),
        dictgen::InsensitiveStr::Ascii("porisings"),
        dictgen::InsensitiveStr::Ascii("porization"),
        dictgen::InsensitiveStr::Ascii("porizations"),
        dictgen::InsensitiveStr::Ascii("porize"),
        dictgen::InsensitiveStr::Ascii("porized"),
        dictgen::InsensitiveStr::Ascii("porizer"),
        dictgen::InsensitiveStr::Ascii("porizers"),
        dictgen::InsensitiveStr::Ascii("porizes"),
        dictgen::InsensitiveStr::Ascii("porizing"),
        dictgen::InsensitiveStr::Ascii("porizinglier"),
        dictgen::InsensitiveStr::Ascii("porizingliest"),
        dictgen::InsensitiveStr::Ascii("porizingly"),
        dictgen::InsensitiveStr::Ascii("porizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TEMPLIZE_3769471964247003706)],
        &[(0b10010, &ENTRY_TEMPLIZES_8206287182084029425)],
        &[(0b01001, &ENTRY_TEMPLIZE_3769471964247003706)],
        &[(0b01001, &ENTRY_TEMPLIZES_8206287182084029425)],
        &[(0b10010, &ENTRY_TEMPORALIZE_8976084796595693342)],
        &[(0b10010, &ENTRY_TEMPORALIZED_9346139556114175316)],
        &[(0b10010, &ENTRY_TEMPORALIZES_17569235997419710911)],
        &[(0b10010, &ENTRY_TEMPORALIZING_10385680194697863891)],
        &[(0b01001, &ENTRY_TEMPORALIZE_8976084796595693342)],
        &[(0b01001, &ENTRY_TEMPORALIZED_9346139556114175316)],
        &[(0b01001, &ENTRY_TEMPORALIZES_17569235997419710911)],
        &[(0b01001, &ENTRY_TEMPORALIZING_10385680194697863891)],
        &[(0b10010, &ENTRY_TEMPORIZATION_9268323585901486943)],
        &[(0b10010, &ENTRY_TEMPORIZATIONS_18395264469348932353)],
        &[(0b10010, &ENTRY_TEMPORIZE_6008538957350717253)],
        &[(0b10010, &ENTRY_TEMPORIZED_13828183401152117443)],
        &[(0b10010, &ENTRY_TEMPORIZER_13728915446164211108)],
        &[(0b10010, &ENTRY_TEMPORIZERS_7683732994752843323)],
        &[(0b10010, &ENTRY_TEMPORIZES_3654086099315586263)],
        &[(0b10010, &ENTRY_TEMPORIZING_6302462174887770996)],
        &[(0b10010, &ENTRY_TEMPORIZINGLIER_6355354281150226976)],
        &[(0b10010, &ENTRY_TEMPORIZINGLIEST_9905876624839839389)],
        &[(0b10010, &ENTRY_TEMPORIZINGLY_11640359263718011924)],
        &[(0b10010, &ENTRY_TEMPORIZINGS_20261713602325724)],
        &[(0b01001, &ENTRY_TEMPORIZATION_9268323585901486943)],
        &[(0b01001, &ENTRY_TEMPORIZATIONS_18395264469348932353)],
        &[(0b01001, &ENTRY_TEMPORIZE_6008538957350717253)],
        &[(0b01001, &ENTRY_TEMPORIZED_13828183401152117443)],
        &[(0b01001, &ENTRY_TEMPORIZER_13728915446164211108)],
        &[(0b01001, &ENTRY_TEMPORIZERS_7683732994752843323)],
        &[(0b01001, &ENTRY_TEMPORIZES_3654086099315586263)],
        &[(0b01001, &ENTRY_TEMPORIZING_6302462174887770996)],
        &[(0b01001, &ENTRY_TEMPORIZINGLIER_6355354281150226976)],
        &[(0b01001, &ENTRY_TEMPORIZINGLIEST_9905876624839839389)],
        &[(0b01001, &ENTRY_TEMPORIZINGLY_11640359263718011924)],
        &[(0b01001, &ENTRY_TEMPORIZINGS_20261713602325724)],
    ],
    range: 5..=13,
};

static VARS_TEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEL_CHILDREN),
    value: None,
};

pub static VARS_TEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("aesthesias"),
        dictgen::InsensitiveStr::Ascii("aesthetic"),
        dictgen::InsensitiveStr::Ascii("aestheticer"),
        dictgen::InsensitiveStr::Ascii("aestheticest"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("epathise"),
        dictgen::InsensitiveStr::Ascii("epathised"),
        dictgen::InsensitiveStr::Ascii("epathises"),
        dictgen::InsensitiveStr::Ascii("epathising"),
        dictgen::InsensitiveStr::Ascii("epathize"),
        dictgen::InsensitiveStr::Ascii("epathized"),
        dictgen::InsensitiveStr::Ascii("epathizes"),
        dictgen::InsensitiveStr::Ascii("epathizing"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("estheticer"),
        dictgen::InsensitiveStr::Ascii("estheticest"),
        dictgen::InsensitiveStr::Ascii("lurise"),
        dictgen::InsensitiveStr::Ascii("lurised"),
        dictgen::InsensitiveStr::Ascii("lurises"),
        dictgen::InsensitiveStr::Ascii("lurising"),
        dictgen::InsensitiveStr::Ascii("lurize"),
        dictgen::InsensitiveStr::Ascii("lurized"),
        dictgen::InsensitiveStr::Ascii("lurizes"),
        dictgen::InsensitiveStr::Ascii("lurizing"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TELE_17660775790618180296)],
        &[(0b11010, &ENTRY_TELESTHESIA_3729177704184763745)],
        &[(0b11010, &ENTRY_TELESTHESIAS_13634253936556894398)],
        &[(0b11010, &ENTRY_TELESTHETIC_2492077632449909509)],
        &[(0b11010, &ENTRY_TELESTHETICER_15325218410106938805)],
        &[(0b11010, &ENTRY_TELESTHETICEST_10500637524144952518)],
        &[(0b00001, &ENTRY_TELE_17660775790618180296)],
        &[(0b10010, &ENTRY_TELEPATHIZE_4890254755616696887)],
        &[(0b10010, &ENTRY_TELEPATHIZED_13030563544943449021)],
        &[(0b10010, &ENTRY_TELEPATHIZES_13175684465670989018)],
        &[(0b10010, &ENTRY_TELEPATHIZING_15634779623380965076)],
        &[(0b01001, &ENTRY_TELEPATHIZE_4890254755616696887)],
        &[(0b01001, &ENTRY_TELEPATHIZED_13030563544943449021)],
        &[(0b01001, &ENTRY_TELEPATHIZES_13175684465670989018)],
        &[(0b01001, &ENTRY_TELEPATHIZING_15634779623380965076)],
        &[(0b00001, &ENTRY_TELESTHESIA_3729177704184763745)],
        &[(0b00001, &ENTRY_TELESTHESIAS_13634253936556894398)],
        &[(0b00001, &ENTRY_TELESTHETIC_2492077632449909509)],
        &[(0b00001, &ENTRY_TELESTHETICER_15325218410106938805)],
        &[(0b00001, &ENTRY_TELESTHETICEST_10500637524144952518)],
        &[(0b10010, &ENTRY_TELLURIZE_12969876447874663017)],
        &[(0b10010, &ENTRY_TELLURIZED_4062571174023013836)],
        &[(0b10010, &ENTRY_TELLURIZES_14477745285616322945)],
        &[(0b10010, &ENTRY_TELLURIZING_15726097355587032776)],
        &[(0b01001, &ENTRY_TELLURIZE_12969876447874663017)],
        &[(0b01001, &ENTRY_TELLURIZED_4062571174023013836)],
        &[(0b01001, &ENTRY_TELLURIZES_14477745285616322945)],
        &[(0b01001, &ENTRY_TELLURIZING_15726097355587032776)],
        &[(0b00001, &ENTRY_TELS_3007087834331223229)],
    ],
    range: 1..=12,
};

static VARS_TEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEG_CHILDREN),
    value: None,
};

pub static VARS_TEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("u")],
    values: &[&[(0b00001, &ENTRY_TEGU_17495886448442942906)]],
    range: 1..=1,
};

static VARS_TEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEE_CHILDREN),
    value: None,
};

pub static VARS_TEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("totaled"),
        dictgen::InsensitiveStr::Ascii("totaler"),
        dictgen::InsensitiveStr::Ascii("totalers"),
        dictgen::InsensitiveStr::Ascii("totaling"),
        dictgen::InsensitiveStr::Ascii("totalled"),
        dictgen::InsensitiveStr::Ascii("totaller"),
        dictgen::InsensitiveStr::Ascii("totallers"),
        dictgen::InsensitiveStr::Ascii("totalling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TEER_1512356504088772276)],
        &[(0b00001, &ENTRY_TEERS_11547310098132473650)],
        &[(0b00001, &ENTRY_TEETOTALED_13601847410093247608)],
        &[(0b00001, &ENTRY_TEETOTALER_4246658529410097511)],
        &[(0b00001, &ENTRY_TEETOTALERS_7523968922648268459)],
        &[(0b00001, &ENTRY_TEETOTALING_14654836145957001388)],
        &[(0b11010, &ENTRY_TEETOTALED_13601847410093247608)],
        &[(0b11010, &ENTRY_TEETOTALER_4246658529410097511)],
        &[(0b11010, &ENTRY_TEETOTALERS_7523968922648268459)],
        &[(0b11010, &ENTRY_TEETOTALING_14654836145957001388)],
    ],
    range: 1..=9,
};

static VARS_TEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEC_CHILDREN),
    value: None,
};

pub static VARS_TEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hnicalisation"),
        dictgen::InsensitiveStr::Ascii("hnicalise"),
        dictgen::InsensitiveStr::Ascii("hnicalises"),
        dictgen::InsensitiveStr::Ascii("hnicalization"),
        dictgen::InsensitiveStr::Ascii("hnicalize"),
        dictgen::InsensitiveStr::Ascii("hnicalizes"),
        dictgen::InsensitiveStr::Ascii("hnicise"),
        dictgen::InsensitiveStr::Ascii("hnicised"),
        dictgen::InsensitiveStr::Ascii("hnicises"),
        dictgen::InsensitiveStr::Ascii("hnicising"),
        dictgen::InsensitiveStr::Ascii("hnicize"),
        dictgen::InsensitiveStr::Ascii("hnicized"),
        dictgen::InsensitiveStr::Ascii("hnicizes"),
        dictgen::InsensitiveStr::Ascii("hnicizing"),
        dictgen::InsensitiveStr::Ascii("hnicolour"),
        dictgen::InsensitiveStr::Ascii("hnicoloured"),
        dictgen::InsensitiveStr::Ascii("hnicolours"),
        dictgen::InsensitiveStr::Ascii("hnologise"),
        dictgen::InsensitiveStr::Ascii("hnologize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TECHNICALIZATION_3773436217131165599)],
        &[(0b10010, &ENTRY_TECHNICALIZE_13592737048499055793)],
        &[(0b10010, &ENTRY_TECHNICALIZES_5595101189542797653)],
        &[(0b01001, &ENTRY_TECHNICALIZATION_3773436217131165599)],
        &[(0b01001, &ENTRY_TECHNICALIZE_13592737048499055793)],
        &[(0b01001, &ENTRY_TECHNICALIZES_5595101189542797653)],
        &[(0b10010, &ENTRY_TECHNICIZE_8212652477507145699)],
        &[(0b10010, &ENTRY_TECHNICIZED_3663306080874533270)],
        &[(0b10010, &ENTRY_TECHNICIZES_13211595356574862793)],
        &[(0b10010, &ENTRY_TECHNICIZING_13378455688370171176)],
        &[(0b01001, &ENTRY_TECHNICIZE_8212652477507145699)],
        &[(0b01001, &ENTRY_TECHNICIZED_3663306080874533270)],
        &[(0b01001, &ENTRY_TECHNICIZES_13211595356574862793)],
        &[(0b01001, &ENTRY_TECHNICIZING_13378455688370171176)],
        &[
            (0b11010, &ENTRY_TECHNICOLOR_13876999640902564556),
            (0b11010, &ENTRY_TECHNICOLOR_14183677618685504801),
        ],
        &[(0b11010, &ENTRY_TECHNICOLORED_1825328488281394359)],
        &[(0b11010, &ENTRY_TECHNICOLORS_14860686180490475866)],
        &[(0b10010, &ENTRY_TECHNOLOGIZE_4630575226590934600)],
        &[(0b01001, &ENTRY_TECHNOLOGIZE_4630575226590934600)],
    ],
    range: 7..=13,
};

static VARS_TEB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEB_CHILDREN),
    value: None,
};

pub static VARS_TEB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TEBILIZE_5379298659414145032)],
        &[(0b10010, &ENTRY_TEBILIZED_12603919274755080976)],
        &[(0b10010, &ENTRY_TEBILIZES_2524900190492767802)],
        &[(0b10010, &ENTRY_TEBILIZING_5956809875127660850)],
        &[(0b01001, &ENTRY_TEBILIZE_5379298659414145032)],
        &[(0b01001, &ENTRY_TEBILIZED_12603919274755080976)],
        &[(0b01001, &ENTRY_TEBILIZES_2524900190492767802)],
        &[(0b01001, &ENTRY_TEBILIZING_5956809875127660850)],
    ],
    range: 5..=7,
};

static VARS_TEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TEA_CHILDREN),
    value: None,
};

pub static VARS_TEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("seller"),
        dictgen::InsensitiveStr::Ascii("sellers"),
        dictgen::InsensitiveStr::Ascii("selling"),
        dictgen::InsensitiveStr::Ascii("sellings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TEER_1512356504088772276)],
        &[(0b00001, &ENTRY_TEASELED_8083609611219835965)],
        &[(0b00001, &ENTRY_TEASELER_15075482462791394349)],
        &[(0b00001, &ENTRY_TEASELERS_17319562617316313679)],
        &[
            (0b00001, &ENTRY_TEASELING_13695401286288634817),
            (0b00001, &ENTRY_TEASELING_2241001256394841761),
        ],
        &[(0b00001, &ENTRY_TEASELINGS_10604239368842442956)],
    ],
    range: 2..=8,
};

static VARS_TA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_TA_CHILDREN),
    value: None,
};

static VARS_TA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_TAB_NODE),
    Some(&VARS_TAC_NODE),
    None,
    Some(&VARS_TAE_NODE),
    Some(&VARS_TAF_NODE),
    None,
    None,
    Some(&VARS_TAI_NODE),
    None,
    None,
    Some(&VARS_TAL_NODE),
    Some(&VARS_TAM_NODE),
    Some(&VARS_TAN_NODE),
    None,
    None,
    None,
    Some(&VARS_TAR_NODE),
    Some(&VARS_TAS_NODE),
    None,
    Some(&VARS_TAU_NODE),
    Some(&VARS_TAV_NODE),
    None,
    Some(&VARS_TAX_NODE),
    Some(&VARS_TAY_NODE),
    None,
];

static VARS_TAY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAY_CHILDREN),
    value: None,
};

pub static VARS_TAY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lorise"),
        dictgen::InsensitiveStr::Ascii("lorises"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAYLORIZE_17635648384739575074)],
        &[(0b10010, &ENTRY_TAYLORIZES_13244584135122060485)],
        &[(0b01001, &ENTRY_TAYLORIZE_17635648384739575074)],
        &[(0b01001, &ENTRY_TAYLORIZES_13244584135122060485)],
    ],
    range: 6..=7,
};

static VARS_TAX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAX_CHILDREN),
    value: None,
};

pub static VARS_TAX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idermise"),
        dictgen::InsensitiveStr::Ascii("idermised"),
        dictgen::InsensitiveStr::Ascii("idermises"),
        dictgen::InsensitiveStr::Ascii("idermising"),
        dictgen::InsensitiveStr::Ascii("idermize"),
        dictgen::InsensitiveStr::Ascii("idermized"),
        dictgen::InsensitiveStr::Ascii("idermizes"),
        dictgen::InsensitiveStr::Ascii("idermizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAXIDERMIZE_2374104358744757711)],
        &[(0b10010, &ENTRY_TAXIDERMIZED_10192910736850674)],
        &[(0b10010, &ENTRY_TAXIDERMIZES_4441796755398649754)],
        &[(0b10010, &ENTRY_TAXIDERMIZING_13017684951259720401)],
        &[(0b01001, &ENTRY_TAXIDERMIZE_2374104358744757711)],
        &[(0b01001, &ENTRY_TAXIDERMIZED_10192910736850674)],
        &[(0b01001, &ENTRY_TAXIDERMIZES_4441796755398649754)],
        &[(0b01001, &ENTRY_TAXIDERMIZING_13017684951259720401)],
    ],
    range: 8..=10,
};

static VARS_TAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAV_CHILDREN),
    value: None,
};

pub static VARS_TAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAVERNIZE_11412342911846701308)],
        &[(0b10010, &ENTRY_TAVERNIZES_6120473175514650417)],
        &[(0b01001, &ENTRY_TAVERNIZE_11412342911846701308)],
        &[(0b01001, &ENTRY_TAVERNIZES_6120473175514650417)],
    ],
    range: 6..=7,
};

static VARS_TAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAU_CHILDREN),
    value: None,
};

pub static VARS_TAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tologise"),
        dictgen::InsensitiveStr::Ascii("tologised"),
        dictgen::InsensitiveStr::Ascii("tologises"),
        dictgen::InsensitiveStr::Ascii("tologising"),
        dictgen::InsensitiveStr::Ascii("tologize"),
        dictgen::InsensitiveStr::Ascii("tologized"),
        dictgen::InsensitiveStr::Ascii("tologizes"),
        dictgen::InsensitiveStr::Ascii("tologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAUTOLOGIZE_4665592265999186622)],
        &[(0b10010, &ENTRY_TAUTOLOGIZED_9842553804886781862)],
        &[(0b10010, &ENTRY_TAUTOLOGIZES_11146116641412142667)],
        &[(0b10010, &ENTRY_TAUTOLOGIZING_9943163653831588506)],
        &[(0b01001, &ENTRY_TAUTOLOGIZE_4665592265999186622)],
        &[(0b01001, &ENTRY_TAUTOLOGIZED_9842553804886781862)],
        &[(0b01001, &ENTRY_TAUTOLOGIZES_11146116641412142667)],
        &[(0b01001, &ENTRY_TAUTOLOGIZING_9943163653831588506)],
    ],
    range: 8..=10,
};

static VARS_TAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAS_CHILDREN),
    value: None,
};

pub static VARS_TAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seling"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("selling"),
        dictgen::InsensitiveStr::Ascii("sells"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TASSELED_15553878924111115665)],
        &[(0b00001, &ENTRY_TASSELING_2676198179605847965)],
        &[(0b11010, &ENTRY_TASSELED_15553878924111115665)],
        &[(0b11010, &ENTRY_TASSELING_2676198179605847965)],
        &[(0b11010, &ENTRY_TASSELS_9644147193425846585)],
    ],
    range: 5..=7,
};

static VARS_TAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAR_CHILDREN),
    value: None,
};

pub static VARS_TAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iffise"),
        dictgen::InsensitiveStr::Ascii("iffises"),
        dictgen::InsensitiveStr::Ascii("iffize"),
        dictgen::InsensitiveStr::Ascii("iffizes"),
        dictgen::InsensitiveStr::Ascii("tarisation"),
        dictgen::InsensitiveStr::Ascii("tarisations"),
        dictgen::InsensitiveStr::Ascii("tarise"),
        dictgen::InsensitiveStr::Ascii("tarised"),
        dictgen::InsensitiveStr::Ascii("tarises"),
        dictgen::InsensitiveStr::Ascii("tarising"),
        dictgen::InsensitiveStr::Ascii("tarization"),
        dictgen::InsensitiveStr::Ascii("tarizations"),
        dictgen::InsensitiveStr::Ascii("tarize"),
        dictgen::InsensitiveStr::Ascii("tarized"),
        dictgen::InsensitiveStr::Ascii("tarizes"),
        dictgen::InsensitiveStr::Ascii("tarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TARIFFIZE_18377098253013907822)],
        &[(0b10010, &ENTRY_TARIFFIZES_4632513233689174159)],
        &[(0b01001, &ENTRY_TARIFFIZE_18377098253013907822)],
        &[(0b01001, &ENTRY_TARIFFIZES_4632513233689174159)],
        &[(0b10010, &ENTRY_TARTARIZATION_1394513065812646894)],
        &[(0b10010, &ENTRY_TARTARIZATIONS_11628589829012700090)],
        &[(0b10010, &ENTRY_TARTARIZE_11607621879783763771)],
        &[(0b10010, &ENTRY_TARTARIZED_531821600819631957)],
        &[(0b10010, &ENTRY_TARTARIZES_6665817306686419426)],
        &[(0b10010, &ENTRY_TARTARIZING_15412039886176166104)],
        &[(0b01001, &ENTRY_TARTARIZATION_1394513065812646894)],
        &[(0b01001, &ENTRY_TARTARIZATIONS_11628589829012700090)],
        &[(0b01001, &ENTRY_TARTARIZE_11607621879783763771)],
        &[(0b01001, &ENTRY_TARTARIZED_531821600819631957)],
        &[(0b01001, &ENTRY_TARTARIZES_6665817306686419426)],
        &[(0b01001, &ENTRY_TARTARIZING_15412039886176166104)],
    ],
    range: 6..=11,
};

static VARS_TAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAN_CHILDREN),
    value: None,
};

pub static VARS_TAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("demise"),
        dictgen::InsensitiveStr::Ascii("demises"),
        dictgen::InsensitiveStr::Ascii("demize"),
        dictgen::InsensitiveStr::Ascii("demizes"),
        dictgen::InsensitiveStr::Ascii("talisation"),
        dictgen::InsensitiveStr::Ascii("talisations"),
        dictgen::InsensitiveStr::Ascii("talise"),
        dictgen::InsensitiveStr::Ascii("talised"),
        dictgen::InsensitiveStr::Ascii("taliser"),
        dictgen::InsensitiveStr::Ascii("talisers"),
        dictgen::InsensitiveStr::Ascii("talises"),
        dictgen::InsensitiveStr::Ascii("talising"),
        dictgen::InsensitiveStr::Ascii("talisinglier"),
        dictgen::InsensitiveStr::Ascii("talisinglies"),
        dictgen::InsensitiveStr::Ascii("talisingliest"),
        dictgen::InsensitiveStr::Ascii("talisingly"),
        dictgen::InsensitiveStr::Ascii("talisingness"),
        dictgen::InsensitiveStr::Ascii("talisingnesses"),
        dictgen::InsensitiveStr::Ascii("talisings"),
        dictgen::InsensitiveStr::Ascii("talization"),
        dictgen::InsensitiveStr::Ascii("talizations"),
        dictgen::InsensitiveStr::Ascii("talize"),
        dictgen::InsensitiveStr::Ascii("talized"),
        dictgen::InsensitiveStr::Ascii("talizer"),
        dictgen::InsensitiveStr::Ascii("talizers"),
        dictgen::InsensitiveStr::Ascii("talizes"),
        dictgen::InsensitiveStr::Ascii("talizing"),
        dictgen::InsensitiveStr::Ascii("talizinglier"),
        dictgen::InsensitiveStr::Ascii("talizinglies"),
        dictgen::InsensitiveStr::Ascii("talizingliest"),
        dictgen::InsensitiveStr::Ascii("talizingly"),
        dictgen::InsensitiveStr::Ascii("talizingness"),
        dictgen::InsensitiveStr::Ascii("talizingnesses"),
        dictgen::InsensitiveStr::Ascii("talizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TANALIZED_9212065894823627745)],
        &[(0b01001, &ENTRY_TANALIZED_9212065894823627745)],
        &[(0b10010, &ENTRY_TANDEMIZE_4594849143604731371)],
        &[(0b10010, &ENTRY_TANDEMIZES_16858842567411722496)],
        &[(0b01001, &ENTRY_TANDEMIZE_4594849143604731371)],
        &[(0b01001, &ENTRY_TANDEMIZES_16858842567411722496)],
        &[(0b10010, &ENTRY_TANTALIZATION_10133038819327360701)],
        &[(0b10010, &ENTRY_TANTALIZATIONS_13771654142203624068)],
        &[(0b10010, &ENTRY_TANTALIZE_15099675080816392884)],
        &[(0b10010, &ENTRY_TANTALIZED_6407916214765676747)],
        &[(0b10010, &ENTRY_TANTALIZER_3311757807060502289)],
        &[(0b10010, &ENTRY_TANTALIZERS_15746926120203675469)],
        &[(0b10010, &ENTRY_TANTALIZES_7562225734061592970)],
        &[(0b10010, &ENTRY_TANTALIZING_5979831725565904591)],
        &[(0b10010, &ENTRY_TANTALIZINGLIER_10045132062074784268)],
        &[(0b10010, &ENTRY_TANTALIZINGLIES_5104449786998566308)],
        &[(0b10010, &ENTRY_TANTALIZINGLIEST_13318655638322508135)],
        &[(0b10010, &ENTRY_TANTALIZINGLY_8124924363029560350)],
        &[(0b10010, &ENTRY_TANTALIZINGNESS_5920752991593005851)],
        &[(0b10010, &ENTRY_TANTALIZINGNESSES_3198907059754343992)],
        &[(0b10010, &ENTRY_TANTALIZINGS_16838246964261155328)],
        &[(0b01001, &ENTRY_TANTALIZATION_10133038819327360701)],
        &[(0b01001, &ENTRY_TANTALIZATIONS_13771654142203624068)],
        &[(0b01001, &ENTRY_TANTALIZE_15099675080816392884)],
        &[(0b01001, &ENTRY_TANTALIZED_6407916214765676747)],
        &[(0b01001, &ENTRY_TANTALIZER_3311757807060502289)],
        &[(0b01001, &ENTRY_TANTALIZERS_15746926120203675469)],
        &[(0b01001, &ENTRY_TANTALIZES_7562225734061592970)],
        &[(0b01001, &ENTRY_TANTALIZING_5979831725565904591)],
        &[(0b01001, &ENTRY_TANTALIZINGLIER_10045132062074784268)],
        &[(0b01001, &ENTRY_TANTALIZINGLIES_5104449786998566308)],
        &[(0b01001, &ENTRY_TANTALIZINGLIEST_13318655638322508135)],
        &[(0b01001, &ENTRY_TANTALIZINGLY_8124924363029560350)],
        &[(0b01001, &ENTRY_TANTALIZINGNESS_5920752991593005851)],
        &[(0b01001, &ENTRY_TANTALIZINGNESSES_3198907059754343992)],
        &[(0b01001, &ENTRY_TANTALIZINGS_16838246964261155328)],
    ],
    range: 6..=14,
};

static VARS_TAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAM_CHILDREN),
    value: None,
};

pub static VARS_TAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("boura"),
        dictgen::InsensitiveStr::Ascii("bouras"),
        dictgen::InsensitiveStr::Ascii("manyise"),
        dictgen::InsensitiveStr::Ascii("manyises"),
        dictgen::InsensitiveStr::Ascii("manyize"),
        dictgen::InsensitiveStr::Ascii("manyizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TAMBURA_1661928953124890659)],
        &[(0b11010, &ENTRY_TAMBURAS_14365291061235589624)],
        &[(0b10010, &ENTRY_TAMMANYIZE_10524041228496510264)],
        &[(0b10010, &ENTRY_TAMMANYIZES_17001559242562845912)],
        &[(0b01001, &ENTRY_TAMMANYIZE_10524041228496510264)],
        &[(0b01001, &ENTRY_TAMMANYIZES_17001559242562845912)],
    ],
    range: 5..=8,
};

static VARS_TAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAL_CHILDREN),
    value: None,
};

pub static VARS_TAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mudisation"),
        dictgen::InsensitiveStr::Ascii("mudisations"),
        dictgen::InsensitiveStr::Ascii("mudise"),
        dictgen::InsensitiveStr::Ascii("mudises"),
        dictgen::InsensitiveStr::Ascii("mudization"),
        dictgen::InsensitiveStr::Ascii("mudizations"),
        dictgen::InsensitiveStr::Ascii("mudize"),
        dictgen::InsensitiveStr::Ascii("mudizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TALMUDIZATION_15638872772942699916)],
        &[(0b10010, &ENTRY_TALMUDIZATIONS_11451589359461499086)],
        &[(0b10010, &ENTRY_TALMUDIZE_16721620815556202151)],
        &[(0b10010, &ENTRY_TALMUDIZES_2392641621064217398)],
        &[(0b01001, &ENTRY_TALMUDIZATION_15638872772942699916)],
        &[(0b01001, &ENTRY_TALMUDIZATIONS_11451589359461499086)],
        &[(0b01001, &ENTRY_TALMUDIZE_16721620815556202151)],
        &[(0b01001, &ENTRY_TALMUDIZES_2392641621064217398)],
    ],
    range: 6..=11,
};

static VARS_TAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAI_CHILDREN),
    value: None,
};

pub static VARS_TAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lorisation"),
        dictgen::InsensitiveStr::Ascii("lorisations"),
        dictgen::InsensitiveStr::Ascii("lorise"),
        dictgen::InsensitiveStr::Ascii("lorises"),
        dictgen::InsensitiveStr::Ascii("lorization"),
        dictgen::InsensitiveStr::Ascii("lorizations"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAILORIZATION_15045235103886073598)],
        &[(0b10010, &ENTRY_TAILORIZATIONS_1736724620876472569)],
        &[(0b10010, &ENTRY_TAILORIZE_15097975052812336572)],
        &[(0b10010, &ENTRY_TAILORIZES_6097967392668050636)],
        &[(0b01001, &ENTRY_TAILORIZATION_15045235103886073598)],
        &[(0b01001, &ENTRY_TAILORIZATIONS_1736724620876472569)],
        &[(0b01001, &ENTRY_TAILORIZE_15097975052812336572)],
        &[(0b01001, &ENTRY_TAILORIZES_6097967392668050636)],
    ],
    range: 6..=11,
};

static VARS_TAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAF_CHILDREN),
    value: None,
};

pub static VARS_TAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fetised"),
        dictgen::InsensitiveStr::Ascii("fetized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_TAFFETIZED_8007155516688755691)],
        &[(0b01001, &ENTRY_TAFFETIZED_8007155516688755691)],
    ],
    range: 7..=7,
};

static VARS_TAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_TE_16963694388719213938)]),
};

pub static VARS_TAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gu"),
        dictgen::InsensitiveStr::Ascii("ls"),
        dictgen::InsensitiveStr::Ascii("nia"),
        dictgen::InsensitiveStr::Ascii("niacidal"),
        dictgen::InsensitiveStr::Ascii("niacide"),
        dictgen::InsensitiveStr::Ascii("niacides"),
        dictgen::InsensitiveStr::Ascii("niae"),
        dictgen::InsensitiveStr::Ascii("niafuge"),
        dictgen::InsensitiveStr::Ascii("niafuges"),
        dictgen::InsensitiveStr::Ascii("nias"),
        dictgen::InsensitiveStr::Ascii("niases"),
        dictgen::InsensitiveStr::Ascii("niasis"),
        dictgen::InsensitiveStr::Ascii("nioid"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b11010, &ENTRY_TEGU_17495886448442942906)],
        &[(0b11010, &ENTRY_TELS_3007087834331223229)],
        &[(0b11010, &ENTRY_TENIA_6242231905882591005)],
        &[(0b11010, &ENTRY_TENIACIDAL_11024692641878915165)],
        &[(0b11010, &ENTRY_TENIACIDE_8144045073011901293)],
        &[(0b11010, &ENTRY_TENIACIDES_9867987590675969789)],
        &[(0b11010, &ENTRY_TENIAE_14899975197394248907)],
        &[(0b11010, &ENTRY_TENIAFUGE_535975770678901901)],
        &[(0b11010, &ENTRY_TENIAFUGES_5656721164722933651)],
        &[(0b11010, &ENTRY_TENIAS_16745934458285507889)],
        &[(0b11010, &ENTRY_TENIASES_4934007100111357532)],
        &[(0b11010, &ENTRY_TENIASIS_7229408385178515529)],
        &[(0b11010, &ENTRY_TENIOID_11942386963829586985)],
        &[(0b11010, &ENTRY_TES_5634224708893959490)],
    ],
    range: 1..=8,
};

static VARS_TAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAC_CHILDREN),
    value: None,
};

pub static VARS_TAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hypnea"),
        dictgen::InsensitiveStr::Ascii("hypneas"),
        dictgen::InsensitiveStr::Ascii("hypneic"),
        dictgen::InsensitiveStr::Ascii("hypnoea"),
        dictgen::InsensitiveStr::Ascii("hypnoeas"),
        dictgen::InsensitiveStr::Ascii("hypnoeic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TACHYPNEA_3166922207303436381)],
        &[(0b00001, &ENTRY_TACHYPNEAS_5067707765941922607)],
        &[(0b00001, &ENTRY_TACHYPNEIC_6595193245006460158)],
        &[(0b11010, &ENTRY_TACHYPNEA_3166922207303436381)],
        &[(0b11010, &ENTRY_TACHYPNEAS_5067707765941922607)],
        &[(0b11010, &ENTRY_TACHYPNEIC_6595193245006460158)],
    ],
    range: 6..=8,
};

static VARS_TAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_TAB_CHILDREN),
    value: None,
};

pub static VARS_TAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("oret"),
        dictgen::InsensitiveStr::Ascii("orets"),
        dictgen::InsensitiveStr::Ascii("orin"),
        dictgen::InsensitiveStr::Ascii("orine"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orins"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ouret"),
        dictgen::InsensitiveStr::Ascii("ourets"),
        dictgen::InsensitiveStr::Ascii("ourin"),
        dictgen::InsensitiveStr::Ascii("ourine"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourins"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b00001, &ENTRY_TABORED_3458012263090109952)],
        &[(0b00001, &ENTRY_TABORER_259230914231617550)],
        &[(0b00001, &ENTRY_TABORERS_6060629822354641976)],
        &[(0b00001, &ENTRY_TABORET_7350560887326673778)],
        &[(0b00001, &ENTRY_TABORETS_12733109459658678516)],
        &[(0b00001, &ENTRY_TABORIN_4037230761017031912)],
        &[(0b00001, &ENTRY_TABORINE_6438755799910501319)],
        &[(0b00001, &ENTRY_TABORING_10201578819028294847)],
        &[(0b00001, &ENTRY_TABORINS_16033201340157357087)],
        &[(0b11010, &ENTRY_TABORED_3458012263090109952)],
        &[(0b11010, &ENTRY_TABORER_259230914231617550)],
        &[(0b11010, &ENTRY_TABORERS_6060629822354641976)],
        &[(0b11010, &ENTRY_TABORET_7350560887326673778)],
        &[(0b11010, &ENTRY_TABORETS_12733109459658678516)],
        &[(0b11010, &ENTRY_TABORIN_4037230761017031912)],
        &[(0b11010, &ENTRY_TABORINE_6438755799910501319)],
        &[(0b11010, &ENTRY_TABORING_10201578819028294847)],
        &[(0b11010, &ENTRY_TABORINS_16033201340157357087)],
        &[(0b11010, &ENTRY_TABULE_16853827266028831247)],
        &[(0b10010, &ENTRY_TABULARIZATION_13918426618250472515)],
        &[(0b10010, &ENTRY_TABULARIZATIONS_7435992087915599492)],
        &[(0b10010, &ENTRY_TABULARIZE_4261090986956683891)],
        &[(0b10010, &ENTRY_TABULARIZED_7994290726718343521)],
        &[(0b10010, &ENTRY_TABULARIZES_5785970776539734545)],
        &[(0b10010, &ENTRY_TABULARIZING_182464911659236753)],
        &[(0b01001, &ENTRY_TABULARIZATION_13918426618250472515)],
        &[(0b01001, &ENTRY_TABULARIZATIONS_7435992087915599492)],
        &[(0b01001, &ENTRY_TABULARIZE_4261090986956683891)],
        &[(0b01001, &ENTRY_TABULARIZED_7994290726718343521)],
        &[(0b01001, &ENTRY_TABULARIZES_5785970776539734545)],
        &[(0b01001, &ENTRY_TABULARIZING_182464911659236753)],
        &[(0b00001, &ENTRY_TABULE_16853827266028831247)],
    ],
    range: 3..=12,
};

static VARS_S_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_S_CHILDREN),
    value: None,
};

static VARS_S_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SA_NODE),
    None,
    Some(&VARS_SC_NODE),
    None,
    Some(&VARS_SE_NODE),
    None,
    None,
    Some(&VARS_SH_NODE),
    Some(&VARS_SI_NODE),
    None,
    Some(&VARS_SK_NODE),
    Some(&VARS_SL_NODE),
    Some(&VARS_SM_NODE),
    Some(&VARS_SN_NODE),
    Some(&VARS_SO_NODE),
    Some(&VARS_SP_NODE),
    Some(&VARS_SQ_NODE),
    None,
    None,
    Some(&VARS_ST_NODE),
    Some(&VARS_SU_NODE),
    None,
    Some(&VARS_SW_NODE),
    None,
    Some(&VARS_SY_NODE),
    None,
];

static VARS_SY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SY_CHILDREN),
    value: None,
};

static VARS_SY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_SYC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SYL_NODE),
    Some(&VARS_SYM_NODE),
    Some(&VARS_SYN_NODE),
    None,
    Some(&VARS_SYP_NODE),
    None,
    Some(&VARS_SYR_NODE),
    Some(&VARS_SYS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SYS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYS_CHILDREN),
    value: None,
};

pub static VARS_SYS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tematisation"),
        dictgen::InsensitiveStr::Ascii("tematisations"),
        dictgen::InsensitiveStr::Ascii("tematise"),
        dictgen::InsensitiveStr::Ascii("tematised"),
        dictgen::InsensitiveStr::Ascii("tematiser"),
        dictgen::InsensitiveStr::Ascii("tematisers"),
        dictgen::InsensitiveStr::Ascii("tematises"),
        dictgen::InsensitiveStr::Ascii("tematising"),
        dictgen::InsensitiveStr::Ascii("tematization"),
        dictgen::InsensitiveStr::Ascii("tematizations"),
        dictgen::InsensitiveStr::Ascii("tematize"),
        dictgen::InsensitiveStr::Ascii("tematized"),
        dictgen::InsensitiveStr::Ascii("tematizer"),
        dictgen::InsensitiveStr::Ascii("tematizers"),
        dictgen::InsensitiveStr::Ascii("tematizes"),
        dictgen::InsensitiveStr::Ascii("tematizing"),
        dictgen::InsensitiveStr::Ascii("temisable"),
        dictgen::InsensitiveStr::Ascii("temisabler"),
        dictgen::InsensitiveStr::Ascii("temisables"),
        dictgen::InsensitiveStr::Ascii("temisablest"),
        dictgen::InsensitiveStr::Ascii("temisation"),
        dictgen::InsensitiveStr::Ascii("temisations"),
        dictgen::InsensitiveStr::Ascii("temise"),
        dictgen::InsensitiveStr::Ascii("temised"),
        dictgen::InsensitiveStr::Ascii("temiser"),
        dictgen::InsensitiveStr::Ascii("temisers"),
        dictgen::InsensitiveStr::Ascii("temises"),
        dictgen::InsensitiveStr::Ascii("temising"),
        dictgen::InsensitiveStr::Ascii("temizable"),
        dictgen::InsensitiveStr::Ascii("temizabler"),
        dictgen::InsensitiveStr::Ascii("temizables"),
        dictgen::InsensitiveStr::Ascii("temizablest"),
        dictgen::InsensitiveStr::Ascii("temization"),
        dictgen::InsensitiveStr::Ascii("temizations"),
        dictgen::InsensitiveStr::Ascii("temize"),
        dictgen::InsensitiveStr::Ascii("temized"),
        dictgen::InsensitiveStr::Ascii("temizer"),
        dictgen::InsensitiveStr::Ascii("temizers"),
        dictgen::InsensitiveStr::Ascii("temizes"),
        dictgen::InsensitiveStr::Ascii("temizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYSTEMATIZATION_7949059312574351676)],
        &[(0b10010, &ENTRY_SYSTEMATIZATIONS_4980889965627146570)],
        &[(0b10010, &ENTRY_SYSTEMATIZE_804615704421462730)],
        &[(0b10010, &ENTRY_SYSTEMATIZED_3960322988302014252)],
        &[(0b10010, &ENTRY_SYSTEMATIZER_12159646041280111468)],
        &[(0b10010, &ENTRY_SYSTEMATIZERS_5220548971047734611)],
        &[(0b10010, &ENTRY_SYSTEMATIZES_6130814802973402788)],
        &[(0b10010, &ENTRY_SYSTEMATIZING_7548356459201607237)],
        &[(0b01001, &ENTRY_SYSTEMATIZATION_7949059312574351676)],
        &[(0b01001, &ENTRY_SYSTEMATIZATIONS_4980889965627146570)],
        &[(0b01001, &ENTRY_SYSTEMATIZE_804615704421462730)],
        &[(0b01001, &ENTRY_SYSTEMATIZED_3960322988302014252)],
        &[(0b01001, &ENTRY_SYSTEMATIZER_12159646041280111468)],
        &[(0b01001, &ENTRY_SYSTEMATIZERS_5220548971047734611)],
        &[(0b01001, &ENTRY_SYSTEMATIZES_6130814802973402788)],
        &[(0b01001, &ENTRY_SYSTEMATIZING_7548356459201607237)],
        &[(0b10010, &ENTRY_SYSTEMIZABLE_6386901091487317898)],
        &[(0b10010, &ENTRY_SYSTEMIZABLER_3507991058574811537)],
        &[(0b10010, &ENTRY_SYSTEMIZABLES_1663867473218562178)],
        &[(0b10010, &ENTRY_SYSTEMIZABLEST_9881026680576809052)],
        &[(0b10010, &ENTRY_SYSTEMIZATION_7402744491389982261)],
        &[(0b10010, &ENTRY_SYSTEMIZATIONS_9736157959771706455)],
        &[(0b10010, &ENTRY_SYSTEMIZE_6507154835856335771)],
        &[(0b10010, &ENTRY_SYSTEMIZED_5994844121926171444)],
        &[(0b10010, &ENTRY_SYSTEMIZER_1967185930700519507)],
        &[(0b10010, &ENTRY_SYSTEMIZERS_9699204790114175286)],
        &[(0b10010, &ENTRY_SYSTEMIZES_1513912670035920399)],
        &[(0b10010, &ENTRY_SYSTEMIZING_11787131178563974725)],
        &[(0b01001, &ENTRY_SYSTEMIZABLE_6386901091487317898)],
        &[(0b01001, &ENTRY_SYSTEMIZABLER_3507991058574811537)],
        &[(0b01001, &ENTRY_SYSTEMIZABLES_1663867473218562178)],
        &[(0b01001, &ENTRY_SYSTEMIZABLEST_9881026680576809052)],
        &[(0b01001, &ENTRY_SYSTEMIZATION_7402744491389982261)],
        &[(0b01001, &ENTRY_SYSTEMIZATIONS_9736157959771706455)],
        &[(0b01001, &ENTRY_SYSTEMIZE_6507154835856335771)],
        &[(0b01001, &ENTRY_SYSTEMIZED_5994844121926171444)],
        &[(0b01001, &ENTRY_SYSTEMIZER_1967185930700519507)],
        &[(0b01001, &ENTRY_SYSTEMIZERS_9699204790114175286)],
        &[(0b01001, &ENTRY_SYSTEMIZES_1513912670035920399)],
        &[(0b01001, &ENTRY_SYSTEMIZING_11787131178563974725)],
    ],
    range: 6..=13,
};

static VARS_SYR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYR_CHILDREN),
    value: None,
};

pub static VARS_SYR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ianise"),
        dictgen::InsensitiveStr::Ascii("ianises"),
        dictgen::InsensitiveStr::Ascii("ianize"),
        dictgen::InsensitiveStr::Ascii("ianizes"),
        dictgen::InsensitiveStr::Ascii("ingocele"),
        dictgen::InsensitiveStr::Ascii("ingocoele"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYRIANIZE_10187036361030900008)],
        &[(0b10010, &ENTRY_SYRIANIZES_15205618974659997671)],
        &[(0b01001, &ENTRY_SYRIANIZE_10187036361030900008)],
        &[(0b01001, &ENTRY_SYRIANIZES_15205618974659997671)],
        &[(0b00001, &ENTRY_SYRINGOCELE_11968813307237913697)],
        &[(0b11010, &ENTRY_SYRINGOCELE_11968813307237913697)],
    ],
    range: 6..=9,
};

static VARS_SYP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYP_CHILDREN),
    value: None,
};

pub static VARS_SYP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hilisation"),
        dictgen::InsensitiveStr::Ascii("hilisations"),
        dictgen::InsensitiveStr::Ascii("hilise"),
        dictgen::InsensitiveStr::Ascii("hilised"),
        dictgen::InsensitiveStr::Ascii("hilising"),
        dictgen::InsensitiveStr::Ascii("hilization"),
        dictgen::InsensitiveStr::Ascii("hilizations"),
        dictgen::InsensitiveStr::Ascii("hilize"),
        dictgen::InsensitiveStr::Ascii("hilized"),
        dictgen::InsensitiveStr::Ascii("hilizing"),
        dictgen::InsensitiveStr::Ascii("hon"),
        dictgen::InsensitiveStr::Ascii("honed"),
        dictgen::InsensitiveStr::Ascii("honing"),
        dictgen::InsensitiveStr::Ascii("honless"),
        dictgen::InsensitiveStr::Ascii("honlesses"),
        dictgen::InsensitiveStr::Ascii("honlike"),
        dictgen::InsensitiveStr::Ascii("honlikes"),
        dictgen::InsensitiveStr::Ascii("honophore"),
        dictgen::InsensitiveStr::Ascii("honostele"),
        dictgen::InsensitiveStr::Ascii("honostelic"),
        dictgen::InsensitiveStr::Ascii("honostely"),
        dictgen::InsensitiveStr::Ascii("hons"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYPHILIZATION_4055568425962123768)],
        &[(0b10010, &ENTRY_SYPHILIZATIONS_6566377490752303452)],
        &[(0b10010, &ENTRY_SYPHILIZE_13140711569267519345)],
        &[(0b10010, &ENTRY_SYPHILIZED_11930486983642777973)],
        &[(0b10010, &ENTRY_SYPHILIZING_14288192544253600248)],
        &[(0b01001, &ENTRY_SYPHILIZATION_4055568425962123768)],
        &[(0b01001, &ENTRY_SYPHILIZATIONS_6566377490752303452)],
        &[(0b01001, &ENTRY_SYPHILIZE_13140711569267519345)],
        &[(0b01001, &ENTRY_SYPHILIZED_11930486983642777973)],
        &[(0b01001, &ENTRY_SYPHILIZING_14288192544253600248)],
        &[(0b10010, &ENTRY_SIPHON_7910828118148547350)],
        &[(0b10010, &ENTRY_SIPHONED_13775252266477144644)],
        &[(0b10010, &ENTRY_SIPHONING_3524409665423772935)],
        &[(0b11010, &ENTRY_SIPHONLESS_10853607871264713731)],
        &[(0b11010, &ENTRY_SIPHONLESSES_6742087362595900505)],
        &[(0b11010, &ENTRY_SIPHONLIKE_3466549338188047789)],
        &[(0b11010, &ENTRY_SIPHONLIKES_4271727245061818819)],
        &[(0b11010, &ENTRY_SIPHONOPHORE_13045084369054789980)],
        &[(0b11010, &ENTRY_SIPHONOSTELE_10401690898945006274)],
        &[(0b11010, &ENTRY_SIPHONOSTELIC_6331118512817996757)],
        &[(0b11010, &ENTRY_SIPHONOSTELY_260206920676310428)],
        &[(0b10010, &ENTRY_SIPHONS_9477554659409124740)],
    ],
    range: 3..=11,
};

static VARS_SYN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SYN_CHILDREN),
    value: None,
};

static VARS_SYN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SYNA_NODE),
    None,
    Some(&VARS_SYNC_NODE),
    Some(&VARS_SYND_NODE),
    Some(&VARS_SYNE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SYNO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_SYNT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SYNT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNT_CHILDREN),
    value: None,
};

pub static VARS_SYNT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hesisation"),
        dictgen::InsensitiveStr::Ascii("hesisations"),
        dictgen::InsensitiveStr::Ascii("hesise"),
        dictgen::InsensitiveStr::Ascii("hesised"),
        dictgen::InsensitiveStr::Ascii("hesiser"),
        dictgen::InsensitiveStr::Ascii("hesisers"),
        dictgen::InsensitiveStr::Ascii("hesises"),
        dictgen::InsensitiveStr::Ascii("hesising"),
        dictgen::InsensitiveStr::Ascii("hesization"),
        dictgen::InsensitiveStr::Ascii("hesizations"),
        dictgen::InsensitiveStr::Ascii("hesize"),
        dictgen::InsensitiveStr::Ascii("hesized"),
        dictgen::InsensitiveStr::Ascii("hesizes"),
        dictgen::InsensitiveStr::Ascii("hesizing"),
        dictgen::InsensitiveStr::Ascii("hetisation"),
        dictgen::InsensitiveStr::Ascii("hetiser"),
        dictgen::InsensitiveStr::Ascii("hetisers"),
        dictgen::InsensitiveStr::Ascii("hetization"),
        dictgen::InsensitiveStr::Ascii("hetize"),
        dictgen::InsensitiveStr::Ascii("hetized"),
        dictgen::InsensitiveStr::Ascii("hetizer"),
        dictgen::InsensitiveStr::Ascii("hetizers"),
        dictgen::InsensitiveStr::Ascii("hetizes"),
        dictgen::InsensitiveStr::Ascii("hetizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYNTHESIZATION_7847480716228741176)],
        &[(0b10010, &ENTRY_SYNTHESIZATIONS_6008071763176942923)],
        &[(0b10010, &ENTRY_SYNTHESIZE_12262264416656123255)],
        &[(0b10010, &ENTRY_SYNTHESIZED_10277854444798047575)],
        &[(0b11010, &ENTRY_SYNTHESIZER_5120597236259656684)],
        &[(0b11010, &ENTRY_SYNTHESIZERS_17412149831785719286)],
        &[(0b10010, &ENTRY_SYNTHESIZES_16719832496998918898)],
        &[(0b10010, &ENTRY_SYNTHESIZING_961211694929147125)],
        &[(0b01001, &ENTRY_SYNTHESIZATION_7847480716228741176)],
        &[(0b01001, &ENTRY_SYNTHESIZATIONS_6008071763176942923)],
        &[(0b01001, &ENTRY_SYNTHESIZE_12262264416656123255)],
        &[(0b01001, &ENTRY_SYNTHESIZED_10277854444798047575)],
        &[(0b01001, &ENTRY_SYNTHESIZES_16719832496998918898)],
        &[(0b01001, &ENTRY_SYNTHESIZING_961211694929147125)],
        &[(0b10010, &ENTRY_SYNTHETIZATION_8539269556584261248)],
        &[(0b10010, &ENTRY_SYNTHETIZER_7370135773010889066)],
        &[(0b10010, &ENTRY_SYNTHETIZERS_13381239636453117418)],
        &[(0b01001, &ENTRY_SYNTHETIZATION_8539269556584261248)],
        &[(0b01000, &ENTRY_SYNTHESIZE_12262264416656123255)],
        &[(0b01000, &ENTRY_SYNTHESIZED_10277854444798047575)],
        &[(0b01001, &ENTRY_SYNTHETIZER_7370135773010889066)],
        &[(0b01001, &ENTRY_SYNTHETIZERS_13381239636453117418)],
        &[(0b01000, &ENTRY_SYNTHESIZES_16719832496998918898)],
        &[(0b01000, &ENTRY_SYNTHESIZING_961211694929147125)],
        &[(0b10010, &ENTRY_SYNTONIZATION_14856908759061340234)],
        &[(0b10010, &ENTRY_SYNTONIZE_1485992200194358305)],
        &[(0b10010, &ENTRY_SYNTONIZED_15041457439325800203)],
        &[(0b10010, &ENTRY_SYNTONIZES_17498682094763362419)],
        &[(0b10010, &ENTRY_SYNTONIZING_3933548631109004593)],
        &[(0b01001, &ENTRY_SYNTONIZATION_14856908759061340234)],
        &[(0b01001, &ENTRY_SYNTONIZE_1485992200194358305)],
        &[(0b01001, &ENTRY_SYNTONIZED_15041457439325800203)],
        &[(0b01001, &ENTRY_SYNTONIZES_17498682094763362419)],
        &[(0b01001, &ENTRY_SYNTONIZING_3933548631109004593)],
    ],
    range: 5..=11,
};

static VARS_SYNO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNO_CHILDREN),
    value: None,
};

pub static VARS_SYNO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecious"),
        dictgen::InsensitiveStr::Ascii("ecise"),
        dictgen::InsensitiveStr::Ascii("ecised"),
        dictgen::InsensitiveStr::Ascii("ecises"),
        dictgen::InsensitiveStr::Ascii("ecising"),
        dictgen::InsensitiveStr::Ascii("ecize"),
        dictgen::InsensitiveStr::Ascii("ecized"),
        dictgen::InsensitiveStr::Ascii("ecizes"),
        dictgen::InsensitiveStr::Ascii("ecizing"),
        dictgen::InsensitiveStr::Ascii("ecologies"),
        dictgen::InsensitiveStr::Ascii("ecology"),
        dictgen::InsensitiveStr::Ascii("etic"),
        dictgen::InsensitiveStr::Ascii("nymise"),
        dictgen::InsensitiveStr::Ascii("nymised"),
        dictgen::InsensitiveStr::Ascii("nymises"),
        dictgen::InsensitiveStr::Ascii("nymising"),
        dictgen::InsensitiveStr::Ascii("nymize"),
        dictgen::InsensitiveStr::Ascii("nymized"),
        dictgen::InsensitiveStr::Ascii("nymizes"),
        dictgen::InsensitiveStr::Ascii("nymizing"),
        dictgen::InsensitiveStr::Ascii("psise"),
        dictgen::InsensitiveStr::Ascii("psised"),
        dictgen::InsensitiveStr::Ascii("psises"),
        dictgen::InsensitiveStr::Ascii("psising"),
        dictgen::InsensitiveStr::Ascii("psize"),
        dictgen::InsensitiveStr::Ascii("psized"),
        dictgen::InsensitiveStr::Ascii("psizes"),
        dictgen::InsensitiveStr::Ascii("psizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SYNECIOUS_16097725599665781486)],
        &[(0b10010, &ENTRY_SYNOECIZE_9903365931663314390)],
        &[(0b10010, &ENTRY_SYNOECIZED_1258981145885331765)],
        &[(0b10010, &ENTRY_SYNOECIZES_14157018111278412405)],
        &[(0b10010, &ENTRY_SYNOECIZING_12619177850029321994)],
        &[(0b01001, &ENTRY_SYNOECIZE_9903365931663314390)],
        &[(0b01001, &ENTRY_SYNOECIZED_1258981145885331765)],
        &[(0b01001, &ENTRY_SYNOECIZES_14157018111278412405)],
        &[(0b01001, &ENTRY_SYNOECIZING_12619177850029321994)],
        &[(0b11010, &ENTRY_SYNECOLOGIES_6305448968712762615)],
        &[(0b11010, &ENTRY_SYNECOLOGY_11727520395273669799)],
        &[(0b11010, &ENTRY_SYNETIC_11062609274567880634)],
        &[(0b10010, &ENTRY_SYNONYMIZE_3437118653893618787)],
        &[(0b10010, &ENTRY_SYNONYMIZED_16655983300964530292)],
        &[(0b10010, &ENTRY_SYNONYMIZES_5682029261506663420)],
        &[(0b10010, &ENTRY_SYNONYMIZING_10383839589382127203)],
        &[(0b01001, &ENTRY_SYNONYMIZE_3437118653893618787)],
        &[(0b01001, &ENTRY_SYNONYMIZED_16655983300964530292)],
        &[(0b01001, &ENTRY_SYNONYMIZES_5682029261506663420)],
        &[(0b01001, &ENTRY_SYNONYMIZING_10383839589382127203)],
        &[(0b10010, &ENTRY_SYNOPSIZE_5009645523556777721)],
        &[(0b10010, &ENTRY_SYNOPSIZED_1730636117992196147)],
        &[(0b10010, &ENTRY_SYNOPSIZES_14967276778682343138)],
        &[(0b10010, &ENTRY_SYNOPSIZING_8436973275561705386)],
        &[(0b01001, &ENTRY_SYNOPSIZE_5009645523556777721)],
        &[(0b01001, &ENTRY_SYNOPSIZED_1730636117992196147)],
        &[(0b01001, &ENTRY_SYNOPSIZES_14967276778682343138)],
        &[(0b01001, &ENTRY_SYNOPSIZING_8436973275561705386)],
    ],
    range: 4..=9,
};

static VARS_SYNE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNE_CHILDREN),
    value: None,
};

pub static VARS_SYNE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("cologies"),
        dictgen::InsensitiveStr::Ascii("cology"),
        dictgen::InsensitiveStr::Ascii("reses"),
        dictgen::InsensitiveStr::Ascii("resis"),
        dictgen::InsensitiveStr::Ascii("rgise"),
        dictgen::InsensitiveStr::Ascii("rgised"),
        dictgen::InsensitiveStr::Ascii("rgises"),
        dictgen::InsensitiveStr::Ascii("rgising"),
        dictgen::InsensitiveStr::Ascii("rgize"),
        dictgen::InsensitiveStr::Ascii("rgized"),
        dictgen::InsensitiveStr::Ascii("rgizes"),
        dictgen::InsensitiveStr::Ascii("rgizing"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("stheticer"),
        dictgen::InsensitiveStr::Ascii("stheticest"),
        dictgen::InsensitiveStr::Ascii("tic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SYNECIOUS_16097725599665781486)],
        &[(0b00001, &ENTRY_SYNECOLOGIES_6305448968712762615)],
        &[(0b00001, &ENTRY_SYNECOLOGY_11727520395273669799)],
        &[(0b00001, &ENTRY_SYNERESES_8324225573506584897)],
        &[(0b00001, &ENTRY_SYNERESIS_10899482620726729247)],
        &[(0b10010, &ENTRY_SYNERGIZE_8702906954167154251)],
        &[(0b10010, &ENTRY_SYNERGIZED_2939063503049761679)],
        &[(0b10010, &ENTRY_SYNERGIZES_1372737127479711106)],
        &[(0b10010, &ENTRY_SYNERGIZING_11050376152195270684)],
        &[(0b01001, &ENTRY_SYNERGIZE_8702906954167154251)],
        &[(0b01001, &ENTRY_SYNERGIZED_2939063503049761679)],
        &[(0b01001, &ENTRY_SYNERGIZES_1372737127479711106)],
        &[(0b01001, &ENTRY_SYNERGIZING_11050376152195270684)],
        &[(0b10001, &ENTRY_SYNESTHESIA_16292496210206747868)],
        &[(0b10001, &ENTRY_SYNESTHESIAS_15212694822545420870)],
        &[(0b10001, &ENTRY_SYNESTHETIC_3600503920231115312)],
        &[(0b10001, &ENTRY_SYNESTHETICER_10910454298234931775)],
        &[(0b10001, &ENTRY_SYNESTHETICEST_831211085037853858)],
        &[(0b00001, &ENTRY_SYNETIC_11062609274567880634)],
    ],
    range: 3..=10,
};

static VARS_SYND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYND_CHILDREN),
    value: None,
};

pub static VARS_SYND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYNDICALIZE_6097714922943684680)],
        &[(0b10010, &ENTRY_SYNDICALIZES_7458900059096200056)],
        &[(0b01001, &ENTRY_SYNDICALIZE_6097714922943684680)],
        &[(0b01001, &ENTRY_SYNDICALIZES_7458900059096200056)],
    ],
    range: 7..=8,
};

static VARS_SYNC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNC_CHILDREN),
    value: None,
};

pub static VARS_SYNC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hronisable"),
        dictgen::InsensitiveStr::Ascii("hronisables"),
        dictgen::InsensitiveStr::Ascii("hronisation"),
        dictgen::InsensitiveStr::Ascii("hronisations"),
        dictgen::InsensitiveStr::Ascii("hronise"),
        dictgen::InsensitiveStr::Ascii("hronised"),
        dictgen::InsensitiveStr::Ascii("hroniser"),
        dictgen::InsensitiveStr::Ascii("hronisers"),
        dictgen::InsensitiveStr::Ascii("hronises"),
        dictgen::InsensitiveStr::Ascii("hronising"),
        dictgen::InsensitiveStr::Ascii("hronizable"),
        dictgen::InsensitiveStr::Ascii("hronizables"),
        dictgen::InsensitiveStr::Ascii("hronization"),
        dictgen::InsensitiveStr::Ascii("hronizations"),
        dictgen::InsensitiveStr::Ascii("hronize"),
        dictgen::InsensitiveStr::Ascii("hronized"),
        dictgen::InsensitiveStr::Ascii("hronizer"),
        dictgen::InsensitiveStr::Ascii("hronizers"),
        dictgen::InsensitiveStr::Ascii("hronizes"),
        dictgen::InsensitiveStr::Ascii("hronizing"),
        dictgen::InsensitiveStr::Ascii("retise"),
        dictgen::InsensitiveStr::Ascii("retised"),
        dictgen::InsensitiveStr::Ascii("retises"),
        dictgen::InsensitiveStr::Ascii("retising"),
        dictgen::InsensitiveStr::Ascii("retize"),
        dictgen::InsensitiveStr::Ascii("retized"),
        dictgen::InsensitiveStr::Ascii("retizes"),
        dictgen::InsensitiveStr::Ascii("retizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYNCHRONIZABLE_3205035752239437919)],
        &[(0b10010, &ENTRY_SYNCHRONIZABLES_11909224206869588914)],
        &[(0b10010, &ENTRY_SYNCHRONIZATION_5190235443366915825)],
        &[(0b10010, &ENTRY_SYNCHRONIZATIONS_17488049115311509779)],
        &[(0b10010, &ENTRY_SYNCHRONIZE_15214148970446599589)],
        &[(0b10010, &ENTRY_SYNCHRONIZED_10463645930849898556)],
        &[(0b10010, &ENTRY_SYNCHRONIZER_18217273731132106451)],
        &[(0b10010, &ENTRY_SYNCHRONIZERS_7212648156840732242)],
        &[(0b10010, &ENTRY_SYNCHRONIZES_1300752223538140438)],
        &[(0b10010, &ENTRY_SYNCHRONIZING_16424531352538153842)],
        &[(0b01001, &ENTRY_SYNCHRONIZABLE_3205035752239437919)],
        &[(0b01001, &ENTRY_SYNCHRONIZABLES_11909224206869588914)],
        &[(0b01001, &ENTRY_SYNCHRONIZATION_5190235443366915825)],
        &[(0b01001, &ENTRY_SYNCHRONIZATIONS_17488049115311509779)],
        &[(0b01001, &ENTRY_SYNCHRONIZE_15214148970446599589)],
        &[(0b01001, &ENTRY_SYNCHRONIZED_10463645930849898556)],
        &[(0b01001, &ENTRY_SYNCHRONIZER_18217273731132106451)],
        &[(0b01001, &ENTRY_SYNCHRONIZERS_7212648156840732242)],
        &[(0b01001, &ENTRY_SYNCHRONIZES_1300752223538140438)],
        &[(0b01001, &ENTRY_SYNCHRONIZING_16424531352538153842)],
        &[(0b10010, &ENTRY_SYNCRETIZE_11946220904942894650)],
        &[(0b10010, &ENTRY_SYNCRETIZED_132756498383462765)],
        &[(0b10010, &ENTRY_SYNCRETIZES_15427417846092983438)],
        &[(0b10010, &ENTRY_SYNCRETIZING_16214408936304608287)],
        &[(0b01001, &ENTRY_SYNCRETIZE_11946220904942894650)],
        &[(0b01001, &ENTRY_SYNCRETIZED_132756498383462765)],
        &[(0b01001, &ENTRY_SYNCRETIZES_15427417846092983438)],
        &[(0b01001, &ENTRY_SYNCRETIZING_16214408936304608287)],
    ],
    range: 6..=12,
};

static VARS_SYNA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYNA_CHILDREN),
    value: None,
};

pub static VARS_SYNA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ereses"),
        dictgen::InsensitiveStr::Ascii("eresis"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("estheticer"),
        dictgen::InsensitiveStr::Ascii("estheticest"),
        dictgen::InsensitiveStr::Ascii("lepha"),
        dictgen::InsensitiveStr::Ascii("lephas"),
        dictgen::InsensitiveStr::Ascii("lephe"),
        dictgen::InsensitiveStr::Ascii("loepha"),
        dictgen::InsensitiveStr::Ascii("loephas"),
        dictgen::InsensitiveStr::Ascii("loephe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SYNERESES_8324225573506584897)],
        &[(0b11010, &ENTRY_SYNERESIS_10899482620726729247)],
        &[(0b11010, &ENTRY_SYNESTHESIA_16292496210206747868)],
        &[(0b11010, &ENTRY_SYNESTHESIAS_15212694822545420870)],
        &[(0b11010, &ENTRY_SYNESTHETIC_3600503920231115312)],
        &[(0b11010, &ENTRY_SYNESTHETICER_10910454298234931775)],
        &[(0b11010, &ENTRY_SYNESTHETICEST_831211085037853858)],
        &[(0b00001, &ENTRY_SYNALEPHA_7165508884472247255)],
        &[(0b00001, &ENTRY_SYNALEPHAS_15856626290957460889)],
        &[(0b00001, &ENTRY_SYNALEPHE_7691233255701997232)],
        &[(0b11010, &ENTRY_SYNALEPHA_7165508884472247255)],
        &[(0b11010, &ENTRY_SYNALEPHAS_15856626290957460889)],
        &[(0b11010, &ENTRY_SYNALEPHE_7691233255701997232)],
    ],
    range: 5..=11,
};

static VARS_SYM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SYM_CHILDREN),
    value: None,
};

static VARS_SYM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SYMB_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SYMM_NODE),
    None,
    None,
    Some(&VARS_SYMP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SYMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYMP_CHILDREN),
    value: None,
};

pub static VARS_SYMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("athise"),
        dictgen::InsensitiveStr::Ascii("athised"),
        dictgen::InsensitiveStr::Ascii("athiser"),
        dictgen::InsensitiveStr::Ascii("athisers"),
        dictgen::InsensitiveStr::Ascii("athises"),
        dictgen::InsensitiveStr::Ascii("athising"),
        dictgen::InsensitiveStr::Ascii("athisinglier"),
        dictgen::InsensitiveStr::Ascii("athisingliest"),
        dictgen::InsensitiveStr::Ascii("athisingly"),
        dictgen::InsensitiveStr::Ascii("athisings"),
        dictgen::InsensitiveStr::Ascii("athize"),
        dictgen::InsensitiveStr::Ascii("athized"),
        dictgen::InsensitiveStr::Ascii("athizer"),
        dictgen::InsensitiveStr::Ascii("athizers"),
        dictgen::InsensitiveStr::Ascii("athizes"),
        dictgen::InsensitiveStr::Ascii("athizing"),
        dictgen::InsensitiveStr::Ascii("athizinglier"),
        dictgen::InsensitiveStr::Ascii("athizingliest"),
        dictgen::InsensitiveStr::Ascii("athizingly"),
        dictgen::InsensitiveStr::Ascii("athizings"),
        dictgen::InsensitiveStr::Ascii("honisation"),
        dictgen::InsensitiveStr::Ascii("honise"),
        dictgen::InsensitiveStr::Ascii("honised"),
        dictgen::InsensitiveStr::Ascii("honising"),
        dictgen::InsensitiveStr::Ascii("honization"),
        dictgen::InsensitiveStr::Ascii("honize"),
        dictgen::InsensitiveStr::Ascii("honized"),
        dictgen::InsensitiveStr::Ascii("honizing"),
        dictgen::InsensitiveStr::Ascii("tomatise"),
        dictgen::InsensitiveStr::Ascii("tomatised"),
        dictgen::InsensitiveStr::Ascii("tomatises"),
        dictgen::InsensitiveStr::Ascii("tomatising"),
        dictgen::InsensitiveStr::Ascii("tomatize"),
        dictgen::InsensitiveStr::Ascii("tomatized"),
        dictgen::InsensitiveStr::Ascii("tomatizes"),
        dictgen::InsensitiveStr::Ascii("tomatizing"),
        dictgen::InsensitiveStr::Ascii("tomise"),
        dictgen::InsensitiveStr::Ascii("tomises"),
        dictgen::InsensitiveStr::Ascii("tomize"),
        dictgen::InsensitiveStr::Ascii("tomizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYMPATHIZE_2083128667147215284)],
        &[(0b10010, &ENTRY_SYMPATHIZED_9100939682714028608)],
        &[(0b10010, &ENTRY_SYMPATHIZER_6062465131842187171)],
        &[(0b10010, &ENTRY_SYMPATHIZERS_3558777146047267180)],
        &[(0b10010, &ENTRY_SYMPATHIZES_18348047905035226610)],
        &[(0b10010, &ENTRY_SYMPATHIZING_5627262407078518926)],
        &[(0b10010, &ENTRY_SYMPATHIZINGLIER_17003334067553508909)],
        &[(0b10010, &ENTRY_SYMPATHIZINGLIEST_8990695458438411519)],
        &[(0b10010, &ENTRY_SYMPATHIZINGLY_18120189054155456947)],
        &[(0b10010, &ENTRY_SYMPATHIZINGS_14242801861585199541)],
        &[(0b01001, &ENTRY_SYMPATHIZE_2083128667147215284)],
        &[(0b01001, &ENTRY_SYMPATHIZED_9100939682714028608)],
        &[(0b01001, &ENTRY_SYMPATHIZER_6062465131842187171)],
        &[(0b01001, &ENTRY_SYMPATHIZERS_3558777146047267180)],
        &[(0b01001, &ENTRY_SYMPATHIZES_18348047905035226610)],
        &[(0b01001, &ENTRY_SYMPATHIZING_5627262407078518926)],
        &[(0b01001, &ENTRY_SYMPATHIZINGLIER_17003334067553508909)],
        &[(0b01001, &ENTRY_SYMPATHIZINGLIEST_8990695458438411519)],
        &[(0b01001, &ENTRY_SYMPATHIZINGLY_18120189054155456947)],
        &[(0b01001, &ENTRY_SYMPATHIZINGS_14242801861585199541)],
        &[(0b10010, &ENTRY_SYMPHONIZATION_7458803542727781710)],
        &[(0b10010, &ENTRY_SYMPHONIZE_14460696128283226931)],
        &[(0b10010, &ENTRY_SYMPHONIZED_10820642800496437334)],
        &[(0b10010, &ENTRY_SYMPHONIZING_6006748045534915173)],
        &[(0b01001, &ENTRY_SYMPHONIZATION_7458803542727781710)],
        &[(0b01001, &ENTRY_SYMPHONIZE_14460696128283226931)],
        &[(0b01001, &ENTRY_SYMPHONIZED_10820642800496437334)],
        &[(0b01001, &ENTRY_SYMPHONIZING_6006748045534915173)],
        &[(0b10010, &ENTRY_SYMPTOMATIZE_7741807692536744481)],
        &[(0b10010, &ENTRY_SYMPTOMATIZED_13255146815106504892)],
        &[(0b10010, &ENTRY_SYMPTOMATIZES_17459302438827356078)],
        &[(0b10010, &ENTRY_SYMPTOMATIZING_7075635847781625915)],
        &[(0b01001, &ENTRY_SYMPTOMATIZE_7741807692536744481)],
        &[(0b01001, &ENTRY_SYMPTOMATIZED_13255146815106504892)],
        &[(0b01001, &ENTRY_SYMPTOMATIZES_17459302438827356078)],
        &[(0b01001, &ENTRY_SYMPTOMATIZING_7075635847781625915)],
        &[(0b10010, &ENTRY_SYMPTOMIZE_10180337916709250431)],
        &[(0b10010, &ENTRY_SYMPTOMIZES_2947814609442326128)],
        &[(0b01001, &ENTRY_SYMPTOMIZE_10180337916709250431)],
        &[(0b01001, &ENTRY_SYMPTOMIZES_2947814609442326128)],
    ],
    range: 6..=13,
};

static VARS_SYMM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYMM_CHILDREN),
    value: None,
};

pub static VARS_SYMM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etricly"),
        dictgen::InsensitiveStr::Ascii("etrisation"),
        dictgen::InsensitiveStr::Ascii("etrisations"),
        dictgen::InsensitiveStr::Ascii("etrise"),
        dictgen::InsensitiveStr::Ascii("etrised"),
        dictgen::InsensitiveStr::Ascii("etrises"),
        dictgen::InsensitiveStr::Ascii("etrising"),
        dictgen::InsensitiveStr::Ascii("etrization"),
        dictgen::InsensitiveStr::Ascii("etrizations"),
        dictgen::InsensitiveStr::Ascii("etrize"),
        dictgen::InsensitiveStr::Ascii("etrized"),
        dictgen::InsensitiveStr::Ascii("etrizes"),
        dictgen::InsensitiveStr::Ascii("etrizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SYMMETRICALLY_11790246473159683276)],
        &[(0b10010, &ENTRY_SYMMETRIZATION_485523952999666992)],
        &[(0b10010, &ENTRY_SYMMETRIZATIONS_13298765629243557367)],
        &[(0b10010, &ENTRY_SYMMETRIZE_17748763142030256395)],
        &[(0b10010, &ENTRY_SYMMETRIZED_13721183907018153188)],
        &[(0b10010, &ENTRY_SYMMETRIZES_14737575873723059815)],
        &[(0b10010, &ENTRY_SYMMETRIZING_17834200335648295925)],
        &[(0b01001, &ENTRY_SYMMETRIZATION_485523952999666992)],
        &[(0b01001, &ENTRY_SYMMETRIZATIONS_13298765629243557367)],
        &[(0b01001, &ENTRY_SYMMETRIZE_17748763142030256395)],
        &[(0b01001, &ENTRY_SYMMETRIZED_13721183907018153188)],
        &[(0b01001, &ENTRY_SYMMETRIZES_14737575873723059815)],
        &[(0b01001, &ENTRY_SYMMETRIZING_17834200335648295925)],
    ],
    range: 6..=11,
};

static VARS_SYMB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYMB_CHILDREN),
    value: None,
};

pub static VARS_SYMB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oled"),
        dictgen::InsensitiveStr::Ascii("oling"),
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olisations"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("oliser"),
        dictgen::InsensitiveStr::Ascii("olisers"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olizations"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizer"),
        dictgen::InsensitiveStr::Ascii("olizers"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
        dictgen::InsensitiveStr::Ascii("olled"),
        dictgen::InsensitiveStr::Ascii("olling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SYMBOLED_11424483443027028085)],
        &[(0b00001, &ENTRY_SYMBOLING_10019336982510109720)],
        &[(0b10010, &ENTRY_SYMBOLIZATION_16179533248304689346)],
        &[(0b10010, &ENTRY_SYMBOLIZATIONS_5969166456353671405)],
        &[(0b10010, &ENTRY_SYMBOLIZE_1459836702485298151)],
        &[(0b10010, &ENTRY_SYMBOLIZED_139431671119330705)],
        &[(0b10010, &ENTRY_SYMBOLIZER_12834461225156804749)],
        &[(0b10010, &ENTRY_SYMBOLIZERS_1983691641725453382)],
        &[(0b10010, &ENTRY_SYMBOLIZES_7534842968073056718)],
        &[(0b10010, &ENTRY_SYMBOLIZING_14319052571837316351)],
        &[(0b01001, &ENTRY_SYMBOLIZATION_16179533248304689346)],
        &[(0b01001, &ENTRY_SYMBOLIZATIONS_5969166456353671405)],
        &[(0b01001, &ENTRY_SYMBOLIZE_1459836702485298151)],
        &[(0b01001, &ENTRY_SYMBOLIZED_139431671119330705)],
        &[(0b01001, &ENTRY_SYMBOLIZER_12834461225156804749)],
        &[(0b01001, &ENTRY_SYMBOLIZERS_1983691641725453382)],
        &[(0b01001, &ENTRY_SYMBOLIZES_7534842968073056718)],
        &[(0b01001, &ENTRY_SYMBOLIZING_14319052571837316351)],
        &[(0b11010, &ENTRY_SYMBOLED_11424483443027028085)],
        &[(0b11010, &ENTRY_SYMBOLING_10019336982510109720)],
    ],
    range: 4..=10,
};

static VARS_SYL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYL_CHILDREN),
    value: None,
};

pub static VARS_SYL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("labise"),
        dictgen::InsensitiveStr::Ascii("labised"),
        dictgen::InsensitiveStr::Ascii("labises"),
        dictgen::InsensitiveStr::Ascii("labising"),
        dictgen::InsensitiveStr::Ascii("labize"),
        dictgen::InsensitiveStr::Ascii("labized"),
        dictgen::InsensitiveStr::Ascii("labizes"),
        dictgen::InsensitiveStr::Ascii("labizing"),
        dictgen::InsensitiveStr::Ascii("logisation"),
        dictgen::InsensitiveStr::Ascii("logisations"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logiser"),
        dictgen::InsensitiveStr::Ascii("logisers"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logization"),
        dictgen::InsensitiveStr::Ascii("logizations"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizer"),
        dictgen::InsensitiveStr::Ascii("logizers"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("vanise"),
        dictgen::InsensitiveStr::Ascii("vanises"),
        dictgen::InsensitiveStr::Ascii("vanize"),
        dictgen::InsensitiveStr::Ascii("vanizes"),
        dictgen::InsensitiveStr::Ascii("viinae"),
        dictgen::InsensitiveStr::Ascii("viine"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYLLABIZE_14838824136293204776)],
        &[(0b10010, &ENTRY_SYLLABIZED_9081626028680716952)],
        &[(0b10010, &ENTRY_SYLLABIZES_4355228480284739560)],
        &[(0b10010, &ENTRY_SYLLABIZING_8483234654100117810)],
        &[(0b01001, &ENTRY_SYLLABIZE_14838824136293204776)],
        &[(0b01001, &ENTRY_SYLLABIZED_9081626028680716952)],
        &[(0b01001, &ENTRY_SYLLABIZES_4355228480284739560)],
        &[(0b01001, &ENTRY_SYLLABIZING_8483234654100117810)],
        &[(0b10010, &ENTRY_SYLLOGIZATION_13866539649373728599)],
        &[(0b10010, &ENTRY_SYLLOGIZATIONS_1183019196317532349)],
        &[(0b10010, &ENTRY_SYLLOGIZE_4080740851235947751)],
        &[(0b10010, &ENTRY_SYLLOGIZED_8853526086846614350)],
        &[(0b10010, &ENTRY_SYLLOGIZER_18106093548206015296)],
        &[(0b10010, &ENTRY_SYLLOGIZERS_16910938558367919539)],
        &[(0b10010, &ENTRY_SYLLOGIZES_4817593494892630151)],
        &[(0b10010, &ENTRY_SYLLOGIZING_2067797967245895866)],
        &[(0b01001, &ENTRY_SYLLOGIZATION_13866539649373728599)],
        &[(0b01001, &ENTRY_SYLLOGIZATIONS_1183019196317532349)],
        &[(0b01001, &ENTRY_SYLLOGIZE_4080740851235947751)],
        &[(0b01001, &ENTRY_SYLLOGIZED_8853526086846614350)],
        &[(0b01001, &ENTRY_SYLLOGIZER_18106093548206015296)],
        &[(0b01001, &ENTRY_SYLLOGIZERS_16910938558367919539)],
        &[(0b01001, &ENTRY_SYLLOGIZES_4817593494892630151)],
        &[(0b01001, &ENTRY_SYLLOGIZING_2067797967245895866)],
        &[(0b10010, &ENTRY_SYLVANIZE_6265985924948097486)],
        &[(0b10010, &ENTRY_SYLVANIZES_12196473219346057983)],
        &[(0b01001, &ENTRY_SYLVANIZE_6265985924948097486)],
        &[(0b01001, &ENTRY_SYLVANIZES_12196473219346057983)],
        &[(0b11010, &ENTRY_SYLVIINE_8241338552519015158)],
        &[(0b00001, &ENTRY_SYLVIINE_8241338552519015158)],
    ],
    range: 5..=11,
};

static VARS_SYC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SYC_CHILDREN),
    value: None,
};

pub static VARS_SYC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ophantise"),
        dictgen::InsensitiveStr::Ascii("ophantised"),
        dictgen::InsensitiveStr::Ascii("ophantises"),
        dictgen::InsensitiveStr::Ascii("ophantising"),
        dictgen::InsensitiveStr::Ascii("ophantize"),
        dictgen::InsensitiveStr::Ascii("ophantized"),
        dictgen::InsensitiveStr::Ascii("ophantizes"),
        dictgen::InsensitiveStr::Ascii("ophantizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SYCOPHANTIZE_12413841667742806235)],
        &[(0b10010, &ENTRY_SYCOPHANTIZED_2066913815102436404)],
        &[(0b10010, &ENTRY_SYCOPHANTIZES_13350123606555790806)],
        &[(0b10010, &ENTRY_SYCOPHANTIZING_3707179500919311993)],
        &[(0b01001, &ENTRY_SYCOPHANTIZE_12413841667742806235)],
        &[(0b01001, &ENTRY_SYCOPHANTIZED_2066913815102436404)],
        &[(0b01001, &ENTRY_SYCOPHANTIZES_13350123606555790806)],
        &[(0b01001, &ENTRY_SYCOPHANTIZING_3707179500919311993)],
    ],
    range: 9..=11,
};

static VARS_SW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SW_CHILDREN),
    value: None,
};

pub static VARS_SW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iveled"),
        dictgen::InsensitiveStr::Ascii("iveling"),
        dictgen::InsensitiveStr::Ascii("ivelled"),
        dictgen::InsensitiveStr::Ascii("ivelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SWIVELED_17790968621944461091)],
        &[(0b00001, &ENTRY_SWIVELING_11766360434972105410)],
        &[(0b11010, &ENTRY_SWIVELED_17790968621944461091)],
        &[(0b11010, &ENTRY_SWIVELING_11766360434972105410)],
    ],
    range: 6..=8,
};

static VARS_SU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SU_CHILDREN),
    value: None,
};

static VARS_SU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SUB_NODE),
    Some(&VARS_SUC_NODE),
    None,
    Some(&VARS_SUE_NODE),
    None,
    Some(&VARS_SUG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_SUL_NODE),
    Some(&VARS_SUM_NODE),
    None,
    None,
    Some(&VARS_SUP_NODE),
    None,
    Some(&VARS_SUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUR_CHILDREN),
    value: None,
};

pub static VARS_SUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("gerise"),
        dictgen::InsensitiveStr::Ascii("gerises"),
        dictgen::InsensitiveStr::Ascii("gerize"),
        dictgen::InsensitiveStr::Ascii("gerizes"),
        dictgen::InsensitiveStr::Ascii("prisal"),
        dictgen::InsensitiveStr::Ascii("prizal"),
        dictgen::InsensitiveStr::Ascii("sise"),
        dictgen::InsensitiveStr::Ascii("size"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SUERS_7272934736981736758)],
        &[(0b10010, &ENTRY_SURGERIZE_4983277252612670769)],
        &[(0b10010, &ENTRY_SURGERIZES_13175724116978873269)],
        &[(0b01001, &ENTRY_SURGERIZE_4983277252612670769)],
        &[(0b01001, &ENTRY_SURGERIZES_13175724116978873269)],
        &[(0b10010, &ENTRY_SURPRIZAL_5281380386605833450)],
        &[(0b01001, &ENTRY_SURPRIZAL_5281380386605833450)],
        &[(0b10010, &ENTRY_SURSIZE_3670570722345111046)],
        &[(0b01001, &ENTRY_SURSIZE_3670570722345111046)],
    ],
    range: 2..=7,
};

static VARS_SUP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SUP_CHILDREN),
    value: None,
};

static VARS_SUP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_SUPE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SUPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SUPE_CHILDREN),
    value: None,
};

static VARS_SUPE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SUPER_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SUPER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SUPER_CHILDREN),
    value: None,
};

static VARS_SUPER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SUPERA_NODE),
    None,
    Some(&VARS_SUPERC_NODE),
    None,
    Some(&VARS_SUPERE_NODE),
    Some(&VARS_SUPERF_NODE),
    None,
    Some(&VARS_SUPERH_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SUPERN_NODE),
    Some(&VARS_SUPERO_NODE),
    None,
    None,
    None,
    Some(&VARS_SUPERS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SUPERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERS_CHILDREN),
    value: None,
};

pub static VARS_SUPERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensitisation"),
        dictgen::InsensitiveStr::Ascii("ensitisations"),
        dictgen::InsensitiveStr::Ascii("ensitise"),
        dictgen::InsensitiveStr::Ascii("ensitised"),
        dictgen::InsensitiveStr::Ascii("ensitising"),
        dictgen::InsensitiveStr::Ascii("ensitization"),
        dictgen::InsensitiveStr::Ascii("ensitizations"),
        dictgen::InsensitiveStr::Ascii("ensitize"),
        dictgen::InsensitiveStr::Ascii("ensitized"),
        dictgen::InsensitiveStr::Ascii("ensitizing"),
        dictgen::InsensitiveStr::Ascii("pecialise"),
        dictgen::InsensitiveStr::Ascii("pecialises"),
        dictgen::InsensitiveStr::Ascii("pecialize"),
        dictgen::InsensitiveStr::Ascii("pecializes"),
        dictgen::InsensitiveStr::Ascii("ubtilised"),
        dictgen::InsensitiveStr::Ascii("ubtiliseds"),
        dictgen::InsensitiveStr::Ascii("ubtilized"),
        dictgen::InsensitiveStr::Ascii("ubtilizeds"),
        dictgen::InsensitiveStr::Ascii("ulphurise"),
        dictgen::InsensitiveStr::Ascii("ulphurises"),
        dictgen::InsensitiveStr::Ascii("ulphurize"),
        dictgen::InsensitiveStr::Ascii("ulphurizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERSENSITIZATION_13006014246685708385)],
        &[(0b10010, &ENTRY_SUPERSENSITIZATIONS_17166516002820124032)],
        &[(0b10010, &ENTRY_SUPERSENSITIZE_7006527570782329036)],
        &[(0b10010, &ENTRY_SUPERSENSITIZED_1021249000838099530)],
        &[(0b10010, &ENTRY_SUPERSENSITIZING_5029091819363480393)],
        &[(0b01001, &ENTRY_SUPERSENSITIZATION_13006014246685708385)],
        &[(0b01001, &ENTRY_SUPERSENSITIZATIONS_17166516002820124032)],
        &[(0b01001, &ENTRY_SUPERSENSITIZE_7006527570782329036)],
        &[(0b01001, &ENTRY_SUPERSENSITIZED_1021249000838099530)],
        &[(0b01001, &ENTRY_SUPERSENSITIZING_5029091819363480393)],
        &[(0b10010, &ENTRY_SUPERSPECIALIZE_252058508575789924)],
        &[(0b10010, &ENTRY_SUPERSPECIALIZES_4737590243517715555)],
        &[(0b01001, &ENTRY_SUPERSPECIALIZE_252058508575789924)],
        &[(0b01001, &ENTRY_SUPERSPECIALIZES_4737590243517715555)],
        &[(0b10010, &ENTRY_SUPERSUBTILIZED_11208309807789263657)],
        &[(0b10010, &ENTRY_SUPERSUBTILIZEDS_13560124924918518109)],
        &[(0b01001, &ENTRY_SUPERSUBTILIZED_11208309807789263657)],
        &[(0b01001, &ENTRY_SUPERSUBTILIZEDS_13560124924918518109)],
        &[(0b10010, &ENTRY_SUPERSULPHURIZE_3926397118291965214)],
        &[(0b10010, &ENTRY_SUPERSULPHURIZES_1086828648943519821)],
        &[(0b01001, &ENTRY_SUPERSULPHURIZE_3926397118291965214)],
        &[(0b01001, &ENTRY_SUPERSULPHURIZES_1086828648943519821)],
    ],
    range: 8..=13,
};

static VARS_SUPERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERO_CHILDREN),
    value: None,
};

pub static VARS_SUPERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERORGANIZATION_8860022256249649969)],
        &[(0b10010, &ENTRY_SUPERORGANIZATIONS_10617131285596283213)],
        &[(0b10010, &ENTRY_SUPERORGANIZE_8384924288227808894)],
        &[(0b10010, &ENTRY_SUPERORGANIZES_5444912774808934766)],
        &[(0b01001, &ENTRY_SUPERORGANIZATION_8860022256249649969)],
        &[(0b01001, &ENTRY_SUPERORGANIZATIONS_10617131285596283213)],
        &[(0b01001, &ENTRY_SUPERORGANIZE_8384924288227808894)],
        &[(0b01001, &ENTRY_SUPERORGANIZES_5444912774808934766)],
    ],
    range: 7..=12,
};

static VARS_SUPERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERN_CHILDREN),
    value: None,
};

pub static VARS_SUPERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aturalise"),
        dictgen::InsensitiveStr::Ascii("aturalised"),
        dictgen::InsensitiveStr::Ascii("aturalises"),
        dictgen::InsensitiveStr::Ascii("aturalising"),
        dictgen::InsensitiveStr::Ascii("aturalize"),
        dictgen::InsensitiveStr::Ascii("aturalized"),
        dictgen::InsensitiveStr::Ascii("aturalizes"),
        dictgen::InsensitiveStr::Ascii("aturalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERNATURALIZE_14037531297937878869)],
        &[(0b10010, &ENTRY_SUPERNATURALIZED_14415170850743090399)],
        &[(0b10010, &ENTRY_SUPERNATURALIZES_16951225069063962411)],
        &[(0b10010, &ENTRY_SUPERNATURALIZING_8508315994313061480)],
        &[(0b01001, &ENTRY_SUPERNATURALIZE_14037531297937878869)],
        &[(0b01001, &ENTRY_SUPERNATURALIZED_14415170850743090399)],
        &[(0b01001, &ENTRY_SUPERNATURALIZES_16951225069063962411)],
        &[(0b01001, &ENTRY_SUPERNATURALIZING_8508315994313061480)],
    ],
    range: 9..=11,
};

static VARS_SUPERH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERH_CHILDREN),
    value: None,
};

pub static VARS_SUPERH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanised"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanising"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanized"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
        dictgen::InsensitiveStr::Ascii("umanizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERHUMANIZE_15633115389662702814)],
        &[(0b10010, &ENTRY_SUPERHUMANIZED_15608702836101169679)],
        &[(0b10010, &ENTRY_SUPERHUMANIZES_10570138598632742368)],
        &[(0b10010, &ENTRY_SUPERHUMANIZING_4071636756107716090)],
        &[(0b01001, &ENTRY_SUPERHUMANIZE_15633115389662702814)],
        &[(0b01001, &ENTRY_SUPERHUMANIZED_15608702836101169679)],
        &[(0b01001, &ENTRY_SUPERHUMANIZES_10570138598632742368)],
        &[(0b01001, &ENTRY_SUPERHUMANIZING_4071636756107716090)],
    ],
    range: 7..=9,
};

static VARS_SUPERF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERF_CHILDREN),
    value: None,
};

pub static VARS_SUPERF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etation"),
        dictgen::InsensitiveStr::Ascii("etations"),
        dictgen::InsensitiveStr::Ascii("icialise"),
        dictgen::InsensitiveStr::Ascii("icialised"),
        dictgen::InsensitiveStr::Ascii("icialises"),
        dictgen::InsensitiveStr::Ascii("icialising"),
        dictgen::InsensitiveStr::Ascii("icialize"),
        dictgen::InsensitiveStr::Ascii("icialized"),
        dictgen::InsensitiveStr::Ascii("icializes"),
        dictgen::InsensitiveStr::Ascii("icializing"),
        dictgen::InsensitiveStr::Ascii("oetation"),
        dictgen::InsensitiveStr::Ascii("oetations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUPERFETATION_12600225493156545849)],
        &[(0b00001, &ENTRY_SUPERFETATIONS_10292712087384952307)],
        &[(0b10010, &ENTRY_SUPERFICIALIZE_2738339175970343799)],
        &[(0b10010, &ENTRY_SUPERFICIALIZED_16789114853240296207)],
        &[(0b10010, &ENTRY_SUPERFICIALIZES_17549727985126882796)],
        &[(0b10010, &ENTRY_SUPERFICIALIZING_17334979727341640969)],
        &[(0b01001, &ENTRY_SUPERFICIALIZE_2738339175970343799)],
        &[(0b01001, &ENTRY_SUPERFICIALIZED_16789114853240296207)],
        &[(0b01001, &ENTRY_SUPERFICIALIZES_17549727985126882796)],
        &[(0b01001, &ENTRY_SUPERFICIALIZING_17334979727341640969)],
        &[(0b11010, &ENTRY_SUPERFETATION_12600225493156545849)],
        &[(0b11010, &ENTRY_SUPERFETATIONS_10292712087384952307)],
    ],
    range: 7..=10,
};

static VARS_SUPERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERE_CHILDREN),
    value: None,
};

pub static VARS_SUPERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPEREMPHASIZE_3382031681661300047)],
        &[(0b10010, &ENTRY_SUPEREMPHASIZES_11905195641762477558)],
        &[(0b01001, &ENTRY_SUPEREMPHASIZE_3382031681661300047)],
        &[(0b01001, &ENTRY_SUPEREMPHASIZES_11905195641762477558)],
    ],
    range: 8..=9,
};

static VARS_SUPERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERC_CHILDREN),
    value: None,
};

pub static VARS_SUPERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anonisation"),
        dictgen::InsensitiveStr::Ascii("anonisations"),
        dictgen::InsensitiveStr::Ascii("anonization"),
        dictgen::InsensitiveStr::Ascii("anonizations"),
        dictgen::InsensitiveStr::Ascii("arbonisation"),
        dictgen::InsensitiveStr::Ascii("arbonisations"),
        dictgen::InsensitiveStr::Ascii("arbonise"),
        dictgen::InsensitiveStr::Ascii("arbonises"),
        dictgen::InsensitiveStr::Ascii("arbonization"),
        dictgen::InsensitiveStr::Ascii("arbonizations"),
        dictgen::InsensitiveStr::Ascii("arbonize"),
        dictgen::InsensitiveStr::Ascii("arbonizes"),
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilised"),
        dictgen::InsensitiveStr::Ascii("iviliseds"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("ivilized"),
        dictgen::InsensitiveStr::Ascii("ivilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUPERCANONIZATION_4336218867107151380)],
        &[(0b10010, &ENTRY_SUPERCANONIZATIONS_4755355331109857311)],
        &[(0b01001, &ENTRY_SUPERCANONIZATION_4336218867107151380)],
        &[(0b01001, &ENTRY_SUPERCANONIZATIONS_4755355331109857311)],
        &[(0b10010, &ENTRY_SUPERCARBONIZATION_1217950256825062958)],
        &[(0b10010, &ENTRY_SUPERCARBONIZATIONS_10831679594408466920)],
        &[(0b10010, &ENTRY_SUPERCARBONIZE_7821965803696896835)],
        &[(0b10010, &ENTRY_SUPERCARBONIZES_683964189361439315)],
        &[(0b01001, &ENTRY_SUPERCARBONIZATION_1217950256825062958)],
        &[(0b01001, &ENTRY_SUPERCARBONIZATIONS_10831679594408466920)],
        &[(0b01001, &ENTRY_SUPERCARBONIZE_7821965803696896835)],
        &[(0b01001, &ENTRY_SUPERCARBONIZES_683964189361439315)],
        &[(0b10010, &ENTRY_SUPERCIVILIZATION_1458840308729646079)],
        &[(0b10010, &ENTRY_SUPERCIVILIZATIONS_2634390504398689511)],
        &[(0b10010, &ENTRY_SUPERCIVILIZED_2238853392228517699)],
        &[(0b10010, &ENTRY_SUPERCIVILIZEDS_2859106069953321338)],
        &[(0b01001, &ENTRY_SUPERCIVILIZATION_1458840308729646079)],
        &[(0b01001, &ENTRY_SUPERCIVILIZATIONS_2634390504398689511)],
        &[(0b01001, &ENTRY_SUPERCIVILIZED_2238853392228517699)],
        &[(0b01001, &ENTRY_SUPERCIVILIZEDS_2859106069953321338)],
    ],
    range: 8..=13,
};

static VARS_SUPERA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUPERA_CHILDREN),
    value: None,
};

pub static VARS_SUPERA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cknowledgement"),
        dictgen::InsensitiveStr::Ascii("cknowledgements"),
        dictgen::InsensitiveStr::Ascii("cknowledgment"),
        dictgen::InsensitiveStr::Ascii("cknowledgments"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SUPERACKNOWLEDGMENT_18055315220706538962)],
        &[(0b11010, &ENTRY_SUPERACKNOWLEDGMENTS_7768783977000239516)],
        &[(0b00001, &ENTRY_SUPERACKNOWLEDGMENT_18055315220706538962)],
        &[(0b00001, &ENTRY_SUPERACKNOWLEDGMENTS_7768783977000239516)],
    ],
    range: 13..=15,
};

static VARS_SUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUM_CHILDREN),
    value: None,
};

pub static VARS_SUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("marisable"),
        dictgen::InsensitiveStr::Ascii("marisation"),
        dictgen::InsensitiveStr::Ascii("marisations"),
        dictgen::InsensitiveStr::Ascii("marise"),
        dictgen::InsensitiveStr::Ascii("marised"),
        dictgen::InsensitiveStr::Ascii("mariser"),
        dictgen::InsensitiveStr::Ascii("marisers"),
        dictgen::InsensitiveStr::Ascii("marises"),
        dictgen::InsensitiveStr::Ascii("marising"),
        dictgen::InsensitiveStr::Ascii("marizable"),
        dictgen::InsensitiveStr::Ascii("marization"),
        dictgen::InsensitiveStr::Ascii("marizations"),
        dictgen::InsensitiveStr::Ascii("marize"),
        dictgen::InsensitiveStr::Ascii("marized"),
        dictgen::InsensitiveStr::Ascii("marizer"),
        dictgen::InsensitiveStr::Ascii("marizers"),
        dictgen::InsensitiveStr::Ascii("marizes"),
        dictgen::InsensitiveStr::Ascii("marizing"),
        dictgen::InsensitiveStr::Ascii("merise"),
        dictgen::InsensitiveStr::Ascii("merises"),
        dictgen::InsensitiveStr::Ascii("merize"),
        dictgen::InsensitiveStr::Ascii("merizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUMMARIZABLE_8885048172619412441)],
        &[(0b10010, &ENTRY_SUMMARIZATION_1450117887113919650)],
        &[(0b10010, &ENTRY_SUMMARIZATIONS_6246410965460713485)],
        &[(0b10010, &ENTRY_SUMMARIZE_4043965903576683508)],
        &[(0b10010, &ENTRY_SUMMARIZED_11820249661747504946)],
        &[(0b10010, &ENTRY_SUMMARIZER_10384176123331578848)],
        &[(0b10010, &ENTRY_SUMMARIZERS_10721471147508695276)],
        &[(0b10010, &ENTRY_SUMMARIZES_14818168405290018071)],
        &[(0b10010, &ENTRY_SUMMARIZING_4468233879394675836)],
        &[(0b01001, &ENTRY_SUMMARIZABLE_8885048172619412441)],
        &[(0b01001, &ENTRY_SUMMARIZATION_1450117887113919650)],
        &[(0b01001, &ENTRY_SUMMARIZATIONS_6246410965460713485)],
        &[(0b01001, &ENTRY_SUMMARIZE_4043965903576683508)],
        &[(0b01001, &ENTRY_SUMMARIZED_11820249661747504946)],
        &[(0b01001, &ENTRY_SUMMARIZER_10384176123331578848)],
        &[(0b01001, &ENTRY_SUMMARIZERS_10721471147508695276)],
        &[(0b01001, &ENTRY_SUMMARIZES_14818168405290018071)],
        &[(0b01001, &ENTRY_SUMMARIZING_4468233879394675836)],
        &[(0b10010, &ENTRY_SUMMERIZE_4051177429594741620)],
        &[(0b10010, &ENTRY_SUMMERIZES_12278244173537641354)],
        &[(0b01001, &ENTRY_SUMMERIZE_4051177429594741620)],
        &[(0b01001, &ENTRY_SUMMERIZES_12278244173537641354)],
    ],
    range: 6..=11,
};

static VARS_SUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUL_CHILDREN),
    value: None,
};

pub static VARS_SUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calised"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calising"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calized"),
        dictgen::InsensitiveStr::Ascii("calizes"),
        dictgen::InsensitiveStr::Ascii("calizing"),
        dictgen::InsensitiveStr::Ascii("fate"),
        dictgen::InsensitiveStr::Ascii("fates"),
        dictgen::InsensitiveStr::Ascii("fatise"),
        dictgen::InsensitiveStr::Ascii("fatises"),
        dictgen::InsensitiveStr::Ascii("fatize"),
        dictgen::InsensitiveStr::Ascii("fatizes"),
        dictgen::InsensitiveStr::Ascii("fide"),
        dictgen::InsensitiveStr::Ascii("fides"),
        dictgen::InsensitiveStr::Ascii("furic"),
        dictgen::InsensitiveStr::Ascii("furization"),
        dictgen::InsensitiveStr::Ascii("furizations"),
        dictgen::InsensitiveStr::Ascii("furize"),
        dictgen::InsensitiveStr::Ascii("furized"),
        dictgen::InsensitiveStr::Ascii("furizes"),
        dictgen::InsensitiveStr::Ascii("furizing"),
        dictgen::InsensitiveStr::Ascii("furous"),
        dictgen::InsensitiveStr::Ascii("phate"),
        dictgen::InsensitiveStr::Ascii("phates"),
        dictgen::InsensitiveStr::Ascii("phide"),
        dictgen::InsensitiveStr::Ascii("phides"),
        dictgen::InsensitiveStr::Ascii("phur"),
        dictgen::InsensitiveStr::Ascii("phured"),
        dictgen::InsensitiveStr::Ascii("phuric"),
        dictgen::InsensitiveStr::Ascii("phuring"),
        dictgen::InsensitiveStr::Ascii("phurisation"),
        dictgen::InsensitiveStr::Ascii("phurisations"),
        dictgen::InsensitiveStr::Ascii("phurise"),
        dictgen::InsensitiveStr::Ascii("phurised"),
        dictgen::InsensitiveStr::Ascii("phurises"),
        dictgen::InsensitiveStr::Ascii("phurising"),
        dictgen::InsensitiveStr::Ascii("phurization"),
        dictgen::InsensitiveStr::Ascii("phurizations"),
        dictgen::InsensitiveStr::Ascii("phurize"),
        dictgen::InsensitiveStr::Ascii("phurized"),
        dictgen::InsensitiveStr::Ascii("phurizes"),
        dictgen::InsensitiveStr::Ascii("phurizing"),
        dictgen::InsensitiveStr::Ascii("phurous"),
        dictgen::InsensitiveStr::Ascii("phurs"),
        dictgen::InsensitiveStr::Ascii("tanise"),
        dictgen::InsensitiveStr::Ascii("tanises"),
        dictgen::InsensitiveStr::Ascii("tanize"),
        dictgen::InsensitiveStr::Ascii("tanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SULCALIZE_8378152628296896141)],
        &[(0b10010, &ENTRY_SULCALIZED_5425406189232692465)],
        &[(0b10010, &ENTRY_SULCALIZES_640675964983651986)],
        &[(0b10010, &ENTRY_SULCALIZING_5886947456402704718)],
        &[(0b01001, &ENTRY_SULCALIZE_8378152628296896141)],
        &[(0b01001, &ENTRY_SULCALIZED_5425406189232692465)],
        &[(0b01001, &ENTRY_SULCALIZES_640675964983651986)],
        &[(0b01001, &ENTRY_SULCALIZING_5886947456402704718)],
        &[(0b01001, &ENTRY_SULFATE_12734582688668505440)],
        &[(0b01001, &ENTRY_SULFATES_4402811146604836852)],
        &[(0b10010, &ENTRY_SULFATIZE_13333268258610123633)],
        &[(0b10010, &ENTRY_SULFATIZES_6036327854424560867)],
        &[(0b01001, &ENTRY_SULFATIZE_13333268258610123633)],
        &[(0b01001, &ENTRY_SULFATIZES_6036327854424560867)],
        &[(0b01001, &ENTRY_SULFIDE_7304142610351212973)],
        &[(0b01001, &ENTRY_SULFIDES_16764216575605816115)],
        &[(0b11001, &ENTRY_SULFURIC_1017009640623214170)],
        &[(0b00001, &ENTRY_SULFURIZATION_14439802421211659492)],
        &[(0b00001, &ENTRY_SULFURIZATIONS_5474468829338012124)],
        &[(0b00001, &ENTRY_SULFURIZE_6207811143838647915)],
        &[(0b00001, &ENTRY_SULFURIZED_13939604428112304430)],
        &[(0b00001, &ENTRY_SULFURIZES_5918702548576518301)],
        &[(0b00001, &ENTRY_SULFURIZING_8560422491260610461)],
        &[(0b01001, &ENTRY_SULFUROUS_10926705129400784683)],
        &[(0b11010, &ENTRY_SULFATE_12734582688668505440)],
        &[(0b11010, &ENTRY_SULFATES_4402811146604836852)],
        &[(0b11010, &ENTRY_SULFIDE_7304142610351212973)],
        &[(0b11010, &ENTRY_SULFIDES_16764216575605816115)],
        &[(0b11010, &ENTRY_SULFUR_10049808270063012273)],
        &[(0b11010, &ENTRY_SULFURED_8189776575606765570)],
        &[(0b11010, &ENTRY_SULFURIC_1017009640623214170)],
        &[(0b11010, &ENTRY_SULFURING_13686792585795899810)],
        &[(0b10010, &ENTRY_SULFURIZATION_14439802421211659492)],
        &[(0b10010, &ENTRY_SULFURIZATIONS_5474468829338012124)],
        &[(0b10010, &ENTRY_SULFURIZE_6207811143838647915)],
        &[(0b10010, &ENTRY_SULFURIZED_13939604428112304430)],
        &[(0b10010, &ENTRY_SULFURIZES_5918702548576518301)],
        &[(0b10010, &ENTRY_SULFURIZING_8560422491260610461)],
        &[(0b01000, &ENTRY_SULFURIZATION_14439802421211659492)],
        &[(0b01000, &ENTRY_SULFURIZATIONS_5474468829338012124)],
        &[(0b01000, &ENTRY_SULFURIZE_6207811143838647915)],
        &[(0b01000, &ENTRY_SULFURIZED_13939604428112304430)],
        &[(0b01000, &ENTRY_SULFURIZES_5918702548576518301)],
        &[(0b01000, &ENTRY_SULFURIZING_8560422491260610461)],
        &[(0b11010, &ENTRY_SULFUROUS_10926705129400784683)],
        &[(0b11010, &ENTRY_SULFURS_750949739916739801)],
        &[(0b10010, &ENTRY_SULTANIZE_4736867272905083425)],
        &[(0b10010, &ENTRY_SULTANIZES_9680614734074701263)],
        &[(0b01001, &ENTRY_SULTANIZE_4736867272905083425)],
        &[(0b01001, &ENTRY_SULTANIZES_9680614734074701263)],
    ],
    range: 4..=12,
};

static VARS_SUG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUG_CHILDREN),
    value: None,
};

pub static VARS_SUG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gestionise"),
        dictgen::InsensitiveStr::Ascii("gestionises"),
        dictgen::InsensitiveStr::Ascii("gestionize"),
        dictgen::InsensitiveStr::Ascii("gestionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUGGESTIONIZE_9511065820694117464)],
        &[(0b10010, &ENTRY_SUGGESTIONIZES_2131192207235128557)],
        &[(0b01001, &ENTRY_SUGGESTIONIZE_9511065820694117464)],
        &[(0b01001, &ENTRY_SUGGESTIONIZES_2131192207235128557)],
    ],
    range: 10..=11,
};

static VARS_SUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUE_CHILDREN),
    value: None,
};

pub static VARS_SUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("rs")],
    values: &[&[(0b00001, &ENTRY_SUERS_7272934736981736758)]],
    range: 2..=2,
};

static VARS_SUC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUC_CHILDREN),
    value: None,
};

pub static VARS_SUC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cor"),
        dictgen::InsensitiveStr::Ascii("corable"),
        dictgen::InsensitiveStr::Ascii("corables"),
        dictgen::InsensitiveStr::Ascii("cored"),
        dictgen::InsensitiveStr::Ascii("corer"),
        dictgen::InsensitiveStr::Ascii("corers"),
        dictgen::InsensitiveStr::Ascii("corful"),
        dictgen::InsensitiveStr::Ascii("coring"),
        dictgen::InsensitiveStr::Ascii("corless"),
        dictgen::InsensitiveStr::Ascii("corlesses"),
        dictgen::InsensitiveStr::Ascii("corrhea"),
        dictgen::InsensitiveStr::Ascii("corrhoea"),
        dictgen::InsensitiveStr::Ascii("cors"),
        dictgen::InsensitiveStr::Ascii("cour"),
        dictgen::InsensitiveStr::Ascii("courable"),
        dictgen::InsensitiveStr::Ascii("courables"),
        dictgen::InsensitiveStr::Ascii("coured"),
        dictgen::InsensitiveStr::Ascii("courer"),
        dictgen::InsensitiveStr::Ascii("courers"),
        dictgen::InsensitiveStr::Ascii("courful"),
        dictgen::InsensitiveStr::Ascii("couring"),
        dictgen::InsensitiveStr::Ascii("courless"),
        dictgen::InsensitiveStr::Ascii("courlesses"),
        dictgen::InsensitiveStr::Ascii("cours"),
        dictgen::InsensitiveStr::Ascii("cubae"),
        dictgen::InsensitiveStr::Ascii("cube"),
    ],
    values: &[
        &[(0b10001, &ENTRY_SUCCOR_15081921561003187015)],
        &[(0b10001, &ENTRY_SUCCORABLE_7603179383102744178)],
        &[(0b10001, &ENTRY_SUCCORABLES_10281575419378237491)],
        &[(0b10001, &ENTRY_SUCCORED_12990159801580773138)],
        &[(0b10001, &ENTRY_SUCCORER_16497801407608107954)],
        &[(0b10001, &ENTRY_SUCCORERS_6561319313200472359)],
        &[(0b10001, &ENTRY_SUCCORFUL_4180327020165538900)],
        &[(0b10001, &ENTRY_SUCCORING_11411217915173349617)],
        &[(0b10001, &ENTRY_SUCCORLESS_7850671832548251866)],
        &[(0b00001, &ENTRY_SUCCORLESSES_12939324178963311324)],
        &[(0b00001, &ENTRY_SUCCORRHEA_1494636851481194334)],
        &[(0b11010, &ENTRY_SUCCORRHEA_1494636851481194334)],
        &[(0b10001, &ENTRY_SUCCORS_3531516934857684627)],
        &[(0b11010, &ENTRY_SUCCOR_15081921561003187015)],
        &[(0b11010, &ENTRY_SUCCORABLE_7603179383102744178)],
        &[(0b11010, &ENTRY_SUCCORABLES_10281575419378237491)],
        &[(0b11010, &ENTRY_SUCCORED_12990159801580773138)],
        &[(0b11010, &ENTRY_SUCCORER_16497801407608107954)],
        &[(0b11010, &ENTRY_SUCCORERS_6561319313200472359)],
        &[(0b11010, &ENTRY_SUCCORFUL_4180327020165538900)],
        &[(0b11010, &ENTRY_SUCCORING_11411217915173349617)],
        &[(0b11010, &ENTRY_SUCCORLESS_7850671832548251866)],
        &[(0b11010, &ENTRY_SUCCORLESSES_12939324178963311324)],
        &[(0b11010, &ENTRY_SUCCORS_3531516934857684627)],
        &[(0b11010, &ENTRY_SUCCUBE_9791440353781686466)],
        &[(0b00001, &ENTRY_SUCCUBE_9791440353781686466)],
    ],
    range: 3..=10,
};

static VARS_SUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SUB_CHILDREN),
    value: None,
};

static VARS_SUB_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SUBA_NODE),
    None,
    Some(&VARS_SUBC_NODE),
    Some(&VARS_SUBD_NODE),
    Some(&VARS_SUBE_NODE),
    Some(&VARS_SUBF_NODE),
    None,
    None,
    Some(&VARS_SUBI_NODE),
    Some(&VARS_SUBJ_NODE),
    None,
    Some(&VARS_SUBL_NODE),
    Some(&VARS_SUBM_NODE),
    None,
    Some(&VARS_SUBO_NODE),
    Some(&VARS_SUBP_NODE),
    None,
    None,
    Some(&VARS_SUBS_NODE),
    Some(&VARS_SUBT_NODE),
    Some(&VARS_SUBU_NODE),
    Some(&VARS_SUBV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_SUBV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBV_CHILDREN),
    value: None,
};

pub static VARS_SUBV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italisedder"),
        dictgen::InsensitiveStr::Ascii("italiseddest"),
        dictgen::InsensitiveStr::Ascii("italiseds"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizedder"),
        dictgen::InsensitiveStr::Ascii("italizeddest"),
        dictgen::InsensitiveStr::Ascii("italizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBVITALIZATION_14104834684189946569)],
        &[(0b10010, &ENTRY_SUBVITALIZED_12798033182946604207)],
        &[(0b10010, &ENTRY_SUBVITALIZEDDER_6038599483589110897)],
        &[(0b10010, &ENTRY_SUBVITALIZEDDEST_4531581466325644556)],
        &[(0b10010, &ENTRY_SUBVITALIZEDS_319956284183288639)],
        &[(0b01001, &ENTRY_SUBVITALIZATION_14104834684189946569)],
        &[(0b01001, &ENTRY_SUBVITALIZED_12798033182946604207)],
        &[(0b01001, &ENTRY_SUBVITALIZEDDER_6038599483589110897)],
        &[(0b01001, &ENTRY_SUBVITALIZEDDEST_4531581466325644556)],
        &[(0b01001, &ENTRY_SUBVITALIZEDS_319956284183288639)],
    ],
    range: 8..=12,
};

static VARS_SUBU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBU_CHILDREN),
    value: None,
};

pub static VARS_SUBU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rbanisation"),
        dictgen::InsensitiveStr::Ascii("rbanisations"),
        dictgen::InsensitiveStr::Ascii("rbanise"),
        dictgen::InsensitiveStr::Ascii("rbanised"),
        dictgen::InsensitiveStr::Ascii("rbanises"),
        dictgen::InsensitiveStr::Ascii("rbanising"),
        dictgen::InsensitiveStr::Ascii("rbanization"),
        dictgen::InsensitiveStr::Ascii("rbanizations"),
        dictgen::InsensitiveStr::Ascii("rbanize"),
        dictgen::InsensitiveStr::Ascii("rbanized"),
        dictgen::InsensitiveStr::Ascii("rbanizes"),
        dictgen::InsensitiveStr::Ascii("rbanizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBURBANIZATION_5041053547374142641)],
        &[(0b10010, &ENTRY_SUBURBANIZATIONS_4594207725356201298)],
        &[(0b10010, &ENTRY_SUBURBANIZE_7361825706290430577)],
        &[(0b10010, &ENTRY_SUBURBANIZED_7801039488105724595)],
        &[(0b10010, &ENTRY_SUBURBANIZES_3051574588598676729)],
        &[(0b10010, &ENTRY_SUBURBANIZING_16607196382879275433)],
        &[(0b01001, &ENTRY_SUBURBANIZATION_5041053547374142641)],
        &[(0b01001, &ENTRY_SUBURBANIZATIONS_4594207725356201298)],
        &[(0b01001, &ENTRY_SUBURBANIZE_7361825706290430577)],
        &[(0b01001, &ENTRY_SUBURBANIZED_7801039488105724595)],
        &[(0b01001, &ENTRY_SUBURBANIZES_3051574588598676729)],
        &[(0b01001, &ENTRY_SUBURBANIZING_16607196382879275433)],
    ],
    range: 7..=12,
};

static VARS_SUBT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBT_CHILDREN),
    value: None,
};

pub static VARS_SUBT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erraneanise"),
        dictgen::InsensitiveStr::Ascii("erraneanises"),
        dictgen::InsensitiveStr::Ascii("erraneanize"),
        dictgen::InsensitiveStr::Ascii("erraneanizes"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("iliser"),
        dictgen::InsensitiveStr::Ascii("ilisers"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizer"),
        dictgen::InsensitiveStr::Ascii("ilizers"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("otaled"),
        dictgen::InsensitiveStr::Ascii("otaling"),
        dictgen::InsensitiveStr::Ascii("otalled"),
        dictgen::InsensitiveStr::Ascii("otalling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBTERRANEANIZE_16122048142322693644)],
        &[(0b10010, &ENTRY_SUBTERRANEANIZES_11938427088659999116)],
        &[(0b01001, &ENTRY_SUBTERRANEANIZE_16122048142322693644)],
        &[(0b01001, &ENTRY_SUBTERRANEANIZES_11938427088659999116)],
        &[(0b10010, &ENTRY_SUBTILIZATION_16525688905774221339)],
        &[(0b10010, &ENTRY_SUBTILIZATIONS_816218037167588581)],
        &[(0b10010, &ENTRY_SUBTILIZE_364396766538437717)],
        &[(0b10010, &ENTRY_SUBTILIZED_12953612644850546188)],
        &[(0b10010, &ENTRY_SUBTILIZER_2092624206187190872)],
        &[(0b10010, &ENTRY_SUBTILIZERS_5918033439060086128)],
        &[(0b10010, &ENTRY_SUBTILIZES_7637829126901224384)],
        &[(0b10010, &ENTRY_SUBTILIZING_4890677210606357966)],
        &[(0b01001, &ENTRY_SUBTILIZATION_16525688905774221339)],
        &[(0b01001, &ENTRY_SUBTILIZATIONS_816218037167588581)],
        &[(0b01001, &ENTRY_SUBTILIZE_364396766538437717)],
        &[(0b01001, &ENTRY_SUBTILIZED_12953612644850546188)],
        &[(0b01001, &ENTRY_SUBTILIZER_2092624206187190872)],
        &[(0b01001, &ENTRY_SUBTILIZERS_5918033439060086128)],
        &[(0b01001, &ENTRY_SUBTILIZES_7637829126901224384)],
        &[(0b01001, &ENTRY_SUBTILIZING_4890677210606357966)],
        &[(0b00001, &ENTRY_SUBTOTALED_11251144387232903283)],
        &[(0b00001, &ENTRY_SUBTOTALING_7729561682231991509)],
        &[(0b11010, &ENTRY_SUBTOTALED_11251144387232903283)],
        &[(0b11010, &ENTRY_SUBTOTALING_7729561682231991509)],
    ],
    range: 5..=12,
};

static VARS_SUBS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBS_CHILDREN),
    value: None,
};

pub static VARS_SUBS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idisable"),
        dictgen::InsensitiveStr::Ascii("idisables"),
        dictgen::InsensitiveStr::Ascii("idisation"),
        dictgen::InsensitiveStr::Ascii("idisations"),
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idised"),
        dictgen::InsensitiveStr::Ascii("idiser"),
        dictgen::InsensitiveStr::Ascii("idisers"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idising"),
        dictgen::InsensitiveStr::Ascii("idizable"),
        dictgen::InsensitiveStr::Ascii("idizables"),
        dictgen::InsensitiveStr::Ascii("idization"),
        dictgen::InsensitiveStr::Ascii("idizations"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idized"),
        dictgen::InsensitiveStr::Ascii("idizer"),
        dictgen::InsensitiveStr::Ascii("idizers"),
        dictgen::InsensitiveStr::Ascii("idizes"),
        dictgen::InsensitiveStr::Ascii("idizing"),
        dictgen::InsensitiveStr::Ascii("pecialise"),
        dictgen::InsensitiveStr::Ascii("pecialises"),
        dictgen::InsensitiveStr::Ascii("pecialities"),
        dictgen::InsensitiveStr::Ascii("peciality"),
        dictgen::InsensitiveStr::Ascii("pecialize"),
        dictgen::InsensitiveStr::Ascii("pecializes"),
        dictgen::InsensitiveStr::Ascii("pecialties"),
        dictgen::InsensitiveStr::Ascii("pecialty"),
        dictgen::InsensitiveStr::Ascii("tandardise"),
        dictgen::InsensitiveStr::Ascii("tandardises"),
        dictgen::InsensitiveStr::Ascii("tandardize"),
        dictgen::InsensitiveStr::Ascii("tandardizes"),
        dictgen::InsensitiveStr::Ascii("tantialise"),
        dictgen::InsensitiveStr::Ascii("tantialised"),
        dictgen::InsensitiveStr::Ascii("tantialises"),
        dictgen::InsensitiveStr::Ascii("tantialising"),
        dictgen::InsensitiveStr::Ascii("tantialize"),
        dictgen::InsensitiveStr::Ascii("tantialized"),
        dictgen::InsensitiveStr::Ascii("tantializes"),
        dictgen::InsensitiveStr::Ascii("tantializing"),
        dictgen::InsensitiveStr::Ascii("tantivise"),
        dictgen::InsensitiveStr::Ascii("tantivised"),
        dictgen::InsensitiveStr::Ascii("tantivises"),
        dictgen::InsensitiveStr::Ascii("tantivising"),
        dictgen::InsensitiveStr::Ascii("tantivize"),
        dictgen::InsensitiveStr::Ascii("tantivized"),
        dictgen::InsensitiveStr::Ascii("tantivizes"),
        dictgen::InsensitiveStr::Ascii("tantivizing"),
        dictgen::InsensitiveStr::Ascii("terilisation"),
        dictgen::InsensitiveStr::Ascii("terilization"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBSIDIZABLE_12403609187359696273)],
        &[(0b10010, &ENTRY_SUBSIDIZABLES_957075676080529205)],
        &[(0b10010, &ENTRY_SUBSIDIZATION_4505517696726661884)],
        &[(0b10010, &ENTRY_SUBSIDIZATIONS_13296883432062947981)],
        &[(0b10010, &ENTRY_SUBSIDIZE_9015916516385257628)],
        &[(0b10010, &ENTRY_SUBSIDIZED_12958293246622856287)],
        &[(0b10010, &ENTRY_SUBSIDIZER_8190087923295833359)],
        &[(0b10010, &ENTRY_SUBSIDIZERS_10377554586473479765)],
        &[(0b10010, &ENTRY_SUBSIDIZES_5852930110538753767)],
        &[(0b10010, &ENTRY_SUBSIDIZING_2567121642876801163)],
        &[(0b01001, &ENTRY_SUBSIDIZABLE_12403609187359696273)],
        &[(0b01001, &ENTRY_SUBSIDIZABLES_957075676080529205)],
        &[(0b01001, &ENTRY_SUBSIDIZATION_4505517696726661884)],
        &[(0b01001, &ENTRY_SUBSIDIZATIONS_13296883432062947981)],
        &[(0b01001, &ENTRY_SUBSIDIZE_9015916516385257628)],
        &[(0b01001, &ENTRY_SUBSIDIZED_12958293246622856287)],
        &[(0b01001, &ENTRY_SUBSIDIZER_8190087923295833359)],
        &[(0b01001, &ENTRY_SUBSIDIZERS_10377554586473479765)],
        &[(0b01001, &ENTRY_SUBSIDIZES_5852930110538753767)],
        &[(0b01001, &ENTRY_SUBSIDIZING_2567121642876801163)],
        &[(0b10010, &ENTRY_SUBSPECIALIZE_5110123534584151405)],
        &[(0b10010, &ENTRY_SUBSPECIALIZES_14179857379487185513)],
        &[(0b11010, &ENTRY_SUBSPECIALTIES_5856104107956385634)],
        &[(0b11010, &ENTRY_SUBSPECIALTY_4476391942712911269)],
        &[(0b01001, &ENTRY_SUBSPECIALIZE_5110123534584151405)],
        &[(0b01001, &ENTRY_SUBSPECIALIZES_14179857379487185513)],
        &[(0b00001, &ENTRY_SUBSPECIALTIES_5856104107956385634)],
        &[(0b00001, &ENTRY_SUBSPECIALTY_4476391942712911269)],
        &[(0b10010, &ENTRY_SUBSTANDARDIZE_1074329812678020525)],
        &[(0b10010, &ENTRY_SUBSTANDARDIZES_8917636387963391968)],
        &[(0b01001, &ENTRY_SUBSTANDARDIZE_1074329812678020525)],
        &[(0b01001, &ENTRY_SUBSTANDARDIZES_8917636387963391968)],
        &[(0b10010, &ENTRY_SUBSTANTIALIZE_16565480476325052589)],
        &[(0b10010, &ENTRY_SUBSTANTIALIZED_9495547837171370415)],
        &[(0b10010, &ENTRY_SUBSTANTIALIZES_2218483493616659856)],
        &[(0b10010, &ENTRY_SUBSTANTIALIZING_3618259364403658920)],
        &[(0b01001, &ENTRY_SUBSTANTIALIZE_16565480476325052589)],
        &[(0b01001, &ENTRY_SUBSTANTIALIZED_9495547837171370415)],
        &[(0b01001, &ENTRY_SUBSTANTIALIZES_2218483493616659856)],
        &[(0b01001, &ENTRY_SUBSTANTIALIZING_3618259364403658920)],
        &[(0b10010, &ENTRY_SUBSTANTIVIZE_13021735481609078621)],
        &[(0b10010, &ENTRY_SUBSTANTIVIZED_4254503445468994674)],
        &[(0b10010, &ENTRY_SUBSTANTIVIZES_10108249589648833227)],
        &[(0b10010, &ENTRY_SUBSTANTIVIZING_13322008447748586118)],
        &[(0b01001, &ENTRY_SUBSTANTIVIZE_13021735481609078621)],
        &[(0b01001, &ENTRY_SUBSTANTIVIZED_4254503445468994674)],
        &[(0b01001, &ENTRY_SUBSTANTIVIZES_10108249589648833227)],
        &[(0b01001, &ENTRY_SUBSTANTIVIZING_13322008447748586118)],
        &[(0b10010, &ENTRY_SUBSTERILIZATION_18359467976046569227)],
        &[(0b01001, &ENTRY_SUBSTERILIZATION_18359467976046569227)],
    ],
    range: 5..=12,
};

static VARS_SUBP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBP_CHILDREN),
    value: None,
};

pub static VARS_SUBP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ulveriser"),
        dictgen::InsensitiveStr::Ascii("ulverisers"),
        dictgen::InsensitiveStr::Ascii("ulverizer"),
        dictgen::InsensitiveStr::Ascii("ulverizers"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBPULVERIZER_6713080541658378074)],
        &[(0b10010, &ENTRY_SUBPULVERIZERS_7885747060142039285)],
        &[(0b01001, &ENTRY_SUBPULVERIZER_6713080541658378074)],
        &[(0b01001, &ENTRY_SUBPULVERIZERS_7885747060142039285)],
    ],
    range: 9..=10,
};

static VARS_SUBO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBO_CHILDREN),
    value: None,
};

pub static VARS_SUBO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("esophageal")],
    values: &[&[(0b11010, &ENTRY_SUBESOPHAGEAL_15820663243055824436)]],
    range: 10..=10,
};

static VARS_SUBM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBM_CHILDREN),
    value: None,
};

pub static VARS_SUBM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iniaturisation"),
        dictgen::InsensitiveStr::Ascii("iniaturise"),
        dictgen::InsensitiveStr::Ascii("iniaturised"),
        dictgen::InsensitiveStr::Ascii("iniaturises"),
        dictgen::InsensitiveStr::Ascii("iniaturising"),
        dictgen::InsensitiveStr::Ascii("iniaturization"),
        dictgen::InsensitiveStr::Ascii("iniaturize"),
        dictgen::InsensitiveStr::Ascii("iniaturized"),
        dictgen::InsensitiveStr::Ascii("iniaturizes"),
        dictgen::InsensitiveStr::Ascii("iniaturizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBMINIATURIZATION_14504776542407713912)],
        &[(0b10010, &ENTRY_SUBMINIATURIZE_10382800191995124390)],
        &[(0b10010, &ENTRY_SUBMINIATURIZED_15597111727187376086)],
        &[(0b10010, &ENTRY_SUBMINIATURIZES_17702176303629650188)],
        &[(0b10010, &ENTRY_SUBMINIATURIZING_14891752532954283444)],
        &[(0b01001, &ENTRY_SUBMINIATURIZATION_14504776542407713912)],
        &[(0b01001, &ENTRY_SUBMINIATURIZE_10382800191995124390)],
        &[(0b01001, &ENTRY_SUBMINIATURIZED_15597111727187376086)],
        &[(0b01001, &ENTRY_SUBMINIATURIZES_17702176303629650188)],
        &[(0b01001, &ENTRY_SUBMINIATURIZING_14891752532954283444)],
    ],
    range: 10..=14,
};

static VARS_SUBL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBL_CHILDREN),
    value: None,
};

pub static VARS_SUBL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imise"),
        dictgen::InsensitiveStr::Ascii("imised"),
        dictgen::InsensitiveStr::Ascii("imises"),
        dictgen::InsensitiveStr::Ascii("imising"),
        dictgen::InsensitiveStr::Ascii("imize"),
        dictgen::InsensitiveStr::Ascii("imized"),
        dictgen::InsensitiveStr::Ascii("imizes"),
        dictgen::InsensitiveStr::Ascii("imizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBLIMIZE_8185998513196337857)],
        &[(0b10010, &ENTRY_SUBLIMIZED_17602677846775104325)],
        &[(0b10010, &ENTRY_SUBLIMIZES_430560762252037002)],
        &[(0b10010, &ENTRY_SUBLIMIZING_12673180625915709564)],
        &[(0b01001, &ENTRY_SUBLIMIZE_8185998513196337857)],
        &[(0b01001, &ENTRY_SUBLIMIZED_17602677846775104325)],
        &[(0b01001, &ENTRY_SUBLIMIZES_430560762252037002)],
        &[(0b01001, &ENTRY_SUBLIMIZING_12673180625915709564)],
    ],
    range: 5..=7,
};

static VARS_SUBJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBJ_CHILDREN),
    value: None,
};

pub static VARS_SUBJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectivisation"),
        dictgen::InsensitiveStr::Ascii("ectivisations"),
        dictgen::InsensitiveStr::Ascii("ectivise"),
        dictgen::InsensitiveStr::Ascii("ectivised"),
        dictgen::InsensitiveStr::Ascii("ectivises"),
        dictgen::InsensitiveStr::Ascii("ectivising"),
        dictgen::InsensitiveStr::Ascii("ectivization"),
        dictgen::InsensitiveStr::Ascii("ectivizations"),
        dictgen::InsensitiveStr::Ascii("ectivize"),
        dictgen::InsensitiveStr::Ascii("ectivized"),
        dictgen::InsensitiveStr::Ascii("ectivizes"),
        dictgen::InsensitiveStr::Ascii("ectivizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBJECTIVIZATION_10907308115440153544)],
        &[(0b10010, &ENTRY_SUBJECTIVIZATIONS_9264628960015842629)],
        &[(0b10010, &ENTRY_SUBJECTIVIZE_2435583356236162378)],
        &[(0b10010, &ENTRY_SUBJECTIVIZED_3246560572891433421)],
        &[(0b10010, &ENTRY_SUBJECTIVIZES_7152248194959006615)],
        &[(0b10010, &ENTRY_SUBJECTIVIZING_8718502587935622549)],
        &[(0b01001, &ENTRY_SUBJECTIVIZATION_10907308115440153544)],
        &[(0b01001, &ENTRY_SUBJECTIVIZATIONS_9264628960015842629)],
        &[(0b01001, &ENTRY_SUBJECTIVIZE_2435583356236162378)],
        &[(0b01001, &ENTRY_SUBJECTIVIZED_3246560572891433421)],
        &[(0b01001, &ENTRY_SUBJECTIVIZES_7152248194959006615)],
        &[(0b01001, &ENTRY_SUBJECTIVIZING_8718502587935622549)],
    ],
    range: 8..=13,
};

static VARS_SUBI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBI_CHILDREN),
    value: None,
};

pub static VARS_SUBI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SUBITIZE_3227874881853303084)],
        &[(0b10010, &ENTRY_SUBITIZED_2108404178901406655)],
        &[(0b10010, &ENTRY_SUBITIZES_5445288650913572325)],
        &[(0b10010, &ENTRY_SUBITIZING_16606524006734697699)],
        &[(0b01001, &ENTRY_SUBITIZE_3227874881853303084)],
        &[(0b01001, &ENTRY_SUBITIZED_2108404178901406655)],
        &[(0b01001, &ENTRY_SUBITIZES_5445288650913572325)],
        &[(0b01001, &ENTRY_SUBITIZING_16606524006734697699)],
    ],
    range: 4..=6,
};

static VARS_SUBF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBF_CHILDREN),
    value: None,
};

pub static VARS_SUBF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lavor"),
        dictgen::InsensitiveStr::Ascii("lavors"),
        dictgen::InsensitiveStr::Ascii("lavour"),
        dictgen::InsensitiveStr::Ascii("lavours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUBFLAVOR_16056956186177727005)],
        &[(0b00001, &ENTRY_SUBFLAVORS_14563327931975471334)],
        &[(0b11010, &ENTRY_SUBFLAVOR_16056956186177727005)],
        &[(0b11010, &ENTRY_SUBFLAVORS_14563327931975471334)],
    ],
    range: 5..=7,
};

static VARS_SUBE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBE_CHILDREN),
    value: None,
};

pub static VARS_SUBE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rate"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
        dictgen::InsensitiveStr::Ascii("sophageal"),
        dictgen::InsensitiveStr::Ascii("theric"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUBERATE_2958713859903830046)],
        &[(0b10010, &ENTRY_SUBERIZATION_1080833948419911642)],
        &[(0b10010, &ENTRY_SUBERIZATIONS_7532836560480717833)],
        &[(0b10010, &ENTRY_SUBERIZE_9965568250579749505)],
        &[(0b10010, &ENTRY_SUBERIZED_10174332333495953086)],
        &[(0b10010, &ENTRY_SUBERIZES_17776114559373177493)],
        &[(0b10010, &ENTRY_SUBERIZING_11515978326235360567)],
        &[(0b01001, &ENTRY_SUBERIZATION_1080833948419911642)],
        &[(0b01001, &ENTRY_SUBERIZATIONS_7532836560480717833)],
        &[(0b01001, &ENTRY_SUBERIZE_9965568250579749505)],
        &[(0b01001, &ENTRY_SUBERIZED_10174332333495953086)],
        &[(0b01001, &ENTRY_SUBERIZES_17776114559373177493)],
        &[(0b01001, &ENTRY_SUBERIZING_11515978326235360567)],
        &[(0b00001, &ENTRY_SUBESOPHAGEAL_15820663243055824436)],
        &[(0b00001, &ENTRY_SUBETHERIC_2596346146616427172)],
    ],
    range: 4..=9,
};

static VARS_SUBD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBD_CHILDREN),
    value: None,
};

pub static VARS_SUBD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uer"),
        dictgen::InsensitiveStr::Ascii("ure"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUBDUER_6426022057783382265)],
        &[(0b11010, &ENTRY_SUBDUER_6426022057783382265)],
    ],
    range: 3..=3,
};

static VARS_SUBC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBC_CHILDREN),
    value: None,
};

pub static VARS_SUBC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aliber"),
        dictgen::InsensitiveStr::Ascii("alibre"),
        dictgen::InsensitiveStr::Ascii("ategorising"),
        dictgen::InsensitiveStr::Ascii("ategorizing"),
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("entre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SUBCALIBER_16406723248353952807)],
        &[(0b11010, &ENTRY_SUBCALIBER_16406723248353952807)],
        &[(0b10010, &ENTRY_SUBCATEGORIZING_3085156622608452887)],
        &[(0b01001, &ENTRY_SUBCATEGORIZING_3085156622608452887)],
        &[(0b00001, &ENTRY_SUBCENTER_9442934379600097289)],
        &[(0b11010, &ENTRY_SUBCENTER_9442934379600097289)],
    ],
    range: 5..=11,
};

static VARS_SUBA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SUBA_CHILDREN),
    value: None,
};

pub static VARS_SUBA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erate"),
        dictgen::InsensitiveStr::Ascii("etheric"),
        dictgen::InsensitiveStr::Ascii("rmor"),
        dictgen::InsensitiveStr::Ascii("rmors"),
        dictgen::InsensitiveStr::Ascii("rmour"),
        dictgen::InsensitiveStr::Ascii("rmours"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SUBERATE_2958713859903830046)],
        &[(0b11010, &ENTRY_SUBETHERIC_2596346146616427172)],
        &[(0b00001, &ENTRY_SUBARMOR_10630628688650559346)],
        &[(0b00001, &ENTRY_SUBARMORS_12932609600459968439)],
        &[(0b11010, &ENTRY_SUBARMOR_10630628688650559346)],
        &[(0b11010, &ENTRY_SUBARMORS_12932609600459968439)],
    ],
    range: 4..=7,
};

static VARS_ST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ST_CHILDREN),
    value: None,
};

static VARS_ST_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_STA_NODE),
    None,
    None,
    None,
    Some(&VARS_STE_NODE),
    None,
    None,
    None,
    Some(&VARS_STI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_STO_NODE),
    None,
    None,
    Some(&VARS_STR_NODE),
    None,
    None,
    Some(&VARS_STU_NODE),
    None,
    None,
    None,
    Some(&VARS_STY_NODE),
    None,
];

static VARS_STY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STY_CHILDREN),
    value: None,
};

pub static VARS_STY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
        dictgen::InsensitiveStr::Ascii("lopised"),
        dictgen::InsensitiveStr::Ascii("lopized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_STYLIZATION_15244694173883242713)],
        &[(0b10010, &ENTRY_STYLIZATIONS_12181517973286032450)],
        &[(0b10010, &ENTRY_STYLIZE_1535390784645754383)],
        &[(0b10010, &ENTRY_STYLIZED_16020758497839181911)],
        &[(0b10010, &ENTRY_STYLIZER_13937646289429611798)],
        &[(0b10010, &ENTRY_STYLIZERS_2371037382842074036)],
        &[(0b10010, &ENTRY_STYLIZES_7516779593566935765)],
        &[(0b10010, &ENTRY_STYLIZING_9348895301814219487)],
        &[(0b01001, &ENTRY_STYLIZATION_15244694173883242713)],
        &[(0b01001, &ENTRY_STYLIZATIONS_12181517973286032450)],
        &[(0b01001, &ENTRY_STYLIZE_1535390784645754383)],
        &[(0b01001, &ENTRY_STYLIZED_16020758497839181911)],
        &[(0b01001, &ENTRY_STYLIZER_13937646289429611798)],
        &[(0b01001, &ENTRY_STYLIZERS_2371037382842074036)],
        &[(0b01001, &ENTRY_STYLIZES_7516779593566935765)],
        &[(0b01001, &ENTRY_STYLIZING_9348895301814219487)],
        &[(0b10010, &ENTRY_STYLOPIZED_12957953051597400041)],
        &[(0b01001, &ENTRY_STYLOPIZED_12957953051597400041)],
    ],
    range: 4..=9,
};

static VARS_STU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STU_CHILDREN),
    value: None,
};

pub static VARS_STU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mour"),
    ],
    values: &[
        &[(0b00001, &ENTRY_STUMOR_11469482697863124360)],
        &[(0b11010, &ENTRY_STUMOR_11469482697863124360)],
    ],
    range: 3..=4,
};

static VARS_STR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STR_CHILDREN),
    value: None,
};

pub static VARS_STR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ee"),
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("obilae"),
        dictgen::InsensitiveStr::Ascii("obile"),
        dictgen::InsensitiveStr::Ascii("obilisation"),
        dictgen::InsensitiveStr::Ascii("obilisations"),
        dictgen::InsensitiveStr::Ascii("obilization"),
        dictgen::InsensitiveStr::Ascii("obilizations"),
        dictgen::InsensitiveStr::Ascii("ucturalisation"),
        dictgen::InsensitiveStr::Ascii("ucturalisations"),
        dictgen::InsensitiveStr::Ascii("ucturalise"),
        dictgen::InsensitiveStr::Ascii("ucturalises"),
        dictgen::InsensitiveStr::Ascii("ucturalization"),
        dictgen::InsensitiveStr::Ascii("ucturalizations"),
        dictgen::InsensitiveStr::Ascii("ucturalize"),
        dictgen::InsensitiveStr::Ascii("ucturalizes"),
        dictgen::InsensitiveStr::Ascii("ychninisation"),
        dictgen::InsensitiveStr::Ascii("ychninisations"),
        dictgen::InsensitiveStr::Ascii("ychninise"),
        dictgen::InsensitiveStr::Ascii("ychninises"),
        dictgen::InsensitiveStr::Ascii("ychninization"),
        dictgen::InsensitiveStr::Ascii("ychninizations"),
        dictgen::InsensitiveStr::Ascii("ychninize"),
        dictgen::InsensitiveStr::Ascii("ychninizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_STERE_14973674637271689830)],
        &[(0b11010, &ENTRY_STERT_15188513933795764953)],
        &[(0b11010, &ENTRY_STROBILE_5462694341161436350)],
        &[(0b00001, &ENTRY_STROBILE_5462694341161436350)],
        &[(0b10010, &ENTRY_STROBILIZATION_7297298229503744242)],
        &[(0b10010, &ENTRY_STROBILIZATIONS_6453453949977182110)],
        &[(0b01001, &ENTRY_STROBILIZATION_7297298229503744242)],
        &[(0b01001, &ENTRY_STROBILIZATIONS_6453453949977182110)],
        &[(0b10010, &ENTRY_STRUCTURALIZATION_16247212527450308015)],
        &[(0b10010, &ENTRY_STRUCTURALIZATIONS_12686176034416013309)],
        &[(0b10010, &ENTRY_STRUCTURALIZE_16594415476051004260)],
        &[(0b10010, &ENTRY_STRUCTURALIZES_538653414352082587)],
        &[(0b01001, &ENTRY_STRUCTURALIZATION_16247212527450308015)],
        &[(0b01001, &ENTRY_STRUCTURALIZATIONS_12686176034416013309)],
        &[(0b01001, &ENTRY_STRUCTURALIZE_16594415476051004260)],
        &[(0b01001, &ENTRY_STRUCTURALIZES_538653414352082587)],
        &[(0b10010, &ENTRY_STRYCHNINIZATION_4044621013040012415)],
        &[(0b10010, &ENTRY_STRYCHNINIZATIONS_565463606315000819)],
        &[(0b10010, &ENTRY_STRYCHNINIZE_17273897055193701327)],
        &[(0b10010, &ENTRY_STRYCHNINIZES_14335926093096659147)],
        &[(0b01001, &ENTRY_STRYCHNINIZATION_4044621013040012415)],
        &[(0b01001, &ENTRY_STRYCHNINIZATIONS_565463606315000819)],
        &[(0b01001, &ENTRY_STRYCHNINIZE_17273897055193701327)],
        &[(0b01001, &ENTRY_STRYCHNINIZES_14335926093096659147)],
    ],
    range: 2..=15,
};

static VARS_STO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STO_CHILDREN),
    value: None,
};

pub static VARS_STO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matodaeum"),
        dictgen::InsensitiveStr::Ascii("matodeum"),
        dictgen::InsensitiveStr::Ascii("modaea"),
        dictgen::InsensitiveStr::Ascii("modaeal"),
        dictgen::InsensitiveStr::Ascii("modaeum"),
        dictgen::InsensitiveStr::Ascii("modaeums"),
        dictgen::InsensitiveStr::Ascii("modea"),
        dictgen::InsensitiveStr::Ascii("modeal"),
        dictgen::InsensitiveStr::Ascii("modeum"),
        dictgen::InsensitiveStr::Ascii("modeums"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rier"),
        dictgen::InsensitiveStr::Ascii("ur"),
        dictgen::InsensitiveStr::Ascii("urier"),
        dictgen::InsensitiveStr::Ascii("wer"),
        dictgen::InsensitiveStr::Ascii("wers"),
        dictgen::InsensitiveStr::Ascii("wre"),
        dictgen::InsensitiveStr::Ascii("wres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_STOMATODEUM_8741098205949880656)],
        &[(0b00001, &ENTRY_STOMATODEUM_8741098205949880656)],
        &[(0b11010, &ENTRY_STOMODEA_17558438948754879743)],
        &[(0b11010, &ENTRY_STOMODEAL_862902637399934901)],
        &[(0b11010, &ENTRY_STOMODEUM_7352107598988685520)],
        &[(0b11010, &ENTRY_STOMODEUMS_6754518911406029725)],
        &[(0b00001, &ENTRY_STOMODEA_17558438948754879743)],
        &[(0b00001, &ENTRY_STOMODEAL_862902637399934901)],
        &[(0b00001, &ENTRY_STOMODEUM_7352107598988685520)],
        &[(0b00001, &ENTRY_STOMODEUMS_6754518911406029725)],
        &[(0b11010, &ENTRY_STOR_5667483645094716832)],
        &[(0b00001, &ENTRY_STOR_5667483645094716832)],
        &[(0b00001, &ENTRY_STORIER_6107744465020666747)],
        &[(0b11010, &ENTRY_STOR_5667483645094716832)],
        &[(0b11010, &ENTRY_STORIER_6107744465020666747)],
        &[(0b00001, &ENTRY_STOWER_3427925530344361004)],
        &[(0b00001, &ENTRY_STOWERS_13406600671717463574)],
        &[(0b11010, &ENTRY_STOWER_3427925530344361004)],
        &[(0b11010, &ENTRY_STOWERS_13406600671717463574)],
    ],
    range: 1..=9,
};

static VARS_STI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STI_CHILDREN),
    value: None,
};

pub static VARS_STI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gmatisation"),
        dictgen::InsensitiveStr::Ascii("gmatisations"),
        dictgen::InsensitiveStr::Ascii("gmatise"),
        dictgen::InsensitiveStr::Ascii("gmatised"),
        dictgen::InsensitiveStr::Ascii("gmatiser"),
        dictgen::InsensitiveStr::Ascii("gmatisers"),
        dictgen::InsensitiveStr::Ascii("gmatises"),
        dictgen::InsensitiveStr::Ascii("gmatising"),
        dictgen::InsensitiveStr::Ascii("gmatization"),
        dictgen::InsensitiveStr::Ascii("gmatizations"),
        dictgen::InsensitiveStr::Ascii("gmatize"),
        dictgen::InsensitiveStr::Ascii("gmatized"),
        dictgen::InsensitiveStr::Ascii("gmatizer"),
        dictgen::InsensitiveStr::Ascii("gmatizers"),
        dictgen::InsensitiveStr::Ascii("gmatizes"),
        dictgen::InsensitiveStr::Ascii("gmatizing"),
        dictgen::InsensitiveStr::Ascii("lbestrol"),
        dictgen::InsensitiveStr::Ascii("lbestrols"),
        dictgen::InsensitiveStr::Ascii("lboestrol"),
        dictgen::InsensitiveStr::Ascii("lboestrols"),
        dictgen::InsensitiveStr::Ascii("pulae"),
        dictgen::InsensitiveStr::Ascii("pule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_STIGMATIZATION_12053258038244177237)],
        &[(0b10010, &ENTRY_STIGMATIZATIONS_5206308770780618928)],
        &[(0b10010, &ENTRY_STIGMATIZE_11220162708705129731)],
        &[(0b10010, &ENTRY_STIGMATIZED_14597283271555524870)],
        &[(0b10010, &ENTRY_STIGMATIZER_6119336948691311551)],
        &[(0b10010, &ENTRY_STIGMATIZERS_14825741166868000953)],
        &[(0b10010, &ENTRY_STIGMATIZES_316959479282222637)],
        &[(0b10010, &ENTRY_STIGMATIZING_14536679038681789225)],
        &[(0b01001, &ENTRY_STIGMATIZATION_12053258038244177237)],
        &[(0b01001, &ENTRY_STIGMATIZATIONS_5206308770780618928)],
        &[(0b01001, &ENTRY_STIGMATIZE_11220162708705129731)],
        &[(0b01001, &ENTRY_STIGMATIZED_14597283271555524870)],
        &[(0b01001, &ENTRY_STIGMATIZER_6119336948691311551)],
        &[(0b01001, &ENTRY_STIGMATIZERS_14825741166868000953)],
        &[(0b01001, &ENTRY_STIGMATIZES_316959479282222637)],
        &[(0b01001, &ENTRY_STIGMATIZING_14536679038681789225)],
        &[(0b00001, &ENTRY_STILBESTROL_10324911942394524790)],
        &[(0b00001, &ENTRY_STILBESTROLS_15735220233409139967)],
        &[(0b11010, &ENTRY_STILBESTROL_10324911942394524790)],
        &[(0b11010, &ENTRY_STILBESTROLS_15735220233409139967)],
        &[(0b11010, &ENTRY_STIPULE_14068580951871446375)],
        &[(0b00001, &ENTRY_STIPULE_14068580951871446375)],
    ],
    range: 4..=12,
};

static VARS_STE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STE_CHILDREN),
    value: None,
};

pub static VARS_STE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arrhea"),
        dictgen::InsensitiveStr::Ascii("arrhoea"),
        dictgen::InsensitiveStr::Ascii("atorrhea"),
        dictgen::InsensitiveStr::Ascii("atorrheas"),
        dictgen::InsensitiveStr::Ascii("atorrhoea"),
        dictgen::InsensitiveStr::Ascii("atorrhoeas"),
        dictgen::InsensitiveStr::Ascii("lae"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("nciled"),
        dictgen::InsensitiveStr::Ascii("nciler"),
        dictgen::InsensitiveStr::Ascii("ncilers"),
        dictgen::InsensitiveStr::Ascii("nciling"),
        dictgen::InsensitiveStr::Ascii("ncilise"),
        dictgen::InsensitiveStr::Ascii("ncilize"),
        dictgen::InsensitiveStr::Ascii("ncilled"),
        dictgen::InsensitiveStr::Ascii("nciller"),
        dictgen::InsensitiveStr::Ascii("ncillers"),
        dictgen::InsensitiveStr::Ascii("ncilling"),
        dictgen::InsensitiveStr::Ascii("nopaeic"),
        dictgen::InsensitiveStr::Ascii("nopeic"),
        dictgen::InsensitiveStr::Ascii("ntor"),
        dictgen::InsensitiveStr::Ascii("ntors"),
        dictgen::InsensitiveStr::Ascii("ntour"),
        dictgen::InsensitiveStr::Ascii("ntours"),
        dictgen::InsensitiveStr::Ascii("rcoraemia"),
        dictgen::InsensitiveStr::Ascii("rcoremia"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("rilisabilities"),
        dictgen::InsensitiveStr::Ascii("rilisability"),
        dictgen::InsensitiveStr::Ascii("rilisable"),
        dictgen::InsensitiveStr::Ascii("rilisabler"),
        dictgen::InsensitiveStr::Ascii("rilisables"),
        dictgen::InsensitiveStr::Ascii("rilisablest"),
        dictgen::InsensitiveStr::Ascii("rilisation"),
        dictgen::InsensitiveStr::Ascii("rilisations"),
        dictgen::InsensitiveStr::Ascii("rilise"),
        dictgen::InsensitiveStr::Ascii("rilised"),
        dictgen::InsensitiveStr::Ascii("riliser"),
        dictgen::InsensitiveStr::Ascii("rilisers"),
        dictgen::InsensitiveStr::Ascii("rilises"),
        dictgen::InsensitiveStr::Ascii("rilising"),
        dictgen::InsensitiveStr::Ascii("rilizabilities"),
        dictgen::InsensitiveStr::Ascii("rilizability"),
        dictgen::InsensitiveStr::Ascii("rilizable"),
        dictgen::InsensitiveStr::Ascii("rilizabler"),
        dictgen::InsensitiveStr::Ascii("rilizables"),
        dictgen::InsensitiveStr::Ascii("rilizablest"),
        dictgen::InsensitiveStr::Ascii("rilization"),
        dictgen::InsensitiveStr::Ascii("rilizations"),
        dictgen::InsensitiveStr::Ascii("rilize"),
        dictgen::InsensitiveStr::Ascii("rilized"),
        dictgen::InsensitiveStr::Ascii("rilizer"),
        dictgen::InsensitiveStr::Ascii("rilizers"),
        dictgen::InsensitiveStr::Ascii("rilizes"),
        dictgen::InsensitiveStr::Ascii("rilizing"),
        dictgen::InsensitiveStr::Ascii("rt"),
    ],
    values: &[
        &[(0b00001, &ENTRY_STEARRHEA_595939535574612058)],
        &[(0b11010, &ENTRY_STEARRHEA_595939535574612058)],
        &[(0b00001, &ENTRY_STEATORRHEA_7006550897790317338)],
        &[(0b00001, &ENTRY_STEATORRHEAS_13012158523524663027)],
        &[(0b11010, &ENTRY_STEATORRHEA_7006550897790317338)],
        &[(0b11010, &ENTRY_STEATORRHEAS_13012158523524663027)],
        &[(0b11010, &ENTRY_STELE_2859069730518054769)],
        &[(0b00001, &ENTRY_STELE_2859069730518054769)],
        &[(0b00001, &ENTRY_STENCILED_5697108428616257678)],
        &[(0b00001, &ENTRY_STENCILER_421866534999425286)],
        &[(0b00001, &ENTRY_STENCILERS_9411797891465728151)],
        &[(0b00001, &ENTRY_STENCILING_2842472389755702411)],
        &[(0b10010, &ENTRY_STENCILIZE_2966153114254176045)],
        &[(0b01001, &ENTRY_STENCILIZE_2966153114254176045)],
        &[(0b11010, &ENTRY_STENCILED_5697108428616257678)],
        &[(0b11010, &ENTRY_STENCILER_421866534999425286)],
        &[(0b11010, &ENTRY_STENCILERS_9411797891465728151)],
        &[(0b11010, &ENTRY_STENCILING_2842472389755702411)],
        &[(0b11010, &ENTRY_STENOPEIC_9668625572592229054)],
        &[(0b00001, &ENTRY_STENOPEIC_9668625572592229054)],
        &[(0b00001, &ENTRY_STENTOR_10267053445154488996)],
        &[(0b00001, &ENTRY_STENTORS_11519094998749861028)],
        &[(0b11010, &ENTRY_STENTOR_10267053445154488996)],
        &[(0b11010, &ENTRY_STENTORS_11519094998749861028)],
        &[(0b11010, &ENTRY_STERCOREMIA_16211710810263584762)],
        &[(0b00001, &ENTRY_STERCOREMIA_16211710810263584762)],
        &[(0b00001, &ENTRY_STERE_14973674637271689830)],
        &[(0b10010, &ENTRY_STERILIZABILITIES_6174521207740612143)],
        &[(0b10010, &ENTRY_STERILIZABILITY_15756429437692504074)],
        &[(0b10010, &ENTRY_STERILIZABLE_4293244513265424916)],
        &[(0b10010, &ENTRY_STERILIZABLER_5396292600348410338)],
        &[(0b10010, &ENTRY_STERILIZABLES_395845848212238864)],
        &[(0b10010, &ENTRY_STERILIZABLEST_17116164156498805946)],
        &[(0b10010, &ENTRY_STERILIZATION_12496932581276788803)],
        &[(0b10010, &ENTRY_STERILIZATIONS_5179586981630149963)],
        &[(0b10010, &ENTRY_STERILIZE_12267676068965370103)],
        &[(0b10010, &ENTRY_STERILIZED_5349106414670253614)],
        &[(0b10010, &ENTRY_STERILIZER_9665607973109051795)],
        &[(0b10010, &ENTRY_STERILIZERS_3242667110144307808)],
        &[(0b10010, &ENTRY_STERILIZES_367692529356557376)],
        &[(0b10010, &ENTRY_STERILIZING_14742234573275089575)],
        &[(0b01001, &ENTRY_STERILIZABILITIES_6174521207740612143)],
        &[(0b01001, &ENTRY_STERILIZABILITY_15756429437692504074)],
        &[(0b01001, &ENTRY_STERILIZABLE_4293244513265424916)],
        &[(0b01001, &ENTRY_STERILIZABLER_5396292600348410338)],
        &[(0b01001, &ENTRY_STERILIZABLES_395845848212238864)],
        &[(0b01001, &ENTRY_STERILIZABLEST_17116164156498805946)],
        &[(0b01001, &ENTRY_STERILIZATION_12496932581276788803)],
        &[(0b01001, &ENTRY_STERILIZATIONS_5179586981630149963)],
        &[(0b01001, &ENTRY_STERILIZE_12267676068965370103)],
        &[(0b01001, &ENTRY_STERILIZED_5349106414670253614)],
        &[(0b01001, &ENTRY_STERILIZER_9665607973109051795)],
        &[(0b01001, &ENTRY_STERILIZERS_3242667110144307808)],
        &[(0b01001, &ENTRY_STERILIZES_367692529356557376)],
        &[(0b01001, &ENTRY_STERILIZING_14742234573275089575)],
        &[(0b00001, &ENTRY_STERT_15188513933795764953)],
    ],
    range: 2..=14,
};

static VARS_STA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_STA_CHILDREN),
    value: None,
};

pub static VARS_STA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilisable"),
        dictgen::InsensitiveStr::Ascii("bilisation"),
        dictgen::InsensitiveStr::Ascii("bilisations"),
        dictgen::InsensitiveStr::Ascii("bilisator"),
        dictgen::InsensitiveStr::Ascii("bilisators"),
        dictgen::InsensitiveStr::Ascii("bilise"),
        dictgen::InsensitiveStr::Ascii("bilised"),
        dictgen::InsensitiveStr::Ascii("biliser"),
        dictgen::InsensitiveStr::Ascii("bilisers"),
        dictgen::InsensitiveStr::Ascii("bilises"),
        dictgen::InsensitiveStr::Ascii("bilising"),
        dictgen::InsensitiveStr::Ascii("bilizable"),
        dictgen::InsensitiveStr::Ascii("bilization"),
        dictgen::InsensitiveStr::Ascii("bilizations"),
        dictgen::InsensitiveStr::Ascii("bilizator"),
        dictgen::InsensitiveStr::Ascii("bilizators"),
        dictgen::InsensitiveStr::Ascii("bilize"),
        dictgen::InsensitiveStr::Ascii("bilized"),
        dictgen::InsensitiveStr::Ascii("bilizer"),
        dictgen::InsensitiveStr::Ascii("bilizers"),
        dictgen::InsensitiveStr::Ascii("bilizes"),
        dictgen::InsensitiveStr::Ascii("bilizing"),
        dictgen::InsensitiveStr::Ascii("llionise"),
        dictgen::InsensitiveStr::Ascii("llionises"),
        dictgen::InsensitiveStr::Ascii("llionize"),
        dictgen::InsensitiveStr::Ascii("llionizes"),
        dictgen::InsensitiveStr::Ascii("lwartise"),
        dictgen::InsensitiveStr::Ascii("lwartises"),
        dictgen::InsensitiveStr::Ascii("lwartize"),
        dictgen::InsensitiveStr::Ascii("lwartizes"),
        dictgen::InsensitiveStr::Ascii("mmelcolor"),
        dictgen::InsensitiveStr::Ascii("mmelcolour"),
        dictgen::InsensitiveStr::Ascii("ndardisable"),
        dictgen::InsensitiveStr::Ascii("ndardisables"),
        dictgen::InsensitiveStr::Ascii("ndardisation"),
        dictgen::InsensitiveStr::Ascii("ndardisations"),
        dictgen::InsensitiveStr::Ascii("ndardise"),
        dictgen::InsensitiveStr::Ascii("ndardised"),
        dictgen::InsensitiveStr::Ascii("ndardiser"),
        dictgen::InsensitiveStr::Ascii("ndardisers"),
        dictgen::InsensitiveStr::Ascii("ndardises"),
        dictgen::InsensitiveStr::Ascii("ndardising"),
        dictgen::InsensitiveStr::Ascii("ndardizable"),
        dictgen::InsensitiveStr::Ascii("ndardizables"),
        dictgen::InsensitiveStr::Ascii("ndardization"),
        dictgen::InsensitiveStr::Ascii("ndardizations"),
        dictgen::InsensitiveStr::Ascii("ndardize"),
        dictgen::InsensitiveStr::Ascii("ndardized"),
        dictgen::InsensitiveStr::Ascii("ndardizer"),
        dictgen::InsensitiveStr::Ascii("ndardizers"),
        dictgen::InsensitiveStr::Ascii("ndardizes"),
        dictgen::InsensitiveStr::Ascii("ndardizing"),
        dictgen::InsensitiveStr::Ascii("nzes"),
        dictgen::InsensitiveStr::Ascii("nzoes"),
        dictgen::InsensitiveStr::Ascii("pedectomised"),
        dictgen::InsensitiveStr::Ascii("pedectomized"),
        dictgen::InsensitiveStr::Ascii("phyledema"),
        dictgen::InsensitiveStr::Ascii("phyloedema"),
        dictgen::InsensitiveStr::Ascii("tisticise"),
        dictgen::InsensitiveStr::Ascii("tisticises"),
        dictgen::InsensitiveStr::Ascii("tisticize"),
        dictgen::InsensitiveStr::Ascii("tisticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_STABILIZABLE_7038167747817470196)],
        &[(0b10010, &ENTRY_STABILIZATION_2391135939043331459)],
        &[(0b10010, &ENTRY_STABILIZATIONS_9746187249939087138)],
        &[(0b10010, &ENTRY_STABILIZATOR_17741108746142693419)],
        &[(0b10010, &ENTRY_STABILIZATORS_7145810033685180235)],
        &[(0b10010, &ENTRY_STABILIZE_1583006602954926586)],
        &[(0b10010, &ENTRY_STABILIZED_11581917854583003610)],
        &[(0b10010, &ENTRY_STABILIZER_3382378464960197128)],
        &[(0b10010, &ENTRY_STABILIZERS_16116889764524023645)],
        &[(0b10010, &ENTRY_STABILIZES_13521081822794596506)],
        &[(0b10010, &ENTRY_STABILIZING_14660265128274227263)],
        &[(0b01001, &ENTRY_STABILIZABLE_7038167747817470196)],
        &[(0b01001, &ENTRY_STABILIZATION_2391135939043331459)],
        &[(0b01001, &ENTRY_STABILIZATIONS_9746187249939087138)],
        &[(0b01001, &ENTRY_STABILIZATOR_17741108746142693419)],
        &[(0b01001, &ENTRY_STABILIZATORS_7145810033685180235)],
        &[(0b01001, &ENTRY_STABILIZE_1583006602954926586)],
        &[(0b01001, &ENTRY_STABILIZED_11581917854583003610)],
        &[(0b01001, &ENTRY_STABILIZER_3382378464960197128)],
        &[(0b01001, &ENTRY_STABILIZERS_16116889764524023645)],
        &[(0b01001, &ENTRY_STABILIZES_13521081822794596506)],
        &[(0b01001, &ENTRY_STABILIZING_14660265128274227263)],
        &[(0b10010, &ENTRY_STALLIONIZE_4208189765970167174)],
        &[(0b10010, &ENTRY_STALLIONIZES_15526567222649873911)],
        &[(0b01001, &ENTRY_STALLIONIZE_4208189765970167174)],
        &[(0b01001, &ENTRY_STALLIONIZES_15526567222649873911)],
        &[(0b10010, &ENTRY_STALWARTIZE_5995004425928514778)],
        &[(0b10010, &ENTRY_STALWARTIZES_10322196274491160190)],
        &[(0b01001, &ENTRY_STALWARTIZE_5995004425928514778)],
        &[(0b01001, &ENTRY_STALWARTIZES_10322196274491160190)],
        &[(0b00001, &ENTRY_STAMMELCOLOR_3112896012993635952)],
        &[(0b11010, &ENTRY_STAMMELCOLOR_3112896012993635952)],
        &[(0b10010, &ENTRY_STANDARDIZABLE_17034002894056241852)],
        &[(0b10010, &ENTRY_STANDARDIZABLES_16202726792541011392)],
        &[(0b10010, &ENTRY_STANDARDIZATION_18269374167214565579)],
        &[(0b10010, &ENTRY_STANDARDIZATIONS_4142468637621036850)],
        &[(0b10010, &ENTRY_STANDARDIZE_13224353253220214220)],
        &[(0b10010, &ENTRY_STANDARDIZED_10576000602438339721)],
        &[(0b10010, &ENTRY_STANDARDIZER_10177388752556810926)],
        &[(0b10010, &ENTRY_STANDARDIZERS_12514193886547172459)],
        &[(0b10010, &ENTRY_STANDARDIZES_15875984166067512659)],
        &[(0b10010, &ENTRY_STANDARDIZING_14529046022304657646)],
        &[(0b01001, &ENTRY_STANDARDIZABLE_17034002894056241852)],
        &[(0b01001, &ENTRY_STANDARDIZABLES_16202726792541011392)],
        &[(0b01001, &ENTRY_STANDARDIZATION_18269374167214565579)],
        &[(0b01001, &ENTRY_STANDARDIZATIONS_4142468637621036850)],
        &[(0b01001, &ENTRY_STANDARDIZE_13224353253220214220)],
        &[(0b01001, &ENTRY_STANDARDIZED_10576000602438339721)],
        &[(0b01001, &ENTRY_STANDARDIZER_10177388752556810926)],
        &[(0b01001, &ENTRY_STANDARDIZERS_12514193886547172459)],
        &[(0b01001, &ENTRY_STANDARDIZES_15875984166067512659)],
        &[(0b01001, &ENTRY_STANDARDIZING_14529046022304657646)],
        &[(0b00001, &ENTRY_STANZES_13092355244299837812)],
        &[(0b11010, &ENTRY_STANZES_13092355244299837812)],
        &[(0b10010, &ENTRY_STAPEDECTOMIZED_3532179470450241494)],
        &[(0b01001, &ENTRY_STAPEDECTOMIZED_3532179470450241494)],
        &[(0b00001, &ENTRY_STAPHYLEDEMA_15542876830880978325)],
        &[(0b11010, &ENTRY_STAPHYLEDEMA_15542876830880978325)],
        &[(0b10010, &ENTRY_STATISTICIZE_5352173326738036614)],
        &[(0b10010, &ENTRY_STATISTICIZES_3777559913591399659)],
        &[(0b01001, &ENTRY_STATISTICIZE_5352173326738036614)],
        &[(0b01001, &ENTRY_STATISTICIZES_3777559913591399659)],
    ],
    range: 4..=13,
};

static VARS_SQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SQ_CHILDREN),
    value: None,
};

pub static VARS_SQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uamae"),
        dictgen::InsensitiveStr::Ascii("uame"),
        dictgen::InsensitiveStr::Ascii("uamulae"),
        dictgen::InsensitiveStr::Ascii("uamule"),
        dictgen::InsensitiveStr::Ascii("uier"),
        dictgen::InsensitiveStr::Ascii("uire"),
        dictgen::InsensitiveStr::Ascii("uirreled"),
        dictgen::InsensitiveStr::Ascii("uirreling"),
        dictgen::InsensitiveStr::Ascii("uirrelled"),
        dictgen::InsensitiveStr::Ascii("uirrelling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SQUAME_15183787142740018891)],
        &[(0b00001, &ENTRY_SQUAME_15183787142740018891)],
        &[(0b11010, &ENTRY_SQUAMULE_11975141371110576408)],
        &[(0b00001, &ENTRY_SQUAMULE_11975141371110576408)],
        &[(0b00001, &ENTRY_SQUIER_16883964174471128452)],
        &[(0b11010, &ENTRY_SQUIER_16883964174471128452)],
        &[(0b01001, &ENTRY_SQUIRRELED_11318257635454397551)],
        &[(0b01001, &ENTRY_SQUIRRELING_17909585620200517283)],
        &[(0b11010, &ENTRY_SQUIRRELED_11318257635454397551)],
        &[(0b11010, &ENTRY_SQUIRRELING_17909585620200517283)],
    ],
    range: 4..=10,
};

static VARS_SP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SP_CHILDREN),
    value: None,
};

static VARS_SP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SPA_NODE),
    None,
    None,
    None,
    Some(&VARS_SPE_NODE),
    None,
    None,
    Some(&VARS_SPH_NODE),
    Some(&VARS_SPI_NODE),
    None,
    None,
    Some(&VARS_SPL_NODE),
    None,
    None,
    Some(&VARS_SPO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SPY_NODE),
    None,
];

static VARS_SPY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPY_CHILDREN),
    value: None,
};

pub static VARS_SPY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SPYER_15698237802555201567)],
        &[(0b11010, &ENTRY_SPYER_15698237802555201567)],
    ],
    range: 2..=2,
};

static VARS_SPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPO_CHILDREN),
    value: None,
};

pub static VARS_SPO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ilt")],
    values: &[&[(0b11010, &ENTRY_SPOILED_9946660437827218525)]],
    range: 3..=3,
};

static VARS_SPL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPL_CHILDREN),
    value: None,
};

pub static VARS_SPL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anchnocele"),
        dictgen::InsensitiveStr::Ascii("anchnocoele"),
        dictgen::InsensitiveStr::Ascii("endor"),
        dictgen::InsensitiveStr::Ascii("endorproof"),
        dictgen::InsensitiveStr::Ascii("endors"),
        dictgen::InsensitiveStr::Ascii("endour"),
        dictgen::InsensitiveStr::Ascii("endourproof"),
        dictgen::InsensitiveStr::Ascii("endours"),
        dictgen::InsensitiveStr::Ascii("enectomised"),
        dictgen::InsensitiveStr::Ascii("enectomized"),
        dictgen::InsensitiveStr::Ascii("enisation"),
        dictgen::InsensitiveStr::Ascii("enisations"),
        dictgen::InsensitiveStr::Ascii("enization"),
        dictgen::InsensitiveStr::Ascii("enizations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SPLANCHNOCELE_10962826556710463329)],
        &[(0b11010, &ENTRY_SPLANCHNOCELE_10962826556710463329)],
        &[(0b11001, &ENTRY_SPLENDOR_698262644085203522)],
        &[(0b00001, &ENTRY_SPLENDORPROOF_8961725742582755989)],
        &[(0b11001, &ENTRY_SPLENDORS_16829161556225143613)],
        &[(0b11010, &ENTRY_SPLENDOR_698262644085203522)],
        &[(0b11010, &ENTRY_SPLENDORPROOF_8961725742582755989)],
        &[(0b11010, &ENTRY_SPLENDORS_16829161556225143613)],
        &[(0b10010, &ENTRY_SPLENECTOMIZED_8219804151047161524)],
        &[(0b01001, &ENTRY_SPLENECTOMIZED_8219804151047161524)],
        &[(0b10010, &ENTRY_SPLENIZATION_7858507853343431089)],
        &[(0b10010, &ENTRY_SPLENIZATIONS_17949623258974597810)],
        &[(0b01001, &ENTRY_SPLENIZATION_7858507853343431089)],
        &[(0b01001, &ENTRY_SPLENIZATIONS_17949623258974597810)],
    ],
    range: 5..=11,
};

static VARS_SPI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPI_CHILDREN),
    value: None,
};

pub static VARS_SPI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("nulae"),
        dictgen::InsensitiveStr::Ascii("nule"),
        dictgen::InsensitiveStr::Ascii("raled"),
        dictgen::InsensitiveStr::Ascii("raling"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralled"),
        dictgen::InsensitiveStr::Ascii("ralling"),
        dictgen::InsensitiveStr::Ascii("rea"),
        dictgen::InsensitiveStr::Ascii("reas"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("ritise"),
        dictgen::InsensitiveStr::Ascii("ritises"),
        dictgen::InsensitiveStr::Ascii("ritize"),
        dictgen::InsensitiveStr::Ascii("ritizes"),
        dictgen::InsensitiveStr::Ascii("ritualisation"),
        dictgen::InsensitiveStr::Ascii("ritualisations"),
        dictgen::InsensitiveStr::Ascii("ritualise"),
        dictgen::InsensitiveStr::Ascii("ritualised"),
        dictgen::InsensitiveStr::Ascii("ritualiser"),
        dictgen::InsensitiveStr::Ascii("ritualisers"),
        dictgen::InsensitiveStr::Ascii("ritualises"),
        dictgen::InsensitiveStr::Ascii("ritualising"),
        dictgen::InsensitiveStr::Ascii("ritualization"),
        dictgen::InsensitiveStr::Ascii("ritualizations"),
        dictgen::InsensitiveStr::Ascii("ritualize"),
        dictgen::InsensitiveStr::Ascii("ritualized"),
        dictgen::InsensitiveStr::Ascii("ritualizer"),
        dictgen::InsensitiveStr::Ascii("ritualizers"),
        dictgen::InsensitiveStr::Ascii("ritualizes"),
        dictgen::InsensitiveStr::Ascii("ritualizing"),
        dictgen::InsensitiveStr::Ascii("rochaetal"),
        dictgen::InsensitiveStr::Ascii("rochaete"),
        dictgen::InsensitiveStr::Ascii("rochaetes"),
        dictgen::InsensitiveStr::Ascii("rochaetoses"),
        dictgen::InsensitiveStr::Ascii("rochaetosis"),
        dictgen::InsensitiveStr::Ascii("rochaetotic"),
        dictgen::InsensitiveStr::Ascii("rochetal"),
        dictgen::InsensitiveStr::Ascii("rochete"),
        dictgen::InsensitiveStr::Ascii("rochetes"),
        dictgen::InsensitiveStr::Ascii("rochetoses"),
        dictgen::InsensitiveStr::Ascii("rochetosis"),
        dictgen::InsensitiveStr::Ascii("rochetotic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SPIERS_5515884338097894490)],
        &[(0b11010, &ENTRY_SPINULE_17210556472422983066)],
        &[(0b00001, &ENTRY_SPINULE_17210556472422983066)],
        &[(0b01001, &ENTRY_SPIRALED_4583591683626098518)],
        &[(0b01001, &ENTRY_SPIRALING_4625432215690768886)],
        &[(0b10010, &ENTRY_SPIRALIZATION_8541479832578673907)],
        &[(0b10010, &ENTRY_SPIRALIZATIONS_2042085502750008288)],
        &[(0b10010, &ENTRY_SPIRALIZE_16007127051122986788)],
        &[(0b10010, &ENTRY_SPIRALIZES_6682564053194995427)],
        &[(0b01001, &ENTRY_SPIRALIZATION_8541479832578673907)],
        &[(0b01001, &ENTRY_SPIRALIZATIONS_2042085502750008288)],
        &[(0b01001, &ENTRY_SPIRALIZE_16007127051122986788)],
        &[(0b01001, &ENTRY_SPIRALIZES_6682564053194995427)],
        &[(0b11010, &ENTRY_SPIRALED_4583591683626098518)],
        &[(0b11010, &ENTRY_SPIRALING_4625432215690768886)],
        &[(0b01001, &ENTRY_SPIREA_16883104999884113279)],
        &[(0b01001, &ENTRY_SPIREAS_14727691610313704462)],
        &[(0b11010, &ENTRY_SPIERS_5515884338097894490)],
        &[(0b10010, &ENTRY_SPIRITIZE_9378881530105575004)],
        &[(0b10010, &ENTRY_SPIRITIZES_6541246359921725745)],
        &[(0b01001, &ENTRY_SPIRITIZE_9378881530105575004)],
        &[(0b01001, &ENTRY_SPIRITIZES_6541246359921725745)],
        &[(0b10010, &ENTRY_SPIRITUALIZATION_10305886720640139033)],
        &[(0b10010, &ENTRY_SPIRITUALIZATIONS_8932729483849010613)],
        &[(0b10010, &ENTRY_SPIRITUALIZE_7047180007869852793)],
        &[(0b10010, &ENTRY_SPIRITUALIZED_2725993091146698638)],
        &[(0b10010, &ENTRY_SPIRITUALIZER_8504978883588201552)],
        &[(0b10010, &ENTRY_SPIRITUALIZERS_3732134443047012330)],
        &[(0b10010, &ENTRY_SPIRITUALIZES_1639337578015899962)],
        &[(0b10010, &ENTRY_SPIRITUALIZING_17446854514925186660)],
        &[(0b01001, &ENTRY_SPIRITUALIZATION_10305886720640139033)],
        &[(0b01001, &ENTRY_SPIRITUALIZATIONS_8932729483849010613)],
        &[(0b01001, &ENTRY_SPIRITUALIZE_7047180007869852793)],
        &[(0b01001, &ENTRY_SPIRITUALIZED_2725993091146698638)],
        &[(0b01001, &ENTRY_SPIRITUALIZER_8504978883588201552)],
        &[(0b01001, &ENTRY_SPIRITUALIZERS_3732134443047012330)],
        &[(0b01001, &ENTRY_SPIRITUALIZES_1639337578015899962)],
        &[(0b01001, &ENTRY_SPIRITUALIZING_17446854514925186660)],
        &[(0b11010, &ENTRY_SPIROCHETAL_11634963050010672522)],
        &[(0b10010, &ENTRY_SPIROCHETE_5978254499923720079)],
        &[(0b10010, &ENTRY_SPIROCHETES_13621339480155823661)],
        &[(0b11010, &ENTRY_SPIROCHETOSES_6730304618752518023)],
        &[(0b11010, &ENTRY_SPIROCHETOSIS_13176480837782571985)],
        &[(0b11010, &ENTRY_SPIROCHETOTIC_8684207899956468554)],
        &[(0b00001, &ENTRY_SPIROCHETAL_11634963050010672522)],
        &[(0b01001, &ENTRY_SPIROCHETE_5978254499923720079)],
        &[(0b01001, &ENTRY_SPIROCHETES_13621339480155823661)],
        &[(0b00001, &ENTRY_SPIROCHETOSES_6730304618752518023)],
        &[(0b00001, &ENTRY_SPIROCHETOSIS_13176480837782571985)],
        &[(0b00001, &ENTRY_SPIROCHETOTIC_8684207899956468554)],
    ],
    range: 3..=14,
};

static VARS_SPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPH_CHILDREN),
    value: None,
};

pub static VARS_SPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aerocrystal"),
        dictgen::InsensitiveStr::Ascii("aerosome"),
        dictgen::InsensitiveStr::Ascii("enethmoid"),
        dictgen::InsensitiveStr::Ascii("enethmoidal"),
        dictgen::InsensitiveStr::Ascii("enoethmoid"),
        dictgen::InsensitiveStr::Ascii("enoethmoidal"),
        dictgen::InsensitiveStr::Ascii("erocrystal"),
        dictgen::InsensitiveStr::Ascii("eroidisation"),
        dictgen::InsensitiveStr::Ascii("eroidisations"),
        dictgen::InsensitiveStr::Ascii("eroidise"),
        dictgen::InsensitiveStr::Ascii("eroidised"),
        dictgen::InsensitiveStr::Ascii("eroidises"),
        dictgen::InsensitiveStr::Ascii("eroidising"),
        dictgen::InsensitiveStr::Ascii("eroidization"),
        dictgen::InsensitiveStr::Ascii("eroidizations"),
        dictgen::InsensitiveStr::Ascii("eroidize"),
        dictgen::InsensitiveStr::Ascii("eroidized"),
        dictgen::InsensitiveStr::Ascii("eroidizes"),
        dictgen::InsensitiveStr::Ascii("eroidizing"),
        dictgen::InsensitiveStr::Ascii("erosome"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SPHEROCRYSTAL_13381643278818911724)],
        &[(0b11010, &ENTRY_SPHEROSOME_14408424187868099563)],
        &[(0b00001, &ENTRY_SPHENETHMOID_8848939739861600805)],
        &[(0b00001, &ENTRY_SPHENETHMOIDAL_4192928733742313479)],
        &[(0b11010, &ENTRY_SPHENETHMOID_8848939739861600805)],
        &[(0b11010, &ENTRY_SPHENETHMOIDAL_4192928733742313479)],
        &[(0b00001, &ENTRY_SPHEROCRYSTAL_13381643278818911724)],
        &[(0b10010, &ENTRY_SPHEROIDIZATION_1425186216287202703)],
        &[(0b10010, &ENTRY_SPHEROIDIZATIONS_780683803829928867)],
        &[(0b10010, &ENTRY_SPHEROIDIZE_11471029450807575082)],
        &[(0b10010, &ENTRY_SPHEROIDIZED_3309613407465330972)],
        &[(0b10010, &ENTRY_SPHEROIDIZES_6259874484087826697)],
        &[(0b10010, &ENTRY_SPHEROIDIZING_11358721974863679837)],
        &[(0b01001, &ENTRY_SPHEROIDIZATION_1425186216287202703)],
        &[(0b01001, &ENTRY_SPHEROIDIZATIONS_780683803829928867)],
        &[(0b01001, &ENTRY_SPHEROIDIZE_11471029450807575082)],
        &[(0b01001, &ENTRY_SPHEROIDIZED_3309613407465330972)],
        &[(0b01001, &ENTRY_SPHEROIDIZES_6259874484087826697)],
        &[(0b01001, &ENTRY_SPHEROIDIZING_11358721974863679837)],
        &[(0b00001, &ENTRY_SPHEROSOME_14408424187868099563)],
    ],
    range: 7..=13,
};

static VARS_SPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPE_CHILDREN),
    value: None,
};

pub static VARS_SPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cialisation"),
        dictgen::InsensitiveStr::Ascii("cialisations"),
        dictgen::InsensitiveStr::Ascii("cialise"),
        dictgen::InsensitiveStr::Ascii("cialised"),
        dictgen::InsensitiveStr::Ascii("cialiser"),
        dictgen::InsensitiveStr::Ascii("cialisers"),
        dictgen::InsensitiveStr::Ascii("cialises"),
        dictgen::InsensitiveStr::Ascii("cialising"),
        dictgen::InsensitiveStr::Ascii("cialities"),
        dictgen::InsensitiveStr::Ascii("ciality"),
        dictgen::InsensitiveStr::Ascii("cialization"),
        dictgen::InsensitiveStr::Ascii("cializations"),
        dictgen::InsensitiveStr::Ascii("cialize"),
        dictgen::InsensitiveStr::Ascii("cialized"),
        dictgen::InsensitiveStr::Ascii("cializer"),
        dictgen::InsensitiveStr::Ascii("cializers"),
        dictgen::InsensitiveStr::Ascii("cializes"),
        dictgen::InsensitiveStr::Ascii("cializing"),
        dictgen::InsensitiveStr::Ascii("cialties"),
        dictgen::InsensitiveStr::Ascii("cialty"),
        dictgen::InsensitiveStr::Ascii("cificise"),
        dictgen::InsensitiveStr::Ascii("cificises"),
        dictgen::InsensitiveStr::Ascii("cificize"),
        dictgen::InsensitiveStr::Ascii("cificizes"),
        dictgen::InsensitiveStr::Ascii("cimenise"),
        dictgen::InsensitiveStr::Ascii("cimenises"),
        dictgen::InsensitiveStr::Ascii("cimenize"),
        dictgen::InsensitiveStr::Ascii("cimenizes"),
        dictgen::InsensitiveStr::Ascii("cter"),
        dictgen::InsensitiveStr::Ascii("ctered"),
        dictgen::InsensitiveStr::Ascii("cterlike"),
        dictgen::InsensitiveStr::Ascii("cterlikes"),
        dictgen::InsensitiveStr::Ascii("cters"),
        dictgen::InsensitiveStr::Ascii("ctre"),
        dictgen::InsensitiveStr::Ascii("ctred"),
        dictgen::InsensitiveStr::Ascii("ctrelike"),
        dictgen::InsensitiveStr::Ascii("ctrelikes"),
        dictgen::InsensitiveStr::Ascii("ctres"),
        dictgen::InsensitiveStr::Ascii("ctrocolorimetry"),
        dictgen::InsensitiveStr::Ascii("ctrocolourimetry"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("laean"),
        dictgen::InsensitiveStr::Ascii("laeological"),
        dictgen::InsensitiveStr::Ascii("laeothem"),
        dictgen::InsensitiveStr::Ascii("laeothems"),
        dictgen::InsensitiveStr::Ascii("lean"),
        dictgen::InsensitiveStr::Ascii("leothem"),
        dictgen::InsensitiveStr::Ascii("leothems"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("rmatorrhea"),
        dictgen::InsensitiveStr::Ascii("rmatorrheas"),
        dictgen::InsensitiveStr::Ascii("rmatorrhoea"),
        dictgen::InsensitiveStr::Ascii("rmatorrhoeas"),
        dictgen::InsensitiveStr::Ascii("ronares"),
        dictgen::InsensitiveStr::Ascii("ronaroes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SPECIALIZATION_14868724416514006075)],
        &[(0b10010, &ENTRY_SPECIALIZATIONS_13893908534368099370)],
        &[(0b10010, &ENTRY_SPECIALIZE_13734198890330005704)],
        &[(0b10010, &ENTRY_SPECIALIZED_8365382398741657820)],
        &[(0b10010, &ENTRY_SPECIALIZER_3424451690381023981)],
        &[(0b10010, &ENTRY_SPECIALIZERS_321317241265822118)],
        &[(0b10010, &ENTRY_SPECIALIZES_12943575911419958048)],
        &[(0b10010, &ENTRY_SPECIALIZING_2079181106562003064)],
        &[(0b10010, &ENTRY_SPECIALTIES_3691519001585260032)],
        &[(0b10010, &ENTRY_SPECIALTY_15229334144133093973)],
        &[(0b01001, &ENTRY_SPECIALIZATION_14868724416514006075)],
        &[(0b01001, &ENTRY_SPECIALIZATIONS_13893908534368099370)],
        &[(0b01001, &ENTRY_SPECIALIZE_13734198890330005704)],
        &[(0b01001, &ENTRY_SPECIALIZED_8365382398741657820)],
        &[(0b01001, &ENTRY_SPECIALIZER_3424451690381023981)],
        &[(0b01001, &ENTRY_SPECIALIZERS_321317241265822118)],
        &[(0b01001, &ENTRY_SPECIALIZES_12943575911419958048)],
        &[(0b01001, &ENTRY_SPECIALIZING_2079181106562003064)],
        &[(0b01001, &ENTRY_SPECIALTIES_3691519001585260032)],
        &[(0b01001, &ENTRY_SPECIALTY_15229334144133093973)],
        &[(0b10010, &ENTRY_SPECIFICIZE_14913302620346573053)],
        &[(0b10010, &ENTRY_SPECIFICIZES_14547115587945723943)],
        &[(0b01001, &ENTRY_SPECIFICIZE_14913302620346573053)],
        &[(0b01001, &ENTRY_SPECIFICIZES_14547115587945723943)],
        &[(0b10010, &ENTRY_SPECIMENIZE_2090384801819711905)],
        &[(0b10010, &ENTRY_SPECIMENIZES_8129034162279199571)],
        &[(0b01001, &ENTRY_SPECIMENIZE_2090384801819711905)],
        &[(0b01001, &ENTRY_SPECIMENIZES_8129034162279199571)],
        &[(0b00001, &ENTRY_SPECTER_13138390153678479670)],
        &[(0b00001, &ENTRY_SPECTERED_863247434920694580)],
        &[(0b00001, &ENTRY_SPECTERLIKE_18260751826068593688)],
        &[(0b00001, &ENTRY_SPECTERLIKES_484157250269129460)],
        &[(0b00001, &ENTRY_SPECTERS_7942939111689789209)],
        &[(0b11010, &ENTRY_SPECTER_13138390153678479670)],
        &[(0b11010, &ENTRY_SPECTERED_863247434920694580)],
        &[(0b11010, &ENTRY_SPECTERLIKE_18260751826068593688)],
        &[(0b11010, &ENTRY_SPECTERLIKES_484157250269129460)],
        &[(0b11010, &ENTRY_SPECTERS_7942939111689789209)],
        &[(0b00001, &ENTRY_SPECTROCOLORIMETRY_1759736892341904212)],
        &[(0b11010, &ENTRY_SPECTROCOLORIMETRY_1759736892341904212)],
        &[(0b00001, &ENTRY_SPEER_13429671139585207271)],
        &[(0b11010, &ENTRY_SPELEAN_8367235262898475105)],
        &[(0b11010, &ENTRY_SPELEOLOGICAL_11481859540905022703)],
        &[(0b11010, &ENTRY_SPELEOTHEM_17324027630005062947)],
        &[(0b11010, &ENTRY_SPELEOTHEMS_10285341670778918846)],
        &[(0b00001, &ENTRY_SPELEAN_8367235262898475105)],
        &[(0b00001, &ENTRY_SPELEOTHEM_17324027630005062947)],
        &[(0b00001, &ENTRY_SPELEOTHEMS_10285341670778918846)],
        &[(0b11010, &ENTRY_SPEER_13429671139585207271)],
        &[(0b00001, &ENTRY_SPERMATORRHEA_11364148558414858528)],
        &[(0b00001, &ENTRY_SPERMATORRHEAS_3208610420634611148)],
        &[(0b11010, &ENTRY_SPERMATORRHEA_11364148558414858528)],
        &[(0b11010, &ENTRY_SPERMATORRHEAS_3208610420634611148)],
        &[(0b00001, &ENTRY_SPERONARES_16134515720540164866)],
        &[(0b11010, &ENTRY_SPERONARES_16134515720540164866)],
    ],
    range: 2..=16,
};

static VARS_SPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SPA_CHILDREN),
    value: None,
};

pub static VARS_SPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("naemia"),
        dictgen::InsensitiveStr::Ascii("naemic"),
        dictgen::InsensitiveStr::Ascii("nemia"),
        dictgen::InsensitiveStr::Ascii("nemic"),
        dictgen::InsensitiveStr::Ascii("niardisation"),
        dictgen::InsensitiveStr::Ascii("niardisations"),
        dictgen::InsensitiveStr::Ascii("niardise"),
        dictgen::InsensitiveStr::Ascii("niardises"),
        dictgen::InsensitiveStr::Ascii("niardization"),
        dictgen::InsensitiveStr::Ascii("niardizations"),
        dictgen::InsensitiveStr::Ascii("niardize"),
        dictgen::InsensitiveStr::Ascii("niardizes"),
        dictgen::InsensitiveStr::Ascii("niolise"),
        dictgen::InsensitiveStr::Ascii("niolised"),
        dictgen::InsensitiveStr::Ascii("niolises"),
        dictgen::InsensitiveStr::Ascii("niolising"),
        dictgen::InsensitiveStr::Ascii("niolize"),
        dictgen::InsensitiveStr::Ascii("niolized"),
        dictgen::InsensitiveStr::Ascii("niolizes"),
        dictgen::InsensitiveStr::Ascii("niolizing"),
        dictgen::InsensitiveStr::Ascii("nishise"),
        dictgen::InsensitiveStr::Ascii("nishises"),
        dictgen::InsensitiveStr::Ascii("nishize"),
        dictgen::InsensitiveStr::Ascii("nishizes"),
        dictgen::InsensitiveStr::Ascii("nopnea"),
        dictgen::InsensitiveStr::Ascii("nopnoea"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("rres"),
        dictgen::InsensitiveStr::Ascii("rtanise"),
        dictgen::InsensitiveStr::Ascii("rtanises"),
        dictgen::InsensitiveStr::Ascii("rtanize"),
        dictgen::InsensitiveStr::Ascii("rtanizes"),
        dictgen::InsensitiveStr::Ascii("tialisation"),
        dictgen::InsensitiveStr::Ascii("tialisations"),
        dictgen::InsensitiveStr::Ascii("tialise"),
        dictgen::InsensitiveStr::Ascii("tialises"),
        dictgen::InsensitiveStr::Ascii("tialization"),
        dictgen::InsensitiveStr::Ascii("tializations"),
        dictgen::InsensitiveStr::Ascii("tialize"),
        dictgen::InsensitiveStr::Ascii("tializes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SPANEMIA_9395556157284175278)],
        &[(0b11010, &ENTRY_SPANEMIC_7019184248567022986)],
        &[(0b00001, &ENTRY_SPANEMIA_9395556157284175278)],
        &[(0b00001, &ENTRY_SPANEMIC_7019184248567022986)],
        &[(0b10010, &ENTRY_SPANIARDIZATION_10902219760262843235)],
        &[(0b10010, &ENTRY_SPANIARDIZATIONS_15525961894554670327)],
        &[(0b10010, &ENTRY_SPANIARDIZE_9569545691628177723)],
        &[(0b10010, &ENTRY_SPANIARDIZES_6439262747070069854)],
        &[(0b01001, &ENTRY_SPANIARDIZATION_10902219760262843235)],
        &[(0b01001, &ENTRY_SPANIARDIZATIONS_15525961894554670327)],
        &[(0b01001, &ENTRY_SPANIARDIZE_9569545691628177723)],
        &[(0b01001, &ENTRY_SPANIARDIZES_6439262747070069854)],
        &[(0b10010, &ENTRY_SPANIOLIZE_16413139481606920807)],
        &[(0b10010, &ENTRY_SPANIOLIZED_9570991099566114102)],
        &[(0b10010, &ENTRY_SPANIOLIZES_7108790081189873491)],
        &[(0b10010, &ENTRY_SPANIOLIZING_13650496056576542802)],
        &[(0b01001, &ENTRY_SPANIOLIZE_16413139481606920807)],
        &[(0b01001, &ENTRY_SPANIOLIZED_9570991099566114102)],
        &[(0b01001, &ENTRY_SPANIOLIZES_7108790081189873491)],
        &[(0b01001, &ENTRY_SPANIOLIZING_13650496056576542802)],
        &[(0b10010, &ENTRY_SPANISHIZE_11599801654411089329)],
        &[(0b10010, &ENTRY_SPANISHIZES_15280734989274435032)],
        &[(0b01001, &ENTRY_SPANISHIZE_11599801654411089329)],
        &[(0b01001, &ENTRY_SPANISHIZES_15280734989274435032)],
        &[(0b00001, &ENTRY_SPANOPNEA_8865008578129066489)],
        &[(0b11010, &ENTRY_SPANOPNEA_8865008578129066489)],
        &[(0b00001, &ENTRY_SPARERS_12651957075913392459)],
        &[(0b11010, &ENTRY_SPARERS_12651957075913392459)],
        &[(0b10010, &ENTRY_SPARTANIZE_14452942641175240684)],
        &[(0b10010, &ENTRY_SPARTANIZES_11376123191933793512)],
        &[(0b01001, &ENTRY_SPARTANIZE_14452942641175240684)],
        &[(0b01001, &ENTRY_SPARTANIZES_11376123191933793512)],
        &[(0b10010, &ENTRY_SPATIALIZATION_17405201949564996789)],
        &[(0b10010, &ENTRY_SPATIALIZATIONS_4112547726772378999)],
        &[(0b10010, &ENTRY_SPATIALIZE_16660740722538409917)],
        &[(0b10010, &ENTRY_SPATIALIZES_13997333572376113619)],
        &[(0b01001, &ENTRY_SPATIALIZATION_17405201949564996789)],
        &[(0b01001, &ENTRY_SPATIALIZATIONS_4112547726772378999)],
        &[(0b01001, &ENTRY_SPATIALIZE_16660740722538409917)],
        &[(0b01001, &ENTRY_SPATIALIZES_13997333572376113619)],
    ],
    range: 4..=13,
};

static VARS_SO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SO_CHILDREN),
    value: None,
};

static VARS_SO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SOB_NODE),
    Some(&VARS_SOC_NODE),
    Some(&VARS_SOD_NODE),
    Some(&VARS_SOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SOL_NODE),
    Some(&VARS_SOM_NODE),
    Some(&VARS_SON_NODE),
    None,
    None,
    None,
    Some(&VARS_SOR_NODE),
    None,
    None,
    Some(&VARS_SOU_NODE),
    Some(&VARS_SOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_SOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOV_CHILDREN),
    value: None,
};

pub static VARS_SOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ietisation"),
        dictgen::InsensitiveStr::Ascii("ietisations"),
        dictgen::InsensitiveStr::Ascii("ietise"),
        dictgen::InsensitiveStr::Ascii("ietised"),
        dictgen::InsensitiveStr::Ascii("ietises"),
        dictgen::InsensitiveStr::Ascii("ietising"),
        dictgen::InsensitiveStr::Ascii("ietization"),
        dictgen::InsensitiveStr::Ascii("ietizations"),
        dictgen::InsensitiveStr::Ascii("ietize"),
        dictgen::InsensitiveStr::Ascii("ietized"),
        dictgen::InsensitiveStr::Ascii("ietizes"),
        dictgen::InsensitiveStr::Ascii("ietizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOVIETIZATION_13205972349841767875)],
        &[(0b10010, &ENTRY_SOVIETIZATIONS_2629132161469247656)],
        &[(0b10010, &ENTRY_SOVIETIZE_15802906407586023669)],
        &[(0b10010, &ENTRY_SOVIETIZED_7565927092510685793)],
        &[(0b10010, &ENTRY_SOVIETIZES_11590305664562136263)],
        &[(0b10010, &ENTRY_SOVIETIZING_16212924505860778534)],
        &[(0b01001, &ENTRY_SOVIETIZATION_13205972349841767875)],
        &[(0b01001, &ENTRY_SOVIETIZATIONS_2629132161469247656)],
        &[(0b01001, &ENTRY_SOVIETIZE_15802906407586023669)],
        &[(0b01001, &ENTRY_SOVIETIZED_7565927092510685793)],
        &[(0b01001, &ENTRY_SOVIETIZES_11590305664562136263)],
        &[(0b01001, &ENTRY_SOVIETIZING_16212924505860778534)],
    ],
    range: 6..=11,
};

static VARS_SOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOU_CHILDREN),
    value: None,
};

pub static VARS_SOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fflaed"),
        dictgen::InsensitiveStr::Ascii("ffled"),
        dictgen::InsensitiveStr::Ascii("lter"),
        dictgen::InsensitiveStr::Ascii("ltre"),
        dictgen::InsensitiveStr::Ascii("rd"),
        dictgen::InsensitiveStr::Ascii("rdine"),
        dictgen::InsensitiveStr::Ascii("rdines"),
        dictgen::InsensitiveStr::Ascii("ry"),
        dictgen::InsensitiveStr::Ascii("thernise"),
        dictgen::InsensitiveStr::Ascii("thernised"),
        dictgen::InsensitiveStr::Ascii("thernises"),
        dictgen::InsensitiveStr::Ascii("thernising"),
        dictgen::InsensitiveStr::Ascii("thernize"),
        dictgen::InsensitiveStr::Ascii("thernized"),
        dictgen::InsensitiveStr::Ascii("thernizes"),
        dictgen::InsensitiveStr::Ascii("thernizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SOUFFLED_11288921415541351012)],
        &[(0b00001, &ENTRY_SOUFFLED_11288921415541351012)],
        &[(0b00001, &ENTRY_SOULTER_16287779215263702830)],
        &[(0b11010, &ENTRY_SOULTER_16287779215263702830)],
        &[(0b11010, &ENTRY_SORD_16682875115764427041)],
        &[(0b11010, &ENTRY_SORDINE_13046642983492348660)],
        &[(0b11010, &ENTRY_SORDINES_17955052261708476598)],
        &[(0b11010, &ENTRY_SORY_866294547402037500)],
        &[(0b10010, &ENTRY_SOUTHERNIZE_2007900784402703927)],
        &[(0b10010, &ENTRY_SOUTHERNIZED_5166061537133315558)],
        &[(0b10010, &ENTRY_SOUTHERNIZES_17801238247060666066)],
        &[(0b10010, &ENTRY_SOUTHERNIZING_7105097135265474755)],
        &[(0b01001, &ENTRY_SOUTHERNIZE_2007900784402703927)],
        &[(0b01001, &ENTRY_SOUTHERNIZED_5166061537133315558)],
        &[(0b01001, &ENTRY_SOUTHERNIZES_17801238247060666066)],
        &[(0b01001, &ENTRY_SOUTHERNIZING_7105097135265474755)],
    ],
    range: 2..=10,
};

static VARS_SOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOR_CHILDREN),
    value: None,
};

pub static VARS_SOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bitisation"),
        dictgen::InsensitiveStr::Ascii("bitisations"),
        dictgen::InsensitiveStr::Ascii("bitise"),
        dictgen::InsensitiveStr::Ascii("bitised"),
        dictgen::InsensitiveStr::Ascii("bitises"),
        dictgen::InsensitiveStr::Ascii("bitising"),
        dictgen::InsensitiveStr::Ascii("bitization"),
        dictgen::InsensitiveStr::Ascii("bitizations"),
        dictgen::InsensitiveStr::Ascii("bitize"),
        dictgen::InsensitiveStr::Ascii("bitized"),
        dictgen::InsensitiveStr::Ascii("bitizes"),
        dictgen::InsensitiveStr::Ascii("bitizing"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("dine"),
        dictgen::InsensitiveStr::Ascii("dines"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SORBITIZATION_3511955197103798019)],
        &[(0b10010, &ENTRY_SORBITIZATIONS_15094150133852333070)],
        &[(0b10010, &ENTRY_SORBITIZE_4953121359286386634)],
        &[(0b10010, &ENTRY_SORBITIZED_11029247990437433113)],
        &[(0b10010, &ENTRY_SORBITIZES_17239730547558440933)],
        &[(0b10010, &ENTRY_SORBITIZING_10552560528290540525)],
        &[(0b01001, &ENTRY_SORBITIZATION_3511955197103798019)],
        &[(0b01001, &ENTRY_SORBITIZATIONS_15094150133852333070)],
        &[(0b01001, &ENTRY_SORBITIZE_4953121359286386634)],
        &[(0b01001, &ENTRY_SORBITIZED_11029247990437433113)],
        &[(0b01001, &ENTRY_SORBITIZES_17239730547558440933)],
        &[(0b01001, &ENTRY_SORBITIZING_10552560528290540525)],
        &[(0b00001, &ENTRY_SORD_16682875115764427041)],
        &[(0b00001, &ENTRY_SORDINE_13046642983492348660)],
        &[(0b00001, &ENTRY_SORDINES_17955052261708476598)],
        &[(0b10010, &ENTRY_SORORIZE_10455264558591532576)],
        &[(0b10010, &ENTRY_SORORIZED_10275110518887074085)],
        &[(0b10010, &ENTRY_SORORIZES_5655621331560912625)],
        &[(0b10010, &ENTRY_SORORIZING_2971025569489318464)],
        &[(0b01001, &ENTRY_SORORIZE_10455264558591532576)],
        &[(0b01001, &ENTRY_SORORIZED_10275110518887074085)],
        &[(0b01001, &ENTRY_SORORIZES_5655621331560912625)],
        &[(0b01001, &ENTRY_SORORIZING_2971025569489318464)],
        &[(0b00001, &ENTRY_SORY_866294547402037500)],
    ],
    range: 1..=11,
};

static VARS_SON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SON_CHILDREN),
    value: None,
};

pub static VARS_SON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("antised"),
        dictgen::InsensitiveStr::Ascii("antiseds"),
        dictgen::InsensitiveStr::Ascii("antized"),
        dictgen::InsensitiveStr::Ascii("antizeds"),
        dictgen::InsensitiveStr::Ascii("netisation"),
        dictgen::InsensitiveStr::Ascii("netise"),
        dictgen::InsensitiveStr::Ascii("netised"),
        dictgen::InsensitiveStr::Ascii("netises"),
        dictgen::InsensitiveStr::Ascii("netising"),
        dictgen::InsensitiveStr::Ascii("netization"),
        dictgen::InsensitiveStr::Ascii("netize"),
        dictgen::InsensitiveStr::Ascii("netized"),
        dictgen::InsensitiveStr::Ascii("netizes"),
        dictgen::InsensitiveStr::Ascii("netizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SONANTIZED_7465742307673093545)],
        &[(0b10010, &ENTRY_SONANTIZEDS_5806347613534212865)],
        &[(0b01001, &ENTRY_SONANTIZED_7465742307673093545)],
        &[(0b01001, &ENTRY_SONANTIZEDS_5806347613534212865)],
        &[(0b10010, &ENTRY_SONNETIZATION_17811800137071473898)],
        &[(0b10010, &ENTRY_SONNETIZE_3336641041466286630)],
        &[(0b10010, &ENTRY_SONNETIZED_16371695347786264769)],
        &[(0b10010, &ENTRY_SONNETIZES_6585967879025542142)],
        &[(0b10010, &ENTRY_SONNETIZING_2853568487817375411)],
        &[(0b01001, &ENTRY_SONNETIZATION_17811800137071473898)],
        &[(0b01001, &ENTRY_SONNETIZE_3336641041466286630)],
        &[(0b01001, &ENTRY_SONNETIZED_16371695347786264769)],
        &[(0b01001, &ENTRY_SONNETIZES_6585967879025542142)],
        &[(0b01001, &ENTRY_SONNETIZING_2853568487817375411)],
    ],
    range: 6..=10,
};

static VARS_SOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOM_CHILDREN),
    value: None,
};

pub static VARS_SOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("aesthesis"),
        dictgen::InsensitiveStr::Ascii("ber"),
        dictgen::InsensitiveStr::Ascii("berer"),
        dictgen::InsensitiveStr::Ascii("berest"),
        dictgen::InsensitiveStr::Ascii("berish"),
        dictgen::InsensitiveStr::Ascii("berly"),
        dictgen::InsensitiveStr::Ascii("berness"),
        dictgen::InsensitiveStr::Ascii("bernesses"),
        dictgen::InsensitiveStr::Ascii("breish"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesis"),
        dictgen::InsensitiveStr::Ascii("niloquise"),
        dictgen::InsensitiveStr::Ascii("niloquised"),
        dictgen::InsensitiveStr::Ascii("niloquises"),
        dictgen::InsensitiveStr::Ascii("niloquising"),
        dictgen::InsensitiveStr::Ascii("niloquize"),
        dictgen::InsensitiveStr::Ascii("niloquized"),
        dictgen::InsensitiveStr::Ascii("niloquizes"),
        dictgen::InsensitiveStr::Ascii("niloquizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SOMESTHESIA_11184895325270057547)],
        &[(0b11010, &ENTRY_SOMESTHESIS_3205445442940535664)],
        &[(0b00001, &ENTRY_SOMBER_5140950589921348685)],
        &[(0b00001, &ENTRY_SOMBERER_17580079165913630117)],
        &[(0b00001, &ENTRY_SOMBEREST_3884649068642437270)],
        &[(0b00001, &ENTRY_SOMBERISH_9751798617429837974)],
        &[(0b00001, &ENTRY_SOMBERLY_14824241355422186369)],
        &[(0b00001, &ENTRY_SOMBERNESS_3289235689799463770)],
        &[(0b00001, &ENTRY_SOMBERNESSES_5970684106925544470)],
        &[(0b11010, &ENTRY_SOMBERISH_9751798617429837974)],
        &[(0b00001, &ENTRY_SOMESTHESIA_11184895325270057547)],
        &[(0b00001, &ENTRY_SOMESTHESIS_3205445442940535664)],
        &[(0b10010, &ENTRY_SOMNILOQUIZE_14989120006007292353)],
        &[(0b10010, &ENTRY_SOMNILOQUIZED_11728587916951539904)],
        &[(0b10010, &ENTRY_SOMNILOQUIZES_7318100064004324381)],
        &[(0b10010, &ENTRY_SOMNILOQUIZING_13842334488833594229)],
        &[(0b01001, &ENTRY_SOMNILOQUIZE_14989120006007292353)],
        &[(0b01001, &ENTRY_SOMNILOQUIZED_11728587916951539904)],
        &[(0b01001, &ENTRY_SOMNILOQUIZES_7318100064004324381)],
        &[(0b01001, &ENTRY_SOMNILOQUIZING_13842334488833594229)],
    ],
    range: 3..=11,
};

static VARS_SOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SOL_CHILDREN),
    value: None,
};

static VARS_SOL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SOLA_NODE),
    None,
    None,
    Some(&VARS_SOLD_NODE),
    Some(&VARS_SOLE_NODE),
    None,
    None,
    None,
    Some(&VARS_SOLI_NODE),
    None,
    None,
    None,
    Some(&VARS_SOLM_NODE),
    None,
    Some(&VARS_SOLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SOLU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_SOLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLU_CHILDREN),
    value: None,
};

pub static VARS_SOLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilisation"),
        dictgen::InsensitiveStr::Ascii("bilisations"),
        dictgen::InsensitiveStr::Ascii("bilise"),
        dictgen::InsensitiveStr::Ascii("bilised"),
        dictgen::InsensitiveStr::Ascii("bilises"),
        dictgen::InsensitiveStr::Ascii("bilising"),
        dictgen::InsensitiveStr::Ascii("bilization"),
        dictgen::InsensitiveStr::Ascii("bilizations"),
        dictgen::InsensitiveStr::Ascii("bilize"),
        dictgen::InsensitiveStr::Ascii("bilized"),
        dictgen::InsensitiveStr::Ascii("bilizes"),
        dictgen::InsensitiveStr::Ascii("bilizing"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizer"),
        dictgen::InsensitiveStr::Ascii("tizers"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLUBILIZATION_11329836872303618229)],
        &[(0b10010, &ENTRY_SOLUBILIZATIONS_4369156796378163009)],
        &[(0b10010, &ENTRY_SOLUBILIZE_1662872893301039501)],
        &[(0b10010, &ENTRY_SOLUBILIZED_6258117609347074455)],
        &[(0b10010, &ENTRY_SOLUBILIZES_13987666377462264730)],
        &[(0b10010, &ENTRY_SOLUBILIZING_10490972660552675683)],
        &[(0b01001, &ENTRY_SOLUBILIZATION_11329836872303618229)],
        &[(0b01001, &ENTRY_SOLUBILIZATIONS_4369156796378163009)],
        &[(0b01001, &ENTRY_SOLUBILIZE_1662872893301039501)],
        &[(0b01001, &ENTRY_SOLUBILIZED_6258117609347074455)],
        &[(0b01001, &ENTRY_SOLUBILIZES_13987666377462264730)],
        &[(0b01001, &ENTRY_SOLUBILIZING_10490972660552675683)],
        &[(0b10010, &ENTRY_SOLUTIZE_5438116954578400359)],
        &[(0b10010, &ENTRY_SOLUTIZER_6497015698400010769)],
        &[(0b10010, &ENTRY_SOLUTIZERS_16598006390430358557)],
        &[(0b10010, &ENTRY_SOLUTIZES_16990892992718942912)],
        &[(0b01001, &ENTRY_SOLUTIZE_5438116954578400359)],
        &[(0b01001, &ENTRY_SOLUTIZER_6497015698400010769)],
        &[(0b01001, &ENTRY_SOLUTIZERS_16598006390430358557)],
        &[(0b01001, &ENTRY_SOLUTIZES_16990892992718942912)],
    ],
    range: 4..=11,
};

static VARS_SOLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLO_CHILDREN),
    value: None,
};

pub static VARS_SOLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLONIZATION_11249232042663309133)],
        &[(0b10010, &ENTRY_SOLONIZATIONS_4433313152747643816)],
        &[(0b01001, &ENTRY_SOLONIZATION_11249232042663309133)],
        &[(0b01001, &ENTRY_SOLONIZATIONS_4433313152747643816)],
    ],
    range: 8..=9,
};

static VARS_SOLM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLM_CHILDREN),
    value: None,
};

pub static VARS_SOLM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLMIZATION_8566929989308185368)],
        &[(0b10010, &ENTRY_SOLMIZATIONS_13280876893352435221)],
        &[(0b01001, &ENTRY_SOLMIZATION_8566929989308185368)],
        &[(0b01001, &ENTRY_SOLMIZATIONS_13280876893352435221)],
    ],
    range: 7..=8,
};

static VARS_SOLI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLI_CHILDREN),
    value: None,
};

pub static VARS_SOLI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("loquisation"),
        dictgen::InsensitiveStr::Ascii("loquise"),
        dictgen::InsensitiveStr::Ascii("loquised"),
        dictgen::InsensitiveStr::Ascii("loquiser"),
        dictgen::InsensitiveStr::Ascii("loquisers"),
        dictgen::InsensitiveStr::Ascii("loquises"),
        dictgen::InsensitiveStr::Ascii("loquising"),
        dictgen::InsensitiveStr::Ascii("loquisingly"),
        dictgen::InsensitiveStr::Ascii("loquisings"),
        dictgen::InsensitiveStr::Ascii("loquization"),
        dictgen::InsensitiveStr::Ascii("loquize"),
        dictgen::InsensitiveStr::Ascii("loquized"),
        dictgen::InsensitiveStr::Ascii("loquizer"),
        dictgen::InsensitiveStr::Ascii("loquizers"),
        dictgen::InsensitiveStr::Ascii("loquizes"),
        dictgen::InsensitiveStr::Ascii("loquizing"),
        dictgen::InsensitiveStr::Ascii("loquizingly"),
        dictgen::InsensitiveStr::Ascii("loquizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLILOQUIZATION_269312513960661785)],
        &[(0b10010, &ENTRY_SOLILOQUIZE_12226193284594737636)],
        &[(0b10010, &ENTRY_SOLILOQUIZED_17939687163528373325)],
        &[(0b10010, &ENTRY_SOLILOQUIZER_5490319459061869143)],
        &[(0b10010, &ENTRY_SOLILOQUIZERS_1912861598555034277)],
        &[(0b10010, &ENTRY_SOLILOQUIZES_9261685774539508340)],
        &[(0b10010, &ENTRY_SOLILOQUIZING_15896904890682292482)],
        &[(0b10010, &ENTRY_SOLILOQUIZINGLY_2770653047985095587)],
        &[(0b10010, &ENTRY_SOLILOQUIZINGS_16013560258108957465)],
        &[(0b01001, &ENTRY_SOLILOQUIZATION_269312513960661785)],
        &[(0b01001, &ENTRY_SOLILOQUIZE_12226193284594737636)],
        &[(0b01001, &ENTRY_SOLILOQUIZED_17939687163528373325)],
        &[(0b01001, &ENTRY_SOLILOQUIZER_5490319459061869143)],
        &[(0b01001, &ENTRY_SOLILOQUIZERS_1912861598555034277)],
        &[(0b01001, &ENTRY_SOLILOQUIZES_9261685774539508340)],
        &[(0b01001, &ENTRY_SOLILOQUIZING_15896904890682292482)],
        &[(0b01001, &ENTRY_SOLILOQUIZINGLY_2770653047985095587)],
        &[(0b01001, &ENTRY_SOLILOQUIZINGS_16013560258108957465)],
    ],
    range: 7..=11,
};

static VARS_SOLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLE_CHILDREN),
    value: None,
};

pub static VARS_SOLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cised"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cising"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cized"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("cizing"),
        dictgen::InsensitiveStr::Ascii("mnisation"),
        dictgen::InsensitiveStr::Ascii("mnisations"),
        dictgen::InsensitiveStr::Ascii("mnise"),
        dictgen::InsensitiveStr::Ascii("mnised"),
        dictgen::InsensitiveStr::Ascii("mniser"),
        dictgen::InsensitiveStr::Ascii("mnisers"),
        dictgen::InsensitiveStr::Ascii("mnises"),
        dictgen::InsensitiveStr::Ascii("mnising"),
        dictgen::InsensitiveStr::Ascii("mnization"),
        dictgen::InsensitiveStr::Ascii("mnizations"),
        dictgen::InsensitiveStr::Ascii("mnize"),
        dictgen::InsensitiveStr::Ascii("mnized"),
        dictgen::InsensitiveStr::Ascii("mnizer"),
        dictgen::InsensitiveStr::Ascii("mnizers"),
        dictgen::InsensitiveStr::Ascii("mnizes"),
        dictgen::InsensitiveStr::Ascii("mnizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLECIZE_4990335805125403138)],
        &[(0b10010, &ENTRY_SOLECIZED_15911538990572619815)],
        &[(0b10010, &ENTRY_SOLECIZES_15788433464347659056)],
        &[(0b10010, &ENTRY_SOLECIZING_12747426853182310591)],
        &[(0b01001, &ENTRY_SOLECIZE_4990335805125403138)],
        &[(0b01001, &ENTRY_SOLECIZED_15911538990572619815)],
        &[(0b01001, &ENTRY_SOLECIZES_15788433464347659056)],
        &[(0b01001, &ENTRY_SOLECIZING_12747426853182310591)],
        &[(0b10010, &ENTRY_SOLEMNIZATION_16787130687056363702)],
        &[(0b10010, &ENTRY_SOLEMNIZATIONS_6129091422641859142)],
        &[(0b10010, &ENTRY_SOLEMNIZE_15796782944155668670)],
        &[(0b10010, &ENTRY_SOLEMNIZED_2852788835971325204)],
        &[(0b10010, &ENTRY_SOLEMNIZER_5978295607112033996)],
        &[(0b10010, &ENTRY_SOLEMNIZERS_2397316897252319748)],
        &[(0b10010, &ENTRY_SOLEMNIZES_17312526288446264851)],
        &[(0b10010, &ENTRY_SOLEMNIZING_1873698687937846065)],
        &[(0b01001, &ENTRY_SOLEMNIZATION_16787130687056363702)],
        &[(0b01001, &ENTRY_SOLEMNIZATIONS_6129091422641859142)],
        &[(0b01001, &ENTRY_SOLEMNIZE_15796782944155668670)],
        &[(0b01001, &ENTRY_SOLEMNIZED_2852788835971325204)],
        &[(0b01001, &ENTRY_SOLEMNIZER_5978295607112033996)],
        &[(0b01001, &ENTRY_SOLEMNIZERS_2397316897252319748)],
        &[(0b01001, &ENTRY_SOLEMNIZES_17312526288446264851)],
        &[(0b01001, &ENTRY_SOLEMNIZING_1873698687937846065)],
    ],
    range: 4..=10,
};

static VARS_SOLD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLD_CHILDREN),
    value: None,
};

pub static VARS_SOLD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ierise"),
        dictgen::InsensitiveStr::Ascii("ierises"),
        dictgen::InsensitiveStr::Ascii("ierize"),
        dictgen::InsensitiveStr::Ascii("ierizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLDIERIZE_16604236556396943965)],
        &[(0b10010, &ENTRY_SOLDIERIZES_11157601016192388331)],
        &[(0b01001, &ENTRY_SOLDIERIZE_16604236556396943965)],
        &[(0b01001, &ENTRY_SOLDIERIZES_11157601016192388331)],
    ],
    range: 6..=7,
};

static VARS_SOLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOLA_CHILDREN),
    value: None,
};

pub static VARS_SOLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOLARIZATION_1192428962792189832)],
        &[(0b10010, &ENTRY_SOLARIZATIONS_4722132275104202763)],
        &[(0b10010, &ENTRY_SOLARIZE_18258216759051483358)],
        &[(0b10010, &ENTRY_SOLARIZED_5808975743485239818)],
        &[(0b10010, &ENTRY_SOLARIZES_5534323195052354549)],
        &[(0b10010, &ENTRY_SOLARIZING_10862859858263346398)],
        &[(0b01001, &ENTRY_SOLARIZATION_1192428962792189832)],
        &[(0b01001, &ENTRY_SOLARIZATIONS_4722132275104202763)],
        &[(0b01001, &ENTRY_SOLARIZE_18258216759051483358)],
        &[(0b01001, &ENTRY_SOLARIZED_5808975743485239818)],
        &[(0b01001, &ENTRY_SOLARIZES_5534323195052354549)],
        &[(0b01001, &ENTRY_SOLARIZING_10862859858263346398)],
    ],
    range: 4..=9,
};

static VARS_SOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_SE_15361672265999879694)]),
};

pub static VARS_SOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_SOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOD_CHILDREN),
    value: None,
};

pub static VARS_SOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("omizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SODOMIZE_6206294818202684654)],
        &[(0b10010, &ENTRY_SODOMIZED_12622748833680108292)],
        &[(0b10010, &ENTRY_SODOMIZES_743917781797229302)],
        &[(0b10010, &ENTRY_SODOMIZING_14921360499846607434)],
        &[(0b01001, &ENTRY_SODOMIZE_6206294818202684654)],
        &[(0b01001, &ENTRY_SODOMIZED_12622748833680108292)],
        &[(0b01001, &ENTRY_SODOMIZES_743917781797229302)],
        &[(0b01001, &ENTRY_SODOMIZING_14921360499846607434)],
    ],
    range: 5..=7,
};

static VARS_SOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOC_CHILDREN),
    value: None,
};

pub static VARS_SOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialiser"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializer"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
        dictgen::InsensitiveStr::Ascii("kdologising"),
        dictgen::InsensitiveStr::Ascii("kdologizing"),
        dictgen::InsensitiveStr::Ascii("ratise"),
        dictgen::InsensitiveStr::Ascii("ratised"),
        dictgen::InsensitiveStr::Ascii("ratises"),
        dictgen::InsensitiveStr::Ascii("ratising"),
        dictgen::InsensitiveStr::Ascii("ratize"),
        dictgen::InsensitiveStr::Ascii("ratized"),
        dictgen::InsensitiveStr::Ascii("ratizes"),
        dictgen::InsensitiveStr::Ascii("ratizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOCIALIZATION_2084413938110848032)],
        &[(0b10010, &ENTRY_SOCIALIZATIONS_10749899080870387486)],
        &[(0b10010, &ENTRY_SOCIALIZE_6985846630440818655)],
        &[(0b10010, &ENTRY_SOCIALIZED_11336946122134321158)],
        &[(0b10010, &ENTRY_SOCIALIZER_15740033054008322482)],
        &[(0b10010, &ENTRY_SOCIALIZES_1566074373781161623)],
        &[(0b10010, &ENTRY_SOCIALIZING_505177211807278288)],
        &[(0b01001, &ENTRY_SOCIALIZATION_2084413938110848032)],
        &[(0b01001, &ENTRY_SOCIALIZATIONS_10749899080870387486)],
        &[(0b01001, &ENTRY_SOCIALIZE_6985846630440818655)],
        &[(0b01001, &ENTRY_SOCIALIZED_11336946122134321158)],
        &[(0b01001, &ENTRY_SOCIALIZER_15740033054008322482)],
        &[(0b01001, &ENTRY_SOCIALIZES_1566074373781161623)],
        &[(0b01001, &ENTRY_SOCIALIZING_505177211807278288)],
        &[(0b10010, &ENTRY_SOCKDOLOGIZING_16991441468659816755)],
        &[(0b01001, &ENTRY_SOCKDOLOGIZING_16991441468659816755)],
        &[(0b10010, &ENTRY_SOCRATIZE_14310113146869106182)],
        &[(0b10010, &ENTRY_SOCRATIZED_9270084545030336528)],
        &[(0b10010, &ENTRY_SOCRATIZES_14641664105677151925)],
        &[(0b10010, &ENTRY_SOCRATIZING_1982796648064876142)],
        &[(0b01001, &ENTRY_SOCRATIZE_14310113146869106182)],
        &[(0b01001, &ENTRY_SOCRATIZED_9270084545030336528)],
        &[(0b01001, &ENTRY_SOCRATIZES_14641664105677151925)],
        &[(0b01001, &ENTRY_SOCRATIZING_1982796648064876142)],
    ],
    range: 6..=11,
};

static VARS_SOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SOB_CHILDREN),
    value: None,
};

pub static VARS_SOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SOBERIZE_13532853448534221620)],
        &[(0b10010, &ENTRY_SOBERIZED_7343261452157716449)],
        &[(0b10010, &ENTRY_SOBERIZES_6877701061854218485)],
        &[(0b10010, &ENTRY_SOBERIZING_10684751466686644496)],
        &[(0b01001, &ENTRY_SOBERIZE_13532853448534221620)],
        &[(0b01001, &ENTRY_SOBERIZED_7343261452157716449)],
        &[(0b01001, &ENTRY_SOBERIZES_6877701061854218485)],
        &[(0b01001, &ENTRY_SOBERIZING_10684751466686644496)],
    ],
    range: 5..=7,
};

static VARS_SN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SN_CHILDREN),
    value: None,
};

pub static VARS_SN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iveled"),
        dictgen::InsensitiveStr::Ascii("iveler"),
        dictgen::InsensitiveStr::Ascii("ivelers"),
        dictgen::InsensitiveStr::Ascii("iveling"),
        dictgen::InsensitiveStr::Ascii("ivelings"),
        dictgen::InsensitiveStr::Ascii("ivelled"),
        dictgen::InsensitiveStr::Ascii("iveller"),
        dictgen::InsensitiveStr::Ascii("ivellers"),
        dictgen::InsensitiveStr::Ascii("ivelling"),
        dictgen::InsensitiveStr::Ascii("ivellings"),
        dictgen::InsensitiveStr::Ascii("obsniveling"),
        dictgen::InsensitiveStr::Ascii("obsnivelling"),
        dictgen::InsensitiveStr::Ascii("orkeled"),
        dictgen::InsensitiveStr::Ascii("orkeling"),
        dictgen::InsensitiveStr::Ascii("orkelled"),
        dictgen::InsensitiveStr::Ascii("orkelling"),
        dictgen::InsensitiveStr::Ascii("owplough"),
        dictgen::InsensitiveStr::Ascii("owploughs"),
        dictgen::InsensitiveStr::Ascii("owplow"),
        dictgen::InsensitiveStr::Ascii("owplows"),
        dictgen::InsensitiveStr::Ascii("owshed"),
        dictgen::InsensitiveStr::Ascii("owshoed"),
        dictgen::InsensitiveStr::Ascii("uffcolored"),
        dictgen::InsensitiveStr::Ascii("uffcoloured"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SNIVELED_18043727065802009410)],
        &[(0b00001, &ENTRY_SNIVELER_2280951551750996939)],
        &[(0b00001, &ENTRY_SNIVELERS_1542130229737259691)],
        &[(0b00001, &ENTRY_SNIVELING_7895796690459397538)],
        &[(0b00001, &ENTRY_SNIVELINGS_9742658510844280475)],
        &[(0b11010, &ENTRY_SNIVELED_18043727065802009410)],
        &[(0b11010, &ENTRY_SNIVELER_2280951551750996939)],
        &[(0b11010, &ENTRY_SNIVELERS_1542130229737259691)],
        &[(0b11010, &ENTRY_SNIVELING_7895796690459397538)],
        &[(0b11010, &ENTRY_SNIVELINGS_9742658510844280475)],
        &[(0b00001, &ENTRY_SNOBSNIVELING_2460193893793738982)],
        &[(0b11010, &ENTRY_SNOBSNIVELING_2460193893793738982)],
        &[(0b01001, &ENTRY_SNORKELED_17424014433959603672)],
        &[(0b01001, &ENTRY_SNORKELING_16143785804725093743)],
        &[(0b11010, &ENTRY_SNORKELED_17424014433959603672)],
        &[(0b11010, &ENTRY_SNORKELING_16143785804725093743)],
        &[(0b11010, &ENTRY_SNOWPLOW_3516237879610950869)],
        &[(0b11010, &ENTRY_SNOWPLOWS_1272088169272096167)],
        &[(0b01001, &ENTRY_SNOWPLOW_3516237879610950869)],
        &[(0b01001, &ENTRY_SNOWPLOWS_1272088169272096167)],
        &[(0b00001, &ENTRY_SNOWSHED_9651694831654123091)],
        &[(0b11010, &ENTRY_SNOWSHED_9651694831654123091)],
        &[(0b00001, &ENTRY_SNUFFCOLORED_10869337707924680144)],
        &[(0b11010, &ENTRY_SNUFFCOLORED_10869337707924680144)],
    ],
    range: 6..=12,
};

static VARS_SM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SM_CHILDREN),
    value: None,
};

pub static VARS_SM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idge"),
        dictgen::InsensitiveStr::Ascii("idges"),
        dictgen::InsensitiveStr::Ascii("older"),
        dictgen::InsensitiveStr::Ascii("oldered"),
        dictgen::InsensitiveStr::Ascii("oldering"),
        dictgen::InsensitiveStr::Ascii("olders"),
    ],
    values: &[
        &[(0b01001, &ENTRY_SMIDGEN_2401448801521207321)],
        &[(0b01001, &ENTRY_SMIDGENS_5145607016666105466)],
        &[(0b01001, &ENTRY_SMOLDER_18276687156827940484)],
        &[(0b01001, &ENTRY_SMOLDERED_12136966478992754787)],
        &[(0b01001, &ENTRY_SMOLDERING_17971483108204682038)],
        &[(0b01001, &ENTRY_SMOLDERS_16317626305242093646)],
    ],
    range: 4..=8,
};

static VARS_SL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SL_CHILDREN),
    value: None,
};

pub static VARS_SL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("avicise"),
        dictgen::InsensitiveStr::Ascii("avicises"),
        dictgen::InsensitiveStr::Ascii("avicize"),
        dictgen::InsensitiveStr::Ascii("avicizes"),
        dictgen::InsensitiveStr::Ascii("avisation"),
        dictgen::InsensitiveStr::Ascii("avisations"),
        dictgen::InsensitiveStr::Ascii("avise"),
        dictgen::InsensitiveStr::Ascii("avises"),
        dictgen::InsensitiveStr::Ascii("avization"),
        dictgen::InsensitiveStr::Ascii("avizations"),
        dictgen::InsensitiveStr::Ascii("avize"),
        dictgen::InsensitiveStr::Ascii("avizes"),
        dictgen::InsensitiveStr::Ascii("avonicise"),
        dictgen::InsensitiveStr::Ascii("avonicised"),
        dictgen::InsensitiveStr::Ascii("avonicises"),
        dictgen::InsensitiveStr::Ascii("avonicising"),
        dictgen::InsensitiveStr::Ascii("avonicize"),
        dictgen::InsensitiveStr::Ascii("avonicized"),
        dictgen::InsensitiveStr::Ascii("avonicizes"),
        dictgen::InsensitiveStr::Ascii("avonicizing"),
        dictgen::InsensitiveStr::Ascii("avonise"),
        dictgen::InsensitiveStr::Ascii("avonised"),
        dictgen::InsensitiveStr::Ascii("avonises"),
        dictgen::InsensitiveStr::Ascii("avonising"),
        dictgen::InsensitiveStr::Ascii("avonize"),
        dictgen::InsensitiveStr::Ascii("avonized"),
        dictgen::InsensitiveStr::Ascii("avonizes"),
        dictgen::InsensitiveStr::Ascii("avonizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("enderise"),
        dictgen::InsensitiveStr::Ascii("enderised"),
        dictgen::InsensitiveStr::Ascii("enderises"),
        dictgen::InsensitiveStr::Ascii("enderising"),
        dictgen::InsensitiveStr::Ascii("enderize"),
        dictgen::InsensitiveStr::Ascii("enderized"),
        dictgen::InsensitiveStr::Ascii("enderizes"),
        dictgen::InsensitiveStr::Ascii("enderizing"),
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("iest"),
        dictgen::InsensitiveStr::Ascii("ily"),
        dictgen::InsensitiveStr::Ascii("oganise"),
        dictgen::InsensitiveStr::Ascii("oganised"),
        dictgen::InsensitiveStr::Ascii("oganises"),
        dictgen::InsensitiveStr::Ascii("oganising"),
        dictgen::InsensitiveStr::Ascii("oganisings"),
        dictgen::InsensitiveStr::Ascii("oganize"),
        dictgen::InsensitiveStr::Ascii("oganized"),
        dictgen::InsensitiveStr::Ascii("oganizes"),
        dictgen::InsensitiveStr::Ascii("oganizing"),
        dictgen::InsensitiveStr::Ascii("oganizings"),
        dictgen::InsensitiveStr::Ascii("uggardise"),
        dictgen::InsensitiveStr::Ascii("uggardised"),
        dictgen::InsensitiveStr::Ascii("uggardises"),
        dictgen::InsensitiveStr::Ascii("uggardising"),
        dictgen::InsensitiveStr::Ascii("uggardize"),
        dictgen::InsensitiveStr::Ascii("uggardized"),
        dictgen::InsensitiveStr::Ascii("uggardizes"),
        dictgen::InsensitiveStr::Ascii("uggardizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SLE_604254537387974736)],
        &[(0b10010, &ENTRY_SLAVICIZE_9761827906822368262)],
        &[(0b10010, &ENTRY_SLAVICIZES_4846190454350142805)],
        &[(0b01001, &ENTRY_SLAVICIZE_9761827906822368262)],
        &[(0b01001, &ENTRY_SLAVICIZES_4846190454350142805)],
        &[(0b10010, &ENTRY_SLAVIZATION_13156747122292743639)],
        &[(0b10010, &ENTRY_SLAVIZATIONS_7586698825967104620)],
        &[(0b10010, &ENTRY_SLAVIZE_12144031893570739805)],
        &[(0b10010, &ENTRY_SLAVIZES_13267642890664123364)],
        &[(0b01001, &ENTRY_SLAVIZATION_13156747122292743639)],
        &[(0b01001, &ENTRY_SLAVIZATIONS_7586698825967104620)],
        &[(0b01001, &ENTRY_SLAVIZE_12144031893570739805)],
        &[(0b01001, &ENTRY_SLAVIZES_13267642890664123364)],
        &[(0b10010, &ENTRY_SLAVONICIZE_7075894969271900254)],
        &[(0b10010, &ENTRY_SLAVONICIZED_4556769722338287574)],
        &[(0b10010, &ENTRY_SLAVONICIZES_14342428999925133169)],
        &[(0b10010, &ENTRY_SLAVONICIZING_9470034451915609982)],
        &[(0b01001, &ENTRY_SLAVONICIZE_7075894969271900254)],
        &[(0b01001, &ENTRY_SLAVONICIZED_4556769722338287574)],
        &[(0b01001, &ENTRY_SLAVONICIZES_14342428999925133169)],
        &[(0b01001, &ENTRY_SLAVONICIZING_9470034451915609982)],
        &[(0b10010, &ENTRY_SLAVONIZE_10938982615068583928)],
        &[(0b10010, &ENTRY_SLAVONIZED_5503323155898817895)],
        &[(0b10010, &ENTRY_SLAVONIZES_1966145414926838006)],
        &[(0b10010, &ENTRY_SLAVONIZING_13559715578718041723)],
        &[(0b01001, &ENTRY_SLAVONIZE_10938982615068583928)],
        &[(0b01001, &ENTRY_SLAVONIZED_5503323155898817895)],
        &[(0b01001, &ENTRY_SLAVONIZES_1966145414926838006)],
        &[(0b01001, &ENTRY_SLAVONIZING_13559715578718041723)],
        &[(0b00001, &ENTRY_SLE_604254537387974736)],
        &[(0b10010, &ENTRY_SLENDERIZE_8515172316335563483)],
        &[(0b10010, &ENTRY_SLENDERIZED_7959376560880260414)],
        &[(0b10010, &ENTRY_SLENDERIZES_16779186498929500242)],
        &[(0b10010, &ENTRY_SLENDERIZING_13145961426039938518)],
        &[(0b01001, &ENTRY_SLENDERIZE_8515172316335563483)],
        &[(0b01001, &ENTRY_SLENDERIZED_7959376560880260414)],
        &[(0b01001, &ENTRY_SLENDERIZES_16779186498929500242)],
        &[(0b01001, &ENTRY_SLENDERIZING_13145961426039938518)],
        &[(0b00001, &ENTRY_SLIER_17739050457284539156)],
        &[(0b00001, &ENTRY_SLIEST_8783540132102900417)],
        &[(0b10011, &ENTRY_SLYLY_3141561617868439191)],
        &[(0b10010, &ENTRY_SLOGANIZE_5861449365002655564)],
        &[(0b10010, &ENTRY_SLOGANIZED_17548782227632388322)],
        &[(0b10010, &ENTRY_SLOGANIZES_2095570969989848762)],
        &[(0b10010, &ENTRY_SLOGANIZING_5351599027342186318)],
        &[(0b10010, &ENTRY_SLOGANIZINGS_8139231964165892944)],
        &[(0b01001, &ENTRY_SLOGANIZE_5861449365002655564)],
        &[(0b01001, &ENTRY_SLOGANIZED_17548782227632388322)],
        &[(0b01001, &ENTRY_SLOGANIZES_2095570969989848762)],
        &[(0b01001, &ENTRY_SLOGANIZING_5351599027342186318)],
        &[(0b01001, &ENTRY_SLOGANIZINGS_8139231964165892944)],
        &[(0b10010, &ENTRY_SLUGGARDIZE_15179917084453478031)],
        &[(0b10010, &ENTRY_SLUGGARDIZED_7217161359617146286)],
        &[(0b10010, &ENTRY_SLUGGARDIZES_2193421694271241177)],
        &[(0b10010, &ENTRY_SLUGGARDIZING_3263004984707806773)],
        &[(0b01001, &ENTRY_SLUGGARDIZE_15179917084453478031)],
        &[(0b01001, &ENTRY_SLUGGARDIZED_7217161359617146286)],
        &[(0b01001, &ENTRY_SLUGGARDIZES_2193421694271241177)],
        &[(0b01001, &ENTRY_SLUGGARDIZING_3263004984707806773)],
    ],
    range: 1..=11,
};

static VARS_SK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SK_CHILDREN),
    value: None,
};

pub static VARS_SK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eer"),
        dictgen::InsensitiveStr::Ascii("eletonisation"),
        dictgen::InsensitiveStr::Ascii("eletonisations"),
        dictgen::InsensitiveStr::Ascii("eletonise"),
        dictgen::InsensitiveStr::Ascii("eletonised"),
        dictgen::InsensitiveStr::Ascii("eletoniser"),
        dictgen::InsensitiveStr::Ascii("eletonisers"),
        dictgen::InsensitiveStr::Ascii("eletonises"),
        dictgen::InsensitiveStr::Ascii("eletonising"),
        dictgen::InsensitiveStr::Ascii("eletonization"),
        dictgen::InsensitiveStr::Ascii("eletonizations"),
        dictgen::InsensitiveStr::Ascii("eletonize"),
        dictgen::InsensitiveStr::Ascii("eletonized"),
        dictgen::InsensitiveStr::Ascii("eletonizer"),
        dictgen::InsensitiveStr::Ascii("eletonizers"),
        dictgen::InsensitiveStr::Ascii("eletonizes"),
        dictgen::InsensitiveStr::Ascii("eletonizing"),
        dictgen::InsensitiveStr::Ascii("eptic"),
        dictgen::InsensitiveStr::Ascii("eptical"),
        dictgen::InsensitiveStr::Ascii("epticaler"),
        dictgen::InsensitiveStr::Ascii("epticalest"),
        dictgen::InsensitiveStr::Ascii("eptically"),
        dictgen::InsensitiveStr::Ascii("epticer"),
        dictgen::InsensitiveStr::Ascii("epticest"),
        dictgen::InsensitiveStr::Ascii("epticise"),
        dictgen::InsensitiveStr::Ascii("epticises"),
        dictgen::InsensitiveStr::Ascii("epticism"),
        dictgen::InsensitiveStr::Ascii("epticisms"),
        dictgen::InsensitiveStr::Ascii("epticize"),
        dictgen::InsensitiveStr::Ascii("epticizes"),
        dictgen::InsensitiveStr::Ascii("eptics"),
        dictgen::InsensitiveStr::Ascii("ere"),
        dictgen::InsensitiveStr::Ascii("ilful"),
        dictgen::InsensitiveStr::Ascii("ilfully"),
        dictgen::InsensitiveStr::Ascii("ilfulness"),
        dictgen::InsensitiveStr::Ascii("illful"),
        dictgen::InsensitiveStr::Ascii("illfully"),
        dictgen::InsensitiveStr::Ascii("illfulness"),
        dictgen::InsensitiveStr::Ascii("yer"),
        dictgen::InsensitiveStr::Ascii("yers"),
        dictgen::InsensitiveStr::Ascii("yre"),
        dictgen::InsensitiveStr::Ascii("yres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SKEER_1740844404740176995)],
        &[(0b10010, &ENTRY_SKELETONIZATION_15176281057395840132)],
        &[(0b10010, &ENTRY_SKELETONIZATIONS_2952274931614855136)],
        &[(0b10010, &ENTRY_SKELETONIZE_8844202107033296437)],
        &[(0b10010, &ENTRY_SKELETONIZED_5834618125945052179)],
        &[(0b10010, &ENTRY_SKELETONIZER_1742743360367189615)],
        &[(0b10010, &ENTRY_SKELETONIZERS_11894178897960069861)],
        &[(0b10010, &ENTRY_SKELETONIZES_5920383959770274591)],
        &[(0b10010, &ENTRY_SKELETONIZING_1830503588720890182)],
        &[(0b01001, &ENTRY_SKELETONIZATION_15176281057395840132)],
        &[(0b01001, &ENTRY_SKELETONIZATIONS_2952274931614855136)],
        &[(0b01001, &ENTRY_SKELETONIZE_8844202107033296437)],
        &[(0b01001, &ENTRY_SKELETONIZED_5834618125945052179)],
        &[(0b01001, &ENTRY_SKELETONIZER_1742743360367189615)],
        &[(0b01001, &ENTRY_SKELETONIZERS_11894178897960069861)],
        &[(0b01001, &ENTRY_SKELETONIZES_5920383959770274591)],
        &[(0b01001, &ENTRY_SKELETONIZING_1830503588720890182)],
        &[(0b11001, &ENTRY_SKEPTIC_9366141399207033866)],
        &[(0b11001, &ENTRY_SKEPTICAL_7567920697289876244)],
        &[(0b11001, &ENTRY_SKEPTICALER_3504236392319734868)],
        &[(0b11001, &ENTRY_SKEPTICALEST_1822492830960306797)],
        &[(0b11001, &ENTRY_SKEPTICALLY_15015708074924057237)],
        &[(0b11001, &ENTRY_SKEPTICER_2654895074232389427)],
        &[(0b11001, &ENTRY_SKEPTICEST_13124338123587490640)],
        &[(0b10010, &ENTRY_SKEPTICIZE_233558052004506284)],
        &[(0b10010, &ENTRY_SKEPTICIZES_1621712858377146669)],
        &[(0b11001, &ENTRY_SKEPTICISM_16324594783111490926)],
        &[(0b11001, &ENTRY_SKEPTICISMS_9470460390001384677)],
        &[(0b01001, &ENTRY_SKEPTICIZE_233558052004506284)],
        &[(0b01001, &ENTRY_SKEPTICIZES_1621712858377146669)],
        &[(0b11001, &ENTRY_SKEPTICS_13432613087589375835)],
        &[(0b11010, &ENTRY_SKEER_1740844404740176995)],
        &[(0b11010, &ENTRY_SKILLFUL_8097707939529755598)],
        &[(0b11010, &ENTRY_SKILLFULLY_17336988368413616611)],
        &[(0b11010, &ENTRY_SKILLFULNESS_10066018729560545262)],
        &[(0b10001, &ENTRY_SKILLFUL_8097707939529755598)],
        &[(0b10001, &ENTRY_SKILLFULLY_17336988368413616611)],
        &[(0b10001, &ENTRY_SKILLFULNESS_10066018729560545262)],
        &[(0b00001, &ENTRY_SKYER_15996106329790412626)],
        &[(0b00001, &ENTRY_SKYERS_744502748846351073)],
        &[(0b11010, &ENTRY_SKYER_15996106329790412626)],
        &[(0b11010, &ENTRY_SKYERS_744502748846351073)],
    ],
    range: 3..=14,
};

static VARS_SI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SI_CHILDREN),
    value: None,
};

static VARS_SI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SIA_NODE),
    None,
    None,
    Some(&VARS_SID_NODE),
    None,
    None,
    Some(&VARS_SIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_SIL_NODE),
    Some(&VARS_SIM_NODE),
    Some(&VARS_SIN_NODE),
    None,
    None,
    None,
    Some(&VARS_SIR_NODE),
    Some(&VARS_SIS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SIZ_NODE),
];

static VARS_SIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIZ_CHILDREN),
    value: None,
};

pub static VARS_SIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ably"),
        dictgen::InsensitiveStr::Ascii("eably"),
        dictgen::InsensitiveStr::Ascii("el"),
    ],
    values: &[
        &[(0b01001, &ENTRY_SIZABLY_1222403150260882875)],
        &[(0b10011, &ENTRY_SIZABLY_1222403150260882875)],
        &[(0b01001, &ENTRY_SIZEL_3837879429176540015)],
    ],
    range: 2..=5,
};

static VARS_SIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIS_CHILDREN),
    value: None,
};

pub static VARS_SIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("el"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("tern"),
        dictgen::InsensitiveStr::Ascii("tren"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SIZEL_3837879429176540015)],
        &[(0b10010, &ENTRY_SISTERIZE_6948431239930971695)],
        &[(0b10010, &ENTRY_SISTERIZES_17019596055143071237)],
        &[(0b01001, &ENTRY_SISTERIZE_6948431239930971695)],
        &[(0b01001, &ENTRY_SISTERIZES_17019596055143071237)],
        &[(0b00001, &ENTRY_SISTERN_11311516313136487178)],
        &[(0b11010, &ENTRY_SISTERN_11311516313136487178)],
    ],
    range: 2..=7,
};

static VARS_SIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIR_CHILDREN),
    value: None,
};

pub static VARS_SIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enised"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enising"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enized"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("enizing"),
        dictgen::InsensitiveStr::Ascii("up"),
        dictgen::InsensitiveStr::Ascii("ups"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SIRENIZE_4666184332714606459)],
        &[(0b10010, &ENTRY_SIRENIZED_2574909956439544564)],
        &[(0b10010, &ENTRY_SIRENIZES_16814257006036530236)],
        &[(0b10010, &ENTRY_SIRENIZING_6540711504301955920)],
        &[(0b01001, &ENTRY_SIRENIZE_4666184332714606459)],
        &[(0b01001, &ENTRY_SIRENIZED_2574909956439544564)],
        &[(0b01001, &ENTRY_SIRENIZES_16814257006036530236)],
        &[(0b01001, &ENTRY_SIRENIZING_6540711504301955920)],
        &[(0b00001, &ENTRY_SYRUP_13414625495147716891)],
        &[(0b00001, &ENTRY_SYRUPS_11767508909122317278)],
    ],
    range: 2..=7,
};

static VARS_SIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIN_CHILDREN),
    value: None,
};

pub static VARS_SIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("gularisation"),
        dictgen::InsensitiveStr::Ascii("gularisations"),
        dictgen::InsensitiveStr::Ascii("gularise"),
        dictgen::InsensitiveStr::Ascii("gularised"),
        dictgen::InsensitiveStr::Ascii("gularises"),
        dictgen::InsensitiveStr::Ascii("gularising"),
        dictgen::InsensitiveStr::Ascii("gularization"),
        dictgen::InsensitiveStr::Ascii("gularizations"),
        dictgen::InsensitiveStr::Ascii("gularize"),
        dictgen::InsensitiveStr::Ascii("gularized"),
        dictgen::InsensitiveStr::Ascii("gularizes"),
        dictgen::InsensitiveStr::Ascii("gularizing"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SINE_3419162536566868807)],
        &[(0b00001, &ENTRY_SINE_3419162536566868807)],
        &[(0b10010, &ENTRY_SINGULARIZATION_4933930872001149831)],
        &[(0b10010, &ENTRY_SINGULARIZATIONS_4989978119532359980)],
        &[(0b10010, &ENTRY_SINGULARIZE_12969745354704340141)],
        &[(0b10010, &ENTRY_SINGULARIZED_14288632382502472280)],
        &[(0b10010, &ENTRY_SINGULARIZES_5332763602386440207)],
        &[(0b10010, &ENTRY_SINGULARIZING_5008211603587521125)],
        &[(0b01001, &ENTRY_SINGULARIZATION_4933930872001149831)],
        &[(0b01001, &ENTRY_SINGULARIZATIONS_4989978119532359980)],
        &[(0b01001, &ENTRY_SINGULARIZE_12969745354704340141)],
        &[(0b01001, &ENTRY_SINGULARIZED_14288632382502472280)],
        &[(0b01001, &ENTRY_SINGULARIZES_5332763602386440207)],
        &[(0b01001, &ENTRY_SINGULARIZING_5008211603587521125)],
        &[(0b10010, &ENTRY_SINICIZE_5519781244176228688)],
        &[(0b10010, &ENTRY_SINICIZED_1170587988011526807)],
        &[(0b10010, &ENTRY_SINICIZES_16916655538728896626)],
        &[(0b10010, &ENTRY_SINICIZING_12485406975219661792)],
        &[(0b01001, &ENTRY_SINICIZE_5519781244176228688)],
        &[(0b01001, &ENTRY_SINICIZED_1170587988011526807)],
        &[(0b01001, &ENTRY_SINICIZES_16916655538728896626)],
        &[(0b01001, &ENTRY_SINICIZING_12485406975219661792)],
    ],
    range: 1..=13,
};

static VARS_SIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIM_CHILDREN),
    value: None,
};

pub static VARS_SIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilarise"),
        dictgen::InsensitiveStr::Ascii("ilarises"),
        dictgen::InsensitiveStr::Ascii("ilarize"),
        dictgen::InsensitiveStr::Ascii("ilarizes"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SIMILARIZE_2700808984999286713)],
        &[(0b10010, &ENTRY_SIMILARIZES_304454380831943452)],
        &[(0b01001, &ENTRY_SIMILARIZE_2700808984999286713)],
        &[(0b01001, &ENTRY_SIMILARIZES_304454380831943452)],
        &[(0b10010, &ENTRY_SIMILIZE_5812929733131056435)],
        &[(0b10010, &ENTRY_SIMILIZED_10847342221820288097)],
        &[(0b10010, &ENTRY_SIMILIZES_8302279519436698760)],
        &[(0b10010, &ENTRY_SIMILIZING_1862547745562599944)],
        &[(0b01001, &ENTRY_SIMILIZE_5812929733131056435)],
        &[(0b01001, &ENTRY_SIMILIZED_10847342221820288097)],
        &[(0b01001, &ENTRY_SIMILIZES_8302279519436698760)],
        &[(0b01001, &ENTRY_SIMILIZING_1862547745562599944)],
        &[(0b10010, &ENTRY_SIMONIZE_353967938486861116)],
        &[(0b01001, &ENTRY_SIMONIZE_353967938486861116)],
    ],
    range: 5..=8,
};

static VARS_SIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIL_CHILDREN),
    value: None,
};

pub static VARS_SIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("icatisation"),
        dictgen::InsensitiveStr::Ascii("icatisations"),
        dictgen::InsensitiveStr::Ascii("icatization"),
        dictgen::InsensitiveStr::Ascii("icatizations"),
        dictgen::InsensitiveStr::Ascii("icidise"),
        dictgen::InsensitiveStr::Ascii("icidises"),
        dictgen::InsensitiveStr::Ascii("icidize"),
        dictgen::InsensitiveStr::Ascii("icidizes"),
        dictgen::InsensitiveStr::Ascii("iconise"),
        dictgen::InsensitiveStr::Ascii("iconises"),
        dictgen::InsensitiveStr::Ascii("iconize"),
        dictgen::InsensitiveStr::Ascii("iconizes"),
        dictgen::InsensitiveStr::Ascii("iculae"),
        dictgen::InsensitiveStr::Ascii("icule"),
        dictgen::InsensitiveStr::Ascii("iquae"),
        dictgen::InsensitiveStr::Ascii("ique"),
        dictgen::InsensitiveStr::Ascii("oed"),
        dictgen::InsensitiveStr::Ascii("verise"),
        dictgen::InsensitiveStr::Ascii("verised"),
        dictgen::InsensitiveStr::Ascii("veriser"),
        dictgen::InsensitiveStr::Ascii("verisers"),
        dictgen::InsensitiveStr::Ascii("verises"),
        dictgen::InsensitiveStr::Ascii("verising"),
        dictgen::InsensitiveStr::Ascii("verize"),
        dictgen::InsensitiveStr::Ascii("verized"),
        dictgen::InsensitiveStr::Ascii("verizer"),
        dictgen::InsensitiveStr::Ascii("verizers"),
        dictgen::InsensitiveStr::Ascii("verizes"),
        dictgen::InsensitiveStr::Ascii("verizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SILED_10789450856636085272)],
        &[(0b10010, &ENTRY_SILICATIZATION_15183159520715497593)],
        &[(0b10010, &ENTRY_SILICATIZATIONS_12311801766905293588)],
        &[(0b01001, &ENTRY_SILICATIZATION_15183159520715497593)],
        &[(0b01001, &ENTRY_SILICATIZATIONS_12311801766905293588)],
        &[(0b10010, &ENTRY_SILICIDIZE_7437759950119638805)],
        &[(0b10010, &ENTRY_SILICIDIZES_5809599080861161027)],
        &[(0b01001, &ENTRY_SILICIDIZE_7437759950119638805)],
        &[(0b01001, &ENTRY_SILICIDIZES_5809599080861161027)],
        &[(0b10010, &ENTRY_SILICONIZE_13299465442579992202)],
        &[(0b10010, &ENTRY_SILICONIZES_14042775956262597692)],
        &[(0b01001, &ENTRY_SILICONIZE_13299465442579992202)],
        &[(0b01001, &ENTRY_SILICONIZES_14042775956262597692)],
        &[(0b11010, &ENTRY_SILICULE_16607190405791216240)],
        &[(0b00001, &ENTRY_SILICULE_16607190405791216240)],
        &[(0b11010, &ENTRY_SILIQUE_350570384784907901)],
        &[(0b00001, &ENTRY_SILIQUE_350570384784907901)],
        &[(0b11010, &ENTRY_SILED_10789450856636085272)],
        &[(0b10010, &ENTRY_SILVERIZE_1532148002770872366)],
        &[(0b10010, &ENTRY_SILVERIZED_3373734626849304080)],
        &[(0b10010, &ENTRY_SILVERIZER_15985635737519372213)],
        &[(0b10010, &ENTRY_SILVERIZERS_3216971382949916106)],
        &[(0b10010, &ENTRY_SILVERIZES_15646884568196086232)],
        &[(0b10010, &ENTRY_SILVERIZING_2034359189517396764)],
        &[(0b01001, &ENTRY_SILVERIZE_1532148002770872366)],
        &[(0b01001, &ENTRY_SILVERIZED_3373734626849304080)],
        &[(0b01001, &ENTRY_SILVERIZER_15985635737519372213)],
        &[(0b01001, &ENTRY_SILVERIZERS_3216971382949916106)],
        &[(0b01001, &ENTRY_SILVERIZES_15646884568196086232)],
        &[(0b01001, &ENTRY_SILVERIZING_2034359189517396764)],
    ],
    range: 2..=12,
};

static VARS_SIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIG_CHILDREN),
    value: None,
};

pub static VARS_SIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("naled"),
        dictgen::InsensitiveStr::Ascii("naler"),
        dictgen::InsensitiveStr::Ascii("nalers"),
        dictgen::InsensitiveStr::Ascii("naling"),
        dictgen::InsensitiveStr::Ascii("nalisation"),
        dictgen::InsensitiveStr::Ascii("nalise"),
        dictgen::InsensitiveStr::Ascii("nalised"),
        dictgen::InsensitiveStr::Ascii("nalises"),
        dictgen::InsensitiveStr::Ascii("nalising"),
        dictgen::InsensitiveStr::Ascii("nalization"),
        dictgen::InsensitiveStr::Ascii("nalize"),
        dictgen::InsensitiveStr::Ascii("nalized"),
        dictgen::InsensitiveStr::Ascii("nalizes"),
        dictgen::InsensitiveStr::Ascii("nalizing"),
        dictgen::InsensitiveStr::Ascii("nalled"),
        dictgen::InsensitiveStr::Ascii("naller"),
        dictgen::InsensitiveStr::Ascii("nallers"),
        dictgen::InsensitiveStr::Ascii("nalling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SIGNALED_4517098988465661597)],
        &[(0b00001, &ENTRY_SIGNALER_11540498906832061128)],
        &[(0b00001, &ENTRY_SIGNALERS_8816754826640457370)],
        &[(0b00001, &ENTRY_SIGNALING_38367410174135288)],
        &[(0b10010, &ENTRY_SIGNALIZATION_6300811578722786643)],
        &[(0b10010, &ENTRY_SIGNALIZE_15445299234874331775)],
        &[(0b10010, &ENTRY_SIGNALIZED_1328658457279077123)],
        &[(0b10010, &ENTRY_SIGNALIZES_15183847864880876512)],
        &[(0b10010, &ENTRY_SIGNALIZING_14031692614622999963)],
        &[(0b01001, &ENTRY_SIGNALIZATION_6300811578722786643)],
        &[(0b01001, &ENTRY_SIGNALIZE_15445299234874331775)],
        &[(0b01001, &ENTRY_SIGNALIZED_1328658457279077123)],
        &[(0b01001, &ENTRY_SIGNALIZES_15183847864880876512)],
        &[(0b01001, &ENTRY_SIGNALIZING_14031692614622999963)],
        &[(0b11010, &ENTRY_SIGNALED_4517098988465661597)],
        &[(0b11010, &ENTRY_SIGNALER_11540498906832061128)],
        &[(0b11010, &ENTRY_SIGNALERS_8816754826640457370)],
        &[(0b11010, &ENTRY_SIGNALING_38367410174135288)],
    ],
    range: 5..=10,
};

static VARS_SID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SID_CHILDREN),
    value: None,
};

pub static VARS_SID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erealise"),
        dictgen::InsensitiveStr::Ascii("erealises"),
        dictgen::InsensitiveStr::Ascii("erealize"),
        dictgen::InsensitiveStr::Ascii("erealizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SIDEREALIZE_13138990443604086580)],
        &[(0b10010, &ENTRY_SIDEREALIZES_5077853180450618510)],
        &[(0b01001, &ENTRY_SIDEREALIZE_13138990443604086580)],
        &[(0b01001, &ENTRY_SIDEREALIZES_5077853180450618510)],
    ],
    range: 8..=9,
};

static VARS_SIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SIA_CHILDREN),
    value: None,
};

pub static VARS_SIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lorrhea"),
        dictgen::InsensitiveStr::Ascii("lorrhoea"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SIALORRHEA_6484075731495212593)],
        &[(0b11010, &ENTRY_SIALORRHEA_6484075731495212593)],
    ],
    range: 7..=8,
};

static VARS_SH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SH_CHILDREN),
    value: None,
};

pub static VARS_SH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aikh"),
        dictgen::InsensitiveStr::Ascii("aikhs"),
        dictgen::InsensitiveStr::Ascii("akespearise"),
        dictgen::InsensitiveStr::Ascii("akespearises"),
        dictgen::InsensitiveStr::Ascii("akespearize"),
        dictgen::InsensitiveStr::Ascii("akespearizes"),
        dictgen::InsensitiveStr::Ascii("epherdise"),
        dictgen::InsensitiveStr::Ascii("epherdises"),
        dictgen::InsensitiveStr::Ascii("epherdize"),
        dictgen::InsensitiveStr::Ascii("epherdizes"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("erardise"),
        dictgen::InsensitiveStr::Ascii("erardised"),
        dictgen::InsensitiveStr::Ascii("erardises"),
        dictgen::InsensitiveStr::Ascii("erardising"),
        dictgen::InsensitiveStr::Ascii("erardize"),
        dictgen::InsensitiveStr::Ascii("erardized"),
        dictgen::InsensitiveStr::Ascii("erardizes"),
        dictgen::InsensitiveStr::Ascii("erardizing"),
        dictgen::InsensitiveStr::Ascii("ere"),
        dictgen::InsensitiveStr::Ascii("intoise"),
        dictgen::InsensitiveStr::Ascii("intoises"),
        dictgen::InsensitiveStr::Ascii("intoize"),
        dictgen::InsensitiveStr::Ascii("intoizes"),
        dictgen::InsensitiveStr::Ascii("kodaer"),
        dictgen::InsensitiveStr::Ascii("koder"),
        dictgen::InsensitiveStr::Ascii("oer"),
        dictgen::InsensitiveStr::Ascii("oveled"),
        dictgen::InsensitiveStr::Ascii("oveler"),
        dictgen::InsensitiveStr::Ascii("ovelers"),
        dictgen::InsensitiveStr::Ascii("oveling"),
        dictgen::InsensitiveStr::Ascii("ovelled"),
        dictgen::InsensitiveStr::Ascii("oveller"),
        dictgen::InsensitiveStr::Ascii("ovellers"),
        dictgen::InsensitiveStr::Ascii("ovelling"),
        dictgen::InsensitiveStr::Ascii("ree"),
        dictgen::InsensitiveStr::Ascii("riveled"),
        dictgen::InsensitiveStr::Ascii("riveling"),
        dictgen::InsensitiveStr::Ascii("rivelled"),
        dictgen::InsensitiveStr::Ascii("rivelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SHEIKH_8983659288141972445)],
        &[(0b00001, &ENTRY_SHEIKHS_10762489381044075569)],
        &[(0b10010, &ENTRY_SHAKESPEARIZE_6066803341152707552)],
        &[(0b10010, &ENTRY_SHAKESPEARIZES_17778092510718324337)],
        &[(0b01001, &ENTRY_SHAKESPEARIZE_6066803341152707552)],
        &[(0b01001, &ENTRY_SHAKESPEARIZES_17778092510718324337)],
        &[(0b10010, &ENTRY_SHEPHERDIZE_9589644434591127897)],
        &[(0b10010, &ENTRY_SHEPHERDIZES_4618442149214601958)],
        &[(0b01001, &ENTRY_SHEPHERDIZE_9589644434591127897)],
        &[(0b01001, &ENTRY_SHEPHERDIZES_4618442149214601958)],
        &[(0b00001, &ENTRY_SHER_17217175326411018784)],
        &[(0b10010, &ENTRY_SHERARDIZE_16617170604726285533)],
        &[(0b10010, &ENTRY_SHERARDIZED_3013055586963630691)],
        &[(0b10010, &ENTRY_SHERARDIZES_5495265908461761242)],
        &[(0b10010, &ENTRY_SHERARDIZING_6141668254225889701)],
        &[(0b01001, &ENTRY_SHERARDIZE_16617170604726285533)],
        &[(0b01001, &ENTRY_SHERARDIZED_3013055586963630691)],
        &[(0b01001, &ENTRY_SHERARDIZES_5495265908461761242)],
        &[(0b01001, &ENTRY_SHERARDIZING_6141668254225889701)],
        &[(0b00001, &ENTRY_SHERE_8519598491987964057)],
        &[(0b10010, &ENTRY_SHINTOIZE_11809502309481638164)],
        &[(0b10010, &ENTRY_SHINTOIZES_7087800735292630340)],
        &[(0b01001, &ENTRY_SHINTOIZE_11809502309481638164)],
        &[(0b01001, &ENTRY_SHINTOIZES_7087800735292630340)],
        &[(0b11010, &ENTRY_SHKODER_5585881395862931532)],
        &[(0b00001, &ENTRY_SHKODER_5585881395862931532)],
        &[(0b11010, &ENTRY_SHER_17217175326411018784)],
        &[(0b00001, &ENTRY_SHOVELED_15062634087638291011)],
        &[(0b01001, &ENTRY_SHOVELER_7861570800291993508)],
        &[(0b01001, &ENTRY_SHOVELERS_2279935736385901824)],
        &[(0b00001, &ENTRY_SHOVELING_4658042570347509024)],
        &[(0b11010, &ENTRY_SHOVELED_15062634087638291011)],
        &[(0b11010, &ENTRY_SHOVELER_7861570800291993508)],
        &[(0b11010, &ENTRY_SHOVELERS_2279935736385901824)],
        &[(0b11010, &ENTRY_SHOVELING_4658042570347509024)],
        &[(0b11010, &ENTRY_SHERE_8519598491987964057)],
        &[(0b00001, &ENTRY_SHRIVELED_9173718681891056162)],
        &[(0b00001, &ENTRY_SHRIVELING_9001440579199169374)],
        &[(0b11010, &ENTRY_SHRIVELED_9173718681891056162)],
        &[(0b11010, &ENTRY_SHRIVELING_9001440579199169374)],
    ],
    range: 2..=12,
};

static VARS_SE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SE_CHILDREN),
    value: Some(&[
        (0b00001, &ENTRY_SE_15361672265999879694),
        (0b00001, &ENTRY_SE_2594869031866220942),
    ]),
};

static VARS_SE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SEB_NODE),
    Some(&VARS_SEC_NODE),
    None,
    Some(&VARS_SEE_NODE),
    None,
    None,
    None,
    Some(&VARS_SEI_NODE),
    None,
    None,
    Some(&VARS_SEL_NODE),
    Some(&VARS_SEM_NODE),
    Some(&VARS_SEN_NODE),
    None,
    Some(&VARS_SEP_NODE),
    Some(&VARS_SEQ_NODE),
    Some(&VARS_SER_NODE),
    None,
    Some(&VARS_SET_NODE),
    None,
    Some(&VARS_SEV_NODE),
    None,
    Some(&VARS_SEX_NODE),
    None,
    None,
];

static VARS_SEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEX_CHILDREN),
    value: None,
};

pub static VARS_SEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEXUALIZATION_598558153365374975)],
        &[(0b10010, &ENTRY_SEXUALIZATIONS_6419691977489313070)],
        &[(0b10010, &ENTRY_SEXUALIZE_9305579592150587788)],
        &[(0b10010, &ENTRY_SEXUALIZED_17516220740309805973)],
        &[(0b10010, &ENTRY_SEXUALIZES_14899097055849161352)],
        &[(0b10010, &ENTRY_SEXUALIZING_13168796826287121808)],
        &[(0b01001, &ENTRY_SEXUALIZATION_598558153365374975)],
        &[(0b01001, &ENTRY_SEXUALIZATIONS_6419691977489313070)],
        &[(0b01001, &ENTRY_SEXUALIZE_9305579592150587788)],
        &[(0b01001, &ENTRY_SEXUALIZED_17516220740309805973)],
        &[(0b01001, &ENTRY_SEXUALIZES_14899097055849161352)],
        &[(0b01001, &ENTRY_SEXUALIZING_13168796826287121808)],
    ],
    range: 6..=11,
};

static VARS_SEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEV_CHILDREN),
    value: None,
};

pub static VARS_SEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEVERALIZE_10314418645470673257)],
        &[(0b10010, &ENTRY_SEVERALIZES_10859120750647710400)],
        &[(0b01001, &ENTRY_SEVERALIZE_10314418645470673257)],
        &[(0b01001, &ENTRY_SEVERALIZES_10859120750647710400)],
        &[(0b10010, &ENTRY_SEVERIZATION_5132300365352798030)],
        &[(0b10010, &ENTRY_SEVERIZATIONS_14701963156627030317)],
        &[(0b10010, &ENTRY_SEVERIZE_17078342800840793427)],
        &[(0b10010, &ENTRY_SEVERIZES_3513402572065109149)],
        &[(0b01001, &ENTRY_SEVERIZATION_5132300365352798030)],
        &[(0b01001, &ENTRY_SEVERIZATIONS_14701963156627030317)],
        &[(0b01001, &ENTRY_SEVERIZE_17078342800840793427)],
        &[(0b01001, &ENTRY_SEVERIZES_3513402572065109149)],
    ],
    range: 5..=10,
};

static VARS_SET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SET_CHILDREN),
    value: None,
};

pub static VARS_SET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SETA_9673520022199067907)],
        &[(0b11010, &ENTRY_SETULE_8234529077451319159)],
        &[(0b00001, &ENTRY_SETULE_8234529077451319159)],
    ],
    range: 1..=4,
};

static VARS_SER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SER_CHILDREN),
    value: None,
};

static VARS_SER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_SERE_NODE),
    None,
    None,
    None,
    Some(&VARS_SERI_NODE),
    None,
    None,
    None,
    Some(&VARS_SERM_NODE),
    None,
    Some(&VARS_SERO_NODE),
    Some(&VARS_SERP_NODE),
    None,
    Some(&VARS_SERR_NODE),
    None,
    None,
    None,
    Some(&VARS_SERV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_SERV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERV_CHILDREN),
    value: None,
};

pub static VARS_SERV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERVILIZE_14834152406961369316)],
        &[(0b10010, &ENTRY_SERVILIZES_8276384829138801671)],
        &[(0b01001, &ENTRY_SERVILIZE_14834152406961369316)],
        &[(0b01001, &ENTRY_SERVILIZES_8276384829138801671)],
    ],
    range: 5..=6,
};

static VARS_SERR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERR_CHILDREN),
    value: None,
};

pub static VARS_SERR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SERRE_3180474638636958561)],
        &[(0b00001, &ENTRY_SERRE_3180474638636958561)],
    ],
    range: 1..=2,
};

static VARS_SERP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERP_CHILDREN),
    value: None,
};

pub static VARS_SERP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entinisation"),
        dictgen::InsensitiveStr::Ascii("entinisations"),
        dictgen::InsensitiveStr::Ascii("entinise"),
        dictgen::InsensitiveStr::Ascii("entinised"),
        dictgen::InsensitiveStr::Ascii("entinises"),
        dictgen::InsensitiveStr::Ascii("entinising"),
        dictgen::InsensitiveStr::Ascii("entinization"),
        dictgen::InsensitiveStr::Ascii("entinizations"),
        dictgen::InsensitiveStr::Ascii("entinize"),
        dictgen::InsensitiveStr::Ascii("entinized"),
        dictgen::InsensitiveStr::Ascii("entinizes"),
        dictgen::InsensitiveStr::Ascii("entinizing"),
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entised"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entising"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entized"),
        dictgen::InsensitiveStr::Ascii("entizes"),
        dictgen::InsensitiveStr::Ascii("entizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERPENTINIZATION_5560169582513450767)],
        &[(0b10010, &ENTRY_SERPENTINIZATIONS_18216025003407152452)],
        &[(0b10010, &ENTRY_SERPENTINIZE_9866240419191948775)],
        &[(0b10010, &ENTRY_SERPENTINIZED_7455002792008011952)],
        &[(0b10010, &ENTRY_SERPENTINIZES_8678826049205047091)],
        &[(0b10010, &ENTRY_SERPENTINIZING_9092366228143126428)],
        &[(0b01001, &ENTRY_SERPENTINIZATION_5560169582513450767)],
        &[(0b01001, &ENTRY_SERPENTINIZATIONS_18216025003407152452)],
        &[(0b01001, &ENTRY_SERPENTINIZE_9866240419191948775)],
        &[(0b01001, &ENTRY_SERPENTINIZED_7455002792008011952)],
        &[(0b01001, &ENTRY_SERPENTINIZES_8678826049205047091)],
        &[(0b01001, &ENTRY_SERPENTINIZING_9092366228143126428)],
        &[(0b10010, &ENTRY_SERPENTIZE_3384972221379685069)],
        &[(0b10010, &ENTRY_SERPENTIZED_4330573112091394638)],
        &[(0b10010, &ENTRY_SERPENTIZES_1625704616745057635)],
        &[(0b10010, &ENTRY_SERPENTIZING_9593903542078580092)],
        &[(0b01001, &ENTRY_SERPENTIZE_3384972221379685069)],
        &[(0b01001, &ENTRY_SERPENTIZED_4330573112091394638)],
        &[(0b01001, &ENTRY_SERPENTIZES_1625704616745057635)],
        &[(0b01001, &ENTRY_SERPENTIZING_9593903542078580092)],
    ],
    range: 6..=13,
};

static VARS_SERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERO_CHILDREN),
    value: None,
};

pub static VARS_SERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sae"),
        dictgen::InsensitiveStr::Ascii("se"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SEROSE_10469280893173049445)],
        &[(0b00001, &ENTRY_SEROSE_10469280893173049445)],
    ],
    range: 2..=3,
};

static VARS_SERM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERM_CHILDREN),
    value: None,
};

pub static VARS_SERM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onisers"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizers"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERMONIZE_237921077671914948)],
        &[(0b10010, &ENTRY_SERMONIZED_5857494441485850990)],
        &[(0b10010, &ENTRY_SERMONIZER_9999853450353383558)],
        &[(0b10010, &ENTRY_SERMONIZERS_10627211662032897475)],
        &[(0b10010, &ENTRY_SERMONIZES_8207614673919524386)],
        &[(0b10010, &ENTRY_SERMONIZING_9180710516114443189)],
        &[(0b01001, &ENTRY_SERMONIZE_237921077671914948)],
        &[(0b01001, &ENTRY_SERMONIZED_5857494441485850990)],
        &[(0b01001, &ENTRY_SERMONIZER_9999853450353383558)],
        &[(0b01001, &ENTRY_SERMONIZERS_10627211662032897475)],
        &[(0b01001, &ENTRY_SERMONIZES_8207614673919524386)],
        &[(0b01001, &ENTRY_SERMONIZING_9180710516114443189)],
    ],
    range: 5..=7,
};

static VARS_SERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERI_CHILDREN),
    value: None,
};

pub static VARS_SERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisability"),
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizability"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("citisation"),
        dictgen::InsensitiveStr::Ascii("citisations"),
        dictgen::InsensitiveStr::Ascii("citization"),
        dictgen::InsensitiveStr::Ascii("citizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERIALIZABILITY_7773982292760873044)],
        &[(0b10010, &ENTRY_SERIALIZABLE_1502323051817082784)],
        &[(0b10010, &ENTRY_SERIALIZATION_8026595017898253094)],
        &[(0b10010, &ENTRY_SERIALIZATIONS_16803629240691327375)],
        &[(0b10010, &ENTRY_SERIALIZE_14044145149155879461)],
        &[(0b10010, &ENTRY_SERIALIZED_1888364664748280784)],
        &[(0b10010, &ENTRY_SERIALIZES_15444051215059194506)],
        &[(0b10010, &ENTRY_SERIALIZING_13270926386983604461)],
        &[(0b01001, &ENTRY_SERIALIZABILITY_7773982292760873044)],
        &[(0b01001, &ENTRY_SERIALIZABLE_1502323051817082784)],
        &[(0b01001, &ENTRY_SERIALIZATION_8026595017898253094)],
        &[(0b01001, &ENTRY_SERIALIZATIONS_16803629240691327375)],
        &[(0b01001, &ENTRY_SERIALIZE_14044145149155879461)],
        &[(0b01001, &ENTRY_SERIALIZED_1888364664748280784)],
        &[(0b01001, &ENTRY_SERIALIZES_15444051215059194506)],
        &[(0b01001, &ENTRY_SERIALIZING_13270926386983604461)],
        &[(0b10010, &ENTRY_SERICITIZATION_8474782731600998020)],
        &[(0b10010, &ENTRY_SERICITIZATIONS_3976668030061776680)],
        &[(0b01001, &ENTRY_SERICITIZATION_8474782731600998020)],
        &[(0b01001, &ENTRY_SERICITIZATIONS_3976668030061776680)],
    ],
    range: 5..=11,
};

static VARS_SERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SERE_CHILDREN),
    value: None,
};

pub static VARS_SERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SERENIZE_13954843561052019043)],
        &[(0b10010, &ENTRY_SERENIZES_3953496351859270409)],
        &[(0b01001, &ENTRY_SERENIZE_13954843561052019043)],
        &[(0b01001, &ENTRY_SERENIZES_3953496351859270409)],
    ],
    range: 4..=5,
};

static VARS_SEQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEQ_CHILDREN),
    value: None,
};

pub static VARS_SEQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uentialise"),
        dictgen::InsensitiveStr::Ascii("uentialised"),
        dictgen::InsensitiveStr::Ascii("uentialises"),
        dictgen::InsensitiveStr::Ascii("uentialising"),
        dictgen::InsensitiveStr::Ascii("uentialize"),
        dictgen::InsensitiveStr::Ascii("uentialized"),
        dictgen::InsensitiveStr::Ascii("uentializes"),
        dictgen::InsensitiveStr::Ascii("uentializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEQUENTIALIZE_7687249845236795)],
        &[(0b10010, &ENTRY_SEQUENTIALIZED_13342886831978411557)],
        &[(0b10010, &ENTRY_SEQUENTIALIZES_903062549732554575)],
        &[(0b10010, &ENTRY_SEQUENTIALIZING_12526259102466204603)],
        &[(0b01001, &ENTRY_SEQUENTIALIZE_7687249845236795)],
        &[(0b01001, &ENTRY_SEQUENTIALIZED_13342886831978411557)],
        &[(0b01001, &ENTRY_SEQUENTIALIZES_903062549732554575)],
        &[(0b01001, &ENTRY_SEQUENTIALIZING_12526259102466204603)],
    ],
    range: 10..=12,
};

static VARS_SEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEP_CHILDREN),
    value: None,
};

pub static VARS_SEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("aledder"),
        dictgen::InsensitiveStr::Ascii("aleddest"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("alledder"),
        dictgen::InsensitiveStr::Ascii("alleddest"),
        dictgen::InsensitiveStr::Ascii("taemia"),
        dictgen::InsensitiveStr::Ascii("tembriser"),
        dictgen::InsensitiveStr::Ascii("tembrisers"),
        dictgen::InsensitiveStr::Ascii("tembrizer"),
        dictgen::InsensitiveStr::Ascii("tembrizers"),
        dictgen::InsensitiveStr::Ascii("temia"),
        dictgen::InsensitiveStr::Ascii("ticaemia"),
        dictgen::InsensitiveStr::Ascii("ticaemias"),
        dictgen::InsensitiveStr::Ascii("ticaemic"),
        dictgen::InsensitiveStr::Ascii("ticemia"),
        dictgen::InsensitiveStr::Ascii("ticemias"),
        dictgen::InsensitiveStr::Ascii("ticemic"),
        dictgen::InsensitiveStr::Ascii("ticisation"),
        dictgen::InsensitiveStr::Ascii("ticisations"),
        dictgen::InsensitiveStr::Ascii("ticization"),
        dictgen::InsensitiveStr::Ascii("ticizations"),
        dictgen::InsensitiveStr::Ascii("ticolored"),
        dictgen::InsensitiveStr::Ascii("ticoloured"),
        dictgen::InsensitiveStr::Ascii("ulcher"),
        dictgen::InsensitiveStr::Ascii("ulchered"),
        dictgen::InsensitiveStr::Ascii("ulchering"),
        dictgen::InsensitiveStr::Ascii("ulchers"),
        dictgen::InsensitiveStr::Ascii("ulchralise"),
        dictgen::InsensitiveStr::Ascii("ulchralises"),
        dictgen::InsensitiveStr::Ascii("ulchralize"),
        dictgen::InsensitiveStr::Ascii("ulchralizes"),
        dictgen::InsensitiveStr::Ascii("ulchre"),
        dictgen::InsensitiveStr::Ascii("ulchred"),
        dictgen::InsensitiveStr::Ascii("ulchres"),
        dictgen::InsensitiveStr::Ascii("ulchring"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SEPALED_12090295642380405616)],
        &[(0b00001, &ENTRY_SEPALEDDER_18149050438233478463)],
        &[(0b00001, &ENTRY_SEPALEDDEST_16726621142433806076)],
        &[(0b11010, &ENTRY_SEPALED_12090295642380405616)],
        &[(0b11010, &ENTRY_SEPALEDDER_18149050438233478463)],
        &[(0b11010, &ENTRY_SEPALEDDEST_16726621142433806076)],
        &[(0b11010, &ENTRY_SEPTEMIA_17627373967872968416)],
        &[(0b10010, &ENTRY_SEPTEMBRIZER_14180678052471741675)],
        &[(0b10010, &ENTRY_SEPTEMBRIZERS_5568167245143709930)],
        &[(0b01001, &ENTRY_SEPTEMBRIZER_14180678052471741675)],
        &[(0b01001, &ENTRY_SEPTEMBRIZERS_5568167245143709930)],
        &[(0b00001, &ENTRY_SEPTEMIA_17627373967872968416)],
        &[(0b10010, &ENTRY_SEPTICEMIA_11397632634952601953)],
        &[(0b10010, &ENTRY_SEPTICEMIAS_12503495764642957726)],
        &[(0b10010, &ENTRY_SEPTICEMIC_17224432424285146941)],
        &[(0b01001, &ENTRY_SEPTICEMIA_11397632634952601953)],
        &[(0b01001, &ENTRY_SEPTICEMIAS_12503495764642957726)],
        &[(0b01001, &ENTRY_SEPTICEMIC_17224432424285146941)],
        &[(0b10010, &ENTRY_SEPTICIZATION_14002989906709765055)],
        &[(0b10010, &ENTRY_SEPTICIZATIONS_14828929428564717195)],
        &[(0b01001, &ENTRY_SEPTICIZATION_14002989906709765055)],
        &[(0b01001, &ENTRY_SEPTICIZATIONS_14828929428564717195)],
        &[(0b00001, &ENTRY_SEPTICOLORED_5211825597090733015)],
        &[(0b11010, &ENTRY_SEPTICOLORED_5211825597090733015)],
        &[(0b00001, &ENTRY_SEPULCHER_5901571127124975988)],
        &[(0b00001, &ENTRY_SEPULCHERED_13156739439863668198)],
        &[(0b00001, &ENTRY_SEPULCHERING_15916701810150961536)],
        &[(0b00001, &ENTRY_SEPULCHERS_17907839135565596907)],
        &[(0b10010, &ENTRY_SEPULCHRALIZE_471485549032044787)],
        &[(0b10010, &ENTRY_SEPULCHRALIZES_11618984573736373917)],
        &[(0b01001, &ENTRY_SEPULCHRALIZE_471485549032044787)],
        &[(0b01001, &ENTRY_SEPULCHRALIZES_11618984573736373917)],
        &[(0b11010, &ENTRY_SEPULCHER_5901571127124975988)],
        &[(0b11010, &ENTRY_SEPULCHERED_13156739439863668198)],
        &[(0b11010, &ENTRY_SEPULCHERS_17907839135565596907)],
        &[(0b11010, &ENTRY_SEPULCHERING_15916701810150961536)],
    ],
    range: 4..=11,
};

static VARS_SEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SEN_CHILDREN),
    value: None,
};

static VARS_SEN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SENI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SENS_NODE),
    Some(&VARS_SENT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SENT_CHILDREN),
    value: None,
};

pub static VARS_SENT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imentalisation"),
        dictgen::InsensitiveStr::Ascii("imentalisations"),
        dictgen::InsensitiveStr::Ascii("imentalise"),
        dictgen::InsensitiveStr::Ascii("imentalised"),
        dictgen::InsensitiveStr::Ascii("imentaliser"),
        dictgen::InsensitiveStr::Ascii("imentalisers"),
        dictgen::InsensitiveStr::Ascii("imentalises"),
        dictgen::InsensitiveStr::Ascii("imentalising"),
        dictgen::InsensitiveStr::Ascii("imentalization"),
        dictgen::InsensitiveStr::Ascii("imentalizations"),
        dictgen::InsensitiveStr::Ascii("imentalize"),
        dictgen::InsensitiveStr::Ascii("imentalized"),
        dictgen::InsensitiveStr::Ascii("imentalizer"),
        dictgen::InsensitiveStr::Ascii("imentalizers"),
        dictgen::InsensitiveStr::Ascii("imentalizes"),
        dictgen::InsensitiveStr::Ascii("imentalizing"),
        dictgen::InsensitiveStr::Ascii("ineled"),
        dictgen::InsensitiveStr::Ascii("ineling"),
        dictgen::InsensitiveStr::Ascii("inelled"),
        dictgen::InsensitiveStr::Ascii("inelling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SENTIMENTALIZATION_9061044606950222949)],
        &[(0b10010, &ENTRY_SENTIMENTALIZATIONS_17372211169793747786)],
        &[(0b10010, &ENTRY_SENTIMENTALIZE_9074334910736712170)],
        &[(0b10010, &ENTRY_SENTIMENTALIZED_7395272655741592803)],
        &[(0b10010, &ENTRY_SENTIMENTALIZER_10892451054407203292)],
        &[(0b10010, &ENTRY_SENTIMENTALIZERS_4236225160895961849)],
        &[(0b10010, &ENTRY_SENTIMENTALIZES_11687838812874218316)],
        &[(0b10010, &ENTRY_SENTIMENTALIZING_9011281810726145623)],
        &[(0b01001, &ENTRY_SENTIMENTALIZATION_9061044606950222949)],
        &[(0b01001, &ENTRY_SENTIMENTALIZATIONS_17372211169793747786)],
        &[(0b01001, &ENTRY_SENTIMENTALIZE_9074334910736712170)],
        &[(0b01001, &ENTRY_SENTIMENTALIZED_7395272655741592803)],
        &[(0b01001, &ENTRY_SENTIMENTALIZER_10892451054407203292)],
        &[(0b01001, &ENTRY_SENTIMENTALIZERS_4236225160895961849)],
        &[(0b01001, &ENTRY_SENTIMENTALIZES_11687838812874218316)],
        &[(0b01001, &ENTRY_SENTIMENTALIZING_9011281810726145623)],
        &[(0b00001, &ENTRY_SENTINELED_15164238305822628477)],
        &[(0b00001, &ENTRY_SENTINELING_11104191602796418564)],
        &[(0b11010, &ENTRY_SENTINELED_15164238305822628477)],
        &[(0b11010, &ENTRY_SENTINELING_11104191602796418564)],
    ],
    range: 6..=15,
};

static VARS_SENS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SENS_CHILDREN),
    value: None,
};

pub static VARS_SENS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalised"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalising"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalized"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
        dictgen::InsensitiveStr::Ascii("ationalizing"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itiser"),
        dictgen::InsensitiveStr::Ascii("itisers"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizer"),
        dictgen::InsensitiveStr::Ascii("itizers"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SENSATIONALIZE_3612877228613212928)],
        &[(0b10010, &ENTRY_SENSATIONALIZED_15672094773557124276)],
        &[(0b10010, &ENTRY_SENSATIONALIZES_6023223775469404764)],
        &[(0b10010, &ENTRY_SENSATIONALIZING_3700944391567555627)],
        &[(0b01001, &ENTRY_SENSATIONALIZE_3612877228613212928)],
        &[(0b01001, &ENTRY_SENSATIONALIZED_15672094773557124276)],
        &[(0b01001, &ENTRY_SENSATIONALIZES_6023223775469404764)],
        &[(0b01001, &ENTRY_SENSATIONALIZING_3700944391567555627)],
        &[(0b10010, &ENTRY_SENSIZE_17053253712096730252)],
        &[(0b10010, &ENTRY_SENSIZES_10006992614374882912)],
        &[(0b10010, &ENTRY_SENSITIZATION_5562142577083526555)],
        &[(0b10010, &ENTRY_SENSITIZATIONS_13654430266545943350)],
        &[(0b10010, &ENTRY_SENSITIZE_314572801275315620)],
        &[(0b10010, &ENTRY_SENSITIZED_3980543883168272054)],
        &[(0b10010, &ENTRY_SENSITIZER_10276855194832816189)],
        &[(0b10010, &ENTRY_SENSITIZERS_18244790979608274479)],
        &[(0b10010, &ENTRY_SENSITIZES_577413584210679666)],
        &[(0b10010, &ENTRY_SENSITIZING_7753308060738960399)],
        &[(0b01001, &ENTRY_SENSITIZATION_5562142577083526555)],
        &[(0b01001, &ENTRY_SENSITIZATIONS_13654430266545943350)],
        &[(0b01001, &ENTRY_SENSITIZE_314572801275315620)],
        &[(0b01001, &ENTRY_SENSITIZED_3980543883168272054)],
        &[(0b01001, &ENTRY_SENSITIZER_10276855194832816189)],
        &[(0b01001, &ENTRY_SENSITIZERS_18244790979608274479)],
        &[(0b01001, &ENTRY_SENSITIZES_577413584210679666)],
        &[(0b01001, &ENTRY_SENSITIZING_7753308060738960399)],
        &[(0b01001, &ENTRY_SENSIZE_17053253712096730252)],
        &[(0b01001, &ENTRY_SENSIZES_10006992614374882912)],
        &[(0b10010, &ENTRY_SENSUALIZATION_18438288000507867475)],
        &[(0b10010, &ENTRY_SENSUALIZATIONS_4903697434091196616)],
        &[(0b10010, &ENTRY_SENSUALIZE_16925018484398827656)],
        &[(0b10010, &ENTRY_SENSUALIZED_5812075572460333798)],
        &[(0b10010, &ENTRY_SENSUALIZES_6027047404814047775)],
        &[(0b10010, &ENTRY_SENSUALIZING_8787028083330334024)],
        &[(0b01001, &ENTRY_SENSUALIZATION_18438288000507867475)],
        &[(0b01001, &ENTRY_SENSUALIZATIONS_4903697434091196616)],
        &[(0b01001, &ENTRY_SENSUALIZE_16925018484398827656)],
        &[(0b01001, &ENTRY_SENSUALIZED_5812075572460333798)],
        &[(0b01001, &ENTRY_SENSUALIZES_6027047404814047775)],
        &[(0b01001, &ENTRY_SENSUALIZING_8787028083330334024)],
    ],
    range: 3..=12,
};

static VARS_SENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SENI_CHILDREN),
    value: None,
};

pub static VARS_SENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SENILIZE_8029621471742989343)],
        &[(0b10010, &ENTRY_SENILIZES_12383752921132409565)],
        &[(0b01001, &ENTRY_SENILIZE_8029621471742989343)],
        &[(0b01001, &ENTRY_SENILIZES_12383752921132409565)],
    ],
    range: 4..=5,
};

static VARS_SEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SEM_CHILDREN),
    value: None,
};

static VARS_SEM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SEMA_NODE),
    None,
    None,
    None,
    Some(&VARS_SEME_NODE),
    None,
    None,
    None,
    Some(&VARS_SEMI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SEMP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SEMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMP_CHILDREN),
    value: None,
};

pub static VARS_SEMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SEMPER_8108831112347458625)],
        &[(0b11010, &ENTRY_SEMPER_8108831112347458625)],
    ],
    range: 2..=2,
};

static VARS_SEMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SEMI_CHILDREN),
    value: None,
};

static VARS_SEMI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SEMIA_NODE),
    None,
    Some(&VARS_SEMIC_NODE),
    None,
    None,
    Some(&VARS_SEMIF_NODE),
    None,
    Some(&VARS_SEMIH_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_SEMIM_NODE),
    Some(&VARS_SEMIN_NODE),
    Some(&VARS_SEMIO_NODE),
    Some(&VARS_SEMIP_NODE),
    None,
    None,
    None,
    Some(&VARS_SEMIT_NODE),
    None,
    Some(&VARS_SEMIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_SEMIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIV_CHILDREN),
    value: None,
};

pub static VARS_SEMIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ulcanised"),
        dictgen::InsensitiveStr::Ascii("ulcaniseds"),
        dictgen::InsensitiveStr::Ascii("ulcanized"),
        dictgen::InsensitiveStr::Ascii("ulcanizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIVULCANIZED_14359220447980579562)],
        &[(0b10010, &ENTRY_SEMIVULCANIZEDS_13162744092050979464)],
        &[(0b01001, &ENTRY_SEMIVULCANIZED_14359220447980579562)],
        &[(0b01001, &ENTRY_SEMIVULCANIZEDS_13162744092050979464)],
    ],
    range: 9..=10,
};

static VARS_SEMIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIT_CHILDREN),
    value: None,
};

pub static VARS_SEMIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SEMITE_8050506285147736874)],
        &[(0b00001, &ENTRY_SEMITE_8050506285147736874)],
        &[(0b10010, &ENTRY_SEMITICIZE_2609826288107126486)],
        &[(0b10010, &ENTRY_SEMITICIZES_14074646105957764366)],
        &[(0b01001, &ENTRY_SEMITICIZE_2609826288107126486)],
        &[(0b01001, &ENTRY_SEMITICIZES_14074646105957764366)],
        &[(0b10010, &ENTRY_SEMITIZATION_2814386441666130450)],
        &[(0b10010, &ENTRY_SEMITIZATIONS_13807542369819114157)],
        &[(0b10010, &ENTRY_SEMITIZE_941534843473568569)],
        &[(0b10010, &ENTRY_SEMITIZED_17290416988749434330)],
        &[(0b10010, &ENTRY_SEMITIZES_11925278580314760912)],
        &[(0b10010, &ENTRY_SEMITIZING_2963320286843005115)],
        &[(0b01001, &ENTRY_SEMITIZATION_2814386441666130450)],
        &[(0b01001, &ENTRY_SEMITIZATIONS_13807542369819114157)],
        &[(0b01001, &ENTRY_SEMITIZE_941534843473568569)],
        &[(0b01001, &ENTRY_SEMITIZED_17290416988749434330)],
        &[(0b01001, &ENTRY_SEMITIZES_11925278580314760912)],
        &[(0b01001, &ENTRY_SEMITIZING_2963320286843005115)],
    ],
    range: 1..=8,
};

static VARS_SEMIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIP_CHILDREN),
    value: None,
};

pub static VARS_SEMIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rofessionalised"),
        dictgen::InsensitiveStr::Ascii("rofessionaliseds"),
        dictgen::InsensitiveStr::Ascii("rofessionalized"),
        dictgen::InsensitiveStr::Ascii("rofessionalizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIPROFESSIONALIZED_17328179078904677907)],
        &[(0b10010, &ENTRY_SEMIPROFESSIONALIZEDS_15921777243236052227)],
        &[(0b01001, &ENTRY_SEMIPROFESSIONALIZED_17328179078904677907)],
        &[(0b01001, &ENTRY_SEMIPROFESSIONALIZEDS_15921777243236052227)],
    ],
    range: 15..=16,
};

static VARS_SEMIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIO_CHILDREN),
    value: None,
};

pub static VARS_SEMIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganiseds"),
        dictgen::InsensitiveStr::Ascii("rganized"),
        dictgen::InsensitiveStr::Ascii("rganizeds"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidiseds"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizeds"),
        dictgen::InsensitiveStr::Ascii("xygenised"),
        dictgen::InsensitiveStr::Ascii("xygeniseds"),
        dictgen::InsensitiveStr::Ascii("xygenized"),
        dictgen::InsensitiveStr::Ascii("xygenizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIORGANIZED_6555791236440295060)],
        &[(0b10010, &ENTRY_SEMIORGANIZEDS_12008364003973962769)],
        &[(0b01001, &ENTRY_SEMIORGANIZED_6555791236440295060)],
        &[(0b01001, &ENTRY_SEMIORGANIZEDS_12008364003973962769)],
        &[(0b10010, &ENTRY_SEMIOXIDIZED_5315770266537512020)],
        &[(0b10010, &ENTRY_SEMIOXIDIZEDS_6159043438844186188)],
        &[(0b01001, &ENTRY_SEMIOXIDIZED_5315770266537512020)],
        &[(0b01001, &ENTRY_SEMIOXIDIZEDS_6159043438844186188)],
        &[(0b10010, &ENTRY_SEMIOXYGENIZED_15324068707582079762)],
        &[(0b10010, &ENTRY_SEMIOXYGENIZEDS_2404118500235275979)],
        &[(0b01001, &ENTRY_SEMIOXYGENIZED_15324068707582079762)],
        &[(0b01001, &ENTRY_SEMIOXYGENIZEDS_2404118500235275979)],
    ],
    range: 7..=10,
};

static VARS_SEMIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIN_CHILDREN),
    value: None,
};

pub static VARS_SEMIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMINARIZE_16382184306789061126)],
        &[(0b10010, &ENTRY_SEMINARIZES_1867316917365228789)],
        &[(0b01001, &ENTRY_SEMINARIZE_16382184306789061126)],
        &[(0b01001, &ENTRY_SEMINARIZES_1867316917365228789)],
        &[(0b10010, &ENTRY_SEMINATIONALIZATION_14555714753335877358)],
        &[(0b10010, &ENTRY_SEMINATIONALIZATIONS_17200787028274260651)],
        &[(0b01001, &ENTRY_SEMINATIONALIZATION_14555714753335877358)],
        &[(0b01001, &ENTRY_SEMINATIONALIZATIONS_17200787028274260651)],
    ],
    range: 5..=15,
};

static VARS_SEMIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIM_CHILDREN),
    value: None,
};

pub static VARS_SEMIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ercerised"),
        dictgen::InsensitiveStr::Ascii("erceriseds"),
        dictgen::InsensitiveStr::Ascii("ercerized"),
        dictgen::InsensitiveStr::Ascii("ercerizeds"),
        dictgen::InsensitiveStr::Ascii("ineralised"),
        dictgen::InsensitiveStr::Ascii("ineraliseds"),
        dictgen::InsensitiveStr::Ascii("ineralized"),
        dictgen::InsensitiveStr::Ascii("ineralizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIMERCERIZED_7395245349141510735)],
        &[(0b10010, &ENTRY_SEMIMERCERIZEDS_6499518726299354192)],
        &[(0b01001, &ENTRY_SEMIMERCERIZED_7395245349141510735)],
        &[(0b01001, &ENTRY_SEMIMERCERIZEDS_6499518726299354192)],
        &[(0b10010, &ENTRY_SEMIMINERALIZED_16937456193304785591)],
        &[(0b10010, &ENTRY_SEMIMINERALIZEDS_7867390791226894698)],
        &[(0b01001, &ENTRY_SEMIMINERALIZED_16937456193304785591)],
        &[(0b01001, &ENTRY_SEMIMINERALIZEDS_7867390791226894698)],
    ],
    range: 9..=11,
};

static VARS_SEMIH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIH_CHILDREN),
    value: None,
};

pub static VARS_SEMIH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onor"),
        dictgen::InsensitiveStr::Ascii("onors"),
        dictgen::InsensitiveStr::Ascii("onour"),
        dictgen::InsensitiveStr::Ascii("onours"),
        dictgen::InsensitiveStr::Ascii("umanised"),
        dictgen::InsensitiveStr::Ascii("umaniseds"),
        dictgen::InsensitiveStr::Ascii("umanized"),
        dictgen::InsensitiveStr::Ascii("umanizeds"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SEMIHONOR_7457444383686448706)],
        &[(0b00001, &ENTRY_SEMIHONORS_12462123375978457923)],
        &[(0b11010, &ENTRY_SEMIHONOR_7457444383686448706)],
        &[(0b11010, &ENTRY_SEMIHONORS_12462123375978457923)],
        &[(0b10010, &ENTRY_SEMIHUMANIZED_17638546783529197556)],
        &[(0b10010, &ENTRY_SEMIHUMANIZEDS_17371974753621699342)],
        &[(0b01001, &ENTRY_SEMIHUMANIZED_17638546783529197556)],
        &[(0b01001, &ENTRY_SEMIHUMANIZEDS_17371974753621699342)],
    ],
    range: 4..=9,
};

static VARS_SEMIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIF_CHILDREN),
    value: None,
};

pub static VARS_SEMIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ossilised"),
        dictgen::InsensitiveStr::Ascii("ossiliseds"),
        dictgen::InsensitiveStr::Ascii("ossilized"),
        dictgen::InsensitiveStr::Ascii("ossilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMIFOSSILIZED_9350071948098066704)],
        &[(0b10010, &ENTRY_SEMIFOSSILIZEDS_7710393663692254880)],
        &[(0b01001, &ENTRY_SEMIFOSSILIZED_9350071948098066704)],
        &[(0b01001, &ENTRY_SEMIFOSSILIZEDS_7710393663692254880)],
    ],
    range: 9..=10,
};

static VARS_SEMIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIC_CHILDREN),
    value: None,
};

pub static VARS_SEMIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arbonise"),
        dictgen::InsensitiveStr::Ascii("arbonises"),
        dictgen::InsensitiveStr::Ascii("arbonize"),
        dictgen::InsensitiveStr::Ascii("arbonizes"),
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilised"),
        dictgen::InsensitiveStr::Ascii("iviliseds"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("ivilized"),
        dictgen::InsensitiveStr::Ascii("ivilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEMICARBONIZE_8409774805182130142)],
        &[(0b10010, &ENTRY_SEMICARBONIZES_1797293499149887442)],
        &[(0b01001, &ENTRY_SEMICARBONIZE_8409774805182130142)],
        &[(0b01001, &ENTRY_SEMICARBONIZES_1797293499149887442)],
        &[(0b10010, &ENTRY_SEMICIVILIZATION_15242671581564814120)],
        &[(0b10010, &ENTRY_SEMICIVILIZATIONS_5720575445164622576)],
        &[(0b10010, &ENTRY_SEMICIVILIZED_4637923957818205530)],
        &[(0b10010, &ENTRY_SEMICIVILIZEDS_2897438279018112835)],
        &[(0b01001, &ENTRY_SEMICIVILIZATION_15242671581564814120)],
        &[(0b01001, &ENTRY_SEMICIVILIZATIONS_5720575445164622576)],
        &[(0b01001, &ENTRY_SEMICIVILIZED_4637923957818205530)],
        &[(0b01001, &ENTRY_SEMICIVILIZEDS_2897438279018112835)],
    ],
    range: 8..=12,
};

static VARS_SEMIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMIA_CHILDREN),
    value: None,
};

pub static VARS_SEMIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("naesthetic"),
        dictgen::InsensitiveStr::Ascii("nesthetic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SEMIANESTHETIC_603220656140835402)],
        &[(0b00001, &ENTRY_SEMIANESTHETIC_603220656140835402)],
    ],
    range: 9..=10,
};

static VARS_SEME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEME_CHILDREN),
    value: None,
};

pub static VARS_SEME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("nov")],
    values: &[&[(0b00001, &ENTRY_SEMENOV_2935209069826757991)]],
    range: 3..=3,
};

static VARS_SEMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEMA_CHILDREN),
    value: None,
};

pub static VARS_SEMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("enov")],
    values: &[&[(0b11010, &ENTRY_SEMENOV_2935209069826757991)]],
    range: 4..=4,
};

static VARS_SEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEL_CHILDREN),
    value: None,
};

pub static VARS_SEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lae"),
        dictgen::InsensitiveStr::Ascii("le"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SELLE_12446852445813787272)],
        &[(0b00001, &ENTRY_SELLE_12446852445813787272)],
    ],
    range: 2..=3,
};

static VARS_SEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEI_CHILDREN),
    value: None,
};

pub static VARS_SEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sable"),
        dictgen::InsensitiveStr::Ascii("ser"),
        dictgen::InsensitiveStr::Ascii("sers"),
        dictgen::InsensitiveStr::Ascii("sin"),
        dictgen::InsensitiveStr::Ascii("sings"),
        dictgen::InsensitiveStr::Ascii("sins"),
        dictgen::InsensitiveStr::Ascii("zable"),
        dictgen::InsensitiveStr::Ascii("zer"),
        dictgen::InsensitiveStr::Ascii("zers"),
        dictgen::InsensitiveStr::Ascii("zin"),
        dictgen::InsensitiveStr::Ascii("zings"),
        dictgen::InsensitiveStr::Ascii("zins"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SEIZABLE_6299895893787769311)],
        &[(0b10010, &ENTRY_SEIZER_12783623317695995317)],
        &[(0b10010, &ENTRY_SEIZERS_3311206369321638961)],
        &[(0b10010, &ENTRY_SEIZIN_7497048659697035283)],
        &[(0b10010, &ENTRY_SEIZINGS_4904640050385479436)],
        &[(0b10010, &ENTRY_SEIZINS_9859687246678890466)],
        &[(0b01001, &ENTRY_SEIZABLE_6299895893787769311)],
        &[(0b01001, &ENTRY_SEIZER_12783623317695995317)],
        &[(0b01001, &ENTRY_SEIZERS_3311206369321638961)],
        &[(0b01001, &ENTRY_SEIZIN_7497048659697035283)],
        &[(0b01001, &ENTRY_SEIZINGS_4904640050385479436)],
        &[(0b01001, &ENTRY_SEIZINS_9859687246678890466)],
    ],
    range: 3..=5,
};

static VARS_SEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEE_CHILDREN),
    value: None,
};

pub static VARS_SEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("d")],
    values: &[&[(0b00001, &ENTRY_SEED_321113364137294796)]],
    range: 1..=1,
};

static VARS_SEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SEC_CHILDREN),
    value: None,
};

static VARS_SEC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SECT_NODE),
    Some(&VARS_SECU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_SECU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SECU_CHILDREN),
    value: None,
};

pub static VARS_SECU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("larisation"),
        dictgen::InsensitiveStr::Ascii("larisations"),
        dictgen::InsensitiveStr::Ascii("larise"),
        dictgen::InsensitiveStr::Ascii("larised"),
        dictgen::InsensitiveStr::Ascii("lariser"),
        dictgen::InsensitiveStr::Ascii("larisers"),
        dictgen::InsensitiveStr::Ascii("larises"),
        dictgen::InsensitiveStr::Ascii("larising"),
        dictgen::InsensitiveStr::Ascii("larization"),
        dictgen::InsensitiveStr::Ascii("larizations"),
        dictgen::InsensitiveStr::Ascii("larize"),
        dictgen::InsensitiveStr::Ascii("larized"),
        dictgen::InsensitiveStr::Ascii("larizer"),
        dictgen::InsensitiveStr::Ascii("larizers"),
        dictgen::InsensitiveStr::Ascii("larizes"),
        dictgen::InsensitiveStr::Ascii("larizing"),
        dictgen::InsensitiveStr::Ascii("lum"),
        dictgen::InsensitiveStr::Ascii("lums"),
        dictgen::InsensitiveStr::Ascii("ritisation"),
        dictgen::InsensitiveStr::Ascii("ritisations"),
        dictgen::InsensitiveStr::Ascii("ritise"),
        dictgen::InsensitiveStr::Ascii("ritised"),
        dictgen::InsensitiveStr::Ascii("ritises"),
        dictgen::InsensitiveStr::Ascii("ritising"),
        dictgen::InsensitiveStr::Ascii("ritization"),
        dictgen::InsensitiveStr::Ascii("ritizations"),
        dictgen::InsensitiveStr::Ascii("ritize"),
        dictgen::InsensitiveStr::Ascii("ritized"),
        dictgen::InsensitiveStr::Ascii("ritizes"),
        dictgen::InsensitiveStr::Ascii("ritizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SECULARIZATION_4665508589899729279)],
        &[(0b10010, &ENTRY_SECULARIZATIONS_18385656083748383194)],
        &[(0b10010, &ENTRY_SECULARIZE_8691674226029598576)],
        &[(0b10010, &ENTRY_SECULARIZED_4356348361234297427)],
        &[(0b10010, &ENTRY_SECULARIZER_8531483256485763608)],
        &[(0b10010, &ENTRY_SECULARIZERS_959509276810245817)],
        &[(0b10010, &ENTRY_SECULARIZES_17808446279659322674)],
        &[(0b10010, &ENTRY_SECULARIZING_3038011191545839970)],
        &[(0b01001, &ENTRY_SECULARIZATION_4665508589899729279)],
        &[(0b01001, &ENTRY_SECULARIZATIONS_18385656083748383194)],
        &[(0b01001, &ENTRY_SECULARIZE_8691674226029598576)],
        &[(0b01001, &ENTRY_SECULARIZED_4356348361234297427)],
        &[(0b01001, &ENTRY_SECULARIZER_8531483256485763608)],
        &[(0b01001, &ENTRY_SECULARIZERS_959509276810245817)],
        &[(0b01001, &ENTRY_SECULARIZES_17808446279659322674)],
        &[(0b01001, &ENTRY_SECULARIZING_3038011191545839970)],
        &[(0b00001, &ENTRY_SECULUM_14580513950849648417)],
        &[(0b00001, &ENTRY_SECULUMS_1417148559086086183)],
        &[(0b10010, &ENTRY_SECURITIZATION_15104434495314939017)],
        &[(0b10010, &ENTRY_SECURITIZATIONS_14825154146636731025)],
        &[(0b10010, &ENTRY_SECURITIZE_14199237267948737829)],
        &[(0b10010, &ENTRY_SECURITIZED_3968791155978166897)],
        &[(0b10010, &ENTRY_SECURITIZES_964431635949451194)],
        &[(0b10010, &ENTRY_SECURITIZING_10216698736284529838)],
        &[(0b01001, &ENTRY_SECURITIZATION_15104434495314939017)],
        &[(0b01001, &ENTRY_SECURITIZATIONS_14825154146636731025)],
        &[(0b01001, &ENTRY_SECURITIZE_14199237267948737829)],
        &[(0b01001, &ENTRY_SECURITIZED_3968791155978166897)],
        &[(0b01001, &ENTRY_SECURITIZES_964431635949451194)],
        &[(0b01001, &ENTRY_SECURITIZING_10216698736284529838)],
    ],
    range: 3..=11,
};

static VARS_SECT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SECT_CHILDREN),
    value: None,
};

pub static VARS_SECT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arianisation"),
        dictgen::InsensitiveStr::Ascii("arianise"),
        dictgen::InsensitiveStr::Ascii("arianised"),
        dictgen::InsensitiveStr::Ascii("arianises"),
        dictgen::InsensitiveStr::Ascii("arianising"),
        dictgen::InsensitiveStr::Ascii("arianization"),
        dictgen::InsensitiveStr::Ascii("arianize"),
        dictgen::InsensitiveStr::Ascii("arianized"),
        dictgen::InsensitiveStr::Ascii("arianizes"),
        dictgen::InsensitiveStr::Ascii("arianizing"),
        dictgen::InsensitiveStr::Ascii("ionalisation"),
        dictgen::InsensitiveStr::Ascii("ionalisations"),
        dictgen::InsensitiveStr::Ascii("ionalise"),
        dictgen::InsensitiveStr::Ascii("ionalised"),
        dictgen::InsensitiveStr::Ascii("ionalises"),
        dictgen::InsensitiveStr::Ascii("ionalising"),
        dictgen::InsensitiveStr::Ascii("ionalization"),
        dictgen::InsensitiveStr::Ascii("ionalizations"),
        dictgen::InsensitiveStr::Ascii("ionalize"),
        dictgen::InsensitiveStr::Ascii("ionalized"),
        dictgen::InsensitiveStr::Ascii("ionalizes"),
        dictgen::InsensitiveStr::Ascii("ionalizing"),
        dictgen::InsensitiveStr::Ascii("ionisation"),
        dictgen::InsensitiveStr::Ascii("ionisations"),
        dictgen::InsensitiveStr::Ascii("ionise"),
        dictgen::InsensitiveStr::Ascii("ionised"),
        dictgen::InsensitiveStr::Ascii("ionises"),
        dictgen::InsensitiveStr::Ascii("ionising"),
        dictgen::InsensitiveStr::Ascii("ionization"),
        dictgen::InsensitiveStr::Ascii("ionizations"),
        dictgen::InsensitiveStr::Ascii("ionize"),
        dictgen::InsensitiveStr::Ascii("ionized"),
        dictgen::InsensitiveStr::Ascii("ionizes"),
        dictgen::InsensitiveStr::Ascii("ionizing"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SECTARIANIZATION_10329500434104171538)],
        &[(0b10010, &ENTRY_SECTARIANIZE_1734665934956097961)],
        &[(0b10010, &ENTRY_SECTARIANIZED_4323075987609952650)],
        &[(0b10010, &ENTRY_SECTARIANIZES_16984853238843084036)],
        &[(0b10010, &ENTRY_SECTARIANIZING_16586872715969887648)],
        &[(0b01001, &ENTRY_SECTARIANIZATION_10329500434104171538)],
        &[(0b01001, &ENTRY_SECTARIANIZE_1734665934956097961)],
        &[(0b01001, &ENTRY_SECTARIANIZED_4323075987609952650)],
        &[(0b01001, &ENTRY_SECTARIANIZES_16984853238843084036)],
        &[(0b01001, &ENTRY_SECTARIANIZING_16586872715969887648)],
        &[(0b10010, &ENTRY_SECTIONALIZATION_7372956859343047861)],
        &[(0b10010, &ENTRY_SECTIONALIZATIONS_3982770312292073083)],
        &[(0b10010, &ENTRY_SECTIONALIZE_6731417115868692513)],
        &[(0b10010, &ENTRY_SECTIONALIZED_15063335524950991716)],
        &[(0b10010, &ENTRY_SECTIONALIZES_4950660755628313153)],
        &[(0b10010, &ENTRY_SECTIONALIZING_11106492791716994585)],
        &[(0b01001, &ENTRY_SECTIONALIZATION_7372956859343047861)],
        &[(0b01001, &ENTRY_SECTIONALIZATIONS_3982770312292073083)],
        &[(0b01001, &ENTRY_SECTIONALIZE_6731417115868692513)],
        &[(0b01001, &ENTRY_SECTIONALIZED_15063335524950991716)],
        &[(0b01001, &ENTRY_SECTIONALIZES_4950660755628313153)],
        &[(0b01001, &ENTRY_SECTIONALIZING_11106492791716994585)],
        &[(0b10010, &ENTRY_SECTIONIZATION_5059309185384353865)],
        &[(0b10010, &ENTRY_SECTIONIZATIONS_7138672770671968877)],
        &[(0b10010, &ENTRY_SECTIONIZE_3662925954380476587)],
        &[(0b10010, &ENTRY_SECTIONIZED_4875591137215667653)],
        &[(0b10010, &ENTRY_SECTIONIZES_6513394183804020021)],
        &[(0b10010, &ENTRY_SECTIONIZING_5472076843239971417)],
        &[(0b01001, &ENTRY_SECTIONIZATION_5059309185384353865)],
        &[(0b01001, &ENTRY_SECTIONIZATIONS_7138672770671968877)],
        &[(0b01001, &ENTRY_SECTIONIZE_3662925954380476587)],
        &[(0b01001, &ENTRY_SECTIONIZED_4875591137215667653)],
        &[(0b01001, &ENTRY_SECTIONIZES_6513394183804020021)],
        &[(0b01001, &ENTRY_SECTIONIZING_5472076843239971417)],
        &[(0b10010, &ENTRY_SECTORIZATION_13074208022324954117)],
        &[(0b10010, &ENTRY_SECTORIZATIONS_1272351990881337199)],
        &[(0b10010, &ENTRY_SECTORIZE_16349435987024198076)],
        &[(0b10010, &ENTRY_SECTORIZED_3551279836961169706)],
        &[(0b10010, &ENTRY_SECTORIZES_3606396525392350810)],
        &[(0b10010, &ENTRY_SECTORIZING_8533377571217926271)],
        &[(0b01001, &ENTRY_SECTORIZATION_13074208022324954117)],
        &[(0b01001, &ENTRY_SECTORIZATIONS_1272351990881337199)],
        &[(0b01001, &ENTRY_SECTORIZE_16349435987024198076)],
        &[(0b01001, &ENTRY_SECTORIZED_3551279836961169706)],
        &[(0b01001, &ENTRY_SECTORIZES_3606396525392350810)],
        &[(0b01001, &ENTRY_SECTORIZING_8533377571217926271)],
    ],
    range: 5..=13,
};

static VARS_SEB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SEB_CHILDREN),
    value: None,
};

pub static VARS_SEB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrheas"),
        dictgen::InsensitiveStr::Ascii("orrheic"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhoeas"),
        dictgen::InsensitiveStr::Ascii("orrhoeic"),
    ],
    values: &[
        &[(0b01001, &ENTRY_SEBORRHEA_5911144256699940196)],
        &[(0b01001, &ENTRY_SEBORRHEAS_17176346816866257994)],
        &[(0b01001, &ENTRY_SEBORRHEIC_1999320639299394735)],
        &[(0b10010, &ENTRY_SEBORRHEA_5911144256699940196)],
        &[(0b10010, &ENTRY_SEBORRHEAS_17176346816866257994)],
        &[(0b10010, &ENTRY_SEBORRHEIC_1999320639299394735)],
    ],
    range: 6..=8,
};

static VARS_SC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SC_CHILDREN),
    value: None,
};

static VARS_SC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SCA_NODE),
    None,
    None,
    None,
    Some(&VARS_SCE_NODE),
    None,
    None,
    Some(&VARS_SCH_NODE),
    Some(&VARS_SCI_NODE),
    None,
    None,
    Some(&VARS_SCL_NODE),
    None,
    None,
    Some(&VARS_SCO_NODE),
    None,
    None,
    Some(&VARS_SCR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SCR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCR_CHILDREN),
    value: None,
};

pub static VARS_SCR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ipturalise"),
        dictgen::InsensitiveStr::Ascii("ipturalises"),
        dictgen::InsensitiveStr::Ascii("ipturalize"),
        dictgen::InsensitiveStr::Ascii("ipturalizes"),
        dictgen::InsensitiveStr::Ascii("utinisation"),
        dictgen::InsensitiveStr::Ascii("utinisations"),
        dictgen::InsensitiveStr::Ascii("utinise"),
        dictgen::InsensitiveStr::Ascii("utinised"),
        dictgen::InsensitiveStr::Ascii("utiniser"),
        dictgen::InsensitiveStr::Ascii("utinisers"),
        dictgen::InsensitiveStr::Ascii("utinises"),
        dictgen::InsensitiveStr::Ascii("utinising"),
        dictgen::InsensitiveStr::Ascii("utinisinglies"),
        dictgen::InsensitiveStr::Ascii("utinisingly"),
        dictgen::InsensitiveStr::Ascii("utinization"),
        dictgen::InsensitiveStr::Ascii("utinizations"),
        dictgen::InsensitiveStr::Ascii("utinize"),
        dictgen::InsensitiveStr::Ascii("utinized"),
        dictgen::InsensitiveStr::Ascii("utinizer"),
        dictgen::InsensitiveStr::Ascii("utinizers"),
        dictgen::InsensitiveStr::Ascii("utinizes"),
        dictgen::InsensitiveStr::Ascii("utinizing"),
        dictgen::InsensitiveStr::Ascii("utinizinglies"),
        dictgen::InsensitiveStr::Ascii("utinizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SCRIPTURALIZE_16965719438311609740)],
        &[(0b10010, &ENTRY_SCRIPTURALIZES_6331235887129690543)],
        &[(0b01001, &ENTRY_SCRIPTURALIZE_16965719438311609740)],
        &[(0b01001, &ENTRY_SCRIPTURALIZES_6331235887129690543)],
        &[(0b10010, &ENTRY_SCRUTINIZATION_17415762227653222410)],
        &[(0b10010, &ENTRY_SCRUTINIZATIONS_16986534141035954565)],
        &[(0b10010, &ENTRY_SCRUTINIZE_2495160673295116727)],
        &[(0b10010, &ENTRY_SCRUTINIZED_138448923562603427)],
        &[(0b10010, &ENTRY_SCRUTINIZER_16787119409611200536)],
        &[(0b10010, &ENTRY_SCRUTINIZERS_9843755621018893931)],
        &[(0b10010, &ENTRY_SCRUTINIZES_14143862930988132210)],
        &[(0b10010, &ENTRY_SCRUTINIZING_10650157705768207198)],
        &[(0b10010, &ENTRY_SCRUTINIZINGLIES_6550131961437823868)],
        &[(0b10010, &ENTRY_SCRUTINIZINGLY_6838183545046867792)],
        &[(0b01001, &ENTRY_SCRUTINIZATION_17415762227653222410)],
        &[(0b01001, &ENTRY_SCRUTINIZATIONS_16986534141035954565)],
        &[(0b01001, &ENTRY_SCRUTINIZE_2495160673295116727)],
        &[(0b01001, &ENTRY_SCRUTINIZED_138448923562603427)],
        &[(0b01001, &ENTRY_SCRUTINIZER_16787119409611200536)],
        &[(0b01001, &ENTRY_SCRUTINIZERS_9843755621018893931)],
        &[(0b01001, &ENTRY_SCRUTINIZES_14143862930988132210)],
        &[(0b01001, &ENTRY_SCRUTINIZING_10650157705768207198)],
        &[(0b01001, &ENTRY_SCRUTINIZINGLIES_6550131961437823868)],
        &[(0b01001, &ENTRY_SCRUTINIZINGLY_6838183545046867792)],
    ],
    range: 7..=13,
};

static VARS_SCO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCO_CHILDREN),
    value: None,
};

pub static VARS_SCO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rse"),
        dictgen::InsensitiveStr::Ascii("rsed"),
        dictgen::InsensitiveStr::Ascii("rses"),
        dictgen::InsensitiveStr::Ascii("rsing"),
        dictgen::InsensitiveStr::Ascii("tticise"),
        dictgen::InsensitiveStr::Ascii("tticised"),
        dictgen::InsensitiveStr::Ascii("tticises"),
        dictgen::InsensitiveStr::Ascii("tticising"),
        dictgen::InsensitiveStr::Ascii("tticize"),
        dictgen::InsensitiveStr::Ascii("tticized"),
        dictgen::InsensitiveStr::Ascii("tticizes"),
        dictgen::InsensitiveStr::Ascii("tticizing"),
        dictgen::InsensitiveStr::Ascii("urse"),
        dictgen::InsensitiveStr::Ascii("ursed"),
        dictgen::InsensitiveStr::Ascii("urses"),
        dictgen::InsensitiveStr::Ascii("ursing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SCORSE_15078698805947392168)],
        &[(0b00001, &ENTRY_SCORSED_16083267741792838932)],
        &[(0b00001, &ENTRY_SCORSES_7140175579256526605)],
        &[(0b00001, &ENTRY_SCORSING_3188653853529728017)],
        &[(0b10010, &ENTRY_SCOTTICIZE_17245280330015663168)],
        &[(0b10010, &ENTRY_SCOTTICIZED_9176139469703286390)],
        &[(0b10010, &ENTRY_SCOTTICIZES_4892539654566755234)],
        &[(0b10010, &ENTRY_SCOTTICIZING_2341284462577725385)],
        &[(0b01001, &ENTRY_SCOTTICIZE_17245280330015663168)],
        &[(0b01001, &ENTRY_SCOTTICIZED_9176139469703286390)],
        &[(0b01001, &ENTRY_SCOTTICIZES_4892539654566755234)],
        &[(0b01001, &ENTRY_SCOTTICIZING_2341284462577725385)],
        &[(0b11010, &ENTRY_SCORSE_15078698805947392168)],
        &[(0b11010, &ENTRY_SCORSED_16083267741792838932)],
        &[(0b11010, &ENTRY_SCORSES_7140175579256526605)],
        &[(0b11010, &ENTRY_SCORSING_3188653853529728017)],
    ],
    range: 3..=9,
};

static VARS_SCL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCL_CHILDREN),
    value: None,
};

pub static VARS_SCL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erae"),
        dictgen::InsensitiveStr::Ascii("ere"),
        dictgen::InsensitiveStr::Ascii("erotisation"),
        dictgen::InsensitiveStr::Ascii("erotise"),
        dictgen::InsensitiveStr::Ascii("erotised"),
        dictgen::InsensitiveStr::Ascii("erotises"),
        dictgen::InsensitiveStr::Ascii("erotising"),
        dictgen::InsensitiveStr::Ascii("erotization"),
        dictgen::InsensitiveStr::Ascii("erotize"),
        dictgen::InsensitiveStr::Ascii("erotized"),
        dictgen::InsensitiveStr::Ascii("erotizes"),
        dictgen::InsensitiveStr::Ascii("erotizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SCLERE_9746329931158778294)],
        &[(0b00001, &ENTRY_SCLERE_9746329931158778294)],
        &[(0b10010, &ENTRY_SCLEROTIZATION_15026971996955314482)],
        &[(0b10010, &ENTRY_SCLEROTIZE_11388338623919176754)],
        &[(0b10010, &ENTRY_SCLEROTIZED_13849096612293754473)],
        &[(0b10010, &ENTRY_SCLEROTIZES_15593295504016734858)],
        &[(0b10010, &ENTRY_SCLEROTIZING_5997112524177379321)],
        &[(0b01001, &ENTRY_SCLEROTIZATION_15026971996955314482)],
        &[(0b01001, &ENTRY_SCLEROTIZE_11388338623919176754)],
        &[(0b01001, &ENTRY_SCLEROTIZED_13849096612293754473)],
        &[(0b01001, &ENTRY_SCLEROTIZES_15593295504016734858)],
        &[(0b01001, &ENTRY_SCLEROTIZING_5997112524177379321)],
    ],
    range: 3..=11,
};

static VARS_SCI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCI_CHILDREN),
    value: None,
};

pub static VARS_SCI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entised"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entising"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entized"),
        dictgen::InsensitiveStr::Ascii("entizes"),
        dictgen::InsensitiveStr::Ascii("entizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SCIENTIZE_10148514792697844596)],
        &[(0b10010, &ENTRY_SCIENTIZED_3311115608371296118)],
        &[(0b10010, &ENTRY_SCIENTIZES_16694012140134350335)],
        &[(0b10010, &ENTRY_SCIENTIZING_15849402639331786377)],
        &[(0b01001, &ENTRY_SCIENTIZE_10148514792697844596)],
        &[(0b01001, &ENTRY_SCIENTIZED_3311115608371296118)],
        &[(0b01001, &ENTRY_SCIENTIZES_16694012140134350335)],
        &[(0b01001, &ENTRY_SCIENTIZING_15849402639331786377)],
    ],
    range: 6..=8,
};

static VARS_SCH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCH_CHILDREN),
    value: None,
};

pub static VARS_SCH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edulise"),
        dictgen::InsensitiveStr::Ascii("edulises"),
        dictgen::InsensitiveStr::Ascii("edulize"),
        dictgen::InsensitiveStr::Ascii("edulizes"),
        dictgen::InsensitiveStr::Ascii("ematisation"),
        dictgen::InsensitiveStr::Ascii("ematisations"),
        dictgen::InsensitiveStr::Ascii("ematise"),
        dictgen::InsensitiveStr::Ascii("ematised"),
        dictgen::InsensitiveStr::Ascii("ematiser"),
        dictgen::InsensitiveStr::Ascii("ematisers"),
        dictgen::InsensitiveStr::Ascii("ematises"),
        dictgen::InsensitiveStr::Ascii("ematising"),
        dictgen::InsensitiveStr::Ascii("ematization"),
        dictgen::InsensitiveStr::Ascii("ematizations"),
        dictgen::InsensitiveStr::Ascii("ematize"),
        dictgen::InsensitiveStr::Ascii("ematized"),
        dictgen::InsensitiveStr::Ascii("ematizer"),
        dictgen::InsensitiveStr::Ascii("ematizers"),
        dictgen::InsensitiveStr::Ascii("ematizes"),
        dictgen::InsensitiveStr::Ascii("ematizing"),
        dictgen::InsensitiveStr::Ascii("illerisation"),
        dictgen::InsensitiveStr::Ascii("illerisations"),
        dictgen::InsensitiveStr::Ascii("illerise"),
        dictgen::InsensitiveStr::Ascii("illerised"),
        dictgen::InsensitiveStr::Ascii("illerises"),
        dictgen::InsensitiveStr::Ascii("illerising"),
        dictgen::InsensitiveStr::Ascii("illerization"),
        dictgen::InsensitiveStr::Ascii("illerizations"),
        dictgen::InsensitiveStr::Ascii("illerize"),
        dictgen::InsensitiveStr::Ascii("illerized"),
        dictgen::InsensitiveStr::Ascii("illerizes"),
        dictgen::InsensitiveStr::Ascii("illerizing"),
        dictgen::InsensitiveStr::Ascii("ismatise"),
        dictgen::InsensitiveStr::Ascii("ismatised"),
        dictgen::InsensitiveStr::Ascii("ismatises"),
        dictgen::InsensitiveStr::Ascii("ismatising"),
        dictgen::InsensitiveStr::Ascii("ismatize"),
        dictgen::InsensitiveStr::Ascii("ismatized"),
        dictgen::InsensitiveStr::Ascii("ismatizes"),
        dictgen::InsensitiveStr::Ascii("ismatizing"),
        dictgen::InsensitiveStr::Ascii("istocelia"),
        dictgen::InsensitiveStr::Ascii("istocoelia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SCHEDULIZE_5696008845820733070)],
        &[(0b10010, &ENTRY_SCHEDULIZES_11998681560108042990)],
        &[(0b01001, &ENTRY_SCHEDULIZE_5696008845820733070)],
        &[(0b01001, &ENTRY_SCHEDULIZES_11998681560108042990)],
        &[(0b10010, &ENTRY_SCHEMATIZATION_12280133115355003981)],
        &[(0b10010, &ENTRY_SCHEMATIZATIONS_10214946104759561540)],
        &[(0b10010, &ENTRY_SCHEMATIZE_17242177807075430578)],
        &[(0b10010, &ENTRY_SCHEMATIZED_6065522728213827719)],
        &[(0b10010, &ENTRY_SCHEMATIZER_5371535585135012777)],
        &[(0b10010, &ENTRY_SCHEMATIZERS_4368175659338148324)],
        &[(0b10010, &ENTRY_SCHEMATIZES_5464172182149518273)],
        &[(0b10010, &ENTRY_SCHEMATIZING_5183188849408735782)],
        &[(0b01001, &ENTRY_SCHEMATIZATION_12280133115355003981)],
        &[(0b01001, &ENTRY_SCHEMATIZATIONS_10214946104759561540)],
        &[(0b01001, &ENTRY_SCHEMATIZE_17242177807075430578)],
        &[(0b01001, &ENTRY_SCHEMATIZED_6065522728213827719)],
        &[(0b01001, &ENTRY_SCHEMATIZER_5371535585135012777)],
        &[(0b01001, &ENTRY_SCHEMATIZERS_4368175659338148324)],
        &[(0b01001, &ENTRY_SCHEMATIZES_5464172182149518273)],
        &[(0b01001, &ENTRY_SCHEMATIZING_5183188849408735782)],
        &[(0b10010, &ENTRY_SCHILLERIZATION_1975534132552758492)],
        &[(0b10010, &ENTRY_SCHILLERIZATIONS_1097721139918947159)],
        &[(0b10010, &ENTRY_SCHILLERIZE_955273459416220138)],
        &[(0b10010, &ENTRY_SCHILLERIZED_8127379884079449773)],
        &[(0b10010, &ENTRY_SCHILLERIZES_7351365606194447161)],
        &[(0b10010, &ENTRY_SCHILLERIZING_10704749465715034583)],
        &[(0b01001, &ENTRY_SCHILLERIZATION_1975534132552758492)],
        &[(0b01001, &ENTRY_SCHILLERIZATIONS_1097721139918947159)],
        &[(0b01001, &ENTRY_SCHILLERIZE_955273459416220138)],
        &[(0b01001, &ENTRY_SCHILLERIZED_8127379884079449773)],
        &[(0b01001, &ENTRY_SCHILLERIZES_7351365606194447161)],
        &[(0b01001, &ENTRY_SCHILLERIZING_10704749465715034583)],
        &[(0b10010, &ENTRY_SCHISMATIZE_6430207238586664982)],
        &[(0b10010, &ENTRY_SCHISMATIZED_3002177619960082558)],
        &[(0b10010, &ENTRY_SCHISMATIZES_14979481534021263364)],
        &[(0b10010, &ENTRY_SCHISMATIZING_18224301025260482655)],
        &[(0b01001, &ENTRY_SCHISMATIZE_6430207238586664982)],
        &[(0b01001, &ENTRY_SCHISMATIZED_3002177619960082558)],
        &[(0b01001, &ENTRY_SCHISMATIZES_14979481534021263364)],
        &[(0b01001, &ENTRY_SCHISMATIZING_18224301025260482655)],
        &[(0b00001, &ENTRY_SCHISTOCELIA_3827142390073980619)],
        &[(0b11010, &ENTRY_SCHISTOCELIA_3827142390073980619)],
    ],
    range: 7..=13,
};

static VARS_SCE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCE_CHILDREN),
    value: None,
};

pub static VARS_SCE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("na"),
        dictgen::InsensitiveStr::Ascii("narioisation"),
        dictgen::InsensitiveStr::Ascii("narioisations"),
        dictgen::InsensitiveStr::Ascii("narioise"),
        dictgen::InsensitiveStr::Ascii("narioises"),
        dictgen::InsensitiveStr::Ascii("narioization"),
        dictgen::InsensitiveStr::Ascii("narioizations"),
        dictgen::InsensitiveStr::Ascii("narioize"),
        dictgen::InsensitiveStr::Ascii("narioizes"),
        dictgen::InsensitiveStr::Ascii("narisation"),
        dictgen::InsensitiveStr::Ascii("narisations"),
        dictgen::InsensitiveStr::Ascii("narise"),
        dictgen::InsensitiveStr::Ascii("narised"),
        dictgen::InsensitiveStr::Ascii("narises"),
        dictgen::InsensitiveStr::Ascii("narising"),
        dictgen::InsensitiveStr::Ascii("narization"),
        dictgen::InsensitiveStr::Ascii("narizations"),
        dictgen::InsensitiveStr::Ascii("narize"),
        dictgen::InsensitiveStr::Ascii("narized"),
        dictgen::InsensitiveStr::Ascii("narizes"),
        dictgen::InsensitiveStr::Ascii("narizing"),
        dictgen::InsensitiveStr::Ascii("pter"),
        dictgen::InsensitiveStr::Ascii("pterdom"),
        dictgen::InsensitiveStr::Ascii("ptered"),
        dictgen::InsensitiveStr::Ascii("ptering"),
        dictgen::InsensitiveStr::Ascii("pterless"),
        dictgen::InsensitiveStr::Ascii("pterlesses"),
        dictgen::InsensitiveStr::Ascii("pters"),
        dictgen::InsensitiveStr::Ascii("ptic"),
        dictgen::InsensitiveStr::Ascii("ptical"),
        dictgen::InsensitiveStr::Ascii("pticaler"),
        dictgen::InsensitiveStr::Ascii("pticalest"),
        dictgen::InsensitiveStr::Ascii("ptically"),
        dictgen::InsensitiveStr::Ascii("pticer"),
        dictgen::InsensitiveStr::Ascii("pticest"),
        dictgen::InsensitiveStr::Ascii("pticism"),
        dictgen::InsensitiveStr::Ascii("pticisms"),
        dictgen::InsensitiveStr::Ascii("ptics"),
        dictgen::InsensitiveStr::Ascii("ptre"),
        dictgen::InsensitiveStr::Ascii("ptred"),
        dictgen::InsensitiveStr::Ascii("ptredom"),
        dictgen::InsensitiveStr::Ascii("ptreless"),
        dictgen::InsensitiveStr::Ascii("ptrelesses"),
        dictgen::InsensitiveStr::Ascii("ptres"),
        dictgen::InsensitiveStr::Ascii("ptring"),
        dictgen::InsensitiveStr::Ascii("vor"),
        dictgen::InsensitiveStr::Ascii("vour"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SCENA_13970174413239259767)],
        &[(0b10010, &ENTRY_SCENARIOIZATION_11568016783832907853)],
        &[(0b10010, &ENTRY_SCENARIOIZATIONS_5354132606433153264)],
        &[(0b10010, &ENTRY_SCENARIOIZE_10573641030848141241)],
        &[(0b10010, &ENTRY_SCENARIOIZES_482550746480154259)],
        &[(0b01001, &ENTRY_SCENARIOIZATION_11568016783832907853)],
        &[(0b01001, &ENTRY_SCENARIOIZATIONS_5354132606433153264)],
        &[(0b01001, &ENTRY_SCENARIOIZE_10573641030848141241)],
        &[(0b01001, &ENTRY_SCENARIOIZES_482550746480154259)],
        &[(0b10010, &ENTRY_SCENARIZATION_8267687093775898269)],
        &[(0b10010, &ENTRY_SCENARIZATIONS_15320566627597434538)],
        &[(0b10010, &ENTRY_SCENARIZE_7764842416771702084)],
        &[(0b10010, &ENTRY_SCENARIZED_13846545490430585820)],
        &[(0b10010, &ENTRY_SCENARIZES_843838764401688514)],
        &[(0b10010, &ENTRY_SCENARIZING_4139993347505235123)],
        &[(0b01001, &ENTRY_SCENARIZATION_8267687093775898269)],
        &[(0b01001, &ENTRY_SCENARIZATIONS_15320566627597434538)],
        &[(0b01001, &ENTRY_SCENARIZE_7764842416771702084)],
        &[(0b01001, &ENTRY_SCENARIZED_13846545490430585820)],
        &[(0b01001, &ENTRY_SCENARIZES_843838764401688514)],
        &[(0b01001, &ENTRY_SCENARIZING_4139993347505235123)],
        &[(0b00001, &ENTRY_SCEPTER_2634314741124349621)],
        &[(0b00001, &ENTRY_SCEPTERDOM_17727578002621263233)],
        &[(0b00001, &ENTRY_SCEPTERED_4309367457883178779)],
        &[(0b00001, &ENTRY_SCEPTERING_11235334755425728893)],
        &[(0b00001, &ENTRY_SCEPTERLESS_14014584389608395039)],
        &[(0b00001, &ENTRY_SCEPTERLESSES_3211886999266482763)],
        &[(0b00001, &ENTRY_SCEPTERS_17320251109355012747)],
        &[(0b11010, &ENTRY_SKEPTIC_9366141399207033866)],
        &[(0b11010, &ENTRY_SKEPTICAL_7567920697289876244)],
        &[(0b11010, &ENTRY_SKEPTICALER_3504236392319734868)],
        &[(0b11010, &ENTRY_SKEPTICALEST_1822492830960306797)],
        &[(0b11010, &ENTRY_SKEPTICALLY_15015708074924057237)],
        &[(0b11010, &ENTRY_SKEPTICER_2654895074232389427)],
        &[(0b11010, &ENTRY_SKEPTICEST_13124338123587490640)],
        &[(0b11010, &ENTRY_SKEPTICISM_16324594783111490926)],
        &[(0b11010, &ENTRY_SKEPTICISMS_9470460390001384677)],
        &[(0b11010, &ENTRY_SKEPTICS_13432613087589375835)],
        &[(0b11010, &ENTRY_SCEPTER_2634314741124349621)],
        &[(0b11010, &ENTRY_SCEPTERED_4309367457883178779)],
        &[(0b11010, &ENTRY_SCEPTERDOM_17727578002621263233)],
        &[(0b11010, &ENTRY_SCEPTERLESS_14014584389608395039)],
        &[(0b11010, &ENTRY_SCEPTERLESSES_3211886999266482763)],
        &[(0b11010, &ENTRY_SCEPTERS_17320251109355012747)],
        &[(0b11010, &ENTRY_SCEPTERING_11235334755425728893)],
        &[(0b00001, &ENTRY_SCEVOR_17742563930876297446)],
        &[(0b11010, &ENTRY_SCEVOR_17742563930876297446)],
    ],
    range: 2..=13,
};

static VARS_SCA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SCA_CHILDREN),
    value: None,
};

pub static VARS_SCA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("ndaled"),
        dictgen::InsensitiveStr::Ascii("ndaling"),
        dictgen::InsensitiveStr::Ascii("ndalisation"),
        dictgen::InsensitiveStr::Ascii("ndalisations"),
        dictgen::InsensitiveStr::Ascii("ndalise"),
        dictgen::InsensitiveStr::Ascii("ndalised"),
        dictgen::InsensitiveStr::Ascii("ndaliser"),
        dictgen::InsensitiveStr::Ascii("ndalisers"),
        dictgen::InsensitiveStr::Ascii("ndalises"),
        dictgen::InsensitiveStr::Ascii("ndalising"),
        dictgen::InsensitiveStr::Ascii("ndalization"),
        dictgen::InsensitiveStr::Ascii("ndalizations"),
        dictgen::InsensitiveStr::Ascii("ndalize"),
        dictgen::InsensitiveStr::Ascii("ndalized"),
        dictgen::InsensitiveStr::Ascii("ndalizer"),
        dictgen::InsensitiveStr::Ascii("ndalizers"),
        dictgen::InsensitiveStr::Ascii("ndalizes"),
        dictgen::InsensitiveStr::Ascii("ndalizing"),
        dictgen::InsensitiveStr::Ascii("ndalled"),
        dictgen::InsensitiveStr::Ascii("ndalling"),
        dictgen::InsensitiveStr::Ascii("paed"),
        dictgen::InsensitiveStr::Ascii("ped"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SCENA_13970174413239259767)],
        &[(0b00001, &ENTRY_SCANDALED_1881652881768607660)],
        &[(0b00001, &ENTRY_SCANDALING_6393905647064815426)],
        &[(0b10010, &ENTRY_SCANDALIZATION_1685701550263872659)],
        &[(0b10010, &ENTRY_SCANDALIZATIONS_7898720696120879071)],
        &[(0b10010, &ENTRY_SCANDALIZE_14741991033789550594)],
        &[(0b10010, &ENTRY_SCANDALIZED_11085730138699741279)],
        &[(0b10010, &ENTRY_SCANDALIZER_5001392876013065734)],
        &[(0b10010, &ENTRY_SCANDALIZERS_15197543038839412069)],
        &[(0b10010, &ENTRY_SCANDALIZES_11290093653234602832)],
        &[(0b10010, &ENTRY_SCANDALIZING_3021901097391350682)],
        &[(0b01001, &ENTRY_SCANDALIZATION_1685701550263872659)],
        &[(0b01001, &ENTRY_SCANDALIZATIONS_7898720696120879071)],
        &[(0b01001, &ENTRY_SCANDALIZE_14741991033789550594)],
        &[(0b01001, &ENTRY_SCANDALIZED_11085730138699741279)],
        &[(0b01001, &ENTRY_SCANDALIZER_5001392876013065734)],
        &[(0b01001, &ENTRY_SCANDALIZERS_15197543038839412069)],
        &[(0b01001, &ENTRY_SCANDALIZES_11290093653234602832)],
        &[(0b01001, &ENTRY_SCANDALIZING_3021901097391350682)],
        &[(0b11010, &ENTRY_SCANDALED_1881652881768607660)],
        &[(0b11010, &ENTRY_SCANDALING_6393905647064815426)],
        &[(0b11010, &ENTRY_SCAPED_11838614965333604867)],
        &[(0b00001, &ENTRY_SCAPED_11838614965333604867)],
    ],
    range: 3..=12,
};

static VARS_SA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SA_CHILDREN),
    value: None,
};

static VARS_SA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_SAB_NODE),
    Some(&VARS_SAC_NODE),
    None,
    Some(&VARS_SAE_NODE),
    Some(&VARS_SAF_NODE),
    None,
    None,
    Some(&VARS_SAI_NODE),
    None,
    None,
    Some(&VARS_SAL_NODE),
    None,
    Some(&VARS_SAN_NODE),
    None,
    Some(&VARS_SAP_NODE),
    None,
    Some(&VARS_SAR_NODE),
    Some(&VARS_SAS_NODE),
    Some(&VARS_SAT_NODE),
    None,
    Some(&VARS_SAV_NODE),
    None,
    Some(&VARS_SAX_NODE),
    None,
    None,
];

static VARS_SAX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAX_CHILDREN),
    value: None,
};

pub static VARS_SAX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SAXONIZATION_13920447163448605602)],
        &[(0b10010, &ENTRY_SAXONIZATIONS_2318853882636501152)],
        &[(0b10010, &ENTRY_SAXONIZE_9115638203834180868)],
        &[(0b10010, &ENTRY_SAXONIZED_12370590955724966093)],
        &[(0b10010, &ENTRY_SAXONIZES_5168843153581210465)],
        &[(0b10010, &ENTRY_SAXONIZING_15329045328723618614)],
        &[(0b01001, &ENTRY_SAXONIZATION_13920447163448605602)],
        &[(0b01001, &ENTRY_SAXONIZATIONS_2318853882636501152)],
        &[(0b01001, &ENTRY_SAXONIZE_9115638203834180868)],
        &[(0b01001, &ENTRY_SAXONIZED_12370590955724966093)],
        &[(0b01001, &ENTRY_SAXONIZES_5168843153581210465)],
        &[(0b01001, &ENTRY_SAXONIZING_15329045328723618614)],
    ],
    range: 5..=10,
};

static VARS_SAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_SAV_CHILDREN),
    value: None,
};

static VARS_SAV_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_SAVA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SAVI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_SAVO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_SAVO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAVO_CHILDREN),
    value: None,
};

pub static VARS_SAVO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("rier"),
        dictgen::InsensitiveStr::Ascii("ries"),
        dictgen::InsensitiveStr::Ascii("riest"),
        dictgen::InsensitiveStr::Ascii("rilies"),
        dictgen::InsensitiveStr::Ascii("rily"),
        dictgen::InsensitiveStr::Ascii("riness"),
        dictgen::InsensitiveStr::Ascii("rinesses"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("ringlier"),
        dictgen::InsensitiveStr::Ascii("ringlies"),
        dictgen::InsensitiveStr::Ascii("ringliest"),
        dictgen::InsensitiveStr::Ascii("ringly"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesser"),
        dictgen::InsensitiveStr::Ascii("rlesses"),
        dictgen::InsensitiveStr::Ascii("rlessest"),
        dictgen::InsensitiveStr::Ascii("rly"),
        dictgen::InsensitiveStr::Ascii("rous"),
        dictgen::InsensitiveStr::Ascii("rouser"),
        dictgen::InsensitiveStr::Ascii("rousest"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("ry"),
        dictgen::InsensitiveStr::Ascii("ur"),
        dictgen::InsensitiveStr::Ascii("ured"),
        dictgen::InsensitiveStr::Ascii("urer"),
        dictgen::InsensitiveStr::Ascii("urers"),
        dictgen::InsensitiveStr::Ascii("urier"),
        dictgen::InsensitiveStr::Ascii("uries"),
        dictgen::InsensitiveStr::Ascii("uriest"),
        dictgen::InsensitiveStr::Ascii("urilies"),
        dictgen::InsensitiveStr::Ascii("urily"),
        dictgen::InsensitiveStr::Ascii("uriness"),
        dictgen::InsensitiveStr::Ascii("urinesses"),
        dictgen::InsensitiveStr::Ascii("uring"),
        dictgen::InsensitiveStr::Ascii("uringlier"),
        dictgen::InsensitiveStr::Ascii("uringlies"),
        dictgen::InsensitiveStr::Ascii("uringliest"),
        dictgen::InsensitiveStr::Ascii("uringly"),
        dictgen::InsensitiveStr::Ascii("urless"),
        dictgen::InsensitiveStr::Ascii("urlesser"),
        dictgen::InsensitiveStr::Ascii("urlesses"),
        dictgen::InsensitiveStr::Ascii("urlessest"),
        dictgen::InsensitiveStr::Ascii("urly"),
        dictgen::InsensitiveStr::Ascii("urous"),
        dictgen::InsensitiveStr::Ascii("urouser"),
        dictgen::InsensitiveStr::Ascii("urousest"),
        dictgen::InsensitiveStr::Ascii("urs"),
        dictgen::InsensitiveStr::Ascii("ury"),
    ],
    values: &[
        &[(0b11001, &ENTRY_SAVOR_7268353245862880587)],
        &[(0b11001, &ENTRY_SAVORED_17866382687586191735)],
        &[(0b11001, &ENTRY_SAVORER_15451082667887423810)],
        &[(0b11001, &ENTRY_SAVORERS_11787687508614999748)],
        &[(0b11001, &ENTRY_SAVORIER_6303687459165405447)],
        &[(0b11001, &ENTRY_SAVORIES_9905015268014283974)],
        &[(0b11001, &ENTRY_SAVORIEST_17206072645132615270)],
        &[(0b11001, &ENTRY_SAVORILIES_6579003325829163067)],
        &[(0b11001, &ENTRY_SAVORILY_15448585721024708912)],
        &[(0b11001, &ENTRY_SAVORINESS_13968014337021909965)],
        &[(0b11001, &ENTRY_SAVORINESSES_10065971623388592088)],
        &[(0b11001, &ENTRY_SAVORING_6763000239615004808)],
        &[(0b11001, &ENTRY_SAVORINGLIER_10137328596366632769)],
        &[(0b11001, &ENTRY_SAVORINGLIES_16962535350125218546)],
        &[(0b11001, &ENTRY_SAVORINGLIEST_15169226019310047256)],
        &[(0b11001, &ENTRY_SAVORINGLY_188792191137435132)],
        &[(0b11001, &ENTRY_SAVORLESS_8806630377030275637)],
        &[(0b11001, &ENTRY_SAVORLESSER_15665106123472425180)],
        &[(0b11001, &ENTRY_SAVORLESSES_7670792878511449933)],
        &[(0b11001, &ENTRY_SAVORLESSEST_9190940621548012509)],
        &[(0b11001, &ENTRY_SAVORLY_7024626808530014518)],
        &[(0b00001, &ENTRY_SAVOROUS_11062427848542635268)],
        &[(0b00001, &ENTRY_SAVOROUSER_1727203765225429536)],
        &[(0b00001, &ENTRY_SAVOROUSEST_3100516665411914597)],
        &[(0b11001, &ENTRY_SAVORS_17864742679821873261)],
        &[(0b11001, &ENTRY_SAVORY_18035223196990312431)],
        &[(0b11010, &ENTRY_SAVOR_7268353245862880587)],
        &[(0b11010, &ENTRY_SAVORED_17866382687586191735)],
        &[(0b11010, &ENTRY_SAVORER_15451082667887423810)],
        &[(0b11010, &ENTRY_SAVORERS_11787687508614999748)],
        &[(0b11010, &ENTRY_SAVORIER_6303687459165405447)],
        &[(0b11010, &ENTRY_SAVORIES_9905015268014283974)],
        &[(0b11010, &ENTRY_SAVORIEST_17206072645132615270)],
        &[(0b11010, &ENTRY_SAVORILIES_6579003325829163067)],
        &[(0b11010, &ENTRY_SAVORILY_15448585721024708912)],
        &[(0b11010, &ENTRY_SAVORINESS_13968014337021909965)],
        &[(0b11010, &ENTRY_SAVORINESSES_10065971623388592088)],
        &[(0b11010, &ENTRY_SAVORING_6763000239615004808)],
        &[(0b11010, &ENTRY_SAVORINGLIER_10137328596366632769)],
        &[(0b11010, &ENTRY_SAVORINGLIES_16962535350125218546)],
        &[(0b11010, &ENTRY_SAVORINGLIEST_15169226019310047256)],
        &[(0b11010, &ENTRY_SAVORINGLY_188792191137435132)],
        &[(0b11010, &ENTRY_SAVORLESS_8806630377030275637)],
        &[(0b11010, &ENTRY_SAVORLESSER_15665106123472425180)],
        &[(0b11010, &ENTRY_SAVORLESSES_7670792878511449933)],
        &[(0b11010, &ENTRY_SAVORLESSEST_9190940621548012509)],
        &[(0b11010, &ENTRY_SAVORLY_7024626808530014518)],
        &[(0b11010, &ENTRY_SAVOROUS_11062427848542635268)],
        &[(0b11010, &ENTRY_SAVOROUSER_1727203765225429536)],
        &[(0b11010, &ENTRY_SAVOROUSEST_3100516665411914597)],
        &[(0b11010, &ENTRY_SAVORS_17864742679821873261)],
        &[(0b11010, &ENTRY_SAVORY_18035223196990312431)],
    ],
    range: 1..=10,
};

static VARS_SAVI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAVI_CHILDREN),
    value: None,
};

pub static VARS_SAVI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("oress"),
        dictgen::InsensitiveStr::Ascii("orhood"),
        dictgen::InsensitiveStr::Ascii("orhoods"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("orship"),
        dictgen::InsensitiveStr::Ascii("orships"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ouress"),
        dictgen::InsensitiveStr::Ascii("ourhood"),
        dictgen::InsensitiveStr::Ascii("ourhoods"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("ourship"),
        dictgen::InsensitiveStr::Ascii("ourships"),
    ],
    values: &[
        &[(0b11001, &ENTRY_SAVIOR_11215020799589174317)],
        &[(0b00001, &ENTRY_SAVIORESS_8494654417327749250)],
        &[(0b11001, &ENTRY_SAVIORHOOD_2729791171284683689)],
        &[(0b11001, &ENTRY_SAVIORHOODS_2311230659362646694)],
        &[(0b11001, &ENTRY_SAVIORS_13252400093779282591)],
        &[(0b11001, &ENTRY_SAVIORSHIP_2762957268664282572)],
        &[(0b11001, &ENTRY_SAVIORSHIPS_11936339798406737592)],
        &[(0b11010, &ENTRY_SAVIOR_11215020799589174317)],
        &[(0b11010, &ENTRY_SAVIORESS_8494654417327749250)],
        &[(0b11010, &ENTRY_SAVIORHOOD_2729791171284683689)],
        &[(0b11010, &ENTRY_SAVIORHOODS_2311230659362646694)],
        &[(0b11010, &ENTRY_SAVIORS_13252400093779282591)],
        &[(0b11010, &ENTRY_SAVIORSHIP_2762957268664282572)],
        &[(0b11010, &ENTRY_SAVIORSHIPS_11936339798406737592)],
    ],
    range: 2..=8,
};

static VARS_SAVA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAVA_CHILDREN),
    value: None,
};

pub static VARS_SAVA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gise"),
        dictgen::InsensitiveStr::Ascii("gises"),
        dictgen::InsensitiveStr::Ascii("gize"),
        dictgen::InsensitiveStr::Ascii("gizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SAVAGIZE_826547977271561744)],
        &[(0b10010, &ENTRY_SAVAGIZES_3717388500719289056)],
        &[(0b01001, &ENTRY_SAVAGIZE_826547977271561744)],
        &[(0b01001, &ENTRY_SAVAGIZES_3717388500719289056)],
    ],
    range: 4..=5,
};

static VARS_SAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAT_CHILDREN),
    value: None,
};

pub static VARS_SAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("ellitise"),
        dictgen::InsensitiveStr::Ascii("ellitised"),
        dictgen::InsensitiveStr::Ascii("ellitises"),
        dictgen::InsensitiveStr::Ascii("ellitising"),
        dictgen::InsensitiveStr::Ascii("ellitize"),
        dictgen::InsensitiveStr::Ascii("ellitized"),
        dictgen::InsensitiveStr::Ascii("ellitizes"),
        dictgen::InsensitiveStr::Ascii("ellitizing"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("irisable"),
        dictgen::InsensitiveStr::Ascii("irisables"),
        dictgen::InsensitiveStr::Ascii("irisation"),
        dictgen::InsensitiveStr::Ascii("irise"),
        dictgen::InsensitiveStr::Ascii("irised"),
        dictgen::InsensitiveStr::Ascii("iriser"),
        dictgen::InsensitiveStr::Ascii("irisers"),
        dictgen::InsensitiveStr::Ascii("irises"),
        dictgen::InsensitiveStr::Ascii("irising"),
        dictgen::InsensitiveStr::Ascii("irizable"),
        dictgen::InsensitiveStr::Ascii("irizables"),
        dictgen::InsensitiveStr::Ascii("irization"),
        dictgen::InsensitiveStr::Ascii("irize"),
        dictgen::InsensitiveStr::Ascii("irized"),
        dictgen::InsensitiveStr::Ascii("irizer"),
        dictgen::InsensitiveStr::Ascii("irizers"),
        dictgen::InsensitiveStr::Ascii("irizes"),
        dictgen::InsensitiveStr::Ascii("irizing"),
        dictgen::InsensitiveStr::Ascii("ivae"),
        dictgen::InsensitiveStr::Ascii("ive"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SATANIZE_2951447326962462423)],
        &[(0b10010, &ENTRY_SATANIZES_4037603454744610431)],
        &[(0b01001, &ENTRY_SATANIZE_2951447326962462423)],
        &[(0b01001, &ENTRY_SATANIZES_4037603454744610431)],
        &[(0b10010, &ENTRY_SATELLITIZE_1312953346097302445)],
        &[(0b10010, &ENTRY_SATELLITIZED_4530790908872238564)],
        &[(0b10010, &ENTRY_SATELLITIZES_15756736520028846542)],
        &[(0b10010, &ENTRY_SATELLITIZING_5844820839355010398)],
        &[(0b01001, &ENTRY_SATELLITIZE_1312953346097302445)],
        &[(0b01001, &ENTRY_SATELLITIZED_4530790908872238564)],
        &[(0b01001, &ENTRY_SATELLITIZES_15756736520028846542)],
        &[(0b01001, &ENTRY_SATELLITIZING_5844820839355010398)],
        &[(0b10010, &ENTRY_SATINIZE_12856779838184407064)],
        &[(0b10010, &ENTRY_SATINIZES_542674649787102689)],
        &[(0b01001, &ENTRY_SATINIZE_12856779838184407064)],
        &[(0b01001, &ENTRY_SATINIZES_542674649787102689)],
        &[(0b10010, &ENTRY_SATIRIZABLE_2981879413723745381)],
        &[(0b10010, &ENTRY_SATIRIZABLES_12495079216543111113)],
        &[(0b10010, &ENTRY_SATIRIZATION_5803523737972554169)],
        &[(0b10010, &ENTRY_SATIRIZE_4670452432959122101)],
        &[(0b10010, &ENTRY_SATIRIZED_7754739640320301410)],
        &[(0b10010, &ENTRY_SATIRIZER_852195482153342188)],
        &[(0b10010, &ENTRY_SATIRIZERS_15574884911196071567)],
        &[(0b10010, &ENTRY_SATIRIZES_10052925778146532918)],
        &[(0b10010, &ENTRY_SATIRIZING_1764005323783146105)],
        &[(0b01001, &ENTRY_SATIRIZABLE_2981879413723745381)],
        &[(0b01001, &ENTRY_SATIRIZABLES_12495079216543111113)],
        &[(0b01001, &ENTRY_SATIRIZATION_5803523737972554169)],
        &[(0b01001, &ENTRY_SATIRIZE_4670452432959122101)],
        &[(0b01001, &ENTRY_SATIRIZED_7754739640320301410)],
        &[(0b01001, &ENTRY_SATIRIZER_852195482153342188)],
        &[(0b01001, &ENTRY_SATIRIZERS_15574884911196071567)],
        &[(0b01001, &ENTRY_SATIRIZES_10052925778146532918)],
        &[(0b01001, &ENTRY_SATIRIZING_1764005323783146105)],
        &[(0b11010, &ENTRY_SATIVE_2657172684842563277)],
        &[(0b00001, &ENTRY_SATIVE_2657172684842563277)],
    ],
    range: 3..=10,
};

static VARS_SAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAS_CHILDREN),
    value: None,
};

pub static VARS_SAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sanidae"),
        dictgen::InsensitiveStr::Ascii("sanide"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SASSANIDE_5335894015828476896)],
        &[(0b00001, &ENTRY_SASSANIDE_5335894015828476896)],
    ],
    range: 6..=7,
};

static VARS_SAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAR_CHILDREN),
    value: None,
};

pub static VARS_SAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cinae"),
        dictgen::InsensitiveStr::Ascii("cine"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SARCINE_1474563832611431940)],
        &[(0b00001, &ENTRY_SARCINE_1474563832611431940)],
    ],
    range: 4..=5,
};

static VARS_SAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAP_CHILDREN),
    value: None,
};

pub static VARS_SAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ientise"),
        dictgen::InsensitiveStr::Ascii("ientises"),
        dictgen::InsensitiveStr::Ascii("ientize"),
        dictgen::InsensitiveStr::Ascii("ientizes"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("raemia"),
        dictgen::InsensitiveStr::Ascii("raemias"),
        dictgen::InsensitiveStr::Ascii("raemic"),
        dictgen::InsensitiveStr::Ascii("remia"),
        dictgen::InsensitiveStr::Ascii("remias"),
        dictgen::InsensitiveStr::Ascii("remic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SAPIENTIZE_14146190997329896957)],
        &[(0b10010, &ENTRY_SAPIENTIZES_16382959409533620025)],
        &[(0b01001, &ENTRY_SAPIENTIZE_14146190997329896957)],
        &[(0b01001, &ENTRY_SAPIENTIZES_16382959409533620025)],
        &[(0b00001, &ENTRY_SAPOR_14377617062405537073)],
        &[(0b00001, &ENTRY_SAPORS_15668621297825529733)],
        &[(0b11010, &ENTRY_SAPOR_14377617062405537073)],
        &[(0b11010, &ENTRY_SAPORS_15668621297825529733)],
        &[(0b11010, &ENTRY_SAPREMIA_10927593620047632704)],
        &[(0b11010, &ENTRY_SAPREMIAS_2393230130508325789)],
        &[(0b11010, &ENTRY_SAPREMIC_9405591661600178250)],
        &[(0b00001, &ENTRY_SAPREMIA_10927593620047632704)],
        &[(0b00001, &ENTRY_SAPREMIAS_2393230130508325789)],
        &[(0b00001, &ENTRY_SAPREMIC_9405591661600178250)],
    ],
    range: 2..=8,
};

static VARS_SAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAN_CHILDREN),
    value: None,
};

pub static VARS_SAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctuarise"),
        dictgen::InsensitiveStr::Ascii("ctuarised"),
        dictgen::InsensitiveStr::Ascii("ctuarises"),
        dictgen::InsensitiveStr::Ascii("ctuarising"),
        dictgen::InsensitiveStr::Ascii("ctuarize"),
        dictgen::InsensitiveStr::Ascii("ctuarized"),
        dictgen::InsensitiveStr::Ascii("ctuarizes"),
        dictgen::InsensitiveStr::Ascii("ctuarizing"),
        dictgen::InsensitiveStr::Ascii("daled"),
        dictgen::InsensitiveStr::Ascii("daling"),
        dictgen::InsensitiveStr::Ascii("dalled"),
        dictgen::InsensitiveStr::Ascii("dalling"),
        dictgen::InsensitiveStr::Ascii("ferd"),
        dictgen::InsensitiveStr::Ascii("forise"),
        dictgen::InsensitiveStr::Ascii("forises"),
        dictgen::InsensitiveStr::Ascii("forising"),
        dictgen::InsensitiveStr::Ascii("forize"),
        dictgen::InsensitiveStr::Ascii("forizes"),
        dictgen::InsensitiveStr::Ascii("forizing"),
        dictgen::InsensitiveStr::Ascii("fred"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itiser"),
        dictgen::InsensitiveStr::Ascii("itisers"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizer"),
        dictgen::InsensitiveStr::Ascii("itizers"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("skritise"),
        dictgen::InsensitiveStr::Ascii("skritize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SANCTUARIZE_2684033985693966023)],
        &[(0b10010, &ENTRY_SANCTUARIZED_13881929576576103541)],
        &[(0b10010, &ENTRY_SANCTUARIZES_886243961160484101)],
        &[(0b10010, &ENTRY_SANCTUARIZING_6723253584803089826)],
        &[(0b01001, &ENTRY_SANCTUARIZE_2684033985693966023)],
        &[(0b01001, &ENTRY_SANCTUARIZED_13881929576576103541)],
        &[(0b01001, &ENTRY_SANCTUARIZES_886243961160484101)],
        &[(0b01001, &ENTRY_SANCTUARIZING_6723253584803089826)],
        &[(0b00001, &ENTRY_SANDALED_13249873388295186265)],
        &[(0b00001, &ENTRY_SANDALING_7683116982062206539)],
        &[(0b11010, &ENTRY_SANDALED_13249873388295186265)],
        &[(0b11010, &ENTRY_SANDALING_7683116982062206539)],
        &[(0b00001, &ENTRY_SANFERD_7356557887418560168)],
        &[(0b10010, &ENTRY_SANFORIZE_4265814001637231765)],
        &[(0b10010, &ENTRY_SANFORIZES_2563826137147657575)],
        &[(0b10010, &ENTRY_SANFORIZING_2868487486423425023)],
        &[(0b01001, &ENTRY_SANFORIZE_4265814001637231765)],
        &[(0b01001, &ENTRY_SANFORIZES_2563826137147657575)],
        &[(0b01001, &ENTRY_SANFORIZING_2868487486423425023)],
        &[(0b11010, &ENTRY_SANFERD_7356557887418560168)],
        &[(0b10010, &ENTRY_SANITIZATION_10312415212709623714)],
        &[(0b10010, &ENTRY_SANITIZATIONS_8021402000169967705)],
        &[(0b10010, &ENTRY_SANITIZE_7331650509497054123)],
        &[(0b10010, &ENTRY_SANITIZED_5841984440856760755)],
        &[(0b10010, &ENTRY_SANITIZER_6961399843419580720)],
        &[(0b10010, &ENTRY_SANITIZERS_9114154210371871378)],
        &[(0b10010, &ENTRY_SANITIZES_14632226777926157749)],
        &[(0b10010, &ENTRY_SANITIZING_15814691895167354347)],
        &[(0b01001, &ENTRY_SANITIZATION_10312415212709623714)],
        &[(0b01001, &ENTRY_SANITIZATIONS_8021402000169967705)],
        &[(0b01001, &ENTRY_SANITIZE_7331650509497054123)],
        &[(0b01001, &ENTRY_SANITIZED_5841984440856760755)],
        &[(0b01001, &ENTRY_SANITIZER_6961399843419580720)],
        &[(0b01001, &ENTRY_SANITIZERS_9114154210371871378)],
        &[(0b01001, &ENTRY_SANITIZES_14632226777926157749)],
        &[(0b01001, &ENTRY_SANITIZING_15814691895167354347)],
        &[(0b10010, &ENTRY_SANSKRITIZE_8185278319719381954)],
        &[(0b01001, &ENTRY_SANSKRITIZE_8185278319719381954)],
    ],
    range: 4..=10,
};

static VARS_SAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAL_CHILDREN),
    value: None,
};

pub static VARS_SAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("able"),
        dictgen::InsensitiveStr::Ascii("abler"),
        dictgen::InsensitiveStr::Ascii("ablest"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("tiers"),
        dictgen::InsensitiveStr::Ascii("tierwise"),
        dictgen::InsensitiveStr::Ascii("tires"),
        dictgen::InsensitiveStr::Ascii("tirewise"),
        dictgen::InsensitiveStr::Ascii("tpeter"),
        dictgen::InsensitiveStr::Ascii("tpeters"),
        dictgen::InsensitiveStr::Ascii("tpetre"),
        dictgen::InsensitiveStr::Ascii("tpetres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SALABLE_13489586256964068577)],
        &[(0b00001, &ENTRY_SALABLER_2191562261555828404)],
        &[(0b00001, &ENTRY_SALABLEST_11739630936470269511)],
        &[(0b10010, &ENTRY_SALINIZATION_14249030620674770707)],
        &[(0b10010, &ENTRY_SALINIZE_1624463717219344911)],
        &[(0b10010, &ENTRY_SALINIZES_15735130644009593162)],
        &[(0b01001, &ENTRY_SALINIZATION_14249030620674770707)],
        &[(0b01001, &ENTRY_SALINIZE_1624463717219344911)],
        &[(0b01001, &ENTRY_SALINIZES_15735130644009593162)],
        &[(0b00001, &ENTRY_SALTIERS_15037062520661036868)],
        &[(0b00001, &ENTRY_SALTIERWISE_13939673853461651998)],
        &[(0b11010, &ENTRY_SALTIERS_15037062520661036868)],
        &[(0b11010, &ENTRY_SALTIERWISE_13939673853461651998)],
        &[(0b00001, &ENTRY_SALTPETER_1364613771688244608)],
        &[(0b00001, &ENTRY_SALTPETERS_13396036659008372276)],
        &[(0b11010, &ENTRY_SALTPETER_1364613771688244608)],
        &[(0b11010, &ENTRY_SALTPETERS_13396036659008372276)],
    ],
    range: 4..=9,
};

static VARS_SAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAI_CHILDREN),
    value: None,
};

pub static VARS_SAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lorising"),
        dictgen::InsensitiveStr::Ascii("lorisings"),
        dictgen::InsensitiveStr::Ascii("lorizing"),
        dictgen::InsensitiveStr::Ascii("lorizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SAILORIZING_10847894908498319787)],
        &[(0b10010, &ENTRY_SAILORIZINGS_828877064204542534)],
        &[(0b01001, &ENTRY_SAILORIZING_10847894908498319787)],
        &[(0b01001, &ENTRY_SAILORIZINGS_828877064204542534)],
    ],
    range: 8..=9,
};

static VARS_SAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAF_CHILDREN),
    value: None,
};

pub static VARS_SAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("ire"),
    ],
    values: &[
        &[(0b00001, &ENTRY_SAFIER_7130557169601659947)],
        &[(0b11010, &ENTRY_SAFIER_7130557169601659947)],
    ],
    range: 3..=3,
};

static VARS_SAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_SE_2594869031866220942)]),
};

pub static VARS_SAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("culum"),
        dictgen::InsensitiveStr::Ascii("culums"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("ta"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SECULUM_14580513950849648417)],
        &[(0b11010, &ENTRY_SECULUMS_1417148559086086183)],
        &[(0b11010, &ENTRY_SEED_321113364137294796)],
        &[(0b11010, &ENTRY_SETA_9673520022199067907)],
    ],
    range: 2..=6,
};

static VARS_SAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAC_CHILDREN),
    value: None,
};

pub static VARS_SAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("charisation"),
        dictgen::InsensitiveStr::Ascii("charisations"),
        dictgen::InsensitiveStr::Ascii("charise"),
        dictgen::InsensitiveStr::Ascii("charised"),
        dictgen::InsensitiveStr::Ascii("charises"),
        dictgen::InsensitiveStr::Ascii("charising"),
        dictgen::InsensitiveStr::Ascii("charization"),
        dictgen::InsensitiveStr::Ascii("charizations"),
        dictgen::InsensitiveStr::Ascii("charize"),
        dictgen::InsensitiveStr::Ascii("charized"),
        dictgen::InsensitiveStr::Ascii("charizes"),
        dictgen::InsensitiveStr::Ascii("charizing"),
        dictgen::InsensitiveStr::Ascii("erdotalise"),
        dictgen::InsensitiveStr::Ascii("erdotalised"),
        dictgen::InsensitiveStr::Ascii("erdotalises"),
        dictgen::InsensitiveStr::Ascii("erdotalising"),
        dictgen::InsensitiveStr::Ascii("erdotalize"),
        dictgen::InsensitiveStr::Ascii("erdotalized"),
        dictgen::InsensitiveStr::Ascii("erdotalizes"),
        dictgen::InsensitiveStr::Ascii("erdotalizing"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
        dictgen::InsensitiveStr::Ascii("ramentise"),
        dictgen::InsensitiveStr::Ascii("ramentises"),
        dictgen::InsensitiveStr::Ascii("ramentize"),
        dictgen::InsensitiveStr::Ascii("ramentizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_SACCHARIZATION_12951479435448622533)],
        &[(0b10010, &ENTRY_SACCHARIZATIONS_17924715140172127263)],
        &[(0b10010, &ENTRY_SACCHARIZE_8112536361258402472)],
        &[(0b10010, &ENTRY_SACCHARIZED_17475431280128284092)],
        &[(0b10010, &ENTRY_SACCHARIZES_17004868231094363900)],
        &[(0b10010, &ENTRY_SACCHARIZING_4047419846397824266)],
        &[(0b01001, &ENTRY_SACCHARIZATION_12951479435448622533)],
        &[(0b01001, &ENTRY_SACCHARIZATIONS_17924715140172127263)],
        &[(0b01001, &ENTRY_SACCHARIZE_8112536361258402472)],
        &[(0b01001, &ENTRY_SACCHARIZED_17475431280128284092)],
        &[(0b01001, &ENTRY_SACCHARIZES_17004868231094363900)],
        &[(0b01001, &ENTRY_SACCHARIZING_4047419846397824266)],
        &[(0b10010, &ENTRY_SACERDOTALIZE_6234124268374846096)],
        &[(0b10010, &ENTRY_SACERDOTALIZED_3090555217942359397)],
        &[(0b10010, &ENTRY_SACERDOTALIZES_3677365514994329629)],
        &[(0b10010, &ENTRY_SACERDOTALIZING_17120181135430251071)],
        &[(0b01001, &ENTRY_SACERDOTALIZE_6234124268374846096)],
        &[(0b01001, &ENTRY_SACERDOTALIZED_3090555217942359397)],
        &[(0b01001, &ENTRY_SACERDOTALIZES_3677365514994329629)],
        &[(0b01001, &ENTRY_SACERDOTALIZING_17120181135430251071)],
        &[(0b10010, &ENTRY_SACRALIZATION_1618414885145018191)],
        &[(0b10010, &ENTRY_SACRALIZATIONS_14811964160883679275)],
        &[(0b10010, &ENTRY_SACRALIZE_10390344760188291303)],
        &[(0b10010, &ENTRY_SACRALIZED_9465526025728376412)],
        &[(0b10010, &ENTRY_SACRALIZES_15118462953215987237)],
        &[(0b10010, &ENTRY_SACRALIZING_12013845710799024326)],
        &[(0b01001, &ENTRY_SACRALIZATION_1618414885145018191)],
        &[(0b01001, &ENTRY_SACRALIZATIONS_14811964160883679275)],
        &[(0b01001, &ENTRY_SACRALIZE_10390344760188291303)],
        &[(0b01001, &ENTRY_SACRALIZED_9465526025728376412)],
        &[(0b01001, &ENTRY_SACRALIZES_15118462953215987237)],
        &[(0b01001, &ENTRY_SACRALIZING_12013845710799024326)],
        &[(0b10010, &ENTRY_SACRAMENTIZE_5105033131237471754)],
        &[(0b10010, &ENTRY_SACRAMENTIZES_16943481266153665364)],
        &[(0b01001, &ENTRY_SACRAMENTIZE_5105033131237471754)],
        &[(0b01001, &ENTRY_SACRAMENTIZES_16943481266153665364)],
    ],
    range: 6..=12,
};

static VARS_SAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_SAB_CHILDREN),
    value: None,
};

pub static VARS_SAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("aeans"),
        dictgen::InsensitiveStr::Ascii("bathise"),
        dictgen::InsensitiveStr::Ascii("bathises"),
        dictgen::InsensitiveStr::Ascii("bathize"),
        dictgen::InsensitiveStr::Ascii("bathizes"),
        dictgen::InsensitiveStr::Ascii("batise"),
        dictgen::InsensitiveStr::Ascii("batised"),
        dictgen::InsensitiveStr::Ascii("batises"),
        dictgen::InsensitiveStr::Ascii("batising"),
        dictgen::InsensitiveStr::Ascii("batize"),
        dictgen::InsensitiveStr::Ascii("batized"),
        dictgen::InsensitiveStr::Ascii("batizes"),
        dictgen::InsensitiveStr::Ascii("batizing"),
        dictgen::InsensitiveStr::Ascii("ean"),
        dictgen::InsensitiveStr::Ascii("eans"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("erbill"),
        dictgen::InsensitiveStr::Ascii("ered"),
        dictgen::InsensitiveStr::Ascii("ering"),
        dictgen::InsensitiveStr::Ascii("erlike"),
        dictgen::InsensitiveStr::Ascii("erlikes"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ertooth"),
        dictgen::InsensitiveStr::Ascii("rebill"),
        dictgen::InsensitiveStr::Ascii("relike"),
        dictgen::InsensitiveStr::Ascii("relikes"),
        dictgen::InsensitiveStr::Ascii("retooth"),
    ],
    values: &[
        &[(0b11010, &ENTRY_SABEAN_3967530483638026323)],
        &[(0b11010, &ENTRY_SABEANS_6165241232825542997)],
        &[(0b10010, &ENTRY_SABBATHIZE_9135552393539099453)],
        &[(0b10010, &ENTRY_SABBATHIZES_14657735120604873546)],
        &[(0b01001, &ENTRY_SABBATHIZE_9135552393539099453)],
        &[(0b01001, &ENTRY_SABBATHIZES_14657735120604873546)],
        &[(0b10010, &ENTRY_SABBATIZE_9501648681615619705)],
        &[(0b10010, &ENTRY_SABBATIZED_13406040171945222761)],
        &[(0b10010, &ENTRY_SABBATIZES_15314102181592132563)],
        &[(0b10010, &ENTRY_SABBATIZING_12733815021350519705)],
        &[(0b01001, &ENTRY_SABBATIZE_9501648681615619705)],
        &[(0b01001, &ENTRY_SABBATIZED_13406040171945222761)],
        &[(0b01001, &ENTRY_SABBATIZES_15314102181592132563)],
        &[(0b01001, &ENTRY_SABBATIZING_12733815021350519705)],
        &[(0b00001, &ENTRY_SABEAN_3967530483638026323)],
        &[(0b00001, &ENTRY_SABEANS_6165241232825542997)],
        &[(0b00001, &ENTRY_SABER_11546898781047404082)],
        &[(0b00001, &ENTRY_SABERBILL_8906790336832465441)],
        &[(0b00001, &ENTRY_SABERED_6570351091920240802)],
        &[(0b00001, &ENTRY_SABERING_678610951848245655)],
        &[(0b00001, &ENTRY_SABERLIKE_13557431937207997081)],
        &[(0b00001, &ENTRY_SABERLIKES_11200825439513418213)],
        &[(0b00001, &ENTRY_SABERS_16530304349268606792)],
        &[(0b00001, &ENTRY_SABERTOOTH_232682195526621441)],
        &[(0b11010, &ENTRY_SABERBILL_8906790336832465441)],
        &[(0b11010, &ENTRY_SABERLIKE_13557431937207997081)],
        &[(0b11010, &ENTRY_SABERLIKES_11200825439513418213)],
        &[(0b11010, &ENTRY_SABERTOOTH_232682195526621441)],
    ],
    range: 2..=8,
};

static VARS_R_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_R_CHILDREN),
    value: None,
};

static VARS_R_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_RA_NODE),
    None,
    None,
    None,
    Some(&VARS_RE_NODE),
    None,
    None,
    Some(&VARS_RH_NODE),
    Some(&VARS_RI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_RU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RU_CHILDREN),
    value: None,
};

static VARS_RU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_RUB_NODE),
    None,
    None,
    None,
    Some(&VARS_RUF_NODE),
    Some(&VARS_RUG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RUM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_RUR_NODE),
    Some(&VARS_RUS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_RUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUS_CHILDREN),
    value: None,
};

pub static VARS_RUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sianisation"),
        dictgen::InsensitiveStr::Ascii("sianisations"),
        dictgen::InsensitiveStr::Ascii("sianise"),
        dictgen::InsensitiveStr::Ascii("sianised"),
        dictgen::InsensitiveStr::Ascii("sianises"),
        dictgen::InsensitiveStr::Ascii("sianising"),
        dictgen::InsensitiveStr::Ascii("sianization"),
        dictgen::InsensitiveStr::Ascii("sianizations"),
        dictgen::InsensitiveStr::Ascii("sianize"),
        dictgen::InsensitiveStr::Ascii("sianized"),
        dictgen::InsensitiveStr::Ascii("sianizes"),
        dictgen::InsensitiveStr::Ascii("sianizing"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RUSSIANIZATION_16898768923421263030)],
        &[(0b10010, &ENTRY_RUSSIANIZATIONS_11585141916754458789)],
        &[(0b10010, &ENTRY_RUSSIANIZE_9206676310088840254)],
        &[(0b10010, &ENTRY_RUSSIANIZED_15749625767358498066)],
        &[(0b10010, &ENTRY_RUSSIANIZES_16645859177250529320)],
        &[(0b10010, &ENTRY_RUSSIANIZING_12272597000608712547)],
        &[(0b01001, &ENTRY_RUSSIANIZATION_16898768923421263030)],
        &[(0b01001, &ENTRY_RUSSIANIZATIONS_11585141916754458789)],
        &[(0b01001, &ENTRY_RUSSIANIZE_9206676310088840254)],
        &[(0b01001, &ENTRY_RUSSIANIZED_15749625767358498066)],
        &[(0b01001, &ENTRY_RUSSIANIZES_16645859177250529320)],
        &[(0b01001, &ENTRY_RUSSIANIZING_12272597000608712547)],
        &[(0b10010, &ENTRY_RUSTICIZE_12734614119488995185)],
        &[(0b10010, &ENTRY_RUSTICIZED_8719798803495007326)],
        &[(0b10010, &ENTRY_RUSTICIZES_5457546844148812271)],
        &[(0b10010, &ENTRY_RUSTICIZING_2240961739878480538)],
        &[(0b01001, &ENTRY_RUSTICIZE_12734614119488995185)],
        &[(0b01001, &ENTRY_RUSTICIZED_8719798803495007326)],
        &[(0b01001, &ENTRY_RUSTICIZES_5457546844148812271)],
        &[(0b01001, &ENTRY_RUSTICIZING_2240961739878480538)],
    ],
    range: 6..=12,
};

static VARS_RUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUR_CHILDREN),
    value: None,
};

pub static VARS_RUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RURALIZATION_12199675531569627500)],
        &[(0b10010, &ENTRY_RURALIZATIONS_18364650995853039163)],
        &[(0b10010, &ENTRY_RURALIZE_10315684701653459711)],
        &[(0b10010, &ENTRY_RURALIZED_10330894529989453328)],
        &[(0b10010, &ENTRY_RURALIZES_2177534473483628527)],
        &[(0b10010, &ENTRY_RURALIZING_13347398545539483501)],
        &[(0b01001, &ENTRY_RURALIZATION_12199675531569627500)],
        &[(0b01001, &ENTRY_RURALIZATIONS_18364650995853039163)],
        &[(0b01001, &ENTRY_RURALIZE_10315684701653459711)],
        &[(0b01001, &ENTRY_RURALIZED_10330894529989453328)],
        &[(0b01001, &ENTRY_RURALIZES_2177534473483628527)],
        &[(0b01001, &ENTRY_RURALIZING_13347398545539483501)],
    ],
    range: 5..=10,
};

static VARS_RUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUM_CHILDREN),
    value: None,
};

pub static VARS_RUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("ormonger"),
        dictgen::InsensitiveStr::Ascii("ormongers"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourmonger"),
        dictgen::InsensitiveStr::Ascii("ourmongers"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_RUMOR_9709120178518195057)],
        &[(0b11001, &ENTRY_RUMORED_18309275267346665123)],
        &[(0b00001, &ENTRY_RUMORER_11488343213641948242)],
        &[(0b00001, &ENTRY_RUMORERS_6357305227935379172)],
        &[(0b11001, &ENTRY_RUMORING_2328261845579723307)],
        &[(0b10001, &ENTRY_RUMORMONGER_7299548335065542796)],
        &[(0b10001, &ENTRY_RUMORMONGERS_12499750377413614176)],
        &[(0b11001, &ENTRY_RUMORS_4907921740910409378)],
        &[(0b11010, &ENTRY_RUMOR_9709120178518195057)],
        &[(0b11010, &ENTRY_RUMORED_18309275267346665123)],
        &[(0b11010, &ENTRY_RUMORER_11488343213641948242)],
        &[(0b11010, &ENTRY_RUMORERS_6357305227935379172)],
        &[(0b11010, &ENTRY_RUMORING_2328261845579723307)],
        &[(0b11010, &ENTRY_RUMORMONGER_7299548335065542796)],
        &[(0b11010, &ENTRY_RUMORMONGERS_12499750377413614176)],
        &[(0b11010, &ENTRY_RUMORS_4907921740910409378)],
    ],
    range: 2..=10,
};

static VARS_RUG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUG_CHILDREN),
    value: None,
};

pub static VARS_RUG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gedisation"),
        dictgen::InsensitiveStr::Ascii("gedisations"),
        dictgen::InsensitiveStr::Ascii("gedise"),
        dictgen::InsensitiveStr::Ascii("gedised"),
        dictgen::InsensitiveStr::Ascii("gedises"),
        dictgen::InsensitiveStr::Ascii("gedising"),
        dictgen::InsensitiveStr::Ascii("gedization"),
        dictgen::InsensitiveStr::Ascii("gedizations"),
        dictgen::InsensitiveStr::Ascii("gedize"),
        dictgen::InsensitiveStr::Ascii("gedized"),
        dictgen::InsensitiveStr::Ascii("gedizes"),
        dictgen::InsensitiveStr::Ascii("gedizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RUGGEDIZATION_5669230878299551336)],
        &[(0b10010, &ENTRY_RUGGEDIZATIONS_632588497204849835)],
        &[(0b10010, &ENTRY_RUGGEDIZE_452263712716974983)],
        &[(0b10010, &ENTRY_RUGGEDIZED_16294057666793563055)],
        &[(0b10010, &ENTRY_RUGGEDIZES_16648500507504288559)],
        &[(0b10010, &ENTRY_RUGGEDIZING_10631138816687857349)],
        &[(0b01001, &ENTRY_RUGGEDIZATION_5669230878299551336)],
        &[(0b01001, &ENTRY_RUGGEDIZATIONS_632588497204849835)],
        &[(0b01001, &ENTRY_RUGGEDIZE_452263712716974983)],
        &[(0b01001, &ENTRY_RUGGEDIZED_16294057666793563055)],
        &[(0b01001, &ENTRY_RUGGEDIZES_16648500507504288559)],
        &[(0b01001, &ENTRY_RUGGEDIZING_10631138816687857349)],
    ],
    range: 6..=11,
};

static VARS_RUF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUF_CHILDREN),
    value: None,
};

pub static VARS_RUF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fianise"),
        dictgen::InsensitiveStr::Ascii("fianises"),
        dictgen::InsensitiveStr::Ascii("fianize"),
        dictgen::InsensitiveStr::Ascii("fianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RUFFIANIZE_17407878081648774516)],
        &[(0b10010, &ENTRY_RUFFIANIZES_14576217936902384026)],
        &[(0b01001, &ENTRY_RUFFIANIZE_17407878081648774516)],
        &[(0b01001, &ENTRY_RUFFIANIZES_14576217936902384026)],
    ],
    range: 7..=8,
};

static VARS_RUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RUB_CHILDREN),
    value: None,
};

pub static VARS_RUB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("berisation"),
        dictgen::InsensitiveStr::Ascii("berise"),
        dictgen::InsensitiveStr::Ascii("berised"),
        dictgen::InsensitiveStr::Ascii("berises"),
        dictgen::InsensitiveStr::Ascii("berising"),
        dictgen::InsensitiveStr::Ascii("berization"),
        dictgen::InsensitiveStr::Ascii("berize"),
        dictgen::InsensitiveStr::Ascii("berized"),
        dictgen::InsensitiveStr::Ascii("berizes"),
        dictgen::InsensitiveStr::Ascii("berizing"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("les"),
        dictgen::InsensitiveStr::Ascii("ricise"),
        dictgen::InsensitiveStr::Ascii("ricises"),
        dictgen::InsensitiveStr::Ascii("ricize"),
        dictgen::InsensitiveStr::Ascii("ricizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RUBBERIZATION_3122682324183377228)],
        &[(0b10010, &ENTRY_RUBBERIZE_8534952429152157034)],
        &[(0b10010, &ENTRY_RUBBERIZED_15637607135983122135)],
        &[(0b10010, &ENTRY_RUBBERIZES_3912030953974462546)],
        &[(0b10010, &ENTRY_RUBBERIZING_5203082318061539960)],
        &[(0b01001, &ENTRY_RUBBERIZATION_3122682324183377228)],
        &[(0b01001, &ENTRY_RUBBERIZE_8534952429152157034)],
        &[(0b01001, &ENTRY_RUBBERIZED_15637607135983122135)],
        &[(0b01001, &ENTRY_RUBBERIZES_3912030953974462546)],
        &[(0b01001, &ENTRY_RUBBERIZING_5203082318061539960)],
        &[(0b00001, &ENTRY_RUBLE_10117878449438778810)],
        &[(0b00001, &ENTRY_RUBLES_5273455018786501602)],
        &[(0b10010, &ENTRY_RUBRICIZE_9836541413862092246)],
        &[(0b10010, &ENTRY_RUBRICIZES_6613684611958202027)],
        &[(0b01001, &ENTRY_RUBRICIZE_9836541413862092246)],
        &[(0b01001, &ENTRY_RUBRICIZES_6613684611958202027)],
    ],
    range: 2..=10,
};

static VARS_RO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RO_CHILDREN),
    value: None,
};

static VARS_RO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_ROB_NODE),
    None,
    None,
    Some(&VARS_ROE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ROM_NODE),
    None,
    Some(&VARS_ROO_NODE),
    None,
    None,
    Some(&VARS_ROR_NODE),
    None,
    None,
    Some(&VARS_ROU_NODE),
    None,
    Some(&VARS_ROW_NODE),
    None,
    Some(&VARS_ROY_NODE),
    None,
];

static VARS_ROY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROY_CHILDREN),
    value: None,
};

pub static VARS_ROY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ROYALIZATION_11067381201878855200)],
        &[(0b10010, &ENTRY_ROYALIZATIONS_16712363081334842649)],
        &[(0b10010, &ENTRY_ROYALIZE_14272296856251086161)],
        &[(0b10010, &ENTRY_ROYALIZED_5272390552778035423)],
        &[(0b10010, &ENTRY_ROYALIZES_806193357964394419)],
        &[(0b10010, &ENTRY_ROYALIZING_3246861064960016421)],
        &[(0b01001, &ENTRY_ROYALIZATION_11067381201878855200)],
        &[(0b01001, &ENTRY_ROYALIZATIONS_16712363081334842649)],
        &[(0b01001, &ENTRY_ROYALIZE_14272296856251086161)],
        &[(0b01001, &ENTRY_ROYALIZED_5272390552778035423)],
        &[(0b01001, &ENTRY_ROYALIZES_806193357964394419)],
        &[(0b01001, &ENTRY_ROYALIZING_3246861064960016421)],
    ],
    range: 5..=10,
};

static VARS_ROW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROW_CHILDREN),
    value: None,
};

pub static VARS_ROW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b01001, &ENTRY_ROWELED_13637303372527211405)],
        &[(0b01001, &ENTRY_ROWELING_13952035716222413490)],
        &[(0b11010, &ENTRY_ROWELED_13637303372527211405)],
        &[(0b11010, &ENTRY_ROWELING_13952035716222413490)],
    ],
    range: 4..=6,
};

static VARS_ROU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROU_CHILDREN),
    value: None,
};

pub static VARS_ROU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ble"),
        dictgen::InsensitiveStr::Ascii("bles"),
        dictgen::InsensitiveStr::Ascii("mania"),
        dictgen::InsensitiveStr::Ascii("manias"),
        dictgen::InsensitiveStr::Ascii("tinisation"),
        dictgen::InsensitiveStr::Ascii("tinisations"),
        dictgen::InsensitiveStr::Ascii("tinise"),
        dictgen::InsensitiveStr::Ascii("tinised"),
        dictgen::InsensitiveStr::Ascii("tinises"),
        dictgen::InsensitiveStr::Ascii("tinising"),
        dictgen::InsensitiveStr::Ascii("tinization"),
        dictgen::InsensitiveStr::Ascii("tinizations"),
        dictgen::InsensitiveStr::Ascii("tinize"),
        dictgen::InsensitiveStr::Ascii("tinized"),
        dictgen::InsensitiveStr::Ascii("tinizes"),
        dictgen::InsensitiveStr::Ascii("tinizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_RUBLE_10117878449438778810)],
        &[(0b11010, &ENTRY_RUBLES_5273455018786501602)],
        &[(0b11010, &ENTRY_ROMANIA_14647491915869407300)],
        &[(0b11010, &ENTRY_ROMANIAS_9441434726837892631)],
        &[(0b10010, &ENTRY_ROUTINIZATION_16656207668238320072)],
        &[(0b10010, &ENTRY_ROUTINIZATIONS_15252472006215427062)],
        &[(0b10010, &ENTRY_ROUTINIZE_5626420320204126115)],
        &[(0b10010, &ENTRY_ROUTINIZED_1851279582216291255)],
        &[(0b10010, &ENTRY_ROUTINIZES_2715007322555254066)],
        &[(0b10010, &ENTRY_ROUTINIZING_6227530109158853879)],
        &[(0b01001, &ENTRY_ROUTINIZATION_16656207668238320072)],
        &[(0b01001, &ENTRY_ROUTINIZATIONS_15252472006215427062)],
        &[(0b01001, &ENTRY_ROUTINIZE_5626420320204126115)],
        &[(0b01001, &ENTRY_ROUTINIZED_1851279582216291255)],
        &[(0b01001, &ENTRY_ROUTINIZES_2715007322555254066)],
        &[(0b01001, &ENTRY_ROUTINIZING_6227530109158853879)],
    ],
    range: 3..=11,
};

static VARS_ROR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROR_CHILDREN),
    value: None,
};

pub static VARS_ROR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b11010, &ENTRY_ROER_9399565430831118531)]],
    range: 1..=1,
};

static VARS_ROO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROO_CHILDREN),
    value: None,
};

pub static VARS_ROO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ed")],
    values: &[&[(0b11010, &ENTRY_ROED_7491598846688934647)]],
    range: 2..=2,
};

static VARS_ROM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROM_CHILDREN),
    value: None,
};

pub static VARS_ROM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ania"),
        dictgen::InsensitiveStr::Ascii("anias"),
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anisers"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizers"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("anticisation"),
        dictgen::InsensitiveStr::Ascii("anticisations"),
        dictgen::InsensitiveStr::Ascii("anticise"),
        dictgen::InsensitiveStr::Ascii("anticised"),
        dictgen::InsensitiveStr::Ascii("anticises"),
        dictgen::InsensitiveStr::Ascii("anticising"),
        dictgen::InsensitiveStr::Ascii("anticization"),
        dictgen::InsensitiveStr::Ascii("anticizations"),
        dictgen::InsensitiveStr::Ascii("anticize"),
        dictgen::InsensitiveStr::Ascii("anticized"),
        dictgen::InsensitiveStr::Ascii("anticizes"),
        dictgen::InsensitiveStr::Ascii("anticizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ROMANIA_14647491915869407300)],
        &[(0b00001, &ENTRY_ROMANIAS_9441434726837892631)],
        &[(0b10010, &ENTRY_ROMANIZATION_1812649176047396288)],
        &[(0b10010, &ENTRY_ROMANIZATIONS_9179904637420783701)],
        &[(0b10010, &ENTRY_ROMANIZE_2020383270516389989)],
        &[(0b10010, &ENTRY_ROMANIZED_8188127372098085668)],
        &[(0b10010, &ENTRY_ROMANIZER_10910799684441102818)],
        &[(0b10010, &ENTRY_ROMANIZERS_7186572903998412475)],
        &[(0b10010, &ENTRY_ROMANIZES_7603852869065493171)],
        &[(0b10010, &ENTRY_ROMANIZING_1191652903917979672)],
        &[(0b01001, &ENTRY_ROMANIZATION_1812649176047396288)],
        &[(0b01001, &ENTRY_ROMANIZATIONS_9179904637420783701)],
        &[(0b01001, &ENTRY_ROMANIZE_2020383270516389989)],
        &[(0b01001, &ENTRY_ROMANIZED_8188127372098085668)],
        &[(0b01001, &ENTRY_ROMANIZER_10910799684441102818)],
        &[(0b01001, &ENTRY_ROMANIZERS_7186572903998412475)],
        &[(0b01001, &ENTRY_ROMANIZES_7603852869065493171)],
        &[(0b01001, &ENTRY_ROMANIZING_1191652903917979672)],
        &[(0b10010, &ENTRY_ROMANTICIZATION_1655615510397751437)],
        &[(0b10010, &ENTRY_ROMANTICIZATIONS_14371809476146672855)],
        &[(0b10010, &ENTRY_ROMANTICIZE_17291657258585049672)],
        &[(0b10010, &ENTRY_ROMANTICIZED_10936525722537335211)],
        &[(0b10010, &ENTRY_ROMANTICIZES_14376155573214247856)],
        &[(0b10010, &ENTRY_ROMANTICIZING_7257111435910768108)],
        &[(0b01001, &ENTRY_ROMANTICIZATION_1655615510397751437)],
        &[(0b01001, &ENTRY_ROMANTICIZATIONS_14371809476146672855)],
        &[(0b01001, &ENTRY_ROMANTICIZE_17291657258585049672)],
        &[(0b01001, &ENTRY_ROMANTICIZED_10936525722537335211)],
        &[(0b01001, &ENTRY_ROMANTICIZES_14376155573214247856)],
        &[(0b01001, &ENTRY_ROMANTICIZING_7257111435910768108)],
    ],
    range: 4..=13,
};

static VARS_ROE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROE_CHILDREN),
    value: None,
};

pub static VARS_ROE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("hm"),
        dictgen::InsensitiveStr::Ascii("ntgenise"),
        dictgen::InsensitiveStr::Ascii("ntgenize"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ROED_7491598846688934647)],
        &[(0b11010, &ENTRY_REHM_1954003150274029388)],
        &[(0b10010, &ENTRY_ROENTGENIZE_10746435571343043012)],
        &[(0b01001, &ENTRY_ROENTGENIZE_10746435571343043012)],
        &[(0b00001, &ENTRY_ROER_9399565430831118531)],
    ],
    range: 1..=8,
};

static VARS_ROB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ROB_CHILDREN),
    value: None,
};

pub static VARS_ROB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otisation"),
        dictgen::InsensitiveStr::Ascii("otisations"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otization"),
        dictgen::InsensitiveStr::Ascii("otizations"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ROBOTIZATION_10442464385649584788)],
        &[(0b10010, &ENTRY_ROBOTIZATIONS_11624944842780950110)],
        &[(0b10010, &ENTRY_ROBOTIZE_1822365081322284994)],
        &[(0b10010, &ENTRY_ROBOTIZED_6871096401872030909)],
        &[(0b10010, &ENTRY_ROBOTIZES_8084732757819391045)],
        &[(0b10010, &ENTRY_ROBOTIZING_9767982352083703401)],
        &[(0b01001, &ENTRY_ROBOTIZATION_10442464385649584788)],
        &[(0b01001, &ENTRY_ROBOTIZATIONS_11624944842780950110)],
        &[(0b01001, &ENTRY_ROBOTIZE_1822365081322284994)],
        &[(0b01001, &ENTRY_ROBOTIZED_6871096401872030909)],
        &[(0b01001, &ENTRY_ROBOTIZES_8084732757819391045)],
        &[(0b01001, &ENTRY_ROBOTIZING_9767982352083703401)],
    ],
    range: 5..=10,
};

static VARS_RI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RI_CHILDREN),
    value: None,
};

pub static VARS_RI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("diculise"),
        dictgen::InsensitiveStr::Ascii("diculises"),
        dictgen::InsensitiveStr::Ascii("diculize"),
        dictgen::InsensitiveStr::Ascii("diculizes"),
        dictgen::InsensitiveStr::Ascii("gidise"),
        dictgen::InsensitiveStr::Ascii("gidised"),
        dictgen::InsensitiveStr::Ascii("gidises"),
        dictgen::InsensitiveStr::Ascii("gidising"),
        dictgen::InsensitiveStr::Ascii("gidize"),
        dictgen::InsensitiveStr::Ascii("gidized"),
        dictgen::InsensitiveStr::Ascii("gidizes"),
        dictgen::InsensitiveStr::Ascii("gidizing"),
        dictgen::InsensitiveStr::Ascii("gor"),
        dictgen::InsensitiveStr::Ascii("gorism"),
        dictgen::InsensitiveStr::Ascii("gorist"),
        dictgen::InsensitiveStr::Ascii("goristic"),
        dictgen::InsensitiveStr::Ascii("gors"),
        dictgen::InsensitiveStr::Ascii("gour"),
        dictgen::InsensitiveStr::Ascii("gourism"),
        dictgen::InsensitiveStr::Ascii("gourist"),
        dictgen::InsensitiveStr::Ascii("gouristic"),
        dictgen::InsensitiveStr::Ascii("gours"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("tornelle"),
        dictgen::InsensitiveStr::Ascii("tornelles"),
        dictgen::InsensitiveStr::Ascii("tournelle"),
        dictgen::InsensitiveStr::Ascii("tournelles"),
        dictgen::InsensitiveStr::Ascii("tualisation"),
        dictgen::InsensitiveStr::Ascii("tualisations"),
        dictgen::InsensitiveStr::Ascii("tualise"),
        dictgen::InsensitiveStr::Ascii("tualised"),
        dictgen::InsensitiveStr::Ascii("tualises"),
        dictgen::InsensitiveStr::Ascii("tualising"),
        dictgen::InsensitiveStr::Ascii("tualization"),
        dictgen::InsensitiveStr::Ascii("tualizations"),
        dictgen::InsensitiveStr::Ascii("tualize"),
        dictgen::InsensitiveStr::Ascii("tualized"),
        dictgen::InsensitiveStr::Ascii("tualizes"),
        dictgen::InsensitiveStr::Ascii("tualizing"),
        dictgen::InsensitiveStr::Ascii("valed"),
        dictgen::InsensitiveStr::Ascii("valess"),
        dictgen::InsensitiveStr::Ascii("valesses"),
        dictgen::InsensitiveStr::Ascii("valing"),
        dictgen::InsensitiveStr::Ascii("valise"),
        dictgen::InsensitiveStr::Ascii("valised"),
        dictgen::InsensitiveStr::Ascii("valises"),
        dictgen::InsensitiveStr::Ascii("valising"),
        dictgen::InsensitiveStr::Ascii("valize"),
        dictgen::InsensitiveStr::Ascii("valized"),
        dictgen::InsensitiveStr::Ascii("valizes"),
        dictgen::InsensitiveStr::Ascii("valizing"),
        dictgen::InsensitiveStr::Ascii("valled"),
        dictgen::InsensitiveStr::Ascii("valless"),
        dictgen::InsensitiveStr::Ascii("vallesses"),
        dictgen::InsensitiveStr::Ascii("valling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RIDICULIZE_1054636858349594298)],
        &[(0b10010, &ENTRY_RIDICULIZES_14575559099525792123)],
        &[(0b01001, &ENTRY_RIDICULIZE_1054636858349594298)],
        &[(0b01001, &ENTRY_RIDICULIZES_14575559099525792123)],
        &[(0b10010, &ENTRY_RIGIDIZE_156720177693369344)],
        &[(0b10010, &ENTRY_RIGIDIZED_2511443842946442888)],
        &[(0b10010, &ENTRY_RIGIDIZES_8642244566818162964)],
        &[(0b10010, &ENTRY_RIGIDIZING_14021102904701047671)],
        &[(0b01001, &ENTRY_RIGIDIZE_156720177693369344)],
        &[(0b01001, &ENTRY_RIGIDIZED_2511443842946442888)],
        &[(0b01001, &ENTRY_RIGIDIZES_8642244566818162964)],
        &[(0b01001, &ENTRY_RIGIDIZING_14021102904701047671)],
        &[(0b11001, &ENTRY_RIGOR_6127041250190650208)],
        &[(0b00001, &ENTRY_RIGORISM_14069127364398578519)],
        &[(0b00001, &ENTRY_RIGORIST_6703622095815747851)],
        &[(0b00001, &ENTRY_RIGORISTIC_12345844524001178474)],
        &[(0b11001, &ENTRY_RIGORS_163306158062409929)],
        &[(0b11010, &ENTRY_RIGOR_6127041250190650208)],
        &[(0b11010, &ENTRY_RIGORISM_14069127364398578519)],
        &[(0b11010, &ENTRY_RIGORIST_6703622095815747851)],
        &[(0b11010, &ENTRY_RIGORISTIC_12345844524001178474)],
        &[(0b11010, &ENTRY_RIGORS_163306158062409929)],
        &[(0b10010, &ENTRY_RIOTIZE_6719680474007390438)],
        &[(0b10010, &ENTRY_RIOTIZES_17355146657912726592)],
        &[(0b01001, &ENTRY_RIOTIZE_6719680474007390438)],
        &[(0b01001, &ENTRY_RIOTIZES_17355146657912726592)],
        &[(0b00001, &ENTRY_RITORNELLE_12914215580998668402)],
        &[(0b00001, &ENTRY_RITORNELLES_18174381851390434260)],
        &[(0b11010, &ENTRY_RITORNELLE_12914215580998668402)],
        &[(0b11010, &ENTRY_RITORNELLES_18174381851390434260)],
        &[(0b10010, &ENTRY_RITUALIZATION_17705479449777175846)],
        &[(0b10010, &ENTRY_RITUALIZATIONS_6446107650917771589)],
        &[(0b10010, &ENTRY_RITUALIZE_10559347390928816833)],
        &[(0b10010, &ENTRY_RITUALIZED_14603675570872660022)],
        &[(0b10010, &ENTRY_RITUALIZES_6743897608838025402)],
        &[(0b10010, &ENTRY_RITUALIZING_5584795455479400064)],
        &[(0b01001, &ENTRY_RITUALIZATION_17705479449777175846)],
        &[(0b01001, &ENTRY_RITUALIZATIONS_6446107650917771589)],
        &[(0b01001, &ENTRY_RITUALIZE_10559347390928816833)],
        &[(0b01001, &ENTRY_RITUALIZED_14603675570872660022)],
        &[(0b01001, &ENTRY_RITUALIZES_6743897608838025402)],
        &[(0b01001, &ENTRY_RITUALIZING_5584795455479400064)],
        &[(0b00001, &ENTRY_RIVALED_1310914145976397449)],
        &[(0b00001, &ENTRY_RIVALESS_17030046039543701469)],
        &[(0b00001, &ENTRY_RIVALESSES_7896212397487020650)],
        &[(0b00001, &ENTRY_RIVALING_6945496358803583057)],
        &[(0b10010, &ENTRY_RIVALIZE_7944174065886798683)],
        &[(0b10010, &ENTRY_RIVALIZED_7182768422071390801)],
        &[(0b10010, &ENTRY_RIVALIZES_2452557101215464168)],
        &[(0b10010, &ENTRY_RIVALIZING_14048952717153236037)],
        &[(0b01001, &ENTRY_RIVALIZE_7944174065886798683)],
        &[(0b01001, &ENTRY_RIVALIZED_7182768422071390801)],
        &[(0b01001, &ENTRY_RIVALIZES_2452557101215464168)],
        &[(0b01001, &ENTRY_RIVALIZING_14048952717153236037)],
        &[(0b11010, &ENTRY_RIVALED_1310914145976397449)],
        &[(0b11010, &ENTRY_RIVALESS_17030046039543701469)],
        &[(0b11010, &ENTRY_RIVALESSES_7896212397487020650)],
        &[(0b11010, &ENTRY_RIVALING_6945496358803583057)],
    ],
    range: 3..=12,
};

static VARS_RH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RH_CHILDREN),
    value: None,
};

static VARS_RH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_RHA_NODE),
    None,
    None,
    None,
    Some(&VARS_RHE_NODE),
    None,
    None,
    None,
    Some(&VARS_RHI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RHO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RHY_NODE),
    None,
];

static VARS_RHY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHY_CHILDREN),
    value: None,
};

pub static VARS_RHY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thmicise"),
        dictgen::InsensitiveStr::Ascii("thmicises"),
        dictgen::InsensitiveStr::Ascii("thmicize"),
        dictgen::InsensitiveStr::Ascii("thmicizes"),
        dictgen::InsensitiveStr::Ascii("thmisable"),
        dictgen::InsensitiveStr::Ascii("thmisables"),
        dictgen::InsensitiveStr::Ascii("thmisation"),
        dictgen::InsensitiveStr::Ascii("thmisations"),
        dictgen::InsensitiveStr::Ascii("thmise"),
        dictgen::InsensitiveStr::Ascii("thmised"),
        dictgen::InsensitiveStr::Ascii("thmises"),
        dictgen::InsensitiveStr::Ascii("thmising"),
        dictgen::InsensitiveStr::Ascii("thmizable"),
        dictgen::InsensitiveStr::Ascii("thmizables"),
        dictgen::InsensitiveStr::Ascii("thmization"),
        dictgen::InsensitiveStr::Ascii("thmizations"),
        dictgen::InsensitiveStr::Ascii("thmize"),
        dictgen::InsensitiveStr::Ascii("thmized"),
        dictgen::InsensitiveStr::Ascii("thmizes"),
        dictgen::InsensitiveStr::Ascii("thmizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RHYTHMICIZE_5163197837266584786)],
        &[(0b10010, &ENTRY_RHYTHMICIZES_6647633033339306298)],
        &[(0b01001, &ENTRY_RHYTHMICIZE_5163197837266584786)],
        &[(0b01001, &ENTRY_RHYTHMICIZES_6647633033339306298)],
        &[(0b10010, &ENTRY_RHYTHMIZABLE_2677462370618412645)],
        &[(0b10010, &ENTRY_RHYTHMIZABLES_17776105921216752906)],
        &[(0b10010, &ENTRY_RHYTHMIZATION_16019734668485258402)],
        &[(0b10010, &ENTRY_RHYTHMIZATIONS_7293786921946666216)],
        &[(0b10010, &ENTRY_RHYTHMIZE_10511981276106529519)],
        &[(0b10010, &ENTRY_RHYTHMIZED_5132054189203196434)],
        &[(0b10010, &ENTRY_RHYTHMIZES_5770183289187248055)],
        &[(0b10010, &ENTRY_RHYTHMIZING_4940630798632079527)],
        &[(0b01001, &ENTRY_RHYTHMIZABLE_2677462370618412645)],
        &[(0b01001, &ENTRY_RHYTHMIZABLES_17776105921216752906)],
        &[(0b01001, &ENTRY_RHYTHMIZATION_16019734668485258402)],
        &[(0b01001, &ENTRY_RHYTHMIZATIONS_7293786921946666216)],
        &[(0b01001, &ENTRY_RHYTHMIZE_10511981276106529519)],
        &[(0b01001, &ENTRY_RHYTHMIZED_5132054189203196434)],
        &[(0b01001, &ENTRY_RHYTHMIZES_5770183289187248055)],
        &[(0b01001, &ENTRY_RHYTHMIZING_4940630798632079527)],
    ],
    range: 6..=11,
};

static VARS_RHO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHO_CHILDREN),
    value: None,
};

pub static VARS_RHO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("danise"),
        dictgen::InsensitiveStr::Ascii("danised"),
        dictgen::InsensitiveStr::Ascii("danises"),
        dictgen::InsensitiveStr::Ascii("danising"),
        dictgen::InsensitiveStr::Ascii("danize"),
        dictgen::InsensitiveStr::Ascii("danized"),
        dictgen::InsensitiveStr::Ascii("danizes"),
        dictgen::InsensitiveStr::Ascii("danizing"),
        dictgen::InsensitiveStr::Ascii("eadine"),
        dictgen::InsensitiveStr::Ascii("tacise"),
        dictgen::InsensitiveStr::Ascii("tacised"),
        dictgen::InsensitiveStr::Ascii("tacises"),
        dictgen::InsensitiveStr::Ascii("tacising"),
        dictgen::InsensitiveStr::Ascii("tacize"),
        dictgen::InsensitiveStr::Ascii("tacized"),
        dictgen::InsensitiveStr::Ascii("tacizes"),
        dictgen::InsensitiveStr::Ascii("tacizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RHODANIZE_302153013978993410)],
        &[(0b10010, &ENTRY_RHODANIZED_12583740850093807678)],
        &[(0b10010, &ENTRY_RHODANIZES_12761949215613135994)],
        &[(0b10010, &ENTRY_RHODANIZING_15623745248128814712)],
        &[(0b01001, &ENTRY_RHODANIZE_302153013978993410)],
        &[(0b01001, &ENTRY_RHODANIZED_12583740850093807678)],
        &[(0b01001, &ENTRY_RHODANIZES_12761949215613135994)],
        &[(0b01001, &ENTRY_RHODANIZING_15623745248128814712)],
        &[(0b11010, &ENTRY_RHEADINE_9620364319130309940)],
        &[(0b10010, &ENTRY_RHOTACIZE_2196984425576687851)],
        &[(0b10010, &ENTRY_RHOTACIZED_9176740167556084330)],
        &[(0b10010, &ENTRY_RHOTACIZES_700796813593687972)],
        &[(0b10010, &ENTRY_RHOTACIZING_1370798169034491463)],
        &[(0b01001, &ENTRY_RHOTACIZE_2196984425576687851)],
        &[(0b01001, &ENTRY_RHOTACIZED_9176740167556084330)],
        &[(0b01001, &ENTRY_RHOTACIZES_700796813593687972)],
        &[(0b01001, &ENTRY_RHOTACIZING_1370798169034491463)],
    ],
    range: 6..=8,
};

static VARS_RHI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHI_CHILDREN),
    value: None,
};

pub static VARS_RHI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nocele"),
        dictgen::InsensitiveStr::Ascii("nocelian"),
        dictgen::InsensitiveStr::Ascii("nocoele"),
        dictgen::InsensitiveStr::Ascii("nocoelian"),
        dictgen::InsensitiveStr::Ascii("norrhea"),
        dictgen::InsensitiveStr::Ascii("norrheal"),
        dictgen::InsensitiveStr::Ascii("norrhoea"),
        dictgen::InsensitiveStr::Ascii("norrhoeal"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RHINOCELE_13394138248730638628)],
        &[(0b00001, &ENTRY_RHINOCELIAN_7468732235130691380)],
        &[(0b11010, &ENTRY_RHINOCELE_13394138248730638628)],
        &[(0b11010, &ENTRY_RHINOCELIAN_7468732235130691380)],
        &[(0b00001, &ENTRY_RHINORRHEA_17760754621625220758)],
        &[(0b00001, &ENTRY_RHINORRHEAL_4168671082299209434)],
        &[(0b11010, &ENTRY_RHINORRHEA_17760754621625220758)],
        &[(0b11010, &ENTRY_RHINORRHEAL_4168671082299209434)],
    ],
    range: 6..=9,
};

static VARS_RHE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHE_CHILDREN),
    value: None,
};

pub static VARS_RHE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adine"),
        dictgen::InsensitiveStr::Ascii("bosis"),
        dictgen::InsensitiveStr::Ascii("tian"),
        dictgen::InsensitiveStr::Ascii("tic"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torising"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("torizing"),
        dictgen::InsensitiveStr::Ascii("umatise"),
        dictgen::InsensitiveStr::Ascii("umatised"),
        dictgen::InsensitiveStr::Ascii("umatises"),
        dictgen::InsensitiveStr::Ascii("umatising"),
        dictgen::InsensitiveStr::Ascii("umatize"),
        dictgen::InsensitiveStr::Ascii("umatized"),
        dictgen::InsensitiveStr::Ascii("umatizes"),
        dictgen::InsensitiveStr::Ascii("umatizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RHEADINE_9620364319130309940)],
        &[(0b00001, &ENTRY_RHEBOSIS_5734830824723368566)],
        &[(0b00001, &ENTRY_RHETIAN_7773375067640200565)],
        &[(0b00001, &ENTRY_RHETIC_18110954895356174940)],
        &[(0b10010, &ENTRY_RHETORIZE_15085474485565052687)],
        &[(0b10010, &ENTRY_RHETORIZED_12036770468694769802)],
        &[(0b10010, &ENTRY_RHETORIZES_11610320224318377716)],
        &[(0b10010, &ENTRY_RHETORIZING_4161503331833209409)],
        &[(0b01001, &ENTRY_RHETORIZE_15085474485565052687)],
        &[(0b01001, &ENTRY_RHETORIZED_12036770468694769802)],
        &[(0b01001, &ENTRY_RHETORIZES_11610320224318377716)],
        &[(0b01001, &ENTRY_RHETORIZING_4161503331833209409)],
        &[(0b10010, &ENTRY_RHEUMATIZE_1531026966882650471)],
        &[(0b10010, &ENTRY_RHEUMATIZED_5025722576540634515)],
        &[(0b10010, &ENTRY_RHEUMATIZES_5411071701844053603)],
        &[(0b10010, &ENTRY_RHEUMATIZING_16915712102407745517)],
        &[(0b01001, &ENTRY_RHEUMATIZE_1531026966882650471)],
        &[(0b01001, &ENTRY_RHEUMATIZED_5025722576540634515)],
        &[(0b01001, &ENTRY_RHEUMATIZES_5411071701844053603)],
        &[(0b01001, &ENTRY_RHEUMATIZING_16915712102407745517)],
    ],
    range: 3..=9,
};

static VARS_RHA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RHA_CHILDREN),
    value: None,
};

pub static VARS_RHA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ebosis"),
        dictgen::InsensitiveStr::Ascii("etian"),
        dictgen::InsensitiveStr::Ascii("etic"),
        dictgen::InsensitiveStr::Ascii("phae"),
        dictgen::InsensitiveStr::Ascii("phe"),
        dictgen::InsensitiveStr::Ascii("psodise"),
        dictgen::InsensitiveStr::Ascii("psodised"),
        dictgen::InsensitiveStr::Ascii("psodises"),
        dictgen::InsensitiveStr::Ascii("psodising"),
        dictgen::InsensitiveStr::Ascii("psodize"),
        dictgen::InsensitiveStr::Ascii("psodized"),
        dictgen::InsensitiveStr::Ascii("psodizes"),
        dictgen::InsensitiveStr::Ascii("psodizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_RHEBOSIS_5734830824723368566)],
        &[(0b11010, &ENTRY_RHETIAN_7773375067640200565)],
        &[(0b11010, &ENTRY_RHETIC_18110954895356174940)],
        &[(0b11010, &ENTRY_RHAPHE_12384818764664453874)],
        &[(0b00001, &ENTRY_RHAPHE_12384818764664453874)],
        &[(0b10010, &ENTRY_RHAPSODIZE_12516177585413432849)],
        &[(0b10010, &ENTRY_RHAPSODIZED_11519621996184024336)],
        &[(0b10010, &ENTRY_RHAPSODIZES_7765267067797422211)],
        &[(0b10010, &ENTRY_RHAPSODIZING_13362377815551382619)],
        &[(0b01001, &ENTRY_RHAPSODIZE_12516177585413432849)],
        &[(0b01001, &ENTRY_RHAPSODIZED_11519621996184024336)],
        &[(0b01001, &ENTRY_RHAPSODIZES_7765267067797422211)],
        &[(0b01001, &ENTRY_RHAPSODIZING_13362377815551382619)],
    ],
    range: 3..=9,
};

static VARS_RE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RE_CHILDREN),
    value: None,
};

static VARS_RE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_REA_NODE),
    Some(&VARS_REB_NODE),
    Some(&VARS_REC_NODE),
    Some(&VARS_RED_NODE),
    Some(&VARS_REE_NODE),
    Some(&VARS_REF_NODE),
    Some(&VARS_REG_NODE),
    Some(&VARS_REH_NODE),
    Some(&VARS_REI_NODE),
    Some(&VARS_REJ_NODE),
    Some(&VARS_REK_NODE),
    Some(&VARS_REL_NODE),
    Some(&VARS_REM_NODE),
    Some(&VARS_REN_NODE),
    Some(&VARS_REO_NODE),
    Some(&VARS_REP_NODE),
    None,
    Some(&VARS_RER_NODE),
    Some(&VARS_RES_NODE),
    Some(&VARS_RET_NODE),
    Some(&VARS_REU_NODE),
    Some(&VARS_REV_NODE),
    None,
    Some(&VARS_REX_NODE),
    None,
    None,
];

static VARS_REX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REX_CHILDREN),
    value: None,
};

pub static VARS_REX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ford"),
        dictgen::InsensitiveStr::Ascii("fourd"),
    ],
    values: &[
        &[(0b00001, &ENTRY_REXFORD_3887609989644811794)],
        &[(0b11010, &ENTRY_REXFORD_3887609989644811794)],
    ],
    range: 4..=5,
};

static VARS_REV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REV_CHILDREN),
    value: None,
};

static VARS_REV_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_REVA_NODE),
    None,
    None,
    None,
    Some(&VARS_REVE_NODE),
    None,
    None,
    None,
    Some(&VARS_REVI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_REVO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_REVO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REVO_CHILDREN),
    value: None,
};

pub static VARS_REVO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("latilise"),
        dictgen::InsensitiveStr::Ascii("latilises"),
        dictgen::InsensitiveStr::Ascii("latilize"),
        dictgen::InsensitiveStr::Ascii("latilizes"),
        dictgen::InsensitiveStr::Ascii("lutionise"),
        dictgen::InsensitiveStr::Ascii("lutionised"),
        dictgen::InsensitiveStr::Ascii("lutionisement"),
        dictgen::InsensitiveStr::Ascii("lutionisements"),
        dictgen::InsensitiveStr::Ascii("lutioniser"),
        dictgen::InsensitiveStr::Ascii("lutionisers"),
        dictgen::InsensitiveStr::Ascii("lutionises"),
        dictgen::InsensitiveStr::Ascii("lutionising"),
        dictgen::InsensitiveStr::Ascii("lutionize"),
        dictgen::InsensitiveStr::Ascii("lutionized"),
        dictgen::InsensitiveStr::Ascii("lutionizement"),
        dictgen::InsensitiveStr::Ascii("lutionizements"),
        dictgen::InsensitiveStr::Ascii("lutionizer"),
        dictgen::InsensitiveStr::Ascii("lutionizers"),
        dictgen::InsensitiveStr::Ascii("lutionizes"),
        dictgen::InsensitiveStr::Ascii("lutionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REVOLATILIZE_2071105640143175086)],
        &[(0b10010, &ENTRY_REVOLATILIZES_261087607754605694)],
        &[(0b01001, &ENTRY_REVOLATILIZE_2071105640143175086)],
        &[(0b01001, &ENTRY_REVOLATILIZES_261087607754605694)],
        &[(0b10010, &ENTRY_REVOLUTIONIZE_7544492450899006022)],
        &[(0b10010, &ENTRY_REVOLUTIONIZED_14375673469401672065)],
        &[(0b10010, &ENTRY_REVOLUTIONIZEMENT_3712613042773672198)],
        &[(0b10010, &ENTRY_REVOLUTIONIZEMENTS_8372696219470999573)],
        &[(0b10010, &ENTRY_REVOLUTIONIZER_13149778382986804291)],
        &[(0b10010, &ENTRY_REVOLUTIONIZERS_8217397059633187294)],
        &[(0b10010, &ENTRY_REVOLUTIONIZES_6397868062466700275)],
        &[(0b10010, &ENTRY_REVOLUTIONIZING_5584470119488633133)],
        &[(0b01001, &ENTRY_REVOLUTIONIZE_7544492450899006022)],
        &[(0b01001, &ENTRY_REVOLUTIONIZED_14375673469401672065)],
        &[(0b01001, &ENTRY_REVOLUTIONIZEMENT_3712613042773672198)],
        &[(0b01001, &ENTRY_REVOLUTIONIZEMENTS_8372696219470999573)],
        &[(0b01001, &ENTRY_REVOLUTIONIZER_13149778382986804291)],
        &[(0b01001, &ENTRY_REVOLUTIONIZERS_8217397059633187294)],
        &[(0b01001, &ENTRY_REVOLUTIONIZES_6397868062466700275)],
        &[(0b01001, &ENTRY_REVOLUTIONIZING_5584470119488633133)],
    ],
    range: 8..=14,
};

static VARS_REVI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REVI_CHILDREN),
    value: None,
};

pub static VARS_REVI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gor"),
        dictgen::InsensitiveStr::Ascii("gour"),
        dictgen::InsensitiveStr::Ascii("sualisation"),
        dictgen::InsensitiveStr::Ascii("sualisations"),
        dictgen::InsensitiveStr::Ascii("sualise"),
        dictgen::InsensitiveStr::Ascii("sualises"),
        dictgen::InsensitiveStr::Ascii("sualization"),
        dictgen::InsensitiveStr::Ascii("sualizations"),
        dictgen::InsensitiveStr::Ascii("sualize"),
        dictgen::InsensitiveStr::Ascii("sualizes"),
        dictgen::InsensitiveStr::Ascii("talisation"),
        dictgen::InsensitiveStr::Ascii("talisations"),
        dictgen::InsensitiveStr::Ascii("talise"),
        dictgen::InsensitiveStr::Ascii("talised"),
        dictgen::InsensitiveStr::Ascii("taliser"),
        dictgen::InsensitiveStr::Ascii("talisers"),
        dictgen::InsensitiveStr::Ascii("talises"),
        dictgen::InsensitiveStr::Ascii("talising"),
        dictgen::InsensitiveStr::Ascii("talization"),
        dictgen::InsensitiveStr::Ascii("talizations"),
        dictgen::InsensitiveStr::Ascii("talize"),
        dictgen::InsensitiveStr::Ascii("talized"),
        dictgen::InsensitiveStr::Ascii("talizer"),
        dictgen::InsensitiveStr::Ascii("talizers"),
        dictgen::InsensitiveStr::Ascii("talizes"),
        dictgen::InsensitiveStr::Ascii("talizing"),
        dictgen::InsensitiveStr::Ascii("valise"),
        dictgen::InsensitiveStr::Ascii("valises"),
        dictgen::InsensitiveStr::Ascii("valize"),
        dictgen::InsensitiveStr::Ascii("valizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_REVIGOR_2376178882147635752)],
        &[(0b11010, &ENTRY_REVIGOR_2376178882147635752)],
        &[(0b10010, &ENTRY_REVISUALIZATION_8953713191827785558)],
        &[(0b10010, &ENTRY_REVISUALIZATIONS_5722856801090540723)],
        &[(0b10010, &ENTRY_REVISUALIZE_10854082452689148747)],
        &[(0b10010, &ENTRY_REVISUALIZES_757435382058959188)],
        &[(0b01001, &ENTRY_REVISUALIZATION_8953713191827785558)],
        &[(0b01001, &ENTRY_REVISUALIZATIONS_5722856801090540723)],
        &[(0b01001, &ENTRY_REVISUALIZE_10854082452689148747)],
        &[(0b01001, &ENTRY_REVISUALIZES_757435382058959188)],
        &[(0b10010, &ENTRY_REVITALIZATION_13062486022413792020)],
        &[(0b10010, &ENTRY_REVITALIZATIONS_10832630253278670475)],
        &[(0b10010, &ENTRY_REVITALIZE_193715103532234630)],
        &[(0b10010, &ENTRY_REVITALIZED_8383897663298145675)],
        &[(0b10010, &ENTRY_REVITALIZER_1269369318155795055)],
        &[(0b10010, &ENTRY_REVITALIZERS_8120596477873838119)],
        &[(0b10010, &ENTRY_REVITALIZES_17733294788931304767)],
        &[(0b10010, &ENTRY_REVITALIZING_16112731945721210438)],
        &[(0b01001, &ENTRY_REVITALIZATION_13062486022413792020)],
        &[(0b01001, &ENTRY_REVITALIZATIONS_10832630253278670475)],
        &[(0b01001, &ENTRY_REVITALIZE_193715103532234630)],
        &[(0b01001, &ENTRY_REVITALIZED_8383897663298145675)],
        &[(0b01001, &ENTRY_REVITALIZER_1269369318155795055)],
        &[(0b01001, &ENTRY_REVITALIZERS_8120596477873838119)],
        &[(0b01001, &ENTRY_REVITALIZES_17733294788931304767)],
        &[(0b01001, &ENTRY_REVITALIZING_16112731945721210438)],
        &[(0b10010, &ENTRY_REVIVALIZE_12399394256488111764)],
        &[(0b10010, &ENTRY_REVIVALIZES_3796336163019290557)],
        &[(0b01001, &ENTRY_REVIVALIZE_12399394256488111764)],
        &[(0b01001, &ENTRY_REVIVALIZES_3796336163019290557)],
    ],
    range: 3..=12,
};

static VARS_REVE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REVE_CHILDREN),
    value: None,
};

pub static VARS_REVE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lationise"),
        dictgen::InsensitiveStr::Ascii("lationises"),
        dictgen::InsensitiveStr::Ascii("lationize"),
        dictgen::InsensitiveStr::Ascii("lationizes"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lings"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("llings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REVELATIONIZE_5638146163757517114)],
        &[(0b10010, &ENTRY_REVELATIONIZES_5374780340001639912)],
        &[(0b01001, &ENTRY_REVELATIONIZE_5638146163757517114)],
        &[(0b01001, &ENTRY_REVELATIONIZES_5374780340001639912)],
        &[(0b00001, &ENTRY_REVELED_3269597357727386753)],
        &[(0b00001, &ENTRY_REVELER_6411534393495033889)],
        &[(0b00001, &ENTRY_REVELERS_6407829396102668960)],
        &[(0b00001, &ENTRY_REVELING_7333428498196314928)],
        &[(0b00001, &ENTRY_REVELINGS_14514277807211085480)],
        &[(0b11010, &ENTRY_REVELED_3269597357727386753)],
        &[(0b11010, &ENTRY_REVELER_6411534393495033889)],
        &[(0b11010, &ENTRY_REVELERS_6407829396102668960)],
        &[(0b11010, &ENTRY_REVELING_7333428498196314928)],
        &[(0b11010, &ENTRY_REVELINGS_14514277807211085480)],
    ],
    range: 3..=10,
};

static VARS_REVA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REVA_CHILDREN),
    value: None,
};

pub static VARS_REVA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lenta"),
        dictgen::InsensitiveStr::Ascii("lentas"),
        dictgen::InsensitiveStr::Ascii("lorisation"),
        dictgen::InsensitiveStr::Ascii("lorisations"),
        dictgen::InsensitiveStr::Ascii("lorise"),
        dictgen::InsensitiveStr::Ascii("lorised"),
        dictgen::InsensitiveStr::Ascii("lorises"),
        dictgen::InsensitiveStr::Ascii("lorising"),
        dictgen::InsensitiveStr::Ascii("lorization"),
        dictgen::InsensitiveStr::Ascii("lorizations"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorized"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
        dictgen::InsensitiveStr::Ascii("lorizing"),
        dictgen::InsensitiveStr::Ascii("porise"),
        dictgen::InsensitiveStr::Ascii("porises"),
        dictgen::InsensitiveStr::Ascii("porization"),
        dictgen::InsensitiveStr::Ascii("porizations"),
        dictgen::InsensitiveStr::Ascii("porize"),
        dictgen::InsensitiveStr::Ascii("porizes"),
        dictgen::InsensitiveStr::Ascii("pourisation"),
        dictgen::InsensitiveStr::Ascii("pourisations"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ERVALENTA_10785450433515167284)],
        &[(0b11010, &ENTRY_ERVALENTAS_18174157063570728071)],
        &[(0b10010, &ENTRY_REVALORIZATION_16691637355795598388)],
        &[(0b10010, &ENTRY_REVALORIZATIONS_8329585362057485832)],
        &[(0b10010, &ENTRY_REVALORIZE_2146865524723286062)],
        &[(0b10010, &ENTRY_REVALORIZED_390002619883458956)],
        &[(0b10010, &ENTRY_REVALORIZES_9002308862045152018)],
        &[(0b10010, &ENTRY_REVALORIZING_15461035195176448361)],
        &[(0b01001, &ENTRY_REVALORIZATION_16691637355795598388)],
        &[(0b01001, &ENTRY_REVALORIZATIONS_8329585362057485832)],
        &[(0b01001, &ENTRY_REVALORIZE_2146865524723286062)],
        &[(0b01001, &ENTRY_REVALORIZED_390002619883458956)],
        &[(0b01001, &ENTRY_REVALORIZES_9002308862045152018)],
        &[(0b01001, &ENTRY_REVALORIZING_15461035195176448361)],
        &[(0b10010, &ENTRY_REVAPORIZE_7400570187982142267)],
        &[(0b10010, &ENTRY_REVAPORIZES_10059326494130071423)],
        &[(0b01001, &ENTRY_REVAPORIZATION_13446372973926423118)],
        &[(0b01001, &ENTRY_REVAPORIZATIONS_5789264572660925070)],
        &[(0b01001, &ENTRY_REVAPORIZE_7400570187982142267)],
        &[(0b01001, &ENTRY_REVAPORIZES_10059326494130071423)],
        &[(0b10010, &ENTRY_REVAPORIZATION_13446372973926423118)],
        &[(0b10010, &ENTRY_REVAPORIZATIONS_5789264572660925070)],
    ],
    range: 5..=12,
};

static VARS_REU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REU_CHILDREN),
    value: None,
};

pub static VARS_REU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilising"),
        dictgen::InsensitiveStr::Ascii("tilization"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilized"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
        dictgen::InsensitiveStr::Ascii("tilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REUTILIZATION_2443696530088053698)],
        &[(0b10010, &ENTRY_REUTILIZE_1981534996476836105)],
        &[(0b10010, &ENTRY_REUTILIZED_16677084184753064782)],
        &[(0b10010, &ENTRY_REUTILIZES_14294564954952197276)],
        &[(0b10010, &ENTRY_REUTILIZING_4912219485422295764)],
        &[(0b01001, &ENTRY_REUTILIZATION_2443696530088053698)],
        &[(0b01001, &ENTRY_REUTILIZE_1981534996476836105)],
        &[(0b01001, &ENTRY_REUTILIZED_16677084184753064782)],
        &[(0b01001, &ENTRY_REUTILIZES_14294564954952197276)],
        &[(0b01001, &ENTRY_REUTILIZING_4912219485422295764)],
    ],
    range: 6..=10,
};

static VARS_RET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RET_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_ERT_3341098308248153715)]),
};

pub static VARS_RET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inulae"),
        dictgen::InsensitiveStr::Ascii("inule"),
        dictgen::InsensitiveStr::Ascii("ranquilise"),
        dictgen::InsensitiveStr::Ascii("ranquilises"),
        dictgen::InsensitiveStr::Ascii("ranquilize"),
        dictgen::InsensitiveStr::Ascii("ranquilizes"),
        dictgen::InsensitiveStr::Ascii("rocaecal"),
        dictgen::InsensitiveStr::Ascii("rocecal"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RETINIZE_8601446109320109567)],
        &[(0b10010, &ENTRY_RETINIZES_17069507706296598945)],
        &[(0b01001, &ENTRY_RETINIZE_8601446109320109567)],
        &[(0b01001, &ENTRY_RETINIZES_17069507706296598945)],
        &[(0b11010, &ENTRY_RETINULE_17387772655780198016)],
        &[(0b00001, &ENTRY_RETINULE_17387772655780198016)],
        &[(0b10010, &ENTRY_RETRANQUILIZE_10089381173173353384)],
        &[(0b10010, &ENTRY_RETRANQUILIZES_11477435536722915071)],
        &[(0b01001, &ENTRY_RETRANQUILIZE_10089381173173353384)],
        &[(0b01001, &ENTRY_RETRANQUILIZES_11477435536722915071)],
        &[(0b11010, &ENTRY_RETROCECAL_264766737757922842)],
        &[(0b00001, &ENTRY_RETROCECAL_264766737757922842)],
    ],
    range: 5..=11,
};

static VARS_RES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RES_CHILDREN),
    value: None,
};

static VARS_RES_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_RESE_NODE),
    None,
    None,
    Some(&VARS_RESH_NODE),
    Some(&VARS_RESI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RESO_NODE),
    Some(&VARS_RESP_NODE),
    None,
    None,
    None,
    Some(&VARS_REST_NODE),
    Some(&VARS_RESU_NODE),
    None,
    None,
    None,
    Some(&VARS_RESY_NODE),
    None,
];

static VARS_RESY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESY_CHILDREN),
    value: None,
};

pub static VARS_RESY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mbolisation"),
        dictgen::InsensitiveStr::Ascii("mbolisations"),
        dictgen::InsensitiveStr::Ascii("mbolise"),
        dictgen::InsensitiveStr::Ascii("mbolises"),
        dictgen::InsensitiveStr::Ascii("mbolization"),
        dictgen::InsensitiveStr::Ascii("mbolizations"),
        dictgen::InsensitiveStr::Ascii("mbolize"),
        dictgen::InsensitiveStr::Ascii("mbolizes"),
        dictgen::InsensitiveStr::Ascii("nchronisation"),
        dictgen::InsensitiveStr::Ascii("nchronisations"),
        dictgen::InsensitiveStr::Ascii("nchronise"),
        dictgen::InsensitiveStr::Ascii("nchronised"),
        dictgen::InsensitiveStr::Ascii("nchronises"),
        dictgen::InsensitiveStr::Ascii("nchronising"),
        dictgen::InsensitiveStr::Ascii("nchronization"),
        dictgen::InsensitiveStr::Ascii("nchronizations"),
        dictgen::InsensitiveStr::Ascii("nchronize"),
        dictgen::InsensitiveStr::Ascii("nchronized"),
        dictgen::InsensitiveStr::Ascii("nchronizes"),
        dictgen::InsensitiveStr::Ascii("nchronizing"),
        dictgen::InsensitiveStr::Ascii("nthesise"),
        dictgen::InsensitiveStr::Ascii("nthesises"),
        dictgen::InsensitiveStr::Ascii("nthesize"),
        dictgen::InsensitiveStr::Ascii("nthesizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESYMBOLIZATION_18289962759086702120)],
        &[(0b10010, &ENTRY_RESYMBOLIZATIONS_13698200804085478042)],
        &[(0b10010, &ENTRY_RESYMBOLIZE_14905039520367290035)],
        &[(0b10010, &ENTRY_RESYMBOLIZES_15380238287856922249)],
        &[(0b01001, &ENTRY_RESYMBOLIZATION_18289962759086702120)],
        &[(0b01001, &ENTRY_RESYMBOLIZATIONS_13698200804085478042)],
        &[(0b01001, &ENTRY_RESYMBOLIZE_14905039520367290035)],
        &[(0b01001, &ENTRY_RESYMBOLIZES_15380238287856922249)],
        &[(0b10010, &ENTRY_RESYNCHRONIZATION_5015538818065006720)],
        &[(0b10010, &ENTRY_RESYNCHRONIZATIONS_15270865884370608060)],
        &[(0b10010, &ENTRY_RESYNCHRONIZE_2523532124129456381)],
        &[(0b10010, &ENTRY_RESYNCHRONIZED_3132801989882471857)],
        &[(0b10010, &ENTRY_RESYNCHRONIZES_5801125742459097915)],
        &[(0b10010, &ENTRY_RESYNCHRONIZING_2324560686252943876)],
        &[(0b01001, &ENTRY_RESYNCHRONIZATION_5015538818065006720)],
        &[(0b01001, &ENTRY_RESYNCHRONIZATIONS_15270865884370608060)],
        &[(0b01001, &ENTRY_RESYNCHRONIZE_2523532124129456381)],
        &[(0b01001, &ENTRY_RESYNCHRONIZED_3132801989882471857)],
        &[(0b01001, &ENTRY_RESYNCHRONIZES_5801125742459097915)],
        &[(0b01001, &ENTRY_RESYNCHRONIZING_2324560686252943876)],
        &[(0b10010, &ENTRY_RESYNTHESIZE_8960121186358208467)],
        &[(0b10010, &ENTRY_RESYNTHESIZES_5964175748046341312)],
        &[(0b01001, &ENTRY_RESYNTHESIZE_8960121186358208467)],
        &[(0b01001, &ENTRY_RESYNTHESIZES_5964175748046341312)],
    ],
    range: 7..=14,
};

static VARS_RESU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESU_CHILDREN),
    value: None,
};

pub static VARS_RESU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rrectionise"),
        dictgen::InsensitiveStr::Ascii("rrectionised"),
        dictgen::InsensitiveStr::Ascii("rrectionises"),
        dictgen::InsensitiveStr::Ascii("rrectionising"),
        dictgen::InsensitiveStr::Ascii("rrectionize"),
        dictgen::InsensitiveStr::Ascii("rrectionized"),
        dictgen::InsensitiveStr::Ascii("rrectionizes"),
        dictgen::InsensitiveStr::Ascii("rrectionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESURRECTIONIZE_6291356889036253818)],
        &[(0b10010, &ENTRY_RESURRECTIONIZED_9400111854395469022)],
        &[(0b10010, &ENTRY_RESURRECTIONIZES_13187140164794979295)],
        &[(0b10010, &ENTRY_RESURRECTIONIZING_691774540853612989)],
        &[(0b01001, &ENTRY_RESURRECTIONIZE_6291356889036253818)],
        &[(0b01001, &ENTRY_RESURRECTIONIZED_9400111854395469022)],
        &[(0b01001, &ENTRY_RESURRECTIONIZES_13187140164794979295)],
        &[(0b01001, &ENTRY_RESURRECTIONIZING_691774540853612989)],
    ],
    range: 11..=13,
};

static VARS_REST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REST_CHILDREN),
    value: None,
};

pub static VARS_REST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andardisation"),
        dictgen::InsensitiveStr::Ascii("andardisations"),
        dictgen::InsensitiveStr::Ascii("andardise"),
        dictgen::InsensitiveStr::Ascii("andardises"),
        dictgen::InsensitiveStr::Ascii("andardization"),
        dictgen::InsensitiveStr::Ascii("andardizations"),
        dictgen::InsensitiveStr::Ascii("andardize"),
        dictgen::InsensitiveStr::Ascii("andardizes"),
        dictgen::InsensitiveStr::Ascii("erilise"),
        dictgen::InsensitiveStr::Ascii("erilises"),
        dictgen::InsensitiveStr::Ascii("erilize"),
        dictgen::InsensitiveStr::Ascii("erilizes"),
        dictgen::InsensitiveStr::Ascii("igmatise"),
        dictgen::InsensitiveStr::Ascii("igmatises"),
        dictgen::InsensitiveStr::Ascii("igmatize"),
        dictgen::InsensitiveStr::Ascii("igmatizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESTANDARDIZATION_1125896047095372970)],
        &[(0b10010, &ENTRY_RESTANDARDIZATIONS_13459493042218397698)],
        &[(0b10010, &ENTRY_RESTANDARDIZE_8395056711505036016)],
        &[(0b10010, &ENTRY_RESTANDARDIZES_16671190134442482587)],
        &[(0b01001, &ENTRY_RESTANDARDIZATION_1125896047095372970)],
        &[(0b01001, &ENTRY_RESTANDARDIZATIONS_13459493042218397698)],
        &[(0b01001, &ENTRY_RESTANDARDIZE_8395056711505036016)],
        &[(0b01001, &ENTRY_RESTANDARDIZES_16671190134442482587)],
        &[(0b10010, &ENTRY_RESTERILIZE_4378046269917637799)],
        &[(0b10010, &ENTRY_RESTERILIZES_6083780946048684800)],
        &[(0b01001, &ENTRY_RESTERILIZE_4378046269917637799)],
        &[(0b01001, &ENTRY_RESTERILIZES_6083780946048684800)],
        &[(0b10010, &ENTRY_RESTIGMATIZE_4978105981890694357)],
        &[(0b10010, &ENTRY_RESTIGMATIZES_6711731024062346456)],
        &[(0b01001, &ENTRY_RESTIGMATIZE_4978105981890694357)],
        &[(0b01001, &ENTRY_RESTIGMATIZES_6711731024062346456)],
    ],
    range: 7..=14,
};

static VARS_RESP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESP_CHILDREN),
    value: None,
};

pub static VARS_RESP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectabilise"),
        dictgen::InsensitiveStr::Ascii("ectabilised"),
        dictgen::InsensitiveStr::Ascii("ectabilises"),
        dictgen::InsensitiveStr::Ascii("ectabilising"),
        dictgen::InsensitiveStr::Ascii("ectabilize"),
        dictgen::InsensitiveStr::Ascii("ectabilized"),
        dictgen::InsensitiveStr::Ascii("ectabilizes"),
        dictgen::InsensitiveStr::Ascii("ectabilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESPECTABILIZE_11155380117077366918)],
        &[(0b10010, &ENTRY_RESPECTABILIZED_14730970511118216639)],
        &[(0b10010, &ENTRY_RESPECTABILIZES_14602704037450130293)],
        &[(0b10010, &ENTRY_RESPECTABILIZING_10915529601473940175)],
        &[(0b01001, &ENTRY_RESPECTABILIZE_11155380117077366918)],
        &[(0b01001, &ENTRY_RESPECTABILIZED_14730970511118216639)],
        &[(0b01001, &ENTRY_RESPECTABILIZES_14602704037450130293)],
        &[(0b01001, &ENTRY_RESPECTABILIZING_10915529601473940175)],
    ],
    range: 10..=12,
};

static VARS_RESO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESO_CHILDREN),
    value: None,
};

pub static VARS_RESO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lemnise"),
        dictgen::InsensitiveStr::Ascii("lemnises"),
        dictgen::InsensitiveStr::Ascii("lemnize"),
        dictgen::InsensitiveStr::Ascii("lemnizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESOLEMNIZE_6056068872801503882)],
        &[(0b10010, &ENTRY_RESOLEMNIZES_10613919753057256614)],
        &[(0b01001, &ENTRY_RESOLEMNIZE_6056068872801503882)],
        &[(0b01001, &ENTRY_RESOLEMNIZES_10613919753057256614)],
    ],
    range: 7..=8,
};

static VARS_RESI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESI_CHILDREN),
    value: None,
};

pub static VARS_RESI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESINIZE_14451332919662209430)],
        &[(0b10010, &ENTRY_RESINIZED_13345987737745617709)],
        &[(0b10010, &ENTRY_RESINIZES_7409295825688368205)],
        &[(0b10010, &ENTRY_RESINIZING_7347311689783160837)],
        &[(0b01001, &ENTRY_RESINIZE_14451332919662209430)],
        &[(0b01001, &ENTRY_RESINIZED_13345987737745617709)],
        &[(0b01001, &ENTRY_RESINIZES_7409295825688368205)],
        &[(0b01001, &ENTRY_RESINIZING_7347311689783160837)],
    ],
    range: 4..=6,
};

static VARS_RESH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESH_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_ERSH_939187057767591954)]),
};

pub static VARS_RESH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("oes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RESHES_14193366709422680589)],
        &[(0b11010, &ENTRY_RESHES_14193366709422680589)],
    ],
    range: 2..=3,
};

static VARS_RESE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RESE_CHILDREN),
    value: None,
};

pub static VARS_RESE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("nsitisation"),
        dictgen::InsensitiveStr::Ascii("nsitisations"),
        dictgen::InsensitiveStr::Ascii("nsitise"),
        dictgen::InsensitiveStr::Ascii("nsitises"),
        dictgen::InsensitiveStr::Ascii("nsitization"),
        dictgen::InsensitiveStr::Ascii("nsitizations"),
        dictgen::InsensitiveStr::Ascii("nsitize"),
        dictgen::InsensitiveStr::Ascii("nsitizes"),
        dictgen::InsensitiveStr::Ascii("pulcher"),
        dictgen::InsensitiveStr::Ascii("pulchers"),
        dictgen::InsensitiveStr::Ascii("pulchre"),
        dictgen::InsensitiveStr::Ascii("pulchres"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RESEIZE_11829660618323635615)],
        &[(0b10010, &ENTRY_RESEIZER_14462609884001927595)],
        &[(0b01001, &ENTRY_RESEIZE_11829660618323635615)],
        &[(0b01001, &ENTRY_RESEIZER_14462609884001927595)],
        &[(0b10010, &ENTRY_RESENSITIZATION_3685514235786941102)],
        &[(0b10010, &ENTRY_RESENSITIZATIONS_919995710981311836)],
        &[(0b10010, &ENTRY_RESENSITIZE_1303613677297439531)],
        &[(0b10010, &ENTRY_RESENSITIZES_12908617404622953233)],
        &[(0b01001, &ENTRY_RESENSITIZATION_3685514235786941102)],
        &[(0b01001, &ENTRY_RESENSITIZATIONS_919995710981311836)],
        &[(0b01001, &ENTRY_RESENSITIZE_1303613677297439531)],
        &[(0b01001, &ENTRY_RESENSITIZES_12908617404622953233)],
        &[(0b00001, &ENTRY_RESEPULCHER_13255687324173800374)],
        &[(0b00001, &ENTRY_RESEPULCHERS_6740248117563664747)],
        &[(0b11010, &ENTRY_RESEPULCHER_13255687324173800374)],
        &[(0b11010, &ENTRY_RESEPULCHERS_6740248117563664747)],
        &[(0b11010, &ENTRY_ERSES_5709814492624908686)],
    ],
    range: 1..=12,
};

static VARS_RER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RER_CHILDREN),
    value: None,
};

pub static VARS_RER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oyalise"),
        dictgen::InsensitiveStr::Ascii("oyalises"),
        dictgen::InsensitiveStr::Ascii("oyalize"),
        dictgen::InsensitiveStr::Ascii("oyalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REROYALIZE_9299210178122090712)],
        &[(0b10010, &ENTRY_REROYALIZES_658053808235761746)],
        &[(0b01001, &ENTRY_REROYALIZE_9299210178122090712)],
        &[(0b01001, &ENTRY_REROYALIZES_658053808235761746)],
    ],
    range: 7..=8,
};

static VARS_REP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REP_CHILDREN),
    value: None,
};

static VARS_REP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_REPA_NODE),
    None,
    None,
    None,
    Some(&VARS_REPE_NODE),
    None,
    None,
    Some(&VARS_REPH_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_REPO_NODE),
    None,
    None,
    Some(&VARS_REPR_NODE),
    None,
    None,
    Some(&VARS_REPU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_REPU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPU_CHILDREN),
    value: None,
};

pub static VARS_REPU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blicanisation"),
        dictgen::InsensitiveStr::Ascii("blicanisations"),
        dictgen::InsensitiveStr::Ascii("blicanise"),
        dictgen::InsensitiveStr::Ascii("blicanised"),
        dictgen::InsensitiveStr::Ascii("blicaniser"),
        dictgen::InsensitiveStr::Ascii("blicanisers"),
        dictgen::InsensitiveStr::Ascii("blicanises"),
        dictgen::InsensitiveStr::Ascii("blicanising"),
        dictgen::InsensitiveStr::Ascii("blicanization"),
        dictgen::InsensitiveStr::Ascii("blicanizations"),
        dictgen::InsensitiveStr::Ascii("blicanize"),
        dictgen::InsensitiveStr::Ascii("blicanized"),
        dictgen::InsensitiveStr::Ascii("blicanizer"),
        dictgen::InsensitiveStr::Ascii("blicanizers"),
        dictgen::InsensitiveStr::Ascii("blicanizes"),
        dictgen::InsensitiveStr::Ascii("blicanizing"),
        dictgen::InsensitiveStr::Ascii("lverise"),
        dictgen::InsensitiveStr::Ascii("lverises"),
        dictgen::InsensitiveStr::Ascii("lverize"),
        dictgen::InsensitiveStr::Ascii("lverizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPUBLICANIZATION_1944426904861411795)],
        &[(0b10010, &ENTRY_REPUBLICANIZATIONS_383652106092527995)],
        &[(0b10010, &ENTRY_REPUBLICANIZE_10386133133725020930)],
        &[(0b10010, &ENTRY_REPUBLICANIZED_580437874147385001)],
        &[(0b10010, &ENTRY_REPUBLICANIZER_18381174866390455070)],
        &[(0b10010, &ENTRY_REPUBLICANIZERS_15251018630663619701)],
        &[(0b10010, &ENTRY_REPUBLICANIZES_7718357541376368950)],
        &[(0b10010, &ENTRY_REPUBLICANIZING_8829607189097248923)],
        &[(0b01001, &ENTRY_REPUBLICANIZATION_1944426904861411795)],
        &[(0b01001, &ENTRY_REPUBLICANIZATIONS_383652106092527995)],
        &[(0b01001, &ENTRY_REPUBLICANIZE_10386133133725020930)],
        &[(0b01001, &ENTRY_REPUBLICANIZED_580437874147385001)],
        &[(0b01001, &ENTRY_REPUBLICANIZER_18381174866390455070)],
        &[(0b01001, &ENTRY_REPUBLICANIZERS_15251018630663619701)],
        &[(0b01001, &ENTRY_REPUBLICANIZES_7718357541376368950)],
        &[(0b01001, &ENTRY_REPUBLICANIZING_8829607189097248923)],
        &[(0b10010, &ENTRY_REPULVERIZE_7976316581557319006)],
        &[(0b10010, &ENTRY_REPULVERIZES_16864243522912897832)],
        &[(0b01001, &ENTRY_REPULVERIZE_7976316581557319006)],
        &[(0b01001, &ENTRY_REPULVERIZES_16864243522912897832)],
    ],
    range: 7..=14,
};

static VARS_REPR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPR_CHILDREN),
    value: None,
};

pub static VARS_REPR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ivatisation"),
        dictgen::InsensitiveStr::Ascii("ivatisations"),
        dictgen::InsensitiveStr::Ascii("ivatise"),
        dictgen::InsensitiveStr::Ascii("ivatised"),
        dictgen::InsensitiveStr::Ascii("ivatises"),
        dictgen::InsensitiveStr::Ascii("ivatising"),
        dictgen::InsensitiveStr::Ascii("ivatization"),
        dictgen::InsensitiveStr::Ascii("ivatizations"),
        dictgen::InsensitiveStr::Ascii("ivatize"),
        dictgen::InsensitiveStr::Ascii("ivatized"),
        dictgen::InsensitiveStr::Ascii("ivatizes"),
        dictgen::InsensitiveStr::Ascii("ivatizing"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("ogramme"),
        dictgen::InsensitiveStr::Ascii("ogrammes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPRIZED_7288407637875600947)],
        &[(0b10010, &ENTRY_REPRIVATIZATION_13650773811954050943)],
        &[(0b10010, &ENTRY_REPRIVATIZATIONS_14878285207711233234)],
        &[(0b10010, &ENTRY_REPRIVATIZE_5415509619751214059)],
        &[(0b10010, &ENTRY_REPRIVATIZED_12098289997527637409)],
        &[(0b10010, &ENTRY_REPRIVATIZES_16228664850321170772)],
        &[(0b10010, &ENTRY_REPRIVATIZING_12815705532271804492)],
        &[(0b01001, &ENTRY_REPRIVATIZATION_13650773811954050943)],
        &[(0b01001, &ENTRY_REPRIVATIZATIONS_14878285207711233234)],
        &[(0b01001, &ENTRY_REPRIVATIZE_5415509619751214059)],
        &[(0b01001, &ENTRY_REPRIVATIZED_12098289997527637409)],
        &[(0b01001, &ENTRY_REPRIVATIZES_16228664850321170772)],
        &[(0b01001, &ENTRY_REPRIVATIZING_12815705532271804492)],
        &[(0b01001, &ENTRY_REPRIZED_7288407637875600947)],
        &[(0b11010, &ENTRY_REPROGRAM_4774339528962451273)],
        &[(0b11010, &ENTRY_REPROGRAMS_14411569368989355062)],
    ],
    range: 4..=12,
};

static VARS_REPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPO_CHILDREN),
    value: None,
};

pub static VARS_REPO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lymerisation"),
        dictgen::InsensitiveStr::Ascii("lymerisations"),
        dictgen::InsensitiveStr::Ascii("lymerise"),
        dictgen::InsensitiveStr::Ascii("lymerises"),
        dictgen::InsensitiveStr::Ascii("lymerization"),
        dictgen::InsensitiveStr::Ascii("lymerizations"),
        dictgen::InsensitiveStr::Ascii("lymerize"),
        dictgen::InsensitiveStr::Ascii("lymerizes"),
        dictgen::InsensitiveStr::Ascii("pularise"),
        dictgen::InsensitiveStr::Ascii("pularize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPOLYMERIZATION_4016733859370100512)],
        &[(0b10010, &ENTRY_REPOLYMERIZATIONS_5935058147340822679)],
        &[(0b10010, &ENTRY_REPOLYMERIZE_9036336021273167586)],
        &[(0b10010, &ENTRY_REPOLYMERIZES_278489027229578119)],
        &[(0b01001, &ENTRY_REPOLYMERIZATION_4016733859370100512)],
        &[(0b01001, &ENTRY_REPOLYMERIZATIONS_5935058147340822679)],
        &[(0b01001, &ENTRY_REPOLYMERIZE_9036336021273167586)],
        &[(0b01001, &ENTRY_REPOLYMERIZES_278489027229578119)],
        &[(0b10010, &ENTRY_REPOPULARIZE_9953057472377229635)],
        &[(0b01001, &ENTRY_REPOPULARIZE_9953057472377229635)],
    ],
    range: 8..=13,
};

static VARS_REPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPH_CHILDREN),
    value: None,
};

pub static VARS_REPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("osphorisation"),
        dictgen::InsensitiveStr::Ascii("osphorisations"),
        dictgen::InsensitiveStr::Ascii("osphorise"),
        dictgen::InsensitiveStr::Ascii("osphorises"),
        dictgen::InsensitiveStr::Ascii("osphorization"),
        dictgen::InsensitiveStr::Ascii("osphorizations"),
        dictgen::InsensitiveStr::Ascii("osphorize"),
        dictgen::InsensitiveStr::Ascii("osphorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPHOSPHORIZATION_1249759851309425020)],
        &[(0b10010, &ENTRY_REPHOSPHORIZATIONS_10501113871961153156)],
        &[(0b10010, &ENTRY_REPHOSPHORIZE_419529770369265116)],
        &[(0b10010, &ENTRY_REPHOSPHORIZES_17888482873852406388)],
        &[(0b01001, &ENTRY_REPHOSPHORIZATION_1249759851309425020)],
        &[(0b01001, &ENTRY_REPHOSPHORIZATIONS_10501113871961153156)],
        &[(0b01001, &ENTRY_REPHOSPHORIZE_419529770369265116)],
        &[(0b01001, &ENTRY_REPHOSPHORIZES_17888482873852406388)],
    ],
    range: 9..=14,
};

static VARS_REPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPE_CHILDREN),
    value: None,
};

pub static VARS_REPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rsonalise"),
        dictgen::InsensitiveStr::Ascii("rsonalize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPERSONALIZE_6974920904850829865)],
        &[(0b01001, &ENTRY_REPERSONALIZE_6974920904850829865)],
    ],
    range: 9..=9,
};

static VARS_REPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REPA_CHILDREN),
    value: None,
};

pub static VARS_REPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ganisation"),
        dictgen::InsensitiveStr::Ascii("ganisations"),
        dictgen::InsensitiveStr::Ascii("ganise"),
        dictgen::InsensitiveStr::Ascii("ganiser"),
        dictgen::InsensitiveStr::Ascii("ganisers"),
        dictgen::InsensitiveStr::Ascii("ganises"),
        dictgen::InsensitiveStr::Ascii("ganization"),
        dictgen::InsensitiveStr::Ascii("ganizations"),
        dictgen::InsensitiveStr::Ascii("ganize"),
        dictgen::InsensitiveStr::Ascii("ganizer"),
        dictgen::InsensitiveStr::Ascii("ganizers"),
        dictgen::InsensitiveStr::Ascii("ganizes"),
        dictgen::InsensitiveStr::Ascii("tronise"),
        dictgen::InsensitiveStr::Ascii("tronises"),
        dictgen::InsensitiveStr::Ascii("tronize"),
        dictgen::InsensitiveStr::Ascii("tronizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REPAGANIZATION_17048111709890154504)],
        &[(0b10010, &ENTRY_REPAGANIZATIONS_11524549005753966827)],
        &[(0b10010, &ENTRY_REPAGANIZE_12973755742278560404)],
        &[(0b10010, &ENTRY_REPAGANIZER_6412817561993591645)],
        &[(0b10010, &ENTRY_REPAGANIZERS_1945767306900866182)],
        &[(0b10010, &ENTRY_REPAGANIZES_9803449503187685243)],
        &[(0b01001, &ENTRY_REPAGANIZATION_17048111709890154504)],
        &[(0b01001, &ENTRY_REPAGANIZATIONS_11524549005753966827)],
        &[(0b01001, &ENTRY_REPAGANIZE_12973755742278560404)],
        &[(0b01001, &ENTRY_REPAGANIZER_6412817561993591645)],
        &[(0b01001, &ENTRY_REPAGANIZERS_1945767306900866182)],
        &[(0b01001, &ENTRY_REPAGANIZES_9803449503187685243)],
        &[(0b10010, &ENTRY_REPATRONIZE_14079123483159349622)],
        &[(0b10010, &ENTRY_REPATRONIZES_15919891777429804526)],
        &[(0b01001, &ENTRY_REPATRONIZE_14079123483159349622)],
        &[(0b01001, &ENTRY_REPATRONIZES_15919891777429804526)],
    ],
    range: 6..=11,
};

static VARS_REO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REO_CHILDREN),
    value: None,
};

pub static VARS_REO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bjectivisation"),
        dictgen::InsensitiveStr::Ascii("bjectivisations"),
        dictgen::InsensitiveStr::Ascii("bjectivise"),
        dictgen::InsensitiveStr::Ascii("bjectivises"),
        dictgen::InsensitiveStr::Ascii("bjectivization"),
        dictgen::InsensitiveStr::Ascii("bjectivizations"),
        dictgen::InsensitiveStr::Ascii("bjectivize"),
        dictgen::InsensitiveStr::Ascii("bjectivizes"),
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisational"),
        dictgen::InsensitiveStr::Ascii("rganisationist"),
        dictgen::InsensitiveStr::Ascii("rganisationists"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganiser"),
        dictgen::InsensitiveStr::Ascii("rganisers"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganising"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizational"),
        dictgen::InsensitiveStr::Ascii("rganizationist"),
        dictgen::InsensitiveStr::Ascii("rganizationists"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganized"),
        dictgen::InsensitiveStr::Ascii("rganizer"),
        dictgen::InsensitiveStr::Ascii("rganizers"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
        dictgen::InsensitiveStr::Ascii("rganizing"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
        dictgen::InsensitiveStr::Ascii("xygenise"),
        dictgen::InsensitiveStr::Ascii("xygenises"),
        dictgen::InsensitiveStr::Ascii("xygenize"),
        dictgen::InsensitiveStr::Ascii("xygenizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REOBJECTIVIZATION_9934627242133960188)],
        &[(0b10010, &ENTRY_REOBJECTIVIZATIONS_484037855015245777)],
        &[(0b10010, &ENTRY_REOBJECTIVIZE_4586321694839316243)],
        &[(0b10010, &ENTRY_REOBJECTIVIZES_2442086806688158809)],
        &[(0b01001, &ENTRY_REOBJECTIVIZATION_9934627242133960188)],
        &[(0b01001, &ENTRY_REOBJECTIVIZATIONS_484037855015245777)],
        &[(0b01001, &ENTRY_REOBJECTIVIZE_4586321694839316243)],
        &[(0b01001, &ENTRY_REOBJECTIVIZES_2442086806688158809)],
        &[(0b10010, &ENTRY_REORGANIZATION_8169886605299414196)],
        &[(0b10010, &ENTRY_REORGANIZATIONAL_10984641565360643637)],
        &[(0b10010, &ENTRY_REORGANIZATIONIST_11925492221252212415)],
        &[(0b10010, &ENTRY_REORGANIZATIONISTS_10384586979829403733)],
        &[(0b10010, &ENTRY_REORGANIZATIONS_3908357981488387825)],
        &[(0b10010, &ENTRY_REORGANIZE_18181270914612994788)],
        &[(0b10010, &ENTRY_REORGANIZED_5774790920194407083)],
        &[(0b10010, &ENTRY_REORGANIZER_2092510006819704008)],
        &[(0b10010, &ENTRY_REORGANIZERS_9885992780785484737)],
        &[(0b10010, &ENTRY_REORGANIZES_3740948184951472727)],
        &[(0b10010, &ENTRY_REORGANIZING_15784567964948699452)],
        &[(0b01001, &ENTRY_REORGANIZATION_8169886605299414196)],
        &[(0b01001, &ENTRY_REORGANIZATIONAL_10984641565360643637)],
        &[(0b01001, &ENTRY_REORGANIZATIONIST_11925492221252212415)],
        &[(0b01001, &ENTRY_REORGANIZATIONISTS_10384586979829403733)],
        &[(0b01001, &ENTRY_REORGANIZATIONS_3908357981488387825)],
        &[(0b01001, &ENTRY_REORGANIZE_18181270914612994788)],
        &[(0b01001, &ENTRY_REORGANIZED_5774790920194407083)],
        &[(0b01001, &ENTRY_REORGANIZER_2092510006819704008)],
        &[(0b01001, &ENTRY_REORGANIZERS_9885992780785484737)],
        &[(0b01001, &ENTRY_REORGANIZES_3740948184951472727)],
        &[(0b01001, &ENTRY_REORGANIZING_15784567964948699452)],
        &[(0b10010, &ENTRY_REOXIDIZE_4983823425119723374)],
        &[(0b10010, &ENTRY_REOXIDIZED_13705047693863706297)],
        &[(0b10010, &ENTRY_REOXIDIZES_14522324553215140631)],
        &[(0b10010, &ENTRY_REOXIDIZING_18024783650819146058)],
        &[(0b01001, &ENTRY_REOXIDIZE_4983823425119723374)],
        &[(0b01001, &ENTRY_REOXIDIZED_13705047693863706297)],
        &[(0b01001, &ENTRY_REOXIDIZES_14522324553215140631)],
        &[(0b01001, &ENTRY_REOXIDIZING_18024783650819146058)],
        &[(0b10010, &ENTRY_REOXYGENIZE_6926836183647945085)],
        &[(0b10010, &ENTRY_REOXYGENIZES_17640431467346669041)],
        &[(0b01001, &ENTRY_REOXYGENIZE_6926836183647945085)],
        &[(0b01001, &ENTRY_REOXYGENIZES_17640431467346669041)],
    ],
    range: 6..=15,
};

static VARS_REN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REN_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_ERN_10092184086657301009)]),
};

pub static VARS_REN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalised"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalising"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalized"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
        dictgen::InsensitiveStr::Ascii("ationalizing"),
        dictgen::InsensitiveStr::Ascii("contre"),
        dictgen::InsensitiveStr::Ascii("counter"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("est"),
        dictgen::InsensitiveStr::Ascii("ferd"),
        dictgen::InsensitiveStr::Ascii("fred"),
        dictgen::InsensitiveStr::Ascii("ormalisation"),
        dictgen::InsensitiveStr::Ascii("ormalisations"),
        dictgen::InsensitiveStr::Ascii("ormalise"),
        dictgen::InsensitiveStr::Ascii("ormalised"),
        dictgen::InsensitiveStr::Ascii("ormalises"),
        dictgen::InsensitiveStr::Ascii("ormalising"),
        dictgen::InsensitiveStr::Ascii("ormalization"),
        dictgen::InsensitiveStr::Ascii("ormalizations"),
        dictgen::InsensitiveStr::Ascii("ormalize"),
        dictgen::InsensitiveStr::Ascii("ormalized"),
        dictgen::InsensitiveStr::Ascii("ormalizes"),
        dictgen::InsensitiveStr::Ascii("ormalizing"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RENATIONALIZE_13763420489757292678)],
        &[(0b10010, &ENTRY_RENATIONALIZED_245883000485081396)],
        &[(0b10010, &ENTRY_RENATIONALIZES_15008886789696665182)],
        &[(0b10010, &ENTRY_RENATIONALIZING_528289503767142524)],
        &[(0b01001, &ENTRY_RENATIONALIZE_13763420489757292678)],
        &[(0b01001, &ENTRY_RENATIONALIZED_245883000485081396)],
        &[(0b01001, &ENTRY_RENATIONALIZES_15008886789696665182)],
        &[(0b01001, &ENTRY_RENATIONALIZING_528289503767142524)],
        &[(0b11010, &ENTRY_RENCOUNTER_17790527784370805465)],
        &[(0b00001, &ENTRY_RENCOUNTER_17790527784370805465)],
        &[(0b11010, &ENTRY_ERNES_16282144925287112174)],
        &[(0b11010, &ENTRY_ERNEST_2869565578515229588)],
        &[(0b00001, &ENTRY_RENFERD_5332380987373616326)],
        &[(0b11010, &ENTRY_RENFERD_5332380987373616326)],
        &[(0b10010, &ENTRY_RENORMALIZATION_9891230551808040808)],
        &[(0b10010, &ENTRY_RENORMALIZATIONS_6818740031112910643)],
        &[(0b10010, &ENTRY_RENORMALIZE_4228995450916847764)],
        &[(0b10010, &ENTRY_RENORMALIZED_12583163063216549053)],
        &[(0b10010, &ENTRY_RENORMALIZES_12053503023445454685)],
        &[(0b10010, &ENTRY_RENORMALIZING_4696927106111124982)],
        &[(0b01001, &ENTRY_RENORMALIZATION_9891230551808040808)],
        &[(0b01001, &ENTRY_RENORMALIZATIONS_6818740031112910643)],
        &[(0b01001, &ENTRY_RENORMALIZE_4228995450916847764)],
        &[(0b01001, &ENTRY_RENORMALIZED_12583163063216549053)],
        &[(0b01001, &ENTRY_RENORMALIZES_12053503023445454685)],
        &[(0b01001, &ENTRY_RENORMALIZING_4696927106111124982)],
        &[(0b11010, &ENTRY_ERNS_11958672731540988082)],
    ],
    range: 1..=13,
};

static VARS_REM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REM_CHILDREN),
    value: None,
};

static VARS_REM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_REMA_NODE),
    None,
    None,
    None,
    Some(&VARS_REME_NODE),
    None,
    None,
    None,
    Some(&VARS_REMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_REMO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_REMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REMO_CHILDREN),
    value: None,
};

pub static VARS_REMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilisation"),
        dictgen::InsensitiveStr::Ascii("bilisations"),
        dictgen::InsensitiveStr::Ascii("bilise"),
        dictgen::InsensitiveStr::Ascii("bilises"),
        dictgen::InsensitiveStr::Ascii("bilization"),
        dictgen::InsensitiveStr::Ascii("bilizations"),
        dictgen::InsensitiveStr::Ascii("bilize"),
        dictgen::InsensitiveStr::Ascii("bilizes"),
        dictgen::InsensitiveStr::Ascii("deled"),
        dictgen::InsensitiveStr::Ascii("deling"),
        dictgen::InsensitiveStr::Ascii("delled"),
        dictgen::InsensitiveStr::Ascii("delling"),
        dictgen::InsensitiveStr::Ascii("ld"),
        dictgen::InsensitiveStr::Ascii("lded"),
        dictgen::InsensitiveStr::Ascii("lding"),
        dictgen::InsensitiveStr::Ascii("lds"),
        dictgen::InsensitiveStr::Ascii("netisation"),
        dictgen::InsensitiveStr::Ascii("netisations"),
        dictgen::InsensitiveStr::Ascii("netise"),
        dictgen::InsensitiveStr::Ascii("netised"),
        dictgen::InsensitiveStr::Ascii("netises"),
        dictgen::InsensitiveStr::Ascii("netising"),
        dictgen::InsensitiveStr::Ascii("netization"),
        dictgen::InsensitiveStr::Ascii("netizations"),
        dictgen::InsensitiveStr::Ascii("netize"),
        dictgen::InsensitiveStr::Ascii("netized"),
        dictgen::InsensitiveStr::Ascii("netizes"),
        dictgen::InsensitiveStr::Ascii("netizing"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
        dictgen::InsensitiveStr::Ascii("uld"),
        dictgen::InsensitiveStr::Ascii("ulded"),
        dictgen::InsensitiveStr::Ascii("ulding"),
        dictgen::InsensitiveStr::Ascii("ulds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REMOBILIZATION_6261107144969557050)],
        &[(0b10010, &ENTRY_REMOBILIZATIONS_11227586492863758304)],
        &[(0b10010, &ENTRY_REMOBILIZE_923807659543256995)],
        &[(0b10010, &ENTRY_REMOBILIZES_12377835762207128096)],
        &[(0b01001, &ENTRY_REMOBILIZATION_6261107144969557050)],
        &[(0b01001, &ENTRY_REMOBILIZATIONS_11227586492863758304)],
        &[(0b01001, &ENTRY_REMOBILIZE_923807659543256995)],
        &[(0b01001, &ENTRY_REMOBILIZES_12377835762207128096)],
        &[(0b00001, &ENTRY_REMODELED_11951619598691255997)],
        &[(0b00001, &ENTRY_REMODELING_5571366996719584181)],
        &[(0b11010, &ENTRY_REMODELED_11951619598691255997)],
        &[(0b11010, &ENTRY_REMODELING_5571366996719584181)],
        &[(0b01001, &ENTRY_REMOLD_2526819628693250098)],
        &[(0b01001, &ENTRY_REMOLDED_18050524398894974310)],
        &[(0b01001, &ENTRY_REMOLDING_6944457580128330593)],
        &[(0b01001, &ENTRY_REMOLDS_1959267912662850297)],
        &[(0b10010, &ENTRY_REMONETIZATION_212742877311562271)],
        &[(0b10010, &ENTRY_REMONETIZATIONS_5697855088114742500)],
        &[(0b10010, &ENTRY_REMONETIZE_10588050293708931308)],
        &[(0b10010, &ENTRY_REMONETIZED_7157192020575645575)],
        &[(0b10010, &ENTRY_REMONETIZES_10479599926916307809)],
        &[(0b10010, &ENTRY_REMONETIZING_11312258848004221079)],
        &[(0b01001, &ENTRY_REMONETIZATION_212742877311562271)],
        &[(0b01001, &ENTRY_REMONETIZATIONS_5697855088114742500)],
        &[(0b01001, &ENTRY_REMONETIZE_10588050293708931308)],
        &[(0b01001, &ENTRY_REMONETIZED_7157192020575645575)],
        &[(0b01001, &ENTRY_REMONETIZES_10479599926916307809)],
        &[(0b01001, &ENTRY_REMONETIZING_11312258848004221079)],
        &[(0b10010, &ENTRY_REMORALIZATION_14016073140723680519)],
        &[(0b10010, &ENTRY_REMORALIZATIONS_5269456965430948283)],
        &[(0b10010, &ENTRY_REMORALIZE_8012535825718652462)],
        &[(0b10010, &ENTRY_REMORALIZED_16025093535995812890)],
        &[(0b10010, &ENTRY_REMORALIZES_11138700545539530334)],
        &[(0b10010, &ENTRY_REMORALIZING_5859909096957765153)],
        &[(0b01001, &ENTRY_REMORALIZATION_14016073140723680519)],
        &[(0b01001, &ENTRY_REMORALIZATIONS_5269456965430948283)],
        &[(0b01001, &ENTRY_REMORALIZE_8012535825718652462)],
        &[(0b01001, &ENTRY_REMORALIZED_16025093535995812890)],
        &[(0b01001, &ENTRY_REMORALIZES_11138700545539530334)],
        &[(0b01001, &ENTRY_REMORALIZING_5859909096957765153)],
        &[(0b11010, &ENTRY_REMOLD_2526819628693250098)],
        &[(0b11010, &ENTRY_REMOLDED_18050524398894974310)],
        &[(0b11010, &ENTRY_REMOLDING_6944457580128330593)],
        &[(0b11010, &ENTRY_REMOLDS_1959267912662850297)],
    ],
    range: 2..=11,
};

static VARS_REMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REMI_CHILDREN),
    value: None,
};

pub static VARS_REMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("litarisation"),
        dictgen::InsensitiveStr::Ascii("litarisations"),
        dictgen::InsensitiveStr::Ascii("litarise"),
        dictgen::InsensitiveStr::Ascii("litarised"),
        dictgen::InsensitiveStr::Ascii("litarises"),
        dictgen::InsensitiveStr::Ascii("litarising"),
        dictgen::InsensitiveStr::Ascii("litarization"),
        dictgen::InsensitiveStr::Ascii("litarizations"),
        dictgen::InsensitiveStr::Ascii("litarize"),
        dictgen::InsensitiveStr::Ascii("litarized"),
        dictgen::InsensitiveStr::Ascii("litarizes"),
        dictgen::InsensitiveStr::Ascii("litarizing"),
        dictgen::InsensitiveStr::Ascii("neralisation"),
        dictgen::InsensitiveStr::Ascii("neralisations"),
        dictgen::InsensitiveStr::Ascii("neralise"),
        dictgen::InsensitiveStr::Ascii("neralised"),
        dictgen::InsensitiveStr::Ascii("neralises"),
        dictgen::InsensitiveStr::Ascii("neralising"),
        dictgen::InsensitiveStr::Ascii("neralization"),
        dictgen::InsensitiveStr::Ascii("neralizations"),
        dictgen::InsensitiveStr::Ascii("neralize"),
        dictgen::InsensitiveStr::Ascii("neralized"),
        dictgen::InsensitiveStr::Ascii("neralizes"),
        dictgen::InsensitiveStr::Ascii("neralizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REMILITARIZATION_11523126169071197406)],
        &[(0b10010, &ENTRY_REMILITARIZATIONS_14597687455768382338)],
        &[(0b10010, &ENTRY_REMILITARIZE_18288519237186766997)],
        &[(0b10010, &ENTRY_REMILITARIZED_11554404031299874708)],
        &[(0b10010, &ENTRY_REMILITARIZES_940580432740816145)],
        &[(0b10010, &ENTRY_REMILITARIZING_4173334694500632492)],
        &[(0b01001, &ENTRY_REMILITARIZATION_11523126169071197406)],
        &[(0b01001, &ENTRY_REMILITARIZATIONS_14597687455768382338)],
        &[(0b01001, &ENTRY_REMILITARIZE_18288519237186766997)],
        &[(0b01001, &ENTRY_REMILITARIZED_11554404031299874708)],
        &[(0b01001, &ENTRY_REMILITARIZES_940580432740816145)],
        &[(0b01001, &ENTRY_REMILITARIZING_4173334694500632492)],
        &[(0b10010, &ENTRY_REMINERALIZATION_9915243010575985238)],
        &[(0b10010, &ENTRY_REMINERALIZATIONS_13810098978375898404)],
        &[(0b10010, &ENTRY_REMINERALIZE_4937501175287881412)],
        &[(0b10010, &ENTRY_REMINERALIZED_3026252061420046310)],
        &[(0b10010, &ENTRY_REMINERALIZES_17167344080905173349)],
        &[(0b10010, &ENTRY_REMINERALIZING_15635899904434541758)],
        &[(0b01001, &ENTRY_REMINERALIZATION_9915243010575985238)],
        &[(0b01001, &ENTRY_REMINERALIZATIONS_13810098978375898404)],
        &[(0b01001, &ENTRY_REMINERALIZE_4937501175287881412)],
        &[(0b01001, &ENTRY_REMINERALIZED_3026252061420046310)],
        &[(0b01001, &ENTRY_REMINERALIZES_17167344080905173349)],
        &[(0b01001, &ENTRY_REMINERALIZING_15635899904434541758)],
    ],
    range: 8..=13,
};

static VARS_REME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REME_CHILDREN),
    value: None,
};

pub static VARS_REME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("morise"),
        dictgen::InsensitiveStr::Ascii("morises"),
        dictgen::InsensitiveStr::Ascii("morize"),
        dictgen::InsensitiveStr::Ascii("morizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REMEMORIZE_9141700253852689935)],
        &[(0b10010, &ENTRY_REMEMORIZES_3334768426875225854)],
        &[(0b01001, &ENTRY_REMEMORIZE_9141700253852689935)],
        &[(0b01001, &ENTRY_REMEMORIZES_3334768426875225854)],
    ],
    range: 6..=7,
};

static VARS_REMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REMA_CHILDREN),
    value: None,
};

pub static VARS_REMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gnetisation"),
        dictgen::InsensitiveStr::Ascii("gnetisations"),
        dictgen::InsensitiveStr::Ascii("gnetise"),
        dictgen::InsensitiveStr::Ascii("gnetises"),
        dictgen::InsensitiveStr::Ascii("gnetization"),
        dictgen::InsensitiveStr::Ascii("gnetizations"),
        dictgen::InsensitiveStr::Ascii("gnetize"),
        dictgen::InsensitiveStr::Ascii("gnetizes"),
        dictgen::InsensitiveStr::Ascii("terialise"),
        dictgen::InsensitiveStr::Ascii("terialised"),
        dictgen::InsensitiveStr::Ascii("terialises"),
        dictgen::InsensitiveStr::Ascii("terialize"),
        dictgen::InsensitiveStr::Ascii("terialized"),
        dictgen::InsensitiveStr::Ascii("terializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REMAGNETIZATION_7449488408017816339)],
        &[(0b10010, &ENTRY_REMAGNETIZATIONS_301607721419429650)],
        &[(0b10010, &ENTRY_REMAGNETIZE_7944947263065196618)],
        &[(0b10010, &ENTRY_REMAGNETIZES_11510663723565945487)],
        &[(0b01001, &ENTRY_REMAGNETIZATION_7449488408017816339)],
        &[(0b01001, &ENTRY_REMAGNETIZATIONS_301607721419429650)],
        &[(0b01001, &ENTRY_REMAGNETIZE_7944947263065196618)],
        &[(0b01001, &ENTRY_REMAGNETIZES_11510663723565945487)],
        &[(0b10010, &ENTRY_REMATERIALIZE_12678282950195083048)],
        &[(0b10010, &ENTRY_REMATERIALIZED_5664061553925446220)],
        &[(0b10010, &ENTRY_REMATERIALIZES_9384263525573606944)],
        &[(0b01001, &ENTRY_REMATERIALIZE_12678282950195083048)],
        &[(0b01001, &ENTRY_REMATERIALIZED_5664061553925446220)],
        &[(0b01001, &ENTRY_REMATERIALIZES_9384263525573606944)],
    ],
    range: 7..=12,
};

static VARS_REL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REL_CHILDREN),
    value: None,
};

pub static VARS_REL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abeled"),
        dictgen::InsensitiveStr::Ascii("abeler"),
        dictgen::InsensitiveStr::Ascii("abelers"),
        dictgen::InsensitiveStr::Ascii("abeling"),
        dictgen::InsensitiveStr::Ascii("abelled"),
        dictgen::InsensitiveStr::Ascii("abeller"),
        dictgen::InsensitiveStr::Ascii("abellers"),
        dictgen::InsensitiveStr::Ascii("abelling"),
        dictgen::InsensitiveStr::Ascii("ativisation"),
        dictgen::InsensitiveStr::Ascii("ativisations"),
        dictgen::InsensitiveStr::Ascii("ativise"),
        dictgen::InsensitiveStr::Ascii("ativised"),
        dictgen::InsensitiveStr::Ascii("ativises"),
        dictgen::InsensitiveStr::Ascii("ativising"),
        dictgen::InsensitiveStr::Ascii("ativization"),
        dictgen::InsensitiveStr::Ascii("ativizations"),
        dictgen::InsensitiveStr::Ascii("ativize"),
        dictgen::InsensitiveStr::Ascii("ativized"),
        dictgen::InsensitiveStr::Ascii("ativizes"),
        dictgen::InsensitiveStr::Ascii("ativizing"),
        dictgen::InsensitiveStr::Ascii("igionise"),
        dictgen::InsensitiveStr::Ascii("igionised"),
        dictgen::InsensitiveStr::Ascii("igionises"),
        dictgen::InsensitiveStr::Ascii("igionising"),
        dictgen::InsensitiveStr::Ascii("igionize"),
        dictgen::InsensitiveStr::Ascii("igionized"),
        dictgen::InsensitiveStr::Ascii("igionizes"),
        dictgen::InsensitiveStr::Ascii("igionizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RELABELED_10158046552075682397)],
        &[(0b00001, &ENTRY_RELABELER_9218654604392185637)],
        &[(0b00001, &ENTRY_RELABELERS_3510633218011220958)],
        &[(0b00001, &ENTRY_RELABELING_17510567259263942187)],
        &[(0b11010, &ENTRY_RELABELED_10158046552075682397)],
        &[(0b11010, &ENTRY_RELABELER_9218654604392185637)],
        &[(0b11010, &ENTRY_RELABELERS_3510633218011220958)],
        &[(0b11010, &ENTRY_RELABELING_17510567259263942187)],
        &[(0b10010, &ENTRY_RELATIVIZATION_5661633830317099380)],
        &[(0b10010, &ENTRY_RELATIVIZATIONS_1630960536153392856)],
        &[(0b10010, &ENTRY_RELATIVIZE_17942359056176228223)],
        &[(0b10010, &ENTRY_RELATIVIZED_2041795511676409313)],
        &[(0b10010, &ENTRY_RELATIVIZES_4604141453046621024)],
        &[(0b10010, &ENTRY_RELATIVIZING_11299084213627555677)],
        &[(0b01001, &ENTRY_RELATIVIZATION_5661633830317099380)],
        &[(0b01001, &ENTRY_RELATIVIZATIONS_1630960536153392856)],
        &[(0b01001, &ENTRY_RELATIVIZE_17942359056176228223)],
        &[(0b01001, &ENTRY_RELATIVIZED_2041795511676409313)],
        &[(0b01001, &ENTRY_RELATIVIZES_4604141453046621024)],
        &[(0b01001, &ENTRY_RELATIVIZING_11299084213627555677)],
        &[(0b10010, &ENTRY_RELIGIONIZE_6532592146342717831)],
        &[(0b10010, &ENTRY_RELIGIONIZED_1463181140685954820)],
        &[(0b10010, &ENTRY_RELIGIONIZES_14839970703278120755)],
        &[(0b10010, &ENTRY_RELIGIONIZING_9823945316309054025)],
        &[(0b01001, &ENTRY_RELIGIONIZE_6532592146342717831)],
        &[(0b01001, &ENTRY_RELIGIONIZED_1463181140685954820)],
        &[(0b01001, &ENTRY_RELIGIONIZES_14839970703278120755)],
        &[(0b01001, &ENTRY_RELIGIONIZING_9823945316309054025)],
    ],
    range: 6..=12,
};

static VARS_REK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REK_CHILDREN),
    value: None,
};

pub static VARS_REK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b11010, &ENTRY_ERKE_6039553976467525040)]],
    range: 1..=1,
};

static VARS_REJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REJ_CHILDREN),
    value: None,
};

pub static VARS_REJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uvenise"),
        dictgen::InsensitiveStr::Ascii("uvenised"),
        dictgen::InsensitiveStr::Ascii("uvenises"),
        dictgen::InsensitiveStr::Ascii("uvenising"),
        dictgen::InsensitiveStr::Ascii("uvenize"),
        dictgen::InsensitiveStr::Ascii("uvenized"),
        dictgen::InsensitiveStr::Ascii("uvenizes"),
        dictgen::InsensitiveStr::Ascii("uvenizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REJUVENIZE_15499984299215050232)],
        &[(0b10010, &ENTRY_REJUVENIZED_8024394360112020134)],
        &[(0b10010, &ENTRY_REJUVENIZES_13596416797841620302)],
        &[(0b10010, &ENTRY_REJUVENIZING_13051690954489546501)],
        &[(0b01001, &ENTRY_REJUVENIZE_15499984299215050232)],
        &[(0b01001, &ENTRY_REJUVENIZED_8024394360112020134)],
        &[(0b01001, &ENTRY_REJUVENIZES_13596416797841620302)],
        &[(0b01001, &ENTRY_REJUVENIZING_13051690954489546501)],
    ],
    range: 7..=9,
};

static VARS_REI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REI_CHILDREN),
    value: None,
};

pub static VARS_REI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialisations"),
        dictgen::InsensitiveStr::Ascii("ndustrialise"),
        dictgen::InsensitiveStr::Ascii("ndustrialised"),
        dictgen::InsensitiveStr::Ascii("ndustrialises"),
        dictgen::InsensitiveStr::Ascii("ndustrialising"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
        dictgen::InsensitiveStr::Ascii("ndustrializations"),
        dictgen::InsensitiveStr::Ascii("ndustrialize"),
        dictgen::InsensitiveStr::Ascii("ndustrialized"),
        dictgen::InsensitiveStr::Ascii("ndustrializes"),
        dictgen::InsensitiveStr::Ascii("ndustrializing"),
        dictgen::InsensitiveStr::Ascii("nitialisation"),
        dictgen::InsensitiveStr::Ascii("nitialise"),
        dictgen::InsensitiveStr::Ascii("nitialised"),
        dictgen::InsensitiveStr::Ascii("nitialises"),
        dictgen::InsensitiveStr::Ascii("nitialising"),
        dictgen::InsensitiveStr::Ascii("nitialization"),
        dictgen::InsensitiveStr::Ascii("nitialize"),
        dictgen::InsensitiveStr::Ascii("nitialized"),
        dictgen::InsensitiveStr::Ascii("nitializes"),
        dictgen::InsensitiveStr::Ascii("nitializing"),
        dictgen::InsensitiveStr::Ascii("temise"),
        dictgen::InsensitiveStr::Ascii("temises"),
        dictgen::InsensitiveStr::Ascii("temize"),
        dictgen::InsensitiveStr::Ascii("temizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REINDUSTRIALIZATION_14617747281891421599)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZATIONS_9294526708641521678)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZE_15338922682080771453)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZED_501582076968778654)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZES_6040168470805305881)],
        &[(0b10010, &ENTRY_REINDUSTRIALIZING_12638875256658078134)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZATION_14617747281891421599)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZATIONS_9294526708641521678)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZE_15338922682080771453)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZED_501582076968778654)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZES_6040168470805305881)],
        &[(0b01001, &ENTRY_REINDUSTRIALIZING_12638875256658078134)],
        &[(0b10010, &ENTRY_REINITIALIZATION_8409745411283248302)],
        &[(0b10010, &ENTRY_REINITIALIZE_13966181957218775879)],
        &[(0b10010, &ENTRY_REINITIALIZED_5276107785704620977)],
        &[(0b10010, &ENTRY_REINITIALIZES_10777259538596408245)],
        &[(0b10010, &ENTRY_REINITIALIZING_2886046725474516411)],
        &[(0b01001, &ENTRY_REINITIALIZATION_8409745411283248302)],
        &[(0b01001, &ENTRY_REINITIALIZE_13966181957218775879)],
        &[(0b01001, &ENTRY_REINITIALIZED_5276107785704620977)],
        &[(0b01001, &ENTRY_REINITIALIZES_10777259538596408245)],
        &[(0b01001, &ENTRY_REINITIALIZING_2886046725474516411)],
        &[(0b10010, &ENTRY_REITEMIZE_16632605337485238276)],
        &[(0b10010, &ENTRY_REITEMIZES_371522371959673766)],
        &[(0b01001, &ENTRY_REITEMIZE_16632605337485238276)],
        &[(0b01001, &ENTRY_REITEMIZES_371522371959673766)],
    ],
    range: 6..=17,
};

static VARS_REH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REH_CHILDREN),
    value: None,
};

pub static VARS_REH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("armonisation"),
        dictgen::InsensitiveStr::Ascii("armonise"),
        dictgen::InsensitiveStr::Ascii("armonises"),
        dictgen::InsensitiveStr::Ascii("armonization"),
        dictgen::InsensitiveStr::Ascii("armonize"),
        dictgen::InsensitiveStr::Ascii("armonizes"),
        dictgen::InsensitiveStr::Ascii("m"),
        dictgen::InsensitiveStr::Ascii("onor"),
        dictgen::InsensitiveStr::Ascii("onors"),
        dictgen::InsensitiveStr::Ascii("onour"),
        dictgen::InsensitiveStr::Ascii("onours"),
        dictgen::InsensitiveStr::Ascii("umanisation"),
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanization"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
        dictgen::InsensitiveStr::Ascii("ybridise"),
        dictgen::InsensitiveStr::Ascii("ybridises"),
        dictgen::InsensitiveStr::Ascii("ybridize"),
        dictgen::InsensitiveStr::Ascii("ybridizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REHARMONIZATION_12536421913907080148)],
        &[(0b10010, &ENTRY_REHARMONIZE_13548735377725430821)],
        &[(0b10010, &ENTRY_REHARMONIZES_7115017876161212459)],
        &[(0b01001, &ENTRY_REHARMONIZATION_12536421913907080148)],
        &[(0b01001, &ENTRY_REHARMONIZE_13548735377725430821)],
        &[(0b01001, &ENTRY_REHARMONIZES_7115017876161212459)],
        &[(0b00001, &ENTRY_REHM_1954003150274029388)],
        &[(0b00001, &ENTRY_REHONOR_10506420481569052180)],
        &[(0b00001, &ENTRY_REHONORS_4455044786531477320)],
        &[(0b11010, &ENTRY_REHONOR_10506420481569052180)],
        &[(0b11010, &ENTRY_REHONORS_4455044786531477320)],
        &[(0b10010, &ENTRY_REHUMANIZATION_823615019743132382)],
        &[(0b10010, &ENTRY_REHUMANIZE_10181332086255781696)],
        &[(0b10010, &ENTRY_REHUMANIZES_9376605652523591285)],
        &[(0b01001, &ENTRY_REHUMANIZATION_823615019743132382)],
        &[(0b01001, &ENTRY_REHUMANIZE_10181332086255781696)],
        &[(0b01001, &ENTRY_REHUMANIZES_9376605652523591285)],
        &[(0b10010, &ENTRY_REHYBRIDIZE_13653700826314235211)],
        &[(0b10010, &ENTRY_REHYBRIDIZES_10629734025595806199)],
        &[(0b01001, &ENTRY_REHYBRIDIZE_13653700826314235211)],
        &[(0b01001, &ENTRY_REHYBRIDIZES_10629734025595806199)],
    ],
    range: 1..=12,
};

static VARS_REG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REG_CHILDREN),
    value: None,
};

pub static VARS_REG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alvanisation"),
        dictgen::InsensitiveStr::Ascii("alvanisations"),
        dictgen::InsensitiveStr::Ascii("alvanise"),
        dictgen::InsensitiveStr::Ascii("alvanises"),
        dictgen::InsensitiveStr::Ascii("alvanization"),
        dictgen::InsensitiveStr::Ascii("alvanizations"),
        dictgen::InsensitiveStr::Ascii("alvanize"),
        dictgen::InsensitiveStr::Ascii("alvanizes"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("ionalisation"),
        dictgen::InsensitiveStr::Ascii("ionalisations"),
        dictgen::InsensitiveStr::Ascii("ionalise"),
        dictgen::InsensitiveStr::Ascii("ionalised"),
        dictgen::InsensitiveStr::Ascii("ionalises"),
        dictgen::InsensitiveStr::Ascii("ionalising"),
        dictgen::InsensitiveStr::Ascii("ionalization"),
        dictgen::InsensitiveStr::Ascii("ionalizations"),
        dictgen::InsensitiveStr::Ascii("ionalize"),
        dictgen::InsensitiveStr::Ascii("ionalized"),
        dictgen::InsensitiveStr::Ascii("ionalizes"),
        dictgen::InsensitiveStr::Ascii("ionalizing"),
        dictgen::InsensitiveStr::Ascii("oes"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ulariser"),
        dictgen::InsensitiveStr::Ascii("ularisers"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizer"),
        dictgen::InsensitiveStr::Ascii("ularizers"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulised"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulising"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulized"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
        dictgen::InsensitiveStr::Ascii("ulizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REGALIZE_13206969410028193305)],
        &[(0b10010, &ENTRY_REGALIZES_11732011390337045014)],
        &[(0b01001, &ENTRY_REGALIZE_13206969410028193305)],
        &[(0b01001, &ENTRY_REGALIZES_11732011390337045014)],
        &[(0b10010, &ENTRY_REGALVANIZATION_17316748002349190251)],
        &[(0b10010, &ENTRY_REGALVANIZATIONS_6701296608833759714)],
        &[(0b10010, &ENTRY_REGALVANIZE_13575761445305979993)],
        &[(0b10010, &ENTRY_REGALVANIZES_4666153610159994761)],
        &[(0b01001, &ENTRY_REGALVANIZATION_17316748002349190251)],
        &[(0b01001, &ENTRY_REGALVANIZATIONS_6701296608833759714)],
        &[(0b01001, &ENTRY_REGALVANIZE_13575761445305979993)],
        &[(0b01001, &ENTRY_REGALVANIZES_4666153610159994761)],
        &[(0b00001, &ENTRY_REGES_12087241832921230914)],
        &[(0b10010, &ENTRY_REGIONALIZATION_6883441710934248998)],
        &[(0b10010, &ENTRY_REGIONALIZATIONS_17188055835713620803)],
        &[(0b10010, &ENTRY_REGIONALIZE_5480712559619945996)],
        &[(0b10010, &ENTRY_REGIONALIZED_5226562196343077794)],
        &[(0b10010, &ENTRY_REGIONALIZES_15726054798830210051)],
        &[(0b10010, &ENTRY_REGIONALIZING_16531030062440884204)],
        &[(0b01001, &ENTRY_REGIONALIZATION_6883441710934248998)],
        &[(0b01001, &ENTRY_REGIONALIZATIONS_17188055835713620803)],
        &[(0b01001, &ENTRY_REGIONALIZE_5480712559619945996)],
        &[(0b01001, &ENTRY_REGIONALIZED_5226562196343077794)],
        &[(0b01001, &ENTRY_REGIONALIZES_15726054798830210051)],
        &[(0b01001, &ENTRY_REGIONALIZING_16531030062440884204)],
        &[(0b11010, &ENTRY_REGES_12087241832921230914)],
        &[(0b10010, &ENTRY_REGULARIZATION_15955920955652647734)],
        &[(0b10010, &ENTRY_REGULARIZATIONS_17491359825165931567)],
        &[(0b10010, &ENTRY_REGULARIZE_7969176896988982612)],
        &[(0b10010, &ENTRY_REGULARIZED_16522280649650166951)],
        &[(0b10010, &ENTRY_REGULARIZER_13094146389105795730)],
        &[(0b10010, &ENTRY_REGULARIZERS_5127847040742478418)],
        &[(0b10010, &ENTRY_REGULARIZES_16029852279967676023)],
        &[(0b10010, &ENTRY_REGULARIZING_3972227314519446977)],
        &[(0b01001, &ENTRY_REGULARIZATION_15955920955652647734)],
        &[(0b01001, &ENTRY_REGULARIZATIONS_17491359825165931567)],
        &[(0b01001, &ENTRY_REGULARIZE_7969176896988982612)],
        &[(0b01001, &ENTRY_REGULARIZED_16522280649650166951)],
        &[(0b01001, &ENTRY_REGULARIZER_13094146389105795730)],
        &[(0b01001, &ENTRY_REGULARIZERS_5127847040742478418)],
        &[(0b01001, &ENTRY_REGULARIZES_16029852279967676023)],
        &[(0b01001, &ENTRY_REGULARIZING_3972227314519446977)],
        &[(0b10010, &ENTRY_REGULIZE_1184324425868079001)],
        &[(0b10010, &ENTRY_REGULIZED_14442601898306206117)],
        &[(0b10010, &ENTRY_REGULIZES_7068489394292161911)],
        &[(0b10010, &ENTRY_REGULIZING_10993526810603007915)],
        &[(0b01001, &ENTRY_REGULIZE_1184324425868079001)],
        &[(0b01001, &ENTRY_REGULIZED_14442601898306206117)],
        &[(0b01001, &ENTRY_REGULIZES_7068489394292161911)],
        &[(0b01001, &ENTRY_REGULIZING_10993526810603007915)],
    ],
    range: 2..=13,
};

static VARS_REF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REF_CHILDREN),
    value: None,
};

pub static VARS_REF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avors"),
        dictgen::InsensitiveStr::Ascii("avour"),
        dictgen::InsensitiveStr::Ascii("avours"),
        dictgen::InsensitiveStr::Ascii("ertilisation"),
        dictgen::InsensitiveStr::Ascii("ertilisations"),
        dictgen::InsensitiveStr::Ascii("ertilise"),
        dictgen::InsensitiveStr::Ascii("ertilises"),
        dictgen::InsensitiveStr::Ascii("ertilization"),
        dictgen::InsensitiveStr::Ascii("ertilizations"),
        dictgen::InsensitiveStr::Ascii("ertilize"),
        dictgen::InsensitiveStr::Ascii("ertilizes"),
        dictgen::InsensitiveStr::Ascii("lectorise"),
        dictgen::InsensitiveStr::Ascii("lectorised"),
        dictgen::InsensitiveStr::Ascii("lectorises"),
        dictgen::InsensitiveStr::Ascii("lectorising"),
        dictgen::InsensitiveStr::Ascii("lectorize"),
        dictgen::InsensitiveStr::Ascii("lectorized"),
        dictgen::InsensitiveStr::Ascii("lectorizes"),
        dictgen::InsensitiveStr::Ascii("lectorizing"),
        dictgen::InsensitiveStr::Ascii("orestisation"),
        dictgen::InsensitiveStr::Ascii("orestise"),
        dictgen::InsensitiveStr::Ascii("orestises"),
        dictgen::InsensitiveStr::Ascii("orestization"),
        dictgen::InsensitiveStr::Ascii("orestize"),
        dictgen::InsensitiveStr::Ascii("orestizes"),
        dictgen::InsensitiveStr::Ascii("ormades"),
        dictgen::InsensitiveStr::Ascii("ormadoes"),
        dictgen::InsensitiveStr::Ascii("ueled"),
        dictgen::InsensitiveStr::Ascii("ueling"),
        dictgen::InsensitiveStr::Ascii("uelled"),
        dictgen::InsensitiveStr::Ascii("uelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_REFAVOR_13127112244409244390)],
        &[(0b00001, &ENTRY_REFAVORS_6261091989940159944)],
        &[(0b11010, &ENTRY_REFAVOR_13127112244409244390)],
        &[(0b11010, &ENTRY_REFAVORS_6261091989940159944)],
        &[(0b10010, &ENTRY_REFERTILIZATION_10871550741687115201)],
        &[(0b10010, &ENTRY_REFERTILIZATIONS_10209257884796898169)],
        &[(0b10010, &ENTRY_REFERTILIZE_12372222114547549332)],
        &[(0b10010, &ENTRY_REFERTILIZES_10965697532320057521)],
        &[(0b01001, &ENTRY_REFERTILIZATION_10871550741687115201)],
        &[(0b01001, &ENTRY_REFERTILIZATIONS_10209257884796898169)],
        &[(0b01001, &ENTRY_REFERTILIZE_12372222114547549332)],
        &[(0b01001, &ENTRY_REFERTILIZES_10965697532320057521)],
        &[(0b10010, &ENTRY_REFLECTORIZE_10275704482949346236)],
        &[(0b10010, &ENTRY_REFLECTORIZED_13272320600964781160)],
        &[(0b10010, &ENTRY_REFLECTORIZES_8900369302482342783)],
        &[(0b10010, &ENTRY_REFLECTORIZING_8154759098223325317)],
        &[(0b01001, &ENTRY_REFLECTORIZE_10275704482949346236)],
        &[(0b01001, &ENTRY_REFLECTORIZED_13272320600964781160)],
        &[(0b01001, &ENTRY_REFLECTORIZES_8900369302482342783)],
        &[(0b01001, &ENTRY_REFLECTORIZING_8154759098223325317)],
        &[(0b10010, &ENTRY_REFORESTIZATION_9160443628806080238)],
        &[(0b10010, &ENTRY_REFORESTIZE_2340774127981028167)],
        &[(0b10010, &ENTRY_REFORESTIZES_11290483511697450376)],
        &[(0b01001, &ENTRY_REFORESTIZATION_9160443628806080238)],
        &[(0b01001, &ENTRY_REFORESTIZE_2340774127981028167)],
        &[(0b01001, &ENTRY_REFORESTIZES_11290483511697450376)],
        &[(0b00001, &ENTRY_REFORMADES_3091028366731709504)],
        &[(0b11010, &ENTRY_REFORMADES_3091028366731709504)],
        &[(0b00001, &ENTRY_REFUELED_6350295186272675162)],
        &[(0b00001, &ENTRY_REFUELING_13653298214509580404)],
        &[(0b11010, &ENTRY_REFUELED_6350295186272675162)],
        &[(0b11010, &ENTRY_REFUELING_13653298214509580404)],
    ],
    range: 4..=13,
};

static VARS_REE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REE_CHILDREN),
    value: None,
};

pub static VARS_REE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dified"),
        dictgen::InsensitiveStr::Ascii("difies"),
        dictgen::InsensitiveStr::Ascii("dify"),
        dictgen::InsensitiveStr::Ascii("difying"),
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasised"),
        dictgen::InsensitiveStr::Ascii("mphasiser"),
        dictgen::InsensitiveStr::Ascii("mphasisers"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasising"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasized"),
        dictgen::InsensitiveStr::Ascii("mphasizer"),
        dictgen::InsensitiveStr::Ascii("mphasizers"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("mphasizing"),
        dictgen::InsensitiveStr::Ascii("nforce"),
        dictgen::InsensitiveStr::Ascii("nforced"),
        dictgen::InsensitiveStr::Ascii("nforces"),
        dictgen::InsensitiveStr::Ascii("nforcing"),
        dictgen::InsensitiveStr::Ascii("ntrance"),
        dictgen::InsensitiveStr::Ascii("xportation"),
        dictgen::InsensitiveStr::Ascii("xporter"),
    ],
    values: &[
        &[(0b00001, &ENTRY_REEDIFIED_17185371367326424982)],
        &[(0b00001, &ENTRY_REEDIFIES_9756610285343034160)],
        &[(0b00001, &ENTRY_REEDIFY_14467490388921640991)],
        &[(0b00001, &ENTRY_REEDIFYING_13575861282224820161)],
        &[(0b10010, &ENTRY_REEMPHASIZE_14845797480169011940)],
        &[(0b10010, &ENTRY_REEMPHASIZED_12384916709213775729)],
        &[(0b10010, &ENTRY_REEMPHASIZER_15541175908528906257)],
        &[(0b10010, &ENTRY_REEMPHASIZERS_5418129948384015229)],
        &[(0b10010, &ENTRY_REEMPHASIZES_1924687289037556817)],
        &[(0b10010, &ENTRY_REEMPHASIZING_5952154417428143353)],
        &[(0b01001, &ENTRY_REEMPHASIZE_14845797480169011940)],
        &[(0b01001, &ENTRY_REEMPHASIZED_12384916709213775729)],
        &[(0b01001, &ENTRY_REEMPHASIZER_15541175908528906257)],
        &[(0b01001, &ENTRY_REEMPHASIZERS_5418129948384015229)],
        &[(0b01001, &ENTRY_REEMPHASIZES_1924687289037556817)],
        &[(0b01001, &ENTRY_REEMPHASIZING_5952154417428143353)],
        &[(0b00001, &ENTRY_REINFORCE_15866859185409520783)],
        &[(0b00001, &ENTRY_REINFORCED_10977672612230158068)],
        &[(0b00001, &ENTRY_REINFORCES_12402996319523896012)],
        &[(0b00001, &ENTRY_REINFORCING_9420906960117208611)],
        &[(0b00001, &ENTRY_REENTRANCE_14813557870017739558)],
        &[(0b00001, &ENTRY_REEXPORTATION_9761953209479597434)],
        &[(0b00001, &ENTRY_REEXPORTER_204235148455899141)],
    ],
    range: 4..=10,
};

static VARS_RED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RED_CHILDREN),
    value: None,
};

pub static VARS_RED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialed"),
        dictgen::InsensitiveStr::Ascii("ialer"),
        dictgen::InsensitiveStr::Ascii("ialing"),
        dictgen::InsensitiveStr::Ascii("ialled"),
        dictgen::InsensitiveStr::Ascii("ialler"),
        dictgen::InsensitiveStr::Ascii("ialling"),
        dictgen::InsensitiveStr::Ascii("isseise"),
        dictgen::InsensitiveStr::Ascii("isseisin"),
        dictgen::InsensitiveStr::Ascii("isseize"),
        dictgen::InsensitiveStr::Ascii("isseizin"),
    ],
    values: &[
        &[(0b01001, &ENTRY_REDIALED_1443583636270689000)],
        &[(0b00001, &ENTRY_REDIALER_15041522948567414545)],
        &[(0b01001, &ENTRY_REDIALING_7917159843633067663)],
        &[(0b11010, &ENTRY_REDIALED_1443583636270689000)],
        &[(0b11010, &ENTRY_REDIALER_15041522948567414545)],
        &[(0b11010, &ENTRY_REDIALING_7917159843633067663)],
        &[(0b10010, &ENTRY_REDISSEIZE_12321412602071096537)],
        &[(0b10010, &ENTRY_REDISSEIZIN_5313153373478904686)],
        &[(0b01001, &ENTRY_REDISSEIZE_12321412602071096537)],
        &[(0b01001, &ENTRY_REDISSEIZIN_5313153373478904686)],
    ],
    range: 5..=8,
};

static VARS_REC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REC_CHILDREN),
    value: None,
};

static VARS_REC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_RECA_NODE),
    None,
    None,
    None,
    Some(&VARS_RECE_NODE),
    None,
    None,
    None,
    Some(&VARS_RECI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RECO_NODE),
    None,
    None,
    Some(&VARS_RECR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_RECR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECR_CHILDREN),
    value: None,
};

pub static VARS_RECR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iticise"),
        dictgen::InsensitiveStr::Ascii("iticises"),
        dictgen::InsensitiveStr::Ascii("iticize"),
        dictgen::InsensitiveStr::Ascii("iticizes"),
        dictgen::InsensitiveStr::Ascii("ystallisation"),
        dictgen::InsensitiveStr::Ascii("ystallisations"),
        dictgen::InsensitiveStr::Ascii("ystallise"),
        dictgen::InsensitiveStr::Ascii("ystallised"),
        dictgen::InsensitiveStr::Ascii("ystallises"),
        dictgen::InsensitiveStr::Ascii("ystallising"),
        dictgen::InsensitiveStr::Ascii("ystallization"),
        dictgen::InsensitiveStr::Ascii("ystallizations"),
        dictgen::InsensitiveStr::Ascii("ystallize"),
        dictgen::InsensitiveStr::Ascii("ystallized"),
        dictgen::InsensitiveStr::Ascii("ystallizes"),
        dictgen::InsensitiveStr::Ascii("ystallizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECRITICIZE_10742947607354632832)],
        &[(0b10010, &ENTRY_RECRITICIZES_90813554752564010)],
        &[(0b01001, &ENTRY_RECRITICIZE_10742947607354632832)],
        &[(0b01001, &ENTRY_RECRITICIZES_90813554752564010)],
        &[(0b10010, &ENTRY_RECRYSTALLIZATION_1860786864462001408)],
        &[(0b10010, &ENTRY_RECRYSTALLIZATIONS_16182832227691275920)],
        &[(0b10010, &ENTRY_RECRYSTALLIZE_17331547300893041236)],
        &[(0b10010, &ENTRY_RECRYSTALLIZED_11205669347561069076)],
        &[(0b10010, &ENTRY_RECRYSTALLIZES_16108644468574946795)],
        &[(0b10010, &ENTRY_RECRYSTALLIZING_12962671839000145939)],
        &[(0b01001, &ENTRY_RECRYSTALLIZATION_1860786864462001408)],
        &[(0b01001, &ENTRY_RECRYSTALLIZATIONS_16182832227691275920)],
        &[(0b01001, &ENTRY_RECRYSTALLIZE_17331547300893041236)],
        &[(0b01001, &ENTRY_RECRYSTALLIZED_11205669347561069076)],
        &[(0b01001, &ENTRY_RECRYSTALLIZES_16108644468574946795)],
        &[(0b01001, &ENTRY_RECRYSTALLIZING_12962671839000145939)],
    ],
    range: 7..=14,
};

static VARS_RECO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RECO_CHILDREN),
    value: None,
};

static VARS_RECO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RECOG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_RECOL_NODE),
    None,
    Some(&VARS_RECON_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_RECON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECON_CHILDREN),
    value: None,
};

pub static VARS_RECON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ceptualisation"),
        dictgen::InsensitiveStr::Ascii("ceptualising"),
        dictgen::InsensitiveStr::Ascii("ceptualization"),
        dictgen::InsensitiveStr::Ascii("ceptualizing"),
        dictgen::InsensitiveStr::Ascii("noiter"),
        dictgen::InsensitiveStr::Ascii("noitered"),
        dictgen::InsensitiveStr::Ascii("noiterer"),
        dictgen::InsensitiveStr::Ascii("noiterers"),
        dictgen::InsensitiveStr::Ascii("noitering"),
        dictgen::InsensitiveStr::Ascii("noiters"),
        dictgen::InsensitiveStr::Ascii("noitre"),
        dictgen::InsensitiveStr::Ascii("noitred"),
        dictgen::InsensitiveStr::Ascii("noitrer"),
        dictgen::InsensitiveStr::Ascii("noitrers"),
        dictgen::InsensitiveStr::Ascii("noitres"),
        dictgen::InsensitiveStr::Ascii("noitring"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECONCEPTUALIZATION_3284710301791003378)],
        &[(0b10010, &ENTRY_RECONCEPTUALIZING_14548968664268398028)],
        &[(0b01001, &ENTRY_RECONCEPTUALIZATION_3284710301791003378)],
        &[(0b01001, &ENTRY_RECONCEPTUALIZING_14548968664268398028)],
        &[(0b01001, &ENTRY_RECONNOITER_18316377090168333117)],
        &[(0b01001, &ENTRY_RECONNOITERED_1091968190945009220)],
        &[(0b00001, &ENTRY_RECONNOITERER_12511415252932652959)],
        &[(0b00001, &ENTRY_RECONNOITERERS_8799608756200599017)],
        &[(0b01001, &ENTRY_RECONNOITERING_18391585459717006853)],
        &[(0b01001, &ENTRY_RECONNOITERS_13027705962087318478)],
        &[(0b11010, &ENTRY_RECONNOITER_18316377090168333117)],
        &[(0b11010, &ENTRY_RECONNOITERED_1091968190945009220)],
        &[(0b11010, &ENTRY_RECONNOITERER_12511415252932652959)],
        &[(0b11010, &ENTRY_RECONNOITERERS_8799608756200599017)],
        &[(0b11010, &ENTRY_RECONNOITERS_13027705962087318478)],
        &[(0b11010, &ENTRY_RECONNOITERING_18391585459717006853)],
    ],
    range: 6..=14,
};

static VARS_RECOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECOL_CHILDREN),
    value: None,
};

pub static VARS_RECOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("oration"),
        dictgen::InsensitiveStr::Ascii("orations"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ouration"),
        dictgen::InsensitiveStr::Ascii("ourations"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECOLONIZATION_16258927676742050499)],
        &[(0b10010, &ENTRY_RECOLONIZATIONS_7011055890180445996)],
        &[(0b10010, &ENTRY_RECOLONIZE_1210620957407633342)],
        &[(0b10010, &ENTRY_RECOLONIZED_1553732142933540424)],
        &[(0b10010, &ENTRY_RECOLONIZES_7070029475272886204)],
        &[(0b10010, &ENTRY_RECOLONIZING_15474385751968098455)],
        &[(0b01001, &ENTRY_RECOLONIZATION_16258927676742050499)],
        &[(0b01001, &ENTRY_RECOLONIZATIONS_7011055890180445996)],
        &[(0b01001, &ENTRY_RECOLONIZE_1210620957407633342)],
        &[(0b01001, &ENTRY_RECOLONIZED_1553732142933540424)],
        &[(0b01001, &ENTRY_RECOLONIZES_7070029475272886204)],
        &[(0b01001, &ENTRY_RECOLONIZING_15474385751968098455)],
        &[(0b10001, &ENTRY_RECOLOR_3257883209193222439)],
        &[(0b00001, &ENTRY_RECOLORATION_284267020047489567)],
        &[(0b00001, &ENTRY_RECOLORATIONS_4889262529781127619)],
        &[(0b10001, &ENTRY_RECOLORED_17015675809629209249)],
        &[(0b10001, &ENTRY_RECOLORING_6696403137875712708)],
        &[(0b10001, &ENTRY_RECOLORS_13250820879245551898)],
        &[(0b11010, &ENTRY_RECOLOR_3257883209193222439)],
        &[(0b11010, &ENTRY_RECOLORATION_284267020047489567)],
        &[(0b11010, &ENTRY_RECOLORATIONS_4889262529781127619)],
        &[(0b11010, &ENTRY_RECOLORED_17015675809629209249)],
        &[(0b11010, &ENTRY_RECOLORING_6696403137875712708)],
        &[(0b11010, &ENTRY_RECOLORS_13250820879245551898)],
    ],
    range: 2..=10,
};

static VARS_RECOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECOG_CHILDREN),
    value: None,
};

pub static VARS_RECOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisability"),
        dictgen::InsensitiveStr::Ascii("nisable"),
        dictgen::InsensitiveStr::Ascii("nisabler"),
        dictgen::InsensitiveStr::Ascii("nisablest"),
        dictgen::InsensitiveStr::Ascii("nisably"),
        dictgen::InsensitiveStr::Ascii("nisance"),
        dictgen::InsensitiveStr::Ascii("nisances"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nisedlies"),
        dictgen::InsensitiveStr::Ascii("nisedly"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nisinglies"),
        dictgen::InsensitiveStr::Ascii("nisingly"),
        dictgen::InsensitiveStr::Ascii("nizability"),
        dictgen::InsensitiveStr::Ascii("nizable"),
        dictgen::InsensitiveStr::Ascii("nizabler"),
        dictgen::InsensitiveStr::Ascii("nizablest"),
        dictgen::InsensitiveStr::Ascii("nizably"),
        dictgen::InsensitiveStr::Ascii("nizance"),
        dictgen::InsensitiveStr::Ascii("nizances"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizedlies"),
        dictgen::InsensitiveStr::Ascii("nizedly"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
        dictgen::InsensitiveStr::Ascii("nizinglies"),
        dictgen::InsensitiveStr::Ascii("nizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECOGNIZABILITY_16998271750617343863)],
        &[(0b10010, &ENTRY_RECOGNIZABLE_5889010403845230013)],
        &[(0b10010, &ENTRY_RECOGNIZABLER_4175265933374548777)],
        &[(0b10010, &ENTRY_RECOGNIZABLEST_10751547482572497805)],
        &[(0b10010, &ENTRY_RECOGNIZABLY_11330537720549631906)],
        &[(0b10010, &ENTRY_RECOGNIZANCE_15579684512687603764)],
        &[(0b10010, &ENTRY_RECOGNIZANCES_6362532022872453821)],
        &[(0b10010, &ENTRY_RECOGNIZE_8073300949060678463)],
        &[(0b10010, &ENTRY_RECOGNIZED_1395716530900621428)],
        &[(0b10010, &ENTRY_RECOGNIZEDLIES_14465767719751035498)],
        &[(0b10010, &ENTRY_RECOGNIZEDLY_15932389996645062386)],
        &[(0b10010, &ENTRY_RECOGNIZER_8772856764417667202)],
        &[(0b10010, &ENTRY_RECOGNIZERS_6758013473971762546)],
        &[(0b10010, &ENTRY_RECOGNIZES_10660009240958159019)],
        &[(0b10010, &ENTRY_RECOGNIZING_11885856045541184543)],
        &[(0b10010, &ENTRY_RECOGNIZINGLIES_11967771031854316683)],
        &[(0b10010, &ENTRY_RECOGNIZINGLY_15449966182297309703)],
        &[(0b01001, &ENTRY_RECOGNIZABILITY_16998271750617343863)],
        &[(0b01001, &ENTRY_RECOGNIZABLE_5889010403845230013)],
        &[(0b01001, &ENTRY_RECOGNIZABLER_4175265933374548777)],
        &[(0b01001, &ENTRY_RECOGNIZABLEST_10751547482572497805)],
        &[(0b01001, &ENTRY_RECOGNIZABLY_11330537720549631906)],
        &[(0b01001, &ENTRY_RECOGNIZANCE_15579684512687603764)],
        &[(0b01001, &ENTRY_RECOGNIZANCES_6362532022872453821)],
        &[(0b01001, &ENTRY_RECOGNIZE_8073300949060678463)],
        &[(0b01001, &ENTRY_RECOGNIZED_1395716530900621428)],
        &[(0b01001, &ENTRY_RECOGNIZEDLIES_14465767719751035498)],
        &[(0b01001, &ENTRY_RECOGNIZEDLY_15932389996645062386)],
        &[(0b01001, &ENTRY_RECOGNIZER_8772856764417667202)],
        &[(0b01001, &ENTRY_RECOGNIZERS_6758013473971762546)],
        &[(0b01001, &ENTRY_RECOGNIZES_10660009240958159019)],
        &[(0b01001, &ENTRY_RECOGNIZING_11885856045541184543)],
        &[(0b01001, &ENTRY_RECOGNIZINGLIES_11967771031854316683)],
        &[(0b01001, &ENTRY_RECOGNIZINGLY_15449966182297309703)],
    ],
    range: 4..=10,
};

static VARS_RECI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECI_CHILDREN),
    value: None,
};

pub static VARS_RECI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("procalise"),
        dictgen::InsensitiveStr::Ascii("procalises"),
        dictgen::InsensitiveStr::Ascii("procalize"),
        dictgen::InsensitiveStr::Ascii("procalizes"),
        dictgen::InsensitiveStr::Ascii("vilisation"),
        dictgen::InsensitiveStr::Ascii("vilisations"),
        dictgen::InsensitiveStr::Ascii("vilise"),
        dictgen::InsensitiveStr::Ascii("vilises"),
        dictgen::InsensitiveStr::Ascii("vilization"),
        dictgen::InsensitiveStr::Ascii("vilizations"),
        dictgen::InsensitiveStr::Ascii("vilize"),
        dictgen::InsensitiveStr::Ascii("vilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECIPROCALIZE_14788818366272476641)],
        &[(0b10010, &ENTRY_RECIPROCALIZES_6837540957901914138)],
        &[(0b01001, &ENTRY_RECIPROCALIZE_14788818366272476641)],
        &[(0b01001, &ENTRY_RECIPROCALIZES_6837540957901914138)],
        &[(0b10010, &ENTRY_RECIVILIZATION_16749469924106120267)],
        &[(0b10010, &ENTRY_RECIVILIZATIONS_15159458739775450649)],
        &[(0b10010, &ENTRY_RECIVILIZE_3997712789498055993)],
        &[(0b10010, &ENTRY_RECIVILIZES_13280929754254705028)],
        &[(0b01001, &ENTRY_RECIVILIZATION_16749469924106120267)],
        &[(0b01001, &ENTRY_RECIVILIZATIONS_15159458739775450649)],
        &[(0b01001, &ENTRY_RECIVILIZE_3997712789498055993)],
        &[(0b01001, &ENTRY_RECIVILIZES_13280929754254705028)],
    ],
    range: 6..=11,
};

static VARS_RECE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECE_CHILDREN),
    value: None,
};

pub static VARS_RECE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ntralisation"),
        dictgen::InsensitiveStr::Ascii("ntralisations"),
        dictgen::InsensitiveStr::Ascii("ntralise"),
        dictgen::InsensitiveStr::Ascii("ntralises"),
        dictgen::InsensitiveStr::Ascii("ntralization"),
        dictgen::InsensitiveStr::Ascii("ntralizations"),
        dictgen::InsensitiveStr::Ascii("ntralize"),
        dictgen::InsensitiveStr::Ascii("ntralizes"),
        dictgen::InsensitiveStr::Ascii("rcelae"),
        dictgen::InsensitiveStr::Ascii("rcele"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECENTRALIZATION_6419892289797763156)],
        &[(0b10010, &ENTRY_RECENTRALIZATIONS_17081718818823233232)],
        &[(0b10010, &ENTRY_RECENTRALIZE_5404153365159026113)],
        &[(0b10010, &ENTRY_RECENTRALIZES_14658033323787489399)],
        &[(0b01001, &ENTRY_RECENTRALIZATION_6419892289797763156)],
        &[(0b01001, &ENTRY_RECENTRALIZATIONS_17081718818823233232)],
        &[(0b01001, &ENTRY_RECENTRALIZE_5404153365159026113)],
        &[(0b01001, &ENTRY_RECENTRALIZES_14658033323787489399)],
        &[(0b11010, &ENTRY_RECERCELE_9415487321125207769)],
        &[(0b00001, &ENTRY_RECERCELE_9415487321125207769)],
    ],
    range: 5..=13,
};

static VARS_RECA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RECA_CHILDREN),
    value: None,
};

pub static VARS_RECA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nalisation"),
        dictgen::InsensitiveStr::Ascii("nalization"),
        dictgen::InsensitiveStr::Ascii("pitalisation"),
        dictgen::InsensitiveStr::Ascii("pitalisations"),
        dictgen::InsensitiveStr::Ascii("pitalise"),
        dictgen::InsensitiveStr::Ascii("pitalised"),
        dictgen::InsensitiveStr::Ascii("pitalises"),
        dictgen::InsensitiveStr::Ascii("pitalising"),
        dictgen::InsensitiveStr::Ascii("pitalization"),
        dictgen::InsensitiveStr::Ascii("pitalizations"),
        dictgen::InsensitiveStr::Ascii("pitalize"),
        dictgen::InsensitiveStr::Ascii("pitalized"),
        dictgen::InsensitiveStr::Ascii("pitalizes"),
        dictgen::InsensitiveStr::Ascii("pitalizing"),
        dictgen::InsensitiveStr::Ascii("rbonisation"),
        dictgen::InsensitiveStr::Ascii("rbonisations"),
        dictgen::InsensitiveStr::Ascii("rbonise"),
        dictgen::InsensitiveStr::Ascii("rboniser"),
        dictgen::InsensitiveStr::Ascii("rbonisers"),
        dictgen::InsensitiveStr::Ascii("rbonises"),
        dictgen::InsensitiveStr::Ascii("rbonization"),
        dictgen::InsensitiveStr::Ascii("rbonizations"),
        dictgen::InsensitiveStr::Ascii("rbonize"),
        dictgen::InsensitiveStr::Ascii("rbonizer"),
        dictgen::InsensitiveStr::Ascii("rbonizers"),
        dictgen::InsensitiveStr::Ascii("rbonizes"),
        dictgen::InsensitiveStr::Ascii("tegorised"),
        dictgen::InsensitiveStr::Ascii("tegorized"),
        dictgen::InsensitiveStr::Ascii("usticise"),
        dictgen::InsensitiveStr::Ascii("usticises"),
        dictgen::InsensitiveStr::Ascii("usticize"),
        dictgen::InsensitiveStr::Ascii("usticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RECANALIZATION_9848130740850646766)],
        &[(0b01001, &ENTRY_RECANALIZATION_9848130740850646766)],
        &[(0b10010, &ENTRY_RECAPITALIZATION_13789246273577829586)],
        &[(0b10010, &ENTRY_RECAPITALIZATIONS_3489528805026955416)],
        &[(0b10010, &ENTRY_RECAPITALIZE_18040056007083479651)],
        &[(0b10010, &ENTRY_RECAPITALIZED_3935375616241692055)],
        &[(0b10010, &ENTRY_RECAPITALIZES_8130308401555173305)],
        &[(0b10010, &ENTRY_RECAPITALIZING_14545289468100637309)],
        &[(0b01001, &ENTRY_RECAPITALIZATION_13789246273577829586)],
        &[(0b01001, &ENTRY_RECAPITALIZATIONS_3489528805026955416)],
        &[(0b01001, &ENTRY_RECAPITALIZE_18040056007083479651)],
        &[(0b01001, &ENTRY_RECAPITALIZED_3935375616241692055)],
        &[(0b01001, &ENTRY_RECAPITALIZES_8130308401555173305)],
        &[(0b01001, &ENTRY_RECAPITALIZING_14545289468100637309)],
        &[(0b10010, &ENTRY_RECARBONIZATION_14106539650901519060)],
        &[(0b10010, &ENTRY_RECARBONIZATIONS_17520317422251898259)],
        &[(0b10010, &ENTRY_RECARBONIZE_15994488180990553654)],
        &[(0b10010, &ENTRY_RECARBONIZER_6401093463168506503)],
        &[(0b10010, &ENTRY_RECARBONIZERS_13171975227254449418)],
        &[(0b10010, &ENTRY_RECARBONIZES_1395029874212040625)],
        &[(0b01001, &ENTRY_RECARBONIZATION_14106539650901519060)],
        &[(0b01001, &ENTRY_RECARBONIZATIONS_17520317422251898259)],
        &[(0b01001, &ENTRY_RECARBONIZE_15994488180990553654)],
        &[(0b01001, &ENTRY_RECARBONIZER_6401093463168506503)],
        &[(0b01001, &ENTRY_RECARBONIZERS_13171975227254449418)],
        &[(0b01001, &ENTRY_RECARBONIZES_1395029874212040625)],
        &[(0b10010, &ENTRY_RECATEGORIZED_1861087840624306453)],
        &[(0b01001, &ENTRY_RECATEGORIZED_1861087840624306453)],
        &[(0b10010, &ENTRY_RECAUSTICIZE_14314640527642854828)],
        &[(0b10010, &ENTRY_RECAUSTICIZES_13573292008926947855)],
        &[(0b01001, &ENTRY_RECAUSTICIZE_14314640527642854828)],
        &[(0b01001, &ENTRY_RECAUSTICIZES_13573292008926947855)],
    ],
    range: 7..=13,
};

static VARS_REB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REB_CHILDREN),
    value: None,
};

pub static VARS_REB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptisation"),
        dictgen::InsensitiveStr::Ascii("aptisations"),
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptised"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptising"),
        dictgen::InsensitiveStr::Ascii("aptization"),
        dictgen::InsensitiveStr::Ascii("aptizations"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptized"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
        dictgen::InsensitiveStr::Ascii("aptizing"),
        dictgen::InsensitiveStr::Ascii("ia"),
        dictgen::InsensitiveStr::Ascii("ias"),
        dictgen::InsensitiveStr::Ascii("ourbonise"),
        dictgen::InsensitiveStr::Ascii("ourbonises"),
        dictgen::InsensitiveStr::Ascii("ourbonize"),
        dictgen::InsensitiveStr::Ascii("ourbonizes"),
        dictgen::InsensitiveStr::Ascii("rutalise"),
        dictgen::InsensitiveStr::Ascii("rutalises"),
        dictgen::InsensitiveStr::Ascii("rutalize"),
        dictgen::InsensitiveStr::Ascii("rutalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REBAPTIZATION_14913572866891296519)],
        &[(0b10010, &ENTRY_REBAPTIZATIONS_10409601231952199745)],
        &[(0b10010, &ENTRY_REBAPTIZE_571434688106506900)],
        &[(0b10010, &ENTRY_REBAPTIZED_7549343503873914730)],
        &[(0b10010, &ENTRY_REBAPTIZES_8627235980201949978)],
        &[(0b10010, &ENTRY_REBAPTIZING_1458650261134996813)],
        &[(0b01001, &ENTRY_REBAPTIZATION_14913572866891296519)],
        &[(0b01001, &ENTRY_REBAPTIZATIONS_10409601231952199745)],
        &[(0b01001, &ENTRY_REBAPTIZE_571434688106506900)],
        &[(0b01001, &ENTRY_REBAPTIZED_7549343503873914730)],
        &[(0b01001, &ENTRY_REBAPTIZES_8627235980201949978)],
        &[(0b01001, &ENTRY_REBAPTIZING_1458650261134996813)],
        &[(0b11010, &ENTRY_ERBIA_3590263034241709068)],
        &[(0b11010, &ENTRY_ERBIAS_7628332259520876430)],
        &[(0b10010, &ENTRY_REBOURBONIZE_5261400215839580856)],
        &[(0b10010, &ENTRY_REBOURBONIZES_17217540334190607076)],
        &[(0b01001, &ENTRY_REBOURBONIZE_5261400215839580856)],
        &[(0b01001, &ENTRY_REBOURBONIZES_17217540334190607076)],
        &[(0b10010, &ENTRY_REBRUTALIZE_15890308064516958097)],
        &[(0b10010, &ENTRY_REBRUTALIZES_4495483792663700379)],
        &[(0b01001, &ENTRY_REBRUTALIZE_15890308064516958097)],
        &[(0b01001, &ENTRY_REBRUTALIZES_4495483792663700379)],
    ],
    range: 2..=11,
};

static VARS_REA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_REA_CHILDREN),
    value: None,
};

static VARS_REA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_REAC_NODE),
    Some(&VARS_READ_NODE),
    Some(&VARS_REAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_REAL_NODE),
    None,
    Some(&VARS_REAN_NODE),
    None,
    Some(&VARS_REAP_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_REAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_REAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAU_CHILDREN),
    value: None,
};

pub static VARS_REAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thorisation"),
        dictgen::InsensitiveStr::Ascii("thorisations"),
        dictgen::InsensitiveStr::Ascii("thorise"),
        dictgen::InsensitiveStr::Ascii("thorises"),
        dictgen::InsensitiveStr::Ascii("thorization"),
        dictgen::InsensitiveStr::Ascii("thorizations"),
        dictgen::InsensitiveStr::Ascii("thorize"),
        dictgen::InsensitiveStr::Ascii("thorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REAUTHORIZATION_5069423989935588733)],
        &[(0b10010, &ENTRY_REAUTHORIZATIONS_15987529216192362803)],
        &[(0b10010, &ENTRY_REAUTHORIZE_1493549425007215475)],
        &[(0b10010, &ENTRY_REAUTHORIZES_9412231466354343842)],
        &[(0b01001, &ENTRY_REAUTHORIZATION_5069423989935588733)],
        &[(0b01001, &ENTRY_REAUTHORIZATIONS_15987529216192362803)],
        &[(0b01001, &ENTRY_REAUTHORIZE_1493549425007215475)],
        &[(0b01001, &ENTRY_REAUTHORIZES_9412231466354343842)],
    ],
    range: 7..=12,
};

static VARS_REAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAP_CHILDREN),
    value: None,
};

pub static VARS_REAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ologise"),
        dictgen::InsensitiveStr::Ascii("ologises"),
        dictgen::InsensitiveStr::Ascii("ologize"),
        dictgen::InsensitiveStr::Ascii("ologizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REAPOLOGIZE_14132055598610834333)],
        &[(0b10010, &ENTRY_REAPOLOGIZES_2274108662665466732)],
        &[(0b01001, &ENTRY_REAPOLOGIZE_14132055598610834333)],
        &[(0b01001, &ENTRY_REAPOLOGIZES_2274108662665466732)],
    ],
    range: 7..=8,
};

static VARS_REAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAN_CHILDREN),
    value: None,
};

pub static VARS_REAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alyse"),
        dictgen::InsensitiveStr::Ascii("alysed"),
        dictgen::InsensitiveStr::Ascii("alyser"),
        dictgen::InsensitiveStr::Ascii("alysers"),
        dictgen::InsensitiveStr::Ascii("alysing"),
        dictgen::InsensitiveStr::Ascii("alyze"),
        dictgen::InsensitiveStr::Ascii("alyzed"),
        dictgen::InsensitiveStr::Ascii("alyzer"),
        dictgen::InsensitiveStr::Ascii("alyzers"),
        dictgen::InsensitiveStr::Ascii("alyzes"),
        dictgen::InsensitiveStr::Ascii("alyzing"),
        dictgen::InsensitiveStr::Ascii("imalise"),
        dictgen::InsensitiveStr::Ascii("imalises"),
        dictgen::InsensitiveStr::Ascii("imalize"),
        dictgen::InsensitiveStr::Ascii("imalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REANALYZE_10186131393135073487)],
        &[(0b10010, &ENTRY_REANALYZED_4571855154510793046)],
        &[(0b10010, &ENTRY_REANALYZER_3769720403208548613)],
        &[(0b10010, &ENTRY_REANALYZERS_11991980726543842859)],
        &[(0b10010, &ENTRY_REANALYZING_7827332182372932126)],
        &[(0b01001, &ENTRY_REANALYZE_10186131393135073487)],
        &[(0b01001, &ENTRY_REANALYZED_4571855154510793046)],
        &[(0b01001, &ENTRY_REANALYZER_3769720403208548613)],
        &[(0b01001, &ENTRY_REANALYZERS_11991980726543842859)],
        &[(0b01001, &ENTRY_REANALYZES_6422780434253423868)],
        &[(0b01001, &ENTRY_REANALYZING_7827332182372932126)],
        &[(0b10010, &ENTRY_REANIMALIZE_3196465253809288594)],
        &[(0b10010, &ENTRY_REANIMALIZES_15653498423524957266)],
        &[(0b01001, &ENTRY_REANIMALIZE_3196465253809288594)],
        &[(0b01001, &ENTRY_REANIMALIZES_15653498423524957266)],
    ],
    range: 5..=8,
};

static VARS_REAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAL_CHILDREN),
    value: None,
};

pub static VARS_REAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isabilities"),
        dictgen::InsensitiveStr::Ascii("isability"),
        dictgen::InsensitiveStr::Ascii("isable"),
        dictgen::InsensitiveStr::Ascii("isableness"),
        dictgen::InsensitiveStr::Ascii("isabler"),
        dictgen::InsensitiveStr::Ascii("isables"),
        dictgen::InsensitiveStr::Ascii("isablest"),
        dictgen::InsensitiveStr::Ascii("isablies"),
        dictgen::InsensitiveStr::Ascii("isably"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("isers"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("isingly"),
        dictgen::InsensitiveStr::Ascii("isings"),
        dictgen::InsensitiveStr::Ascii("isticise"),
        dictgen::InsensitiveStr::Ascii("isticises"),
        dictgen::InsensitiveStr::Ascii("isticize"),
        dictgen::InsensitiveStr::Ascii("isticizes"),
        dictgen::InsensitiveStr::Ascii("izabilities"),
        dictgen::InsensitiveStr::Ascii("izability"),
        dictgen::InsensitiveStr::Ascii("izable"),
        dictgen::InsensitiveStr::Ascii("izableness"),
        dictgen::InsensitiveStr::Ascii("izabler"),
        dictgen::InsensitiveStr::Ascii("izables"),
        dictgen::InsensitiveStr::Ascii("izablest"),
        dictgen::InsensitiveStr::Ascii("izablies"),
        dictgen::InsensitiveStr::Ascii("izably"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("izers"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("izingly"),
        dictgen::InsensitiveStr::Ascii("izings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REALIZABILITIES_1107948109278957869)],
        &[(0b10010, &ENTRY_REALIZABILITY_7120240154132794852)],
        &[(0b10010, &ENTRY_REALIZABLE_17163353249932728066)],
        &[(0b10010, &ENTRY_REALIZABLENESS_16356767595928190053)],
        &[(0b10010, &ENTRY_REALIZABLER_10808842652675364031)],
        &[(0b10010, &ENTRY_REALIZABLES_12573952050524775505)],
        &[(0b10010, &ENTRY_REALIZABLEST_5797694315741755778)],
        &[(0b10010, &ENTRY_REALIZABLIES_11825765500038359602)],
        &[(0b10010, &ENTRY_REALIZABLY_9506389367577953795)],
        &[(0b10010, &ENTRY_REALIZATION_14225128147203750365)],
        &[(0b10010, &ENTRY_REALIZATIONS_11017380405499744692)],
        &[(0b10010, &ENTRY_REALIZE_2182577141310692876)],
        &[(0b10010, &ENTRY_REALIZED_1705791300416174175)],
        &[(0b10010, &ENTRY_REALIZER_492931096277732629)],
        &[(0b10010, &ENTRY_REALIZERS_5837268423419941688)],
        &[(0b10010, &ENTRY_REALIZES_10741119444291026235)],
        &[(0b10010, &ENTRY_REALIZING_3319107293179944558)],
        &[(0b10010, &ENTRY_REALIZINGLY_11111595947779632968)],
        &[(0b10010, &ENTRY_REALIZINGS_8807041604242423702)],
        &[(0b10010, &ENTRY_REALISTICIZE_5772362692210402917)],
        &[(0b10010, &ENTRY_REALISTICIZES_9600102337891080845)],
        &[(0b01001, &ENTRY_REALISTICIZE_5772362692210402917)],
        &[(0b01001, &ENTRY_REALISTICIZES_9600102337891080845)],
        &[(0b01001, &ENTRY_REALIZABILITIES_1107948109278957869)],
        &[(0b01001, &ENTRY_REALIZABILITY_7120240154132794852)],
        &[(0b01001, &ENTRY_REALIZABLE_17163353249932728066)],
        &[(0b01001, &ENTRY_REALIZABLENESS_16356767595928190053)],
        &[(0b01001, &ENTRY_REALIZABLER_10808842652675364031)],
        &[(0b01001, &ENTRY_REALIZABLES_12573952050524775505)],
        &[(0b01001, &ENTRY_REALIZABLEST_5797694315741755778)],
        &[(0b01001, &ENTRY_REALIZABLIES_11825765500038359602)],
        &[(0b01001, &ENTRY_REALIZABLY_9506389367577953795)],
        &[(0b01001, &ENTRY_REALIZATION_14225128147203750365)],
        &[(0b01001, &ENTRY_REALIZATIONS_11017380405499744692)],
        &[(0b01001, &ENTRY_REALIZE_2182577141310692876)],
        &[(0b01001, &ENTRY_REALIZED_1705791300416174175)],
        &[(0b01001, &ENTRY_REALIZER_492931096277732629)],
        &[(0b01001, &ENTRY_REALIZERS_5837268423419941688)],
        &[(0b01001, &ENTRY_REALIZES_10741119444291026235)],
        &[(0b01001, &ENTRY_REALIZING_3319107293179944558)],
        &[(0b01001, &ENTRY_REALIZINGLY_11111595947779632968)],
        &[(0b01001, &ENTRY_REALIZINGS_8807041604242423702)],
    ],
    range: 3..=11,
};

static VARS_REAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAE_CHILDREN),
    value: None,
};

pub static VARS_REAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dified"),
        dictgen::InsensitiveStr::Ascii("difies"),
        dictgen::InsensitiveStr::Ascii("dify"),
        dictgen::InsensitiveStr::Ascii("difying"),
        dictgen::InsensitiveStr::Ascii("ntrance"),
        dictgen::InsensitiveStr::Ascii("xportation"),
        dictgen::InsensitiveStr::Ascii("xporter"),
    ],
    values: &[
        &[(0b11010, &ENTRY_REEDIFIED_17185371367326424982)],
        &[(0b11010, &ENTRY_REEDIFIES_9756610285343034160)],
        &[(0b11010, &ENTRY_REEDIFY_14467490388921640991)],
        &[(0b11010, &ENTRY_REEDIFYING_13575861282224820161)],
        &[(0b11010, &ENTRY_REENTRANCE_14813557870017739558)],
        &[(0b11010, &ENTRY_REEXPORTATION_9761953209479597434)],
        &[(0b11010, &ENTRY_REEXPORTER_204235148455899141)],
    ],
    range: 4..=10,
};

static VARS_READ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_READ_CHILDREN),
    value: None,
};

pub static VARS_READ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("vertise"),
        dictgen::InsensitiveStr::Ascii("vertised"),
        dictgen::InsensitiveStr::Ascii("vertising"),
        dictgen::InsensitiveStr::Ascii("vertize"),
        dictgen::InsensitiveStr::Ascii("vertized"),
        dictgen::InsensitiveStr::Ascii("vertizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_READVERTIZE_17135010889729486559)],
        &[(0b10010, &ENTRY_READVERTIZED_17989467612846660175)],
        &[(0b10010, &ENTRY_READVERTIZING_4761320404074285638)],
        &[(0b01001, &ENTRY_READVERTIZE_17135010889729486559)],
        &[(0b01001, &ENTRY_READVERTIZED_17989467612846660175)],
        &[(0b01001, &ENTRY_READVERTIZING_4761320404074285638)],
    ],
    range: 7..=9,
};

static VARS_REAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_REAC_CHILDREN),
    value: None,
};

pub static VARS_REAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("climatisation"),
        dictgen::InsensitiveStr::Ascii("climatisations"),
        dictgen::InsensitiveStr::Ascii("climatise"),
        dictgen::InsensitiveStr::Ascii("climatised"),
        dictgen::InsensitiveStr::Ascii("climatises"),
        dictgen::InsensitiveStr::Ascii("climatising"),
        dictgen::InsensitiveStr::Ascii("climatization"),
        dictgen::InsensitiveStr::Ascii("climatizations"),
        dictgen::InsensitiveStr::Ascii("climatize"),
        dictgen::InsensitiveStr::Ascii("climatized"),
        dictgen::InsensitiveStr::Ascii("climatizes"),
        dictgen::InsensitiveStr::Ascii("climatizing"),
        dictgen::InsensitiveStr::Ascii("tualise"),
        dictgen::InsensitiveStr::Ascii("tualises"),
        dictgen::InsensitiveStr::Ascii("tualize"),
        dictgen::InsensitiveStr::Ascii("tualizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_REACCLIMATIZATION_8003619318055185625)],
        &[(0b10010, &ENTRY_REACCLIMATIZATIONS_445812918952620334)],
        &[(0b10010, &ENTRY_REACCLIMATIZE_16936237501871362788)],
        &[(0b10010, &ENTRY_REACCLIMATIZED_10228493679848009990)],
        &[(0b10010, &ENTRY_REACCLIMATIZES_3770736538867723242)],
        &[(0b10010, &ENTRY_REACCLIMATIZING_13464669649206437692)],
        &[(0b01001, &ENTRY_REACCLIMATIZATION_8003619318055185625)],
        &[(0b01001, &ENTRY_REACCLIMATIZATIONS_445812918952620334)],
        &[(0b01001, &ENTRY_REACCLIMATIZE_16936237501871362788)],
        &[(0b01001, &ENTRY_REACCLIMATIZED_10228493679848009990)],
        &[(0b01001, &ENTRY_REACCLIMATIZES_3770736538867723242)],
        &[(0b01001, &ENTRY_REACCLIMATIZING_13464669649206437692)],
        &[(0b10010, &ENTRY_REACTUALIZE_15121608179320441718)],
        &[(0b10010, &ENTRY_REACTUALIZES_5611298045086045988)],
        &[(0b01001, &ENTRY_REACTUALIZE_15121608179320441718)],
        &[(0b01001, &ENTRY_REACTUALIZES_5611298045086045988)],
    ],
    range: 7..=14,
};

static VARS_RA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_RA_CHILDREN),
    value: None,
};

static VARS_RA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_RAC_NODE),
    Some(&VARS_RAD_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_RAM_NODE),
    Some(&VARS_RAN_NODE),
    None,
    Some(&VARS_RAP_NODE),
    None,
    None,
    Some(&VARS_RAS_NODE),
    Some(&VARS_RAT_NODE),
    None,
    Some(&VARS_RAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_RAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAV_CHILDREN),
    value: None,
};

pub static VARS_RAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RAVELED_13769751134216869095)],
        &[(0b00001, &ENTRY_RAVELER_5664226560864499541)],
        &[(0b00001, &ENTRY_RAVELERS_15565713204718807849)],
        &[
            (0b01001, &ENTRY_RAVELING_14313363779439759025),
            (0b00001, &ENTRY_RAVELING_17036141143171588397),
        ],
        &[(0b01001, &ENTRY_RAVELINGS_4361143677870266413)],
        &[(0b11010, &ENTRY_RAVELED_13769751134216869095)],
        &[(0b11010, &ENTRY_RAVELER_5664226560864499541)],
        &[(0b11010, &ENTRY_RAVELERS_15565713204718807849)],
        &[
            (0b11010, &ENTRY_RAVELING_14313363779439759025),
            (0b11010, &ENTRY_RAVELING_17036141143171588397),
        ],
        &[(0b11010, &ENTRY_RAVELINGS_4361143677870266413)],
    ],
    range: 4..=7,
};

static VARS_RAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAT_CHILDREN),
    value: None,
};

pub static VARS_RAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ionalisable"),
        dictgen::InsensitiveStr::Ascii("ionalisables"),
        dictgen::InsensitiveStr::Ascii("ionalisation"),
        dictgen::InsensitiveStr::Ascii("ionalisations"),
        dictgen::InsensitiveStr::Ascii("ionalise"),
        dictgen::InsensitiveStr::Ascii("ionalised"),
        dictgen::InsensitiveStr::Ascii("ionaliser"),
        dictgen::InsensitiveStr::Ascii("ionalisers"),
        dictgen::InsensitiveStr::Ascii("ionalises"),
        dictgen::InsensitiveStr::Ascii("ionalising"),
        dictgen::InsensitiveStr::Ascii("ionalizable"),
        dictgen::InsensitiveStr::Ascii("ionalizables"),
        dictgen::InsensitiveStr::Ascii("ionalization"),
        dictgen::InsensitiveStr::Ascii("ionalizations"),
        dictgen::InsensitiveStr::Ascii("ionalize"),
        dictgen::InsensitiveStr::Ascii("ionalized"),
        dictgen::InsensitiveStr::Ascii("ionalizer"),
        dictgen::InsensitiveStr::Ascii("ionalizers"),
        dictgen::InsensitiveStr::Ascii("ionalizes"),
        dictgen::InsensitiveStr::Ascii("ionalizing"),
        dictgen::InsensitiveStr::Ascii("itae"),
        dictgen::InsensitiveStr::Ascii("ite"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RATIONALIZABLE_10229605389803701324)],
        &[(0b10010, &ENTRY_RATIONALIZABLES_2843790548240367930)],
        &[(0b10010, &ENTRY_RATIONALIZATION_8601852902277773028)],
        &[(0b10010, &ENTRY_RATIONALIZATIONS_8459085318220075747)],
        &[(0b10010, &ENTRY_RATIONALIZE_17083234249921972490)],
        &[(0b10010, &ENTRY_RATIONALIZED_17223545651759435903)],
        &[(0b10010, &ENTRY_RATIONALIZER_6435122838480912496)],
        &[(0b10010, &ENTRY_RATIONALIZERS_12960131638398414888)],
        &[(0b10010, &ENTRY_RATIONALIZES_6112460011448011714)],
        &[(0b10010, &ENTRY_RATIONALIZING_2753577106103404272)],
        &[(0b01001, &ENTRY_RATIONALIZABLE_10229605389803701324)],
        &[(0b01001, &ENTRY_RATIONALIZABLES_2843790548240367930)],
        &[(0b01001, &ENTRY_RATIONALIZATION_8601852902277773028)],
        &[(0b01001, &ENTRY_RATIONALIZATIONS_8459085318220075747)],
        &[(0b01001, &ENTRY_RATIONALIZE_17083234249921972490)],
        &[(0b01001, &ENTRY_RATIONALIZED_17223545651759435903)],
        &[(0b01001, &ENTRY_RATIONALIZER_6435122838480912496)],
        &[(0b01001, &ENTRY_RATIONALIZERS_12960131638398414888)],
        &[(0b01001, &ENTRY_RATIONALIZES_6112460011448011714)],
        &[(0b01001, &ENTRY_RATIONALIZING_2753577106103404272)],
        &[(0b11010, &ENTRY_RATITE_17526384648991858474)],
        &[(0b00001, &ENTRY_RATITE_17526384648991858474)],
    ],
    range: 3..=13,
};

static VARS_RAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAS_CHILDREN),
    value: None,
};

pub static VARS_RAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RASCALIZE_69827033231107941)],
        &[(0b10010, &ENTRY_RASCALIZES_12077348347946302905)],
        &[(0b01001, &ENTRY_RASCALIZE_69827033231107941)],
        &[(0b01001, &ENTRY_RASCALIZES_12077348347946302905)],
    ],
    range: 6..=7,
};

static VARS_RAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAP_CHILDREN),
    value: None,
};

pub static VARS_RAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hae"),
        dictgen::InsensitiveStr::Ascii("he"),
        dictgen::InsensitiveStr::Ascii("hidae"),
        dictgen::InsensitiveStr::Ascii("hide"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_RAPHE_15534448576458755657)],
        &[(0b00001, &ENTRY_RAPHE_15534448576458755657)],
        &[(0b11010, &ENTRY_RAPHIDE_6262708817040760676)],
        &[(0b00001, &ENTRY_RAPHIDE_6262708817040760676)],
        &[(0b10010, &ENTRY_RAPTURIZE_14952128339321888268)],
        &[(0b10010, &ENTRY_RAPTURIZED_3183871509685674458)],
        &[(0b10010, &ENTRY_RAPTURIZES_3958786363790102011)],
        &[(0b10010, &ENTRY_RAPTURIZING_12142986500465888480)],
        &[(0b01001, &ENTRY_RAPTURIZE_14952128339321888268)],
        &[(0b01001, &ENTRY_RAPTURIZED_3183871509685674458)],
        &[(0b01001, &ENTRY_RAPTURIZES_3958786363790102011)],
        &[(0b01001, &ENTRY_RAPTURIZING_12142986500465888480)],
    ],
    range: 2..=8,
};

static VARS_RAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAN_CHILDREN),
    value: None,
};

pub static VARS_RAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cor"),
        dictgen::InsensitiveStr::Ascii("cors"),
        dictgen::InsensitiveStr::Ascii("cour"),
        dictgen::InsensitiveStr::Ascii("cours"),
        dictgen::InsensitiveStr::Ascii("domisation"),
        dictgen::InsensitiveStr::Ascii("domisations"),
        dictgen::InsensitiveStr::Ascii("domise"),
        dictgen::InsensitiveStr::Ascii("domised"),
        dictgen::InsensitiveStr::Ascii("domiser"),
        dictgen::InsensitiveStr::Ascii("domisers"),
        dictgen::InsensitiveStr::Ascii("domises"),
        dictgen::InsensitiveStr::Ascii("domising"),
        dictgen::InsensitiveStr::Ascii("domization"),
        dictgen::InsensitiveStr::Ascii("domizations"),
        dictgen::InsensitiveStr::Ascii("domize"),
        dictgen::InsensitiveStr::Ascii("domized"),
        dictgen::InsensitiveStr::Ascii("domizer"),
        dictgen::InsensitiveStr::Ascii("domizers"),
        dictgen::InsensitiveStr::Ascii("domizes"),
        dictgen::InsensitiveStr::Ascii("domizing"),
    ],
    values: &[
        &[(0b11001, &ENTRY_RANCOR_3021538336566889427)],
        &[(0b11001, &ENTRY_RANCORS_6479511528152236851)],
        &[(0b11010, &ENTRY_RANCOR_3021538336566889427)],
        &[(0b11010, &ENTRY_RANCORS_6479511528152236851)],
        &[(0b10010, &ENTRY_RANDOMIZATION_1289611966234918219)],
        &[(0b10010, &ENTRY_RANDOMIZATIONS_17892832491968037972)],
        &[(0b10010, &ENTRY_RANDOMIZE_13711817980083119800)],
        &[(0b10010, &ENTRY_RANDOMIZED_14523974732692007480)],
        &[(0b10010, &ENTRY_RANDOMIZER_17355019921057008602)],
        &[(0b10010, &ENTRY_RANDOMIZERS_15224984926574272799)],
        &[(0b10010, &ENTRY_RANDOMIZES_13716959639798364190)],
        &[(0b10010, &ENTRY_RANDOMIZING_1606855122710420786)],
        &[(0b01001, &ENTRY_RANDOMIZATION_1289611966234918219)],
        &[(0b01001, &ENTRY_RANDOMIZATIONS_17892832491968037972)],
        &[(0b01001, &ENTRY_RANDOMIZE_13711817980083119800)],
        &[(0b01001, &ENTRY_RANDOMIZED_14523974732692007480)],
        &[(0b01001, &ENTRY_RANDOMIZER_17355019921057008602)],
        &[(0b01001, &ENTRY_RANDOMIZERS_15224984926574272799)],
        &[(0b01001, &ENTRY_RANDOMIZES_13716959639798364190)],
        &[(0b01001, &ENTRY_RANDOMIZING_1606855122710420786)],
    ],
    range: 3..=11,
};

static VARS_RAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAM_CHILDREN),
    value: None,
};

pub static VARS_RAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("pier"),
        dictgen::InsensitiveStr::Ascii("pire"),
    ],
    values: &[
        &[(0b11010, &ENTRY_RAME_6231188682149452305)],
        &[(0b00001, &ENTRY_RAME_6231188682149452305)],
        &[(0b00001, &ENTRY_RAMPIER_15736266043397566231)],
        &[(0b11010, &ENTRY_RAMPIER_15736266043397566231)],
    ],
    range: 1..=4,
};

static VARS_RAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAD_CHILDREN),
    value: None,
};

pub static VARS_RAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("borne"),
        dictgen::InsensitiveStr::Ascii("bourne"),
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
        dictgen::InsensitiveStr::Ascii("icalisation"),
        dictgen::InsensitiveStr::Ascii("icalisations"),
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalised"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalising"),
        dictgen::InsensitiveStr::Ascii("icalization"),
        dictgen::InsensitiveStr::Ascii("icalizations"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalized"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
        dictgen::InsensitiveStr::Ascii("icalizing"),
        dictgen::InsensitiveStr::Ascii("iopasteurisation"),
        dictgen::InsensitiveStr::Ascii("iopasteurization"),
        dictgen::InsensitiveStr::Ascii("iosensitise"),
        dictgen::InsensitiveStr::Ascii("iosensitised"),
        dictgen::InsensitiveStr::Ascii("iosensitises"),
        dictgen::InsensitiveStr::Ascii("iosensitising"),
        dictgen::InsensitiveStr::Ascii("iosensitize"),
        dictgen::InsensitiveStr::Ascii("iosensitized"),
        dictgen::InsensitiveStr::Ascii("iosensitizes"),
        dictgen::InsensitiveStr::Ascii("iosensitizing"),
        dictgen::InsensitiveStr::Ascii("iosterilisation"),
        dictgen::InsensitiveStr::Ascii("iosterilise"),
        dictgen::InsensitiveStr::Ascii("iosterilised"),
        dictgen::InsensitiveStr::Ascii("iosterilises"),
        dictgen::InsensitiveStr::Ascii("iosterilising"),
        dictgen::InsensitiveStr::Ascii("iosterilization"),
        dictgen::InsensitiveStr::Ascii("iosterilize"),
        dictgen::InsensitiveStr::Ascii("iosterilized"),
        dictgen::InsensitiveStr::Ascii("iosterilizes"),
        dictgen::InsensitiveStr::Ascii("iosterilizing"),
        dictgen::InsensitiveStr::Ascii("iumisation"),
        dictgen::InsensitiveStr::Ascii("iumisations"),
        dictgen::InsensitiveStr::Ascii("iumise"),
        dictgen::InsensitiveStr::Ascii("iumises"),
        dictgen::InsensitiveStr::Ascii("iumization"),
        dictgen::InsensitiveStr::Ascii("iumizations"),
        dictgen::InsensitiveStr::Ascii("iumize"),
        dictgen::InsensitiveStr::Ascii("iumizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_RADBORNE_10850064437245752174)],
        &[(0b11010, &ENTRY_RADBORNE_10850064437245752174)],
        &[(0b10010, &ENTRY_RADIALIZATION_15909242338822109844)],
        &[(0b10010, &ENTRY_RADIALIZATIONS_15793970150795442621)],
        &[(0b10010, &ENTRY_RADIALIZE_4331722839835606750)],
        &[(0b10010, &ENTRY_RADIALIZED_4912265723493507733)],
        &[(0b10010, &ENTRY_RADIALIZES_8096719627410360859)],
        &[(0b10010, &ENTRY_RADIALIZING_3370202487268261936)],
        &[(0b01001, &ENTRY_RADIALIZATION_15909242338822109844)],
        &[(0b01001, &ENTRY_RADIALIZATIONS_15793970150795442621)],
        &[(0b01001, &ENTRY_RADIALIZE_4331722839835606750)],
        &[(0b01001, &ENTRY_RADIALIZED_4912265723493507733)],
        &[(0b01001, &ENTRY_RADIALIZES_8096719627410360859)],
        &[(0b01001, &ENTRY_RADIALIZING_3370202487268261936)],
        &[(0b10010, &ENTRY_RADICALIZATION_4526956637788815699)],
        &[(0b10010, &ENTRY_RADICALIZATIONS_9773145707790145185)],
        &[(0b10010, &ENTRY_RADICALIZE_657046847784299688)],
        &[(0b10010, &ENTRY_RADICALIZED_970968663725575990)],
        &[(0b10010, &ENTRY_RADICALIZES_6199505773390853831)],
        &[(0b10010, &ENTRY_RADICALIZING_13409080083804221460)],
        &[(0b01001, &ENTRY_RADICALIZATION_4526956637788815699)],
        &[(0b01001, &ENTRY_RADICALIZATIONS_9773145707790145185)],
        &[(0b01001, &ENTRY_RADICALIZE_657046847784299688)],
        &[(0b01001, &ENTRY_RADICALIZED_970968663725575990)],
        &[(0b01001, &ENTRY_RADICALIZES_6199505773390853831)],
        &[(0b01001, &ENTRY_RADICALIZING_13409080083804221460)],
        &[(0b10010, &ENTRY_RADIOPASTEURIZATION_10077706312711948195)],
        &[(0b01001, &ENTRY_RADIOPASTEURIZATION_10077706312711948195)],
        &[(0b10010, &ENTRY_RADIOSENSITIZE_493147068573479374)],
        &[(0b10010, &ENTRY_RADIOSENSITIZED_10310974351051252440)],
        &[(0b10010, &ENTRY_RADIOSENSITIZES_4744175567736666306)],
        &[(0b10010, &ENTRY_RADIOSENSITIZING_15687044239286203316)],
        &[(0b01001, &ENTRY_RADIOSENSITIZE_493147068573479374)],
        &[(0b01001, &ENTRY_RADIOSENSITIZED_10310974351051252440)],
        &[(0b01001, &ENTRY_RADIOSENSITIZES_4744175567736666306)],
        &[(0b01001, &ENTRY_RADIOSENSITIZING_15687044239286203316)],
        &[(0b10010, &ENTRY_RADIOSTERILIZATION_14328698460471594598)],
        &[(0b10010, &ENTRY_RADIOSTERILIZE_12451407989140658611)],
        &[(0b10010, &ENTRY_RADIOSTERILIZED_16138782642102283578)],
        &[(0b10010, &ENTRY_RADIOSTERILIZES_17227682815929026577)],
        &[(0b10010, &ENTRY_RADIOSTERILIZING_12025330816893790142)],
        &[(0b01001, &ENTRY_RADIOSTERILIZATION_14328698460471594598)],
        &[(0b01001, &ENTRY_RADIOSTERILIZE_12451407989140658611)],
        &[(0b01001, &ENTRY_RADIOSTERILIZED_16138782642102283578)],
        &[(0b01001, &ENTRY_RADIOSTERILIZES_17227682815929026577)],
        &[(0b01001, &ENTRY_RADIOSTERILIZING_12025330816893790142)],
        &[(0b10010, &ENTRY_RADIUMIZATION_619606104192746118)],
        &[(0b10010, &ENTRY_RADIUMIZATIONS_843643436347756512)],
        &[(0b10010, &ENTRY_RADIUMIZE_2819850161118182574)],
        &[(0b10010, &ENTRY_RADIUMIZES_769494073563782637)],
        &[(0b01001, &ENTRY_RADIUMIZATION_619606104192746118)],
        &[(0b01001, &ENTRY_RADIUMIZATIONS_843643436347756512)],
        &[(0b01001, &ENTRY_RADIUMIZE_2819850161118182574)],
        &[(0b01001, &ENTRY_RADIUMIZES_769494073563782637)],
    ],
    range: 5..=16,
};

static VARS_RAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_RAC_CHILDREN),
    value: None,
};

pub static VARS_RAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emisation"),
        dictgen::InsensitiveStr::Ascii("emisations"),
        dictgen::InsensitiveStr::Ascii("emise"),
        dictgen::InsensitiveStr::Ascii("emised"),
        dictgen::InsensitiveStr::Ascii("emises"),
        dictgen::InsensitiveStr::Ascii("emising"),
        dictgen::InsensitiveStr::Ascii("emization"),
        dictgen::InsensitiveStr::Ascii("emizations"),
        dictgen::InsensitiveStr::Ascii("emize"),
        dictgen::InsensitiveStr::Ascii("emized"),
        dictgen::InsensitiveStr::Ascii("emizes"),
        dictgen::InsensitiveStr::Ascii("emizing"),
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_RACEMIZATION_14866059904893991517)],
        &[(0b10010, &ENTRY_RACEMIZATIONS_14925364252241043462)],
        &[(0b10010, &ENTRY_RACEMIZE_16676538356806008445)],
        &[(0b10010, &ENTRY_RACEMIZED_15166940075916248285)],
        &[(0b10010, &ENTRY_RACEMIZES_12324385455966583212)],
        &[(0b10010, &ENTRY_RACEMIZING_10678064324413578265)],
        &[(0b01001, &ENTRY_RACEMIZATION_14866059904893991517)],
        &[(0b01001, &ENTRY_RACEMIZATIONS_14925364252241043462)],
        &[(0b01001, &ENTRY_RACEMIZE_16676538356806008445)],
        &[(0b01001, &ENTRY_RACEMIZED_15166940075916248285)],
        &[(0b01001, &ENTRY_RACEMIZES_12324385455966583212)],
        &[(0b01001, &ENTRY_RACEMIZING_10678064324413578265)],
        &[(0b10010, &ENTRY_RACIALIZATION_3759743204420570975)],
        &[(0b10010, &ENTRY_RACIALIZATIONS_6346019920628038343)],
        &[(0b10010, &ENTRY_RACIALIZE_5925611520403941440)],
        &[(0b10010, &ENTRY_RACIALIZES_4973469964628099453)],
        &[(0b01001, &ENTRY_RACIALIZATION_3759743204420570975)],
        &[(0b01001, &ENTRY_RACIALIZATIONS_6346019920628038343)],
        &[(0b01001, &ENTRY_RACIALIZE_5925611520403941440)],
        &[(0b01001, &ENTRY_RACIALIZES_4973469964628099453)],
    ],
    range: 5..=11,
};

static VARS_Q_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_Q_CHILDREN),
    value: None,
};

static VARS_Q_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_QU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_QU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_QU_CHILDREN),
    value: None,
};

static VARS_QU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_QUA_NODE),
    None,
    None,
    None,
    Some(&VARS_QUE_NODE),
    None,
    None,
    None,
    Some(&VARS_QUI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_QUI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_QUI_CHILDREN),
    value: None,
};

pub static VARS_QUI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ninise"),
        dictgen::InsensitiveStr::Ascii("ninises"),
        dictgen::InsensitiveStr::Ascii("ninize"),
        dictgen::InsensitiveStr::Ascii("ninizes"),
        dictgen::InsensitiveStr::Ascii("ntessentialise"),
        dictgen::InsensitiveStr::Ascii("ntessentialised"),
        dictgen::InsensitiveStr::Ascii("ntessentialises"),
        dictgen::InsensitiveStr::Ascii("ntessentialising"),
        dictgen::InsensitiveStr::Ascii("ntessentialize"),
        dictgen::InsensitiveStr::Ascii("ntessentialized"),
        dictgen::InsensitiveStr::Ascii("ntessentializes"),
        dictgen::InsensitiveStr::Ascii("ntessentializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_QUININIZE_2087156858031016226)],
        &[(0b10010, &ENTRY_QUININIZES_10108031189738596948)],
        &[(0b01001, &ENTRY_QUININIZE_2087156858031016226)],
        &[(0b01001, &ENTRY_QUININIZES_10108031189738596948)],
        &[(0b10010, &ENTRY_QUINTESSENTIALIZE_1798676908258309491)],
        &[(0b10010, &ENTRY_QUINTESSENTIALIZED_10608544255035328498)],
        &[(0b10010, &ENTRY_QUINTESSENTIALIZES_5864610073124488816)],
        &[(0b10010, &ENTRY_QUINTESSENTIALIZING_13955826412375505803)],
        &[(0b01001, &ENTRY_QUINTESSENTIALIZE_1798676908258309491)],
        &[(0b01001, &ENTRY_QUINTESSENTIALIZED_10608544255035328498)],
        &[(0b01001, &ENTRY_QUINTESSENTIALIZES_5864610073124488816)],
        &[(0b01001, &ENTRY_QUINTESSENTIALIZING_13955826412375505803)],
    ],
    range: 6..=16,
};

static VARS_QUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_QUE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_QUE_13586725649236549292)]),
};

pub static VARS_QUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("relae"),
        dictgen::InsensitiveStr::Ascii("rele"),
        dictgen::InsensitiveStr::Ascii("stionaries"),
        dictgen::InsensitiveStr::Ascii("stionary"),
        dictgen::InsensitiveStr::Ascii("stor"),
        dictgen::InsensitiveStr::Ascii("storial"),
        dictgen::InsensitiveStr::Ascii("stors"),
        dictgen::InsensitiveStr::Ascii("storship"),
        dictgen::InsensitiveStr::Ascii("ueing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_QUERELE_11808184504409924035)],
        &[(0b00001, &ENTRY_QUERELE_11808184504409924035)],
        &[(0b00001, &ENTRY_QUESTIONARIES_10402520069112102625)],
        &[(0b00001, &ENTRY_QUESTIONARY_355066268016349878)],
        &[(0b00001, &ENTRY_QUAESTOR_17594907692681861950)],
        &[(0b00001, &ENTRY_QUESTORIAL_3922144180001555115)],
        &[(0b00001, &ENTRY_QUAESTORS_8483323232262543948)],
        &[(0b00001, &ENTRY_QUESTORSHIP_6181167330242868713)],
        &[(0b11010, &ENTRY_QUEUING_16824913408770003331)],
    ],
    range: 4..=10,
};

static VARS_QUA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_QUA_CHILDREN),
    value: None,
};

pub static VARS_QUA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("estionaries"),
        dictgen::InsensitiveStr::Ascii("estionary"),
        dictgen::InsensitiveStr::Ascii("estorial"),
        dictgen::InsensitiveStr::Ascii("estorship"),
        dictgen::InsensitiveStr::Ascii("kerisation"),
        dictgen::InsensitiveStr::Ascii("kerisations"),
        dictgen::InsensitiveStr::Ascii("kerise"),
        dictgen::InsensitiveStr::Ascii("kerises"),
        dictgen::InsensitiveStr::Ascii("kerization"),
        dictgen::InsensitiveStr::Ascii("kerizations"),
        dictgen::InsensitiveStr::Ascii("kerize"),
        dictgen::InsensitiveStr::Ascii("kerizes"),
        dictgen::InsensitiveStr::Ascii("ntisation"),
        dictgen::InsensitiveStr::Ascii("ntisations"),
        dictgen::InsensitiveStr::Ascii("ntise"),
        dictgen::InsensitiveStr::Ascii("ntised"),
        dictgen::InsensitiveStr::Ascii("ntiser"),
        dictgen::InsensitiveStr::Ascii("ntisers"),
        dictgen::InsensitiveStr::Ascii("ntises"),
        dictgen::InsensitiveStr::Ascii("ntising"),
        dictgen::InsensitiveStr::Ascii("ntization"),
        dictgen::InsensitiveStr::Ascii("ntizations"),
        dictgen::InsensitiveStr::Ascii("ntize"),
        dictgen::InsensitiveStr::Ascii("ntized"),
        dictgen::InsensitiveStr::Ascii("ntizer"),
        dictgen::InsensitiveStr::Ascii("ntizers"),
        dictgen::InsensitiveStr::Ascii("ntizes"),
        dictgen::InsensitiveStr::Ascii("ntizing"),
        dictgen::InsensitiveStr::Ascii("rreled"),
        dictgen::InsensitiveStr::Ascii("rreler"),
        dictgen::InsensitiveStr::Ascii("rrelers"),
        dictgen::InsensitiveStr::Ascii("rreling"),
        dictgen::InsensitiveStr::Ascii("rrelled"),
        dictgen::InsensitiveStr::Ascii("rreller"),
        dictgen::InsensitiveStr::Ascii("rrellers"),
        dictgen::InsensitiveStr::Ascii("rrelling"),
        dictgen::InsensitiveStr::Ascii("rrellous"),
        dictgen::InsensitiveStr::Ascii("rrelous"),
        dictgen::InsensitiveStr::Ascii("rterisation"),
        dictgen::InsensitiveStr::Ascii("rterisations"),
        dictgen::InsensitiveStr::Ascii("rterization"),
        dictgen::InsensitiveStr::Ascii("rterizations"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_QUE_13586725649236549292)],
        &[(0b11010, &ENTRY_QUESTIONARIES_10402520069112102625)],
        &[(0b11010, &ENTRY_QUESTIONARY_355066268016349878)],
        &[(0b11010, &ENTRY_QUESTORIAL_3922144180001555115)],
        &[(0b11010, &ENTRY_QUESTORSHIP_6181167330242868713)],
        &[(0b10010, &ENTRY_QUAKERIZATION_15271082910314921958)],
        &[(0b10010, &ENTRY_QUAKERIZATIONS_9091064691709489634)],
        &[(0b10010, &ENTRY_QUAKERIZE_11128424253154253323)],
        &[(0b10010, &ENTRY_QUAKERIZES_6225644625493387619)],
        &[(0b01001, &ENTRY_QUAKERIZATION_15271082910314921958)],
        &[(0b01001, &ENTRY_QUAKERIZATIONS_9091064691709489634)],
        &[(0b01001, &ENTRY_QUAKERIZE_11128424253154253323)],
        &[(0b01001, &ENTRY_QUAKERIZES_6225644625493387619)],
        &[(0b10010, &ENTRY_QUANTIZATION_17530637216436047165)],
        &[(0b10010, &ENTRY_QUANTIZATIONS_18436605585180790614)],
        &[(0b10010, &ENTRY_QUANTIZE_11931499095330665012)],
        &[(0b10010, &ENTRY_QUANTIZED_2680364749022486524)],
        &[(0b10010, &ENTRY_QUANTIZER_3494983548212992900)],
        &[(0b10010, &ENTRY_QUANTIZERS_7834757600518271281)],
        &[(0b10010, &ENTRY_QUANTIZES_4468236107907530850)],
        &[(0b10010, &ENTRY_QUANTIZING_17051402668649809855)],
        &[(0b01001, &ENTRY_QUANTIZATION_17530637216436047165)],
        &[(0b01001, &ENTRY_QUANTIZATIONS_18436605585180790614)],
        &[(0b01001, &ENTRY_QUANTIZE_11931499095330665012)],
        &[(0b01001, &ENTRY_QUANTIZED_2680364749022486524)],
        &[(0b01001, &ENTRY_QUANTIZER_3494983548212992900)],
        &[(0b01001, &ENTRY_QUANTIZERS_7834757600518271281)],
        &[(0b01001, &ENTRY_QUANTIZES_4468236107907530850)],
        &[(0b01001, &ENTRY_QUANTIZING_17051402668649809855)],
        &[(0b00001, &ENTRY_QUARRELED_5653253897786374680)],
        &[(0b00001, &ENTRY_QUARRELER_4085235523024441706)],
        &[(0b00001, &ENTRY_QUARRELERS_358900163381073241)],
        &[(0b00001, &ENTRY_QUARRELING_10764751794518869060)],
        &[(0b11010, &ENTRY_QUARRELED_5653253897786374680)],
        &[(0b11010, &ENTRY_QUARRELER_4085235523024441706)],
        &[(0b11010, &ENTRY_QUARRELERS_358900163381073241)],
        &[(0b11010, &ENTRY_QUARRELING_10764751794518869060)],
        &[(0b11010, &ENTRY_QUARRELOUS_11262396164858801968)],
        &[(0b00001, &ENTRY_QUARRELOUS_11262396164858801968)],
        &[(0b10010, &ENTRY_QUARTERIZATION_15534356304257305635)],
        &[(0b10010, &ENTRY_QUARTERIZATIONS_5989124183283298739)],
        &[(0b01001, &ENTRY_QUARTERIZATION_15534356304257305635)],
        &[(0b01001, &ENTRY_QUARTERIZATIONS_5989124183283298739)],
        &[(0b00001, &ENTRY_QUATERS_9944017358673782792)],
        &[(0b11010, &ENTRY_QUATERS_9944017358673782792)],
    ],
    range: 1..=12,
};

static VARS_P_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_P_CHILDREN),
    value: None,
};

static VARS_P_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PA_NODE),
    None,
    None,
    None,
    Some(&VARS_PE_NODE),
    None,
    None,
    Some(&VARS_PH_NODE),
    Some(&VARS_PI_NODE),
    None,
    None,
    Some(&VARS_PL_NODE),
    None,
    None,
    Some(&VARS_PO_NODE),
    None,
    None,
    Some(&VARS_PR_NODE),
    Some(&VARS_PS_NODE),
    Some(&VARS_PT_NODE),
    Some(&VARS_PU_NODE),
    None,
    None,
    None,
    Some(&VARS_PY_NODE),
    None,
];

static VARS_PY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PY_CHILDREN),
    value: None,
};

static VARS_PY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PYA_NODE),
    None,
    None,
    None,
    Some(&VARS_PYE_NODE),
    None,
    Some(&VARS_PYG_NODE),
    None,
    None,
    Some(&VARS_PYJ_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PYO_NODE),
    None,
    None,
    Some(&VARS_PYR_NODE),
    None,
    Some(&VARS_PYT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PYT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYT_CHILDREN),
    value: None,
};

pub static VARS_PYT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hagoreanise"),
        dictgen::InsensitiveStr::Ascii("hagoreanises"),
        dictgen::InsensitiveStr::Ascii("hagoreanize"),
        dictgen::InsensitiveStr::Ascii("hagoreanizes"),
        dictgen::InsensitiveStr::Ascii("honinae"),
        dictgen::InsensitiveStr::Ascii("honine"),
        dictgen::InsensitiveStr::Ascii("honise"),
        dictgen::InsensitiveStr::Ascii("honises"),
        dictgen::InsensitiveStr::Ascii("honize"),
        dictgen::InsensitiveStr::Ascii("honizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PYTHAGOREANIZE_8350121642033180635)],
        &[(0b10010, &ENTRY_PYTHAGOREANIZES_7402158601998337606)],
        &[(0b01001, &ENTRY_PYTHAGOREANIZE_8350121642033180635)],
        &[(0b01001, &ENTRY_PYTHAGOREANIZES_7402158601998337606)],
        &[(0b11010, &ENTRY_PYTHONINE_8378069869888673614)],
        &[(0b00001, &ENTRY_PYTHONINE_8378069869888673614)],
        &[(0b10010, &ENTRY_PYTHONIZE_5308256505462488849)],
        &[(0b10010, &ENTRY_PYTHONIZES_14271598598290338942)],
        &[(0b01001, &ENTRY_PYTHONIZE_5308256505462488849)],
        &[(0b01001, &ENTRY_PYTHONIZES_14271598598290338942)],
    ],
    range: 6..=12,
};

static VARS_PYR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYR_CHILDREN),
    value: None,
};

pub static VARS_PYR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amidise"),
        dictgen::InsensitiveStr::Ascii("amidises"),
        dictgen::InsensitiveStr::Ascii("amidize"),
        dictgen::InsensitiveStr::Ascii("amidizes"),
        dictgen::InsensitiveStr::Ascii("enaean"),
        dictgen::InsensitiveStr::Ascii("enaeus"),
        dictgen::InsensitiveStr::Ascii("enean"),
        dictgen::InsensitiveStr::Ascii("eneus"),
        dictgen::InsensitiveStr::Ascii("idinise"),
        dictgen::InsensitiveStr::Ascii("idinises"),
        dictgen::InsensitiveStr::Ascii("idinize"),
        dictgen::InsensitiveStr::Ascii("idinizes"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("olysable"),
        dictgen::InsensitiveStr::Ascii("olysate"),
        dictgen::InsensitiveStr::Ascii("olysates"),
        dictgen::InsensitiveStr::Ascii("olyse"),
        dictgen::InsensitiveStr::Ascii("olysed"),
        dictgen::InsensitiveStr::Ascii("olyser"),
        dictgen::InsensitiveStr::Ascii("olyses"),
        dictgen::InsensitiveStr::Ascii("olysing"),
        dictgen::InsensitiveStr::Ascii("olyzable"),
        dictgen::InsensitiveStr::Ascii("olyzate"),
        dictgen::InsensitiveStr::Ascii("olyzates"),
        dictgen::InsensitiveStr::Ascii("olyze"),
        dictgen::InsensitiveStr::Ascii("olyzed"),
        dictgen::InsensitiveStr::Ascii("olyzer"),
        dictgen::InsensitiveStr::Ascii("olyzes"),
        dictgen::InsensitiveStr::Ascii("olyzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PYRAMIDIZE_10588274532217907765)],
        &[(0b10010, &ENTRY_PYRAMIDIZES_12212385747150866566)],
        &[(0b01001, &ENTRY_PYRAMIDIZE_10588274532217907765)],
        &[(0b01001, &ENTRY_PYRAMIDIZES_12212385747150866566)],
        &[(0b11010, &ENTRY_PYRENEAN_2152548018236454357)],
        &[(0b11010, &ENTRY_PYRENEUS_10190704627498876210)],
        &[(0b00001, &ENTRY_PYRENEAN_2152548018236454357)],
        &[(0b00001, &ENTRY_PYRENEUS_10190704627498876210)],
        &[(0b10010, &ENTRY_PYRIDINIZE_3186988452300111430)],
        &[(0b10010, &ENTRY_PYRIDINIZES_3075368646720279500)],
        &[(0b01001, &ENTRY_PYRIDINIZE_3186988452300111430)],
        &[(0b01001, &ENTRY_PYRIDINIZES_3075368646720279500)],
        &[(0b10010, &ENTRY_PYRITIZATION_6948326992466383447)],
        &[(0b10010, &ENTRY_PYRITIZATIONS_190433604980286404)],
        &[(0b10010, &ENTRY_PYRITIZE_14505383613972185021)],
        &[(0b10010, &ENTRY_PYRITIZED_10674668536971383379)],
        &[(0b10010, &ENTRY_PYRITIZES_14093831203611662019)],
        &[(0b10010, &ENTRY_PYRITIZING_12622208379397963806)],
        &[(0b01001, &ENTRY_PYRITIZATION_6948326992466383447)],
        &[(0b01001, &ENTRY_PYRITIZATIONS_190433604980286404)],
        &[(0b01001, &ENTRY_PYRITIZE_14505383613972185021)],
        &[(0b01001, &ENTRY_PYRITIZED_10674668536971383379)],
        &[(0b01001, &ENTRY_PYRITIZES_14093831203611662019)],
        &[(0b01001, &ENTRY_PYRITIZING_12622208379397963806)],
        &[(0b11010, &ENTRY_PYROLYZABLE_16182293090477516327)],
        &[(0b11010, &ENTRY_PYROLYZATE_13930186823001114533)],
        &[(0b11010, &ENTRY_PYROLYZATES_6791890316899917756)],
        &[(0b11010, &ENTRY_PYROLYZE_13780640574314797884)],
        &[(0b11010, &ENTRY_PYROLYZED_6450196473837000816)],
        &[(0b11010, &ENTRY_PYROLYZER_11614680328839062524)],
        &[(0b11010, &ENTRY_PYROLYZES_2811540809177764183)],
        &[(0b11010, &ENTRY_PYROLYZING_11483665575108061827)],
        &[(0b00001, &ENTRY_PYROLYZABLE_16182293090477516327)],
        &[(0b00001, &ENTRY_PYROLYZATE_13930186823001114533)],
        &[(0b00001, &ENTRY_PYROLYZATES_6791890316899917756)],
        &[(0b01001, &ENTRY_PYROLYZE_13780640574314797884)],
        &[(0b01001, &ENTRY_PYROLYZED_6450196473837000816)],
        &[(0b00001, &ENTRY_PYROLYZER_11614680328839062524)],
        &[(0b01001, &ENTRY_PYROLYZES_2811540809177764183)],
        &[(0b01001, &ENTRY_PYROLYZING_11483665575108061827)],
    ],
    range: 5..=10,
};

static VARS_PYO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYO_CHILDREN),
    value: None,
};

pub static VARS_PYO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rrhea"),
        dictgen::InsensitiveStr::Ascii("rrheal"),
        dictgen::InsensitiveStr::Ascii("rrhealer"),
        dictgen::InsensitiveStr::Ascii("rrhealest"),
        dictgen::InsensitiveStr::Ascii("rrheas"),
        dictgen::InsensitiveStr::Ascii("rrheic"),
        dictgen::InsensitiveStr::Ascii("rrhoea"),
        dictgen::InsensitiveStr::Ascii("rrhoeal"),
        dictgen::InsensitiveStr::Ascii("rrhoealer"),
        dictgen::InsensitiveStr::Ascii("rrhoealest"),
        dictgen::InsensitiveStr::Ascii("rrhoeas"),
        dictgen::InsensitiveStr::Ascii("rrhoeic"),
    ],
    values: &[
        &[(0b01001, &ENTRY_PYORRHEA_11452852603058973873)],
        &[(0b00001, &ENTRY_PYORRHEAL_12472249177810835579)],
        &[(0b00001, &ENTRY_PYORRHEALER_15895959795219668705)],
        &[(0b00001, &ENTRY_PYORRHEALEST_1028023297156077918)],
        &[(0b01001, &ENTRY_PYORRHEAS_9316984276613632473)],
        &[(0b00001, &ENTRY_PYORRHEIC_3299650509022396406)],
        &[(0b10010, &ENTRY_PYORRHEA_11452852603058973873)],
        &[(0b11010, &ENTRY_PYORRHEAL_12472249177810835579)],
        &[(0b11010, &ENTRY_PYORRHEALER_15895959795219668705)],
        &[(0b11010, &ENTRY_PYORRHEALEST_1028023297156077918)],
        &[(0b10010, &ENTRY_PYORRHEAS_9316984276613632473)],
        &[(0b11010, &ENTRY_PYORRHEIC_3299650509022396406)],
    ],
    range: 5..=10,
};

static VARS_PYJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYJ_CHILDREN),
    value: None,
};

pub static VARS_PYJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ama"),
        dictgen::InsensitiveStr::Ascii("amas"),
        dictgen::InsensitiveStr::Ascii("amased"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PAJAMA_6036010499883376406)],
        &[(0b11010, &ENTRY_PAJAMAS_2981078080473633806)],
        &[(0b11010, &ENTRY_PAJAMAED_5631330919975772121)],
    ],
    range: 3..=6,
};

static VARS_PYG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYG_CHILDREN),
    value: None,
};

pub static VARS_PYG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maean"),
        dictgen::InsensitiveStr::Ascii("mean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PYGMEAN_12059756127958428908)],
        &[(0b00001, &ENTRY_PYGMEAN_12059756127958428908)],
    ],
    range: 4..=5,
};

static VARS_PYE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYE_CHILDREN),
    value: None,
};

pub static VARS_PYE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mia"),
        dictgen::InsensitiveStr::Ascii("mias"),
        dictgen::InsensitiveStr::Ascii("mic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PYEMIA_7988102216395544750)],
        &[(0b00001, &ENTRY_PYEMIAS_9051871355215634753)],
        &[(0b00001, &ENTRY_PYEMIC_11860923235877484798)],
    ],
    range: 3..=4,
};

static VARS_PYA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PYA_CHILDREN),
    value: None,
};

pub static VARS_PYA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PYEMIA_7988102216395544750)],
        &[(0b11010, &ENTRY_PYEMIAS_9051871355215634753)],
        &[(0b11010, &ENTRY_PYEMIC_11860923235877484798)],
    ],
    range: 4..=5,
};

static VARS_PU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PU_CHILDREN),
    value: None,
};

static VARS_PU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_PUB_NODE),
    None,
    None,
    Some(&VARS_PUE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PUL_NODE),
    Some(&VARS_PUM_NODE),
    None,
    None,
    Some(&VARS_PUP_NODE),
    None,
    Some(&VARS_PUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUR_CHILDREN),
    value: None,
};

pub static VARS_PUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("itanise"),
        dictgen::InsensitiveStr::Ascii("itanised"),
        dictgen::InsensitiveStr::Ascii("itaniser"),
        dictgen::InsensitiveStr::Ascii("itanisers"),
        dictgen::InsensitiveStr::Ascii("itanises"),
        dictgen::InsensitiveStr::Ascii("itanising"),
        dictgen::InsensitiveStr::Ascii("itanize"),
        dictgen::InsensitiveStr::Ascii("itanized"),
        dictgen::InsensitiveStr::Ascii("itanizer"),
        dictgen::InsensitiveStr::Ascii("itanizers"),
        dictgen::InsensitiveStr::Ascii("itanizes"),
        dictgen::InsensitiveStr::Ascii("itanizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PUERS_17142262766965004130)],
        &[(0b10010, &ENTRY_PURITANIZE_8338922501694901333)],
        &[(0b10010, &ENTRY_PURITANIZED_6789297151619861986)],
        &[(0b10010, &ENTRY_PURITANIZER_5571229184904133146)],
        &[(0b10010, &ENTRY_PURITANIZERS_1778141389685069367)],
        &[(0b10010, &ENTRY_PURITANIZES_4562255768937344613)],
        &[(0b10010, &ENTRY_PURITANIZING_2268731325006525499)],
        &[(0b01001, &ENTRY_PURITANIZE_8338922501694901333)],
        &[(0b01001, &ENTRY_PURITANIZED_6789297151619861986)],
        &[(0b01001, &ENTRY_PURITANIZER_5571229184904133146)],
        &[(0b01001, &ENTRY_PURITANIZERS_1778141389685069367)],
        &[(0b01001, &ENTRY_PURITANIZES_4562255768937344613)],
        &[(0b01001, &ENTRY_PURITANIZING_2268731325006525499)],
    ],
    range: 2..=9,
};

static VARS_PUP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUP_CHILDREN),
    value: None,
};

pub static VARS_PUP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("petise"),
        dictgen::InsensitiveStr::Ascii("petises"),
        dictgen::InsensitiveStr::Ascii("petize"),
        dictgen::InsensitiveStr::Ascii("petizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PUPILIZE_5377680490535459429)],
        &[(0b10010, &ENTRY_PUPILIZES_1894766054254996796)],
        &[(0b01001, &ENTRY_PUPILIZE_5377680490535459429)],
        &[(0b01001, &ENTRY_PUPILIZES_1894766054254996796)],
        &[(0b10010, &ENTRY_PUPPETIZE_77358709430575945)],
        &[(0b10010, &ENTRY_PUPPETIZES_4248804414422953519)],
        &[(0b01001, &ENTRY_PUPPETIZE_77358709430575945)],
        &[(0b01001, &ENTRY_PUPPETIZES_4248804414422953519)],
    ],
    range: 5..=7,
};

static VARS_PUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUM_CHILDREN),
    value: None,
};

pub static VARS_PUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("meled"),
        dictgen::InsensitiveStr::Ascii("meler"),
        dictgen::InsensitiveStr::Ascii("meling"),
        dictgen::InsensitiveStr::Ascii("melled"),
        dictgen::InsensitiveStr::Ascii("meller"),
        dictgen::InsensitiveStr::Ascii("melling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PUMMELED_18323564550000511359)],
        &[(0b00001, &ENTRY_PUMMELER_15868425804772851271)],
        &[(0b00001, &ENTRY_PUMMELING_11168437237560180925)],
        &[(0b11010, &ENTRY_PUMMELED_18323564550000511359)],
        &[(0b11010, &ENTRY_PUMMELER_15868425804772851271)],
        &[(0b11010, &ENTRY_PUMMELING_11168437237560180925)],
    ],
    range: 5..=7,
};

static VARS_PUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUL_CHILDREN),
    value: None,
};

pub static VARS_PUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icidae"),
        dictgen::InsensitiveStr::Ascii("icide"),
        dictgen::InsensitiveStr::Ascii("lmanise"),
        dictgen::InsensitiveStr::Ascii("lmanises"),
        dictgen::InsensitiveStr::Ascii("lmanize"),
        dictgen::InsensitiveStr::Ascii("lmanizes"),
        dictgen::InsensitiveStr::Ascii("pitise"),
        dictgen::InsensitiveStr::Ascii("pitises"),
        dictgen::InsensitiveStr::Ascii("pitize"),
        dictgen::InsensitiveStr::Ascii("pitizes"),
        dictgen::InsensitiveStr::Ascii("verisable"),
        dictgen::InsensitiveStr::Ascii("verisabler"),
        dictgen::InsensitiveStr::Ascii("verisables"),
        dictgen::InsensitiveStr::Ascii("verisablest"),
        dictgen::InsensitiveStr::Ascii("verisation"),
        dictgen::InsensitiveStr::Ascii("verisations"),
        dictgen::InsensitiveStr::Ascii("verise"),
        dictgen::InsensitiveStr::Ascii("verised"),
        dictgen::InsensitiveStr::Ascii("veriser"),
        dictgen::InsensitiveStr::Ascii("verisers"),
        dictgen::InsensitiveStr::Ascii("verises"),
        dictgen::InsensitiveStr::Ascii("verising"),
        dictgen::InsensitiveStr::Ascii("verizable"),
        dictgen::InsensitiveStr::Ascii("verizabler"),
        dictgen::InsensitiveStr::Ascii("verizables"),
        dictgen::InsensitiveStr::Ascii("verizablest"),
        dictgen::InsensitiveStr::Ascii("verization"),
        dictgen::InsensitiveStr::Ascii("verizations"),
        dictgen::InsensitiveStr::Ascii("verize"),
        dictgen::InsensitiveStr::Ascii("verized"),
        dictgen::InsensitiveStr::Ascii("verizer"),
        dictgen::InsensitiveStr::Ascii("verizers"),
        dictgen::InsensitiveStr::Ascii("verizes"),
        dictgen::InsensitiveStr::Ascii("verizing"),
        dictgen::InsensitiveStr::Ascii("vilised"),
        dictgen::InsensitiveStr::Ascii("vilized"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PULICIDE_3980015686815717552)],
        &[(0b00001, &ENTRY_PULICIDE_3980015686815717552)],
        &[(0b10010, &ENTRY_PULLMANIZE_5203335815973067932)],
        &[(0b10010, &ENTRY_PULLMANIZES_15655484632672360202)],
        &[(0b01001, &ENTRY_PULLMANIZE_5203335815973067932)],
        &[(0b01001, &ENTRY_PULLMANIZES_15655484632672360202)],
        &[(0b10010, &ENTRY_PULPITIZE_14520819506187442470)],
        &[(0b10010, &ENTRY_PULPITIZES_600820339977194743)],
        &[(0b01001, &ENTRY_PULPITIZE_14520819506187442470)],
        &[(0b01001, &ENTRY_PULPITIZES_600820339977194743)],
        &[(0b10010, &ENTRY_PULVERIZABLE_5528070605510221873)],
        &[(0b10010, &ENTRY_PULVERIZABLER_10798841945279688999)],
        &[(0b10010, &ENTRY_PULVERIZABLES_12801837069908355828)],
        &[(0b10010, &ENTRY_PULVERIZABLEST_9880898831981142418)],
        &[(0b10010, &ENTRY_PULVERIZATION_200228103143865531)],
        &[(0b10010, &ENTRY_PULVERIZATIONS_14450827217528983318)],
        &[(0b10010, &ENTRY_PULVERIZE_4116752745240045211)],
        &[(0b10010, &ENTRY_PULVERIZED_14246254308729460669)],
        &[(0b10010, &ENTRY_PULVERIZER_14835766143113548223)],
        &[(0b10010, &ENTRY_PULVERIZERS_7182805923294437318)],
        &[(0b10010, &ENTRY_PULVERIZES_1827295055378958546)],
        &[(0b10010, &ENTRY_PULVERIZING_17352214593955572763)],
        &[(0b01001, &ENTRY_PULVERIZABLE_5528070605510221873)],
        &[(0b01001, &ENTRY_PULVERIZABLER_10798841945279688999)],
        &[(0b01001, &ENTRY_PULVERIZABLES_12801837069908355828)],
        &[(0b01001, &ENTRY_PULVERIZABLEST_9880898831981142418)],
        &[(0b01001, &ENTRY_PULVERIZATION_200228103143865531)],
        &[(0b01001, &ENTRY_PULVERIZATIONS_14450827217528983318)],
        &[(0b01001, &ENTRY_PULVERIZE_4116752745240045211)],
        &[(0b01001, &ENTRY_PULVERIZED_14246254308729460669)],
        &[(0b01001, &ENTRY_PULVERIZER_14835766143113548223)],
        &[(0b01001, &ENTRY_PULVERIZERS_7182805923294437318)],
        &[(0b01001, &ENTRY_PULVERIZES_1827295055378958546)],
        &[(0b01001, &ENTRY_PULVERIZING_17352214593955572763)],
        &[(0b10010, &ENTRY_PULVILIZED_10532293626777762076)],
        &[(0b01001, &ENTRY_PULVILIZED_10532293626777762076)],
    ],
    range: 5..=11,
};

static VARS_PUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUE_CHILDREN),
    value: None,
};

pub static VARS_PUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bloisation"),
        dictgen::InsensitiveStr::Ascii("bloisations"),
        dictgen::InsensitiveStr::Ascii("bloise"),
        dictgen::InsensitiveStr::Ascii("bloises"),
        dictgen::InsensitiveStr::Ascii("bloization"),
        dictgen::InsensitiveStr::Ascii("bloizations"),
        dictgen::InsensitiveStr::Ascii("bloize"),
        dictgen::InsensitiveStr::Ascii("bloizes"),
        dictgen::InsensitiveStr::Ascii("rs"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PUEBLOIZATION_14471611923776355990)],
        &[(0b10010, &ENTRY_PUEBLOIZATIONS_17184954788467253967)],
        &[(0b10010, &ENTRY_PUEBLOIZE_4789148533035124772)],
        &[(0b10010, &ENTRY_PUEBLOIZES_16793523394160108027)],
        &[(0b01001, &ENTRY_PUEBLOIZATION_14471611923776355990)],
        &[(0b01001, &ENTRY_PUEBLOIZATIONS_17184954788467253967)],
        &[(0b01001, &ENTRY_PUEBLOIZE_4789148533035124772)],
        &[(0b01001, &ENTRY_PUEBLOIZES_16793523394160108027)],
        &[(0b00001, &ENTRY_PUERS_17142262766965004130)],
    ],
    range: 2..=11,
};

static VARS_PUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PUB_CHILDREN),
    value: None,
};

pub static VARS_PUB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("licae"),
        dictgen::InsensitiveStr::Ascii("lice"),
        dictgen::InsensitiveStr::Ascii("licise"),
        dictgen::InsensitiveStr::Ascii("licised"),
        dictgen::InsensitiveStr::Ascii("licises"),
        dictgen::InsensitiveStr::Ascii("licising"),
        dictgen::InsensitiveStr::Ascii("licize"),
        dictgen::InsensitiveStr::Ascii("licized"),
        dictgen::InsensitiveStr::Ascii("licizes"),
        dictgen::InsensitiveStr::Ascii("licizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PUBLICE_2505581592993963568)],
        &[(0b00001, &ENTRY_PUBLICE_2505581592993963568)],
        &[(0b10010, &ENTRY_PUBLICIZE_3888814953502121211)],
        &[(0b10010, &ENTRY_PUBLICIZED_18157849789983063314)],
        &[(0b10010, &ENTRY_PUBLICIZES_16376391030778715202)],
        &[(0b10010, &ENTRY_PUBLICIZING_15997293412271552492)],
        &[(0b01001, &ENTRY_PUBLICIZE_3888814953502121211)],
        &[(0b01001, &ENTRY_PUBLICIZED_18157849789983063314)],
        &[(0b01001, &ENTRY_PUBLICIZES_16376391030778715202)],
        &[(0b01001, &ENTRY_PUBLICIZING_15997293412271552492)],
    ],
    range: 4..=8,
};

static VARS_PT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PT_CHILDREN),
    value: None,
};

pub static VARS_PT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olemaean"),
        dictgen::InsensitiveStr::Ascii("olemean"),
        dictgen::InsensitiveStr::Ascii("yalise"),
        dictgen::InsensitiveStr::Ascii("yalised"),
        dictgen::InsensitiveStr::Ascii("yalises"),
        dictgen::InsensitiveStr::Ascii("yalising"),
        dictgen::InsensitiveStr::Ascii("yalize"),
        dictgen::InsensitiveStr::Ascii("yalized"),
        dictgen::InsensitiveStr::Ascii("yalizes"),
        dictgen::InsensitiveStr::Ascii("yalizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PTOLEMEAN_7707720059199920848)],
        &[(0b00001, &ENTRY_PTOLEMEAN_7707720059199920848)],
        &[(0b10010, &ENTRY_PTYALIZE_4353643134370653716)],
        &[(0b10010, &ENTRY_PTYALIZED_14737891637486973456)],
        &[(0b10010, &ENTRY_PTYALIZES_12224265186752645935)],
        &[(0b10010, &ENTRY_PTYALIZING_4613334822493205194)],
        &[(0b01001, &ENTRY_PTYALIZE_4353643134370653716)],
        &[(0b01001, &ENTRY_PTYALIZED_14737891637486973456)],
        &[(0b01001, &ENTRY_PTYALIZES_12224265186752645935)],
        &[(0b01001, &ENTRY_PTYALIZING_4613334822493205194)],
    ],
    range: 6..=8,
};

static VARS_PS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PS_CHILDREN),
    value: None,
};

pub static VARS_PS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("almodise"),
        dictgen::InsensitiveStr::Ascii("almodised"),
        dictgen::InsensitiveStr::Ascii("almodises"),
        dictgen::InsensitiveStr::Ascii("almodising"),
        dictgen::InsensitiveStr::Ascii("almodize"),
        dictgen::InsensitiveStr::Ascii("almodized"),
        dictgen::InsensitiveStr::Ascii("almodizes"),
        dictgen::InsensitiveStr::Ascii("almodizing"),
        dictgen::InsensitiveStr::Ascii("eudaesthesia"),
        dictgen::InsensitiveStr::Ascii("eudelephant"),
        dictgen::InsensitiveStr::Ascii("eudembryo"),
        dictgen::InsensitiveStr::Ascii("eudembryonic"),
        dictgen::InsensitiveStr::Ascii("eudesthesia"),
        dictgen::InsensitiveStr::Ascii("eudhaemal"),
        dictgen::InsensitiveStr::Ascii("eudhemal"),
        dictgen::InsensitiveStr::Ascii("eudoanaemia"),
        dictgen::InsensitiveStr::Ascii("eudoanaemias"),
        dictgen::InsensitiveStr::Ascii("eudoanaemic"),
        dictgen::InsensitiveStr::Ascii("eudoanaemics"),
        dictgen::InsensitiveStr::Ascii("eudoanemia"),
        dictgen::InsensitiveStr::Ascii("eudoanemias"),
        dictgen::InsensitiveStr::Ascii("eudoanemic"),
        dictgen::InsensitiveStr::Ascii("eudoanemics"),
        dictgen::InsensitiveStr::Ascii("eudocele"),
        dictgen::InsensitiveStr::Ascii("eudocelom"),
        dictgen::InsensitiveStr::Ascii("eudocoele"),
        dictgen::InsensitiveStr::Ascii("eudocoelom"),
        dictgen::InsensitiveStr::Ascii("eudoedema"),
        dictgen::InsensitiveStr::Ascii("eudoedemas"),
        dictgen::InsensitiveStr::Ascii("eudoelephant"),
        dictgen::InsensitiveStr::Ascii("eudoembryo"),
        dictgen::InsensitiveStr::Ascii("eudoembryonic"),
        dictgen::InsensitiveStr::Ascii("eudographise"),
        dictgen::InsensitiveStr::Ascii("eudographises"),
        dictgen::InsensitiveStr::Ascii("eudographize"),
        dictgen::InsensitiveStr::Ascii("eudographizes"),
        dictgen::InsensitiveStr::Ascii("eudolunulae"),
        dictgen::InsensitiveStr::Ascii("eudolunule"),
        dictgen::InsensitiveStr::Ascii("eudooedema"),
        dictgen::InsensitiveStr::Ascii("eudooedemas"),
        dictgen::InsensitiveStr::Ascii("ychoanalyse"),
        dictgen::InsensitiveStr::Ascii("ychoanalysed"),
        dictgen::InsensitiveStr::Ascii("ychoanalyser"),
        dictgen::InsensitiveStr::Ascii("ychoanalysers"),
        dictgen::InsensitiveStr::Ascii("ychoanalysing"),
        dictgen::InsensitiveStr::Ascii("ychoanalyze"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzed"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzer"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzers"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzes"),
        dictgen::InsensitiveStr::Ascii("ychoanalyzing"),
        dictgen::InsensitiveStr::Ascii("ychologisation"),
        dictgen::InsensitiveStr::Ascii("ychologise"),
        dictgen::InsensitiveStr::Ascii("ychologised"),
        dictgen::InsensitiveStr::Ascii("ychologises"),
        dictgen::InsensitiveStr::Ascii("ychologising"),
        dictgen::InsensitiveStr::Ascii("ychologization"),
        dictgen::InsensitiveStr::Ascii("ychologize"),
        dictgen::InsensitiveStr::Ascii("ychologized"),
        dictgen::InsensitiveStr::Ascii("ychologizes"),
        dictgen::InsensitiveStr::Ascii("ychologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PSALMODIZE_6785943915373540400)],
        &[(0b10010, &ENTRY_PSALMODIZED_9886224417033316783)],
        &[(0b10010, &ENTRY_PSALMODIZES_313135324604902888)],
        &[(0b10010, &ENTRY_PSALMODIZING_16968583801346153803)],
        &[(0b01001, &ENTRY_PSALMODIZE_6785943915373540400)],
        &[(0b01001, &ENTRY_PSALMODIZED_9886224417033316783)],
        &[(0b01001, &ENTRY_PSALMODIZES_313135324604902888)],
        &[(0b01001, &ENTRY_PSALMODIZING_16968583801346153803)],
        &[(0b11010, &ENTRY_PSEUDESTHESIA_12407767994846061516)],
        &[(0b00001, &ENTRY_PSEUDELEPHANT_11694652678064871967)],
        &[(0b00001, &ENTRY_PSEUDEMBRYO_10487252041242116470)],
        &[(0b00001, &ENTRY_PSEUDEMBRYONIC_17990306181748605974)],
        &[(0b00001, &ENTRY_PSEUDESTHESIA_12407767994846061516)],
        &[(0b11010, &ENTRY_PSEUDHEMAL_4355056111903797494)],
        &[(0b00001, &ENTRY_PSEUDHEMAL_4355056111903797494)],
        &[(0b11010, &ENTRY_PSEUDOANEMIA_5124966852485838539)],
        &[(0b11010, &ENTRY_PSEUDOANEMIAS_6046630203472884287)],
        &[(0b11010, &ENTRY_PSEUDOANEMIC_11200180250612296538)],
        &[(0b11010, &ENTRY_PSEUDOANEMICS_2122831063804414766)],
        &[(0b00001, &ENTRY_PSEUDOANEMIA_5124966852485838539)],
        &[(0b00001, &ENTRY_PSEUDOANEMIAS_6046630203472884287)],
        &[(0b00001, &ENTRY_PSEUDOANEMIC_11200180250612296538)],
        &[(0b00001, &ENTRY_PSEUDOANEMICS_2122831063804414766)],
        &[(0b00001, &ENTRY_PSEUDOCELE_16415452007409564004)],
        &[(0b00001, &ENTRY_PSEUDOCELOM_1695207054053145685)],
        &[(0b11010, &ENTRY_PSEUDOCELE_16415452007409564004)],
        &[(0b11010, &ENTRY_PSEUDOCELOM_1695207054053145685)],
        &[(0b00001, &ENTRY_PSEUDOEDEMA_15891555805692784302)],
        &[(0b00001, &ENTRY_PSEUDOEDEMAS_16026718825763332741)],
        &[(0b11010, &ENTRY_PSEUDELEPHANT_11694652678064871967)],
        &[(0b11010, &ENTRY_PSEUDEMBRYO_10487252041242116470)],
        &[(0b11010, &ENTRY_PSEUDEMBRYONIC_17990306181748605974)],
        &[(0b10010, &ENTRY_PSEUDOGRAPHIZE_5452057591678689737)],
        &[(0b10010, &ENTRY_PSEUDOGRAPHIZES_3672980465786441046)],
        &[(0b01001, &ENTRY_PSEUDOGRAPHIZE_5452057591678689737)],
        &[(0b01001, &ENTRY_PSEUDOGRAPHIZES_3672980465786441046)],
        &[(0b11010, &ENTRY_PSEUDOLUNULE_1282566980410169374)],
        &[(0b00001, &ENTRY_PSEUDOLUNULE_1282566980410169374)],
        &[(0b11010, &ENTRY_PSEUDOEDEMA_15891555805692784302)],
        &[(0b11010, &ENTRY_PSEUDOEDEMAS_16026718825763332741)],
        &[(0b10010, &ENTRY_PSYCHOANALYZE_3750025217840958426)],
        &[(0b10010, &ENTRY_PSYCHOANALYZED_5816959482018278884)],
        &[(0b10010, &ENTRY_PSYCHOANALYZER_12400127427681777018)],
        &[(0b10010, &ENTRY_PSYCHOANALYZERS_1935290147506502388)],
        &[(0b10010, &ENTRY_PSYCHOANALYZING_11072585094830037830)],
        &[(0b01001, &ENTRY_PSYCHOANALYZE_3750025217840958426)],
        &[(0b01001, &ENTRY_PSYCHOANALYZED_5816959482018278884)],
        &[(0b01001, &ENTRY_PSYCHOANALYZER_12400127427681777018)],
        &[(0b01001, &ENTRY_PSYCHOANALYZERS_1935290147506502388)],
        &[(0b01001, &ENTRY_PSYCHOANALYZES_16566220832374590261)],
        &[(0b01001, &ENTRY_PSYCHOANALYZING_11072585094830037830)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZATION_13227193510267031057)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZE_15669513547256121943)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZED_12194990558663330704)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZES_13336468276425310690)],
        &[(0b10010, &ENTRY_PSYCHOLOGIZING_15426494443157713628)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZATION_13227193510267031057)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZE_15669513547256121943)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZED_12194990558663330704)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZES_13336468276425310690)],
        &[(0b01001, &ENTRY_PSYCHOLOGIZING_15426494443157713628)],
    ],
    range: 8..=14,
};

static VARS_PR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PR_CHILDREN),
    value: None,
};

static VARS_PR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PRA_NODE),
    None,
    None,
    None,
    Some(&VARS_PRE_NODE),
    None,
    None,
    None,
    Some(&VARS_PRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PRU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_PRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRU_CHILDREN),
    value: None,
};

pub static VARS_PRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ssianisation"),
        dictgen::InsensitiveStr::Ascii("ssianisations"),
        dictgen::InsensitiveStr::Ascii("ssianise"),
        dictgen::InsensitiveStr::Ascii("ssianised"),
        dictgen::InsensitiveStr::Ascii("ssianiser"),
        dictgen::InsensitiveStr::Ascii("ssianisers"),
        dictgen::InsensitiveStr::Ascii("ssianises"),
        dictgen::InsensitiveStr::Ascii("ssianising"),
        dictgen::InsensitiveStr::Ascii("ssianization"),
        dictgen::InsensitiveStr::Ascii("ssianizations"),
        dictgen::InsensitiveStr::Ascii("ssianize"),
        dictgen::InsensitiveStr::Ascii("ssianized"),
        dictgen::InsensitiveStr::Ascii("ssianizer"),
        dictgen::InsensitiveStr::Ascii("ssianizers"),
        dictgen::InsensitiveStr::Ascii("ssianizes"),
        dictgen::InsensitiveStr::Ascii("ssianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRUSSIANIZATION_10958382439781151197)],
        &[(0b10010, &ENTRY_PRUSSIANIZATIONS_6915840876369617729)],
        &[(0b10010, &ENTRY_PRUSSIANIZE_12907469526535425712)],
        &[(0b10010, &ENTRY_PRUSSIANIZED_7738848135177998531)],
        &[(0b10010, &ENTRY_PRUSSIANIZER_17577551278831620692)],
        &[(0b10010, &ENTRY_PRUSSIANIZERS_15563358695966470583)],
        &[(0b10010, &ENTRY_PRUSSIANIZES_16592096312730648273)],
        &[(0b10010, &ENTRY_PRUSSIANIZING_17187448249162985680)],
        &[(0b01001, &ENTRY_PRUSSIANIZATION_10958382439781151197)],
        &[(0b01001, &ENTRY_PRUSSIANIZATIONS_6915840876369617729)],
        &[(0b01001, &ENTRY_PRUSSIANIZE_12907469526535425712)],
        &[(0b01001, &ENTRY_PRUSSIANIZED_7738848135177998531)],
        &[(0b01001, &ENTRY_PRUSSIANIZER_17577551278831620692)],
        &[(0b01001, &ENTRY_PRUSSIANIZERS_15563358695966470583)],
        &[(0b01001, &ENTRY_PRUSSIANIZES_16592096312730648273)],
        &[(0b01001, &ENTRY_PRUSSIANIZING_17187448249162985680)],
    ],
    range: 8..=13,
};

static VARS_PRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PRO_CHILDREN),
    value: None,
};

static VARS_PRO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PROA_NODE),
    Some(&VARS_PROB_NODE),
    Some(&VARS_PROC_NODE),
    Some(&VARS_PROD_NODE),
    Some(&VARS_PROE_NODE),
    Some(&VARS_PROF_NODE),
    Some(&VARS_PROG_NODE),
    None,
    Some(&VARS_PROI_NODE),
    Some(&VARS_PROJ_NODE),
    None,
    Some(&VARS_PROL_NODE),
    None,
    Some(&VARS_PRON_NODE),
    Some(&VARS_PROO_NODE),
    Some(&VARS_PROP_NODE),
    None,
    None,
    Some(&VARS_PROS_NODE),
    Some(&VARS_PROT_NODE),
    None,
    Some(&VARS_PROV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_PROV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROV_CHILDREN),
    value: None,
};

pub static VARS_PROV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erbialise"),
        dictgen::InsensitiveStr::Ascii("erbialised"),
        dictgen::InsensitiveStr::Ascii("erbialises"),
        dictgen::InsensitiveStr::Ascii("erbialising"),
        dictgen::InsensitiveStr::Ascii("erbialize"),
        dictgen::InsensitiveStr::Ascii("erbialized"),
        dictgen::InsensitiveStr::Ascii("erbializes"),
        dictgen::InsensitiveStr::Ascii("erbializing"),
        dictgen::InsensitiveStr::Ascii("erbise"),
        dictgen::InsensitiveStr::Ascii("erbises"),
        dictgen::InsensitiveStr::Ascii("erbize"),
        dictgen::InsensitiveStr::Ascii("erbizes"),
        dictgen::InsensitiveStr::Ascii("incialisation"),
        dictgen::InsensitiveStr::Ascii("incialisations"),
        dictgen::InsensitiveStr::Ascii("incialise"),
        dictgen::InsensitiveStr::Ascii("incialised"),
        dictgen::InsensitiveStr::Ascii("incialises"),
        dictgen::InsensitiveStr::Ascii("incialising"),
        dictgen::InsensitiveStr::Ascii("incialization"),
        dictgen::InsensitiveStr::Ascii("incializations"),
        dictgen::InsensitiveStr::Ascii("incialize"),
        dictgen::InsensitiveStr::Ascii("incialized"),
        dictgen::InsensitiveStr::Ascii("incializes"),
        dictgen::InsensitiveStr::Ascii("incializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROVERBIALIZE_10779880440815640572)],
        &[(0b10010, &ENTRY_PROVERBIALIZED_15384141908364563413)],
        &[(0b10010, &ENTRY_PROVERBIALIZES_5554547456085258371)],
        &[(0b10010, &ENTRY_PROVERBIALIZING_16662355151354609960)],
        &[(0b01001, &ENTRY_PROVERBIALIZE_10779880440815640572)],
        &[(0b01001, &ENTRY_PROVERBIALIZED_15384141908364563413)],
        &[(0b01001, &ENTRY_PROVERBIALIZES_5554547456085258371)],
        &[(0b01001, &ENTRY_PROVERBIALIZING_16662355151354609960)],
        &[(0b10010, &ENTRY_PROVERBIZE_5057145621251371752)],
        &[(0b10010, &ENTRY_PROVERBIZES_1232232315538032087)],
        &[(0b01001, &ENTRY_PROVERBIZE_5057145621251371752)],
        &[(0b01001, &ENTRY_PROVERBIZES_1232232315538032087)],
        &[(0b10010, &ENTRY_PROVINCIALIZATION_13831389932205748314)],
        &[(0b10010, &ENTRY_PROVINCIALIZATIONS_7082778031208249106)],
        &[(0b10010, &ENTRY_PROVINCIALIZE_15342640692775315618)],
        &[(0b10010, &ENTRY_PROVINCIALIZED_2188539660593884677)],
        &[(0b10010, &ENTRY_PROVINCIALIZES_2334082830205990146)],
        &[(0b10010, &ENTRY_PROVINCIALIZING_13986914622652313230)],
        &[(0b01001, &ENTRY_PROVINCIALIZATION_13831389932205748314)],
        &[(0b01001, &ENTRY_PROVINCIALIZATIONS_7082778031208249106)],
        &[(0b01001, &ENTRY_PROVINCIALIZE_15342640692775315618)],
        &[(0b01001, &ENTRY_PROVINCIALIZED_2188539660593884677)],
        &[(0b01001, &ENTRY_PROVINCIALIZES_2334082830205990146)],
        &[(0b01001, &ENTRY_PROVINCIALIZING_13986914622652313230)],
    ],
    range: 6..=14,
};

static VARS_PROT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROT_CHILDREN),
    value: None,
};

pub static VARS_PROT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectionise"),
        dictgen::InsensitiveStr::Ascii("ectionises"),
        dictgen::InsensitiveStr::Ascii("ectionize"),
        dictgen::InsensitiveStr::Ascii("ectionizes"),
        dictgen::InsensitiveStr::Ascii("eidae"),
        dictgen::InsensitiveStr::Ascii("eide"),
        dictgen::InsensitiveStr::Ascii("estantise"),
        dictgen::InsensitiveStr::Ascii("estantised"),
        dictgen::InsensitiveStr::Ascii("estantises"),
        dictgen::InsensitiveStr::Ascii("estantising"),
        dictgen::InsensitiveStr::Ascii("estantize"),
        dictgen::InsensitiveStr::Ascii("estantized"),
        dictgen::InsensitiveStr::Ascii("estantizes"),
        dictgen::InsensitiveStr::Ascii("estantizing"),
        dictgen::InsensitiveStr::Ascii("hoaenor"),
        dictgen::InsensitiveStr::Ascii("hoenor"),
        dictgen::InsensitiveStr::Ascii("oarchaeology"),
        dictgen::InsensitiveStr::Ascii("oarcheology"),
        dictgen::InsensitiveStr::Ascii("ocoled"),
        dictgen::InsensitiveStr::Ascii("ocoling"),
        dictgen::InsensitiveStr::Ascii("ocolisation"),
        dictgen::InsensitiveStr::Ascii("ocolisations"),
        dictgen::InsensitiveStr::Ascii("ocolise"),
        dictgen::InsensitiveStr::Ascii("ocolised"),
        dictgen::InsensitiveStr::Ascii("ocolises"),
        dictgen::InsensitiveStr::Ascii("ocolising"),
        dictgen::InsensitiveStr::Ascii("ocolization"),
        dictgen::InsensitiveStr::Ascii("ocolizations"),
        dictgen::InsensitiveStr::Ascii("ocolize"),
        dictgen::InsensitiveStr::Ascii("ocolized"),
        dictgen::InsensitiveStr::Ascii("ocolizes"),
        dictgen::InsensitiveStr::Ascii("ocolizing"),
        dictgen::InsensitiveStr::Ascii("ocolled"),
        dictgen::InsensitiveStr::Ascii("ocolling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROTECTIONIZE_13639705024576405936)],
        &[(0b10010, &ENTRY_PROTECTIONIZES_10344288741949666317)],
        &[(0b01001, &ENTRY_PROTECTIONIZE_13639705024576405936)],
        &[(0b01001, &ENTRY_PROTECTIONIZES_10344288741949666317)],
        &[(0b11010, &ENTRY_PROTEIDE_15177699273216527826)],
        &[(0b00001, &ENTRY_PROTEIDE_15177699273216527826)],
        &[(0b10010, &ENTRY_PROTESTANTIZE_5849584465690284720)],
        &[(0b10010, &ENTRY_PROTESTANTIZED_7638390729359938099)],
        &[(0b10010, &ENTRY_PROTESTANTIZES_1093133710944013164)],
        &[(0b10010, &ENTRY_PROTESTANTIZING_218744719233014114)],
        &[(0b01001, &ENTRY_PROTESTANTIZE_5849584465690284720)],
        &[(0b01001, &ENTRY_PROTESTANTIZED_7638390729359938099)],
        &[(0b01001, &ENTRY_PROTESTANTIZES_1093133710944013164)],
        &[(0b01001, &ENTRY_PROTESTANTIZING_218744719233014114)],
        &[(0b11010, &ENTRY_PROTHOENOR_15356183037577716314)],
        &[(0b00001, &ENTRY_PROTHOENOR_15356183037577716314)],
        &[(0b11010, &ENTRY_PROTOARCHEOLOGY_3979328534027257913)],
        &[(0b00001, &ENTRY_PROTOARCHEOLOGY_3979328534027257913)],
        &[(0b00001, &ENTRY_PROTOCOLED_9184207318768023915)],
        &[(0b00001, &ENTRY_PROTOCOLING_16289008591020603327)],
        &[(0b10010, &ENTRY_PROTOCOLIZATION_912207443070037399)],
        &[(0b10010, &ENTRY_PROTOCOLIZATIONS_15242092987659511854)],
        &[(0b10010, &ENTRY_PROTOCOLIZE_15855693097748168695)],
        &[(0b10010, &ENTRY_PROTOCOLIZED_17551306331631525677)],
        &[(0b10010, &ENTRY_PROTOCOLIZES_11921216524567616192)],
        &[(0b10010, &ENTRY_PROTOCOLIZING_6817748168002379013)],
        &[(0b01001, &ENTRY_PROTOCOLIZATION_912207443070037399)],
        &[(0b01001, &ENTRY_PROTOCOLIZATIONS_15242092987659511854)],
        &[(0b01001, &ENTRY_PROTOCOLIZE_15855693097748168695)],
        &[(0b01001, &ENTRY_PROTOCOLIZED_17551306331631525677)],
        &[(0b01001, &ENTRY_PROTOCOLIZES_11921216524567616192)],
        &[(0b01001, &ENTRY_PROTOCOLIZING_6817748168002379013)],
        &[(0b11010, &ENTRY_PROTOCOLED_9184207318768023915)],
        &[(0b11010, &ENTRY_PROTOCOLING_16289008591020603327)],
    ],
    range: 4..=12,
};

static VARS_PROS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROS_CHILDREN),
    value: None,
};

pub static VARS_PROS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elytisation"),
        dictgen::InsensitiveStr::Ascii("elytisations"),
        dictgen::InsensitiveStr::Ascii("elytise"),
        dictgen::InsensitiveStr::Ascii("elytised"),
        dictgen::InsensitiveStr::Ascii("elytiser"),
        dictgen::InsensitiveStr::Ascii("elytisers"),
        dictgen::InsensitiveStr::Ascii("elytises"),
        dictgen::InsensitiveStr::Ascii("elytising"),
        dictgen::InsensitiveStr::Ascii("elytization"),
        dictgen::InsensitiveStr::Ascii("elytizations"),
        dictgen::InsensitiveStr::Ascii("elytize"),
        dictgen::InsensitiveStr::Ascii("elytized"),
        dictgen::InsensitiveStr::Ascii("elytizer"),
        dictgen::InsensitiveStr::Ascii("elytizers"),
        dictgen::InsensitiveStr::Ascii("elytizes"),
        dictgen::InsensitiveStr::Ascii("elytizing"),
        dictgen::InsensitiveStr::Ascii("euchae"),
        dictgen::InsensitiveStr::Ascii("euche"),
        dictgen::InsensitiveStr::Ascii("ocele"),
        dictgen::InsensitiveStr::Ascii("ocoele"),
        dictgen::InsensitiveStr::Ascii("opopeia"),
        dictgen::InsensitiveStr::Ascii("opopeial"),
        dictgen::InsensitiveStr::Ascii("opopeias"),
        dictgen::InsensitiveStr::Ascii("opopoeial"),
        dictgen::InsensitiveStr::Ascii("tatorrhea"),
        dictgen::InsensitiveStr::Ascii("tatorrhoea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROSELYTIZATION_6529379067249492159)],
        &[(0b10010, &ENTRY_PROSELYTIZATIONS_9868313451413411610)],
        &[(0b10010, &ENTRY_PROSELYTIZE_2045808347498243297)],
        &[(0b10010, &ENTRY_PROSELYTIZED_2214158284515887133)],
        &[(0b10010, &ENTRY_PROSELYTIZER_16192805406416418559)],
        &[(0b10010, &ENTRY_PROSELYTIZERS_8374451172555772107)],
        &[(0b10010, &ENTRY_PROSELYTIZES_17493975453031891132)],
        &[(0b10010, &ENTRY_PROSELYTIZING_9230222865633259129)],
        &[(0b01001, &ENTRY_PROSELYTIZATION_6529379067249492159)],
        &[(0b01001, &ENTRY_PROSELYTIZATIONS_9868313451413411610)],
        &[(0b01001, &ENTRY_PROSELYTIZE_2045808347498243297)],
        &[(0b01001, &ENTRY_PROSELYTIZED_2214158284515887133)],
        &[(0b01001, &ENTRY_PROSELYTIZER_16192805406416418559)],
        &[(0b01001, &ENTRY_PROSELYTIZERS_8374451172555772107)],
        &[(0b01001, &ENTRY_PROSELYTIZES_17493975453031891132)],
        &[(0b01001, &ENTRY_PROSELYTIZING_9230222865633259129)],
        &[(0b11010, &ENTRY_PROSEUCHE_18082547994938576822)],
        &[(0b00001, &ENTRY_PROSEUCHE_18082547994938576822)],
        &[(0b00001, &ENTRY_PROSOCELE_8377653530954019059)],
        &[(0b11010, &ENTRY_PROSOCELE_8377653530954019059)],
        &[(0b01001, &ENTRY_PROSOPOPOEIA_18371169721208163527)],
        &[(0b00001, &ENTRY_PROSOPOPEIAL_11424645114316445715)],
        &[(0b01001, &ENTRY_PROSOPOPOEIAS_7785383172591439340)],
        &[(0b11010, &ENTRY_PROSOPOPEIAL_11424645114316445715)],
        &[(0b00001, &ENTRY_PROSTATORRHEA_560097517692680467)],
        &[(0b11010, &ENTRY_PROSTATORRHEA_560097517692680467)],
    ],
    range: 5..=12,
};

static VARS_PROP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROP_CHILDREN),
    value: None,
};

pub static VARS_PROP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agandise"),
        dictgen::InsensitiveStr::Ascii("agandised"),
        dictgen::InsensitiveStr::Ascii("agandises"),
        dictgen::InsensitiveStr::Ascii("agandising"),
        dictgen::InsensitiveStr::Ascii("agandize"),
        dictgen::InsensitiveStr::Ascii("agandized"),
        dictgen::InsensitiveStr::Ascii("agandizes"),
        dictgen::InsensitiveStr::Ascii("agandizing"),
        dictgen::InsensitiveStr::Ascii("hetise"),
        dictgen::InsensitiveStr::Ascii("hetises"),
        dictgen::InsensitiveStr::Ascii("hetize"),
        dictgen::InsensitiveStr::Ascii("hetizes"),
        dictgen::InsensitiveStr::Ascii("ositionise"),
        dictgen::InsensitiveStr::Ascii("ositionises"),
        dictgen::InsensitiveStr::Ascii("ositionize"),
        dictgen::InsensitiveStr::Ascii("ositionizes"),
        dictgen::InsensitiveStr::Ascii("raetor"),
        dictgen::InsensitiveStr::Ascii("raetorial"),
        dictgen::InsensitiveStr::Ascii("raetorian"),
        dictgen::InsensitiveStr::Ascii("raetors"),
        dictgen::InsensitiveStr::Ascii("retor"),
        dictgen::InsensitiveStr::Ascii("retorial"),
        dictgen::InsensitiveStr::Ascii("retorian"),
        dictgen::InsensitiveStr::Ascii("retors"),
        dictgen::InsensitiveStr::Ascii("ylitisation"),
        dictgen::InsensitiveStr::Ascii("ylitisations"),
        dictgen::InsensitiveStr::Ascii("ylitise"),
        dictgen::InsensitiveStr::Ascii("ylitised"),
        dictgen::InsensitiveStr::Ascii("ylitises"),
        dictgen::InsensitiveStr::Ascii("ylitising"),
        dictgen::InsensitiveStr::Ascii("ylitization"),
        dictgen::InsensitiveStr::Ascii("ylitizations"),
        dictgen::InsensitiveStr::Ascii("ylitize"),
        dictgen::InsensitiveStr::Ascii("ylitized"),
        dictgen::InsensitiveStr::Ascii("ylitizes"),
        dictgen::InsensitiveStr::Ascii("ylitizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROPAGANDIZE_17672695121638138026)],
        &[(0b10010, &ENTRY_PROPAGANDIZED_7923401534538057928)],
        &[(0b10010, &ENTRY_PROPAGANDIZES_17414306414554519223)],
        &[(0b10010, &ENTRY_PROPAGANDIZING_14458179375605730291)],
        &[(0b01001, &ENTRY_PROPAGANDIZE_17672695121638138026)],
        &[(0b01001, &ENTRY_PROPAGANDIZED_7923401534538057928)],
        &[(0b01001, &ENTRY_PROPAGANDIZES_17414306414554519223)],
        &[(0b01001, &ENTRY_PROPAGANDIZING_14458179375605730291)],
        &[(0b10010, &ENTRY_PROPHETIZE_3283856741265018815)],
        &[(0b10010, &ENTRY_PROPHETIZES_7700079523894166264)],
        &[(0b01001, &ENTRY_PROPHETIZE_3283856741265018815)],
        &[(0b01001, &ENTRY_PROPHETIZES_7700079523894166264)],
        &[(0b10010, &ENTRY_PROPOSITIONIZE_16503275049520839015)],
        &[(0b10010, &ENTRY_PROPOSITIONIZES_13969404499779129990)],
        &[(0b01001, &ENTRY_PROPOSITIONIZE_16503275049520839015)],
        &[(0b01001, &ENTRY_PROPOSITIONIZES_13969404499779129990)],
        &[(0b11010, &ENTRY_PROPRETOR_8308951553220524726)],
        &[(0b11010, &ENTRY_PROPRETORIAL_4183494453271841116)],
        &[(0b11010, &ENTRY_PROPRETORIAN_14560418131352376207)],
        &[(0b11010, &ENTRY_PROPRETORS_1061872627090076302)],
        &[(0b00001, &ENTRY_PROPRETOR_8308951553220524726)],
        &[(0b00001, &ENTRY_PROPRETORIAL_4183494453271841116)],
        &[(0b00001, &ENTRY_PROPRETORIAN_14560418131352376207)],
        &[(0b00001, &ENTRY_PROPRETORS_1061872627090076302)],
        &[(0b10010, &ENTRY_PROPYLITIZATION_13836495940814672284)],
        &[(0b10010, &ENTRY_PROPYLITIZATIONS_7094329496024697216)],
        &[(0b10010, &ENTRY_PROPYLITIZE_11679071963245365055)],
        &[(0b10010, &ENTRY_PROPYLITIZED_8590898197469215076)],
        &[(0b10010, &ENTRY_PROPYLITIZES_1960476382403426175)],
        &[(0b10010, &ENTRY_PROPYLITIZING_1919046230221160069)],
        &[(0b01001, &ENTRY_PROPYLITIZATION_13836495940814672284)],
        &[(0b01001, &ENTRY_PROPYLITIZATIONS_7094329496024697216)],
        &[(0b01001, &ENTRY_PROPYLITIZE_11679071963245365055)],
        &[(0b01001, &ENTRY_PROPYLITIZED_8590898197469215076)],
        &[(0b01001, &ENTRY_PROPYLITIZES_1960476382403426175)],
        &[(0b01001, &ENTRY_PROPYLITIZING_1919046230221160069)],
    ],
    range: 5..=12,
};

static VARS_PROO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROO_CHILDREN),
    value: None,
};

pub static VARS_PROO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("emium")],
    values: &[&[(0b11010, &ENTRY_PROEMIUM_11682631817645057378)]],
    range: 5..=5,
};

static VARS_PRON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRON_CHILDREN),
    value: None,
};

pub static VARS_PRON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ominalisation"),
        dictgen::InsensitiveStr::Ascii("ominalise"),
        dictgen::InsensitiveStr::Ascii("ominalization"),
        dictgen::InsensitiveStr::Ascii("ominalize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRONOMINALIZATION_17724208934767078054)],
        &[(0b10010, &ENTRY_PRONOMINALIZE_3240389965162843516)],
        &[(0b01001, &ENTRY_PRONOMINALIZATION_17724208934767078054)],
        &[(0b01001, &ENTRY_PRONOMINALIZE_3240389965162843516)],
    ],
    range: 9..=13,
};

static VARS_PROL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROL_CHILDREN),
    value: None,
};

pub static VARS_PROL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etarianisation"),
        dictgen::InsensitiveStr::Ascii("etarianisations"),
        dictgen::InsensitiveStr::Ascii("etarianise"),
        dictgen::InsensitiveStr::Ascii("etarianised"),
        dictgen::InsensitiveStr::Ascii("etarianises"),
        dictgen::InsensitiveStr::Ascii("etarianising"),
        dictgen::InsensitiveStr::Ascii("etarianization"),
        dictgen::InsensitiveStr::Ascii("etarianizations"),
        dictgen::InsensitiveStr::Ascii("etarianize"),
        dictgen::InsensitiveStr::Ascii("etarianized"),
        dictgen::InsensitiveStr::Ascii("etarianizes"),
        dictgen::InsensitiveStr::Ascii("etarianizing"),
        dictgen::InsensitiveStr::Ascii("etarise"),
        dictgen::InsensitiveStr::Ascii("etarised"),
        dictgen::InsensitiveStr::Ascii("etarising"),
        dictgen::InsensitiveStr::Ascii("etarize"),
        dictgen::InsensitiveStr::Ascii("etarized"),
        dictgen::InsensitiveStr::Ascii("etarizing"),
        dictgen::InsensitiveStr::Ascii("og"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ogs"),
        dictgen::InsensitiveStr::Ascii("oguise"),
        dictgen::InsensitiveStr::Ascii("oguised"),
        dictgen::InsensitiveStr::Ascii("oguiser"),
        dictgen::InsensitiveStr::Ascii("oguisers"),
        dictgen::InsensitiveStr::Ascii("oguises"),
        dictgen::InsensitiveStr::Ascii("oguising"),
        dictgen::InsensitiveStr::Ascii("oguize"),
        dictgen::InsensitiveStr::Ascii("oguized"),
        dictgen::InsensitiveStr::Ascii("oguizer"),
        dictgen::InsensitiveStr::Ascii("oguizers"),
        dictgen::InsensitiveStr::Ascii("oguizes"),
        dictgen::InsensitiveStr::Ascii("oguizing"),
        dictgen::InsensitiveStr::Ascii("usionise"),
        dictgen::InsensitiveStr::Ascii("usionises"),
        dictgen::InsensitiveStr::Ascii("usionize"),
        dictgen::InsensitiveStr::Ascii("usionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROLETARIANIZATION_13313275210976607060)],
        &[(0b10010, &ENTRY_PROLETARIANIZATIONS_18153332863179741779)],
        &[(0b10010, &ENTRY_PROLETARIANIZE_10306000725556427592)],
        &[(0b10010, &ENTRY_PROLETARIANIZED_5537836316707945052)],
        &[(0b10010, &ENTRY_PROLETARIANIZES_3808504865584636556)],
        &[(0b10010, &ENTRY_PROLETARIANIZING_14033305622778298474)],
        &[(0b01001, &ENTRY_PROLETARIANIZATION_13313275210976607060)],
        &[(0b01001, &ENTRY_PROLETARIANIZATIONS_18153332863179741779)],
        &[(0b01001, &ENTRY_PROLETARIANIZE_10306000725556427592)],
        &[(0b01001, &ENTRY_PROLETARIANIZED_5537836316707945052)],
        &[(0b01001, &ENTRY_PROLETARIANIZES_3808504865584636556)],
        &[(0b01001, &ENTRY_PROLETARIANIZING_14033305622778298474)],
        &[(0b10010, &ENTRY_PROLETARIZE_7658575278102132004)],
        &[(0b10010, &ENTRY_PROLETARIZED_10377426615142966996)],
        &[(0b10010, &ENTRY_PROLETARIZING_7622597255202403783)],
        &[(0b01001, &ENTRY_PROLETARIZE_7658575278102132004)],
        &[(0b01001, &ENTRY_PROLETARIZED_10377426615142966996)],
        &[(0b01001, &ENTRY_PROLETARIZING_7622597255202403783)],
        &[(0b00001, &ENTRY_PROLOGUE_17671930941462455526)],
        &[(0b10010, &ENTRY_PROLOGIZE_15505078668032774171)],
        &[(0b10010, &ENTRY_PROLOGIZED_3624222185686090329)],
        &[(0b10010, &ENTRY_PROLOGIZES_12046698321881734610)],
        &[(0b10010, &ENTRY_PROLOGIZING_18036732420796600279)],
        &[(0b01001, &ENTRY_PROLOGIZE_15505078668032774171)],
        &[(0b01001, &ENTRY_PROLOGIZED_3624222185686090329)],
        &[(0b01001, &ENTRY_PROLOGIZES_12046698321881734610)],
        &[(0b01001, &ENTRY_PROLOGIZING_18036732420796600279)],
        &[(0b00001, &ENTRY_PROLOGUES_9340649334758661479)],
        &[(0b10010, &ENTRY_PROLOGUIZE_11510955088004134734)],
        &[(0b10010, &ENTRY_PROLOGUIZED_3253550402486536987)],
        &[(0b10010, &ENTRY_PROLOGUIZER_11977593482018675531)],
        &[(0b10010, &ENTRY_PROLOGUIZERS_2076286811253592679)],
        &[(0b10010, &ENTRY_PROLOGUIZES_3296728645194085464)],
        &[(0b10010, &ENTRY_PROLOGUIZING_3954350899886287768)],
        &[(0b01001, &ENTRY_PROLOGUIZE_11510955088004134734)],
        &[(0b01001, &ENTRY_PROLOGUIZED_3253550402486536987)],
        &[(0b01001, &ENTRY_PROLOGUIZER_11977593482018675531)],
        &[(0b01001, &ENTRY_PROLOGUIZERS_2076286811253592679)],
        &[(0b01001, &ENTRY_PROLOGUIZES_3296728645194085464)],
        &[(0b01001, &ENTRY_PROLOGUIZING_3954350899886287768)],
        &[(0b10010, &ENTRY_PROLUSIONIZE_16730185172419057812)],
        &[(0b10010, &ENTRY_PROLUSIONIZES_17256356705404835970)],
        &[(0b01001, &ENTRY_PROLUSIONIZE_16730185172419057812)],
        &[(0b01001, &ENTRY_PROLUSIONIZES_17256356705404835970)],
    ],
    range: 2..=15,
};

static VARS_PROJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROJ_CHILDREN),
    value: None,
};

pub static VARS_PROJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectisation"),
        dictgen::InsensitiveStr::Ascii("ectisations"),
        dictgen::InsensitiveStr::Ascii("ectization"),
        dictgen::InsensitiveStr::Ascii("ectizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROJECTIZATION_8930022185867417632)],
        &[(0b10010, &ENTRY_PROJECTIZATIONS_11440603583583794637)],
        &[(0b01001, &ENTRY_PROJECTIZATION_8930022185867417632)],
        &[(0b01001, &ENTRY_PROJECTIZATIONS_11440603583583794637)],
    ],
    range: 10..=11,
};

static VARS_PROI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROI_CHILDREN),
    value: None,
};

pub static VARS_PROI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROINDUSTRIALIZATION_15813974036579142612)],
        &[(0b01001, &ENTRY_PROINDUSTRIALIZATION_15813974036579142612)],
    ],
    range: 16..=16,
};

static VARS_PROG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROG_CHILDREN),
    value: None,
};

pub static VARS_PROG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ramed"),
        dictgen::InsensitiveStr::Ascii("ramer"),
        dictgen::InsensitiveStr::Ascii("ramers"),
        dictgen::InsensitiveStr::Ascii("raming"),
        dictgen::InsensitiveStr::Ascii("ramme"),
        dictgen::InsensitiveStr::Ascii("rammes"),
    ],
    values: &[
        &[
            (0b00001, &ENTRY_PROGRAMMED_15849257509422591276),
            (0b00001, &ENTRY_PROGRAMMED_3055388991746463602),
        ],
        &[(0b00001, &ENTRY_PROGRAMMER_12330374135731657861)],
        &[(0b00001, &ENTRY_PROGRAMMERS_4515854859838156319)],
        &[
            (0b00001, &ENTRY_PROGRAMMING_13190911417711133911),
            (0b00001, &ENTRY_PROGRAMMING_9724385457632698919),
        ],
        &[
            (0b10010, &ENTRY_PROGRAM_1168207610116917818),
            (0b10011, &ENTRY_PROGRAM_15467367788727504514),
        ],
        &[
            (0b10011, &ENTRY_PROGRAMS_11792468001587502418),
            (0b10010, &ENTRY_PROGRAMS_8949972925814469251),
        ],
    ],
    range: 5..=6,
};

static VARS_PROF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROF_CHILDREN),
    value: None,
};

pub static VARS_PROF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("essionalisation"),
        dictgen::InsensitiveStr::Ascii("essionalisations"),
        dictgen::InsensitiveStr::Ascii("essionalise"),
        dictgen::InsensitiveStr::Ascii("essionalised"),
        dictgen::InsensitiveStr::Ascii("essionalises"),
        dictgen::InsensitiveStr::Ascii("essionalising"),
        dictgen::InsensitiveStr::Ascii("essionalization"),
        dictgen::InsensitiveStr::Ascii("essionalizations"),
        dictgen::InsensitiveStr::Ascii("essionalize"),
        dictgen::InsensitiveStr::Ascii("essionalized"),
        dictgen::InsensitiveStr::Ascii("essionalizes"),
        dictgen::InsensitiveStr::Ascii("essionalizing"),
        dictgen::InsensitiveStr::Ascii("essionise"),
        dictgen::InsensitiveStr::Ascii("essionises"),
        dictgen::InsensitiveStr::Ascii("essionize"),
        dictgen::InsensitiveStr::Ascii("essionizes"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROFANIZE_12830076681879400499)],
        &[(0b10010, &ENTRY_PROFANIZES_15276099779609209125)],
        &[(0b01001, &ENTRY_PROFANIZE_12830076681879400499)],
        &[(0b01001, &ENTRY_PROFANIZES_15276099779609209125)],
        &[(0b00001, &ENTRY_PROFER_10895731134357597757)],
        &[(0b10010, &ENTRY_PROFESSIONALIZATION_17530475144205441796)],
        &[(0b10010, &ENTRY_PROFESSIONALIZATIONS_820894818241176416)],
        &[(0b10010, &ENTRY_PROFESSIONALIZE_6867732579804889823)],
        &[(0b10010, &ENTRY_PROFESSIONALIZED_12953071907076905796)],
        &[(0b10010, &ENTRY_PROFESSIONALIZES_13019583386600406552)],
        &[(0b10010, &ENTRY_PROFESSIONALIZING_7693734081343569569)],
        &[(0b01001, &ENTRY_PROFESSIONALIZATION_17530475144205441796)],
        &[(0b01001, &ENTRY_PROFESSIONALIZATIONS_820894818241176416)],
        &[(0b01001, &ENTRY_PROFESSIONALIZE_6867732579804889823)],
        &[(0b01001, &ENTRY_PROFESSIONALIZED_12953071907076905796)],
        &[(0b01001, &ENTRY_PROFESSIONALIZES_13019583386600406552)],
        &[(0b01001, &ENTRY_PROFESSIONALIZING_7693734081343569569)],
        &[(0b10010, &ENTRY_PROFESSIONIZE_13454304658050553817)],
        &[(0b10010, &ENTRY_PROFESSIONIZES_7991571007403712278)],
        &[(0b01001, &ENTRY_PROFESSIONIZE_13454304658050553817)],
        &[(0b01001, &ENTRY_PROFESSIONIZES_7991571007403712278)],
        &[(0b11010, &ENTRY_PROFER_10895731134357597757)],
    ],
    range: 2..=16,
};

static VARS_PROE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROE_CHILDREN),
    value: None,
};

pub static VARS_PROE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mial"),
        dictgen::InsensitiveStr::Ascii("mium"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PREMIAL_17144185719904663728)],
        &[(0b00001, &ENTRY_PROEMIUM_11682631817645057378)],
    ],
    range: 4..=4,
};

static VARS_PROD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROD_CHILDREN),
    value: None,
};

pub static VARS_PROD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("igalise"),
        dictgen::InsensitiveStr::Ascii("igalised"),
        dictgen::InsensitiveStr::Ascii("igalises"),
        dictgen::InsensitiveStr::Ascii("igalising"),
        dictgen::InsensitiveStr::Ascii("igalize"),
        dictgen::InsensitiveStr::Ascii("igalized"),
        dictgen::InsensitiveStr::Ascii("igalizes"),
        dictgen::InsensitiveStr::Ascii("igalizing"),
        dictgen::InsensitiveStr::Ascii("uctise"),
        dictgen::InsensitiveStr::Ascii("uctised"),
        dictgen::InsensitiveStr::Ascii("uctiser"),
        dictgen::InsensitiveStr::Ascii("uctisers"),
        dictgen::InsensitiveStr::Ascii("uctises"),
        dictgen::InsensitiveStr::Ascii("uctising"),
        dictgen::InsensitiveStr::Ascii("uctize"),
        dictgen::InsensitiveStr::Ascii("uctized"),
        dictgen::InsensitiveStr::Ascii("uctizer"),
        dictgen::InsensitiveStr::Ascii("uctizers"),
        dictgen::InsensitiveStr::Ascii("uctizes"),
        dictgen::InsensitiveStr::Ascii("uctizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRODIGALIZE_12533163844995161541)],
        &[(0b10010, &ENTRY_PRODIGALIZED_3428487070963375705)],
        &[(0b10010, &ENTRY_PRODIGALIZES_14628265773798361699)],
        &[(0b10010, &ENTRY_PRODIGALIZING_14011101052657811503)],
        &[(0b01001, &ENTRY_PRODIGALIZE_12533163844995161541)],
        &[(0b01001, &ENTRY_PRODIGALIZED_3428487070963375705)],
        &[(0b01001, &ENTRY_PRODIGALIZES_14628265773798361699)],
        &[(0b01001, &ENTRY_PRODIGALIZING_14011101052657811503)],
        &[(0b10010, &ENTRY_PRODUCTIZE_355214308695677973)],
        &[(0b10010, &ENTRY_PRODUCTIZED_10091772006605087705)],
        &[(0b10010, &ENTRY_PRODUCTIZER_743913279002903740)],
        &[(0b10010, &ENTRY_PRODUCTIZERS_7546776594887641211)],
        &[(0b10010, &ENTRY_PRODUCTIZES_15067875440491410917)],
        &[(0b10010, &ENTRY_PRODUCTIZING_14463995875743510428)],
        &[(0b01001, &ENTRY_PRODUCTIZE_355214308695677973)],
        &[(0b01001, &ENTRY_PRODUCTIZED_10091772006605087705)],
        &[(0b01001, &ENTRY_PRODUCTIZER_743913279002903740)],
        &[(0b01001, &ENTRY_PRODUCTIZERS_7546776594887641211)],
        &[(0b01001, &ENTRY_PRODUCTIZES_15067875440491410917)],
        &[(0b01001, &ENTRY_PRODUCTIZING_14463995875743510428)],
    ],
    range: 6..=9,
};

static VARS_PROC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROC_CHILDREN),
    value: None,
};

pub static VARS_PROC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("essionise"),
        dictgen::InsensitiveStr::Ascii("essionises"),
        dictgen::InsensitiveStr::Ascii("essionize"),
        dictgen::InsensitiveStr::Ascii("essionizes"),
        dictgen::InsensitiveStr::Ascii("rusteanise"),
        dictgen::InsensitiveStr::Ascii("rusteanises"),
        dictgen::InsensitiveStr::Ascii("rusteanize"),
        dictgen::InsensitiveStr::Ascii("rusteanizes"),
        dictgen::InsensitiveStr::Ascii("todaea"),
        dictgen::InsensitiveStr::Ascii("todaeal"),
        dictgen::InsensitiveStr::Ascii("todaeum"),
        dictgen::InsensitiveStr::Ascii("todaeums"),
        dictgen::InsensitiveStr::Ascii("todea"),
        dictgen::InsensitiveStr::Ascii("todeal"),
        dictgen::InsensitiveStr::Ascii("todeum"),
        dictgen::InsensitiveStr::Ascii("todeums"),
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torising"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("torizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROCESSIONIZE_7433283850303828458)],
        &[(0b10010, &ENTRY_PROCESSIONIZES_13973102018086646225)],
        &[(0b01001, &ENTRY_PROCESSIONIZE_7433283850303828458)],
        &[(0b01001, &ENTRY_PROCESSIONIZES_13973102018086646225)],
        &[(0b10010, &ENTRY_PROCRUSTEANIZE_744493252621097169)],
        &[(0b10010, &ENTRY_PROCRUSTEANIZES_16493517354618629803)],
        &[(0b01001, &ENTRY_PROCRUSTEANIZE_744493252621097169)],
        &[(0b01001, &ENTRY_PROCRUSTEANIZES_16493517354618629803)],
        &[(0b11010, &ENTRY_PROCTODEA_7394203941595428980)],
        &[(0b11010, &ENTRY_PROCTODEAL_4699518537214479716)],
        &[(0b11010, &ENTRY_PROCTODEUM_12835100775651605738)],
        &[(0b11010, &ENTRY_PROCTODEUMS_7965990816311016504)],
        &[(0b00001, &ENTRY_PROCTODEA_7394203941595428980)],
        &[(0b00001, &ENTRY_PROCTODEAL_4699518537214479716)],
        &[(0b00001, &ENTRY_PROCTODEUM_12835100775651605738)],
        &[(0b00001, &ENTRY_PROCTODEUMS_7965990816311016504)],
        &[(0b10010, &ENTRY_PROCTORIZATION_10856447202079910826)],
        &[(0b10010, &ENTRY_PROCTORIZATIONS_16880863477174659915)],
        &[(0b10010, &ENTRY_PROCTORIZE_2264104820190419500)],
        &[(0b10010, &ENTRY_PROCTORIZED_2668674070254259488)],
        &[(0b10010, &ENTRY_PROCTORIZES_5348616729395822128)],
        &[(0b10010, &ENTRY_PROCTORIZING_12194166959190016917)],
        &[(0b01001, &ENTRY_PROCTORIZATION_10856447202079910826)],
        &[(0b01001, &ENTRY_PROCTORIZATIONS_16880863477174659915)],
        &[(0b01001, &ENTRY_PROCTORIZE_2264104820190419500)],
        &[(0b01001, &ENTRY_PROCTORIZED_2668674070254259488)],
        &[(0b01001, &ENTRY_PROCTORIZES_5348616729395822128)],
        &[(0b01001, &ENTRY_PROCTORIZING_12194166959190016917)],
    ],
    range: 5..=11,
};

static VARS_PROB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROB_CHILDREN),
    value: None,
};

pub static VARS_PROB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lemise"),
        dictgen::InsensitiveStr::Ascii("lemises"),
        dictgen::InsensitiveStr::Ascii("lemize"),
        dictgen::InsensitiveStr::Ascii("lemizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROBLEMIZE_3733154693918512723)],
        &[(0b10010, &ENTRY_PROBLEMIZES_16167676205731844544)],
        &[(0b01001, &ENTRY_PROBLEMIZE_3733154693918512723)],
        &[(0b01001, &ENTRY_PROBLEMIZES_16167676205731844544)],
    ],
    range: 6..=7,
};

static VARS_PROA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PROA_CHILDREN),
    value: None,
};

pub static VARS_PROA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dvertising"),
        dictgen::InsensitiveStr::Ascii("dvertizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PROADVERTIZING_11854284288281126528)],
        &[(0b01001, &ENTRY_PROADVERTIZING_11854284288281126528)],
    ],
    range: 10..=10,
};

static VARS_PRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRI_CHILDREN),
    value: None,
};

pub static VARS_PRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maeval"),
        dictgen::InsensitiveStr::Ascii("maevally"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("oritisation"),
        dictgen::InsensitiveStr::Ascii("oritisations"),
        dictgen::InsensitiveStr::Ascii("oritise"),
        dictgen::InsensitiveStr::Ascii("oritised"),
        dictgen::InsensitiveStr::Ascii("oritiser"),
        dictgen::InsensitiveStr::Ascii("oritisers"),
        dictgen::InsensitiveStr::Ascii("oritises"),
        dictgen::InsensitiveStr::Ascii("oritising"),
        dictgen::InsensitiveStr::Ascii("oritisings"),
        dictgen::InsensitiveStr::Ascii("oritization"),
        dictgen::InsensitiveStr::Ascii("oritizations"),
        dictgen::InsensitiveStr::Ascii("oritize"),
        dictgen::InsensitiveStr::Ascii("oritized"),
        dictgen::InsensitiveStr::Ascii("oritizer"),
        dictgen::InsensitiveStr::Ascii("oritizers"),
        dictgen::InsensitiveStr::Ascii("oritizes"),
        dictgen::InsensitiveStr::Ascii("oritizing"),
        dictgen::InsensitiveStr::Ascii("oritizings"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("sable"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sed"),
        dictgen::InsensitiveStr::Ascii("ser"),
        dictgen::InsensitiveStr::Ascii("sers"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("sing"),
        dictgen::InsensitiveStr::Ascii("vatisation"),
        dictgen::InsensitiveStr::Ascii("vatisations"),
        dictgen::InsensitiveStr::Ascii("vatise"),
        dictgen::InsensitiveStr::Ascii("vatised"),
        dictgen::InsensitiveStr::Ascii("vatiser"),
        dictgen::InsensitiveStr::Ascii("vatisers"),
        dictgen::InsensitiveStr::Ascii("vatises"),
        dictgen::InsensitiveStr::Ascii("vatising"),
        dictgen::InsensitiveStr::Ascii("vatization"),
        dictgen::InsensitiveStr::Ascii("vatizations"),
        dictgen::InsensitiveStr::Ascii("vatize"),
        dictgen::InsensitiveStr::Ascii("vatized"),
        dictgen::InsensitiveStr::Ascii("vatizer"),
        dictgen::InsensitiveStr::Ascii("vatizers"),
        dictgen::InsensitiveStr::Ascii("vatizes"),
        dictgen::InsensitiveStr::Ascii("vatizing"),
        dictgen::InsensitiveStr::Ascii("zable"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PRIMEVAL_14403698219446531068)],
        &[(0b11010, &ENTRY_PRIMEVALLY_2674971179088086646)],
        &[(0b10010, &ENTRY_PRIORIZATION_15831247715416791292)],
        &[(0b10010, &ENTRY_PRIORIZATIONS_7395933477241911403)],
        &[(0b10010, &ENTRY_PRIORIZE_4435503407458868165)],
        &[(0b10010, &ENTRY_PRIORIZED_986408301813837211)],
        &[(0b10010, &ENTRY_PRIORIZES_9591483062801861397)],
        &[(0b10010, &ENTRY_PRIORIZING_9325893624043708471)],
        &[(0b10010, &ENTRY_PRIORITIZATION_10049497275055472359)],
        &[(0b10010, &ENTRY_PRIORITIZATIONS_6646156489290472561)],
        &[(0b10010, &ENTRY_PRIORITIZE_6692938915255740696)],
        &[(0b10010, &ENTRY_PRIORITIZED_18023070841869180732)],
        &[(0b10010, &ENTRY_PRIORITIZER_6938111019701759275)],
        &[(0b10010, &ENTRY_PRIORITIZERS_16197836004941116010)],
        &[(0b10010, &ENTRY_PRIORITIZES_11503923781258978352)],
        &[(0b10010, &ENTRY_PRIORITIZING_1918447248395854235)],
        &[(0b10010, &ENTRY_PRIORITIZINGS_4795506597517888826)],
        &[(0b01001, &ENTRY_PRIORITIZATION_10049497275055472359)],
        &[(0b01001, &ENTRY_PRIORITIZATIONS_6646156489290472561)],
        &[(0b01001, &ENTRY_PRIORITIZE_6692938915255740696)],
        &[(0b01001, &ENTRY_PRIORITIZED_18023070841869180732)],
        &[(0b01001, &ENTRY_PRIORITIZER_6938111019701759275)],
        &[(0b01001, &ENTRY_PRIORITIZERS_16197836004941116010)],
        &[(0b01001, &ENTRY_PRIORITIZES_11503923781258978352)],
        &[(0b01001, &ENTRY_PRIORITIZING_1918447248395854235)],
        &[(0b01001, &ENTRY_PRIORITIZINGS_4795506597517888826)],
        &[(0b01001, &ENTRY_PRIORIZATION_15831247715416791292)],
        &[(0b01001, &ENTRY_PRIORIZATIONS_7395933477241911403)],
        &[(0b01001, &ENTRY_PRIORIZE_4435503407458868165)],
        &[(0b01001, &ENTRY_PRIORIZED_986408301813837211)],
        &[(0b01001, &ENTRY_PRIORIZES_9591483062801861397)],
        &[(0b01001, &ENTRY_PRIORIZING_9325893624043708471)],
        &[(0b10010, &ENTRY_PRIZABLE_8782369217264532396)],
        &[(0b10010, &ENTRY_PRIZE_9161502193249494227)],
        &[(0b10010, &ENTRY_PRIZED_5215566249205572067)],
        &[(0b10010, &ENTRY_PRIZER_2531822262597590420)],
        &[(0b10010, &ENTRY_PRIZERS_17915377328744820091)],
        &[(0b10010, &ENTRY_PRIZES_15467106908555365225)],
        &[(0b10010, &ENTRY_PRIZING_5227861388750045611)],
        &[(0b10010, &ENTRY_PRIVATIZATION_13261595712696321543)],
        &[(0b10010, &ENTRY_PRIVATIZATIONS_14900435995228716791)],
        &[(0b10010, &ENTRY_PRIVATIZE_15602436903519402958)],
        &[(0b10010, &ENTRY_PRIVATIZED_18440711924740318570)],
        &[(0b10010, &ENTRY_PRIVATIZER_5363515162384255634)],
        &[(0b10010, &ENTRY_PRIVATIZERS_4935862002795256053)],
        &[(0b10010, &ENTRY_PRIVATIZES_13414685946229171001)],
        &[(0b10010, &ENTRY_PRIVATIZING_12559648713578210369)],
        &[(0b01001, &ENTRY_PRIVATIZATION_13261595712696321543)],
        &[(0b01001, &ENTRY_PRIVATIZATIONS_14900435995228716791)],
        &[(0b01001, &ENTRY_PRIVATIZE_15602436903519402958)],
        &[(0b01001, &ENTRY_PRIVATIZED_18440711924740318570)],
        &[(0b01001, &ENTRY_PRIVATIZER_5363515162384255634)],
        &[(0b01001, &ENTRY_PRIVATIZERS_4935862002795256053)],
        &[(0b01001, &ENTRY_PRIVATIZES_13414685946229171001)],
        &[(0b01001, &ENTRY_PRIVATIZING_12559648713578210369)],
        &[(0b01001, &ENTRY_PRIZABLE_8782369217264532396)],
    ],
    range: 2..=12,
};

static VARS_PRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PRE_CHILDREN),
    value: None,
};

static VARS_PRE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PREA_NODE),
    Some(&VARS_PREB_NODE),
    Some(&VARS_PREC_NODE),
    Some(&VARS_PRED_NODE),
    Some(&VARS_PREE_NODE),
    Some(&VARS_PREF_NODE),
    Some(&VARS_PREG_NODE),
    Some(&VARS_PREH_NODE),
    Some(&VARS_PREI_NODE),
    Some(&VARS_PREJ_NODE),
    None,
    Some(&VARS_PREL_NODE),
    Some(&VARS_PREM_NODE),
    Some(&VARS_PREN_NODE),
    Some(&VARS_PREO_NODE),
    Some(&VARS_PREP_NODE),
    None,
    Some(&VARS_PRER_NODE),
    Some(&VARS_PRES_NODE),
    Some(&VARS_PRET_NODE),
    Some(&VARS_PREU_NODE),
    Some(&VARS_PREV_NODE),
    None,
    None,
    None,
    Some(&VARS_PREZ_NODE),
];

static VARS_PREZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREZ_CHILDREN),
    value: None,
};

pub static VARS_PREZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ygapophysis")],
    values: &[&[(0b00001, &ENTRY_PREZYGAPOPHYSIS_14960217627658149191)]],
    range: 11..=11,
};

static VARS_PREV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREV_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_PERV_1140727827150260852)]),
};

pub static VARS_PREV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("iable"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("iousness"),
        dictgen::InsensitiveStr::Ascii("iousnesses"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ue"),
        dictgen::InsensitiveStr::Ascii("ues"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERVE_18165674324823475517)],
        &[(0b11010, &ENTRY_PERVED_18208319127618556214)],
        &[(0b11010, &ENTRY_PERVES_5996851197956304566)],
        &[(0b11010, &ENTRY_PERVIABLE_4699952660241611906)],
        &[(0b11010, &ENTRY_PERVING_12586188415039019252)],
        &[(0b11010, &ENTRY_PERVIOUSNESS_4962441648916650935)],
        &[(0b11010, &ENTRY_PERVIOUSNESSES_15261112133254148006)],
        &[(0b10010, &ENTRY_PREVIZE_17807664688989533725)],
        &[(0b01001, &ENTRY_PREVIZE_17807664688989533725)],
        &[(0b00001, &ENTRY_PREVIEW_17926315694824576755)],
        &[(0b00001, &ENTRY_PREVIEWS_1728617467859287905)],
    ],
    range: 1..=10,
};

static VARS_PREU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREU_CHILDREN),
    value: None,
};

pub static VARS_PREU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilisable"),
        dictgen::InsensitiveStr::Ascii("tilisables"),
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilisations"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilizable"),
        dictgen::InsensitiveStr::Ascii("tilizables"),
        dictgen::InsensitiveStr::Ascii("tilization"),
        dictgen::InsensitiveStr::Ascii("tilizations"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREUTILIZABLE_13773594832026128190)],
        &[(0b10010, &ENTRY_PREUTILIZABLES_16060283126975272357)],
        &[(0b10010, &ENTRY_PREUTILIZATION_4481094491629481493)],
        &[(0b10010, &ENTRY_PREUTILIZATIONS_15650215591627789397)],
        &[(0b10010, &ENTRY_PREUTILIZE_2615669183062771932)],
        &[(0b10010, &ENTRY_PREUTILIZES_9219722857883342032)],
        &[(0b01001, &ENTRY_PREUTILIZABLE_13773594832026128190)],
        &[(0b01001, &ENTRY_PREUTILIZABLES_16060283126975272357)],
        &[(0b01001, &ENTRY_PREUTILIZATION_4481094491629481493)],
        &[(0b01001, &ENTRY_PREUTILIZATIONS_15650215591627789397)],
        &[(0b01001, &ENTRY_PREUTILIZE_2615669183062771932)],
        &[(0b01001, &ENTRY_PREUTILIZES_9219722857883342032)],
    ],
    range: 6..=11,
};

static VARS_PRET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRET_CHILDREN),
    value: None,
};

pub static VARS_PRET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("axation"),
        dictgen::InsensitiveStr::Ascii("ence"),
        dictgen::InsensitiveStr::Ascii("ences"),
        dictgen::InsensitiveStr::Ascii("encive"),
        dictgen::InsensitiveStr::Ascii("ense"),
        dictgen::InsensitiveStr::Ascii("enses"),
        dictgen::InsensitiveStr::Ascii("ensive"),
        dictgen::InsensitiveStr::Ascii("erit"),
        dictgen::InsensitiveStr::Ascii("erits"),
        dictgen::InsensitiveStr::Ascii("exta"),
        dictgen::InsensitiveStr::Ascii("extae"),
        dictgen::InsensitiveStr::Ascii("orial"),
        dictgen::InsensitiveStr::Ascii("orians"),
        dictgen::InsensitiveStr::Ascii("orium"),
        dictgen::InsensitiveStr::Ascii("orius"),
        dictgen::InsensitiveStr::Ascii("orship"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRETAXATION_16254819888221291653)],
        &[(0b11010, &ENTRY_PRETENSE_1806063105069921307)],
        &[(0b11010, &ENTRY_PRETENSES_15397156974880122447)],
        &[(0b11010, &ENTRY_PRETENSIVE_6141437866379382582)],
        &[(0b01001, &ENTRY_PRETENSE_1806063105069921307)],
        &[(0b01001, &ENTRY_PRETENSES_15397156974880122447)],
        &[(0b00001, &ENTRY_PRETENSIVE_6141437866379382582)],
        &[(0b01001, &ENTRY_PRETERIT_6327351993261882986)],
        &[(0b01001, &ENTRY_PRETERITS_3983698582275509615)],
        &[(0b00001, &ENTRY_PRETEXTA_322521945222134396)],
        &[(0b00001, &ENTRY_PRETEXTAE_16184667912878448094)],
        &[(0b00001, &ENTRY_PRETORIAL_7197260765783954402)],
        &[(0b00001, &ENTRY_PRETORIANS_5321413914837421784)],
        &[(0b00001, &ENTRY_PRETORIUM_1712722934465958271)],
        &[(0b00001, &ENTRY_PRETORIUS_278833463846710853)],
        &[(0b00001, &ENTRY_PRETORSHIP_298144548841059349)],
    ],
    range: 4..=7,
};

static VARS_PRES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRES_CHILDREN),
    value: None,
};

pub static VARS_PRES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("byterianise"),
        dictgen::InsensitiveStr::Ascii("byterianised"),
        dictgen::InsensitiveStr::Ascii("byterianises"),
        dictgen::InsensitiveStr::Ascii("byterianising"),
        dictgen::InsensitiveStr::Ascii("byterianize"),
        dictgen::InsensitiveStr::Ascii("byterianized"),
        dictgen::InsensitiveStr::Ascii("byterianizes"),
        dictgen::InsensitiveStr::Ascii("byterianizing"),
        dictgen::InsensitiveStr::Ascii("cutum"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("idia"),
        dictgen::InsensitiveStr::Ascii("olve"),
        dictgen::InsensitiveStr::Ascii("pecialise"),
        dictgen::InsensitiveStr::Ascii("pecialises"),
        dictgen::InsensitiveStr::Ascii("pecialize"),
        dictgen::InsensitiveStr::Ascii("pecializes"),
        dictgen::InsensitiveStr::Ascii("phenoid"),
        dictgen::InsensitiveStr::Ascii("plendor"),
        dictgen::InsensitiveStr::Ascii("plendors"),
        dictgen::InsensitiveStr::Ascii("plendour"),
        dictgen::InsensitiveStr::Ascii("plendours"),
        dictgen::InsensitiveStr::Ascii("surisation"),
        dictgen::InsensitiveStr::Ascii("surisations"),
        dictgen::InsensitiveStr::Ascii("surise"),
        dictgen::InsensitiveStr::Ascii("surised"),
        dictgen::InsensitiveStr::Ascii("suriser"),
        dictgen::InsensitiveStr::Ascii("surisers"),
        dictgen::InsensitiveStr::Ascii("surises"),
        dictgen::InsensitiveStr::Ascii("surising"),
        dictgen::InsensitiveStr::Ascii("surization"),
        dictgen::InsensitiveStr::Ascii("surizations"),
        dictgen::InsensitiveStr::Ascii("surize"),
        dictgen::InsensitiveStr::Ascii("surized"),
        dictgen::InsensitiveStr::Ascii("surizer"),
        dictgen::InsensitiveStr::Ascii("surizers"),
        dictgen::InsensitiveStr::Ascii("surizes"),
        dictgen::InsensitiveStr::Ascii("surizing"),
        dictgen::InsensitiveStr::Ascii("t"),
        dictgen::InsensitiveStr::Ascii("tandardisation"),
        dictgen::InsensitiveStr::Ascii("tandardisations"),
        dictgen::InsensitiveStr::Ascii("tandardise"),
        dictgen::InsensitiveStr::Ascii("tandardises"),
        dictgen::InsensitiveStr::Ascii("tandardization"),
        dictgen::InsensitiveStr::Ascii("tandardizations"),
        dictgen::InsensitiveStr::Ascii("tandardize"),
        dictgen::InsensitiveStr::Ascii("tandardizes"),
        dictgen::InsensitiveStr::Ascii("ternal"),
        dictgen::InsensitiveStr::Ascii("ternum"),
        dictgen::InsensitiveStr::Ascii("tomium"),
        dictgen::InsensitiveStr::Ascii("ympathise"),
        dictgen::InsensitiveStr::Ascii("ympathises"),
        dictgen::InsensitiveStr::Ascii("ympathize"),
        dictgen::InsensitiveStr::Ascii("ympathizes"),
        dictgen::InsensitiveStr::Ascii("ystolic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRESBYTERIANIZE_8184517241649663285)],
        &[(0b10010, &ENTRY_PRESBYTERIANIZED_5190559539797332403)],
        &[(0b10010, &ENTRY_PRESBYTERIANIZES_8616191738584033370)],
        &[(0b10010, &ENTRY_PRESBYTERIANIZING_11910404725477468034)],
        &[(0b01001, &ENTRY_PRESBYTERIANIZE_8184517241649663285)],
        &[(0b01001, &ENTRY_PRESBYTERIANIZED_5190559539797332403)],
        &[(0b01001, &ENTRY_PRESBYTERIANIZES_8616191738584033370)],
        &[(0b01001, &ENTRY_PRESBYTERIANIZING_11910404725477468034)],
        &[(0b00001, &ENTRY_PRESCUTUM_17649301303017684495)],
        &[(0b11010, &ENTRY_PERSE_2874440396224431051)],
        &[(0b00001, &ENTRY_PRESIDIUMS_9456994175801399467)],
        &[(0b11010, &ENTRY_PERSOLVE_11803654124888842880)],
        &[(0b10010, &ENTRY_PRESPECIALIZE_5200997299409119252)],
        &[(0b10010, &ENTRY_PRESPECIALIZES_4338740854406485524)],
        &[(0b01001, &ENTRY_PRESPECIALIZE_5200997299409119252)],
        &[(0b01001, &ENTRY_PRESPECIALIZES_4338740854406485524)],
        &[(0b00001, &ENTRY_PRESPHENOID_4701941519879933792)],
        &[(0b00001, &ENTRY_PRESPLENDOR_14618107087953500253)],
        &[(0b00001, &ENTRY_PRESPLENDORS_7651174344094545694)],
        &[(0b11010, &ENTRY_PRESPLENDOR_14618107087953500253)],
        &[(0b11010, &ENTRY_PRESPLENDORS_7651174344094545694)],
        &[(0b10010, &ENTRY_PRESSURIZATION_4111870375056375369)],
        &[(0b10010, &ENTRY_PRESSURIZATIONS_9413572764001477371)],
        &[(0b10010, &ENTRY_PRESSURIZE_3538034947751085670)],
        &[(0b10010, &ENTRY_PRESSURIZED_5893734113312881931)],
        &[(0b10010, &ENTRY_PRESSURIZER_14526609251745245222)],
        &[(0b10010, &ENTRY_PRESSURIZERS_9860382008246735540)],
        &[(0b10010, &ENTRY_PRESSURIZES_3533546061921034401)],
        &[(0b10010, &ENTRY_PRESSURIZING_920510292816130320)],
        &[(0b01001, &ENTRY_PRESSURIZATION_4111870375056375369)],
        &[(0b01001, &ENTRY_PRESSURIZATIONS_9413572764001477371)],
        &[(0b01001, &ENTRY_PRESSURIZE_3538034947751085670)],
        &[(0b01001, &ENTRY_PRESSURIZED_5893734113312881931)],
        &[(0b01001, &ENTRY_PRESSURIZER_14526609251745245222)],
        &[(0b01001, &ENTRY_PRESSURIZERS_9860382008246735540)],
        &[(0b01001, &ENTRY_PRESSURIZES_3533546061921034401)],
        &[(0b01001, &ENTRY_PRESSURIZING_920510292816130320)],
        &[(0b11010, &ENTRY_PERST_10410873219912667942)],
        &[(0b10010, &ENTRY_PRESTANDARDIZATION_3948421959409387438)],
        &[(0b10010, &ENTRY_PRESTANDARDIZATIONS_5412386093865221649)],
        &[(0b10010, &ENTRY_PRESTANDARDIZE_16454569100293825332)],
        &[(0b10010, &ENTRY_PRESTANDARDIZES_9801992665812395054)],
        &[(0b01001, &ENTRY_PRESTANDARDIZATION_3948421959409387438)],
        &[(0b01001, &ENTRY_PRESTANDARDIZATIONS_5412386093865221649)],
        &[(0b01001, &ENTRY_PRESTANDARDIZE_16454569100293825332)],
        &[(0b01001, &ENTRY_PRESTANDARDIZES_9801992665812395054)],
        &[(0b00001, &ENTRY_PRESTERNAL_3731098073887538850)],
        &[(0b00001, &ENTRY_PRESTERNUM_10191977327812747108)],
        &[(0b00001, &ENTRY_PRESTOMIUM_2175790353005742393)],
        &[(0b10010, &ENTRY_PRESYMPATHIZE_15962690746467493454)],
        &[(0b10010, &ENTRY_PRESYMPATHIZES_2675310532900913878)],
        &[(0b01001, &ENTRY_PRESYMPATHIZE_15962690746467493454)],
        &[(0b01001, &ENTRY_PRESYMPATHIZES_2675310532900913878)],
        &[(0b00001, &ENTRY_PRESYSTOLIC_17980529676890563829)],
    ],
    range: 1..=15,
};

static VARS_PRER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRER_CHILDREN),
    value: None,
};

pub static VARS_PRER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealisation"),
        dictgen::InsensitiveStr::Ascii("ealisations"),
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealization"),
        dictgen::InsensitiveStr::Ascii("ealizations"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
        dictgen::InsensitiveStr::Ascii("ecognise"),
        dictgen::InsensitiveStr::Ascii("ecognises"),
        dictgen::InsensitiveStr::Ascii("ecognize"),
        dictgen::InsensitiveStr::Ascii("ecognizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREREALIZATION_4400758119524381256)],
        &[(0b10010, &ENTRY_PREREALIZATIONS_7749496154695447428)],
        &[(0b10010, &ENTRY_PREREALIZE_10993114358642100374)],
        &[(0b10010, &ENTRY_PREREALIZES_2515206386849164818)],
        &[(0b01001, &ENTRY_PREREALIZATION_4400758119524381256)],
        &[(0b01001, &ENTRY_PREREALIZATIONS_7749496154695447428)],
        &[(0b01001, &ENTRY_PREREALIZE_10993114358642100374)],
        &[(0b01001, &ENTRY_PREREALIZES_2515206386849164818)],
        &[(0b10010, &ENTRY_PRERECOGNIZE_14434517406120082197)],
        &[(0b10010, &ENTRY_PRERECOGNIZES_7610001357511214473)],
        &[(0b01001, &ENTRY_PRERECOGNIZE_14434517406120082197)],
        &[(0b01001, &ENTRY_PRERECOGNIZES_7610001357511214473)],
    ],
    range: 6..=11,
};

static VARS_PREP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREP_CHILDREN),
    value: None,
};

pub static VARS_PREP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alaeolithic"),
        dictgen::InsensitiveStr::Ascii("aleolithic"),
        dictgen::InsensitiveStr::Ascii("end"),
        dictgen::InsensitiveStr::Ascii("ended"),
        dictgen::InsensitiveStr::Ascii("ending"),
        dictgen::InsensitiveStr::Ascii("erfect"),
        dictgen::InsensitiveStr::Ascii("ositor"),
        dictgen::InsensitiveStr::Ascii("ositure"),
        dictgen::InsensitiveStr::Ascii("oster"),
        dictgen::InsensitiveStr::Ascii("ostor"),
        dictgen::InsensitiveStr::Ascii("ostors"),
        dictgen::InsensitiveStr::Ascii("rogram"),
        dictgen::InsensitiveStr::Ascii("rogramme"),
        dictgen::InsensitiveStr::Ascii("ubis"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PREPALEOLITHIC_14202951488126805096)],
        &[(0b00001, &ENTRY_PREPALEOLITHIC_14202951488126805096)],
        &[(0b11010, &ENTRY_PERPEND_7695504195883399642)],
        &[(0b11010, &ENTRY_PERPENDED_14779081215925715227)],
        &[(0b11010, &ENTRY_PERPENDING_9760848409550374555)],
        &[(0b11010, &ENTRY_PERPERFECT_2601720249166533392)],
        &[(0b00001, &ENTRY_PREPOSITOR_12797659440544372540)],
        &[(0b00001, &ENTRY_PREPOSITURE_5966359554589897516)],
        &[(0b00001, &ENTRY_PREPOSTER_9979045838450867710)],
        &[(0b00001, &ENTRY_PREPOSTOR_6334579978765007057)],
        &[(0b00001, &ENTRY_PREPOSTORS_8760995478070950332)],
        &[(0b01001, &ENTRY_PREPROGRAM_182544249377649179)],
        &[(0b10010, &ENTRY_PREPROGRAM_182544249377649179)],
        &[(0b00001, &ENTRY_PREPUBIS_17618648717583634353)],
    ],
    range: 3..=11,
};

static VARS_PREO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREO_CHILDREN),
    value: None,
};

pub static VARS_PREO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esophageal"),
        dictgen::InsensitiveStr::Ascii("ffence"),
        dictgen::InsensitiveStr::Ascii("ffences"),
        dictgen::InsensitiveStr::Ascii("ffense"),
        dictgen::InsensitiveStr::Ascii("ffenses"),
        dictgen::InsensitiveStr::Ascii("perculum"),
        dictgen::InsensitiveStr::Ascii("ral"),
        dictgen::InsensitiveStr::Ascii("rally"),
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
        dictgen::InsensitiveStr::Ascii("tic"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PREESOPHAGEAL_2065887315526261809)],
        &[(0b11010, &ENTRY_PREOFFENSE_11630042685186486975)],
        &[(0b11010, &ENTRY_PREOFFENSES_7584630623721414684)],
        &[(0b00001, &ENTRY_PREOFFENSE_11630042685186486975)],
        &[(0b00001, &ENTRY_PREOFFENSES_7584630623721414684)],
        &[(0b00001, &ENTRY_PREOPERCULUM_4376076836382915800)],
        &[(0b11010, &ENTRY_PERORAL_1577247151206222930)],
        &[(0b11010, &ENTRY_PERORALLY_2346315785712029791)],
        &[(0b10010, &ENTRY_PREORGANIZATION_17672450543180011422)],
        &[(0b10010, &ENTRY_PREORGANIZATIONS_3818715016042200743)],
        &[(0b10010, &ENTRY_PREORGANIZE_15777355745082526626)],
        &[(0b10010, &ENTRY_PREORGANIZES_17328812055563044028)],
        &[(0b01001, &ENTRY_PREORGANIZATION_17672450543180011422)],
        &[(0b01001, &ENTRY_PREORGANIZATIONS_3818715016042200743)],
        &[(0b01001, &ENTRY_PREORGANIZE_15777355745082526626)],
        &[(0b01001, &ENTRY_PREORGANIZES_17328812055563044028)],
        &[(0b11010, &ENTRY_PEROTIC_2582865836237824851)],
        &[(0b10010, &ENTRY_PREOXIDIZE_17502318642758251409)],
        &[(0b10010, &ENTRY_PREOXIDIZED_9338268775141885485)],
        &[(0b10010, &ENTRY_PREOXIDIZES_17578000495699558353)],
        &[(0b10010, &ENTRY_PREOXIDIZING_3438668301704654435)],
        &[(0b01001, &ENTRY_PREOXIDIZE_17502318642758251409)],
        &[(0b01001, &ENTRY_PREOXIDIZED_9338268775141885485)],
        &[(0b01001, &ENTRY_PREOXIDIZES_17578000495699558353)],
        &[(0b01001, &ENTRY_PREOXIDIZING_3438668301704654435)],
    ],
    range: 3..=12,
};

static VARS_PREN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREN_CHILDREN),
    value: None,
};

pub static VARS_PREN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arial"),
        dictgen::InsensitiveStr::Ascii("asal"),
        dictgen::InsensitiveStr::Ascii("eural"),
        dictgen::InsensitiveStr::Ascii("omen"),
        dictgen::InsensitiveStr::Ascii("omens"),
        dictgen::InsensitiveStr::Ascii("omina"),
        dictgen::InsensitiveStr::Ascii("ominal"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRENARIAL_18182351486930830192)],
        &[(0b11010, &ENTRY_PERNASAL_16102840364502673315)],
        &[(0b00001, &ENTRY_PRENEURAL_3562453023809034170)],
        &[(0b00001, &ENTRY_PRAENOMEN_2873680985932826564)],
        &[(0b00001, &ENTRY_PRAENOMENS_5004906408322264673)],
        &[(0b00001, &ENTRY_PRENOMINA_17447004374293437505)],
        &[(0b00001, &ENTRY_PRENOMINAL_10726676408919250433)],
    ],
    range: 4..=6,
};

static VARS_PREM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREM_CHILDREN),
    value: None,
};

pub static VARS_PREM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("axilla"),
        dictgen::InsensitiveStr::Ascii("ial"),
        dictgen::InsensitiveStr::Ascii("illennialise"),
        dictgen::InsensitiveStr::Ascii("illennialised"),
        dictgen::InsensitiveStr::Ascii("illennialising"),
        dictgen::InsensitiveStr::Ascii("illennialize"),
        dictgen::InsensitiveStr::Ascii("illennialized"),
        dictgen::InsensitiveStr::Ascii("illennializing"),
        dictgen::InsensitiveStr::Ascii("issable"),
        dictgen::InsensitiveStr::Ascii("ixture"),
        dictgen::InsensitiveStr::Ascii("onopolise"),
        dictgen::InsensitiveStr::Ascii("onopolises"),
        dictgen::InsensitiveStr::Ascii("onopolize"),
        dictgen::InsensitiveStr::Ascii("onopolizes"),
        dictgen::InsensitiveStr::Ascii("unire"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREMAXILLA_16555020865872052033)],
        &[(0b00001, &ENTRY_PREMIAL_17144185719904663728)],
        &[(0b10010, &ENTRY_PREMILLENNIALIZE_18288969862610819617)],
        &[(0b10010, &ENTRY_PREMILLENNIALIZED_9480514167408665185)],
        &[(0b10010, &ENTRY_PREMILLENNIALIZING_250347440556746925)],
        &[(0b01001, &ENTRY_PREMILLENNIALIZE_18288969862610819617)],
        &[(0b01001, &ENTRY_PREMILLENNIALIZED_9480514167408665185)],
        &[(0b01001, &ENTRY_PREMILLENNIALIZING_250347440556746925)],
        &[(0b11010, &ENTRY_PERMISSABLE_8744644961382997089)],
        &[(0b11010, &ENTRY_PERMIXTURE_15232799364862600989)],
        &[(0b10010, &ENTRY_PREMONOPOLIZE_14172697931226828378)],
        &[(0b10010, &ENTRY_PREMONOPOLIZES_7937512297899186558)],
        &[(0b01001, &ENTRY_PREMONOPOLIZE_14172697931226828378)],
        &[(0b01001, &ENTRY_PREMONOPOLIZES_7937512297899186558)],
        &[(0b00001, &ENTRY_PREMUNIRE_3892014183676337382)],
    ],
    range: 3..=14,
};

static VARS_PREL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREL_CHILDREN),
    value: None,
};

pub static VARS_PREL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("abours"),
        dictgen::InsensitiveStr::Ascii("abrum"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atised"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atising"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atized"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("atizing"),
        dictgen::InsensitiveStr::Ascii("ect"),
        dictgen::InsensitiveStr::Ascii("ected"),
        dictgen::InsensitiveStr::Ascii("ecting"),
        dictgen::InsensitiveStr::Ascii("ection"),
        dictgen::InsensitiveStr::Ascii("ector"),
        dictgen::InsensitiveStr::Ascii("ectorship"),
        dictgen::InsensitiveStr::Ascii("ectress"),
        dictgen::InsensitiveStr::Ascii("ects"),
        dictgen::InsensitiveStr::Ascii("ingual"),
        dictgen::InsensitiveStr::Ascii("ingually"),
        dictgen::InsensitiveStr::Ascii("ocalisation"),
        dictgen::InsensitiveStr::Ascii("ocalisations"),
        dictgen::InsensitiveStr::Ascii("ocalization"),
        dictgen::InsensitiveStr::Ascii("ocalizations"),
        dictgen::InsensitiveStr::Ascii("udise"),
        dictgen::InsensitiveStr::Ascii("udises"),
        dictgen::InsensitiveStr::Ascii("udium"),
        dictgen::InsensitiveStr::Ascii("udize"),
        dictgen::InsensitiveStr::Ascii("udizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRELABOR_12579549139000343078)],
        &[(0b00001, &ENTRY_PRELABORS_17252519264142630543)],
        &[(0b11010, &ENTRY_PRELABOR_12579549139000343078)],
        &[(0b11010, &ENTRY_PRELABORS_17252519264142630543)],
        &[(0b00001, &ENTRY_PRELABRUM_10363708726410721819)],
        &[(0b10010, &ENTRY_PRELATIZE_4433569070164127916)],
        &[(0b10010, &ENTRY_PRELATIZED_17510592065974205916)],
        &[(0b10010, &ENTRY_PRELATIZES_10566341519699434934)],
        &[(0b10010, &ENTRY_PRELATIZING_14962226743591213307)],
        &[(0b01001, &ENTRY_PRELATIZE_4433569070164127916)],
        &[(0b01001, &ENTRY_PRELATIZED_17510592065974205916)],
        &[(0b01001, &ENTRY_PRELATIZES_10566341519699434934)],
        &[(0b01001, &ENTRY_PRELATIZING_14962226743591213307)],
        &[(0b00001, &ENTRY_PRELECT_15124133363040005475)],
        &[(0b00001, &ENTRY_PRELECTED_7002487587150372222)],
        &[(0b00001, &ENTRY_PRELECTING_16302727756637083199)],
        &[
            (0b11010, &ENTRY_PERLECTION_3296452498431632093),
            (0b00001, &ENTRY_PRELECTION_2555285504483882003),
        ],
        &[(0b00001, &ENTRY_PRELECTOR_8132693048713382385)],
        &[(0b00001, &ENTRY_PRELECTORSHIP_10522488084784290490)],
        &[(0b00001, &ENTRY_PRELECTRESS_16642358695295070918)],
        &[(0b00001, &ENTRY_PRELECTS_14241179781669955525)],
        &[(0b11010, &ENTRY_PERLINGUAL_3419901988075232474)],
        &[(0b11010, &ENTRY_PERLINGUALLY_11928722645527217541)],
        &[(0b10010, &ENTRY_PRELOCALIZATION_17757820466661991097)],
        &[(0b10010, &ENTRY_PRELOCALIZATIONS_6698192050669739492)],
        &[(0b01001, &ENTRY_PRELOCALIZATION_17757820466661991097)],
        &[(0b01001, &ENTRY_PRELOCALIZATIONS_6698192050669739492)],
        &[(0b10010, &ENTRY_PRELUDIZE_11687616460356004648)],
        &[(0b10010, &ENTRY_PRELUDIZES_17476896209888158296)],
        &[(0b10001, &ENTRY_PRELUDIUM_16182938175477138747)],
        &[(0b01001, &ENTRY_PRELUDIZE_11687616460356004648)],
        &[(0b01001, &ENTRY_PRELUDIZES_17476896209888158296)],
    ],
    range: 3..=12,
};

static VARS_PREJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREJ_CHILDREN),
    value: None,
};

pub static VARS_PREJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ink"),
        dictgen::InsensitiveStr::Ascii("udgement"),
        dictgen::InsensitiveStr::Ascii("udgements"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERJINK_7961075561267618144)],
        &[(0b10010, &ENTRY_PREJUDGMENT_17092778308241323356)],
        &[(0b10010, &ENTRY_PREJUDGMENTS_10781730302929103775)],
    ],
    range: 3..=9,
};

static VARS_PREI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREI_CHILDREN),
    value: None,
};

pub static VARS_PREI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nitialise"),
        dictgen::InsensitiveStr::Ascii("nitialised"),
        dictgen::InsensitiveStr::Ascii("nitialises"),
        dictgen::InsensitiveStr::Ascii("nitialising"),
        dictgen::InsensitiveStr::Ascii("nitialize"),
        dictgen::InsensitiveStr::Ascii("nitialized"),
        dictgen::InsensitiveStr::Ascii("nitializes"),
        dictgen::InsensitiveStr::Ascii("nitializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREINITIALIZE_5958730031534599577)],
        &[(0b10010, &ENTRY_PREINITIALIZED_1342530234296788703)],
        &[(0b10010, &ENTRY_PREINITIALIZES_1948106422392976020)],
        &[(0b10010, &ENTRY_PREINITIALIZING_12725446901089230467)],
        &[(0b01001, &ENTRY_PREINITIALIZE_5958730031534599577)],
        &[(0b01001, &ENTRY_PREINITIALIZED_1342530234296788703)],
        &[(0b01001, &ENTRY_PREINITIALIZES_1948106422392976020)],
        &[(0b01001, &ENTRY_PREINITIALIZING_12725446901089230467)],
    ],
    range: 9..=11,
};

static VARS_PREH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREH_CHILDREN),
    value: None,
};

pub static VARS_PREH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("allux"),
        dictgen::InsensitiveStr::Ascii("azard"),
        dictgen::InsensitiveStr::Ascii("umor"),
        dictgen::InsensitiveStr::Ascii("umors"),
        dictgen::InsensitiveStr::Ascii("umour"),
        dictgen::InsensitiveStr::Ascii("umours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREHALLUX_13547378424609565453)],
        &[(0b11010, &ENTRY_PERHAZARD_5172084758894143542)],
        &[(0b00001, &ENTRY_PREHUMOR_5171358378179024334)],
        &[(0b00001, &ENTRY_PREHUMORS_5727486563202761536)],
        &[(0b11010, &ENTRY_PREHUMOR_5171358378179024334)],
        &[(0b11010, &ENTRY_PREHUMORS_5727486563202761536)],
    ],
    range: 4..=6,
};

static VARS_PREG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREG_CHILDREN),
    value: None,
};

pub static VARS_PREG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alvanise"),
        dictgen::InsensitiveStr::Ascii("alvanises"),
        dictgen::InsensitiveStr::Ascii("alvanize"),
        dictgen::InsensitiveStr::Ascii("alvanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREGALVANIZE_12483583304872451614)],
        &[(0b10010, &ENTRY_PREGALVANIZES_12463518520956893780)],
        &[(0b01001, &ENTRY_PREGALVANIZE_12483583304872451614)],
        &[(0b01001, &ENTRY_PREGALVANIZES_12463518520956893780)],
    ],
    range: 8..=9,
};

static VARS_PREF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREF_CHILDREN),
    value: None,
};

pub static VARS_PREF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avorable"),
        dictgen::InsensitiveStr::Ascii("avorables"),
        dictgen::InsensitiveStr::Ascii("avorablies"),
        dictgen::InsensitiveStr::Ascii("avorably"),
        dictgen::InsensitiveStr::Ascii("avorite"),
        dictgen::InsensitiveStr::Ascii("avorites"),
        dictgen::InsensitiveStr::Ascii("avors"),
        dictgen::InsensitiveStr::Ascii("avour"),
        dictgen::InsensitiveStr::Ascii("avourable"),
        dictgen::InsensitiveStr::Ascii("avourables"),
        dictgen::InsensitiveStr::Ascii("avourablies"),
        dictgen::InsensitiveStr::Ascii("avourably"),
        dictgen::InsensitiveStr::Ascii("avourite"),
        dictgen::InsensitiveStr::Ascii("avourites"),
        dictgen::InsensitiveStr::Ascii("avours"),
        dictgen::InsensitiveStr::Ascii("ectorial"),
        dictgen::InsensitiveStr::Ascii("ertilisation"),
        dictgen::InsensitiveStr::Ascii("ertilisations"),
        dictgen::InsensitiveStr::Ascii("ertilise"),
        dictgen::InsensitiveStr::Ascii("ertilises"),
        dictgen::InsensitiveStr::Ascii("ertilization"),
        dictgen::InsensitiveStr::Ascii("ertilizations"),
        dictgen::InsensitiveStr::Ascii("ertilize"),
        dictgen::InsensitiveStr::Ascii("ertilizes"),
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("lavor"),
        dictgen::InsensitiveStr::Ascii("lavoring"),
        dictgen::InsensitiveStr::Ascii("lavorings"),
        dictgen::InsensitiveStr::Ascii("lavors"),
        dictgen::InsensitiveStr::Ascii("lavour"),
        dictgen::InsensitiveStr::Ascii("lavouring"),
        dictgen::InsensitiveStr::Ascii("lavourings"),
        dictgen::InsensitiveStr::Ascii("lavours"),
        dictgen::InsensitiveStr::Ascii("loration"),
        dictgen::InsensitiveStr::Ascii("oliation"),
        dictgen::InsensitiveStr::Ascii("oliations"),
        dictgen::InsensitiveStr::Ascii("ormant"),
        dictgen::InsensitiveStr::Ascii("ormative"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREFAVOR_9822958321616866402)],
        &[(0b00001, &ENTRY_PREFAVORABLE_15977451896887575400)],
        &[(0b00001, &ENTRY_PREFAVORABLES_15171050073851160534)],
        &[(0b00001, &ENTRY_PREFAVORABLIES_10995828792301769177)],
        &[(0b00001, &ENTRY_PREFAVORABLY_2906405353959131669)],
        &[(0b00001, &ENTRY_PREFAVORITE_12845110563536419892)],
        &[(0b00001, &ENTRY_PREFAVORITES_1782004517342464146)],
        &[(0b00001, &ENTRY_PREFAVORS_7516975395445427601)],
        &[(0b11010, &ENTRY_PREFAVOR_9822958321616866402)],
        &[(0b11010, &ENTRY_PREFAVORABLE_15977451896887575400)],
        &[(0b11010, &ENTRY_PREFAVORABLES_15171050073851160534)],
        &[(0b11010, &ENTRY_PREFAVORABLIES_10995828792301769177)],
        &[(0b11010, &ENTRY_PREFAVORABLY_2906405353959131669)],
        &[(0b11010, &ENTRY_PREFAVORITE_12845110563536419892)],
        &[(0b11010, &ENTRY_PREFAVORITES_1782004517342464146)],
        &[(0b11010, &ENTRY_PREFAVORS_7516975395445427601)],
        &[(0b00001, &ENTRY_PREFECTORIAL_15709778797625379140)],
        &[(0b10010, &ENTRY_PREFERTILIZATION_18227646050360159024)],
        &[(0b10010, &ENTRY_PREFERTILIZATIONS_1818756888116056700)],
        &[(0b10010, &ENTRY_PREFERTILIZE_14615806731386054716)],
        &[(0b10010, &ENTRY_PREFERTILIZES_1495803436587693020)],
        &[(0b01001, &ENTRY_PREFERTILIZATION_18227646050360159024)],
        &[(0b01001, &ENTRY_PREFERTILIZATIONS_1818756888116056700)],
        &[(0b01001, &ENTRY_PREFERTILIZE_14615806731386054716)],
        &[(0b01001, &ENTRY_PREFERTILIZES_1495803436587693020)],
        &[(0b11010, &ENTRY_PERFET_12737033377426427677)],
        &[(0b00001, &ENTRY_PREFLAVOR_17202106869497805689)],
        &[(0b00001, &ENTRY_PREFLAVORING_6802911008767761287)],
        &[(0b00001, &ENTRY_PREFLAVORINGS_4617219348151300123)],
        &[(0b00001, &ENTRY_PREFLAVORS_6105553296569719644)],
        &[(0b11010, &ENTRY_PREFLAVOR_17202106869497805689)],
        &[(0b11010, &ENTRY_PREFLAVORING_6802911008767761287)],
        &[(0b11010, &ENTRY_PREFLAVORINGS_4617219348151300123)],
        &[(0b11010, &ENTRY_PREFLAVORS_6105553296569719644)],
        &[(0b00001, &ENTRY_PREFLORATION_11916715073975297394)],
        &[
            (0b11010, &ENTRY_PERFOLIATION_15643738965251302962),
            (0b00001, &ENTRY_PREFOLIATION_802436263196003766),
        ],
        &[(0b11010, &ENTRY_PERFOLIATIONS_5441070203325996418)],
        &[(0b11010, &ENTRY_PERFORMANT_1886331341238867877)],
        &[(0b11010, &ENTRY_PERFORMATIVE_11653583321194826668)],
    ],
    range: 2..=13,
};

static VARS_PREE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREE_CHILDREN),
    value: None,
};

pub static VARS_PREE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mptor"),
        dictgen::InsensitiveStr::Ascii("sophageal"),
        dictgen::InsensitiveStr::Ascii("stival"),
        dictgen::InsensitiveStr::Ascii("xistent"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREEMPTOR_2461656381478908185)],
        &[
            (0b00001, &ENTRY_PREESOPHAGEAL_14877226231602978003),
            (0b00001, &ENTRY_PREESOPHAGEAL_2065887315526261809),
        ],
        &[(0b00001, &ENTRY_PREESTIVAL_6075881105306786790)],
        &[(0b00001, &ENTRY_PREEXISTENT_5468737224949447194)],
    ],
    range: 5..=9,
};

static VARS_PRED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRED_CHILDREN),
    value: None,
};

pub static VARS_PRED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ial"),
        dictgen::InsensitiveStr::Ascii("ialist"),
        dictgen::InsensitiveStr::Ascii("iality"),
        dictgen::InsensitiveStr::Ascii("ials"),
        dictgen::InsensitiveStr::Ascii("iligent"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREDIAL_9694094483984666534)],
        &[(0b00001, &ENTRY_PREDIALIST_224083735542634220)],
        &[(0b00001, &ENTRY_PREDIALITY_5750901920352866705)],
        &[(0b00001, &ENTRY_PREDIALS_13414568675400088449)],
        &[(0b11010, &ENTRY_PERDILIGENT_5349792271361198811)],
        &[(0b11010, &ENTRY_PERDY_1390936130181263743)],
    ],
    range: 1..=7,
};

static VARS_PREC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PREC_CHILDREN),
    value: None,
};

static VARS_PREC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PRECA_NODE),
    None,
    None,
    None,
    Some(&VARS_PRECE_NODE),
    None,
    None,
    Some(&VARS_PRECH_NODE),
    Some(&VARS_PRECI_NODE),
    None,
    None,
    Some(&VARS_PRECL_NODE),
    None,
    None,
    Some(&VARS_PRECO_NODE),
    None,
    None,
    Some(&VARS_PRECR_NODE),
    None,
    None,
    Some(&VARS_PRECU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_PRECU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECU_CHILDREN),
    value: None,
};

pub static VARS_PRECU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("neus"),
        dictgen::InsensitiveStr::Ascii("rrent"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRECUNEUS_11481546809254856891)],
        &[(0b11010, &ENTRY_PERCURRENT_15522415679210362636)],
    ],
    range: 4..=5,
};

static VARS_PRECR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECR_CHILDREN),
    value: None,
};

pub static VARS_PRECR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iticise"),
        dictgen::InsensitiveStr::Ascii("iticises"),
        dictgen::InsensitiveStr::Ascii("iticize"),
        dictgen::InsensitiveStr::Ascii("iticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRECRITICIZE_8846824592864407133)],
        &[(0b10010, &ENTRY_PRECRITICIZES_15135281493768452751)],
        &[(0b01001, &ENTRY_PRECRITICIZE_8846824592864407133)],
        &[(0b01001, &ENTRY_PRECRITICIZES_15135281493768452751)],
    ],
    range: 7..=8,
};

static VARS_PRECO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECO_CHILDREN),
    value: None,
};

pub static VARS_PRECO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cial"),
        dictgen::InsensitiveStr::Ascii("lor"),
        dictgen::InsensitiveStr::Ascii("lorable"),
        dictgen::InsensitiveStr::Ascii("lorabler"),
        dictgen::InsensitiveStr::Ascii("lorables"),
        dictgen::InsensitiveStr::Ascii("lorablest"),
        dictgen::InsensitiveStr::Ascii("loration"),
        dictgen::InsensitiveStr::Ascii("lorations"),
        dictgen::InsensitiveStr::Ascii("lored"),
        dictgen::InsensitiveStr::Ascii("loring"),
        dictgen::InsensitiveStr::Ascii("lorings"),
        dictgen::InsensitiveStr::Ascii("lors"),
        dictgen::InsensitiveStr::Ascii("lour"),
        dictgen::InsensitiveStr::Ascii("lourable"),
        dictgen::InsensitiveStr::Ascii("lourabler"),
        dictgen::InsensitiveStr::Ascii("lourables"),
        dictgen::InsensitiveStr::Ascii("lourablest"),
        dictgen::InsensitiveStr::Ascii("louration"),
        dictgen::InsensitiveStr::Ascii("lourations"),
        dictgen::InsensitiveStr::Ascii("loured"),
        dictgen::InsensitiveStr::Ascii("louring"),
        dictgen::InsensitiveStr::Ascii("lourings"),
        dictgen::InsensitiveStr::Ascii("lours"),
        dictgen::InsensitiveStr::Ascii("mpound"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
        dictgen::InsensitiveStr::Ascii("racoid"),
        dictgen::InsensitiveStr::Ascii("rdia"),
        dictgen::InsensitiveStr::Ascii("rdial"),
        dictgen::InsensitiveStr::Ascii("rdium"),
        dictgen::InsensitiveStr::Ascii("rnu"),
        dictgen::InsensitiveStr::Ascii("x"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRECOCIAL_8294693877415543753)],
        &[(0b10001, &ENTRY_PRECOLOR_17299860958104955202)],
        &[(0b10001, &ENTRY_PRECOLORABLE_5487085359496706867)],
        &[(0b10001, &ENTRY_PRECOLORABLER_11767685787558642755)],
        &[(0b10001, &ENTRY_PRECOLORABLES_16733631722514561712)],
        &[(0b10001, &ENTRY_PRECOLORABLEST_6808278957047261325)],
        &[(0b00001, &ENTRY_PRECOLORATION_10656995892359877853)],
        &[(0b00001, &ENTRY_PRECOLORATIONS_10499804334250645010)],
        &[(0b10001, &ENTRY_PRECOLORED_9698300540722607314)],
        &[(0b10001, &ENTRY_PRECOLORING_6024220919758395050)],
        &[(0b10001, &ENTRY_PRECOLORINGS_4691510199823561883)],
        &[(0b10001, &ENTRY_PRECOLORS_9083220684090884764)],
        &[(0b11010, &ENTRY_PRECOLOR_17299860958104955202)],
        &[(0b11010, &ENTRY_PRECOLORABLE_5487085359496706867)],
        &[(0b11010, &ENTRY_PRECOLORABLER_11767685787558642755)],
        &[(0b11010, &ENTRY_PRECOLORABLES_16733631722514561712)],
        &[(0b11010, &ENTRY_PRECOLORABLEST_6808278957047261325)],
        &[(0b11010, &ENTRY_PRECOLORATION_10656995892359877853)],
        &[(0b11010, &ENTRY_PRECOLORATIONS_10499804334250645010)],
        &[(0b11010, &ENTRY_PRECOLORED_9698300540722607314)],
        &[(0b11010, &ENTRY_PRECOLORING_6024220919758395050)],
        &[(0b11010, &ENTRY_PRECOLORINGS_4691510199823561883)],
        &[(0b11010, &ENTRY_PRECOLORS_9083220684090884764)],
        &[(0b11010, &ENTRY_PERCOMPOUND_414258272162299801)],
        &[(0b10010, &ENTRY_PRECONIZATION_16258034160636183447)],
        &[(0b10010, &ENTRY_PRECONIZATIONS_12551697775601965661)],
        &[(0b10010, &ENTRY_PRECONIZE_9740123560582240989)],
        &[(0b10010, &ENTRY_PRECONIZED_9790826501440568673)],
        &[(0b10010, &ENTRY_PRECONIZER_1030946604754458839)],
        &[(0b10010, &ENTRY_PRECONIZERS_5442536382274699448)],
        &[(0b10010, &ENTRY_PRECONIZES_1119327710154936908)],
        &[(0b10010, &ENTRY_PRECONIZING_10462413300311269807)],
        &[(0b01001, &ENTRY_PRECONIZATION_16258034160636183447)],
        &[(0b01001, &ENTRY_PRECONIZATIONS_12551697775601965661)],
        &[(0b01001, &ENTRY_PRECONIZE_9740123560582240989)],
        &[(0b01001, &ENTRY_PRECONIZED_9790826501440568673)],
        &[(0b01001, &ENTRY_PRECONIZER_1030946604754458839)],
        &[(0b01001, &ENTRY_PRECONIZERS_5442536382274699448)],
        &[(0b01001, &ENTRY_PRECONIZES_1119327710154936908)],
        &[(0b01001, &ENTRY_PRECONIZING_10462413300311269807)],
        &[(0b00001, &ENTRY_PRECORACOID_8217660205581287132)],
        &[(0b00001, &ENTRY_PRECORDIA_1238253163440816627)],
        &[(0b00001, &ENTRY_PRECORDIAL_11745663068833489838)],
        &[(0b00001, &ENTRY_PRECORDIUM_5299854035063803868)],
        &[(0b00001, &ENTRY_PRECORNU_1505512584010830310)],
        &[(0b00001, &ENTRY_PRECOX_3189402882782043655)],
    ],
    range: 1..=10,
};

static VARS_PRECL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECL_CHILDREN),
    value: None,
};

pub static VARS_PRECL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ose")],
    values: &[&[(0b11010, &ENTRY_PERCLOSE_11470867655063256438)]],
    range: 3..=3,
};

static VARS_PRECI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECI_CHILDREN),
    value: None,
};

pub static VARS_PRECI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("pe"),
        dictgen::InsensitiveStr::Ascii("pes"),
        dictgen::InsensitiveStr::Ascii("sionise"),
        dictgen::InsensitiveStr::Ascii("sionises"),
        dictgen::InsensitiveStr::Ascii("sionize"),
        dictgen::InsensitiveStr::Ascii("sionizes"),
        dictgen::InsensitiveStr::Ascii("vilisation"),
        dictgen::InsensitiveStr::Ascii("vilisations"),
        dictgen::InsensitiveStr::Ascii("vilization"),
        dictgen::InsensitiveStr::Ascii("vilizations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRECIPE_13555769800049677911)],
        &[(0b00001, &ENTRY_PRECIPES_591594308859789992)],
        &[(0b10010, &ENTRY_PRECISIONIZE_16309913476870820127)],
        &[(0b10010, &ENTRY_PRECISIONIZES_17461523032107876112)],
        &[(0b01001, &ENTRY_PRECISIONIZE_16309913476870820127)],
        &[(0b01001, &ENTRY_PRECISIONIZES_17461523032107876112)],
        &[(0b10010, &ENTRY_PRECIVILIZATION_8718510999880386433)],
        &[(0b10010, &ENTRY_PRECIVILIZATIONS_15617845600007536715)],
        &[(0b01001, &ENTRY_PRECIVILIZATION_8718510999880386433)],
        &[(0b01001, &ENTRY_PRECIVILIZATIONS_15617845600007536715)],
    ],
    range: 2..=11,
};

static VARS_PRECH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECH_CHILDREN),
    value: None,
};

pub static VARS_PRECH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("loric")],
    values: &[&[(0b11010, &ENTRY_PERCHLORIC_15808215951562951935)]],
    range: 5..=5,
};

static VARS_PRECE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECE_CHILDREN),
    value: None,
};

pub static VARS_PRECE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b11010, &ENTRY_PERCES_984660829518258229)]],
    range: 1..=1,
};

static VARS_PRECA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRECA_CHILDREN),
    value: None,
};

pub static VARS_PRECA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncelation"),
        dictgen::InsensitiveStr::Ascii("va"),
        dictgen::InsensitiveStr::Ascii("vae"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PRECANCELATION_15491223411860446070)],
        &[(0b00001, &ENTRY_PRECAVA_2402040055160081507)],
        &[(0b00001, &ENTRY_PRECAVAE_5572444235139095890)],
    ],
    range: 2..=9,
};

static VARS_PREB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREB_CHILDREN),
    value: None,
};

pub static VARS_PREB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PREBAPTIZE_17160053539170465128)],
        &[(0b10010, &ENTRY_PREBAPTIZES_11093608958711804148)],
        &[(0b01001, &ENTRY_PREBAPTIZE_17160053539170465128)],
        &[(0b01001, &ENTRY_PREBAPTIZES_11093608958711804148)],
    ],
    range: 6..=7,
};

static VARS_PREA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PREA_CHILDREN),
    value: None,
};

pub static VARS_PREA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bdomen"),
        dictgen::InsensitiveStr::Ascii("cetabular"),
        dictgen::InsensitiveStr::Ascii("cherise"),
        dictgen::InsensitiveStr::Ascii("cherises"),
        dictgen::InsensitiveStr::Ascii("cherize"),
        dictgen::InsensitiveStr::Ascii("cherizes"),
        dictgen::InsensitiveStr::Ascii("cid"),
        dictgen::InsensitiveStr::Ascii("cidity"),
        dictgen::InsensitiveStr::Ascii("cknowledgement"),
        dictgen::InsensitiveStr::Ascii("cknowledgements"),
        dictgen::InsensitiveStr::Ascii("cknowledgment"),
        dictgen::InsensitiveStr::Ascii("cknowledgments"),
        dictgen::InsensitiveStr::Ascii("ct"),
        dictgen::InsensitiveStr::Ascii("cute"),
        dictgen::InsensitiveStr::Ascii("emptor"),
        dictgen::InsensitiveStr::Ascii("estival"),
        dictgen::InsensitiveStr::Ascii("existent"),
        dictgen::InsensitiveStr::Ascii("mbulatory"),
        dictgen::InsensitiveStr::Ascii("naesthetic"),
        dictgen::InsensitiveStr::Ascii("naesthetics"),
        dictgen::InsensitiveStr::Ascii("nal"),
        dictgen::InsensitiveStr::Ascii("nesthetic"),
        dictgen::InsensitiveStr::Ascii("nesthetics"),
        dictgen::InsensitiveStr::Ascii("pprise"),
        dictgen::InsensitiveStr::Ascii("pprised"),
        dictgen::InsensitiveStr::Ascii("pprising"),
        dictgen::InsensitiveStr::Ascii("pprize"),
        dictgen::InsensitiveStr::Ascii("pprized"),
        dictgen::InsensitiveStr::Ascii("pprizing"),
        dictgen::InsensitiveStr::Ascii("uthorise"),
        dictgen::InsensitiveStr::Ascii("uthorize"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PREABDOMEN_8539482488045440061)],
        &[(0b00001, &ENTRY_PREACETABULAR_8250642348247679862)],
        &[(0b10010, &ENTRY_PREACHERIZE_3114832429644025826)],
        &[(0b10010, &ENTRY_PREACHERIZES_18214780901228990451)],
        &[(0b01001, &ENTRY_PREACHERIZE_3114832429644025826)],
        &[(0b01001, &ENTRY_PREACHERIZES_18214780901228990451)],
        &[(0b11010, &ENTRY_PERACID_17853350354268795572)],
        &[(0b11010, &ENTRY_PERACIDITY_1147905095983877951)],
        &[(0b11010, &ENTRY_PREACKNOWLEDGMENT_15471253594011483017)],
        &[(0b11010, &ENTRY_PREACKNOWLEDGMENTS_5969739714891516296)],
        &[(0b00001, &ENTRY_PREACKNOWLEDGMENT_15471253594011483017)],
        &[(0b00001, &ENTRY_PREACKNOWLEDGMENTS_5969739714891516296)],
        &[(0b11010, &ENTRY_PERACT_16940258999462133608)],
        &[(0b11010, &ENTRY_PERACUTE_2328162913715436273)],
        &[(0b11010, &ENTRY_PREEMPTOR_2461656381478908185)],
        &[(0b11010, &ENTRY_PREESTIVAL_6075881105306786790)],
        &[(0b11010, &ENTRY_PREEXISTENT_5468737224949447194)],
        &[(0b11010, &ENTRY_PERAMBULATORY_3211690938406856596)],
        &[(0b11010, &ENTRY_PREANESTHETIC_17135960641353610099)],
        &[(0b11010, &ENTRY_PREANESTHETICS_8419853812971756134)],
        &[(0b00001, &ENTRY_PREANAL_8282447312000633016)],
        &[(0b00001, &ENTRY_PREANESTHETIC_17135960641353610099)],
        &[(0b00001, &ENTRY_PREANESTHETICS_8419853812971756134)],
        &[(0b10010, &ENTRY_PREAPPRIZE_14429026707964341876)],
        &[(0b10010, &ENTRY_PREAPPRIZED_1864318479019696185)],
        &[(0b10010, &ENTRY_PREAPPRIZING_7573932856271642590)],
        &[(0b01001, &ENTRY_PREAPPRIZE_14429026707964341876)],
        &[(0b01001, &ENTRY_PREAPPRIZED_1864318479019696185)],
        &[(0b01001, &ENTRY_PREAPPRIZING_7573932856271642590)],
        &[(0b10010, &ENTRY_PREAUTHORIZE_15918741156332951414)],
        &[(0b01001, &ENTRY_PREAUTHORIZE_15918741156332951414)],
    ],
    range: 2..=15,
};

static VARS_PRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PRA_CHILDREN),
    value: None,
};

static VARS_PRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_PRAC_NODE),
    None,
    Some(&VARS_PRAE_NODE),
    None,
    Some(&VARS_PRAG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PRAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRAG_CHILDREN),
    value: None,
};

pub static VARS_PRAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matisations"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matiser"),
        dictgen::InsensitiveStr::Ascii("matisers"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matizations"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizer"),
        dictgen::InsensitiveStr::Ascii("matizers"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PRAGMATIZATION_8346324153987456718)],
        &[(0b10010, &ENTRY_PRAGMATIZATIONS_1347693305826589779)],
        &[(0b10010, &ENTRY_PRAGMATIZE_10222982293817030908)],
        &[(0b10010, &ENTRY_PRAGMATIZED_15911492964724941957)],
        &[(0b10010, &ENTRY_PRAGMATIZER_13231924506248328620)],
        &[(0b10010, &ENTRY_PRAGMATIZERS_17050725505178628169)],
        &[(0b10010, &ENTRY_PRAGMATIZES_4196103149615407244)],
        &[(0b10010, &ENTRY_PRAGMATIZING_5484672503035338428)],
        &[(0b01001, &ENTRY_PRAGMATIZATION_8346324153987456718)],
        &[(0b01001, &ENTRY_PRAGMATIZATIONS_1347693305826589779)],
        &[(0b01001, &ENTRY_PRAGMATIZE_10222982293817030908)],
        &[(0b01001, &ENTRY_PRAGMATIZED_15911492964724941957)],
        &[(0b01001, &ENTRY_PRAGMATIZER_13231924506248328620)],
        &[(0b01001, &ENTRY_PRAGMATIZERS_17050725505178628169)],
        &[(0b01001, &ENTRY_PRAGMATIZES_4196103149615407244)],
        &[(0b01001, &ENTRY_PRAGMATIZING_5484672503035338428)],
    ],
    range: 6..=11,
};

static VARS_PRAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRAE_CHILDREN),
    value: None,
};

pub static VARS_PRAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abdomen"),
        dictgen::InsensitiveStr::Ascii("acetabular"),
        dictgen::InsensitiveStr::Ascii("anal"),
        dictgen::InsensitiveStr::Ascii("cava"),
        dictgen::InsensitiveStr::Ascii("cavae"),
        dictgen::InsensitiveStr::Ascii("cipe"),
        dictgen::InsensitiveStr::Ascii("cipes"),
        dictgen::InsensitiveStr::Ascii("cocial"),
        dictgen::InsensitiveStr::Ascii("coracoid"),
        dictgen::InsensitiveStr::Ascii("cordia"),
        dictgen::InsensitiveStr::Ascii("cordial"),
        dictgen::InsensitiveStr::Ascii("cordium"),
        dictgen::InsensitiveStr::Ascii("cornu"),
        dictgen::InsensitiveStr::Ascii("cox"),
        dictgen::InsensitiveStr::Ascii("cuneus"),
        dictgen::InsensitiveStr::Ascii("dial"),
        dictgen::InsensitiveStr::Ascii("dialist"),
        dictgen::InsensitiveStr::Ascii("diality"),
        dictgen::InsensitiveStr::Ascii("dials"),
        dictgen::InsensitiveStr::Ascii("esophageal"),
        dictgen::InsensitiveStr::Ascii("fectorial"),
        dictgen::InsensitiveStr::Ascii("floration"),
        dictgen::InsensitiveStr::Ascii("foliation"),
        dictgen::InsensitiveStr::Ascii("hallux"),
        dictgen::InsensitiveStr::Ascii("labrum"),
        dictgen::InsensitiveStr::Ascii("lect"),
        dictgen::InsensitiveStr::Ascii("lected"),
        dictgen::InsensitiveStr::Ascii("lecting"),
        dictgen::InsensitiveStr::Ascii("lection"),
        dictgen::InsensitiveStr::Ascii("lector"),
        dictgen::InsensitiveStr::Ascii("lectorship"),
        dictgen::InsensitiveStr::Ascii("lectress"),
        dictgen::InsensitiveStr::Ascii("lects"),
        dictgen::InsensitiveStr::Ascii("ludium"),
        dictgen::InsensitiveStr::Ascii("maxilla"),
        dictgen::InsensitiveStr::Ascii("munire"),
        dictgen::InsensitiveStr::Ascii("narial"),
        dictgen::InsensitiveStr::Ascii("neural"),
        dictgen::InsensitiveStr::Ascii("nomina"),
        dictgen::InsensitiveStr::Ascii("nominal"),
        dictgen::InsensitiveStr::Ascii("operculum"),
        dictgen::InsensitiveStr::Ascii("positor"),
        dictgen::InsensitiveStr::Ascii("positure"),
        dictgen::InsensitiveStr::Ascii("poster"),
        dictgen::InsensitiveStr::Ascii("postor"),
        dictgen::InsensitiveStr::Ascii("postors"),
        dictgen::InsensitiveStr::Ascii("pubis"),
        dictgen::InsensitiveStr::Ascii("scutum"),
        dictgen::InsensitiveStr::Ascii("sphenoid"),
        dictgen::InsensitiveStr::Ascii("sternal"),
        dictgen::InsensitiveStr::Ascii("sternum"),
        dictgen::InsensitiveStr::Ascii("stomium"),
        dictgen::InsensitiveStr::Ascii("systolic"),
        dictgen::InsensitiveStr::Ascii("taxation"),
        dictgen::InsensitiveStr::Ascii("texta"),
        dictgen::InsensitiveStr::Ascii("textae"),
        dictgen::InsensitiveStr::Ascii("torial"),
        dictgen::InsensitiveStr::Ascii("torians"),
        dictgen::InsensitiveStr::Ascii("torium"),
        dictgen::InsensitiveStr::Ascii("torius"),
        dictgen::InsensitiveStr::Ascii("torship"),
        dictgen::InsensitiveStr::Ascii("zygapophysis"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PREABDOMEN_8539482488045440061)],
        &[(0b11010, &ENTRY_PREACETABULAR_8250642348247679862)],
        &[(0b11010, &ENTRY_PREANAL_8282447312000633016)],
        &[(0b11010, &ENTRY_PRECAVA_2402040055160081507)],
        &[(0b11010, &ENTRY_PRECAVAE_5572444235139095890)],
        &[(0b11010, &ENTRY_PRECIPE_13555769800049677911)],
        &[(0b11010, &ENTRY_PRECIPES_591594308859789992)],
        &[(0b11010, &ENTRY_PRECOCIAL_8294693877415543753)],
        &[(0b11010, &ENTRY_PRECORACOID_8217660205581287132)],
        &[(0b11010, &ENTRY_PRECORDIA_1238253163440816627)],
        &[(0b11010, &ENTRY_PRECORDIAL_11745663068833489838)],
        &[(0b11010, &ENTRY_PRECORDIUM_5299854035063803868)],
        &[(0b11010, &ENTRY_PRECORNU_1505512584010830310)],
        &[(0b11010, &ENTRY_PRECOX_3189402882782043655)],
        &[(0b11010, &ENTRY_PRECUNEUS_11481546809254856891)],
        &[(0b11010, &ENTRY_PREDIAL_9694094483984666534)],
        &[(0b11010, &ENTRY_PREDIALIST_224083735542634220)],
        &[(0b11010, &ENTRY_PREDIALITY_5750901920352866705)],
        &[(0b11010, &ENTRY_PREDIALS_13414568675400088449)],
        &[(0b11010, &ENTRY_PREESOPHAGEAL_14877226231602978003)],
        &[(0b11010, &ENTRY_PREFECTORIAL_15709778797625379140)],
        &[(0b11010, &ENTRY_PREFLORATION_11916715073975297394)],
        &[(0b11010, &ENTRY_PREFOLIATION_802436263196003766)],
        &[(0b11010, &ENTRY_PREHALLUX_13547378424609565453)],
        &[(0b11010, &ENTRY_PRELABRUM_10363708726410721819)],
        &[(0b11010, &ENTRY_PRELECT_15124133363040005475)],
        &[(0b11010, &ENTRY_PRELECTED_7002487587150372222)],
        &[(0b11010, &ENTRY_PRELECTING_16302727756637083199)],
        &[(0b11010, &ENTRY_PRELECTION_2555285504483882003)],
        &[(0b11010, &ENTRY_PRELECTOR_8132693048713382385)],
        &[(0b11010, &ENTRY_PRELECTORSHIP_10522488084784290490)],
        &[(0b11010, &ENTRY_PRELECTRESS_16642358695295070918)],
        &[(0b11010, &ENTRY_PRELECTS_14241179781669955525)],
        &[(0b11010, &ENTRY_PRELUDIUM_16182938175477138747)],
        &[(0b11010, &ENTRY_PREMAXILLA_16555020865872052033)],
        &[(0b11010, &ENTRY_PREMUNIRE_3892014183676337382)],
        &[(0b11010, &ENTRY_PRENARIAL_18182351486930830192)],
        &[(0b11010, &ENTRY_PRENEURAL_3562453023809034170)],
        &[(0b11010, &ENTRY_PRENOMINA_17447004374293437505)],
        &[(0b11010, &ENTRY_PRENOMINAL_10726676408919250433)],
        &[(0b11010, &ENTRY_PREOPERCULUM_4376076836382915800)],
        &[(0b11010, &ENTRY_PREPOSITOR_12797659440544372540)],
        &[(0b11010, &ENTRY_PREPOSITURE_5966359554589897516)],
        &[(0b11010, &ENTRY_PREPOSTER_9979045838450867710)],
        &[(0b11010, &ENTRY_PREPOSTOR_6334579978765007057)],
        &[(0b11010, &ENTRY_PREPOSTORS_8760995478070950332)],
        &[(0b11010, &ENTRY_PREPUBIS_17618648717583634353)],
        &[(0b11010, &ENTRY_PRESCUTUM_17649301303017684495)],
        &[(0b11010, &ENTRY_PRESPHENOID_4701941519879933792)],
        &[(0b11010, &ENTRY_PRESTERNAL_3731098073887538850)],
        &[(0b11010, &ENTRY_PRESTERNUM_10191977327812747108)],
        &[(0b11010, &ENTRY_PRESTOMIUM_2175790353005742393)],
        &[(0b11010, &ENTRY_PRESYSTOLIC_17980529676890563829)],
        &[(0b11010, &ENTRY_PRETAXATION_16254819888221291653)],
        &[(0b11010, &ENTRY_PRETEXTA_322521945222134396)],
        &[(0b11010, &ENTRY_PRETEXTAE_16184667912878448094)],
        &[(0b11010, &ENTRY_PRETORIAL_7197260765783954402)],
        &[(0b11010, &ENTRY_PRETORIANS_5321413914837421784)],
        &[(0b11010, &ENTRY_PRETORIUM_1712722934465958271)],
        &[(0b11010, &ENTRY_PRETORIUS_278833463846710853)],
        &[(0b11010, &ENTRY_PRETORSHIP_298144548841059349)],
        &[(0b11010, &ENTRY_PREZYGAPOPHYSIS_14960217627658149191)],
    ],
    range: 3..=12,
};

static VARS_PRAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PRAC_CHILDREN),
    value: None,
};

pub static VARS_PRAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ticed"),
        dictgen::InsensitiveStr::Ascii("ticer"),
        dictgen::InsensitiveStr::Ascii("ticers"),
        dictgen::InsensitiveStr::Ascii("ticing"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
    ],
    values: &[
        &[(0b01001, &ENTRY_PRACTICED_11550656047130039147)],
        &[(0b00001, &ENTRY_PRACTICER_839837859698199934)],
        &[(0b00001, &ENTRY_PRACTICERS_15222235322635642468)],
        &[(0b01001, &ENTRY_PRACTICING_13680497227185368763)],
        &[(0b11010, &ENTRY_PRACTICER_839837859698199934)],
        &[(0b11010, &ENTRY_PRACTICERS_15222235322635642468)],
    ],
    range: 5..=6,
};

static VARS_PO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PO_CHILDREN),
    value: None,
};

static VARS_PO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_POE_NODE),
    None,
    Some(&VARS_POG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_POL_NODE),
    Some(&VARS_POM_NODE),
    None,
    None,
    Some(&VARS_POP_NODE),
    None,
    Some(&VARS_POR_NODE),
    Some(&VARS_POS_NODE),
    Some(&VARS_POT_NODE),
    Some(&VARS_POU_NODE),
    None,
    Some(&VARS_POW_NODE),
    None,
    None,
    None,
];

static VARS_POW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POW_CHILDREN),
    value: None,
};

pub static VARS_POW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("derisation"),
        dictgen::InsensitiveStr::Ascii("derisations"),
        dictgen::InsensitiveStr::Ascii("derise"),
        dictgen::InsensitiveStr::Ascii("deriser"),
        dictgen::InsensitiveStr::Ascii("derisers"),
        dictgen::InsensitiveStr::Ascii("derises"),
        dictgen::InsensitiveStr::Ascii("derization"),
        dictgen::InsensitiveStr::Ascii("derizations"),
        dictgen::InsensitiveStr::Ascii("derize"),
        dictgen::InsensitiveStr::Ascii("derizer"),
        dictgen::InsensitiveStr::Ascii("derizers"),
        dictgen::InsensitiveStr::Ascii("derizes"),
        dictgen::InsensitiveStr::Ascii("ellise"),
        dictgen::InsensitiveStr::Ascii("ellised"),
        dictgen::InsensitiveStr::Ascii("ellises"),
        dictgen::InsensitiveStr::Ascii("ellising"),
        dictgen::InsensitiveStr::Ascii("ellize"),
        dictgen::InsensitiveStr::Ascii("ellized"),
        dictgen::InsensitiveStr::Ascii("ellizes"),
        dictgen::InsensitiveStr::Ascii("ellizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POWDERIZATION_12047778760438241820)],
        &[(0b10010, &ENTRY_POWDERIZATIONS_9770977248142054242)],
        &[(0b10010, &ENTRY_POWDERIZE_10555038798728915476)],
        &[(0b10010, &ENTRY_POWDERIZER_11484081010411649926)],
        &[(0b10010, &ENTRY_POWDERIZERS_7366910102231696330)],
        &[(0b10010, &ENTRY_POWDERIZES_11458042212841934341)],
        &[(0b01001, &ENTRY_POWDERIZATION_12047778760438241820)],
        &[(0b01001, &ENTRY_POWDERIZATIONS_9770977248142054242)],
        &[(0b01001, &ENTRY_POWDERIZE_10555038798728915476)],
        &[(0b01001, &ENTRY_POWDERIZER_11484081010411649926)],
        &[(0b01001, &ENTRY_POWDERIZERS_7366910102231696330)],
        &[(0b01001, &ENTRY_POWDERIZES_11458042212841934341)],
        &[(0b10010, &ENTRY_POWELLIZE_14871332950257843934)],
        &[(0b10010, &ENTRY_POWELLIZED_12963613621406656955)],
        &[(0b10010, &ENTRY_POWELLIZES_16503487494090301096)],
        &[(0b10010, &ENTRY_POWELLIZING_8322629798558997363)],
        &[(0b01001, &ENTRY_POWELLIZE_14871332950257843934)],
        &[(0b01001, &ENTRY_POWELLIZED_12963613621406656955)],
        &[(0b01001, &ENTRY_POWELLIZES_16503487494090301096)],
        &[(0b01001, &ENTRY_POWELLIZING_8322629798558997363)],
    ],
    range: 6..=11,
};

static VARS_POU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POU_CHILDREN),
    value: None,
};

pub static VARS_POU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("der"),
        dictgen::InsensitiveStr::Ascii("ders"),
        dictgen::InsensitiveStr::Ascii("dre"),
        dictgen::InsensitiveStr::Ascii("dres"),
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("lders"),
        dictgen::InsensitiveStr::Ascii("ldre"),
        dictgen::InsensitiveStr::Ascii("ldres"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("ringly"),
    ],
    values: &[
        &[(0b00001, &ENTRY_POUDER_1862804635953235487)],
        &[(0b00001, &ENTRY_POUDERS_8848899925700000053)],
        &[(0b11010, &ENTRY_POUDER_1862804635953235487)],
        &[(0b11010, &ENTRY_POUDERS_8848899925700000053)],
        &[(0b00001, &ENTRY_POULDER_6920280469594748753)],
        &[(0b00001, &ENTRY_POULDERS_4715865184887114546)],
        &[(0b11010, &ENTRY_POULDER_6920280469594748753)],
        &[(0b11010, &ENTRY_POULDERS_4715865184887114546)],
        &[(0b11010, &ENTRY_PORER_9472582636394035687)],
        &[(0b11010, &ENTRY_PORERS_4411327756997706729)],
        &[(0b11010, &ENTRY_PORINGLY_740562095994905397)],
    ],
    range: 3..=6,
};

static VARS_POT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POT_CHILDREN),
    value: None,
};

pub static VARS_POT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entialisation"),
        dictgen::InsensitiveStr::Ascii("entialisations"),
        dictgen::InsensitiveStr::Ascii("entialise"),
        dictgen::InsensitiveStr::Ascii("entialises"),
        dictgen::InsensitiveStr::Ascii("entialization"),
        dictgen::InsensitiveStr::Ascii("entializations"),
        dictgen::InsensitiveStr::Ascii("entialize"),
        dictgen::InsensitiveStr::Ascii("entializes"),
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entised"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entising"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entized"),
        dictgen::InsensitiveStr::Ascii("entizes"),
        dictgen::InsensitiveStr::Ascii("entizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POTENTIALIZATION_11370824378801485428)],
        &[(0b10010, &ENTRY_POTENTIALIZATIONS_16123270987906203275)],
        &[(0b10010, &ENTRY_POTENTIALIZE_5306242383006066570)],
        &[(0b10010, &ENTRY_POTENTIALIZES_7730671741473751473)],
        &[(0b01001, &ENTRY_POTENTIALIZATION_11370824378801485428)],
        &[(0b01001, &ENTRY_POTENTIALIZATIONS_16123270987906203275)],
        &[(0b01001, &ENTRY_POTENTIALIZE_5306242383006066570)],
        &[(0b01001, &ENTRY_POTENTIALIZES_7730671741473751473)],
        &[(0b10010, &ENTRY_POTENTIZE_10353484216841656321)],
        &[(0b10010, &ENTRY_POTENTIZED_16902758254500333884)],
        &[(0b10010, &ENTRY_POTENTIZES_1694669823229591466)],
        &[(0b10010, &ENTRY_POTENTIZING_10663920911074862748)],
        &[(0b01001, &ENTRY_POTENTIZE_10353484216841656321)],
        &[(0b01001, &ENTRY_POTENTIZED_16902758254500333884)],
        &[(0b01001, &ENTRY_POTENTIZES_1694669823229591466)],
        &[(0b01001, &ENTRY_POTENTIZING_10663920911074862748)],
    ],
    range: 6..=14,
};

static VARS_POS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POS_CHILDREN),
    value: None,
};

pub static VARS_POS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itivise"),
        dictgen::InsensitiveStr::Ascii("itivises"),
        dictgen::InsensitiveStr::Ascii("itivize"),
        dictgen::InsensitiveStr::Ascii("itivizes"),
        dictgen::InsensitiveStr::Ascii("tcaecal"),
        dictgen::InsensitiveStr::Ascii("tcecal"),
        dictgen::InsensitiveStr::Ascii("tcenal"),
        dictgen::InsensitiveStr::Ascii("tcoenal"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("tfetal"),
        dictgen::InsensitiveStr::Ascii("tfoetal"),
        dictgen::InsensitiveStr::Ascii("tmediaeval"),
        dictgen::InsensitiveStr::Ascii("tmedieval"),
        dictgen::InsensitiveStr::Ascii("tsynchronisation"),
        dictgen::InsensitiveStr::Ascii("tsynchronization"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POSITIVIZE_13041357091243880766)],
        &[(0b10010, &ENTRY_POSITIVIZES_14569839266695497939)],
        &[(0b01001, &ENTRY_POSITIVIZE_13041357091243880766)],
        &[(0b01001, &ENTRY_POSITIVIZES_14569839266695497939)],
        &[(0b11010, &ENTRY_POSTCECAL_14039669434720483948)],
        &[(0b00001, &ENTRY_POSTCECAL_14039669434720483948)],
        &[(0b00001, &ENTRY_POSTCENAL_71447031611727038)],
        &[(0b11010, &ENTRY_POSTCENAL_71447031611727038)],
        &[(0b10010, &ENTRY_POSTERIZE_4633009065826989954)],
        &[(0b10010, &ENTRY_POSTERIZES_9574605860726504253)],
        &[(0b01001, &ENTRY_POSTERIZE_4633009065826989954)],
        &[(0b01001, &ENTRY_POSTERIZES_9574605860726504253)],
        &[(0b00001, &ENTRY_POSTFETAL_16829805480542213123)],
        &[(0b11010, &ENTRY_POSTFETAL_16829805480542213123)],
        &[(0b11010, &ENTRY_POSTMEDIEVAL_10289905348058220127)],
        &[(0b00001, &ENTRY_POSTMEDIEVAL_10289905348058220127)],
        &[(0b10010, &ENTRY_POSTSYNCHRONIZATION_9735500999067667804)],
        &[(0b01001, &ENTRY_POSTSYNCHRONIZATION_9735500999067667804)],
        &[(0b10010, &ENTRY_POSTURIZE_539261955307310954)],
        &[(0b10010, &ENTRY_POSTURIZED_2355664241763722768)],
        &[(0b10010, &ENTRY_POSTURIZES_17600122313050486119)],
        &[(0b10010, &ENTRY_POSTURIZING_14553163107601026995)],
        &[(0b01001, &ENTRY_POSTURIZE_539261955307310954)],
        &[(0b01001, &ENTRY_POSTURIZED_2355664241763722768)],
        &[(0b01001, &ENTRY_POSTURIZES_17600122313050486119)],
        &[(0b01001, &ENTRY_POSTURIZING_14553163107601026995)],
    ],
    range: 6..=16,
};

static VARS_POR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POR_CHILDREN),
    value: None,
};

pub static VARS_POR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("celainisation"),
        dictgen::InsensitiveStr::Ascii("celainisations"),
        dictgen::InsensitiveStr::Ascii("celainise"),
        dictgen::InsensitiveStr::Ascii("celainised"),
        dictgen::InsensitiveStr::Ascii("celainises"),
        dictgen::InsensitiveStr::Ascii("celainising"),
        dictgen::InsensitiveStr::Ascii("celainization"),
        dictgen::InsensitiveStr::Ascii("celainizations"),
        dictgen::InsensitiveStr::Ascii("celainize"),
        dictgen::InsensitiveStr::Ascii("celainized"),
        dictgen::InsensitiveStr::Ascii("celainizes"),
        dictgen::InsensitiveStr::Ascii("celainizing"),
        dictgen::InsensitiveStr::Ascii("cellanise"),
        dictgen::InsensitiveStr::Ascii("cellanised"),
        dictgen::InsensitiveStr::Ascii("cellanises"),
        dictgen::InsensitiveStr::Ascii("cellanising"),
        dictgen::InsensitiveStr::Ascii("cellanize"),
        dictgen::InsensitiveStr::Ascii("cellanized"),
        dictgen::InsensitiveStr::Ascii("cellanizes"),
        dictgen::InsensitiveStr::Ascii("cellanizing"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ingly"),
        dictgen::InsensitiveStr::Ascii("phyrisation"),
        dictgen::InsensitiveStr::Ascii("phyrization"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tionise"),
        dictgen::InsensitiveStr::Ascii("tionises"),
        dictgen::InsensitiveStr::Ascii("tionize"),
        dictgen::InsensitiveStr::Ascii("tionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PORCELAINIZATION_9987125517935607146)],
        &[(0b10010, &ENTRY_PORCELAINIZATIONS_14201569580189820572)],
        &[(0b10010, &ENTRY_PORCELAINIZE_7702297476189597070)],
        &[(0b10010, &ENTRY_PORCELAINIZED_8958345284962155259)],
        &[(0b10010, &ENTRY_PORCELAINIZES_1116700990546127264)],
        &[(0b10010, &ENTRY_PORCELAINIZING_2678178218886181111)],
        &[(0b01001, &ENTRY_PORCELAINIZATION_9987125517935607146)],
        &[(0b01001, &ENTRY_PORCELAINIZATIONS_14201569580189820572)],
        &[(0b01001, &ENTRY_PORCELAINIZE_7702297476189597070)],
        &[(0b01001, &ENTRY_PORCELAINIZED_8958345284962155259)],
        &[(0b01001, &ENTRY_PORCELAINIZES_1116700990546127264)],
        &[(0b01001, &ENTRY_PORCELAINIZING_2678178218886181111)],
        &[(0b10010, &ENTRY_PORCELLANIZE_5956584629780862310)],
        &[(0b10010, &ENTRY_PORCELLANIZED_12491685883750980597)],
        &[(0b10010, &ENTRY_PORCELLANIZES_17114777964969417887)],
        &[(0b10010, &ENTRY_PORCELLANIZING_6640350574304143446)],
        &[(0b01001, &ENTRY_PORCELLANIZE_5956584629780862310)],
        &[(0b01001, &ENTRY_PORCELLANIZED_12491685883750980597)],
        &[(0b01001, &ENTRY_PORCELLANIZES_17114777964969417887)],
        &[(0b01001, &ENTRY_PORCELLANIZING_6640350574304143446)],
        &[(0b00001, &ENTRY_PORER_9472582636394035687)],
        &[(0b00001, &ENTRY_PORERS_4411327756997706729)],
        &[(0b00001, &ENTRY_PORINGLY_740562095994905397)],
        &[(0b10010, &ENTRY_PORPHYRIZATION_15592157274159456926)],
        &[(0b01001, &ENTRY_PORPHYRIZATION_15592157274159456926)],
        &[(0b11010, &ENTRY_PORTE_13739395240559234500)],
        &[(0b00001, &ENTRY_PORTE_13739395240559234500)],
        &[(0b10010, &ENTRY_PORTIONIZE_8183616402693368236)],
        &[(0b10010, &ENTRY_PORTIONIZES_8759997646839791547)],
        &[(0b01001, &ENTRY_PORTIONIZE_8183616402693368236)],
        &[(0b01001, &ENTRY_PORTIONIZES_8759997646839791547)],
    ],
    range: 2..=14,
};

static VARS_POP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POP_CHILDREN),
    value: None,
};

pub static VARS_POP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("litaeal"),
        dictgen::InsensitiveStr::Ascii("liteal"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ulariser"),
        dictgen::InsensitiveStr::Ascii("ularisers"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizer"),
        dictgen::InsensitiveStr::Ascii("ularizers"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_POPLITEAL_14608064669039474519)],
        &[(0b00001, &ENTRY_POPLITEAL_14608064669039474519)],
        &[(0b10010, &ENTRY_POPULARIZATION_10295312737144065502)],
        &[(0b10010, &ENTRY_POPULARIZATIONS_10148778209943335276)],
        &[(0b10010, &ENTRY_POPULARIZE_17375893854271172775)],
        &[(0b10010, &ENTRY_POPULARIZED_13593967020396788947)],
        &[(0b10010, &ENTRY_POPULARIZER_6873378968353377212)],
        &[(0b10010, &ENTRY_POPULARIZERS_5104664749735053424)],
        &[(0b10010, &ENTRY_POPULARIZES_7700265923486687652)],
        &[(0b10010, &ENTRY_POPULARIZING_14605893405429303093)],
        &[(0b01001, &ENTRY_POPULARIZATION_10295312737144065502)],
        &[(0b01001, &ENTRY_POPULARIZATIONS_10148778209943335276)],
        &[(0b01001, &ENTRY_POPULARIZE_17375893854271172775)],
        &[(0b01001, &ENTRY_POPULARIZED_13593967020396788947)],
        &[(0b01001, &ENTRY_POPULARIZER_6873378968353377212)],
        &[(0b01001, &ENTRY_POPULARIZERS_5104664749735053424)],
        &[(0b01001, &ENTRY_POPULARIZES_7700265923486687652)],
        &[(0b01001, &ENTRY_POPULARIZING_14605893405429303093)],
    ],
    range: 6..=12,
};

static VARS_POM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POM_CHILDREN),
    value: None,
};

pub static VARS_POM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erium"),
        dictgen::InsensitiveStr::Ascii("mae"),
        dictgen::InsensitiveStr::Ascii("me"),
        dictgen::InsensitiveStr::Ascii("meled"),
        dictgen::InsensitiveStr::Ascii("meling"),
        dictgen::InsensitiveStr::Ascii("melled"),
        dictgen::InsensitiveStr::Ascii("melling"),
        dictgen::InsensitiveStr::Ascii("oerium"),
    ],
    values: &[
        &[(0b00001, &ENTRY_POMERIUM_7580577065603898743)],
        &[(0b11010, &ENTRY_POMME_11806614092839333597)],
        &[(0b00001, &ENTRY_POMME_11806614092839333597)],
        &[(0b00001, &ENTRY_POMMELED_16416408068787374405)],
        &[(0b00001, &ENTRY_POMMELING_3838938060420187338)],
        &[(0b11010, &ENTRY_POMMELED_16416408068787374405)],
        &[(0b11010, &ENTRY_POMMELING_3838938060420187338)],
        &[(0b11010, &ENTRY_POMERIUM_7580577065603898743)],
    ],
    range: 2..=7,
};

static VARS_POL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_POL_CHILDREN),
    value: None,
};

static VARS_POL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_POLA_NODE),
    None,
    None,
    None,
    Some(&VARS_POLE_NODE),
    None,
    None,
    None,
    Some(&VARS_POLI_NODE),
    None,
    None,
    Some(&VARS_POLL_NODE),
    None,
    None,
    Some(&VARS_POLO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_POLY_NODE),
    None,
];

static VARS_POLY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLY_CHILDREN),
    value: None,
};

pub static VARS_POLY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("chaetous"),
        dictgen::InsensitiveStr::Ascii("chetous"),
        dictgen::InsensitiveStr::Ascii("chromatise"),
        dictgen::InsensitiveStr::Ascii("chromatises"),
        dictgen::InsensitiveStr::Ascii("chromatize"),
        dictgen::InsensitiveStr::Ascii("chromatizes"),
        dictgen::InsensitiveStr::Ascii("chromise"),
        dictgen::InsensitiveStr::Ascii("chromises"),
        dictgen::InsensitiveStr::Ascii("chromize"),
        dictgen::InsensitiveStr::Ascii("chromizes"),
        dictgen::InsensitiveStr::Ascii("cythaemia"),
        dictgen::InsensitiveStr::Ascii("cythaemias"),
        dictgen::InsensitiveStr::Ascii("cythaemic"),
        dictgen::InsensitiveStr::Ascii("cythemia"),
        dictgen::InsensitiveStr::Ascii("cythemias"),
        dictgen::InsensitiveStr::Ascii("cythemic"),
        dictgen::InsensitiveStr::Ascii("daemonism"),
        dictgen::InsensitiveStr::Ascii("daemonisms"),
        dictgen::InsensitiveStr::Ascii("daemonist"),
        dictgen::InsensitiveStr::Ascii("demonism"),
        dictgen::InsensitiveStr::Ascii("demonisms"),
        dictgen::InsensitiveStr::Ascii("demonist"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("estrous"),
        dictgen::InsensitiveStr::Ascii("gamise"),
        dictgen::InsensitiveStr::Ascii("gamises"),
        dictgen::InsensitiveStr::Ascii("gamize"),
        dictgen::InsensitiveStr::Ascii("gamizes"),
        dictgen::InsensitiveStr::Ascii("haemia"),
        dictgen::InsensitiveStr::Ascii("haemic"),
        dictgen::InsensitiveStr::Ascii("hemia"),
        dictgen::InsensitiveStr::Ascii("hemic"),
        dictgen::InsensitiveStr::Ascii("merisation"),
        dictgen::InsensitiveStr::Ascii("merisations"),
        dictgen::InsensitiveStr::Ascii("merise"),
        dictgen::InsensitiveStr::Ascii("merised"),
        dictgen::InsensitiveStr::Ascii("merises"),
        dictgen::InsensitiveStr::Ascii("merising"),
        dictgen::InsensitiveStr::Ascii("merization"),
        dictgen::InsensitiveStr::Ascii("merizations"),
        dictgen::InsensitiveStr::Ascii("merize"),
        dictgen::InsensitiveStr::Ascii("merized"),
        dictgen::InsensitiveStr::Ascii("merizes"),
        dictgen::InsensitiveStr::Ascii("merizing"),
        dictgen::InsensitiveStr::Ascii("oestrous"),
        dictgen::InsensitiveStr::Ascii("pnea"),
        dictgen::InsensitiveStr::Ascii("pneic"),
        dictgen::InsensitiveStr::Ascii("pnoea"),
        dictgen::InsensitiveStr::Ascii("pnoeic"),
        dictgen::InsensitiveStr::Ascii("sulphurisation"),
        dictgen::InsensitiveStr::Ascii("sulphurisations"),
        dictgen::InsensitiveStr::Ascii("sulphurization"),
        dictgen::InsensitiveStr::Ascii("sulphurizations"),
        dictgen::InsensitiveStr::Ascii("tetrafluorethylene"),
        dictgen::InsensitiveStr::Ascii("tetrafluorethylenes"),
        dictgen::InsensitiveStr::Ascii("tetrafluoroethylene"),
        dictgen::InsensitiveStr::Ascii("tetrafluoroethylenes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_POLYEMIA_17781042628014686510)],
        &[(0b11010, &ENTRY_POLYEMIC_18304127681548786255)],
        &[(0b11010, &ENTRY_POLYCHETOUS_17197291065339885815)],
        &[(0b00001, &ENTRY_POLYCHETOUS_17197291065339885815)],
        &[(0b10010, &ENTRY_POLYCHROMATIZE_14431815754129053959)],
        &[(0b10010, &ENTRY_POLYCHROMATIZES_16629345361533556580)],
        &[(0b01001, &ENTRY_POLYCHROMATIZE_14431815754129053959)],
        &[(0b01001, &ENTRY_POLYCHROMATIZES_16629345361533556580)],
        &[(0b10010, &ENTRY_POLYCHROMIZE_13944884036814089178)],
        &[(0b10010, &ENTRY_POLYCHROMIZES_2277776581160811502)],
        &[(0b01001, &ENTRY_POLYCHROMIZE_13944884036814089178)],
        &[(0b01001, &ENTRY_POLYCHROMIZES_2277776581160811502)],
        &[(0b11010, &ENTRY_POLYCYTHEMIA_14165398609961484401)],
        &[(0b11010, &ENTRY_POLYCYTHEMIAS_7616824030036243533)],
        &[(0b11010, &ENTRY_POLYCYTHEMIC_5540881666593967005)],
        &[(0b10001, &ENTRY_POLYCYTHEMIA_14165398609961484401)],
        &[(0b10001, &ENTRY_POLYCYTHEMIAS_7616824030036243533)],
        &[(0b10001, &ENTRY_POLYCYTHEMIC_5540881666593967005)],
        &[(0b11010, &ENTRY_POLYDEMONISM_16806489744265358404)],
        &[(0b11010, &ENTRY_POLYDEMONISMS_17257398736277156608)],
        &[(0b11010, &ENTRY_POLYDEMONIST_2400662006979178253)],
        &[(0b00001, &ENTRY_POLYDEMONISM_16806489744265358404)],
        &[(0b00001, &ENTRY_POLYDEMONISMS_17257398736277156608)],
        &[(0b00001, &ENTRY_POLYDEMONIST_2400662006979178253)],
        &[(0b00001, &ENTRY_POLYEMIA_17781042628014686510)],
        &[(0b00001, &ENTRY_POLYEMIC_18304127681548786255)],
        &[(0b00001, &ENTRY_POLYESTROUS_2879884995798832892)],
        &[(0b10010, &ENTRY_POLYGAMIZE_4701005109108984743)],
        &[(0b10010, &ENTRY_POLYGAMIZES_4155489596892642301)],
        &[(0b01001, &ENTRY_POLYGAMIZE_4701005109108984743)],
        &[(0b01001, &ENTRY_POLYGAMIZES_4155489596892642301)],
        &[(0b11010, &ENTRY_POLYHEMIA_4404645305177677050)],
        &[(0b11010, &ENTRY_POLYHEMIC_8102827937421178102)],
        &[(0b00001, &ENTRY_POLYHEMIA_4404645305177677050)],
        &[(0b00001, &ENTRY_POLYHEMIC_8102827937421178102)],
        &[(0b10010, &ENTRY_POLYMERIZATION_18049461613528686745)],
        &[(0b10010, &ENTRY_POLYMERIZATIONS_1788553349915748767)],
        &[(0b10010, &ENTRY_POLYMERIZE_11038516628766467707)],
        &[(0b10010, &ENTRY_POLYMERIZED_12064504202018530181)],
        &[(0b10010, &ENTRY_POLYMERIZES_13931345882261943519)],
        &[(0b10010, &ENTRY_POLYMERIZING_15482080955154321693)],
        &[(0b01001, &ENTRY_POLYMERIZATION_18049461613528686745)],
        &[(0b01001, &ENTRY_POLYMERIZATIONS_1788553349915748767)],
        &[(0b01001, &ENTRY_POLYMERIZE_11038516628766467707)],
        &[(0b01001, &ENTRY_POLYMERIZED_12064504202018530181)],
        &[(0b01001, &ENTRY_POLYMERIZES_13931345882261943519)],
        &[(0b01001, &ENTRY_POLYMERIZING_15482080955154321693)],
        &[(0b11010, &ENTRY_POLYESTROUS_2879884995798832892)],
        &[(0b00001, &ENTRY_POLYPNEA_16221546989138969049)],
        &[(0b00001, &ENTRY_POLYPNEIC_6919979616272944790)],
        &[(0b11010, &ENTRY_POLYPNEA_16221546989138969049)],
        &[(0b11010, &ENTRY_POLYPNEIC_6919979616272944790)],
        &[(0b10010, &ENTRY_POLYSULPHURIZATION_16575270856614193114)],
        &[(0b10010, &ENTRY_POLYSULPHURIZATIONS_12547437930211655448)],
        &[(0b01001, &ENTRY_POLYSULPHURIZATION_16575270856614193114)],
        &[(0b01001, &ENTRY_POLYSULPHURIZATIONS_12547437930211655448)],
        &[(0b00001, &ENTRY_POLYTETRAFLUORETHYLENE_11537018490473818492)],
        &[(0b00001, &ENTRY_POLYTETRAFLUORETHYLENES_14333880617074724294)],
        &[(0b11010, &ENTRY_POLYTETRAFLUORETHYLENE_11537018490473818492)],
        &[(0b11010, &ENTRY_POLYTETRAFLUORETHYLENES_14333880617074724294)],
    ],
    range: 4..=20,
};

static VARS_POLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLO_CHILDREN),
    value: None,
};

pub static VARS_POLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLONIZATION_8741534032787718755)],
        &[(0b10010, &ENTRY_POLONIZE_9672172949014869969)],
        &[(0b10010, &ENTRY_POLONIZED_13808803990994600692)],
        &[(0b10010, &ENTRY_POLONIZES_1377448503955337088)],
        &[(0b10010, &ENTRY_POLONIZING_11665670612780971592)],
        &[(0b01001, &ENTRY_POLONIZATION_8741534032787718755)],
        &[(0b01001, &ENTRY_POLONIZE_9672172949014869969)],
        &[(0b01001, &ENTRY_POLONIZED_13808803990994600692)],
        &[(0b01001, &ENTRY_POLONIZES_1377448503955337088)],
        &[(0b01001, &ENTRY_POLONIZING_11665670612780971592)],
    ],
    range: 4..=8,
};

static VARS_POLL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLL_CHILDREN),
    value: None,
};

pub static VARS_POLL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eniser"),
        dictgen::InsensitiveStr::Ascii("enizer"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("iniser"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizer"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLLENIZER_5840287768704113985)],
        &[(0b01001, &ENTRY_POLLENIZER_5840287768704113985)],
        &[(0b10010, &ENTRY_POLLINIZE_10886640222621907817)],
        &[(0b10010, &ENTRY_POLLINIZED_6258305591882108144)],
        &[(0b10010, &ENTRY_POLLINIZER_6800524124081945052)],
        &[(0b10010, &ENTRY_POLLINIZES_11100365061845756268)],
        &[(0b10010, &ENTRY_POLLINIZING_4104790501701690763)],
        &[(0b01001, &ENTRY_POLLINIZE_10886640222621907817)],
        &[(0b01001, &ENTRY_POLLINIZED_6258305591882108144)],
        &[(0b01001, &ENTRY_POLLINIZER_6800524124081945052)],
        &[(0b01001, &ENTRY_POLLINIZES_11100365061845756268)],
        &[(0b01001, &ENTRY_POLLINIZING_4104790501701690763)],
    ],
    range: 5..=7,
};

static VARS_POLI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLI_CHILDREN),
    value: None,
};

pub static VARS_POLI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("ciser"),
        dictgen::InsensitiveStr::Ascii("cisers"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cizer"),
        dictgen::InsensitiveStr::Ascii("cizers"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("encephalitis"),
        dictgen::InsensitiveStr::Ascii("encephalomyelitis"),
        dictgen::InsensitiveStr::Ascii("oencephalitis"),
        dictgen::InsensitiveStr::Ascii("oencephalomyelitis"),
        dictgen::InsensitiveStr::Ascii("ticalise"),
        dictgen::InsensitiveStr::Ascii("ticalises"),
        dictgen::InsensitiveStr::Ascii("ticalize"),
        dictgen::InsensitiveStr::Ascii("ticalizes"),
        dictgen::InsensitiveStr::Ascii("ticisation"),
        dictgen::InsensitiveStr::Ascii("ticisations"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticiser"),
        dictgen::InsensitiveStr::Ascii("ticisers"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticization"),
        dictgen::InsensitiveStr::Ascii("ticizations"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizer"),
        dictgen::InsensitiveStr::Ascii("ticizers"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLICIZE_10899804007360448438)],
        &[(0b10010, &ENTRY_POLICIZER_7661480523981039298)],
        &[(0b10010, &ENTRY_POLICIZERS_8186732544489935409)],
        &[(0b10010, &ENTRY_POLICIZES_17833072986612710012)],
        &[(0b01001, &ENTRY_POLICIZE_10899804007360448438)],
        &[(0b01001, &ENTRY_POLICIZER_7661480523981039298)],
        &[(0b01001, &ENTRY_POLICIZERS_8186732544489935409)],
        &[(0b01001, &ENTRY_POLICIZES_17833072986612710012)],
        &[(0b00001, &ENTRY_POLIENCEPHALITIS_172737026792843669)],
        &[(0b00001, &ENTRY_POLIENCEPHALOMYELITIS_8330515026545676649)],
        &[(0b11010, &ENTRY_POLIENCEPHALITIS_172737026792843669)],
        &[(0b11010, &ENTRY_POLIENCEPHALOMYELITIS_8330515026545676649)],
        &[(0b10010, &ENTRY_POLITICALIZE_10489182143049842367)],
        &[(0b10010, &ENTRY_POLITICALIZES_14895104409541264986)],
        &[(0b01001, &ENTRY_POLITICALIZE_10489182143049842367)],
        &[(0b01001, &ENTRY_POLITICALIZES_14895104409541264986)],
        &[(0b10010, &ENTRY_POLITICIZATION_9693630840601338434)],
        &[(0b10010, &ENTRY_POLITICIZATIONS_16141763812889263962)],
        &[(0b10010, &ENTRY_POLITICIZE_1586885444741062386)],
        &[(0b10010, &ENTRY_POLITICIZED_9943489674474208118)],
        &[(0b10010, &ENTRY_POLITICIZER_8670872545261874659)],
        &[(0b10010, &ENTRY_POLITICIZERS_8269047630805008309)],
        &[(0b10010, &ENTRY_POLITICIZES_16334449170755490531)],
        &[(0b10010, &ENTRY_POLITICIZING_1898540618836719058)],
        &[(0b01001, &ENTRY_POLITICIZATION_9693630840601338434)],
        &[(0b01001, &ENTRY_POLITICIZATIONS_16141763812889263962)],
        &[(0b01001, &ENTRY_POLITICIZE_1586885444741062386)],
        &[(0b01001, &ENTRY_POLITICIZED_9943489674474208118)],
        &[(0b01001, &ENTRY_POLITICIZER_8670872545261874659)],
        &[(0b01001, &ENTRY_POLITICIZERS_8269047630805008309)],
        &[(0b01001, &ENTRY_POLITICIZES_16334449170755490531)],
        &[(0b01001, &ENTRY_POLITICIZING_1898540618836719058)],
        &[(0b10010, &ENTRY_POLITIZE_10652477445125067866)],
        &[(0b10010, &ENTRY_POLITIZES_15000365599209906701)],
        &[(0b01001, &ENTRY_POLITIZE_10652477445125067866)],
        &[(0b01001, &ENTRY_POLITIZES_15000365599209906701)],
    ],
    range: 4..=18,
};

static VARS_POLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLE_CHILDREN),
    value: None,
};

pub static VARS_POLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("micise"),
        dictgen::InsensitiveStr::Ascii("micised"),
        dictgen::InsensitiveStr::Ascii("micises"),
        dictgen::InsensitiveStr::Ascii("micising"),
        dictgen::InsensitiveStr::Ascii("micize"),
        dictgen::InsensitiveStr::Ascii("micized"),
        dictgen::InsensitiveStr::Ascii("micizes"),
        dictgen::InsensitiveStr::Ascii("micizing"),
        dictgen::InsensitiveStr::Ascii("mise"),
        dictgen::InsensitiveStr::Ascii("mised"),
        dictgen::InsensitiveStr::Ascii("mises"),
        dictgen::InsensitiveStr::Ascii("mising"),
        dictgen::InsensitiveStr::Ascii("mize"),
        dictgen::InsensitiveStr::Ascii("mized"),
        dictgen::InsensitiveStr::Ascii("mizes"),
        dictgen::InsensitiveStr::Ascii("mizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLEMICIZE_15883334541461649709)],
        &[(0b10010, &ENTRY_POLEMICIZED_13601254523654189992)],
        &[(0b10010, &ENTRY_POLEMICIZES_7887077854042670715)],
        &[(0b10010, &ENTRY_POLEMICIZING_15439521581223222709)],
        &[(0b01001, &ENTRY_POLEMICIZE_15883334541461649709)],
        &[(0b01001, &ENTRY_POLEMICIZED_13601254523654189992)],
        &[(0b01001, &ENTRY_POLEMICIZES_7887077854042670715)],
        &[(0b01001, &ENTRY_POLEMICIZING_15439521581223222709)],
        &[(0b10010, &ENTRY_POLEMIZE_2362684992503726512)],
        &[(0b10010, &ENTRY_POLEMIZED_5436292800704660484)],
        &[(0b10010, &ENTRY_POLEMIZES_15540925378458860831)],
        &[(0b10010, &ENTRY_POLEMIZING_15735246634115649723)],
        &[(0b01001, &ENTRY_POLEMIZE_2362684992503726512)],
        &[(0b01001, &ENTRY_POLEMIZED_5436292800704660484)],
        &[(0b01001, &ENTRY_POLEMIZES_15540925378458860831)],
        &[(0b01001, &ENTRY_POLEMIZING_15735246634115649723)],
    ],
    range: 4..=8,
};

static VARS_POLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POLA_CHILDREN),
    value: None,
};

pub static VARS_POLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("risabilities"),
        dictgen::InsensitiveStr::Ascii("risability"),
        dictgen::InsensitiveStr::Ascii("risable"),
        dictgen::InsensitiveStr::Ascii("risables"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("risers"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rizabilities"),
        dictgen::InsensitiveStr::Ascii("rizability"),
        dictgen::InsensitiveStr::Ascii("rizable"),
        dictgen::InsensitiveStr::Ascii("rizables"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizer"),
        dictgen::InsensitiveStr::Ascii("rizers"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POLARIZABILITIES_13289488269656306907)],
        &[(0b10010, &ENTRY_POLARIZABILITY_2003936501471489904)],
        &[(0b10010, &ENTRY_POLARIZABLE_7358307787201683785)],
        &[(0b10010, &ENTRY_POLARIZABLES_17746214108386056113)],
        &[(0b10010, &ENTRY_POLARIZATION_4404414468379288726)],
        &[(0b10010, &ENTRY_POLARIZATIONS_16811903515928848250)],
        &[(0b10010, &ENTRY_POLARIZE_4104034252753850020)],
        &[(0b10010, &ENTRY_POLARIZED_12877424935504157237)],
        &[(0b10010, &ENTRY_POLARIZER_3000102012663356590)],
        &[(0b10010, &ENTRY_POLARIZERS_4664406204726333551)],
        &[(0b10010, &ENTRY_POLARIZES_2266758101576701172)],
        &[(0b10010, &ENTRY_POLARIZING_7254748840434133551)],
        &[(0b01001, &ENTRY_POLARIZABILITIES_13289488269656306907)],
        &[(0b01001, &ENTRY_POLARIZABILITY_2003936501471489904)],
        &[(0b01001, &ENTRY_POLARIZABLE_7358307787201683785)],
        &[(0b01001, &ENTRY_POLARIZABLES_17746214108386056113)],
        &[(0b01001, &ENTRY_POLARIZATION_4404414468379288726)],
        &[(0b01001, &ENTRY_POLARIZATIONS_16811903515928848250)],
        &[(0b01001, &ENTRY_POLARIZE_4104034252753850020)],
        &[(0b01001, &ENTRY_POLARIZED_12877424935504157237)],
        &[(0b01001, &ENTRY_POLARIZER_3000102012663356590)],
        &[(0b01001, &ENTRY_POLARIZERS_4664406204726333551)],
        &[(0b01001, &ENTRY_POLARIZES_2266758101576701172)],
        &[(0b01001, &ENTRY_POLARIZING_7254748840434133551)],
    ],
    range: 4..=12,
};

static VARS_POG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POG_CHILDREN),
    value: None,
};

pub static VARS_POG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("romise"),
        dictgen::InsensitiveStr::Ascii("romises"),
        dictgen::InsensitiveStr::Ascii("romize"),
        dictgen::InsensitiveStr::Ascii("romizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POGROMIZE_6165616786920282232)],
        &[(0b10010, &ENTRY_POGROMIZES_15657629853908989575)],
        &[(0b01001, &ENTRY_POGROMIZE_6165616786920282232)],
        &[(0b01001, &ENTRY_POGROMIZES_15657629853908989575)],
    ],
    range: 6..=7,
};

static VARS_POE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_POE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_PE_11577855917495375674)]),
};

pub static VARS_POE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ticisation"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticization"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tisations"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tizations"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizer"),
        dictgen::InsensitiveStr::Ascii("tizers"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
        dictgen::InsensitiveStr::Ascii("tling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_POETICIZATION_3652192917145042403)],
        &[(0b10010, &ENTRY_POETICIZE_9872291277159870038)],
        &[(0b10010, &ENTRY_POETICIZED_12390573338020882499)],
        &[(0b10010, &ENTRY_POETICIZES_14806750979505922739)],
        &[(0b10010, &ENTRY_POETICIZING_612825552438033007)],
        &[(0b01001, &ENTRY_POETICIZATION_3652192917145042403)],
        &[(0b01001, &ENTRY_POETICIZE_9872291277159870038)],
        &[(0b01001, &ENTRY_POETICIZED_12390573338020882499)],
        &[(0b01001, &ENTRY_POETICIZES_14806750979505922739)],
        &[(0b01001, &ENTRY_POETICIZING_612825552438033007)],
        &[(0b10010, &ENTRY_POETIZATION_4980016800203199624)],
        &[(0b10010, &ENTRY_POETIZATIONS_14017988435836090874)],
        &[(0b10010, &ENTRY_POETIZE_12703762149983503651)],
        &[(0b10010, &ENTRY_POETIZED_1386961114003301059)],
        &[(0b10010, &ENTRY_POETIZER_6456895478682975622)],
        &[(0b10010, &ENTRY_POETIZERS_18165640128590713376)],
        &[(0b10010, &ENTRY_POETIZES_5644621901340662571)],
        &[(0b10010, &ENTRY_POETIZING_5617458256013617960)],
        &[(0b01001, &ENTRY_POETIZATION_4980016800203199624)],
        &[(0b01001, &ENTRY_POETIZATIONS_14017988435836090874)],
        &[(0b01001, &ENTRY_POETIZE_12703762149983503651)],
        &[(0b01001, &ENTRY_POETIZED_1386961114003301059)],
        &[(0b01001, &ENTRY_POETIZER_6456895478682975622)],
        &[(0b01001, &ENTRY_POETIZERS_18165640128590713376)],
        &[(0b01001, &ENTRY_POETIZES_5644621901340662571)],
        &[(0b01001, &ENTRY_POETIZING_5617458256013617960)],
        &[(0b11010, &ENTRY_PETLING_4679867327279057417)],
    ],
    range: 4..=10,
};

static VARS_PL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PL_CHILDREN),
    value: None,
};

static VARS_PL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PLA_NODE),
    None,
    None,
    None,
    Some(&VARS_PLE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PLU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_PLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLU_CHILDREN),
    value: None,
};

pub static VARS_PLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mulae"),
        dictgen::InsensitiveStr::Ascii("mule"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("raliser"),
        dictgen::InsensitiveStr::Ascii("ralisers"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizer"),
        dictgen::InsensitiveStr::Ascii("ralizers"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLUMULE_11005874244288887731)],
        &[(0b00001, &ENTRY_PLUMULE_11005874244288887731)],
        &[(0b10010, &ENTRY_PLURALIZATION_8169254968713730067)],
        &[(0b10010, &ENTRY_PLURALIZATIONS_1198848109390483960)],
        &[(0b10010, &ENTRY_PLURALIZE_4399070254818053480)],
        &[(0b10010, &ENTRY_PLURALIZED_3500489174231988842)],
        &[(0b10010, &ENTRY_PLURALIZER_1892398405711976310)],
        &[(0b10010, &ENTRY_PLURALIZERS_17783207971007642026)],
        &[(0b10010, &ENTRY_PLURALIZES_15840415766673228613)],
        &[(0b10010, &ENTRY_PLURALIZING_11743846805855674925)],
        &[(0b01001, &ENTRY_PLURALIZATION_8169254968713730067)],
        &[(0b01001, &ENTRY_PLURALIZATIONS_1198848109390483960)],
        &[(0b01001, &ENTRY_PLURALIZE_4399070254818053480)],
        &[(0b01001, &ENTRY_PLURALIZED_3500489174231988842)],
        &[(0b01001, &ENTRY_PLURALIZER_1892398405711976310)],
        &[(0b01001, &ENTRY_PLURALIZERS_17783207971007642026)],
        &[(0b01001, &ENTRY_PLURALIZES_15840415766673228613)],
        &[(0b01001, &ENTRY_PLURALIZING_11743846805855674925)],
    ],
    range: 4..=11,
};

static VARS_PLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLO_CHILDREN),
    value: None,
};

pub static VARS_PLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ugh"),
        dictgen::InsensitiveStr::Ascii("ughable"),
        dictgen::InsensitiveStr::Ascii("ughboy"),
        dictgen::InsensitiveStr::Ascii("ughboys"),
        dictgen::InsensitiveStr::Ascii("ughed"),
        dictgen::InsensitiveStr::Ascii("ugher"),
        dictgen::InsensitiveStr::Ascii("ughers"),
        dictgen::InsensitiveStr::Ascii("ughhead"),
        dictgen::InsensitiveStr::Ascii("ughing"),
        dictgen::InsensitiveStr::Ascii("ughman"),
        dictgen::InsensitiveStr::Ascii("ughmen"),
        dictgen::InsensitiveStr::Ascii("ughs"),
        dictgen::InsensitiveStr::Ascii("ughshare"),
        dictgen::InsensitiveStr::Ascii("ughshares"),
        dictgen::InsensitiveStr::Ascii("w"),
        dictgen::InsensitiveStr::Ascii("wable"),
        dictgen::InsensitiveStr::Ascii("wboy"),
        dictgen::InsensitiveStr::Ascii("wboys"),
        dictgen::InsensitiveStr::Ascii("wed"),
        dictgen::InsensitiveStr::Ascii("wer"),
        dictgen::InsensitiveStr::Ascii("wers"),
        dictgen::InsensitiveStr::Ascii("whead"),
        dictgen::InsensitiveStr::Ascii("wing"),
        dictgen::InsensitiveStr::Ascii("wman"),
        dictgen::InsensitiveStr::Ascii("wmen"),
        dictgen::InsensitiveStr::Ascii("ws"),
        dictgen::InsensitiveStr::Ascii("wshare"),
        dictgen::InsensitiveStr::Ascii("wshares"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLOW_15240143167426020265)],
        &[(0b10010, &ENTRY_PLOWABLE_714244179924658667)],
        &[(0b11010, &ENTRY_PLOWBOY_17926082723965440447)],
        &[(0b11010, &ENTRY_PLOWBOYS_15819867342839929654)],
        &[(0b11010, &ENTRY_PLOWED_2972982119152462143)],
        &[(0b10010, &ENTRY_PLOWER_2190961427050860856)],
        &[(0b10010, &ENTRY_PLOWERS_12826470249782049773)],
        &[(0b11010, &ENTRY_PLOWHEAD_14619897313081193220)],
        &[(0b11010, &ENTRY_PLOWING_16570546940479665223)],
        &[(0b11010, &ENTRY_PLOWMAN_13581836870693601113)],
        &[(0b11010, &ENTRY_PLOWMEN_15058389578896302329)],
        &[(0b11010, &ENTRY_PLOWS_17736521420248608990)],
        &[(0b11010, &ENTRY_PLOWSHARE_6048515192383180113)],
        &[(0b11010, &ENTRY_PLOWSHARES_10499526776608850484)],
        &[(0b01001, &ENTRY_PLOW_15240143167426020265)],
        &[(0b01001, &ENTRY_PLOWABLE_714244179924658667)],
        &[(0b00001, &ENTRY_PLOWBOY_17926082723965440447)],
        &[(0b00001, &ENTRY_PLOWBOYS_15819867342839929654)],
        &[(0b01001, &ENTRY_PLOWED_2972982119152462143)],
        &[(0b01001, &ENTRY_PLOWER_2190961427050860856)],
        &[(0b01001, &ENTRY_PLOWERS_12826470249782049773)],
        &[(0b00001, &ENTRY_PLOWHEAD_14619897313081193220)],
        &[(0b01001, &ENTRY_PLOWING_16570546940479665223)],
        &[(0b01001, &ENTRY_PLOWMAN_13581836870693601113)],
        &[(0b01001, &ENTRY_PLOWMEN_15058389578896302329)],
        &[(0b01001, &ENTRY_PLOWS_17736521420248608990)],
        &[(0b01001, &ENTRY_PLOWSHARE_6048515192383180113)],
        &[(0b01001, &ENTRY_PLOWSHARES_10499526776608850484)],
    ],
    range: 1..=9,
};

static VARS_PLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLE_CHILDREN),
    value: None,
};

pub static VARS_PLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("beianisation"),
        dictgen::InsensitiveStr::Ascii("beianise"),
        dictgen::InsensitiveStr::Ascii("beianised"),
        dictgen::InsensitiveStr::Ascii("beianises"),
        dictgen::InsensitiveStr::Ascii("beianising"),
        dictgen::InsensitiveStr::Ascii("beianization"),
        dictgen::InsensitiveStr::Ascii("beianize"),
        dictgen::InsensitiveStr::Ascii("beianized"),
        dictgen::InsensitiveStr::Ascii("beianizes"),
        dictgen::InsensitiveStr::Ascii("beianizing"),
        dictgen::InsensitiveStr::Ascii("uroperitonaeal"),
        dictgen::InsensitiveStr::Ascii("uroperitoneal"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PLEBEIANIZATION_4489677126502230770)],
        &[(0b10010, &ENTRY_PLEBEIANIZE_13948307616682534202)],
        &[(0b10010, &ENTRY_PLEBEIANIZED_12150770105441799169)],
        &[(0b10010, &ENTRY_PLEBEIANIZES_8283743331693072026)],
        &[(0b10010, &ENTRY_PLEBEIANIZING_18092068760405524948)],
        &[(0b01001, &ENTRY_PLEBEIANIZATION_4489677126502230770)],
        &[(0b01001, &ENTRY_PLEBEIANIZE_13948307616682534202)],
        &[(0b01001, &ENTRY_PLEBEIANIZED_12150770105441799169)],
        &[(0b01001, &ENTRY_PLEBEIANIZES_8283743331693072026)],
        &[(0b01001, &ENTRY_PLEBEIANIZING_18092068760405524948)],
        &[(0b11010, &ENTRY_PLEUROPERITONEAL_18421227973934406014)],
        &[(0b00001, &ENTRY_PLEUROPERITONEAL_18421227973934406014)],
    ],
    range: 8..=14,
};

static VARS_PLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PLA_CHILDREN),
    value: None,
};

static VARS_PLA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_PLAC_NODE),
    None,
    None,
    None,
    Some(&VARS_PLAG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PLAN_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PLAS_NODE),
    Some(&VARS_PLAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PLAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAT_CHILDREN),
    value: None,
};

pub static VARS_PLAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aea"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
        dictgen::InsensitiveStr::Ascii("itudinisation"),
        dictgen::InsensitiveStr::Ascii("itudinisations"),
        dictgen::InsensitiveStr::Ascii("itudinise"),
        dictgen::InsensitiveStr::Ascii("itudinised"),
        dictgen::InsensitiveStr::Ascii("itudiniser"),
        dictgen::InsensitiveStr::Ascii("itudinises"),
        dictgen::InsensitiveStr::Ascii("itudinising"),
        dictgen::InsensitiveStr::Ascii("itudinization"),
        dictgen::InsensitiveStr::Ascii("itudinizations"),
        dictgen::InsensitiveStr::Ascii("itudinize"),
        dictgen::InsensitiveStr::Ascii("itudinized"),
        dictgen::InsensitiveStr::Ascii("itudinizer"),
        dictgen::InsensitiveStr::Ascii("itudinizes"),
        dictgen::InsensitiveStr::Ascii("itudinizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("ycelian"),
        dictgen::InsensitiveStr::Ascii("ycelous"),
        dictgen::InsensitiveStr::Ascii("ycoelian"),
        dictgen::InsensitiveStr::Ascii("ycoelous"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLATEA_8349780907664188770)],
        &[(0b00001, &ENTRY_PLATEA_8349780907664188770)],
        &[(0b10010, &ENTRY_PLATINIZATION_7294928098928662795)],
        &[(0b10010, &ENTRY_PLATINIZATIONS_15552354246238607901)],
        &[(0b10010, &ENTRY_PLATINIZE_1605954097470852281)],
        &[(0b10010, &ENTRY_PLATINIZED_1054043595774840925)],
        &[(0b10010, &ENTRY_PLATINIZES_15021159787768685270)],
        &[(0b10010, &ENTRY_PLATINIZING_15398368952512453882)],
        &[(0b01001, &ENTRY_PLATINIZATION_7294928098928662795)],
        &[(0b01001, &ENTRY_PLATINIZATIONS_15552354246238607901)],
        &[(0b01001, &ENTRY_PLATINIZE_1605954097470852281)],
        &[(0b01001, &ENTRY_PLATINIZED_1054043595774840925)],
        &[(0b01001, &ENTRY_PLATINIZES_15021159787768685270)],
        &[(0b01001, &ENTRY_PLATINIZING_15398368952512453882)],
        &[(0b10010, &ENTRY_PLATITUDINIZATION_13708809875774352690)],
        &[(0b10010, &ENTRY_PLATITUDINIZATIONS_7700065669634779606)],
        &[(0b10010, &ENTRY_PLATITUDINIZE_16047744417590066437)],
        &[(0b10010, &ENTRY_PLATITUDINIZED_162055508592689397)],
        &[(0b10010, &ENTRY_PLATITUDINIZER_9937278398027092459)],
        &[(0b10010, &ENTRY_PLATITUDINIZES_4385490697041100884)],
        &[(0b10010, &ENTRY_PLATITUDINIZING_17727869419869709916)],
        &[(0b01001, &ENTRY_PLATITUDINIZATION_13708809875774352690)],
        &[(0b01001, &ENTRY_PLATITUDINIZATIONS_7700065669634779606)],
        &[(0b01001, &ENTRY_PLATITUDINIZE_16047744417590066437)],
        &[(0b01001, &ENTRY_PLATITUDINIZED_162055508592689397)],
        &[(0b01001, &ENTRY_PLATITUDINIZER_9937278398027092459)],
        &[(0b01001, &ENTRY_PLATITUDINIZES_4385490697041100884)],
        &[(0b01001, &ENTRY_PLATITUDINIZING_17727869419869709916)],
        &[(0b10010, &ENTRY_PLATONIZATION_7174077875190383867)],
        &[(0b10010, &ENTRY_PLATONIZE_16844425756925172171)],
        &[(0b10010, &ENTRY_PLATONIZED_17997626260125938103)],
        &[(0b10010, &ENTRY_PLATONIZER_3400111701490312811)],
        &[(0b10010, &ENTRY_PLATONIZES_12255582039294891460)],
        &[(0b10010, &ENTRY_PLATONIZING_3294563492691077109)],
        &[(0b01001, &ENTRY_PLATONIZATION_7174077875190383867)],
        &[(0b01001, &ENTRY_PLATONIZE_16844425756925172171)],
        &[(0b01001, &ENTRY_PLATONIZED_17997626260125938103)],
        &[(0b01001, &ENTRY_PLATONIZER_3400111701490312811)],
        &[(0b01001, &ENTRY_PLATONIZES_12255582039294891460)],
        &[(0b01001, &ENTRY_PLATONIZING_3294563492691077109)],
        &[(0b00001, &ENTRY_PLATYCELIAN_16729912161176580577)],
        &[(0b00001, &ENTRY_PLATYCELOUS_6600039705539585991)],
        &[(0b11010, &ENTRY_PLATYCELIAN_16729912161176580577)],
        &[(0b11010, &ENTRY_PLATYCELOUS_6600039705539585991)],
    ],
    range: 2..=14,
};

static VARS_PLAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAS_CHILDREN),
    value: None,
};

pub static VARS_PLAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maphaeresis"),
        dictgen::InsensitiveStr::Ascii("mapheresis"),
        dictgen::InsensitiveStr::Ascii("molyse"),
        dictgen::InsensitiveStr::Ascii("molysed"),
        dictgen::InsensitiveStr::Ascii("molyses"),
        dictgen::InsensitiveStr::Ascii("molysing"),
        dictgen::InsensitiveStr::Ascii("molyze"),
        dictgen::InsensitiveStr::Ascii("molyzed"),
        dictgen::InsensitiveStr::Ascii("molyzes"),
        dictgen::InsensitiveStr::Ascii("molyzing"),
        dictgen::InsensitiveStr::Ascii("ticisation"),
        dictgen::InsensitiveStr::Ascii("ticisations"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticiser"),
        dictgen::InsensitiveStr::Ascii("ticisers"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticization"),
        dictgen::InsensitiveStr::Ascii("ticizations"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizer"),
        dictgen::InsensitiveStr::Ascii("ticizers"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLASMAPHERESIS_1508628979977175584)],
        &[(0b00001, &ENTRY_PLASMAPHERESIS_1508628979977175584)],
        &[(0b11010, &ENTRY_PLASMOLYZE_7108165619266701720)],
        &[(0b11010, &ENTRY_PLASMOLYZED_1073560925313062172)],
        &[(0b11010, &ENTRY_PLASMOLYZES_14848652000638172841)],
        &[(0b11010, &ENTRY_PLASMOLYZING_14342415833639819900)],
        &[(0b00001, &ENTRY_PLASMOLYZE_7108165619266701720)],
        &[(0b00001, &ENTRY_PLASMOLYZED_1073560925313062172)],
        &[(0b00001, &ENTRY_PLASMOLYZES_14848652000638172841)],
        &[(0b00001, &ENTRY_PLASMOLYZING_14342415833639819900)],
        &[(0b10010, &ENTRY_PLASTICIZATION_14104512748126545924)],
        &[(0b10010, &ENTRY_PLASTICIZATIONS_8714202375888992754)],
        &[(0b10010, &ENTRY_PLASTICIZE_5295414425579558521)],
        &[(0b10010, &ENTRY_PLASTICIZED_1092409437998471695)],
        &[(0b10010, &ENTRY_PLASTICIZER_4503458591975420540)],
        &[(0b10010, &ENTRY_PLASTICIZERS_1689438428234931431)],
        &[(0b10010, &ENTRY_PLASTICIZES_14237267039551578506)],
        &[(0b10010, &ENTRY_PLASTICIZING_10532662878530701536)],
        &[(0b01001, &ENTRY_PLASTICIZATION_14104512748126545924)],
        &[(0b01001, &ENTRY_PLASTICIZATIONS_8714202375888992754)],
        &[(0b01001, &ENTRY_PLASTICIZE_5295414425579558521)],
        &[(0b01001, &ENTRY_PLASTICIZED_1092409437998471695)],
        &[(0b01001, &ENTRY_PLASTICIZER_4503458591975420540)],
        &[(0b01001, &ENTRY_PLASTICIZERS_1689438428234931431)],
        &[(0b01001, &ENTRY_PLASTICIZES_14237267039551578506)],
        &[(0b01001, &ENTRY_PLASTICIZING_10532662878530701536)],
    ],
    range: 6..=11,
};

static VARS_PLAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAN_CHILDREN),
    value: None,
};

pub static VARS_PLAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tulae"),
        dictgen::InsensitiveStr::Ascii("tule"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLANTE_15938795954501174987)],
        &[(0b00001, &ENTRY_PLANTE_15938795954501174987)],
        &[(0b11010, &ENTRY_PLANTULE_7509094958023933361)],
        &[(0b00001, &ENTRY_PLANTULE_7509094958023933361)],
    ],
    range: 2..=5,
};

static VARS_PLAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAG_CHILDREN),
    value: None,
};

pub static VARS_PLAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("iarisation"),
        dictgen::InsensitiveStr::Ascii("iarisations"),
        dictgen::InsensitiveStr::Ascii("iarise"),
        dictgen::InsensitiveStr::Ascii("iarised"),
        dictgen::InsensitiveStr::Ascii("iariser"),
        dictgen::InsensitiveStr::Ascii("iarisers"),
        dictgen::InsensitiveStr::Ascii("iarises"),
        dictgen::InsensitiveStr::Ascii("iarising"),
        dictgen::InsensitiveStr::Ascii("iarization"),
        dictgen::InsensitiveStr::Ascii("iarizations"),
        dictgen::InsensitiveStr::Ascii("iarize"),
        dictgen::InsensitiveStr::Ascii("iarized"),
        dictgen::InsensitiveStr::Ascii("iarizer"),
        dictgen::InsensitiveStr::Ascii("iarizers"),
        dictgen::InsensitiveStr::Ascii("iarizes"),
        dictgen::InsensitiveStr::Ascii("iarizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLAGE_5780289291015820410)],
        &[(0b00001, &ENTRY_PLAGE_5780289291015820410)],
        &[(0b10010, &ENTRY_PLAGIARIZATION_4700253329027850825)],
        &[(0b10010, &ENTRY_PLAGIARIZATIONS_3623763755946048017)],
        &[(0b10010, &ENTRY_PLAGIARIZE_3775190677956286864)],
        &[(0b10010, &ENTRY_PLAGIARIZED_12321658142956326932)],
        &[(0b10010, &ENTRY_PLAGIARIZER_6131721956520951955)],
        &[(0b10010, &ENTRY_PLAGIARIZERS_4000297058035207269)],
        &[(0b10010, &ENTRY_PLAGIARIZES_3079051217833247235)],
        &[(0b10010, &ENTRY_PLAGIARIZING_6331297137787838542)],
        &[(0b01001, &ENTRY_PLAGIARIZATION_4700253329027850825)],
        &[(0b01001, &ENTRY_PLAGIARIZATIONS_3623763755946048017)],
        &[(0b01001, &ENTRY_PLAGIARIZE_3775190677956286864)],
        &[(0b01001, &ENTRY_PLAGIARIZED_12321658142956326932)],
        &[(0b01001, &ENTRY_PLAGIARIZER_6131721956520951955)],
        &[(0b01001, &ENTRY_PLAGIARIZERS_4000297058035207269)],
        &[(0b01001, &ENTRY_PLAGIARIZES_3079051217833247235)],
        &[(0b01001, &ENTRY_PLAGIARIZING_6331297137787838542)],
    ],
    range: 1..=11,
};

static VARS_PLAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PLAC_CHILDREN),
    value: None,
};

pub static VARS_PLAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("ean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PLACEAN_10780406184619843162)],
        &[(0b00001, &ENTRY_PLACEAN_10780406184619843162)],
    ],
    range: 3..=4,
};

static VARS_PI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PI_CHILDREN),
    value: None,
};

static VARS_PI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PIA_NODE),
    None,
    Some(&VARS_PIC_NODE),
    Some(&VARS_PID_NODE),
    None,
    None,
    Some(&VARS_PIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PIL_NODE),
    None,
    Some(&VARS_PIN_NODE),
    None,
    None,
    None,
    Some(&VARS_PIR_NODE),
    Some(&VARS_PIS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PIZ_NODE),
];

static VARS_PIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIZ_CHILDREN),
    value: None,
};

pub static VARS_PIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("es")],
    values: &[&[(0b01001, &ENTRY_PIZES_15927503519599533301)]],
    range: 2..=2,
};

static VARS_PIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIS_CHILDREN),
    value: None,
};

pub static VARS_PIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cinae"),
        dictgen::InsensitiveStr::Ascii("cine"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("toled"),
        dictgen::InsensitiveStr::Ascii("toling"),
        dictgen::InsensitiveStr::Ascii("tolled"),
        dictgen::InsensitiveStr::Ascii("tolling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PISCINE_5027149564915569308)],
        &[(0b00001, &ENTRY_PISCINE_5027149564915569308)],
        &[(0b10010, &ENTRY_PIZES_15927503519599533301)],
        &[(0b00001, &ENTRY_PISTOLED_14184147191541856361)],
        &[(0b00001, &ENTRY_PISTOLING_10255809735953360817)],
        &[(0b11010, &ENTRY_PISTOLED_14184147191541856361)],
        &[(0b11010, &ENTRY_PISTOLING_10255809735953360817)],
    ],
    range: 2..=7,
};

static VARS_PIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIR_CHILDREN),
    value: None,
};

pub static VARS_PIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PIRATIZE_6749125827462808539)],
        &[(0b10010, &ENTRY_PIRATIZES_8919560401490093200)],
        &[(0b01001, &ENTRY_PIRATIZE_6749125827462808539)],
        &[(0b01001, &ENTRY_PIRATIZES_8919560401490093200)],
    ],
    range: 5..=6,
};

static VARS_PIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIN_CHILDREN),
    value: None,
};

pub static VARS_PIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("darise"),
        dictgen::InsensitiveStr::Ascii("darised"),
        dictgen::InsensitiveStr::Ascii("darises"),
        dictgen::InsensitiveStr::Ascii("darising"),
        dictgen::InsensitiveStr::Ascii("darize"),
        dictgen::InsensitiveStr::Ascii("darized"),
        dictgen::InsensitiveStr::Ascii("darizes"),
        dictgen::InsensitiveStr::Ascii("darizing"),
        dictgen::InsensitiveStr::Ascii("nulae"),
        dictgen::InsensitiveStr::Ascii("nule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PINDARIZE_3371672470278825880)],
        &[(0b10010, &ENTRY_PINDARIZED_6373523452419605770)],
        &[(0b10010, &ENTRY_PINDARIZES_4435880422606251900)],
        &[(0b10010, &ENTRY_PINDARIZING_9646845228045121987)],
        &[(0b01001, &ENTRY_PINDARIZE_3371672470278825880)],
        &[(0b01001, &ENTRY_PINDARIZED_6373523452419605770)],
        &[(0b01001, &ENTRY_PINDARIZES_4435880422606251900)],
        &[(0b01001, &ENTRY_PINDARIZING_9646845228045121987)],
        &[(0b11010, &ENTRY_PINNULE_585935578756924342)],
        &[(0b00001, &ENTRY_PINNULE_585935578756924342)],
    ],
    range: 4..=8,
};

static VARS_PIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIL_CHILDREN),
    value: None,
};

pub static VARS_PIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("grimise"),
        dictgen::InsensitiveStr::Ascii("grimised"),
        dictgen::InsensitiveStr::Ascii("grimises"),
        dictgen::InsensitiveStr::Ascii("grimising"),
        dictgen::InsensitiveStr::Ascii("grimize"),
        dictgen::InsensitiveStr::Ascii("grimized"),
        dictgen::InsensitiveStr::Ascii("grimizes"),
        dictgen::InsensitiveStr::Ascii("grimizing"),
        dictgen::InsensitiveStr::Ascii("larise"),
        dictgen::InsensitiveStr::Ascii("larises"),
        dictgen::InsensitiveStr::Ascii("larize"),
        dictgen::InsensitiveStr::Ascii("larizes"),
        dictgen::InsensitiveStr::Ascii("lorise"),
        dictgen::InsensitiveStr::Ascii("lorised"),
        dictgen::InsensitiveStr::Ascii("lorises"),
        dictgen::InsensitiveStr::Ascii("lorising"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorized"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
        dictgen::InsensitiveStr::Ascii("lorizing"),
        dictgen::InsensitiveStr::Ascii("lowbeer"),
        dictgen::InsensitiveStr::Ascii("lowbere"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PILGRIMIZE_15115937713453969329)],
        &[(0b10010, &ENTRY_PILGRIMIZED_11204759801928429576)],
        &[(0b10010, &ENTRY_PILGRIMIZES_245368581812668914)],
        &[(0b10010, &ENTRY_PILGRIMIZING_9980588741013675877)],
        &[(0b01001, &ENTRY_PILGRIMIZE_15115937713453969329)],
        &[(0b01001, &ENTRY_PILGRIMIZED_11204759801928429576)],
        &[(0b01001, &ENTRY_PILGRIMIZES_245368581812668914)],
        &[(0b01001, &ENTRY_PILGRIMIZING_9980588741013675877)],
        &[(0b10010, &ENTRY_PILLARIZE_9018246236618645996)],
        &[(0b10010, &ENTRY_PILLARIZES_17692578717946990918)],
        &[(0b01001, &ENTRY_PILLARIZE_9018246236618645996)],
        &[(0b01001, &ENTRY_PILLARIZES_17692578717946990918)],
        &[(0b10010, &ENTRY_PILLORIZE_7161828989665068634)],
        &[(0b10010, &ENTRY_PILLORIZED_894715813225067108)],
        &[(0b10010, &ENTRY_PILLORIZES_12687325336889895788)],
        &[(0b10010, &ENTRY_PILLORIZING_16890095566787510096)],
        &[(0b01001, &ENTRY_PILLORIZE_7161828989665068634)],
        &[(0b01001, &ENTRY_PILLORIZED_894715813225067108)],
        &[(0b01001, &ENTRY_PILLORIZES_12687325336889895788)],
        &[(0b01001, &ENTRY_PILLORIZING_16890095566787510096)],
        &[(0b00001, &ENTRY_PILLOWBEER_7601320084724894311)],
        &[(0b11010, &ENTRY_PILLOWBEER_7601320084724894311)],
    ],
    range: 6..=9,
};

static VARS_PIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIG_CHILDREN),
    value: None,
};

pub static VARS_PIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maean"),
        dictgen::InsensitiveStr::Ascii("mean"),
        dictgen::InsensitiveStr::Ascii("mentise"),
        dictgen::InsensitiveStr::Ascii("mentises"),
        dictgen::InsensitiveStr::Ascii("mentize"),
        dictgen::InsensitiveStr::Ascii("mentizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PIGMEAN_838416186676693472)],
        &[(0b00001, &ENTRY_PIGMEAN_838416186676693472)],
        &[(0b10010, &ENTRY_PIGMENTIZE_17000768533660304435)],
        &[(0b10010, &ENTRY_PIGMENTIZES_7839824677968960729)],
        &[(0b01001, &ENTRY_PIGMENTIZE_17000768533660304435)],
        &[(0b01001, &ENTRY_PIGMENTIZES_7839824677968960729)],
    ],
    range: 4..=8,
};

static VARS_PID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PID_CHILDREN),
    value: None,
};

pub static VARS_PID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ginisation"),
        dictgen::InsensitiveStr::Ascii("ginisations"),
        dictgen::InsensitiveStr::Ascii("ginise"),
        dictgen::InsensitiveStr::Ascii("ginised"),
        dictgen::InsensitiveStr::Ascii("ginises"),
        dictgen::InsensitiveStr::Ascii("ginising"),
        dictgen::InsensitiveStr::Ascii("ginization"),
        dictgen::InsensitiveStr::Ascii("ginizations"),
        dictgen::InsensitiveStr::Ascii("ginize"),
        dictgen::InsensitiveStr::Ascii("ginized"),
        dictgen::InsensitiveStr::Ascii("ginizes"),
        dictgen::InsensitiveStr::Ascii("ginizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PIDGINIZATION_4247850683463639292)],
        &[(0b10010, &ENTRY_PIDGINIZATIONS_12337613956252475858)],
        &[(0b10010, &ENTRY_PIDGINIZE_16450854328377794588)],
        &[(0b10010, &ENTRY_PIDGINIZED_9275549597676109200)],
        &[(0b10010, &ENTRY_PIDGINIZES_9819290300342306986)],
        &[(0b10010, &ENTRY_PIDGINIZING_1233279765890722824)],
        &[(0b01001, &ENTRY_PIDGINIZATION_4247850683463639292)],
        &[(0b01001, &ENTRY_PIDGINIZATIONS_12337613956252475858)],
        &[(0b01001, &ENTRY_PIDGINIZE_16450854328377794588)],
        &[(0b01001, &ENTRY_PIDGINIZED_9275549597676109200)],
        &[(0b01001, &ENTRY_PIDGINIZES_9819290300342306986)],
        &[(0b01001, &ENTRY_PIDGINIZING_1233279765890722824)],
    ],
    range: 6..=11,
};

static VARS_PIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIC_CHILDREN),
    value: None,
};

pub static VARS_PIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogram"),
        dictgen::InsensitiveStr::Ascii("ogramme"),
        dictgen::InsensitiveStr::Ascii("ogrammes"),
        dictgen::InsensitiveStr::Ascii("ograms"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ometers"),
        dictgen::InsensitiveStr::Ascii("ometre"),
        dictgen::InsensitiveStr::Ascii("ometres"),
        dictgen::InsensitiveStr::Ascii("torialisation"),
        dictgen::InsensitiveStr::Ascii("torialisations"),
        dictgen::InsensitiveStr::Ascii("torialise"),
        dictgen::InsensitiveStr::Ascii("torialised"),
        dictgen::InsensitiveStr::Ascii("torialises"),
        dictgen::InsensitiveStr::Ascii("torialising"),
        dictgen::InsensitiveStr::Ascii("torialization"),
        dictgen::InsensitiveStr::Ascii("torializations"),
        dictgen::InsensitiveStr::Ascii("torialize"),
        dictgen::InsensitiveStr::Ascii("torialized"),
        dictgen::InsensitiveStr::Ascii("torializes"),
        dictgen::InsensitiveStr::Ascii("torializing"),
        dictgen::InsensitiveStr::Ascii("turisation"),
        dictgen::InsensitiveStr::Ascii("turisations"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turization"),
        dictgen::InsensitiveStr::Ascii("turizations"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_PICOGRAM_11350367043126236604)],
        &[(0b10010, &ENTRY_PICOGRAM_11350367043126236604)],
        &[(0b10010, &ENTRY_PICOGRAMS_10906014752748869240)],
        &[(0b01001, &ENTRY_PICOGRAMS_10906014752748869240)],
        &[(0b00001, &ENTRY_PICOMETER_2628061784674895811)],
        &[(0b00001, &ENTRY_PICOMETERS_12211512401784472293)],
        &[(0b11010, &ENTRY_PICOMETER_2628061784674895811)],
        &[(0b11010, &ENTRY_PICOMETERS_12211512401784472293)],
        &[(0b10010, &ENTRY_PICTORIALIZATION_14708484463367740539)],
        &[(0b10010, &ENTRY_PICTORIALIZATIONS_4913660434215340848)],
        &[(0b10010, &ENTRY_PICTORIALIZE_17160489486570007365)],
        &[(0b10010, &ENTRY_PICTORIALIZED_4300804023861683584)],
        &[(0b10010, &ENTRY_PICTORIALIZES_17175738548381080003)],
        &[(0b10010, &ENTRY_PICTORIALIZING_4361304323804901214)],
        &[(0b01001, &ENTRY_PICTORIALIZATION_14708484463367740539)],
        &[(0b01001, &ENTRY_PICTORIALIZATIONS_4913660434215340848)],
        &[(0b01001, &ENTRY_PICTORIALIZE_17160489486570007365)],
        &[(0b01001, &ENTRY_PICTORIALIZED_4300804023861683584)],
        &[(0b01001, &ENTRY_PICTORIALIZES_17175738548381080003)],
        &[(0b01001, &ENTRY_PICTORIALIZING_4361304323804901214)],
        &[(0b10010, &ENTRY_PICTURIZATION_16841013829361902460)],
        &[(0b10010, &ENTRY_PICTURIZATIONS_8940902236643797185)],
        &[(0b10010, &ENTRY_PICTURIZE_9024247702062369559)],
        &[(0b10010, &ENTRY_PICTURIZED_3383491133099344173)],
        &[(0b10010, &ENTRY_PICTURIZES_9102727891294622822)],
        &[(0b10010, &ENTRY_PICTURIZING_10815202759366884688)],
        &[(0b01001, &ENTRY_PICTURIZATION_16841013829361902460)],
        &[(0b01001, &ENTRY_PICTURIZATIONS_8940902236643797185)],
        &[(0b01001, &ENTRY_PICTURIZE_9024247702062369559)],
        &[(0b01001, &ENTRY_PICTURIZED_3383491133099344173)],
        &[(0b01001, &ENTRY_PICTURIZES_9102727891294622822)],
        &[(0b01001, &ENTRY_PICTURIZING_10815202759366884688)],
    ],
    range: 5..=14,
};

static VARS_PIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PIA_CHILDREN),
    value: None,
};

pub static VARS_PIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rhaemic"),
        dictgen::InsensitiveStr::Ascii("rhemic"),
        dictgen::InsensitiveStr::Ascii("ster"),
        dictgen::InsensitiveStr::Ascii("sters"),
        dictgen::InsensitiveStr::Ascii("stre"),
        dictgen::InsensitiveStr::Ascii("stres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PIARHEMIC_4373779022618005958)],
        &[(0b00001, &ENTRY_PIARHEMIC_4373779022618005958)],
        &[(0b00001, &ENTRY_PIASTER_13635975646054450930)],
        &[(0b00001, &ENTRY_PIASTERS_16176301200771126280)],
        &[(0b11010, &ENTRY_PIASTER_13635975646054450930)],
        &[(0b11010, &ENTRY_PIASTERS_16176301200771126280)],
    ],
    range: 4..=7,
};

static VARS_PH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PH_CHILDREN),
    value: None,
};

static VARS_PH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PHA_NODE),
    None,
    None,
    None,
    Some(&VARS_PHE_NODE),
    None,
    None,
    None,
    Some(&VARS_PHI_NODE),
    None,
    None,
    Some(&VARS_PHL_NODE),
    None,
    None,
    Some(&VARS_PHO_NODE),
    None,
    None,
    Some(&VARS_PHR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PHY_NODE),
    None,
];

static VARS_PHY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHY_CHILDREN),
    value: None,
};

pub static VARS_PHY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lactolaema"),
        dictgen::InsensitiveStr::Ascii("lactolaemata"),
        dictgen::InsensitiveStr::Ascii("lactolema"),
        dictgen::InsensitiveStr::Ascii("lactolemata"),
        dictgen::InsensitiveStr::Ascii("toecology"),
        dictgen::InsensitiveStr::Ascii("tohaemagglutinin"),
        dictgen::InsensitiveStr::Ascii("tohemagglutinin"),
        dictgen::InsensitiveStr::Ascii("tooecology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHYLACTOLEMA_17387053296583525798)],
        &[(0b11010, &ENTRY_PHYLACTOLEMATA_15645283540839306050)],
        &[(0b00001, &ENTRY_PHYLACTOLEMA_17387053296583525798)],
        &[(0b00001, &ENTRY_PHYLACTOLEMATA_15645283540839306050)],
        &[(0b00001, &ENTRY_PHYTOECOLOGY_3833250044946066382)],
        &[(0b11010, &ENTRY_PHYTOHEMAGGLUTININ_8708803765514094222)],
        &[(0b00001, &ENTRY_PHYTOHEMAGGLUTININ_8708803765514094222)],
        &[(0b11010, &ENTRY_PHYTOECOLOGY_3833250044946066382)],
    ],
    range: 9..=16,
};

static VARS_PHR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHR_CHILDREN),
    value: None,
};

pub static VARS_PHR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enologise"),
        dictgen::InsensitiveStr::Ascii("enologised"),
        dictgen::InsensitiveStr::Ascii("enologises"),
        dictgen::InsensitiveStr::Ascii("enologising"),
        dictgen::InsensitiveStr::Ascii("enologize"),
        dictgen::InsensitiveStr::Ascii("enologized"),
        dictgen::InsensitiveStr::Ascii("enologizes"),
        dictgen::InsensitiveStr::Ascii("enologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PHRENOLOGIZE_12593199073368999981)],
        &[(0b10010, &ENTRY_PHRENOLOGIZED_5269289788245932959)],
        &[(0b10010, &ENTRY_PHRENOLOGIZES_9501866944819113429)],
        &[(0b10010, &ENTRY_PHRENOLOGIZING_16363166802450050044)],
        &[(0b01001, &ENTRY_PHRENOLOGIZE_12593199073368999981)],
        &[(0b01001, &ENTRY_PHRENOLOGIZED_5269289788245932959)],
        &[(0b01001, &ENTRY_PHRENOLOGIZES_9501866944819113429)],
        &[(0b01001, &ENTRY_PHRENOLOGIZING_16363166802450050044)],
    ],
    range: 9..=11,
};

static VARS_PHO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PHO_CHILDREN),
    value: None,
};

static VARS_PHO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_PHOC_NODE),
    None,
    Some(&VARS_PHOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PHON_NODE),
    None,
    None,
    None,
    Some(&VARS_PHOR_NODE),
    Some(&VARS_PHOS_NODE),
    Some(&VARS_PHOT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PHOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PHOT_CHILDREN),
    value: None,
};

static VARS_PHOT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PHOTA_NODE),
    None,
    None,
    None,
    Some(&VARS_PHOTE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PHOTO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PHOTO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOTO_CHILDREN),
    value: None,
};

pub static VARS_PHOTO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthetic"),
        dictgen::InsensitiveStr::Ascii("catalyser"),
        dictgen::InsensitiveStr::Ascii("catalysers"),
        dictgen::InsensitiveStr::Ascii("catalyzer"),
        dictgen::InsensitiveStr::Ascii("catalyzers"),
        dictgen::InsensitiveStr::Ascii("esthesis"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("graphise"),
        dictgen::InsensitiveStr::Ascii("graphises"),
        dictgen::InsensitiveStr::Ascii("graphize"),
        dictgen::InsensitiveStr::Ascii("graphizes"),
        dictgen::InsensitiveStr::Ascii("ionisation"),
        dictgen::InsensitiveStr::Ascii("ionisations"),
        dictgen::InsensitiveStr::Ascii("ionization"),
        dictgen::InsensitiveStr::Ascii("ionizations"),
        dictgen::InsensitiveStr::Ascii("isomerisation"),
        dictgen::InsensitiveStr::Ascii("isomerisations"),
        dictgen::InsensitiveStr::Ascii("isomerization"),
        dictgen::InsensitiveStr::Ascii("isomerizations"),
        dictgen::InsensitiveStr::Ascii("labeled"),
        dictgen::InsensitiveStr::Ascii("labeler"),
        dictgen::InsensitiveStr::Ascii("labeling"),
        dictgen::InsensitiveStr::Ascii("labelled"),
        dictgen::InsensitiveStr::Ascii("labeller"),
        dictgen::InsensitiveStr::Ascii("labelling"),
        dictgen::InsensitiveStr::Ascii("lysable"),
        dictgen::InsensitiveStr::Ascii("lyse"),
        dictgen::InsensitiveStr::Ascii("lysed"),
        dictgen::InsensitiveStr::Ascii("lyses"),
        dictgen::InsensitiveStr::Ascii("lysing"),
        dictgen::InsensitiveStr::Ascii("lyzable"),
        dictgen::InsensitiveStr::Ascii("lyze"),
        dictgen::InsensitiveStr::Ascii("lyzed"),
        dictgen::InsensitiveStr::Ascii("lyzes"),
        dictgen::InsensitiveStr::Ascii("lyzing"),
        dictgen::InsensitiveStr::Ascii("polymerisation"),
        dictgen::InsensitiveStr::Ascii("polymerisations"),
        dictgen::InsensitiveStr::Ascii("polymerization"),
        dictgen::InsensitiveStr::Ascii("polymerizations"),
        dictgen::InsensitiveStr::Ascii("sensitisation"),
        dictgen::InsensitiveStr::Ascii("sensitisations"),
        dictgen::InsensitiveStr::Ascii("sensitise"),
        dictgen::InsensitiveStr::Ascii("sensitised"),
        dictgen::InsensitiveStr::Ascii("sensitiser"),
        dictgen::InsensitiveStr::Ascii("sensitisers"),
        dictgen::InsensitiveStr::Ascii("sensitises"),
        dictgen::InsensitiveStr::Ascii("sensitising"),
        dictgen::InsensitiveStr::Ascii("sensitization"),
        dictgen::InsensitiveStr::Ascii("sensitizations"),
        dictgen::InsensitiveStr::Ascii("sensitize"),
        dictgen::InsensitiveStr::Ascii("sensitized"),
        dictgen::InsensitiveStr::Ascii("sensitizer"),
        dictgen::InsensitiveStr::Ascii("sensitizers"),
        dictgen::InsensitiveStr::Ascii("sensitizes"),
        dictgen::InsensitiveStr::Ascii("sensitizing"),
        dictgen::InsensitiveStr::Ascii("synthesise"),
        dictgen::InsensitiveStr::Ascii("synthesised"),
        dictgen::InsensitiveStr::Ascii("synthesises"),
        dictgen::InsensitiveStr::Ascii("synthesising"),
        dictgen::InsensitiveStr::Ascii("synthesize"),
        dictgen::InsensitiveStr::Ascii("synthesized"),
        dictgen::InsensitiveStr::Ascii("synthesizes"),
        dictgen::InsensitiveStr::Ascii("synthesizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHOTOESTHETIC_6617324081715374387)],
        &[(0b11010, &ENTRY_PHOTOCATALYZER_11050841619007985543)],
        &[(0b11010, &ENTRY_PHOTOCATALYZERS_13764405179670914256)],
        &[(0b00001, &ENTRY_PHOTOCATALYZER_11050841619007985543)],
        &[(0b00001, &ENTRY_PHOTOCATALYZERS_13764405179670914256)],
        &[(0b11010, &ENTRY_PHOTESTHESIS_17727520840546347652)],
        &[(0b00001, &ENTRY_PHOTOESTHETIC_6617324081715374387)],
        &[(0b10010, &ENTRY_PHOTOGRAPHIZE_3680030487733185738)],
        &[(0b10010, &ENTRY_PHOTOGRAPHIZES_7246623188004089530)],
        &[(0b01001, &ENTRY_PHOTOGRAPHIZE_3680030487733185738)],
        &[(0b01001, &ENTRY_PHOTOGRAPHIZES_7246623188004089530)],
        &[(0b10010, &ENTRY_PHOTOIONIZATION_3174791429214154918)],
        &[(0b10010, &ENTRY_PHOTOIONIZATIONS_4578393814749909045)],
        &[(0b01001, &ENTRY_PHOTOIONIZATION_3174791429214154918)],
        &[(0b01001, &ENTRY_PHOTOIONIZATIONS_4578393814749909045)],
        &[(0b10010, &ENTRY_PHOTOISOMERIZATION_6751720425527323933)],
        &[(0b10010, &ENTRY_PHOTOISOMERIZATIONS_14085447749077811360)],
        &[(0b01001, &ENTRY_PHOTOISOMERIZATION_6751720425527323933)],
        &[(0b01001, &ENTRY_PHOTOISOMERIZATIONS_14085447749077811360)],
        &[(0b00001, &ENTRY_PHOTOLABELED_9221461550333475470)],
        &[(0b00001, &ENTRY_PHOTOLABELER_13495566989885803749)],
        &[(0b00001, &ENTRY_PHOTOLABELING_12804494872614821285)],
        &[(0b11010, &ENTRY_PHOTOLABELED_9221461550333475470)],
        &[(0b11010, &ENTRY_PHOTOLABELER_13495566989885803749)],
        &[(0b11010, &ENTRY_PHOTOLABELING_12804494872614821285)],
        &[(0b11010, &ENTRY_PHOTOLYZABLE_1307676699359278891)],
        &[(0b10010, &ENTRY_PHOTOLYZE_16302775288316268906)],
        &[(0b10010, &ENTRY_PHOTOLYZED_15412604323863050603)],
        &[(0b10010, &ENTRY_PHOTOLYZES_13815346102662155645)],
        &[(0b10010, &ENTRY_PHOTOLYZING_5023754747286858353)],
        &[(0b00001, &ENTRY_PHOTOLYZABLE_1307676699359278891)],
        &[(0b01001, &ENTRY_PHOTOLYZE_16302775288316268906)],
        &[(0b01001, &ENTRY_PHOTOLYZED_15412604323863050603)],
        &[(0b01001, &ENTRY_PHOTOLYZES_13815346102662155645)],
        &[(0b01001, &ENTRY_PHOTOLYZING_5023754747286858353)],
        &[(0b10010, &ENTRY_PHOTOPOLYMERIZATION_16063694208716353085)],
        &[(0b10010, &ENTRY_PHOTOPOLYMERIZATIONS_5207608956609586528)],
        &[(0b01001, &ENTRY_PHOTOPOLYMERIZATION_16063694208716353085)],
        &[(0b01001, &ENTRY_PHOTOPOLYMERIZATIONS_5207608956609586528)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZATION_5069654584948615148)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZATIONS_13004505883705820957)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZE_8288914178365456711)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZED_12285633572666221887)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZER_16139858535991349387)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZERS_9865390720202085290)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZES_9120738511428773132)],
        &[(0b10010, &ENTRY_PHOTOSENSITIZING_2349728015045574141)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZATION_5069654584948615148)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZATIONS_13004505883705820957)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZE_8288914178365456711)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZED_12285633572666221887)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZER_16139858535991349387)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZERS_9865390720202085290)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZES_9120738511428773132)],
        &[(0b01001, &ENTRY_PHOTOSENSITIZING_2349728015045574141)],
        &[(0b10010, &ENTRY_PHOTOSYNTHESIZE_16528133077473184545)],
        &[(0b10010, &ENTRY_PHOTOSYNTHESIZED_4022833954742135604)],
        &[(0b10010, &ENTRY_PHOTOSYNTHESIZES_11615882972300115120)],
        &[(0b10010, &ENTRY_PHOTOSYNTHESIZING_1052004418989698159)],
        &[(0b01001, &ENTRY_PHOTOSYNTHESIZE_16528133077473184545)],
        &[(0b01001, &ENTRY_PHOTOSYNTHESIZED_4022833954742135604)],
        &[(0b01001, &ENTRY_PHOTOSYNTHESIZES_11615882972300115120)],
        &[(0b01001, &ENTRY_PHOTOSYNTHESIZING_1052004418989698159)],
    ],
    range: 4..=15,
};

static VARS_PHOTE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOTE_CHILDREN),
    value: None,
};

pub static VARS_PHOTE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("sthesis")],
    values: &[&[
        (0b00001, &ENTRY_PHOTESTHESIS_17727520840546347652),
        (0b00001, &ENTRY_PHOTESTHESIS_6981549980908445509),
    ]],
    range: 7..=7,
};

static VARS_PHOTA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOTA_CHILDREN),
    value: None,
};

pub static VARS_PHOTA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("esthesis")],
    values: &[&[(0b11010, &ENTRY_PHOTESTHESIS_6981549980908445509)]],
    range: 8..=8,
};

static VARS_PHOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOS_CHILDREN),
    value: None,
};

pub static VARS_PHOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("phatisation"),
        dictgen::InsensitiveStr::Ascii("phatisations"),
        dictgen::InsensitiveStr::Ascii("phatise"),
        dictgen::InsensitiveStr::Ascii("phatised"),
        dictgen::InsensitiveStr::Ascii("phatises"),
        dictgen::InsensitiveStr::Ascii("phatising"),
        dictgen::InsensitiveStr::Ascii("phatization"),
        dictgen::InsensitiveStr::Ascii("phatizations"),
        dictgen::InsensitiveStr::Ascii("phatize"),
        dictgen::InsensitiveStr::Ascii("phatized"),
        dictgen::InsensitiveStr::Ascii("phatizes"),
        dictgen::InsensitiveStr::Ascii("phatizing"),
        dictgen::InsensitiveStr::Ascii("phorise"),
        dictgen::InsensitiveStr::Ascii("phorised"),
        dictgen::InsensitiveStr::Ascii("phorises"),
        dictgen::InsensitiveStr::Ascii("phorising"),
        dictgen::InsensitiveStr::Ascii("phorize"),
        dictgen::InsensitiveStr::Ascii("phorized"),
        dictgen::InsensitiveStr::Ascii("phorizes"),
        dictgen::InsensitiveStr::Ascii("phorizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PHOSPHATIZATION_4175899370839304733)],
        &[(0b10010, &ENTRY_PHOSPHATIZATIONS_12255974002935158132)],
        &[(0b10010, &ENTRY_PHOSPHATIZE_589509609004210876)],
        &[(0b10010, &ENTRY_PHOSPHATIZED_8578950796519736557)],
        &[(0b10010, &ENTRY_PHOSPHATIZES_5129360819999903073)],
        &[(0b10010, &ENTRY_PHOSPHATIZING_4826539255258763256)],
        &[(0b01001, &ENTRY_PHOSPHATIZATION_4175899370839304733)],
        &[(0b01001, &ENTRY_PHOSPHATIZATIONS_12255974002935158132)],
        &[(0b01001, &ENTRY_PHOSPHATIZE_589509609004210876)],
        &[(0b01001, &ENTRY_PHOSPHATIZED_8578950796519736557)],
        &[(0b01001, &ENTRY_PHOSPHATIZES_5129360819999903073)],
        &[(0b01001, &ENTRY_PHOSPHATIZING_4826539255258763256)],
        &[(0b10010, &ENTRY_PHOSPHORIZE_13215518786176964054)],
        &[(0b10010, &ENTRY_PHOSPHORIZED_3504819966842929193)],
        &[(0b10010, &ENTRY_PHOSPHORIZES_17522331139923456458)],
        &[(0b10010, &ENTRY_PHOSPHORIZING_12248460229299793587)],
        &[(0b01001, &ENTRY_PHOSPHORIZE_13215518786176964054)],
        &[(0b01001, &ENTRY_PHOSPHORIZED_3504819966842929193)],
        &[(0b01001, &ENTRY_PHOSPHORIZES_17522331139923456458)],
        &[(0b01001, &ENTRY_PHOSPHORIZING_12248460229299793587)],
    ],
    range: 7..=12,
};

static VARS_PHOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOR_CHILDREN),
    value: None,
};

pub static VARS_PHOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rhea"),
        dictgen::InsensitiveStr::Ascii("rhoea"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PHORRHEA_13208068197196345881)],
        &[(0b11010, &ENTRY_PHORRHEA_13208068197196345881)],
    ],
    range: 4..=5,
};

static VARS_PHON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHON_CHILDREN),
    value: None,
};

pub static VARS_PHON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emicisation"),
        dictgen::InsensitiveStr::Ascii("emicisations"),
        dictgen::InsensitiveStr::Ascii("emicise"),
        dictgen::InsensitiveStr::Ascii("emicised"),
        dictgen::InsensitiveStr::Ascii("emicises"),
        dictgen::InsensitiveStr::Ascii("emicising"),
        dictgen::InsensitiveStr::Ascii("emicization"),
        dictgen::InsensitiveStr::Ascii("emicizations"),
        dictgen::InsensitiveStr::Ascii("emicize"),
        dictgen::InsensitiveStr::Ascii("emicized"),
        dictgen::InsensitiveStr::Ascii("emicizes"),
        dictgen::InsensitiveStr::Ascii("emicizing"),
        dictgen::InsensitiveStr::Ascii("eticisation"),
        dictgen::InsensitiveStr::Ascii("eticisations"),
        dictgen::InsensitiveStr::Ascii("eticise"),
        dictgen::InsensitiveStr::Ascii("eticised"),
        dictgen::InsensitiveStr::Ascii("eticises"),
        dictgen::InsensitiveStr::Ascii("eticising"),
        dictgen::InsensitiveStr::Ascii("eticization"),
        dictgen::InsensitiveStr::Ascii("eticizations"),
        dictgen::InsensitiveStr::Ascii("eticize"),
        dictgen::InsensitiveStr::Ascii("eticized"),
        dictgen::InsensitiveStr::Ascii("eticizes"),
        dictgen::InsensitiveStr::Ascii("eticizing"),
        dictgen::InsensitiveStr::Ascii("etisation"),
        dictgen::InsensitiveStr::Ascii("etisations"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etization"),
        dictgen::InsensitiveStr::Ascii("etizations"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
        dictgen::InsensitiveStr::Ascii("eyed"),
        dictgen::InsensitiveStr::Ascii("eying"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PHONEMICIZATION_6303074211462240322)],
        &[(0b10010, &ENTRY_PHONEMICIZATIONS_11036149124276358577)],
        &[(0b10010, &ENTRY_PHONEMICIZE_1810541375439591225)],
        &[(0b10010, &ENTRY_PHONEMICIZED_17232917412462599644)],
        &[(0b10010, &ENTRY_PHONEMICIZES_17606626718946608666)],
        &[(0b10010, &ENTRY_PHONEMICIZING_15981242182632342378)],
        &[(0b01001, &ENTRY_PHONEMICIZATION_6303074211462240322)],
        &[(0b01001, &ENTRY_PHONEMICIZATIONS_11036149124276358577)],
        &[(0b01001, &ENTRY_PHONEMICIZE_1810541375439591225)],
        &[(0b01001, &ENTRY_PHONEMICIZED_17232917412462599644)],
        &[(0b01001, &ENTRY_PHONEMICIZES_17606626718946608666)],
        &[(0b01001, &ENTRY_PHONEMICIZING_15981242182632342378)],
        &[(0b10010, &ENTRY_PHONETICIZATION_6365986386084047589)],
        &[(0b10010, &ENTRY_PHONETICIZATIONS_12272721619858915699)],
        &[(0b10010, &ENTRY_PHONETICIZE_2002370945385634969)],
        &[(0b10010, &ENTRY_PHONETICIZED_10076514556044395589)],
        &[(0b10010, &ENTRY_PHONETICIZES_5738497385018760916)],
        &[(0b10010, &ENTRY_PHONETICIZING_10352945092040857910)],
        &[(0b01001, &ENTRY_PHONETICIZATION_6365986386084047589)],
        &[(0b01001, &ENTRY_PHONETICIZATIONS_12272721619858915699)],
        &[(0b01001, &ENTRY_PHONETICIZE_2002370945385634969)],
        &[(0b01001, &ENTRY_PHONETICIZED_10076514556044395589)],
        &[(0b01001, &ENTRY_PHONETICIZES_5738497385018760916)],
        &[(0b01001, &ENTRY_PHONETICIZING_10352945092040857910)],
        &[(0b10010, &ENTRY_PHONETIZATION_5080772382710194175)],
        &[(0b10010, &ENTRY_PHONETIZATIONS_1478303085829485731)],
        &[(0b10010, &ENTRY_PHONETIZE_3810717706362844733)],
        &[(0b10010, &ENTRY_PHONETIZED_11767329492705150794)],
        &[(0b10010, &ENTRY_PHONETIZES_242560119274525330)],
        &[(0b10010, &ENTRY_PHONETIZING_14395480576666108961)],
        &[(0b01001, &ENTRY_PHONETIZATION_5080772382710194175)],
        &[(0b01001, &ENTRY_PHONETIZATIONS_1478303085829485731)],
        &[(0b01001, &ENTRY_PHONETIZE_3810717706362844733)],
        &[(0b01001, &ENTRY_PHONETIZED_11767329492705150794)],
        &[(0b01001, &ENTRY_PHONETIZES_242560119274525330)],
        &[(0b01001, &ENTRY_PHONETIZING_14395480576666108961)],
        &[(0b00001, &ENTRY_PHONIED_13398169357989663661)],
        &[(0b00001, &ENTRY_PHONYING_3078208997195609574)],
    ],
    range: 4..=12,
};

static VARS_PHOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOE_CHILDREN),
    value: None,
};

pub static VARS_PHOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nicia"),
        dictgen::InsensitiveStr::Ascii("nicopter"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHENICIA_14934589472014784294)],
        &[(0b11010, &ENTRY_PHENICOPTER_102813840191262241)],
    ],
    range: 5..=8,
};

static VARS_PHOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHOC_CHILDREN),
    value: None,
};

pub static VARS_PHOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("ean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHOCEAN_7579607581288728415)],
        &[(0b00001, &ENTRY_PHOCEAN_7579607581288728415)],
    ],
    range: 3..=4,
};

static VARS_PHL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHL_CHILDREN),
    value: None,
};

pub static VARS_PHL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ebotomisation"),
        dictgen::InsensitiveStr::Ascii("ebotomisations"),
        dictgen::InsensitiveStr::Ascii("ebotomise"),
        dictgen::InsensitiveStr::Ascii("ebotomised"),
        dictgen::InsensitiveStr::Ascii("ebotomises"),
        dictgen::InsensitiveStr::Ascii("ebotomising"),
        dictgen::InsensitiveStr::Ascii("ebotomization"),
        dictgen::InsensitiveStr::Ascii("ebotomizations"),
        dictgen::InsensitiveStr::Ascii("ebotomize"),
        dictgen::InsensitiveStr::Ascii("ebotomized"),
        dictgen::InsensitiveStr::Ascii("ebotomizes"),
        dictgen::InsensitiveStr::Ascii("ebotomizing"),
        dictgen::InsensitiveStr::Ascii("eum"),
        dictgen::InsensitiveStr::Ascii("oeum"),
        dictgen::InsensitiveStr::Ascii("yctaena"),
        dictgen::InsensitiveStr::Ascii("yctaenae"),
        dictgen::InsensitiveStr::Ascii("yctaenula"),
        dictgen::InsensitiveStr::Ascii("yctena"),
        dictgen::InsensitiveStr::Ascii("yctenae"),
        dictgen::InsensitiveStr::Ascii("yctenula"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PHLEBOTOMIZATION_17488495197793456474)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZATIONS_3737256506686661609)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZE_13394579245233538581)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZED_970872551213502213)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZES_14047846782365849478)],
        &[(0b10010, &ENTRY_PHLEBOTOMIZING_11774110694895870408)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZATION_17488495197793456474)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZATIONS_3737256506686661609)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZE_13394579245233538581)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZED_970872551213502213)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZES_14047846782365849478)],
        &[(0b01001, &ENTRY_PHLEBOTOMIZING_11774110694895870408)],
        &[(0b00001, &ENTRY_PHLEUM_16719770166396319761)],
        &[(0b11010, &ENTRY_PHLEUM_16719770166396319761)],
        &[(0b11010, &ENTRY_PHLYCTENA_8261775604592086893)],
        &[(0b11010, &ENTRY_PHLYCTENAE_12296549464075244070)],
        &[(0b11010, &ENTRY_PHLYCTENULA_6345950092510926138)],
        &[(0b00001, &ENTRY_PHLYCTENA_8261775604592086893)],
        &[(0b00001, &ENTRY_PHLYCTENAE_12296549464075244070)],
        &[(0b00001, &ENTRY_PHLYCTENULA_6345950092510926138)],
    ],
    range: 3..=14,
};

static VARS_PHI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHI_CHILDREN),
    value: None,
};

pub static VARS_PHI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alae"),
        dictgen::InsensitiveStr::Ascii("ale"),
        dictgen::InsensitiveStr::Ascii("lanthropise"),
        dictgen::InsensitiveStr::Ascii("lanthropised"),
        dictgen::InsensitiveStr::Ascii("lanthropises"),
        dictgen::InsensitiveStr::Ascii("lanthropising"),
        dictgen::InsensitiveStr::Ascii("lanthropize"),
        dictgen::InsensitiveStr::Ascii("lanthropized"),
        dictgen::InsensitiveStr::Ascii("lanthropizes"),
        dictgen::InsensitiveStr::Ascii("lanthropizing"),
        dictgen::InsensitiveStr::Ascii("lippise"),
        dictgen::InsensitiveStr::Ascii("lippised"),
        dictgen::InsensitiveStr::Ascii("lippises"),
        dictgen::InsensitiveStr::Ascii("lippising"),
        dictgen::InsensitiveStr::Ascii("lippize"),
        dictgen::InsensitiveStr::Ascii("lippized"),
        dictgen::InsensitiveStr::Ascii("lippizes"),
        dictgen::InsensitiveStr::Ascii("lippizing"),
        dictgen::InsensitiveStr::Ascii("listinise"),
        dictgen::InsensitiveStr::Ascii("listinised"),
        dictgen::InsensitiveStr::Ascii("listinises"),
        dictgen::InsensitiveStr::Ascii("listinising"),
        dictgen::InsensitiveStr::Ascii("listinize"),
        dictgen::InsensitiveStr::Ascii("listinized"),
        dictgen::InsensitiveStr::Ascii("listinizes"),
        dictgen::InsensitiveStr::Ascii("listinizing"),
        dictgen::InsensitiveStr::Ascii("lopena"),
        dictgen::InsensitiveStr::Ascii("lopenas"),
        dictgen::InsensitiveStr::Ascii("lopoena"),
        dictgen::InsensitiveStr::Ascii("lopoenas"),
        dictgen::InsensitiveStr::Ascii("losophisation"),
        dictgen::InsensitiveStr::Ascii("losophisations"),
        dictgen::InsensitiveStr::Ascii("losophise"),
        dictgen::InsensitiveStr::Ascii("losophised"),
        dictgen::InsensitiveStr::Ascii("losophiser"),
        dictgen::InsensitiveStr::Ascii("losophisers"),
        dictgen::InsensitiveStr::Ascii("losophises"),
        dictgen::InsensitiveStr::Ascii("losophising"),
        dictgen::InsensitiveStr::Ascii("losophization"),
        dictgen::InsensitiveStr::Ascii("losophizations"),
        dictgen::InsensitiveStr::Ascii("losophize"),
        dictgen::InsensitiveStr::Ascii("losophized"),
        dictgen::InsensitiveStr::Ascii("losophizer"),
        dictgen::InsensitiveStr::Ascii("losophizers"),
        dictgen::InsensitiveStr::Ascii("losophizes"),
        dictgen::InsensitiveStr::Ascii("losophizing"),
        dictgen::InsensitiveStr::Ascii("lter"),
        dictgen::InsensitiveStr::Ascii("lters"),
        dictgen::InsensitiveStr::Ascii("ltre"),
        dictgen::InsensitiveStr::Ascii("ltres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHIALE_15569191502692089501)],
        &[(0b00001, &ENTRY_PHIALE_15569191502692089501)],
        &[(0b10010, &ENTRY_PHILANTHROPIZE_12054368829621898817)],
        &[(0b10010, &ENTRY_PHILANTHROPIZED_17491092524543553798)],
        &[(0b10010, &ENTRY_PHILANTHROPIZES_151487037009790340)],
        &[(0b10010, &ENTRY_PHILANTHROPIZING_8217762732269119746)],
        &[(0b01001, &ENTRY_PHILANTHROPIZE_12054368829621898817)],
        &[(0b01001, &ENTRY_PHILANTHROPIZED_17491092524543553798)],
        &[(0b01001, &ENTRY_PHILANTHROPIZES_151487037009790340)],
        &[(0b01001, &ENTRY_PHILANTHROPIZING_8217762732269119746)],
        &[(0b10010, &ENTRY_PHILIPPIZE_9477479770062521505)],
        &[(0b10010, &ENTRY_PHILIPPIZED_178919350171556335)],
        &[(0b10010, &ENTRY_PHILIPPIZES_14363488635976035891)],
        &[(0b10010, &ENTRY_PHILIPPIZING_12349528995152369239)],
        &[(0b01001, &ENTRY_PHILIPPIZE_9477479770062521505)],
        &[(0b01001, &ENTRY_PHILIPPIZED_178919350171556335)],
        &[(0b01001, &ENTRY_PHILIPPIZES_14363488635976035891)],
        &[(0b01001, &ENTRY_PHILIPPIZING_12349528995152369239)],
        &[(0b10010, &ENTRY_PHILISTINIZE_16879618291594956234)],
        &[(0b10010, &ENTRY_PHILISTINIZED_6164180281250753702)],
        &[(0b10010, &ENTRY_PHILISTINIZES_3022920025750648291)],
        &[(0b10010, &ENTRY_PHILISTINIZING_14787991683374543288)],
        &[(0b01001, &ENTRY_PHILISTINIZE_16879618291594956234)],
        &[(0b01001, &ENTRY_PHILISTINIZED_6164180281250753702)],
        &[(0b01001, &ENTRY_PHILISTINIZES_3022920025750648291)],
        &[(0b01001, &ENTRY_PHILISTINIZING_14787991683374543288)],
        &[(0b00001, &ENTRY_PHILOPENA_14474550932692405335)],
        &[(0b00001, &ENTRY_PHILOPENAS_8942731290254359945)],
        &[(0b11010, &ENTRY_PHILOPENA_14474550932692405335)],
        &[(0b11010, &ENTRY_PHILOPENAS_8942731290254359945)],
        &[(0b10010, &ENTRY_PHILOSOPHIZATION_16601469055263628196)],
        &[(0b10010, &ENTRY_PHILOSOPHIZATIONS_1471954898649055414)],
        &[(0b10010, &ENTRY_PHILOSOPHIZE_13043053738496452138)],
        &[(0b10010, &ENTRY_PHILOSOPHIZED_11971381862609038159)],
        &[(0b10010, &ENTRY_PHILOSOPHIZER_1947368971791216137)],
        &[(0b10010, &ENTRY_PHILOSOPHIZERS_9374939330362272451)],
        &[(0b10010, &ENTRY_PHILOSOPHIZES_9120030685330947055)],
        &[(0b10010, &ENTRY_PHILOSOPHIZING_7182661913083580067)],
        &[(0b01001, &ENTRY_PHILOSOPHIZATION_16601469055263628196)],
        &[(0b01001, &ENTRY_PHILOSOPHIZATIONS_1471954898649055414)],
        &[(0b01001, &ENTRY_PHILOSOPHIZE_13043053738496452138)],
        &[(0b01001, &ENTRY_PHILOSOPHIZED_11971381862609038159)],
        &[(0b01001, &ENTRY_PHILOSOPHIZER_1947368971791216137)],
        &[(0b01001, &ENTRY_PHILOSOPHIZERS_9374939330362272451)],
        &[(0b01001, &ENTRY_PHILOSOPHIZES_9120030685330947055)],
        &[(0b01001, &ENTRY_PHILOSOPHIZING_7182661913083580067)],
        &[(0b00001, &ENTRY_PHILTER_15997600924358339768)],
        &[(0b00001, &ENTRY_PHILTERS_13502292058065280597)],
        &[(0b11010, &ENTRY_PHILTER_15997600924358339768)],
        &[(0b11010, &ENTRY_PHILTERS_13502292058065280597)],
    ],
    range: 3..=14,
};

static VARS_PHE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHE_CHILDREN),
    value: None,
};

pub static VARS_PHE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lonion"),
        dictgen::InsensitiveStr::Ascii("lonions"),
        dictgen::InsensitiveStr::Ascii("nicia"),
        dictgen::InsensitiveStr::Ascii("nicopter"),
        dictgen::InsensitiveStr::Ascii("nogam"),
        dictgen::InsensitiveStr::Ascii("nogams"),
        dictgen::InsensitiveStr::Ascii("nogenesis"),
        dictgen::InsensitiveStr::Ascii("nogenetic"),
        dictgen::InsensitiveStr::Ascii("nolisation"),
        dictgen::InsensitiveStr::Ascii("nolisations"),
        dictgen::InsensitiveStr::Ascii("nolise"),
        dictgen::InsensitiveStr::Ascii("nolises"),
        dictgen::InsensitiveStr::Ascii("nolization"),
        dictgen::InsensitiveStr::Ascii("nolizations"),
        dictgen::InsensitiveStr::Ascii("nolize"),
        dictgen::InsensitiveStr::Ascii("nolizes"),
        dictgen::InsensitiveStr::Ascii("nological"),
        dictgen::InsensitiveStr::Ascii("nologies"),
        dictgen::InsensitiveStr::Ascii("nology"),
        dictgen::InsensitiveStr::Ascii("nomenalisation"),
        dictgen::InsensitiveStr::Ascii("nomenalisations"),
        dictgen::InsensitiveStr::Ascii("nomenalise"),
        dictgen::InsensitiveStr::Ascii("nomenalised"),
        dictgen::InsensitiveStr::Ascii("nomenalises"),
        dictgen::InsensitiveStr::Ascii("nomenalising"),
        dictgen::InsensitiveStr::Ascii("nomenalization"),
        dictgen::InsensitiveStr::Ascii("nomenalizations"),
        dictgen::InsensitiveStr::Ascii("nomenalize"),
        dictgen::InsensitiveStr::Ascii("nomenalized"),
        dictgen::InsensitiveStr::Ascii("nomenalizes"),
        dictgen::InsensitiveStr::Ascii("nomenalizing"),
        dictgen::InsensitiveStr::Ascii("nomenise"),
        dictgen::InsensitiveStr::Ascii("nomenised"),
        dictgen::InsensitiveStr::Ascii("nomenises"),
        dictgen::InsensitiveStr::Ascii("nomenising"),
        dictgen::InsensitiveStr::Ascii("nomenism"),
        dictgen::InsensitiveStr::Ascii("nomenize"),
        dictgen::InsensitiveStr::Ascii("nomenized"),
        dictgen::InsensitiveStr::Ascii("nomenizes"),
        dictgen::InsensitiveStr::Ascii("nomenizing"),
        dictgen::InsensitiveStr::Ascii("nozygous"),
        dictgen::InsensitiveStr::Ascii("ophyl"),
        dictgen::InsensitiveStr::Ascii("ophyll"),
        dictgen::InsensitiveStr::Ascii("ophytin"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PHELONION_6969396090547227356)],
        &[(0b00001, &ENTRY_PHELONIONS_7275701311297650329)],
        &[(0b00001, &ENTRY_PHENICIA_14934589472014784294)],
        &[(0b00001, &ENTRY_PHENICOPTER_102813840191262241)],
        &[(0b00001, &ENTRY_PHENOGAM_2031537475522870003)],
        &[(0b00001, &ENTRY_PHENOGAMS_16570370822932628992)],
        &[(0b00001, &ENTRY_PHENOGENESIS_17567829228271993340)],
        &[(0b00001, &ENTRY_PHENOGENETIC_17720618598147822936)],
        &[(0b10010, &ENTRY_PHENOLIZATION_2757248655281103600)],
        &[(0b10010, &ENTRY_PHENOLIZATIONS_14432785009139345517)],
        &[(0b10010, &ENTRY_PHENOLIZE_13707720084951712605)],
        &[(0b10010, &ENTRY_PHENOLIZES_7668478898891743701)],
        &[(0b01001, &ENTRY_PHENOLIZATION_2757248655281103600)],
        &[(0b01001, &ENTRY_PHENOLIZATIONS_14432785009139345517)],
        &[(0b01001, &ENTRY_PHENOLIZE_13707720084951712605)],
        &[(0b01001, &ENTRY_PHENOLIZES_7668478898891743701)],
        &[(0b00001, &ENTRY_PHENOLOGICAL_18143589645340253850)],
        &[(0b00001, &ENTRY_PHENOLOGIES_16864158914924322992)],
        &[(0b00001, &ENTRY_PHENOLOGY_10696299477585495820)],
        &[(0b10010, &ENTRY_PHENOMENALIZATION_3655891833450393811)],
        &[(0b10010, &ENTRY_PHENOMENALIZATIONS_14204828183062550964)],
        &[(0b10010, &ENTRY_PHENOMENALIZE_11717565309304041099)],
        &[(0b10010, &ENTRY_PHENOMENALIZED_5794978347542150916)],
        &[(0b10010, &ENTRY_PHENOMENALIZES_14468079307814950479)],
        &[(0b10010, &ENTRY_PHENOMENALIZING_15597205978617856018)],
        &[(0b01001, &ENTRY_PHENOMENALIZATION_3655891833450393811)],
        &[(0b01001, &ENTRY_PHENOMENALIZATIONS_14204828183062550964)],
        &[(0b01001, &ENTRY_PHENOMENALIZE_11717565309304041099)],
        &[(0b01001, &ENTRY_PHENOMENALIZED_5794978347542150916)],
        &[(0b01001, &ENTRY_PHENOMENALIZES_14468079307814950479)],
        &[(0b01001, &ENTRY_PHENOMENALIZING_15597205978617856018)],
        &[(0b10010, &ENTRY_PHENOMENIZE_9110544169399242876)],
        &[(0b10010, &ENTRY_PHENOMENIZED_1139593925364905286)],
        &[(0b10010, &ENTRY_PHENOMENIZES_17606511759958816816)],
        &[(0b10010, &ENTRY_PHENOMENIZING_6848532127265778662)],
        &[(0b00001, &ENTRY_PHENOMENISM_5615148023723810129)],
        &[(0b01001, &ENTRY_PHENOMENIZE_9110544169399242876)],
        &[(0b01001, &ENTRY_PHENOMENIZED_1139593925364905286)],
        &[(0b01001, &ENTRY_PHENOMENIZES_17606511759958816816)],
        &[(0b01001, &ENTRY_PHENOMENIZING_6848532127265778662)],
        &[(0b00001, &ENTRY_PHENOZYGOUS_10218199328032200205)],
        &[(0b00001, &ENTRY_PHEOPHYL_11552466584906711269)],
        &[(0b00001, &ENTRY_PHEOPHYLL_17122888113078909815)],
        &[(0b00001, &ENTRY_PHEOPHYTIN_2724547005457304078)],
    ],
    range: 5..=15,
};

static VARS_PHA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PHA_CHILDREN),
    value: None,
};

pub static VARS_PHA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aenna"),
        dictgen::InsensitiveStr::Ascii("cochere"),
        dictgen::InsensitiveStr::Ascii("cocherine"),
        dictgen::InsensitiveStr::Ascii("cochoere"),
        dictgen::InsensitiveStr::Ascii("cochoerine"),
        dictgen::InsensitiveStr::Ascii("elonion"),
        dictgen::InsensitiveStr::Ascii("elonions"),
        dictgen::InsensitiveStr::Ascii("enna"),
        dictgen::InsensitiveStr::Ascii("enogam"),
        dictgen::InsensitiveStr::Ascii("enogams"),
        dictgen::InsensitiveStr::Ascii("enogenesis"),
        dictgen::InsensitiveStr::Ascii("enogenetic"),
        dictgen::InsensitiveStr::Ascii("enological"),
        dictgen::InsensitiveStr::Ascii("enologies"),
        dictgen::InsensitiveStr::Ascii("enology"),
        dictgen::InsensitiveStr::Ascii("enomenism"),
        dictgen::InsensitiveStr::Ascii("enozygous"),
        dictgen::InsensitiveStr::Ascii("eophyl"),
        dictgen::InsensitiveStr::Ascii("eophyll"),
        dictgen::InsensitiveStr::Ascii("eophytin"),
        dictgen::InsensitiveStr::Ascii("gedaena"),
        dictgen::InsensitiveStr::Ascii("gedaenas"),
        dictgen::InsensitiveStr::Ascii("gedaenic"),
        dictgen::InsensitiveStr::Ascii("gedaenical"),
        dictgen::InsensitiveStr::Ascii("gedaenous"),
        dictgen::InsensitiveStr::Ascii("gedena"),
        dictgen::InsensitiveStr::Ascii("gedenas"),
        dictgen::InsensitiveStr::Ascii("gedenic"),
        dictgen::InsensitiveStr::Ascii("gedenical"),
        dictgen::InsensitiveStr::Ascii("gedenous"),
        dictgen::InsensitiveStr::Ascii("gocytise"),
        dictgen::InsensitiveStr::Ascii("gocytises"),
        dictgen::InsensitiveStr::Ascii("gocytize"),
        dictgen::InsensitiveStr::Ascii("gocytizes"),
        dictgen::InsensitiveStr::Ascii("ntomise"),
        dictgen::InsensitiveStr::Ascii("ntomiser"),
        dictgen::InsensitiveStr::Ascii("ntomisers"),
        dictgen::InsensitiveStr::Ascii("ntomises"),
        dictgen::InsensitiveStr::Ascii("ntomize"),
        dictgen::InsensitiveStr::Ascii("ntomizer"),
        dictgen::InsensitiveStr::Ascii("ntomizers"),
        dictgen::InsensitiveStr::Ascii("ntomizes"),
        dictgen::InsensitiveStr::Ascii("risaean"),
        dictgen::InsensitiveStr::Ascii("risean"),
        dictgen::InsensitiveStr::Ascii("rmacopeial"),
        dictgen::InsensitiveStr::Ascii("rmacopeian"),
        dictgen::InsensitiveStr::Ascii("rmacopoeian"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PHAENNA_6872669718419162795)],
        &[(0b00001, &ENTRY_PHACOCHERE_4955198037695802664)],
        &[(0b00001, &ENTRY_PHACOCHERINE_10095812869794876875)],
        &[(0b11010, &ENTRY_PHACOCHERE_4955198037695802664)],
        &[(0b11010, &ENTRY_PHACOCHERINE_10095812869794876875)],
        &[(0b11010, &ENTRY_PHELONION_6969396090547227356)],
        &[(0b11010, &ENTRY_PHELONIONS_7275701311297650329)],
        &[(0b00001, &ENTRY_PHAENNA_6872669718419162795)],
        &[(0b11010, &ENTRY_PHENOGAM_2031537475522870003)],
        &[(0b11010, &ENTRY_PHENOGAMS_16570370822932628992)],
        &[(0b11010, &ENTRY_PHENOGENESIS_17567829228271993340)],
        &[(0b11010, &ENTRY_PHENOGENETIC_17720618598147822936)],
        &[(0b11010, &ENTRY_PHENOLOGICAL_18143589645340253850)],
        &[(0b11010, &ENTRY_PHENOLOGIES_16864158914924322992)],
        &[(0b11010, &ENTRY_PHENOLOGY_10696299477585495820)],
        &[(0b11010, &ENTRY_PHENOMENISM_5615148023723810129)],
        &[(0b11010, &ENTRY_PHENOZYGOUS_10218199328032200205)],
        &[(0b11010, &ENTRY_PHEOPHYL_11552466584906711269)],
        &[(0b11010, &ENTRY_PHEOPHYLL_17122888113078909815)],
        &[(0b11010, &ENTRY_PHEOPHYTIN_2724547005457304078)],
        &[(0b11010, &ENTRY_PHAGEDENA_317734246379814153)],
        &[(0b11010, &ENTRY_PHAGEDENAS_11187954412184935604)],
        &[(0b11010, &ENTRY_PHAGEDENIC_17318315545560183857)],
        &[(0b11010, &ENTRY_PHAGEDENICAL_16284853943068372065)],
        &[(0b11010, &ENTRY_PHAGEDENOUS_1804302093376783588)],
        &[(0b00001, &ENTRY_PHAGEDENA_317734246379814153)],
        &[(0b00001, &ENTRY_PHAGEDENAS_11187954412184935604)],
        &[(0b00001, &ENTRY_PHAGEDENIC_17318315545560183857)],
        &[(0b00001, &ENTRY_PHAGEDENICAL_16284853943068372065)],
        &[(0b00001, &ENTRY_PHAGEDENOUS_1804302093376783588)],
        &[(0b10010, &ENTRY_PHAGOCYTIZE_14412062490428630989)],
        &[(0b10010, &ENTRY_PHAGOCYTIZES_5484801342814585347)],
        &[(0b01001, &ENTRY_PHAGOCYTIZE_14412062490428630989)],
        &[(0b01001, &ENTRY_PHAGOCYTIZES_5484801342814585347)],
        &[(0b10010, &ENTRY_PHANTOMIZE_9606576662403812455)],
        &[(0b10010, &ENTRY_PHANTOMIZER_15050193001568501253)],
        &[(0b10010, &ENTRY_PHANTOMIZERS_12075504307273453169)],
        &[(0b10010, &ENTRY_PHANTOMIZES_5888358266315867784)],
        &[(0b01001, &ENTRY_PHANTOMIZE_9606576662403812455)],
        &[(0b01001, &ENTRY_PHANTOMIZER_15050193001568501253)],
        &[(0b01001, &ENTRY_PHANTOMIZERS_12075504307273453169)],
        &[(0b01001, &ENTRY_PHANTOMIZES_5888358266315867784)],
        &[(0b11010, &ENTRY_PHARISEAN_2326065742596188618)],
        &[(0b00001, &ENTRY_PHARISEAN_2326065742596188618)],
        &[(0b00001, &ENTRY_PHARMACOPOEIAL_11804050835567169007)],
        &[(0b00001, &ENTRY_PHARMACOPEIAN_4683846151180244693)],
        &[(0b11010, &ENTRY_PHARMACOPEIAN_4683846151180244693)],
    ],
    range: 4..=11,
};

static VARS_PE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_PE_11577855917495375674)]),
};

static VARS_PE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PEA_NODE),
    None,
    Some(&VARS_PEC_NODE),
    Some(&VARS_PED_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PEI_NODE),
    None,
    None,
    Some(&VARS_PEL_NODE),
    Some(&VARS_PEM_NODE),
    Some(&VARS_PEN_NODE),
    None,
    Some(&VARS_PEP_NODE),
    None,
    Some(&VARS_PER_NODE),
    None,
    Some(&VARS_PET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PET_CHILDREN),
    value: None,
};

pub static VARS_PET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("rarchise"),
        dictgen::InsensitiveStr::Ascii("rarchised"),
        dictgen::InsensitiveStr::Ascii("rarchises"),
        dictgen::InsensitiveStr::Ascii("rarchising"),
        dictgen::InsensitiveStr::Ascii("rarchize"),
        dictgen::InsensitiveStr::Ascii("rarchized"),
        dictgen::InsensitiveStr::Ascii("rarchizes"),
        dictgen::InsensitiveStr::Ascii("rarchizing"),
        dictgen::InsensitiveStr::Ascii("rolisation"),
        dictgen::InsensitiveStr::Ascii("rolisations"),
        dictgen::InsensitiveStr::Ascii("rolise"),
        dictgen::InsensitiveStr::Ascii("rolises"),
        dictgen::InsensitiveStr::Ascii("rolization"),
        dictgen::InsensitiveStr::Ascii("rolizations"),
        dictgen::InsensitiveStr::Ascii("rolize"),
        dictgen::InsensitiveStr::Ascii("rolizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PETALED_67675403619589060)],
        &[(0b11010, &ENTRY_PETALED_67675403619589060)],
        &[(0b00001, &ENTRY_PETLING_4679867327279057417)],
        &[(0b10010, &ENTRY_PETRARCHIZE_7900319410477587125)],
        &[(0b10010, &ENTRY_PETRARCHIZED_7254765400339686109)],
        &[(0b10010, &ENTRY_PETRARCHIZES_4178876562035449090)],
        &[(0b10010, &ENTRY_PETRARCHIZING_12012636599315128862)],
        &[(0b01001, &ENTRY_PETRARCHIZE_7900319410477587125)],
        &[(0b01001, &ENTRY_PETRARCHIZED_7254765400339686109)],
        &[(0b01001, &ENTRY_PETRARCHIZES_4178876562035449090)],
        &[(0b01001, &ENTRY_PETRARCHIZING_12012636599315128862)],
        &[(0b10010, &ENTRY_PETROLIZATION_16999409919613399973)],
        &[(0b10010, &ENTRY_PETROLIZATIONS_7511909901714380822)],
        &[(0b10010, &ENTRY_PETROLIZE_7665552287162264221)],
        &[(0b10010, &ENTRY_PETROLIZES_4132811127736998863)],
        &[(0b01001, &ENTRY_PETROLIZATION_16999409919613399973)],
        &[(0b01001, &ENTRY_PETROLIZATIONS_7511909901714380822)],
        &[(0b01001, &ENTRY_PETROLIZE_7665552287162264221)],
        &[(0b01001, &ENTRY_PETROLIZES_4132811127736998863)],
    ],
    range: 4..=11,
};

static VARS_PER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PER_CHILDREN),
    value: None,
};

static VARS_PER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PERA_NODE),
    None,
    Some(&VARS_PERC_NODE),
    Some(&VARS_PERD_NODE),
    Some(&VARS_PERE_NODE),
    Some(&VARS_PERF_NODE),
    None,
    Some(&VARS_PERH_NODE),
    Some(&VARS_PERI_NODE),
    Some(&VARS_PERJ_NODE),
    None,
    Some(&VARS_PERL_NODE),
    Some(&VARS_PERM_NODE),
    Some(&VARS_PERN_NODE),
    Some(&VARS_PERO_NODE),
    Some(&VARS_PERP_NODE),
    None,
    None,
    Some(&VARS_PERS_NODE),
    None,
    Some(&VARS_PERU_NODE),
    Some(&VARS_PERV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_PERV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERV_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_PERV_1140727827150260852)]),
};

pub static VARS_PERV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("iable"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("iousness"),
        dictgen::InsensitiveStr::Ascii("iousnesses"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERVE_18165674324823475517)],
        &[(0b00001, &ENTRY_PERVED_18208319127618556214)],
        &[(0b00001, &ENTRY_PERVES_5996851197956304566)],
        &[(0b00001, &ENTRY_PERVIABLE_4699952660241611906)],
        &[(0b00001, &ENTRY_PERVING_12586188415039019252)],
        &[(0b00001, &ENTRY_PERVIOUSNESS_4962441648916650935)],
        &[(0b00001, &ENTRY_PERVIOUSNESSES_15261112133254148006)],
    ],
    range: 1..=10,
};

static VARS_PERU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERU_CHILDREN),
    value: None,
};

pub static VARS_PERU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("vianise"),
        dictgen::InsensitiveStr::Ascii("vianises"),
        dictgen::InsensitiveStr::Ascii("vianize"),
        dictgen::InsensitiveStr::Ascii("vianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PERUVIANIZE_6382627651753832553)],
        &[(0b10010, &ENTRY_PERUVIANIZES_14090175275525112564)],
        &[(0b01001, &ENTRY_PERUVIANIZE_6382627651753832553)],
        &[(0b01001, &ENTRY_PERUVIANIZES_14090175275525112564)],
    ],
    range: 7..=8,
};

static VARS_PERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERS_CHILDREN),
    value: None,
};

pub static VARS_PERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ianisation"),
        dictgen::InsensitiveStr::Ascii("ianisations"),
        dictgen::InsensitiveStr::Ascii("ianise"),
        dictgen::InsensitiveStr::Ascii("ianised"),
        dictgen::InsensitiveStr::Ascii("ianises"),
        dictgen::InsensitiveStr::Ascii("ianising"),
        dictgen::InsensitiveStr::Ascii("ianization"),
        dictgen::InsensitiveStr::Ascii("ianizations"),
        dictgen::InsensitiveStr::Ascii("ianize"),
        dictgen::InsensitiveStr::Ascii("ianized"),
        dictgen::InsensitiveStr::Ascii("ianizes"),
        dictgen::InsensitiveStr::Ascii("ianizing"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("olve"),
        dictgen::InsensitiveStr::Ascii("onalisation"),
        dictgen::InsensitiveStr::Ascii("onalisations"),
        dictgen::InsensitiveStr::Ascii("onalise"),
        dictgen::InsensitiveStr::Ascii("onalised"),
        dictgen::InsensitiveStr::Ascii("onalises"),
        dictgen::InsensitiveStr::Ascii("onalising"),
        dictgen::InsensitiveStr::Ascii("onalization"),
        dictgen::InsensitiveStr::Ascii("onalizations"),
        dictgen::InsensitiveStr::Ascii("onalize"),
        dictgen::InsensitiveStr::Ascii("onalized"),
        dictgen::InsensitiveStr::Ascii("onalizes"),
        dictgen::InsensitiveStr::Ascii("onalizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("t"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERSE_13659628269605068524)],
        &[
            (0b00001, &ENTRY_PERSE_13659628269605068524),
            (0b00001, &ENTRY_PERSE_2874440396224431051),
        ],
        &[(0b10010, &ENTRY_PERSIANIZATION_10456152347071316181)],
        &[(0b10010, &ENTRY_PERSIANIZATIONS_12804723289958534578)],
        &[(0b10010, &ENTRY_PERSIANIZE_10319509138110538325)],
        &[(0b10010, &ENTRY_PERSIANIZED_9516440395848303807)],
        &[(0b10010, &ENTRY_PERSIANIZES_9445770532797771551)],
        &[(0b10010, &ENTRY_PERSIANIZING_12004543135849853067)],
        &[(0b01001, &ENTRY_PERSIANIZATION_10456152347071316181)],
        &[(0b01001, &ENTRY_PERSIANIZATIONS_12804723289958534578)],
        &[(0b01001, &ENTRY_PERSIANIZE_10319509138110538325)],
        &[(0b01001, &ENTRY_PERSIANIZED_9516440395848303807)],
        &[(0b01001, &ENTRY_PERSIANIZES_9445770532797771551)],
        &[(0b01001, &ENTRY_PERSIANIZING_12004543135849853067)],
        &[(0b10010, &ENTRY_PERSICIZE_9817820256246452496)],
        &[(0b10010, &ENTRY_PERSICIZED_8426958054366327606)],
        &[(0b10010, &ENTRY_PERSICIZES_3173733872542747533)],
        &[(0b10010, &ENTRY_PERSICIZING_345314971166446532)],
        &[(0b01001, &ENTRY_PERSICIZE_9817820256246452496)],
        &[(0b01001, &ENTRY_PERSICIZED_8426958054366327606)],
        &[(0b01001, &ENTRY_PERSICIZES_3173733872542747533)],
        &[(0b01001, &ENTRY_PERSICIZING_345314971166446532)],
        &[(0b00001, &ENTRY_PERSOLVE_11803654124888842880)],
        &[(0b10010, &ENTRY_PERSONALIZATION_8393077675198614709)],
        &[(0b10010, &ENTRY_PERSONALIZATIONS_3072710456827540417)],
        &[(0b10010, &ENTRY_PERSONALIZE_4748948411684788546)],
        &[(0b10010, &ENTRY_PERSONALIZED_8380116593820467680)],
        &[(0b10010, &ENTRY_PERSONALIZES_8288542045462193378)],
        &[(0b10010, &ENTRY_PERSONALIZING_6482443885062681058)],
        &[(0b01001, &ENTRY_PERSONALIZATION_8393077675198614709)],
        &[(0b01001, &ENTRY_PERSONALIZATIONS_3072710456827540417)],
        &[(0b01001, &ENTRY_PERSONALIZE_4748948411684788546)],
        &[(0b01001, &ENTRY_PERSONALIZED_8380116593820467680)],
        &[(0b01001, &ENTRY_PERSONALIZES_8288542045462193378)],
        &[(0b01001, &ENTRY_PERSONALIZING_6482443885062681058)],
        &[(0b10010, &ENTRY_PERSONIZATION_15871628578229626875)],
        &[(0b10010, &ENTRY_PERSONIZATIONS_2363579352700768230)],
        &[(0b10010, &ENTRY_PERSONIZE_13482080998389432603)],
        &[(0b10010, &ENTRY_PERSONIZED_13450813166358378857)],
        &[(0b10010, &ENTRY_PERSONIZES_990720830743251132)],
        &[(0b10010, &ENTRY_PERSONIZING_14903686723706359501)],
        &[(0b01001, &ENTRY_PERSONIZATION_15871628578229626875)],
        &[(0b01001, &ENTRY_PERSONIZATIONS_2363579352700768230)],
        &[(0b01001, &ENTRY_PERSONIZE_13482080998389432603)],
        &[(0b01001, &ENTRY_PERSONIZED_13450813166358378857)],
        &[(0b01001, &ENTRY_PERSONIZES_990720830743251132)],
        &[(0b01001, &ENTRY_PERSONIZING_14903686723706359501)],
        &[(0b00001, &ENTRY_PERST_10410873219912667942)],
    ],
    range: 1..=12,
};

static VARS_PERP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERP_CHILDREN),
    value: None,
};

pub static VARS_PERP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("end"),
        dictgen::InsensitiveStr::Ascii("ended"),
        dictgen::InsensitiveStr::Ascii("ending"),
        dictgen::InsensitiveStr::Ascii("erfect"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERPEND_7695504195883399642)],
        &[(0b00001, &ENTRY_PERPENDED_14779081215925715227)],
        &[(0b00001, &ENTRY_PERPENDING_9760848409550374555)],
        &[(0b00001, &ENTRY_PERPERFECT_2601720249166533392)],
    ],
    range: 3..=6,
};

static VARS_PERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERO_CHILDREN),
    value: None,
};

pub static VARS_PERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ral"),
        dictgen::InsensitiveStr::Ascii("rally"),
        dictgen::InsensitiveStr::Ascii("tic"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidisement"),
        dictgen::InsensitiveStr::Ascii("xidisements"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizement"),
        dictgen::InsensitiveStr::Ascii("xidizements"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERORAL_1577247151206222930)],
        &[(0b00001, &ENTRY_PERORALLY_2346315785712029791)],
        &[(0b00001, &ENTRY_PEROTIC_2582865836237824851)],
        &[(0b10010, &ENTRY_PEROXIDIZE_15017198944556073397)],
        &[(0b10010, &ENTRY_PEROXIDIZED_501835571565398577)],
        &[(0b10010, &ENTRY_PEROXIDIZEMENT_15148226652591344641)],
        &[(0b10010, &ENTRY_PEROXIDIZEMENTS_14879084608269866527)],
        &[(0b10010, &ENTRY_PEROXIDIZES_2231452525489889274)],
        &[(0b10010, &ENTRY_PEROXIDIZING_9108083056272744022)],
        &[(0b01001, &ENTRY_PEROXIDIZE_15017198944556073397)],
        &[(0b01001, &ENTRY_PEROXIDIZED_501835571565398577)],
        &[(0b01001, &ENTRY_PEROXIDIZEMENT_15148226652591344641)],
        &[(0b01001, &ENTRY_PEROXIDIZEMENTS_14879084608269866527)],
        &[(0b01001, &ENTRY_PEROXIDIZES_2231452525489889274)],
        &[(0b01001, &ENTRY_PEROXIDIZING_9108083056272744022)],
    ],
    range: 3..=11,
};

static VARS_PERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERN_CHILDREN),
    value: None,
};

pub static VARS_PERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("asal")],
    values: &[&[(0b00001, &ENTRY_PERNASAL_16102840364502673315)]],
    range: 4..=4,
};

static VARS_PERM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERM_CHILDREN),
    value: None,
};

pub static VARS_PERM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("issable"),
        dictgen::InsensitiveStr::Ascii("ixture"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERMISSABLE_8744644961382997089)],
        &[(0b00001, &ENTRY_PERMIXTURE_15232799364862600989)],
    ],
    range: 6..=7,
};

static VARS_PERL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERL_CHILDREN),
    value: None,
};

pub static VARS_PERL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ection"),
        dictgen::InsensitiveStr::Ascii("ingual"),
        dictgen::InsensitiveStr::Ascii("ingually"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERLECTION_3296452498431632093)],
        &[(0b00001, &ENTRY_PERLINGUAL_3419901988075232474)],
        &[(0b00001, &ENTRY_PERLINGUALLY_11928722645527217541)],
    ],
    range: 6..=8,
};

static VARS_PERJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERJ_CHILDREN),
    value: None,
};

pub static VARS_PERJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ink")],
    values: &[&[(0b00001, &ENTRY_PERJINK_7961075561267618144)]],
    range: 3..=3,
};

static VARS_PERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERI_CHILDREN),
    value: None,
};

pub static VARS_PERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caecal"),
        dictgen::InsensitiveStr::Ascii("caecitis"),
        dictgen::InsensitiveStr::Ascii("cecal"),
        dictgen::InsensitiveStr::Ascii("cecitis"),
        dictgen::InsensitiveStr::Ascii("center"),
        dictgen::InsensitiveStr::Ascii("centre"),
        dictgen::InsensitiveStr::Ascii("chaete"),
        dictgen::InsensitiveStr::Ascii("chete"),
        dictgen::InsensitiveStr::Ascii("copae"),
        dictgen::InsensitiveStr::Ascii("cope"),
        dictgen::InsensitiveStr::Ascii("esophageal"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("odicalise"),
        dictgen::InsensitiveStr::Ascii("odicalises"),
        dictgen::InsensitiveStr::Ascii("odicalize"),
        dictgen::InsensitiveStr::Ascii("odicalizes"),
        dictgen::InsensitiveStr::Ascii("odisation"),
        dictgen::InsensitiveStr::Ascii("odisations"),
        dictgen::InsensitiveStr::Ascii("odise"),
        dictgen::InsensitiveStr::Ascii("odised"),
        dictgen::InsensitiveStr::Ascii("odises"),
        dictgen::InsensitiveStr::Ascii("odising"),
        dictgen::InsensitiveStr::Ascii("odization"),
        dictgen::InsensitiveStr::Ascii("odizations"),
        dictgen::InsensitiveStr::Ascii("odize"),
        dictgen::InsensitiveStr::Ascii("odized"),
        dictgen::InsensitiveStr::Ascii("odizes"),
        dictgen::InsensitiveStr::Ascii("odizing"),
        dictgen::InsensitiveStr::Ascii("oesophageal"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERICECAL_5535752974684809547)],
        &[(0b11010, &ENTRY_PERICECITIS_12086693101644590542)],
        &[(0b00001, &ENTRY_PERICECAL_5535752974684809547)],
        &[(0b00001, &ENTRY_PERICECITIS_12086693101644590542)],
        &[(0b00001, &ENTRY_PERICENTER_10108739404975251919)],
        &[(0b11010, &ENTRY_PERICENTER_10108739404975251919)],
        &[(0b11010, &ENTRY_PERICHETE_2868508308788688470)],
        &[(0b00001, &ENTRY_PERICHETE_2868508308788688470)],
        &[(0b11010, &ENTRY_PERICOPE_2464029041518638801)],
        &[(0b00001, &ENTRY_PERICOPE_2464029041518638801)],
        &[(0b00001, &ENTRY_PERIESOPHAGEAL_9030912638833637940)],
        &[(0b00001, &ENTRY_PERILED_4377735023565021754)],
        &[(0b00001, &ENTRY_PERILING_9472490737862744839)],
        &[(0b11010, &ENTRY_PERILED_4377735023565021754)],
        &[(0b11010, &ENTRY_PERILING_9472490737862744839)],
        &[(0b10010, &ENTRY_PERIODICALIZE_16956000779487375960)],
        &[(0b10010, &ENTRY_PERIODICALIZES_7197610449394818524)],
        &[(0b01001, &ENTRY_PERIODICALIZE_16956000779487375960)],
        &[(0b01001, &ENTRY_PERIODICALIZES_7197610449394818524)],
        &[(0b10010, &ENTRY_PERIODIZATION_5007045201160928503)],
        &[(0b10010, &ENTRY_PERIODIZATIONS_16536767337590632344)],
        &[(0b10010, &ENTRY_PERIODIZE_14073031487379844742)],
        &[(0b10010, &ENTRY_PERIODIZED_14494857337622522468)],
        &[(0b10010, &ENTRY_PERIODIZES_184925638931471611)],
        &[(0b10010, &ENTRY_PERIODIZING_9095983531047177361)],
        &[(0b01001, &ENTRY_PERIODIZATION_5007045201160928503)],
        &[(0b01001, &ENTRY_PERIODIZATIONS_16536767337590632344)],
        &[(0b01001, &ENTRY_PERIODIZE_14073031487379844742)],
        &[(0b01001, &ENTRY_PERIODIZED_14494857337622522468)],
        &[(0b01001, &ENTRY_PERIODIZES_184925638931471611)],
        &[(0b01001, &ENTRY_PERIODIZING_9095983531047177361)],
        &[(0b11010, &ENTRY_PERIESOPHAGEAL_9030912638833637940)],
    ],
    range: 3..=11,
};

static VARS_PERH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERH_CHILDREN),
    value: None,
};

pub static VARS_PERH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("azard")],
    values: &[&[(0b00001, &ENTRY_PERHAZARD_5172084758894143542)]],
    range: 5..=5,
};

static VARS_PERF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERF_CHILDREN),
    value: None,
};

pub static VARS_PERF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectivise"),
        dictgen::InsensitiveStr::Ascii("ectivises"),
        dictgen::InsensitiveStr::Ascii("ectivize"),
        dictgen::InsensitiveStr::Ascii("ectivizes"),
        dictgen::InsensitiveStr::Ascii("ervor"),
        dictgen::InsensitiveStr::Ascii("ervors"),
        dictgen::InsensitiveStr::Ascii("ervour"),
        dictgen::InsensitiveStr::Ascii("ervours"),
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("oliation"),
        dictgen::InsensitiveStr::Ascii("oliations"),
        dictgen::InsensitiveStr::Ascii("ormant"),
        dictgen::InsensitiveStr::Ascii("ormative"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PERFECTIVIZE_12830499112403314573)],
        &[(0b10010, &ENTRY_PERFECTIVIZES_9087949345192893342)],
        &[(0b01001, &ENTRY_PERFECTIVIZE_12830499112403314573)],
        &[(0b01001, &ENTRY_PERFECTIVIZES_9087949345192893342)],
        &[(0b00001, &ENTRY_PERFERVOR_514072560594963060)],
        &[(0b00001, &ENTRY_PERFERVORS_3703900686039672985)],
        &[(0b11010, &ENTRY_PERFERVOR_514072560594963060)],
        &[(0b11010, &ENTRY_PERFERVORS_3703900686039672985)],
        &[(0b00001, &ENTRY_PERFET_12737033377426427677)],
        &[(0b00001, &ENTRY_PERFOLIATION_15643738965251302962)],
        &[(0b00001, &ENTRY_PERFOLIATIONS_5441070203325996418)],
        &[(0b00001, &ENTRY_PERFORMANT_1886331341238867877)],
        &[(0b00001, &ENTRY_PERFORMATIVE_11653583321194826668)],
    ],
    range: 2..=9,
};

static VARS_PERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERE_CHILDREN),
    value: None,
};

pub static VARS_PERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("nnialise"),
        dictgen::InsensitiveStr::Ascii("nnialises"),
        dictgen::InsensitiveStr::Ascii("nnialize"),
        dictgen::InsensitiveStr::Ascii("nnializes"),
        dictgen::InsensitiveStr::Ascii("on"),
        dictgen::InsensitiveStr::Ascii("opod"),
        dictgen::InsensitiveStr::Ascii("opods"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PEREA_5147570010794111976)],
        &[(0b10010, &ENTRY_PERENNIALIZE_16426253784606656534)],
        &[(0b10010, &ENTRY_PERENNIALIZES_4803467841688723694)],
        &[(0b01001, &ENTRY_PERENNIALIZE_16426253784606656534)],
        &[(0b01001, &ENTRY_PERENNIALIZES_4803467841688723694)],
        &[(0b00001, &ENTRY_PEREON_16795200992980059464)],
        &[(0b00001, &ENTRY_PEREOPOD_9605155749429362953)],
        &[(0b00001, &ENTRY_PEREOPODS_14626696459269814659)],
    ],
    range: 1..=9,
};

static VARS_PERD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERD_CHILDREN),
    value: None,
};

pub static VARS_PERD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icinae"),
        dictgen::InsensitiveStr::Ascii("icine"),
        dictgen::InsensitiveStr::Ascii("iligent"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PERDICINE_4604747959856287967)],
        &[(0b00001, &ENTRY_PERDICINE_4604747959856287967)],
        &[(0b00001, &ENTRY_PERDILIGENT_5349792271361198811)],
        &[(0b00001, &ENTRY_PERDY_1390936130181263743)],
    ],
    range: 1..=7,
};

static VARS_PERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERC_CHILDREN),
    value: None,
};

pub static VARS_PERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("hlorethane"),
        dictgen::InsensitiveStr::Ascii("hlorethylene"),
        dictgen::InsensitiveStr::Ascii("hloric"),
        dictgen::InsensitiveStr::Ascii("hloroethane"),
        dictgen::InsensitiveStr::Ascii("hloroethylene"),
        dictgen::InsensitiveStr::Ascii("lose"),
        dictgen::InsensitiveStr::Ascii("ompound"),
        dictgen::InsensitiveStr::Ascii("urrent"),
        dictgen::InsensitiveStr::Ascii("ussionise"),
        dictgen::InsensitiveStr::Ascii("ussionises"),
        dictgen::InsensitiveStr::Ascii("ussionize"),
        dictgen::InsensitiveStr::Ascii("ussionizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERCES_984660829518258229)],
        &[(0b00001, &ENTRY_PERCHLORETHANE_6974667202987518966)],
        &[(0b00001, &ENTRY_PERCHLORETHYLENE_3449824728229271694)],
        &[(0b00001, &ENTRY_PERCHLORIC_15808215951562951935)],
        &[(0b11010, &ENTRY_PERCHLORETHANE_6974667202987518966)],
        &[(0b11010, &ENTRY_PERCHLORETHYLENE_3449824728229271694)],
        &[(0b00001, &ENTRY_PERCLOSE_11470867655063256438)],
        &[(0b00001, &ENTRY_PERCOMPOUND_414258272162299801)],
        &[(0b00001, &ENTRY_PERCURRENT_15522415679210362636)],
        &[(0b10010, &ENTRY_PERCUSSIONIZE_5158674871645362213)],
        &[(0b10010, &ENTRY_PERCUSSIONIZES_9711788919324651680)],
        &[(0b01001, &ENTRY_PERCUSSIONIZE_5158674871645362213)],
        &[(0b01001, &ENTRY_PERCUSSIONIZES_9711788919324651680)],
    ],
    range: 2..=13,
};

static VARS_PERA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PERA_CHILDREN),
    value: None,
};

pub static VARS_PERA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cid"),
        dictgen::InsensitiveStr::Ascii("cidity"),
        dictgen::InsensitiveStr::Ascii("ct"),
        dictgen::InsensitiveStr::Ascii("cute"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("eon"),
        dictgen::InsensitiveStr::Ascii("eopod"),
        dictgen::InsensitiveStr::Ascii("eopods"),
        dictgen::InsensitiveStr::Ascii("mbulatory"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PERACID_17853350354268795572)],
        &[(0b00001, &ENTRY_PERACIDITY_1147905095983877951)],
        &[(0b00001, &ENTRY_PERACT_16940258999462133608)],
        &[(0b00001, &ENTRY_PERACUTE_2328162913715436273)],
        &[(0b11010, &ENTRY_PEREA_5147570010794111976)],
        &[(0b11010, &ENTRY_PEREON_16795200992980059464)],
        &[(0b11010, &ENTRY_PEREOPOD_9605155749429362953)],
        &[(0b11010, &ENTRY_PEREOPODS_14626696459269814659)],
        &[(0b00001, &ENTRY_PERAMBULATORY_3211690938406856596)],
    ],
    range: 2..=9,
};

static VARS_PEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEP_CHILDREN),
    value: None,
};

pub static VARS_PEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tisable"),
        dictgen::InsensitiveStr::Ascii("tisables"),
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tisations"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tizable"),
        dictgen::InsensitiveStr::Ascii("tizables"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tizations"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizer"),
        dictgen::InsensitiveStr::Ascii("tizers"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
        dictgen::InsensitiveStr::Ascii("tonaemia"),
        dictgen::InsensitiveStr::Ascii("tonemia"),
        dictgen::InsensitiveStr::Ascii("tonisation"),
        dictgen::InsensitiveStr::Ascii("tonisations"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonised"),
        dictgen::InsensitiveStr::Ascii("toniser"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonising"),
        dictgen::InsensitiveStr::Ascii("tonization"),
        dictgen::InsensitiveStr::Ascii("tonizations"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonized"),
        dictgen::InsensitiveStr::Ascii("tonizer"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
        dictgen::InsensitiveStr::Ascii("tonizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PEPTIZABLE_13316576643501522207)],
        &[(0b10010, &ENTRY_PEPTIZABLES_15657004397021338874)],
        &[(0b10010, &ENTRY_PEPTIZATION_5533911940283450501)],
        &[(0b10010, &ENTRY_PEPTIZATIONS_7100944985070861177)],
        &[(0b10010, &ENTRY_PEPTIZE_3206314528337021093)],
        &[(0b10010, &ENTRY_PEPTIZED_15712022209384607271)],
        &[(0b10010, &ENTRY_PEPTIZER_10333676369659848983)],
        &[(0b10010, &ENTRY_PEPTIZERS_969896506919570594)],
        &[(0b10010, &ENTRY_PEPTIZES_5403839734258988322)],
        &[(0b10010, &ENTRY_PEPTIZING_15074374005726673747)],
        &[(0b01001, &ENTRY_PEPTIZABLE_13316576643501522207)],
        &[(0b01001, &ENTRY_PEPTIZABLES_15657004397021338874)],
        &[(0b01001, &ENTRY_PEPTIZATION_5533911940283450501)],
        &[(0b01001, &ENTRY_PEPTIZATIONS_7100944985070861177)],
        &[(0b01001, &ENTRY_PEPTIZE_3206314528337021093)],
        &[(0b01001, &ENTRY_PEPTIZED_15712022209384607271)],
        &[(0b01001, &ENTRY_PEPTIZER_10333676369659848983)],
        &[(0b01001, &ENTRY_PEPTIZERS_969896506919570594)],
        &[(0b01001, &ENTRY_PEPTIZES_5403839734258988322)],
        &[(0b01001, &ENTRY_PEPTIZING_15074374005726673747)],
        &[(0b11010, &ENTRY_PEPTONEMIA_8029620330697355971)],
        &[(0b00001, &ENTRY_PEPTONEMIA_8029620330697355971)],
        &[(0b10010, &ENTRY_PEPTONIZATION_17372160958497222923)],
        &[(0b10010, &ENTRY_PEPTONIZATIONS_2407257450314860216)],
        &[(0b10010, &ENTRY_PEPTONIZE_912826138201664087)],
        &[(0b10010, &ENTRY_PEPTONIZED_13587359379059596523)],
        &[(0b10010, &ENTRY_PEPTONIZER_17508640818259226113)],
        &[(0b10010, &ENTRY_PEPTONIZES_1040139223657965665)],
        &[(0b10010, &ENTRY_PEPTONIZING_5828043672896126547)],
        &[(0b01001, &ENTRY_PEPTONIZATION_17372160958497222923)],
        &[(0b01001, &ENTRY_PEPTONIZATIONS_2407257450314860216)],
        &[(0b01001, &ENTRY_PEPTONIZE_912826138201664087)],
        &[(0b01001, &ENTRY_PEPTONIZED_13587359379059596523)],
        &[(0b01001, &ENTRY_PEPTONIZER_17508640818259226113)],
        &[(0b01001, &ENTRY_PEPTONIZES_1040139223657965665)],
        &[(0b01001, &ENTRY_PEPTONIZING_5828043672896126547)],
    ],
    range: 4..=11,
};

static VARS_PEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEN_CHILDREN),
    value: None,
};

pub static VARS_PEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisabler"),
        dictgen::InsensitiveStr::Ascii("alisables"),
        dictgen::InsensitiveStr::Ascii("alisablest"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alizabler"),
        dictgen::InsensitiveStr::Ascii("alizables"),
        dictgen::InsensitiveStr::Ascii("alizablest"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ciled"),
        dictgen::InsensitiveStr::Ascii("ciler"),
        dictgen::InsensitiveStr::Ascii("cilers"),
        dictgen::InsensitiveStr::Ascii("ciling"),
        dictgen::InsensitiveStr::Ascii("cilings"),
        dictgen::InsensitiveStr::Ascii("cilled"),
        dictgen::InsensitiveStr::Ascii("ciller"),
        dictgen::InsensitiveStr::Ascii("cillers"),
        dictgen::InsensitiveStr::Ascii("cilling"),
        dictgen::InsensitiveStr::Ascii("cillings"),
        dictgen::InsensitiveStr::Ascii("elopise"),
        dictgen::InsensitiveStr::Ascii("elopised"),
        dictgen::InsensitiveStr::Ascii("elopises"),
        dictgen::InsensitiveStr::Ascii("elopising"),
        dictgen::InsensitiveStr::Ascii("elopize"),
        dictgen::InsensitiveStr::Ascii("elopized"),
        dictgen::InsensitiveStr::Ascii("elopizes"),
        dictgen::InsensitiveStr::Ascii("elopizing"),
        dictgen::InsensitiveStr::Ascii("nae"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("sae"),
        dictgen::InsensitiveStr::Ascii("se"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PENALIZABLE_16402490500753160561)],
        &[(0b10010, &ENTRY_PENALIZABLER_10283897399997620359)],
        &[(0b10010, &ENTRY_PENALIZABLES_14294337734166643281)],
        &[(0b10010, &ENTRY_PENALIZABLEST_16037788470703942853)],
        &[(0b10010, &ENTRY_PENALIZATION_17360891794071301320)],
        &[(0b10010, &ENTRY_PENALIZATIONS_9661842803190426071)],
        &[(0b10010, &ENTRY_PENALIZE_13430081598461307052)],
        &[(0b10010, &ENTRY_PENALIZED_7857910456156235058)],
        &[(0b10010, &ENTRY_PENALIZES_3401061733632791919)],
        &[(0b10010, &ENTRY_PENALIZING_18001384479269088536)],
        &[(0b01001, &ENTRY_PENALIZABLE_16402490500753160561)],
        &[(0b01001, &ENTRY_PENALIZABLER_10283897399997620359)],
        &[(0b01001, &ENTRY_PENALIZABLES_14294337734166643281)],
        &[(0b01001, &ENTRY_PENALIZABLEST_16037788470703942853)],
        &[(0b01001, &ENTRY_PENALIZATION_17360891794071301320)],
        &[(0b01001, &ENTRY_PENALIZATIONS_9661842803190426071)],
        &[(0b01001, &ENTRY_PENALIZE_13430081598461307052)],
        &[(0b01001, &ENTRY_PENALIZED_7857910456156235058)],
        &[(0b01001, &ENTRY_PENALIZES_3401061733632791919)],
        &[(0b01001, &ENTRY_PENALIZING_18001384479269088536)],
        &[(0b00001, &ENTRY_PENCILED_10698957931815950057)],
        &[(0b00001, &ENTRY_PENCILER_9299836922075131413)],
        &[(0b00001, &ENTRY_PENCILERS_13737441358026249172)],
        &[(0b00001, &ENTRY_PENCILING_13598020385460524085)],
        &[(0b00001, &ENTRY_PENCILINGS_819897427661414754)],
        &[(0b11010, &ENTRY_PENCILED_10698957931815950057)],
        &[(0b11010, &ENTRY_PENCILER_9299836922075131413)],
        &[(0b11010, &ENTRY_PENCILERS_13737441358026249172)],
        &[(0b11010, &ENTRY_PENCILING_13598020385460524085)],
        &[(0b11010, &ENTRY_PENCILINGS_819897427661414754)],
        &[(0b10010, &ENTRY_PENELOPIZE_222534767843534320)],
        &[(0b10010, &ENTRY_PENELOPIZED_16045288822105268504)],
        &[(0b10010, &ENTRY_PENELOPIZES_15812264060242899742)],
        &[(0b10010, &ENTRY_PENELOPIZING_9454561321061976299)],
        &[(0b01001, &ENTRY_PENELOPIZE_222534767843534320)],
        &[(0b01001, &ENTRY_PENELOPIZED_16045288822105268504)],
        &[(0b01001, &ENTRY_PENELOPIZES_15812264060242899742)],
        &[(0b01001, &ENTRY_PENELOPIZING_9454561321061976299)],
        &[(0b11010, &ENTRY_PENNE_16194116927221501612)],
        &[(0b00001, &ENTRY_PENNE_16194116927221501612)],
        &[(0b11010, &ENTRY_PENSE_14215361872352066210)],
        &[(0b00001, &ENTRY_PENSE_14215361872352066210)],
    ],
    range: 2..=10,
};

static VARS_PEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEM_CHILDREN),
    value: None,
};

pub static VARS_PEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("micanisation"),
        dictgen::InsensitiveStr::Ascii("micanisations"),
        dictgen::InsensitiveStr::Ascii("micanise"),
        dictgen::InsensitiveStr::Ascii("micanises"),
        dictgen::InsensitiveStr::Ascii("micanization"),
        dictgen::InsensitiveStr::Ascii("micanizations"),
        dictgen::InsensitiveStr::Ascii("micanize"),
        dictgen::InsensitiveStr::Ascii("micanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PEMMICANIZATION_3498493847858548991)],
        &[(0b10010, &ENTRY_PEMMICANIZATIONS_17863458648609504163)],
        &[(0b10010, &ENTRY_PEMMICANIZE_8863060726060100789)],
        &[(0b10010, &ENTRY_PEMMICANIZES_6099205721806444605)],
        &[(0b01001, &ENTRY_PEMMICANIZATION_3498493847858548991)],
        &[(0b01001, &ENTRY_PEMMICANIZATIONS_17863458648609504163)],
        &[(0b01001, &ENTRY_PEMMICANIZE_8863060726060100789)],
        &[(0b01001, &ENTRY_PEMMICANIZES_6099205721806444605)],
    ],
    range: 8..=13,
};

static VARS_PEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEL_CHILDREN),
    value: None,
};

pub static VARS_PEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("letisation"),
        dictgen::InsensitiveStr::Ascii("letisations"),
        dictgen::InsensitiveStr::Ascii("letise"),
        dictgen::InsensitiveStr::Ascii("letised"),
        dictgen::InsensitiveStr::Ascii("letiser"),
        dictgen::InsensitiveStr::Ascii("letises"),
        dictgen::InsensitiveStr::Ascii("letising"),
        dictgen::InsensitiveStr::Ascii("letization"),
        dictgen::InsensitiveStr::Ascii("letizations"),
        dictgen::InsensitiveStr::Ascii("letize"),
        dictgen::InsensitiveStr::Ascii("letized"),
        dictgen::InsensitiveStr::Ascii("letizer"),
        dictgen::InsensitiveStr::Ascii("letizes"),
        dictgen::InsensitiveStr::Ascii("letizing"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PELLETIZATION_6788072609952471440)],
        &[(0b10010, &ENTRY_PELLETIZATIONS_1053842567457998907)],
        &[(0b10010, &ENTRY_PELLETIZE_14681817165893413798)],
        &[(0b10010, &ENTRY_PELLETIZED_3294804075577157384)],
        &[(0b10010, &ENTRY_PELLETIZER_17745386141239426126)],
        &[(0b10010, &ENTRY_PELLETIZES_1850622828084500629)],
        &[(0b10010, &ENTRY_PELLETIZING_9020807315258444838)],
        &[(0b01001, &ENTRY_PELLETIZATION_6788072609952471440)],
        &[(0b01001, &ENTRY_PELLETIZATIONS_1053842567457998907)],
        &[(0b01001, &ENTRY_PELLETIZE_14681817165893413798)],
        &[(0b01001, &ENTRY_PELLETIZED_3294804075577157384)],
        &[(0b01001, &ENTRY_PELLETIZER_17745386141239426126)],
        &[(0b01001, &ENTRY_PELLETIZES_1850622828084500629)],
        &[(0b01001, &ENTRY_PELLETIZING_9020807315258444838)],
        &[(0b10010, &ENTRY_PELORIZED_14193283977378715867)],
        &[(0b01001, &ENTRY_PELORIZED_14193283977378715867)],
    ],
    range: 6..=11,
};

static VARS_PEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEI_CHILDREN),
    value: None,
};

pub static VARS_PEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sed"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("sing"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zed"),
        dictgen::InsensitiveStr::Ascii("zes"),
        dictgen::InsensitiveStr::Ascii("zing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PEIZE_885907093702515829)],
        &[(0b10010, &ENTRY_PEIZED_12509957894247332986)],
        &[(0b10010, &ENTRY_PEIZES_2190131057773292627)],
        &[(0b10010, &ENTRY_PEIZING_15796017161972728108)],
        &[(0b01001, &ENTRY_PEIZE_885907093702515829)],
        &[(0b01001, &ENTRY_PEIZED_12509957894247332986)],
        &[(0b01001, &ENTRY_PEIZES_2190131057773292627)],
        &[(0b01001, &ENTRY_PEIZING_15796017161972728108)],
    ],
    range: 2..=4,
};

static VARS_PED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PED_CHILDREN),
    value: None,
};

static VARS_PED_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PEDA_NODE),
    None,
    None,
    Some(&VARS_PEDD_NODE),
    Some(&VARS_PEDE_NODE),
    None,
    None,
    None,
    Some(&VARS_PEDI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PEDO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PEDO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDO_CHILDREN),
    value: None,
};

pub static VARS_PEDO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("baptism"),
        dictgen::InsensitiveStr::Ascii("baptist"),
        dictgen::InsensitiveStr::Ascii("dontic"),
        dictgen::InsensitiveStr::Ascii("dontics"),
        dictgen::InsensitiveStr::Ascii("geneses"),
        dictgen::InsensitiveStr::Ascii("genesis"),
        dictgen::InsensitiveStr::Ascii("genetic"),
        dictgen::InsensitiveStr::Ascii("genic"),
        dictgen::InsensitiveStr::Ascii("logical"),
        dictgen::InsensitiveStr::Ascii("logist"),
        dictgen::InsensitiveStr::Ascii("logists"),
        dictgen::InsensitiveStr::Ascii("metrical"),
        dictgen::InsensitiveStr::Ascii("morphic"),
        dictgen::InsensitiveStr::Ascii("morphism"),
        dictgen::InsensitiveStr::Ascii("morphisms"),
        dictgen::InsensitiveStr::Ascii("morphoses"),
        dictgen::InsensitiveStr::Ascii("morphosis"),
        dictgen::InsensitiveStr::Ascii("phile"),
        dictgen::InsensitiveStr::Ascii("philes"),
        dictgen::InsensitiveStr::Ascii("philia"),
        dictgen::InsensitiveStr::Ascii("philiac"),
        dictgen::InsensitiveStr::Ascii("philiacs"),
        dictgen::InsensitiveStr::Ascii("philias"),
        dictgen::InsensitiveStr::Ascii("philic"),
        dictgen::InsensitiveStr::Ascii("tribe"),
        dictgen::InsensitiveStr::Ascii("trophic"),
        dictgen::InsensitiveStr::Ascii("trophist"),
        dictgen::InsensitiveStr::Ascii("trophy"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PEDOBAPTISM_10804678125904355110)],
        &[(0b00001, &ENTRY_PEDOBAPTIST_17393232685703437549)],
        &[(0b00001, &ENTRY_PEDODONTIC_10829590082192845044)],
        &[(0b00001, &ENTRY_PEDODONTICS_5640137182749900289)],
        &[(0b00001, &ENTRY_PEDOGENESES_15579264777447032512)],
        &[(0b00001, &ENTRY_PEDOGENESIS_2691289146214329072)],
        &[(0b00001, &ENTRY_PEDOGENETIC_9300436022082143535)],
        &[(0b00001, &ENTRY_PEDOGENIC_15968023895342516337)],
        &[(0b00001, &ENTRY_PEDOLOGICAL_10471927294836257811)],
        &[(0b00001, &ENTRY_PEDOLOGIST_17875058654848962441)],
        &[(0b00001, &ENTRY_PEDOLOGISTS_1295482932093776852)],
        &[(0b00001, &ENTRY_PEDOMETRICAL_11798284037226839595)],
        &[(0b00001, &ENTRY_PEDOMORPHIC_6860459212658075764)],
        &[(0b00001, &ENTRY_PEDOMORPHISM_1336265225990998891)],
        &[(0b00001, &ENTRY_PEDOMORPHISMS_16472332478041997069)],
        &[(0b00001, &ENTRY_PEDOMORPHOSES_11301460943449417276)],
        &[(0b00001, &ENTRY_PEDOMORPHOSIS_14966272193032820392)],
        &[(0b11001, &ENTRY_PEDOPHILE_9927986055882192373)],
        &[(0b11001, &ENTRY_PEDOPHILES_4655841018136971409)],
        &[(0b10001, &ENTRY_PEDOPHILIA_9946016916272449426)],
        &[(0b10001, &ENTRY_PEDOPHILIAC_875642557192171107)],
        &[(0b10001, &ENTRY_PEDOPHILIACS_9467101932093289852)],
        &[(0b10001, &ENTRY_PEDOPHILIAS_10406528979051385197)],
        &[(0b10001, &ENTRY_PEDOPHILIC_10586175930831437217)],
        &[(0b00001, &ENTRY_PEDOTRIBE_5791037896195905072)],
        &[(0b00001, &ENTRY_PEDOTROPHIC_4225819697418345119)],
        &[(0b00001, &ENTRY_PEDOTROPHIST_13613791383976217031)],
        &[(0b00001, &ENTRY_PEDOTROPHY_11224422965985252808)],
    ],
    range: 5..=9,
};

static VARS_PEDI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDI_CHILDREN),
    value: None,
};

pub static VARS_PEDI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atric"),
        dictgen::InsensitiveStr::Ascii("atrician"),
        dictgen::InsensitiveStr::Ascii("atricians"),
        dictgen::InsensitiveStr::Ascii("atrics"),
        dictgen::InsensitiveStr::Ascii("atrist"),
        dictgen::InsensitiveStr::Ascii("atrists"),
        dictgen::InsensitiveStr::Ascii("atry"),
    ],
    values: &[
        &[(0b11001, &ENTRY_PEDIATRIC_15313872787895414938)],
        &[(0b11001, &ENTRY_PEDIATRICIAN_4966154998070314122)],
        &[(0b11001, &ENTRY_PEDIATRICIANS_15463730532134461621)],
        &[(0b11001, &ENTRY_PEDIATRICS_13936732030428661587)],
        &[(0b00001, &ENTRY_PEDIATRICIAN_4966154998070314122)],
        &[(0b00001, &ENTRY_PEDIATRICIANS_15463730532134461621)],
        &[(0b00001, &ENTRY_PEDIATRY_2293953192712354696)],
    ],
    range: 4..=9,
};

static VARS_PEDE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDE_CHILDREN),
    value: None,
};

pub static VARS_PEDE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rastic"),
        dictgen::InsensitiveStr::Ascii("rastically"),
        dictgen::InsensitiveStr::Ascii("staled"),
        dictgen::InsensitiveStr::Ascii("staling"),
        dictgen::InsensitiveStr::Ascii("stalled"),
        dictgen::InsensitiveStr::Ascii("stalling"),
        dictgen::InsensitiveStr::Ascii("strianisation"),
        dictgen::InsensitiveStr::Ascii("strianisations"),
        dictgen::InsensitiveStr::Ascii("strianise"),
        dictgen::InsensitiveStr::Ascii("strianised"),
        dictgen::InsensitiveStr::Ascii("strianises"),
        dictgen::InsensitiveStr::Ascii("strianising"),
        dictgen::InsensitiveStr::Ascii("strianization"),
        dictgen::InsensitiveStr::Ascii("strianizations"),
        dictgen::InsensitiveStr::Ascii("strianize"),
        dictgen::InsensitiveStr::Ascii("strianized"),
        dictgen::InsensitiveStr::Ascii("strianizes"),
        dictgen::InsensitiveStr::Ascii("strianizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PEDERASTIC_17115437534756487424)],
        &[(0b00001, &ENTRY_PEDERASTICALLY_1594944586317571210)],
        &[(0b00001, &ENTRY_PEDESTALED_5064702925171931752)],
        &[(0b00001, &ENTRY_PEDESTALING_5513881429185692140)],
        &[(0b11010, &ENTRY_PEDESTALED_5064702925171931752)],
        &[(0b11010, &ENTRY_PEDESTALING_5513881429185692140)],
        &[(0b10010, &ENTRY_PEDESTRIANIZATION_6831974054939138972)],
        &[(0b10010, &ENTRY_PEDESTRIANIZATIONS_1818839118428039973)],
        &[(0b10010, &ENTRY_PEDESTRIANIZE_8912536611462431290)],
        &[(0b10010, &ENTRY_PEDESTRIANIZED_6092822769668740533)],
        &[(0b10010, &ENTRY_PEDESTRIANIZES_4773122656566851623)],
        &[(0b10010, &ENTRY_PEDESTRIANIZING_6787761233409265782)],
        &[(0b01001, &ENTRY_PEDESTRIANIZATION_6831974054939138972)],
        &[(0b01001, &ENTRY_PEDESTRIANIZATIONS_1818839118428039973)],
        &[(0b01001, &ENTRY_PEDESTRIANIZE_8912536611462431290)],
        &[(0b01001, &ENTRY_PEDESTRIANIZED_6092822769668740533)],
        &[(0b01001, &ENTRY_PEDESTRIANIZES_4773122656566851623)],
        &[(0b01001, &ENTRY_PEDESTRIANIZING_6787761233409265782)],
    ],
    range: 6..=14,
};

static VARS_PEDD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDD_CHILDREN),
    value: None,
};

pub static VARS_PEDD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
    ],
    values: &[
        &[(0b01001, &ENTRY_PEDDLER_12988527131900246705)],
        &[(0b01001, &ENTRY_PEDDLERS_7582072568641139004)],
    ],
    range: 3..=4,
};

static VARS_PEDA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEDA_CHILDREN),
    value: None,
};

pub static VARS_PEDA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gog"),
        dictgen::InsensitiveStr::Ascii("gogism"),
        dictgen::InsensitiveStr::Ascii("gogs"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("nticise"),
        dictgen::InsensitiveStr::Ascii("nticised"),
        dictgen::InsensitiveStr::Ascii("nticises"),
        dictgen::InsensitiveStr::Ascii("nticising"),
        dictgen::InsensitiveStr::Ascii("nticize"),
        dictgen::InsensitiveStr::Ascii("nticized"),
        dictgen::InsensitiveStr::Ascii("nticizes"),
        dictgen::InsensitiveStr::Ascii("nticizing"),
        dictgen::InsensitiveStr::Ascii("ntise"),
        dictgen::InsensitiveStr::Ascii("ntised"),
        dictgen::InsensitiveStr::Ascii("ntises"),
        dictgen::InsensitiveStr::Ascii("ntising"),
        dictgen::InsensitiveStr::Ascii("ntize"),
        dictgen::InsensitiveStr::Ascii("ntized"),
        dictgen::InsensitiveStr::Ascii("ntizes"),
        dictgen::InsensitiveStr::Ascii("ntizing"),
        dictgen::InsensitiveStr::Ascii("trophia"),
        dictgen::InsensitiveStr::Ascii("trophy"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PEDAGOGUE_5925453470466399155)],
        &[(0b00001, &ENTRY_PEDAGOGISM_2620385797924030298)],
        &[(0b00001, &ENTRY_PEDAGOGUES_16264776000371188720)],
        &[(0b01001, &ENTRY_PEDALED_7595673651683866382)],
        &[(0b01001, &ENTRY_PEDALER_10178424986842986369)],
        &[(0b01001, &ENTRY_PEDALERS_4293589040040332936)],
        &[(0b01001, &ENTRY_PEDALING_16638355318352644805)],
        &[(0b11010, &ENTRY_PEDALED_7595673651683866382)],
        &[(0b11010, &ENTRY_PEDALER_10178424986842986369)],
        &[(0b11010, &ENTRY_PEDALERS_4293589040040332936)],
        &[(0b11010, &ENTRY_PEDALING_16638355318352644805)],
        &[(0b10010, &ENTRY_PEDANTICIZE_15008322026356551489)],
        &[(0b10010, &ENTRY_PEDANTICIZED_2644900939669971869)],
        &[(0b10010, &ENTRY_PEDANTICIZES_14833130317335097545)],
        &[(0b10010, &ENTRY_PEDANTICIZING_5200924377674025265)],
        &[(0b01001, &ENTRY_PEDANTICIZE_15008322026356551489)],
        &[(0b01001, &ENTRY_PEDANTICIZED_2644900939669971869)],
        &[(0b01001, &ENTRY_PEDANTICIZES_14833130317335097545)],
        &[(0b01001, &ENTRY_PEDANTICIZING_5200924377674025265)],
        &[(0b10010, &ENTRY_PEDANTIZE_692434760472693565)],
        &[(0b10010, &ENTRY_PEDANTIZED_7459552709032736273)],
        &[(0b10010, &ENTRY_PEDANTIZES_9391276727368944001)],
        &[(0b10010, &ENTRY_PEDANTIZING_12101236953723349590)],
        &[(0b01001, &ENTRY_PEDANTIZE_692434760472693565)],
        &[(0b01001, &ENTRY_PEDANTIZED_7459552709032736273)],
        &[(0b01001, &ENTRY_PEDANTIZES_9391276727368944001)],
        &[(0b01001, &ENTRY_PEDANTIZING_12101236953723349590)],
        &[(0b00001, &ENTRY_PEDATROPHIA_11165730187451303309)],
        &[(0b00001, &ENTRY_PEDATROPHY_16866522103673061087)],
    ],
    range: 3..=9,
};

static VARS_PEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEC_CHILDREN),
    value: None,
};

pub static VARS_PEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tisations"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tizations"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
        dictgen::InsensitiveStr::Ascii("uliarise"),
        dictgen::InsensitiveStr::Ascii("uliarised"),
        dictgen::InsensitiveStr::Ascii("uliarises"),
        dictgen::InsensitiveStr::Ascii("uliarising"),
        dictgen::InsensitiveStr::Ascii("uliarize"),
        dictgen::InsensitiveStr::Ascii("uliarized"),
        dictgen::InsensitiveStr::Ascii("uliarizes"),
        dictgen::InsensitiveStr::Ascii("uliarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PECTIZATION_11254255408733762028)],
        &[(0b10010, &ENTRY_PECTIZATIONS_4185232191919886847)],
        &[(0b10010, &ENTRY_PECTIZE_5412505057526179714)],
        &[(0b10010, &ENTRY_PECTIZED_10449981344915979630)],
        &[(0b10010, &ENTRY_PECTIZES_755598332277146179)],
        &[(0b10010, &ENTRY_PECTIZING_3322743597581866011)],
        &[(0b01001, &ENTRY_PECTIZATION_11254255408733762028)],
        &[(0b01001, &ENTRY_PECTIZATIONS_4185232191919886847)],
        &[(0b01001, &ENTRY_PECTIZE_5412505057526179714)],
        &[(0b01001, &ENTRY_PECTIZED_10449981344915979630)],
        &[(0b01001, &ENTRY_PECTIZES_755598332277146179)],
        &[(0b01001, &ENTRY_PECTIZING_3322743597581866011)],
        &[(0b10010, &ENTRY_PECULIARIZE_3060403711343105035)],
        &[(0b10010, &ENTRY_PECULIARIZED_1005227671399616416)],
        &[(0b10010, &ENTRY_PECULIARIZES_4613690243312766864)],
        &[(0b10010, &ENTRY_PECULIARIZING_2141506766135845761)],
        &[(0b01001, &ENTRY_PECULIARIZE_3060403711343105035)],
        &[(0b01001, &ENTRY_PECULIARIZED_1005227671399616416)],
        &[(0b01001, &ENTRY_PECULIARIZES_4613690243312766864)],
        &[(0b01001, &ENTRY_PECULIARIZING_2141506766135845761)],
    ],
    range: 4..=10,
};

static VARS_PEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PEA_CHILDREN),
    value: None,
};

pub static VARS_PEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rlisation"),
        dictgen::InsensitiveStr::Ascii("rlise"),
        dictgen::InsensitiveStr::Ascii("rlised"),
        dictgen::InsensitiveStr::Ascii("rlises"),
        dictgen::InsensitiveStr::Ascii("rlising"),
        dictgen::InsensitiveStr::Ascii("rlization"),
        dictgen::InsensitiveStr::Ascii("rlize"),
        dictgen::InsensitiveStr::Ascii("rlized"),
        dictgen::InsensitiveStr::Ascii("rlizes"),
        dictgen::InsensitiveStr::Ascii("rlizing"),
        dictgen::InsensitiveStr::Ascii("santise"),
        dictgen::InsensitiveStr::Ascii("santises"),
        dictgen::InsensitiveStr::Ascii("santize"),
        dictgen::InsensitiveStr::Ascii("santizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PEARLIZATION_26508564052178328)],
        &[(0b10010, &ENTRY_PEARLIZE_1870800665189695789)],
        &[(0b10010, &ENTRY_PEARLIZED_1624453871015926144)],
        &[(0b10010, &ENTRY_PEARLIZES_12869936007759673957)],
        &[(0b10010, &ENTRY_PEARLIZING_9707287977475426638)],
        &[(0b01001, &ENTRY_PEARLIZATION_26508564052178328)],
        &[(0b01001, &ENTRY_PEARLIZE_1870800665189695789)],
        &[(0b01001, &ENTRY_PEARLIZED_1624453871015926144)],
        &[(0b01001, &ENTRY_PEARLIZES_12869936007759673957)],
        &[(0b01001, &ENTRY_PEARLIZING_9707287977475426638)],
        &[(0b10010, &ENTRY_PEASANTIZE_642017851460607948)],
        &[(0b10010, &ENTRY_PEASANTIZES_10166156031855873894)],
        &[(0b01001, &ENTRY_PEASANTIZE_642017851460607948)],
        &[(0b01001, &ENTRY_PEASANTIZES_10166156031855873894)],
    ],
    range: 5..=9,
};

static VARS_PA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PA_CHILDREN),
    value: None,
};

static VARS_PA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_PAC_NODE),
    None,
    Some(&VARS_PAE_NODE),
    None,
    Some(&VARS_PAG_NODE),
    None,
    None,
    Some(&VARS_PAJ_NODE),
    None,
    Some(&VARS_PAL_NODE),
    Some(&VARS_PAM_NODE),
    Some(&VARS_PAN_NODE),
    None,
    Some(&VARS_PAP_NODE),
    None,
    Some(&VARS_PAR_NODE),
    Some(&VARS_PAS_NODE),
    Some(&VARS_PAT_NODE),
    Some(&VARS_PAU_NODE),
    Some(&VARS_PAV_NODE),
    None,
    None,
    Some(&VARS_PAY_NODE),
    None,
];

static VARS_PAY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAY_CHILDREN),
    value: None,
};

pub static VARS_PAY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAYNIZE_3729038275545179140)],
        &[(0b10010, &ENTRY_PAYNIZES_15490955026943979655)],
        &[(0b01001, &ENTRY_PAYNIZE_3729038275545179140)],
        &[(0b01001, &ENTRY_PAYNIZES_15490955026943979655)],
    ],
    range: 4..=5,
};

static VARS_PAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAV_CHILDREN),
    value: None,
};

pub static VARS_PAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ior"),
        dictgen::InsensitiveStr::Ascii("iors"),
        dictgen::InsensitiveStr::Ascii("iour"),
        dictgen::InsensitiveStr::Ascii("iours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PAVIOR_17636375175721697070)],
        &[(0b00001, &ENTRY_PAVIORS_7306783981371552851)],
        &[(0b11010, &ENTRY_PAVIOR_17636375175721697070)],
        &[(0b11010, &ENTRY_PAVIORS_7306783981371552851)],
    ],
    range: 3..=5,
};

static VARS_PAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAU_CHILDREN),
    value: None,
};

pub static VARS_PAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("linise"),
        dictgen::InsensitiveStr::Ascii("linises"),
        dictgen::InsensitiveStr::Ascii("linize"),
        dictgen::InsensitiveStr::Ascii("linizes"),
        dictgen::InsensitiveStr::Ascii("perisation"),
        dictgen::InsensitiveStr::Ascii("perisations"),
        dictgen::InsensitiveStr::Ascii("perise"),
        dictgen::InsensitiveStr::Ascii("perised"),
        dictgen::InsensitiveStr::Ascii("periser"),
        dictgen::InsensitiveStr::Ascii("perisers"),
        dictgen::InsensitiveStr::Ascii("perises"),
        dictgen::InsensitiveStr::Ascii("perising"),
        dictgen::InsensitiveStr::Ascii("perization"),
        dictgen::InsensitiveStr::Ascii("perizations"),
        dictgen::InsensitiveStr::Ascii("perize"),
        dictgen::InsensitiveStr::Ascii("perized"),
        dictgen::InsensitiveStr::Ascii("perizer"),
        dictgen::InsensitiveStr::Ascii("perizers"),
        dictgen::InsensitiveStr::Ascii("perizes"),
        dictgen::InsensitiveStr::Ascii("perizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAULINIZE_4447070483648697360)],
        &[(0b10010, &ENTRY_PAULINIZES_7824935294790294303)],
        &[(0b01001, &ENTRY_PAULINIZE_4447070483648697360)],
        &[(0b01001, &ENTRY_PAULINIZES_7824935294790294303)],
        &[(0b10010, &ENTRY_PAUPERIZATION_1367294979133470708)],
        &[(0b10010, &ENTRY_PAUPERIZATIONS_12078339223087449719)],
        &[(0b10010, &ENTRY_PAUPERIZE_8616451812771143864)],
        &[(0b10010, &ENTRY_PAUPERIZED_2170585696432841058)],
        &[(0b10010, &ENTRY_PAUPERIZER_17515758464001019002)],
        &[(0b10010, &ENTRY_PAUPERIZERS_11032753764651813331)],
        &[(0b10010, &ENTRY_PAUPERIZES_6629297486906140663)],
        &[(0b10010, &ENTRY_PAUPERIZING_15608270047399709224)],
        &[(0b01001, &ENTRY_PAUPERIZATION_1367294979133470708)],
        &[(0b01001, &ENTRY_PAUPERIZATIONS_12078339223087449719)],
        &[(0b01001, &ENTRY_PAUPERIZE_8616451812771143864)],
        &[(0b01001, &ENTRY_PAUPERIZED_2170585696432841058)],
        &[(0b01001, &ENTRY_PAUPERIZER_17515758464001019002)],
        &[(0b01001, &ENTRY_PAUPERIZERS_11032753764651813331)],
        &[(0b01001, &ENTRY_PAUPERIZES_6629297486906140663)],
        &[(0b01001, &ENTRY_PAUPERIZING_15608270047399709224)],
    ],
    range: 6..=11,
};

static VARS_PAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAT_CHILDREN),
    value: None,
};

pub static VARS_PAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernalise"),
        dictgen::InsensitiveStr::Ascii("ernalises"),
        dictgen::InsensitiveStr::Ascii("ernalize"),
        dictgen::InsensitiveStr::Ascii("ernalizes"),
        dictgen::InsensitiveStr::Ascii("inae"),
        dictgen::InsensitiveStr::Ascii("inaed"),
        dictgen::InsensitiveStr::Ascii("ine"),
        dictgen::InsensitiveStr::Ascii("ined"),
        dictgen::InsensitiveStr::Ascii("rialisation"),
        dictgen::InsensitiveStr::Ascii("rialisations"),
        dictgen::InsensitiveStr::Ascii("rialise"),
        dictgen::InsensitiveStr::Ascii("rialised"),
        dictgen::InsensitiveStr::Ascii("rialises"),
        dictgen::InsensitiveStr::Ascii("rialising"),
        dictgen::InsensitiveStr::Ascii("rialization"),
        dictgen::InsensitiveStr::Ascii("rializations"),
        dictgen::InsensitiveStr::Ascii("rialize"),
        dictgen::InsensitiveStr::Ascii("rialized"),
        dictgen::InsensitiveStr::Ascii("rializes"),
        dictgen::InsensitiveStr::Ascii("rializing"),
        dictgen::InsensitiveStr::Ascii("rices"),
        dictgen::InsensitiveStr::Ascii("ricoes"),
        dictgen::InsensitiveStr::Ascii("ronisable"),
        dictgen::InsensitiveStr::Ascii("ronisabler"),
        dictgen::InsensitiveStr::Ascii("ronisables"),
        dictgen::InsensitiveStr::Ascii("ronisablest"),
        dictgen::InsensitiveStr::Ascii("ronisation"),
        dictgen::InsensitiveStr::Ascii("ronisations"),
        dictgen::InsensitiveStr::Ascii("ronise"),
        dictgen::InsensitiveStr::Ascii("ronised"),
        dictgen::InsensitiveStr::Ascii("roniser"),
        dictgen::InsensitiveStr::Ascii("ronisers"),
        dictgen::InsensitiveStr::Ascii("ronises"),
        dictgen::InsensitiveStr::Ascii("ronising"),
        dictgen::InsensitiveStr::Ascii("ronisinglier"),
        dictgen::InsensitiveStr::Ascii("ronisingliest"),
        dictgen::InsensitiveStr::Ascii("ronisingly"),
        dictgen::InsensitiveStr::Ascii("ronisings"),
        dictgen::InsensitiveStr::Ascii("ronizable"),
        dictgen::InsensitiveStr::Ascii("ronizabler"),
        dictgen::InsensitiveStr::Ascii("ronizables"),
        dictgen::InsensitiveStr::Ascii("ronizablest"),
        dictgen::InsensitiveStr::Ascii("ronization"),
        dictgen::InsensitiveStr::Ascii("ronizations"),
        dictgen::InsensitiveStr::Ascii("ronize"),
        dictgen::InsensitiveStr::Ascii("ronized"),
        dictgen::InsensitiveStr::Ascii("ronizer"),
        dictgen::InsensitiveStr::Ascii("ronizers"),
        dictgen::InsensitiveStr::Ascii("ronizes"),
        dictgen::InsensitiveStr::Ascii("ronizing"),
        dictgen::InsensitiveStr::Ascii("ronizinglier"),
        dictgen::InsensitiveStr::Ascii("ronizingliest"),
        dictgen::InsensitiveStr::Ascii("ronizingly"),
        dictgen::InsensitiveStr::Ascii("ronizings"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("ternise"),
        dictgen::InsensitiveStr::Ascii("ternises"),
        dictgen::InsensitiveStr::Ascii("ternize"),
        dictgen::InsensitiveStr::Ascii("ternizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PATERNALIZE_16820296051551287672)],
        &[(0b10010, &ENTRY_PATERNALIZES_1247257877767433807)],
        &[(0b01001, &ENTRY_PATERNALIZE_16820296051551287672)],
        &[(0b01001, &ENTRY_PATERNALIZES_1247257877767433807)],
        &[(0b11010, &ENTRY_PATINE_2970293521113220017)],
        &[(0b11010, &ENTRY_PATINED_13394457292336487862)],
        &[(0b00001, &ENTRY_PATINE_2970293521113220017)],
        &[(0b00001, &ENTRY_PATINED_13394457292336487862)],
        &[(0b10010, &ENTRY_PATRIALIZATION_16537461446526410102)],
        &[(0b10010, &ENTRY_PATRIALIZATIONS_17945934088767852952)],
        &[(0b10010, &ENTRY_PATRIALIZE_9230345548828707773)],
        &[(0b10010, &ENTRY_PATRIALIZED_3341367979909806645)],
        &[(0b10010, &ENTRY_PATRIALIZES_185244585711165697)],
        &[(0b10010, &ENTRY_PATRIALIZING_11575701095687435072)],
        &[(0b01001, &ENTRY_PATRIALIZATION_16537461446526410102)],
        &[(0b01001, &ENTRY_PATRIALIZATIONS_17945934088767852952)],
        &[(0b01001, &ENTRY_PATRIALIZE_9230345548828707773)],
        &[(0b01001, &ENTRY_PATRIALIZED_3341367979909806645)],
        &[(0b01001, &ENTRY_PATRIALIZES_185244585711165697)],
        &[(0b01001, &ENTRY_PATRIALIZING_11575701095687435072)],
        &[(0b00001, &ENTRY_PATRICES_5662411576011637155)],
        &[(0b11010, &ENTRY_PATRICES_5662411576011637155)],
        &[(0b10010, &ENTRY_PATRONIZABLE_15319193123060273715)],
        &[(0b10010, &ENTRY_PATRONIZABLER_4132412027758830590)],
        &[(0b10010, &ENTRY_PATRONIZABLES_9272342348159028844)],
        &[(0b10010, &ENTRY_PATRONIZABLEST_9689527443658363422)],
        &[(0b10010, &ENTRY_PATRONIZATION_6477606590083038612)],
        &[(0b10010, &ENTRY_PATRONIZATIONS_7552667099953006768)],
        &[(0b10010, &ENTRY_PATRONIZE_5579497708777119859)],
        &[(0b10010, &ENTRY_PATRONIZED_2861263128246082573)],
        &[(0b10010, &ENTRY_PATRONIZER_6993255105150109640)],
        &[(0b10010, &ENTRY_PATRONIZERS_12866923462083731422)],
        &[(0b10010, &ENTRY_PATRONIZES_339151254169886766)],
        &[(0b10010, &ENTRY_PATRONIZING_3034907083264382838)],
        &[(0b10010, &ENTRY_PATRONIZINGLIER_4247129633497959722)],
        &[(0b10010, &ENTRY_PATRONIZINGLIEST_16680534920939329902)],
        &[(0b10010, &ENTRY_PATRONIZINGLY_1677195389459576502)],
        &[(0b10010, &ENTRY_PATRONIZINGS_17625682551925708597)],
        &[(0b01001, &ENTRY_PATRONIZABLE_15319193123060273715)],
        &[(0b01001, &ENTRY_PATRONIZABLER_4132412027758830590)],
        &[(0b01001, &ENTRY_PATRONIZABLES_9272342348159028844)],
        &[(0b01001, &ENTRY_PATRONIZABLEST_9689527443658363422)],
        &[(0b01001, &ENTRY_PATRONIZATION_6477606590083038612)],
        &[(0b01001, &ENTRY_PATRONIZATIONS_7552667099953006768)],
        &[(0b01001, &ENTRY_PATRONIZE_5579497708777119859)],
        &[(0b01001, &ENTRY_PATRONIZED_2861263128246082573)],
        &[(0b01001, &ENTRY_PATRONIZER_6993255105150109640)],
        &[(0b01001, &ENTRY_PATRONIZERS_12866923462083731422)],
        &[(0b01001, &ENTRY_PATRONIZES_339151254169886766)],
        &[(0b01001, &ENTRY_PATRONIZING_3034907083264382838)],
        &[(0b01001, &ENTRY_PATRONIZINGLIER_4247129633497959722)],
        &[(0b01001, &ENTRY_PATRONIZINGLIEST_16680534920939329902)],
        &[(0b01001, &ENTRY_PATRONIZINGLY_1677195389459576502)],
        &[(0b01001, &ENTRY_PATRONIZINGS_17625682551925708597)],
        &[(0b11010, &ENTRY_PATTE_18436126856913566134)],
        &[(0b00001, &ENTRY_PATTE_18436126856913566134)],
        &[(0b10010, &ENTRY_PATTERNIZE_3076936465414513253)],
        &[(0b10010, &ENTRY_PATTERNIZES_12992806022556722958)],
        &[(0b01001, &ENTRY_PATTERNIZE_3076936465414513253)],
        &[(0b01001, &ENTRY_PATTERNIZES_12992806022556722958)],
    ],
    range: 2..=13,
};

static VARS_PAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAS_CHILDREN),
    value: None,
};

pub static VARS_PAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iphaae"),
        dictgen::InsensitiveStr::Ascii("iphae"),
        dictgen::InsensitiveStr::Ascii("sades"),
        dictgen::InsensitiveStr::Ascii("sadoes"),
        dictgen::InsensitiveStr::Ascii("sivisation"),
        dictgen::InsensitiveStr::Ascii("sivization"),
        dictgen::InsensitiveStr::Ascii("teurisation"),
        dictgen::InsensitiveStr::Ascii("teurisations"),
        dictgen::InsensitiveStr::Ascii("teurise"),
        dictgen::InsensitiveStr::Ascii("teurised"),
        dictgen::InsensitiveStr::Ascii("teuriser"),
        dictgen::InsensitiveStr::Ascii("teurisers"),
        dictgen::InsensitiveStr::Ascii("teurises"),
        dictgen::InsensitiveStr::Ascii("teurising"),
        dictgen::InsensitiveStr::Ascii("teurization"),
        dictgen::InsensitiveStr::Ascii("teurizations"),
        dictgen::InsensitiveStr::Ascii("teurize"),
        dictgen::InsensitiveStr::Ascii("teurized"),
        dictgen::InsensitiveStr::Ascii("teurizer"),
        dictgen::InsensitiveStr::Ascii("teurizers"),
        dictgen::InsensitiveStr::Ascii("teurizes"),
        dictgen::InsensitiveStr::Ascii("teurizing"),
        dictgen::InsensitiveStr::Ascii("toralise"),
        dictgen::InsensitiveStr::Ascii("toralises"),
        dictgen::InsensitiveStr::Ascii("toralize"),
        dictgen::InsensitiveStr::Ascii("toralizes"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PASIPHAE_10488119709560322867)],
        &[(0b00001, &ENTRY_PASIPHAE_10488119709560322867)],
        &[(0b00001, &ENTRY_PASSADES_13578732946213603806)],
        &[(0b11010, &ENTRY_PASSADES_13578732946213603806)],
        &[(0b10010, &ENTRY_PASSIVIZATION_14743361941945546861)],
        &[(0b01001, &ENTRY_PASSIVIZATION_14743361941945546861)],
        &[(0b10010, &ENTRY_PASTEURIZATION_3504555580005315179)],
        &[(0b10010, &ENTRY_PASTEURIZATIONS_102052595045476495)],
        &[(0b10010, &ENTRY_PASTEURIZE_2832181573565026454)],
        &[(0b10010, &ENTRY_PASTEURIZED_5146326881382822263)],
        &[(0b10010, &ENTRY_PASTEURIZER_7779730307883141682)],
        &[(0b10010, &ENTRY_PASTEURIZERS_9491345555555085016)],
        &[(0b10010, &ENTRY_PASTEURIZES_16714282537428831202)],
        &[(0b10010, &ENTRY_PASTEURIZING_7347504323568813914)],
        &[(0b01001, &ENTRY_PASTEURIZATION_3504555580005315179)],
        &[(0b01001, &ENTRY_PASTEURIZATIONS_102052595045476495)],
        &[(0b01001, &ENTRY_PASTEURIZE_2832181573565026454)],
        &[(0b01001, &ENTRY_PASTEURIZED_5146326881382822263)],
        &[(0b01001, &ENTRY_PASTEURIZER_7779730307883141682)],
        &[(0b01001, &ENTRY_PASTEURIZERS_9491345555555085016)],
        &[(0b01001, &ENTRY_PASTEURIZES_16714282537428831202)],
        &[(0b01001, &ENTRY_PASTEURIZING_7347504323568813914)],
        &[(0b10010, &ENTRY_PASTORALIZE_17951514580198521378)],
        &[(0b10010, &ENTRY_PASTORALIZES_4475797865513749802)],
        &[(0b01001, &ENTRY_PASTORALIZE_17951514580198521378)],
        &[(0b01001, &ENTRY_PASTORALIZES_4475797865513749802)],
        &[(0b10010, &ENTRY_PASTORIZE_1632691559568233544)],
        &[(0b10010, &ENTRY_PASTORIZES_7445639879481102329)],
        &[(0b01001, &ENTRY_PASTORIZE_1632691559568233544)],
        &[(0b01001, &ENTRY_PASTORIZES_7445639879481102329)],
    ],
    range: 5..=12,
};

static VARS_PAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PAR_CHILDREN),
    value: None,
};

static VARS_PAR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PARA_NODE),
    None,
    Some(&VARS_PARC_NODE),
    None,
    Some(&VARS_PARE_NODE),
    Some(&VARS_PARF_NODE),
    None,
    None,
    Some(&VARS_PARI_NODE),
    None,
    None,
    Some(&VARS_PARL_NODE),
    None,
    None,
    Some(&VARS_PARO_NODE),
    None,
    None,
    Some(&VARS_PARR_NODE),
    Some(&VARS_PARS_NODE),
    Some(&VARS_PART_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PART_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PART_CHILDREN),
    value: None,
};

pub static VARS_PART_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
        dictgen::InsensitiveStr::Ascii("icolored"),
        dictgen::InsensitiveStr::Ascii("icoloredder"),
        dictgen::InsensitiveStr::Ascii("icoloreddest"),
        dictgen::InsensitiveStr::Ascii("icoloured"),
        dictgen::InsensitiveStr::Ascii("icolouredder"),
        dictgen::InsensitiveStr::Ascii("icoloureddest"),
        dictgen::InsensitiveStr::Ascii("icularisation"),
        dictgen::InsensitiveStr::Ascii("icularisations"),
        dictgen::InsensitiveStr::Ascii("icularise"),
        dictgen::InsensitiveStr::Ascii("icularised"),
        dictgen::InsensitiveStr::Ascii("iculariser"),
        dictgen::InsensitiveStr::Ascii("icularises"),
        dictgen::InsensitiveStr::Ascii("icularising"),
        dictgen::InsensitiveStr::Ascii("icularization"),
        dictgen::InsensitiveStr::Ascii("icularizations"),
        dictgen::InsensitiveStr::Ascii("icularize"),
        dictgen::InsensitiveStr::Ascii("icularized"),
        dictgen::InsensitiveStr::Ascii("icularizer"),
        dictgen::InsensitiveStr::Ascii("icularizes"),
        dictgen::InsensitiveStr::Ascii("icularizing"),
        dictgen::InsensitiveStr::Ascii("isanise"),
        dictgen::InsensitiveStr::Ascii("isanises"),
        dictgen::InsensitiveStr::Ascii("isanize"),
        dictgen::InsensitiveStr::Ascii("isanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARTIALIZE_6483459727437604593)],
        &[(0b10010, &ENTRY_PARTIALIZED_2709517819508033472)],
        &[(0b10010, &ENTRY_PARTIALIZES_13769905578223386853)],
        &[(0b10010, &ENTRY_PARTIALIZING_11646327448099240465)],
        &[(0b01001, &ENTRY_PARTIALIZE_6483459727437604593)],
        &[(0b01001, &ENTRY_PARTIALIZED_2709517819508033472)],
        &[(0b01001, &ENTRY_PARTIALIZES_13769905578223386853)],
        &[(0b01001, &ENTRY_PARTIALIZING_11646327448099240465)],
        &[(0b10001, &ENTRY_PARTICOLORED_4962898152175870348)],
        &[(0b10001, &ENTRY_PARTICOLOREDDER_10954556914378270950)],
        &[(0b10001, &ENTRY_PARTICOLOREDDEST_2681475883544822311)],
        &[(0b11010, &ENTRY_PARTICOLORED_4962898152175870348)],
        &[(0b11010, &ENTRY_PARTICOLOREDDER_10954556914378270950)],
        &[(0b11010, &ENTRY_PARTICOLOREDDEST_2681475883544822311)],
        &[(0b10010, &ENTRY_PARTICULARIZATION_10597016863146923743)],
        &[(0b10010, &ENTRY_PARTICULARIZATIONS_12840694709588521802)],
        &[(0b10010, &ENTRY_PARTICULARIZE_6799382390040618665)],
        &[(0b10010, &ENTRY_PARTICULARIZED_14793866807327365849)],
        &[(0b10010, &ENTRY_PARTICULARIZER_9553956621020704685)],
        &[(0b10010, &ENTRY_PARTICULARIZES_3435670524070905736)],
        &[(0b10010, &ENTRY_PARTICULARIZING_2129782421225948865)],
        &[(0b01001, &ENTRY_PARTICULARIZATION_10597016863146923743)],
        &[(0b01001, &ENTRY_PARTICULARIZATIONS_12840694709588521802)],
        &[(0b01001, &ENTRY_PARTICULARIZE_6799382390040618665)],
        &[(0b01001, &ENTRY_PARTICULARIZED_14793866807327365849)],
        &[(0b01001, &ENTRY_PARTICULARIZER_9553956621020704685)],
        &[(0b01001, &ENTRY_PARTICULARIZES_3435670524070905736)],
        &[(0b01001, &ENTRY_PARTICULARIZING_2129782421225948865)],
        &[(0b10010, &ENTRY_PARTISANIZE_7728091169711740923)],
        &[(0b10010, &ENTRY_PARTISANIZES_9558412409025070058)],
        &[(0b01001, &ENTRY_PARTISANIZE_7728091169711740923)],
        &[(0b01001, &ENTRY_PARTISANIZES_9558412409025070058)],
    ],
    range: 6..=14,
};

static VARS_PARS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARS_CHILDREN),
    value: None,
};

pub static VARS_PARS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARSONIZE_999620183438182016)],
        &[(0b10010, &ENTRY_PARSONIZES_7532265200903960160)],
        &[(0b01001, &ENTRY_PARSONIZE_999620183438182016)],
        &[(0b01001, &ENTRY_PARSONIZES_7532265200903960160)],
    ],
    range: 5..=6,
};

static VARS_PARR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARR_CHILDREN),
    value: None,
};

pub static VARS_PARR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARROTIZE_3559774235199949197)],
        &[(0b10010, &ENTRY_PARROTIZES_9482751000492529167)],
        &[(0b01001, &ENTRY_PARROTIZE_3559774235199949197)],
        &[(0b01001, &ENTRY_PARROTIZES_9482751000492529167)],
    ],
    range: 5..=6,
};

static VARS_PARO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARO_CHILDREN),
    value: None,
};

pub static VARS_PARO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chialisation"),
        dictgen::InsensitiveStr::Ascii("chialisations"),
        dictgen::InsensitiveStr::Ascii("chialise"),
        dictgen::InsensitiveStr::Ascii("chialised"),
        dictgen::InsensitiveStr::Ascii("chialises"),
        dictgen::InsensitiveStr::Ascii("chialising"),
        dictgen::InsensitiveStr::Ascii("chialization"),
        dictgen::InsensitiveStr::Ascii("chializations"),
        dictgen::InsensitiveStr::Ascii("chialize"),
        dictgen::InsensitiveStr::Ascii("chialized"),
        dictgen::InsensitiveStr::Ascii("chializes"),
        dictgen::InsensitiveStr::Ascii("chializing"),
        dictgen::InsensitiveStr::Ascii("ecious"),
        dictgen::InsensitiveStr::Ascii("eciously"),
        dictgen::InsensitiveStr::Ascii("eciousness"),
        dictgen::InsensitiveStr::Ascii("ecism"),
        dictgen::InsensitiveStr::Ascii("ecy"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAROCHIALIZATION_9992801911204982717)],
        &[(0b10010, &ENTRY_PAROCHIALIZATIONS_9802414540039811945)],
        &[(0b10010, &ENTRY_PAROCHIALIZE_4878369212533866158)],
        &[(0b10010, &ENTRY_PAROCHIALIZED_7260130425534967642)],
        &[(0b10010, &ENTRY_PAROCHIALIZES_18097243070015350318)],
        &[(0b10010, &ENTRY_PAROCHIALIZING_17616216312392224371)],
        &[(0b01001, &ENTRY_PAROCHIALIZATION_9992801911204982717)],
        &[(0b01001, &ENTRY_PAROCHIALIZATIONS_9802414540039811945)],
        &[(0b01001, &ENTRY_PAROCHIALIZE_4878369212533866158)],
        &[(0b01001, &ENTRY_PAROCHIALIZED_7260130425534967642)],
        &[(0b01001, &ENTRY_PAROCHIALIZES_18097243070015350318)],
        &[(0b01001, &ENTRY_PAROCHIALIZING_17616216312392224371)],
        &[(0b11010, &ENTRY_PARECIOUS_12511564458907798074)],
        &[(0b11010, &ENTRY_PARECIOUSLY_11156310959668142943)],
        &[(0b11010, &ENTRY_PARECIOUSNESS_7874749331627836854)],
        &[(0b11010, &ENTRY_PARECISM_15139198512135907949)],
        &[(0b11010, &ENTRY_PARECY_5096581135883021145)],
    ],
    range: 3..=13,
};

static VARS_PARL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARL_CHILDREN),
    value: None,
};

pub static VARS_PARL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orish"),
        dictgen::InsensitiveStr::Ascii("ormaid"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourish"),
        dictgen::InsensitiveStr::Ascii("ourmaid"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_PARLOR_941908612091762590)],
        &[(0b00001, &ENTRY_PARLORISH_12231920163055198915)],
        &[(0b10001, &ENTRY_PARLORMAID_11273400895928326109)],
        &[(0b11001, &ENTRY_PARLORS_15955075320930669198)],
        &[(0b11010, &ENTRY_PARLOR_941908612091762590)],
        &[(0b11010, &ENTRY_PARLORISH_12231920163055198915)],
        &[(0b11010, &ENTRY_PARLORMAID_11273400895928326109)],
        &[(0b11010, &ENTRY_PARLORS_15955075320930669198)],
    ],
    range: 2..=7,
};

static VARS_PARI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARI_CHILDREN),
    value: None,
};

pub static VARS_PARI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sianisation"),
        dictgen::InsensitiveStr::Ascii("sianisations"),
        dictgen::InsensitiveStr::Ascii("sianise"),
        dictgen::InsensitiveStr::Ascii("sianises"),
        dictgen::InsensitiveStr::Ascii("sianization"),
        dictgen::InsensitiveStr::Ascii("sianizations"),
        dictgen::InsensitiveStr::Ascii("sianize"),
        dictgen::InsensitiveStr::Ascii("sianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARISIANIZATION_2149081518294904073)],
        &[(0b10010, &ENTRY_PARISIANIZATIONS_12496635998441245631)],
        &[(0b10010, &ENTRY_PARISIANIZE_6192760037620464041)],
        &[(0b10010, &ENTRY_PARISIANIZES_425663399052281478)],
        &[(0b01001, &ENTRY_PARISIANIZATION_2149081518294904073)],
        &[(0b01001, &ENTRY_PARISIANIZATIONS_12496635998441245631)],
        &[(0b01001, &ENTRY_PARISIANIZE_6192760037620464041)],
        &[(0b01001, &ENTRY_PARISIANIZES_425663399052281478)],
    ],
    range: 7..=12,
};

static VARS_PARF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARF_CHILDREN),
    value: None,
};

pub static VARS_PARF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ocalisation"),
        dictgen::InsensitiveStr::Ascii("ocalise"),
        dictgen::InsensitiveStr::Ascii("ocalization"),
        dictgen::InsensitiveStr::Ascii("ocalize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARFOCALIZATION_15255494080564826957)],
        &[(0b10010, &ENTRY_PARFOCALIZE_11199953063987118573)],
        &[(0b01001, &ENTRY_PARFOCALIZATION_15255494080564826957)],
        &[(0b01001, &ENTRY_PARFOCALIZE_11199953063987118573)],
    ],
    range: 7..=11,
};

static VARS_PARE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARE_CHILDREN),
    value: None,
};

pub static VARS_PARE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("ciously"),
        dictgen::InsensitiveStr::Ascii("ciousness"),
        dictgen::InsensitiveStr::Ascii("cism"),
        dictgen::InsensitiveStr::Ascii("cy"),
        dictgen::InsensitiveStr::Ascii("neses"),
        dictgen::InsensitiveStr::Ascii("nesis"),
        dictgen::InsensitiveStr::Ascii("netic"),
        dictgen::InsensitiveStr::Ascii("netical"),
        dictgen::InsensitiveStr::Ascii("nthesisation"),
        dictgen::InsensitiveStr::Ascii("nthesise"),
        dictgen::InsensitiveStr::Ascii("nthesised"),
        dictgen::InsensitiveStr::Ascii("nthesises"),
        dictgen::InsensitiveStr::Ascii("nthesising"),
        dictgen::InsensitiveStr::Ascii("nthesization"),
        dictgen::InsensitiveStr::Ascii("nthesize"),
        dictgen::InsensitiveStr::Ascii("nthesized"),
        dictgen::InsensitiveStr::Ascii("nthesizes"),
        dictgen::InsensitiveStr::Ascii("nthesizing"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PARECIOUS_12511564458907798074)],
        &[(0b10001, &ENTRY_PARECIOUSLY_11156310959668142943)],
        &[(0b10001, &ENTRY_PARECIOUSNESS_7874749331627836854)],
        &[(0b10001, &ENTRY_PARECISM_15139198512135907949)],
        &[(0b10001, &ENTRY_PARECY_5096581135883021145)],
        &[(0b10001, &ENTRY_PARENESES_13856725007668956765)],
        &[(0b10001, &ENTRY_PARENESIS_16089230337112310128)],
        &[(0b10001, &ENTRY_PARENETIC_14181412180643963721)],
        &[(0b10001, &ENTRY_PARENETICAL_16075969944259996555)],
        &[(0b10010, &ENTRY_PARENTHESIZATION_9124500764491892448)],
        &[(0b10010, &ENTRY_PARENTHESIZE_14226036285596216236)],
        &[(0b10010, &ENTRY_PARENTHESIZED_13190399718764525857)],
        &[(0b10010, &ENTRY_PARENTHESIZES_16946392961248470353)],
        &[(0b10010, &ENTRY_PARENTHESIZING_4060837799462431128)],
        &[(0b01001, &ENTRY_PARENTHESIZATION_9124500764491892448)],
        &[(0b01001, &ENTRY_PARENTHESIZE_14226036285596216236)],
        &[(0b01001, &ENTRY_PARENTHESIZED_13190399718764525857)],
        &[(0b01001, &ENTRY_PARENTHESIZES_16946392961248470353)],
        &[(0b01001, &ENTRY_PARENTHESIZING_4060837799462431128)],
        &[(0b10001, &ENTRY_PARESTHESIA_1881280237839265168)],
        &[(0b10001, &ENTRY_PARESTHESIAS_1637525985108297517)],
        &[(0b10001, &ENTRY_PARESTHETIC_3283039464622031643)],
    ],
    range: 2..=12,
};

static VARS_PARC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARC_CHILDREN),
    value: None,
};

pub static VARS_PARC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("hmentise"),
        dictgen::InsensitiveStr::Ascii("hmentised"),
        dictgen::InsensitiveStr::Ascii("hmentises"),
        dictgen::InsensitiveStr::Ascii("hmentising"),
        dictgen::InsensitiveStr::Ascii("hmentize"),
        dictgen::InsensitiveStr::Ascii("hmentized"),
        dictgen::InsensitiveStr::Ascii("hmentizes"),
        dictgen::InsensitiveStr::Ascii("hmentizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PARCELED_13390569989951727254)],
        &[(0b00001, &ENTRY_PARCELER_13062850192066854861)],
        &[(0b00001, &ENTRY_PARCELING_8316945993856781576)],
        &[(0b11010, &ENTRY_PARCELED_13390569989951727254)],
        &[(0b11010, &ENTRY_PARCELER_13062850192066854861)],
        &[(0b11010, &ENTRY_PARCELING_8316945993856781576)],
        &[(0b10010, &ENTRY_PARCHMENTIZE_12324213011474346454)],
        &[(0b10010, &ENTRY_PARCHMENTIZED_12167483454807635503)],
        &[(0b10010, &ENTRY_PARCHMENTIZES_3633165695178418266)],
        &[(0b10010, &ENTRY_PARCHMENTIZING_5076165931333507700)],
        &[(0b01001, &ENTRY_PARCHMENTIZE_12324213011474346454)],
        &[(0b01001, &ENTRY_PARCHMENTIZED_12167483454807635503)],
        &[(0b01001, &ENTRY_PARCHMENTIZES_3633165695178418266)],
        &[(0b01001, &ENTRY_PARCHMENTIZING_5076165931333507700)],
    ],
    range: 4..=10,
};

static VARS_PARA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PARA_CHILDREN),
    value: None,
};

static VARS_PARA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_PARAB_NODE),
    None,
    None,
    Some(&VARS_PARAE_NODE),
    Some(&VARS_PARAF_NODE),
    Some(&VARS_PARAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_PARAL_NODE),
    Some(&VARS_PARAM_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PARAS_NODE),
    Some(&VARS_PARAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PARAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAT_CHILDREN),
    value: None,
};

pub static VARS_PARAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hyroidectomise"),
        dictgen::InsensitiveStr::Ascii("hyroidectomised"),
        dictgen::InsensitiveStr::Ascii("hyroidectomises"),
        dictgen::InsensitiveStr::Ascii("hyroidectomising"),
        dictgen::InsensitiveStr::Ascii("hyroidectomize"),
        dictgen::InsensitiveStr::Ascii("hyroidectomized"),
        dictgen::InsensitiveStr::Ascii("hyroidectomizes"),
        dictgen::InsensitiveStr::Ascii("hyroidectomizing"),
        dictgen::InsensitiveStr::Ascii("ragedia"),
        dictgen::InsensitiveStr::Ascii("ragoedia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARATHYROIDECTOMIZE_14332962201064430908)],
        &[(0b10010, &ENTRY_PARATHYROIDECTOMIZED_6685949501942941317)],
        &[(0b10010, &ENTRY_PARATHYROIDECTOMIZES_13875716632357128903)],
        &[(0b10010, &ENTRY_PARATHYROIDECTOMIZING_12468529059301511586)],
        &[(0b01001, &ENTRY_PARATHYROIDECTOMIZE_14332962201064430908)],
        &[(0b01001, &ENTRY_PARATHYROIDECTOMIZED_6685949501942941317)],
        &[(0b01001, &ENTRY_PARATHYROIDECTOMIZES_13875716632357128903)],
        &[(0b01001, &ENTRY_PARATHYROIDECTOMIZING_12468529059301511586)],
        &[(0b00001, &ENTRY_PARATRAGEDIA_7102269813615164101)],
        &[(0b11010, &ENTRY_PARATRAGEDIA_7102269813615164101)],
    ],
    range: 7..=16,
};

static VARS_PARAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAS_CHILDREN),
    value: None,
};

pub static VARS_PARAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elenae"),
        dictgen::InsensitiveStr::Ascii("elene"),
        dictgen::InsensitiveStr::Ascii("itaemia"),
        dictgen::InsensitiveStr::Ascii("itemia"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PARASELENE_14205012842021982883)],
        &[(0b00001, &ENTRY_PARASELENE_14205012842021982883)],
        &[(0b11010, &ENTRY_PARASITEMIA_2010465244019964494)],
        &[(0b10001, &ENTRY_PARASITEMIA_2010465244019964494)],
        &[(0b10010, &ENTRY_PARASITIZATION_14820584356162257753)],
        &[(0b10010, &ENTRY_PARASITIZE_5242435462062853785)],
        &[(0b10010, &ENTRY_PARASITIZED_8321931620618387182)],
        &[(0b10010, &ENTRY_PARASITIZES_4416122141775362722)],
        &[(0b10010, &ENTRY_PARASITIZING_9042112679581969658)],
        &[(0b01001, &ENTRY_PARASITIZATION_14820584356162257753)],
        &[(0b01001, &ENTRY_PARASITIZE_5242435462062853785)],
        &[(0b01001, &ENTRY_PARASITIZED_8321931620618387182)],
        &[(0b01001, &ENTRY_PARASITIZES_4416122141775362722)],
        &[(0b01001, &ENTRY_PARASITIZING_9042112679581969658)],
    ],
    range: 5..=9,
};

static VARS_PARAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAM_CHILDREN),
    value: None,
};

pub static VARS_PARAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecium"),
        dictgen::InsensitiveStr::Ascii("eterisable"),
        dictgen::InsensitiveStr::Ascii("eterisation"),
        dictgen::InsensitiveStr::Ascii("eterisations"),
        dictgen::InsensitiveStr::Ascii("eterise"),
        dictgen::InsensitiveStr::Ascii("eterised"),
        dictgen::InsensitiveStr::Ascii("eterises"),
        dictgen::InsensitiveStr::Ascii("eterising"),
        dictgen::InsensitiveStr::Ascii("eterizable"),
        dictgen::InsensitiveStr::Ascii("eterization"),
        dictgen::InsensitiveStr::Ascii("eterizations"),
        dictgen::InsensitiveStr::Ascii("eterize"),
        dictgen::InsensitiveStr::Ascii("eterized"),
        dictgen::InsensitiveStr::Ascii("eterizes"),
        dictgen::InsensitiveStr::Ascii("eterizing"),
        dictgen::InsensitiveStr::Ascii("etrisable"),
        dictgen::InsensitiveStr::Ascii("etrisation"),
        dictgen::InsensitiveStr::Ascii("etrisations"),
        dictgen::InsensitiveStr::Ascii("etrise"),
        dictgen::InsensitiveStr::Ascii("etrised"),
        dictgen::InsensitiveStr::Ascii("etrises"),
        dictgen::InsensitiveStr::Ascii("etrising"),
        dictgen::InsensitiveStr::Ascii("etrizable"),
        dictgen::InsensitiveStr::Ascii("etrization"),
        dictgen::InsensitiveStr::Ascii("etrizations"),
        dictgen::InsensitiveStr::Ascii("etrize"),
        dictgen::InsensitiveStr::Ascii("etrized"),
        dictgen::InsensitiveStr::Ascii("etrizes"),
        dictgen::InsensitiveStr::Ascii("etrizing"),
        dictgen::InsensitiveStr::Ascii("oecium"),
    ],
    values: &[
        &[(0b00001, &ENTRY_PARAMECIUM_11380345148477920829)],
        &[(0b10010, &ENTRY_PARAMETERIZABLE_2808545627544279194)],
        &[(0b10010, &ENTRY_PARAMETERIZATION_7197627343403819237)],
        &[(0b10010, &ENTRY_PARAMETERIZATIONS_4100532402271729672)],
        &[(0b10010, &ENTRY_PARAMETERIZE_749505129591253272)],
        &[(0b10010, &ENTRY_PARAMETERIZED_13105902558710911600)],
        &[(0b10010, &ENTRY_PARAMETERIZES_5120553313235644221)],
        &[(0b10010, &ENTRY_PARAMETERIZING_11261879865339041710)],
        &[(0b01001, &ENTRY_PARAMETERIZABLE_2808545627544279194)],
        &[(0b01001, &ENTRY_PARAMETERIZATION_7197627343403819237)],
        &[(0b01001, &ENTRY_PARAMETERIZATIONS_4100532402271729672)],
        &[(0b01001, &ENTRY_PARAMETERIZE_749505129591253272)],
        &[(0b01001, &ENTRY_PARAMETERIZED_13105902558710911600)],
        &[(0b01001, &ENTRY_PARAMETERIZES_5120553313235644221)],
        &[(0b01001, &ENTRY_PARAMETERIZING_11261879865339041710)],
        &[(0b10010, &ENTRY_PARAMETRIZABLE_5928777122379787793)],
        &[(0b10010, &ENTRY_PARAMETRIZATION_7411406993709104163)],
        &[(0b10010, &ENTRY_PARAMETRIZATIONS_5016585554931052909)],
        &[(0b10010, &ENTRY_PARAMETRIZE_14088334789658250719)],
        &[(0b10010, &ENTRY_PARAMETRIZED_17784422469128630511)],
        &[(0b10010, &ENTRY_PARAMETRIZES_15875840276606359299)],
        &[(0b10010, &ENTRY_PARAMETRIZING_684518743725650757)],
        &[(0b01001, &ENTRY_PARAMETRIZABLE_5928777122379787793)],
        &[(0b01001, &ENTRY_PARAMETRIZATION_7411406993709104163)],
        &[(0b01001, &ENTRY_PARAMETRIZATIONS_5016585554931052909)],
        &[(0b01001, &ENTRY_PARAMETRIZE_14088334789658250719)],
        &[(0b01001, &ENTRY_PARAMETRIZED_17784422469128630511)],
        &[(0b01001, &ENTRY_PARAMETRIZES_15875840276606359299)],
        &[(0b01001, &ENTRY_PARAMETRIZING_684518743725650757)],
        &[(0b11010, &ENTRY_PARAMECIUM_11380345148477920829)],
    ],
    range: 5..=12,
};

static VARS_PARAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAL_CHILDREN),
    value: None,
};

pub static VARS_PARAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lelisation"),
        dictgen::InsensitiveStr::Ascii("lelisations"),
        dictgen::InsensitiveStr::Ascii("lelise"),
        dictgen::InsensitiveStr::Ascii("lelised"),
        dictgen::InsensitiveStr::Ascii("leliser"),
        dictgen::InsensitiveStr::Ascii("lelisers"),
        dictgen::InsensitiveStr::Ascii("lelises"),
        dictgen::InsensitiveStr::Ascii("lelising"),
        dictgen::InsensitiveStr::Ascii("lelization"),
        dictgen::InsensitiveStr::Ascii("lelizations"),
        dictgen::InsensitiveStr::Ascii("lelize"),
        dictgen::InsensitiveStr::Ascii("lelized"),
        dictgen::InsensitiveStr::Ascii("lelizer"),
        dictgen::InsensitiveStr::Ascii("lelizers"),
        dictgen::InsensitiveStr::Ascii("lelizes"),
        dictgen::InsensitiveStr::Ascii("lelizing"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ysation"),
        dictgen::InsensitiveStr::Ascii("ysations"),
        dictgen::InsensitiveStr::Ascii("yse"),
        dictgen::InsensitiveStr::Ascii("ysed"),
        dictgen::InsensitiveStr::Ascii("ysedlies"),
        dictgen::InsensitiveStr::Ascii("ysedly"),
        dictgen::InsensitiveStr::Ascii("yser"),
        dictgen::InsensitiveStr::Ascii("ysers"),
        dictgen::InsensitiveStr::Ascii("ysing"),
        dictgen::InsensitiveStr::Ascii("ysinglies"),
        dictgen::InsensitiveStr::Ascii("ysingly"),
        dictgen::InsensitiveStr::Ascii("yzation"),
        dictgen::InsensitiveStr::Ascii("yzations"),
        dictgen::InsensitiveStr::Ascii("yze"),
        dictgen::InsensitiveStr::Ascii("yzed"),
        dictgen::InsensitiveStr::Ascii("yzedlies"),
        dictgen::InsensitiveStr::Ascii("yzedly"),
        dictgen::InsensitiveStr::Ascii("yzer"),
        dictgen::InsensitiveStr::Ascii("yzers"),
        dictgen::InsensitiveStr::Ascii("yzes"),
        dictgen::InsensitiveStr::Ascii("yzing"),
        dictgen::InsensitiveStr::Ascii("yzinglies"),
        dictgen::InsensitiveStr::Ascii("yzingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARALLELIZATION_11371893526743177056)],
        &[(0b10010, &ENTRY_PARALLELIZATIONS_5527525018980081767)],
        &[(0b10010, &ENTRY_PARALLELIZE_4476089616460732502)],
        &[(0b10010, &ENTRY_PARALLELIZED_7737697672669886109)],
        &[(0b10010, &ENTRY_PARALLELIZER_9529835313527884654)],
        &[(0b10010, &ENTRY_PARALLELIZERS_17955085162563936649)],
        &[(0b10010, &ENTRY_PARALLELIZES_6725281951117805650)],
        &[(0b10010, &ENTRY_PARALLELIZING_10961993960559405417)],
        &[(0b01001, &ENTRY_PARALLELIZATION_11371893526743177056)],
        &[(0b01001, &ENTRY_PARALLELIZATIONS_5527525018980081767)],
        &[(0b01001, &ENTRY_PARALLELIZE_4476089616460732502)],
        &[(0b01001, &ENTRY_PARALLELIZED_7737697672669886109)],
        &[(0b01001, &ENTRY_PARALLELIZER_9529835313527884654)],
        &[(0b01001, &ENTRY_PARALLELIZERS_17955085162563936649)],
        &[(0b01001, &ENTRY_PARALLELIZES_6725281951117805650)],
        &[(0b01001, &ENTRY_PARALLELIZING_10961993960559405417)],
        &[(0b10010, &ENTRY_PARALOGIZE_276245645846907921)],
        &[(0b10010, &ENTRY_PARALOGIZED_7353441990226128641)],
        &[(0b10010, &ENTRY_PARALOGIZES_12884972439326038225)],
        &[(0b10010, &ENTRY_PARALOGIZING_8939374896317650319)],
        &[(0b01001, &ENTRY_PARALOGIZE_276245645846907921)],
        &[(0b01001, &ENTRY_PARALOGIZED_7353441990226128641)],
        &[(0b01001, &ENTRY_PARALOGIZES_12884972439326038225)],
        &[(0b01001, &ENTRY_PARALOGIZING_8939374896317650319)],
        &[(0b11010, &ENTRY_PARALYZATION_16507089340912060778)],
        &[(0b11010, &ENTRY_PARALYZATIONS_1774275609038042526)],
        &[(0b11010, &ENTRY_PARALYZE_4857352680562257186)],
        &[(0b11010, &ENTRY_PARALYZED_14571626041912266449)],
        &[(0b11010, &ENTRY_PARALYZEDLIES_3750343561858475702)],
        &[(0b11010, &ENTRY_PARALYZEDLY_8828875855047300798)],
        &[(0b11010, &ENTRY_PARALYZER_12700307170063304346)],
        &[(0b11010, &ENTRY_PARALYZERS_16689764779974601608)],
        &[(0b11010, &ENTRY_PARALYZING_4886446215231470079)],
        &[(0b11010, &ENTRY_PARALYZINGLIES_8785740653550502606)],
        &[(0b11010, &ENTRY_PARALYZINGLY_2992135569354984660)],
        &[(0b00001, &ENTRY_PARALYZATION_16507089340912060778)],
        &[(0b00001, &ENTRY_PARALYZATIONS_1774275609038042526)],
        &[(0b01001, &ENTRY_PARALYZE_4857352680562257186)],
        &[(0b01001, &ENTRY_PARALYZED_14571626041912266449)],
        &[(0b00001, &ENTRY_PARALYZEDLIES_3750343561858475702)],
        &[(0b00001, &ENTRY_PARALYZEDLY_8828875855047300798)],
        &[(0b00001, &ENTRY_PARALYZER_12700307170063304346)],
        &[(0b00001, &ENTRY_PARALYZERS_16689764779974601608)],
        &[(0b01001, &ENTRY_PARALYZES_13640131716118540510)],
        &[(0b01001, &ENTRY_PARALYZING_4886446215231470079)],
        &[(0b00001, &ENTRY_PARALYZINGLIES_8785740653550502606)],
        &[(0b00001, &ENTRY_PARALYZINGLY_2992135569354984660)],
    ],
    range: 3..=11,
};

static VARS_PARAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAG_CHILDREN),
    value: None,
};

pub static VARS_PARAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("raphise"),
        dictgen::InsensitiveStr::Ascii("raphises"),
        dictgen::InsensitiveStr::Ascii("raphize"),
        dictgen::InsensitiveStr::Ascii("raphizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARAGRAPHIZE_15316990182254058602)],
        &[(0b10010, &ENTRY_PARAGRAPHIZES_18032803927207327558)],
        &[(0b01001, &ENTRY_PARAGRAPHIZE_15316990182254058602)],
        &[(0b01001, &ENTRY_PARAGRAPHIZES_18032803927207327558)],
    ],
    range: 7..=8,
};

static VARS_PARAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAF_CHILDREN),
    value: None,
};

pub static VARS_PARAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("finise"),
        dictgen::InsensitiveStr::Ascii("finises"),
        dictgen::InsensitiveStr::Ascii("finize"),
        dictgen::InsensitiveStr::Ascii("finizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARAFFINIZE_10242502814954171305)],
        &[(0b10010, &ENTRY_PARAFFINIZES_12064336249396828188)],
        &[(0b01001, &ENTRY_PARAFFINIZE_10242502814954171305)],
        &[(0b01001, &ENTRY_PARAFFINIZES_12064336249396828188)],
    ],
    range: 6..=7,
};

static VARS_PARAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAE_CHILDREN),
    value: None,
};

pub static VARS_PARAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("neses"),
        dictgen::InsensitiveStr::Ascii("nesis"),
        dictgen::InsensitiveStr::Ascii("netic"),
        dictgen::InsensitiveStr::Ascii("netical"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PARENESES_13856725007668956765)],
        &[(0b11010, &ENTRY_PARENESIS_16089230337112310128)],
        &[(0b11010, &ENTRY_PARENETIC_14181412180643963721)],
        &[(0b11010, &ENTRY_PARENETICAL_16075969944259996555)],
        &[(0b11010, &ENTRY_PARESTHESIA_1881280237839265168)],
        &[(0b11010, &ENTRY_PARESTHESIAS_1637525985108297517)],
        &[(0b11010, &ENTRY_PARESTHETIC_3283039464622031643)],
    ],
    range: 5..=8,
};

static VARS_PARAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PARAB_CHILDREN),
    value: None,
};

pub static VARS_PARAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PARABOLIZATION_3443054328623013834)],
        &[(0b10010, &ENTRY_PARABOLIZE_647480633800331213)],
        &[(0b10010, &ENTRY_PARABOLIZED_16123534121411965653)],
        &[(0b10010, &ENTRY_PARABOLIZES_7112996769899442233)],
        &[(0b10010, &ENTRY_PARABOLIZING_16537085326922700301)],
        &[(0b01001, &ENTRY_PARABOLIZATION_3443054328623013834)],
        &[(0b01001, &ENTRY_PARABOLIZE_647480633800331213)],
        &[(0b01001, &ENTRY_PARABOLIZED_16123534121411965653)],
        &[(0b01001, &ENTRY_PARABOLIZES_7112996769899442233)],
        &[(0b01001, &ENTRY_PARABOLIZING_16537085326922700301)],
    ],
    range: 5..=9,
};

static VARS_PAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAP_CHILDREN),
    value: None,
};

pub static VARS_PAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("illedema"),
        dictgen::InsensitiveStr::Ascii("illoedema"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAPALIZATION_18093835441065843962)],
        &[(0b10010, &ENTRY_PAPALIZATIONS_8937933260778799316)],
        &[(0b10010, &ENTRY_PAPALIZE_7508341397145332147)],
        &[(0b10010, &ENTRY_PAPALIZED_8860509933771894456)],
        &[(0b10010, &ENTRY_PAPALIZER_16569059721153045662)],
        &[(0b10010, &ENTRY_PAPALIZERS_3871507791493356862)],
        &[(0b10010, &ENTRY_PAPALIZES_16609776725154006255)],
        &[(0b10010, &ENTRY_PAPALIZING_11590725765608182808)],
        &[(0b01001, &ENTRY_PAPALIZATION_18093835441065843962)],
        &[(0b01001, &ENTRY_PAPALIZATIONS_8937933260778799316)],
        &[(0b01001, &ENTRY_PAPALIZE_7508341397145332147)],
        &[(0b01001, &ENTRY_PAPALIZED_8860509933771894456)],
        &[(0b01001, &ENTRY_PAPALIZER_16569059721153045662)],
        &[(0b01001, &ENTRY_PAPALIZERS_3871507791493356862)],
        &[(0b01001, &ENTRY_PAPALIZES_16609776725154006255)],
        &[(0b01001, &ENTRY_PAPALIZING_11590725765608182808)],
        &[(0b10001, &ENTRY_PAPILLEDEMA_13947738993687090385)],
        &[(0b11010, &ENTRY_PAPILLEDEMA_13947738993687090385)],
        &[(0b11010, &ENTRY_PAPULE_7630225005240179696)],
        &[(0b00001, &ENTRY_PAPULE_7630225005240179696)],
    ],
    range: 3..=10,
};

static VARS_PAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAN_CHILDREN),
    value: None,
};

pub static VARS_PAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("aesthesias"),
        dictgen::InsensitiveStr::Ascii("aesthetic"),
        dictgen::InsensitiveStr::Ascii("derise"),
        dictgen::InsensitiveStr::Ascii("derises"),
        dictgen::InsensitiveStr::Ascii("derize"),
        dictgen::InsensitiveStr::Ascii("derizes"),
        dictgen::InsensitiveStr::Ascii("dora"),
        dictgen::InsensitiveStr::Ascii("doura"),
        dictgen::InsensitiveStr::Ascii("egyrise"),
        dictgen::InsensitiveStr::Ascii("egyrised"),
        dictgen::InsensitiveStr::Ascii("egyrises"),
        dictgen::InsensitiveStr::Ascii("egyrising"),
        dictgen::InsensitiveStr::Ascii("egyrize"),
        dictgen::InsensitiveStr::Ascii("egyrized"),
        dictgen::InsensitiveStr::Ascii("egyrizes"),
        dictgen::InsensitiveStr::Ascii("egyrizing"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elist"),
        dictgen::InsensitiveStr::Ascii("elists"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
        dictgen::InsensitiveStr::Ascii("ellisation"),
        dictgen::InsensitiveStr::Ascii("ellist"),
        dictgen::InsensitiveStr::Ascii("ellists"),
        dictgen::InsensitiveStr::Ascii("ellization"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("gaea"),
        dictgen::InsensitiveStr::Ascii("gea"),
        dictgen::InsensitiveStr::Ascii("omphaean"),
        dictgen::InsensitiveStr::Ascii("omphean"),
        dictgen::InsensitiveStr::Ascii("theonisation"),
        dictgen::InsensitiveStr::Ascii("theonisations"),
        dictgen::InsensitiveStr::Ascii("theonise"),
        dictgen::InsensitiveStr::Ascii("theonises"),
        dictgen::InsensitiveStr::Ascii("theonization"),
        dictgen::InsensitiveStr::Ascii("theonizations"),
        dictgen::InsensitiveStr::Ascii("theonize"),
        dictgen::InsensitiveStr::Ascii("theonizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PANESTHESIA_11035715240294507957)],
        &[(0b11010, &ENTRY_PANESTHESIAS_12180956018251533666)],
        &[(0b11010, &ENTRY_PANESTHETIC_11607514217078102793)],
        &[(0b10010, &ENTRY_PANDERIZE_13584391243213121721)],
        &[(0b10010, &ENTRY_PANDERIZES_1524284286880339446)],
        &[(0b01001, &ENTRY_PANDERIZE_13584391243213121721)],
        &[(0b01001, &ENTRY_PANDERIZES_1524284286880339446)],
        &[(0b00001, &ENTRY_PANDORA_3725190345946682637)],
        &[(0b11010, &ENTRY_PANDORA_3725190345946682637)],
        &[(0b10010, &ENTRY_PANEGYRIZE_13725594811903766701)],
        &[(0b10010, &ENTRY_PANEGYRIZED_2757369675942335026)],
        &[(0b10010, &ENTRY_PANEGYRIZES_11019653756667579465)],
        &[(0b10010, &ENTRY_PANEGYRIZING_8733146786926436047)],
        &[(0b01001, &ENTRY_PANEGYRIZE_13725594811903766701)],
        &[(0b01001, &ENTRY_PANEGYRIZED_2757369675942335026)],
        &[(0b01001, &ENTRY_PANEGYRIZES_11019653756667579465)],
        &[(0b01001, &ENTRY_PANEGYRIZING_8733146786926436047)],
        &[(0b00001, &ENTRY_PANELED_13703633025394020864)],
        &[(0b00001, &ENTRY_PANELING_6797910716086726489)],
        &[(0b00001, &ENTRY_PANELINGS_15074841711846726284)],
        &[(0b10010, &ENTRY_PANELIZED_13331281099468759927)],
        &[(0b00001, &ENTRY_PANELIST_1479227178929273987)],
        &[(0b00001, &ENTRY_PANELISTS_3944165336031850149)],
        &[(0b00001, &ENTRY_PANELIZATION_16652578521390386065)],
        &[(0b01001, &ENTRY_PANELIZED_13331281099468759927)],
        &[(0b11010, &ENTRY_PANELED_13703633025394020864)],
        &[(0b11010, &ENTRY_PANELING_6797910716086726489)],
        &[(0b11010, &ENTRY_PANELINGS_15074841711846726284)],
        &[(0b10010, &ENTRY_PANELIZATION_16652578521390386065)],
        &[(0b11010, &ENTRY_PANELIST_1479227178929273987)],
        &[(0b11010, &ENTRY_PANELISTS_3944165336031850149)],
        &[(0b01000, &ENTRY_PANELIZATION_16652578521390386065)],
        &[(0b10001, &ENTRY_PANESTHESIA_11035715240294507957)],
        &[(0b10001, &ENTRY_PANESTHESIAS_12180956018251533666)],
        &[(0b10001, &ENTRY_PANESTHETIC_11607514217078102793)],
        &[(0b11010, &ENTRY_PANGEA_7134656067039212415)],
        &[(0b00001, &ENTRY_PANGEA_7134656067039212415)],
        &[(0b11010, &ENTRY_PANOMPHEAN_3871256800146061540)],
        &[(0b00001, &ENTRY_PANOMPHEAN_3871256800146061540)],
        &[(0b10010, &ENTRY_PANTHEONIZATION_944840168044661015)],
        &[(0b10010, &ENTRY_PANTHEONIZATIONS_3423114313425744840)],
        &[(0b10010, &ENTRY_PANTHEONIZE_13681139475213145828)],
        &[(0b10010, &ENTRY_PANTHEONIZES_2223291708212001129)],
        &[(0b01001, &ENTRY_PANTHEONIZATION_944840168044661015)],
        &[(0b01001, &ENTRY_PANTHEONIZATIONS_3423114313425744840)],
        &[(0b01001, &ENTRY_PANTHEONIZE_13681139475213145828)],
        &[(0b01001, &ENTRY_PANTHEONIZES_2223291708212001129)],
    ],
    range: 3..=13,
};

static VARS_PAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAM_CHILDREN),
    value: None,
};

pub static VARS_PAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("perise"),
        dictgen::InsensitiveStr::Ascii("perises"),
        dictgen::InsensitiveStr::Ascii("perize"),
        dictgen::InsensitiveStr::Ascii("perizes"),
        dictgen::InsensitiveStr::Ascii("phletise"),
        dictgen::InsensitiveStr::Ascii("phletises"),
        dictgen::InsensitiveStr::Ascii("phletize"),
        dictgen::InsensitiveStr::Ascii("phletizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAMPERIZE_340939352609954382)],
        &[(0b10010, &ENTRY_PAMPERIZES_14945268529810280091)],
        &[(0b01001, &ENTRY_PAMPERIZE_340939352609954382)],
        &[(0b01001, &ENTRY_PAMPERIZES_14945268529810280091)],
        &[(0b10010, &ENTRY_PAMPHLETIZE_11971804629691384479)],
        &[(0b10010, &ENTRY_PAMPHLETIZES_10198512299714902969)],
        &[(0b01001, &ENTRY_PAMPHLETIZE_11971804629691384479)],
        &[(0b01001, &ENTRY_PAMPHLETIZES_10198512299714902969)],
    ],
    range: 6..=9,
};

static VARS_PAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PAL_CHILDREN),
    value: None,
};

static VARS_PAL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALA_NODE),
    None,
    None,
    None,
    Some(&VARS_PALE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALL_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PALL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALL_CHILDREN),
    value: None,
};

pub static VARS_PALL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adiumise"),
        dictgen::InsensitiveStr::Ascii("adiumises"),
        dictgen::InsensitiveStr::Ascii("adiumize"),
        dictgen::InsensitiveStr::Ascii("adiumizes"),
        dictgen::InsensitiveStr::Ascii("etisation"),
        dictgen::InsensitiveStr::Ascii("etisations"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etiser"),
        dictgen::InsensitiveStr::Ascii("etisers"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etization"),
        dictgen::InsensitiveStr::Ascii("etizations"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizer"),
        dictgen::InsensitiveStr::Ascii("etizers"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PALLADIUMIZE_17702952767718609388)],
        &[(0b10010, &ENTRY_PALLADIUMIZES_9849089739995990190)],
        &[(0b01001, &ENTRY_PALLADIUMIZE_17702952767718609388)],
        &[(0b01001, &ENTRY_PALLADIUMIZES_9849089739995990190)],
        &[(0b10010, &ENTRY_PALLETIZATION_9100136200462548037)],
        &[(0b10010, &ENTRY_PALLETIZATIONS_6464829452261813832)],
        &[(0b10010, &ENTRY_PALLETIZE_1396210646911825010)],
        &[(0b10010, &ENTRY_PALLETIZED_12902140764229882038)],
        &[(0b10010, &ENTRY_PALLETIZER_6914094309015631146)],
        &[(0b10010, &ENTRY_PALLETIZERS_11548138475235590986)],
        &[(0b10010, &ENTRY_PALLETIZES_13198673987307815474)],
        &[(0b10010, &ENTRY_PALLETIZING_10974154931828649144)],
        &[(0b01001, &ENTRY_PALLETIZATION_9100136200462548037)],
        &[(0b01001, &ENTRY_PALLETIZATIONS_6464829452261813832)],
        &[(0b01001, &ENTRY_PALLETIZE_1396210646911825010)],
        &[(0b01001, &ENTRY_PALLETIZED_12902140764229882038)],
        &[(0b01001, &ENTRY_PALLETIZER_6914094309015631146)],
        &[(0b01001, &ENTRY_PALLETIZERS_11548138475235590986)],
        &[(0b01001, &ENTRY_PALLETIZES_13198673987307815474)],
        &[(0b01001, &ENTRY_PALLETIZING_10974154931828649144)],
    ],
    range: 5..=10,
};

static VARS_PALE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALE_CHILDREN),
    value: None,
};

static VARS_PALE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALEA_NODE),
    None,
    None,
    None,
    Some(&VARS_PALEE_NODE),
    None,
    None,
    None,
    Some(&VARS_PALEI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALEO_NODE),
    None,
    None,
    None,
    Some(&VARS_PALES_NODE),
    Some(&VARS_PALET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PALET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALET_CHILDREN),
    value: None,
};

pub static VARS_PALET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("iology")],
    values: &[&[(0b10001, &ENTRY_PALETIOLOGY_10862221893256067090)]],
    range: 6..=6,
};

static VARS_PALES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALES_CHILDREN),
    value: None,
};

pub static VARS_PALES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tra"),
        dictgen::InsensitiveStr::Ascii("trae"),
        dictgen::InsensitiveStr::Ascii("tral"),
        dictgen::InsensitiveStr::Ascii("tras"),
        dictgen::InsensitiveStr::Ascii("trian"),
        dictgen::InsensitiveStr::Ascii("tric"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALESTRA_5229500943251203121)],
        &[(0b10001, &ENTRY_PALESTRAE_1477667196546852023)],
        &[(0b10001, &ENTRY_PALESTRAL_2129721318476523672)],
        &[(0b10001, &ENTRY_PALESTRAS_10577628877980961814)],
        &[(0b10001, &ENTRY_PALESTRIAN_16896525722710554753)],
        &[(0b10001, &ENTRY_PALESTRIC_13247296948328839180)],
    ],
    range: 3..=5,
};

static VARS_PALEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALEO_CHILDREN),
    value: None,
};

static VARS_PALEO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALEOA_NODE),
    Some(&VARS_PALEOB_NODE),
    Some(&VARS_PALEOC_NODE),
    Some(&VARS_PALEOD_NODE),
    Some(&VARS_PALEOE_NODE),
    Some(&VARS_PALEOF_NODE),
    Some(&VARS_PALEOG_NODE),
    Some(&VARS_PALEOH_NODE),
    Some(&VARS_PALEOI_NODE),
    None,
    None,
    Some(&VARS_PALEOL_NODE),
    Some(&VARS_PALEOM_NODE),
    Some(&VARS_PALEON_NODE),
    None,
    Some(&VARS_PALEOP_NODE),
    None,
    Some(&VARS_PALEOR_NODE),
    Some(&VARS_PALEOS_NODE),
    Some(&VARS_PALEOT_NODE),
    None,
    Some(&VARS_PALEOV_NODE),
    None,
    None,
    None,
    Some(&VARS_PALEOZ_NODE),
];

static VARS_PALEOZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOZ_CHILDREN),
    value: None,
};

pub static VARS_PALEOZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oic"),
        dictgen::InsensitiveStr::Ascii("oologic"),
        dictgen::InsensitiveStr::Ascii("oological"),
        dictgen::InsensitiveStr::Ascii("oologies"),
        dictgen::InsensitiveStr::Ascii("oologist"),
        dictgen::InsensitiveStr::Ascii("oologists"),
        dictgen::InsensitiveStr::Ascii("oology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOZOIC_15539659693355565678)],
        &[(0b10001, &ENTRY_PALEOZOOLOGIC_15918765432702043975)],
        &[(0b10001, &ENTRY_PALEOZOOLOGICAL_8783617239969730799)],
        &[(0b10001, &ENTRY_PALEOZOOLOGIES_3410495526345315585)],
        &[(0b10001, &ENTRY_PALEOZOOLOGIST_18146472512848833302)],
        &[(0b10001, &ENTRY_PALEOZOOLOGISTS_16974824863261009461)],
        &[(0b10001, &ENTRY_PALEOZOOLOGY_1422962101591588438)],
    ],
    range: 3..=9,
};

static VARS_PALEOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOV_CHILDREN),
    value: None,
};

pub static VARS_PALEOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("olcanic")],
    values: &[&[(0b10001, &ENTRY_PALEOVOLCANIC_375156208850882906)]],
    range: 7..=7,
};

static VARS_PALEOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOT_CHILDREN),
    value: None,
};

pub static VARS_PALEOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("echnic"),
        dictgen::InsensitiveStr::Ascii("halamus"),
        dictgen::InsensitiveStr::Ascii("ropical"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOTECHNIC_15389758989633104362)],
        &[(0b10001, &ENTRY_PALEOTHALAMUS_7765630969377615058)],
        &[(0b10001, &ENTRY_PALEOTROPICAL_5321237610871013456)],
    ],
    range: 6..=7,
};

static VARS_PALEOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOS_CHILDREN),
    value: None,
};

pub static VARS_PALEOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("triatal"),
        dictgen::InsensitiveStr::Ascii("triatum"),
        dictgen::InsensitiveStr::Ascii("tylic"),
        dictgen::InsensitiveStr::Ascii("tyly"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOSTRIATAL_11075530959524135503)],
        &[(0b10001, &ENTRY_PALEOSTRIATUM_3018739928180146534)],
        &[(0b10001, &ENTRY_PALEOSTYLIC_7185491761609231755)],
        &[(0b10001, &ENTRY_PALEOSTYLY_16331580432550579450)],
    ],
    range: 4..=7,
};

static VARS_PALEOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOR_CHILDREN),
    value: None,
};

pub static VARS_PALEOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nithological"),
        dictgen::InsensitiveStr::Ascii("nithology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEORNITHOLOGICAL_1866733716411651985)],
        &[(0b10001, &ENTRY_PALEORNITHOLOGY_3476002279004463238)],
    ],
    range: 9..=12,
};

static VARS_PALEOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOP_CHILDREN),
    value: None,
};

pub static VARS_PALEOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("athologic"),
        dictgen::InsensitiveStr::Ascii("athological"),
        dictgen::InsensitiveStr::Ascii("athologies"),
        dictgen::InsensitiveStr::Ascii("athologist"),
        dictgen::InsensitiveStr::Ascii("athologists"),
        dictgen::InsensitiveStr::Ascii("athology"),
        dictgen::InsensitiveStr::Ascii("edology"),
        dictgen::InsensitiveStr::Ascii("hysiography"),
        dictgen::InsensitiveStr::Ascii("hysiology"),
        dictgen::InsensitiveStr::Ascii("hytic"),
        dictgen::InsensitiveStr::Ascii("hytological"),
        dictgen::InsensitiveStr::Ascii("hytologist"),
        dictgen::InsensitiveStr::Ascii("hytology"),
        dictgen::InsensitiveStr::Ascii("lain"),
        dictgen::InsensitiveStr::Ascii("otamology"),
        dictgen::InsensitiveStr::Ascii("sychic"),
        dictgen::InsensitiveStr::Ascii("sychological"),
        dictgen::InsensitiveStr::Ascii("sychology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOPATHOLOGIC_12214316584075954034)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGICAL_6887317455291404805)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGIES_14671677750367365866)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGIST_12270610216847457118)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGISTS_17271348023550711951)],
        &[(0b10001, &ENTRY_PALEOPATHOLOGY_5627090926175726231)],
        &[(0b10001, &ENTRY_PALEOPEDOLOGY_1197146382262396542)],
        &[(0b10001, &ENTRY_PALEOPHYSIOGRAPHY_12430780127473103003)],
        &[(0b10001, &ENTRY_PALEOPHYSIOLOGY_11536100909731884978)],
        &[(0b10001, &ENTRY_PALEOPHYTIC_11763578694401197746)],
        &[(0b10001, &ENTRY_PALEOPHYTOLOGICAL_11128259889095522921)],
        &[(0b10001, &ENTRY_PALEOPHYTOLOGIST_8077452540555712875)],
        &[(0b10001, &ENTRY_PALEOPHYTOLOGY_17976758756772027621)],
        &[(0b10001, &ENTRY_PALEOPLAIN_3909898326665799560)],
        &[(0b10001, &ENTRY_PALEOPOTAMOLOGY_5121637181893167860)],
        &[(0b10001, &ENTRY_PALEOPSYCHIC_4583882512800260814)],
        &[(0b10001, &ENTRY_PALEOPSYCHOLOGICAL_11882282799276562417)],
        &[(0b10001, &ENTRY_PALEOPSYCHOLOGY_283847755015723996)],
    ],
    range: 4..=12,
};

static VARS_PALEON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEON_CHILDREN),
    value: None,
};

pub static VARS_PALEON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tographic"),
        dictgen::InsensitiveStr::Ascii("tographical"),
        dictgen::InsensitiveStr::Ascii("tographies"),
        dictgen::InsensitiveStr::Ascii("tography"),
        dictgen::InsensitiveStr::Ascii("tol"),
        dictgen::InsensitiveStr::Ascii("tologic"),
        dictgen::InsensitiveStr::Ascii("tological"),
        dictgen::InsensitiveStr::Ascii("tologically"),
        dictgen::InsensitiveStr::Ascii("tologist"),
        dictgen::InsensitiveStr::Ascii("tologists"),
        dictgen::InsensitiveStr::Ascii("tology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEONTOGRAPHIC_14553442358192254400)],
        &[(0b10001, &ENTRY_PALEONTOGRAPHICAL_14600480157080012123)],
        &[(0b10001, &ENTRY_PALEONTOGRAPHIES_4145254269175447370)],
        &[(0b10001, &ENTRY_PALEONTOGRAPHY_7112963726296976935)],
        &[(0b10001, &ENTRY_PALEONTOL_12365596636789393329)],
        &[(0b10001, &ENTRY_PALEONTOLOGIC_17768892661333746888)],
        &[(0b11001, &ENTRY_PALEONTOLOGICAL_12663535461634576551)],
        &[(0b10001, &ENTRY_PALEONTOLOGICALLY_3574530926178177300)],
        &[(0b11001, &ENTRY_PALEONTOLOGIST_12247171017461904774)],
        &[(0b11001, &ENTRY_PALEONTOLOGISTS_13268509669082698999)],
        &[(0b11001, &ENTRY_PALEONTOLOGY_9348542274173969502)],
    ],
    range: 3..=11,
};

static VARS_PALEOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOM_CHILDREN),
    value: None,
};

pub static VARS_PALEOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnetism"),
        dictgen::InsensitiveStr::Ascii("agnetisms"),
        dictgen::InsensitiveStr::Ascii("etallic"),
        dictgen::InsensitiveStr::Ascii("eteorological"),
        dictgen::InsensitiveStr::Ascii("eteorology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOMAGNETISM_12747245265284798200)],
        &[(0b10001, &ENTRY_PALEOMAGNETISMS_12975495479790421940)],
        &[(0b10001, &ENTRY_PALEOMETALLIC_496020103900724451)],
        &[(0b10001, &ENTRY_PALEOMETEOROLOGICAL_550400106195388111)],
        &[(0b10001, &ENTRY_PALEOMETEOROLOGY_13517875046229169369)],
    ],
    range: 7..=13,
};

static VARS_PALEOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOL_CHILDREN),
    value: None,
};

pub static VARS_PALEOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atry"),
        dictgen::InsensitiveStr::Ascii("imnology"),
        dictgen::InsensitiveStr::Ascii("ith"),
        dictgen::InsensitiveStr::Ascii("ithic"),
        dictgen::InsensitiveStr::Ascii("ithical"),
        dictgen::InsensitiveStr::Ascii("ithist"),
        dictgen::InsensitiveStr::Ascii("ithoid"),
        dictgen::InsensitiveStr::Ascii("iths"),
        dictgen::InsensitiveStr::Ascii("ithy"),
        dictgen::InsensitiveStr::Ascii("ogical"),
        dictgen::InsensitiveStr::Ascii("ogist"),
        dictgen::InsensitiveStr::Ascii("ogy"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOLATRY_10924970429013530423)],
        &[(0b10001, &ENTRY_PALEOLIMNOLOGY_14150694516900017849)],
        &[(0b10001, &ENTRY_PALEOLITH_1045819319387817757)],
        &[(0b11001, &ENTRY_PALEOLITHIC_9773849440157812866)],
        &[(0b10001, &ENTRY_PALEOLITHICAL_2938847385029098541)],
        &[(0b10001, &ENTRY_PALEOLITHIST_5532799631229777418)],
        &[(0b10001, &ENTRY_PALEOLITHOID_13241766435280101823)],
        &[(0b10001, &ENTRY_PALEOLITHS_17748074122835398462)],
        &[(0b10001, &ENTRY_PALEOLITHY_10861400960502824252)],
        &[(0b10001, &ENTRY_PALEOLOGICAL_14540869198514592883)],
        &[(0b10001, &ENTRY_PALEOLOGIST_12695091568939120465)],
        &[(0b10001, &ENTRY_PALEOLOGY_14864767825292514427)],
    ],
    range: 3..=8,
};

static VARS_PALEOI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOI_CHILDREN),
    value: None,
};

pub static VARS_PALEOI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("chthyology")],
    values: &[&[(0b10001, &ENTRY_PALEOICHTHYOLOGY_7690182781909447343)]],
    range: 10..=10,
};

static VARS_PALEOH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOH_CHILDREN),
    value: None,
};

pub static VARS_PALEOH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erpetologist"),
        dictgen::InsensitiveStr::Ascii("erpetology"),
        dictgen::InsensitiveStr::Ascii("istology"),
        dictgen::InsensitiveStr::Ascii("ydrography"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOHERPETOLOGIST_2006506636872959347)],
        &[(0b10001, &ENTRY_PALEOHERPETOLOGY_6195422226443274584)],
        &[(0b10001, &ENTRY_PALEOHISTOLOGY_11971446365505053036)],
        &[(0b10001, &ENTRY_PALEOHYDROGRAPHY_16923732770996851993)],
    ],
    range: 8..=12,
};

static VARS_PALEOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOG_CHILDREN),
    value: None,
};

pub static VARS_PALEOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enesis"),
        dictgen::InsensitiveStr::Ascii("enetic"),
        dictgen::InsensitiveStr::Ascii("eographer"),
        dictgen::InsensitiveStr::Ascii("eographers"),
        dictgen::InsensitiveStr::Ascii("eographic"),
        dictgen::InsensitiveStr::Ascii("eographical"),
        dictgen::InsensitiveStr::Ascii("eographically"),
        dictgen::InsensitiveStr::Ascii("eographies"),
        dictgen::InsensitiveStr::Ascii("eography"),
        dictgen::InsensitiveStr::Ascii("eology"),
        dictgen::InsensitiveStr::Ascii("laciology"),
        dictgen::InsensitiveStr::Ascii("lyph"),
        dictgen::InsensitiveStr::Ascii("raph"),
        dictgen::InsensitiveStr::Ascii("raphic"),
        dictgen::InsensitiveStr::Ascii("raphical"),
        dictgen::InsensitiveStr::Ascii("raphically"),
        dictgen::InsensitiveStr::Ascii("raphist"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOGENESIS_3600166863543332590)],
        &[(0b10001, &ENTRY_PALEOGENETIC_1015196132875105067)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHER_6181412299853337706)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHERS_17871739223134050844)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHIC_7239153512084908161)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHICAL_8531426019765749589)],
        &[(0b10001, &ENTRY_PALEOGEOGRAPHICALLY_13029998877556984898)],
        &[(0b11001, &ENTRY_PALEOGEOGRAPHIES_4879378358799199366)],
        &[(0b11001, &ENTRY_PALEOGEOGRAPHY_9694730594843353950)],
        &[(0b10001, &ENTRY_PALEOGEOLOGY_1446971404483318371)],
        &[(0b10001, &ENTRY_PALEOGLACIOLOGY_1379886853019110102)],
        &[(0b10001, &ENTRY_PALEOGLYPH_15757196795062379228)],
        &[(0b10001, &ENTRY_PALEOGRAPH_12540277689198261106)],
        &[(0b10001, &ENTRY_PALEOGRAPHIC_13213503981348166251)],
        &[(0b10001, &ENTRY_PALEOGRAPHICAL_8773289818657734421)],
        &[(0b10001, &ENTRY_PALEOGRAPHICALLY_13565114456978434920)],
        &[(0b10001, &ENTRY_PALEOGRAPHIST_1276539096646670959)],
    ],
    range: 4..=13,
};

static VARS_PALEOF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOF_CHILDREN),
    value: None,
};

pub static VARS_PALEOF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("auna")],
    values: &[&[(0b10001, &ENTRY_PALEOFAUNA_9255676362516904097)]],
    range: 4..=4,
};

static VARS_PALEOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOE_CHILDREN),
    value: None,
};

pub static VARS_PALEOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cologic"),
        dictgen::InsensitiveStr::Ascii("cological"),
        dictgen::InsensitiveStr::Ascii("cologies"),
        dictgen::InsensitiveStr::Ascii("cologist"),
        dictgen::InsensitiveStr::Ascii("cologists"),
        dictgen::InsensitiveStr::Ascii("cology"),
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("ntomologic"),
        dictgen::InsensitiveStr::Ascii("ntomological"),
        dictgen::InsensitiveStr::Ascii("ntomologist"),
        dictgen::InsensitiveStr::Ascii("remology"),
        dictgen::InsensitiveStr::Ascii("thnic"),
        dictgen::InsensitiveStr::Ascii("thnography"),
        dictgen::InsensitiveStr::Ascii("thnologic"),
        dictgen::InsensitiveStr::Ascii("thnological"),
        dictgen::InsensitiveStr::Ascii("thnologist"),
        dictgen::InsensitiveStr::Ascii("thnology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOECOLOGIC_2338176615715809865)],
        &[(0b10001, &ENTRY_PALEOECOLOGICAL_11947291013008837430)],
        &[(0b11001, &ENTRY_PALEOECOLOGIES_11813930991122462231)],
        &[(0b10001, &ENTRY_PALEOECOLOGIST_6577271230726993315)],
        &[(0b10001, &ENTRY_PALEOECOLOGISTS_12793530961960552689)],
        &[(0b11001, &ENTRY_PALEOECOLOGY_9627329165537969229)],
        &[(0b10001, &ENTRY_PALEOENCEPHALON_12092496594413779771)],
        &[(0b10001, &ENTRY_PALEOENTOMOLOGIC_383886705450148741)],
        &[(0b10001, &ENTRY_PALEOENTOMOLOGICAL_13035092658337348165)],
        &[(0b10001, &ENTRY_PALEOENTOMOLOGIST_5711399062674583841)],
        &[(0b10001, &ENTRY_PALEOEREMOLOGY_4326619216815037045)],
        &[(0b10001, &ENTRY_PALEOETHNIC_2616697170182083042)],
        &[(0b10001, &ENTRY_PALEOETHNOGRAPHY_10029791943046919018)],
        &[(0b10001, &ENTRY_PALEOETHNOLOGIC_1647305402535030374)],
        &[(0b10001, &ENTRY_PALEOETHNOLOGICAL_4237301460218128665)],
        &[(0b10001, &ENTRY_PALEOETHNOLOGIST_7879442028488422184)],
        &[(0b10001, &ENTRY_PALEOETHNOLOGY_8500804609820740340)],
    ],
    range: 5..=12,
};

static VARS_PALEOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOD_CHILDREN),
    value: None,
};

pub static VARS_PALEOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("endrologic"),
        dictgen::InsensitiveStr::Ascii("endrological"),
        dictgen::InsensitiveStr::Ascii("endrologically"),
        dictgen::InsensitiveStr::Ascii("endrologist"),
        dictgen::InsensitiveStr::Ascii("endrology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEODENDROLOGIC_8085277507686382792)],
        &[(0b10001, &ENTRY_PALEODENDROLOGICAL_2041711262884531596)],
        &[(0b10001, &ENTRY_PALEODENDROLOGICALLY_3827473591390270826)],
        &[(0b10001, &ENTRY_PALEODENDROLOGIST_1101730449788449946)],
        &[(0b10001, &ENTRY_PALEODENDROLOGY_4540542604348310427)],
    ],
    range: 9..=14,
};

static VARS_PALEOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOC_CHILDREN),
    value: None,
};

pub static VARS_PALEOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eanography"),
        dictgen::InsensitiveStr::Ascii("horology"),
        dictgen::InsensitiveStr::Ascii("limatic"),
        dictgen::InsensitiveStr::Ascii("limatologic"),
        dictgen::InsensitiveStr::Ascii("limatological"),
        dictgen::InsensitiveStr::Ascii("limatologies"),
        dictgen::InsensitiveStr::Ascii("limatologist"),
        dictgen::InsensitiveStr::Ascii("limatologists"),
        dictgen::InsensitiveStr::Ascii("limatology"),
        dictgen::InsensitiveStr::Ascii("oncha"),
        dictgen::InsensitiveStr::Ascii("osmic"),
        dictgen::InsensitiveStr::Ascii("osmology"),
        dictgen::InsensitiveStr::Ascii("rystal"),
        dictgen::InsensitiveStr::Ascii("rystallic"),
        dictgen::InsensitiveStr::Ascii("rystalline"),
        dictgen::InsensitiveStr::Ascii("rystic"),
        dictgen::InsensitiveStr::Ascii("yclic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOCEANOGRAPHY_17101199344090437462)],
        &[(0b10001, &ENTRY_PALEOCHOROLOGY_5640429438972653065)],
        &[(0b10001, &ENTRY_PALEOCLIMATIC_4864976749151865103)],
        &[(0b10001, &ENTRY_PALEOCLIMATOLOGIC_526146125986738672)],
        &[(0b10001, &ENTRY_PALEOCLIMATOLOGICAL_1574786532199586705)],
        &[(0b11001, &ENTRY_PALEOCLIMATOLOGIES_5179884944969798580)],
        &[(0b10001, &ENTRY_PALEOCLIMATOLOGIST_6598866277215835335)],
        &[(0b10001, &ENTRY_PALEOCLIMATOLOGISTS_12743875895326058182)],
        &[(0b11001, &ENTRY_PALEOCLIMATOLOGY_15887222804850141365)],
        &[(0b10001, &ENTRY_PALEOCONCHA_17786127602602440622)],
        &[(0b10001, &ENTRY_PALEOCOSMIC_7194233103148258600)],
        &[(0b10001, &ENTRY_PALEOCOSMOLOGY_7229374416435600718)],
        &[(0b10001, &ENTRY_PALEOCRYSTAL_9876015479913580253)],
        &[(0b10001, &ENTRY_PALEOCRYSTALLIC_14538230435317171258)],
        &[(0b10001, &ENTRY_PALEOCRYSTALLINE_10365119975362565017)],
        &[(0b10001, &ENTRY_PALEOCRYSTIC_2695211631331372901)],
        &[(0b10001, &ENTRY_PALEOCYCLIC_1891041371707085992)],
    ],
    range: 5..=13,
};

static VARS_PALEOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOB_CHILDREN),
    value: None,
};

pub static VARS_PALEOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iogeography"),
        dictgen::InsensitiveStr::Ascii("iologic"),
        dictgen::InsensitiveStr::Ascii("iological"),
        dictgen::InsensitiveStr::Ascii("iologies"),
        dictgen::InsensitiveStr::Ascii("iologist"),
        dictgen::InsensitiveStr::Ascii("iologists"),
        dictgen::InsensitiveStr::Ascii("iology"),
        dictgen::InsensitiveStr::Ascii("otanic"),
        dictgen::InsensitiveStr::Ascii("otanical"),
        dictgen::InsensitiveStr::Ascii("otanically"),
        dictgen::InsensitiveStr::Ascii("otanies"),
        dictgen::InsensitiveStr::Ascii("otanist"),
        dictgen::InsensitiveStr::Ascii("otanists"),
        dictgen::InsensitiveStr::Ascii("otany"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOBIOGEOGRAPHY_12815064252785970775)],
        &[(0b10001, &ENTRY_PALEOBIOLOGIC_16440511702072730664)],
        &[(0b10001, &ENTRY_PALEOBIOLOGICAL_6984844449398043034)],
        &[(0b10001, &ENTRY_PALEOBIOLOGIES_9640345759259243883)],
        &[(0b10001, &ENTRY_PALEOBIOLOGIST_10727925421273428200)],
        &[(0b10001, &ENTRY_PALEOBIOLOGISTS_13074678415638321770)],
        &[(0b10001, &ENTRY_PALEOBIOLOGY_11504082211509448873)],
        &[(0b10001, &ENTRY_PALEOBOTANIC_4268740945431822060)],
        &[(0b10001, &ENTRY_PALEOBOTANICAL_15741271816715346651)],
        &[(0b10001, &ENTRY_PALEOBOTANICALLY_531809237195935810)],
        &[(0b10001, &ENTRY_PALEOBOTANIES_9907904145366116896)],
        &[(0b10001, &ENTRY_PALEOBOTANIST_899453557168994746)],
        &[(0b10001, &ENTRY_PALEOBOTANISTS_4400435446022569085)],
        &[(0b10001, &ENTRY_PALEOBOTANY_14491399323716171031)],
    ],
    range: 5..=11,
};

static VARS_PALEOA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEOA_CHILDREN),
    value: None,
};

pub static VARS_PALEOA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lchemical"),
        dictgen::InsensitiveStr::Ascii("nthropic"),
        dictgen::InsensitiveStr::Ascii("nthropography"),
        dictgen::InsensitiveStr::Ascii("nthropological"),
        dictgen::InsensitiveStr::Ascii("nthropologies"),
        dictgen::InsensitiveStr::Ascii("nthropologist"),
        dictgen::InsensitiveStr::Ascii("nthropologists"),
        dictgen::InsensitiveStr::Ascii("nthropology"),
        dictgen::InsensitiveStr::Ascii("nthropus"),
        dictgen::InsensitiveStr::Ascii("tavism"),
        dictgen::InsensitiveStr::Ascii("tavistic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEOALCHEMICAL_15713650654596147408)],
        &[(0b10001, &ENTRY_PALEOANTHROPIC_5954958120113844205)],
        &[(0b10001, &ENTRY_PALEOANTHROPOGRAPHY_9998212461382827548)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGICAL_18192493413636001900)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGIES_8205118955898337795)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGIST_17669887741894885204)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGISTS_4369638882884050551)],
        &[(0b10001, &ENTRY_PALEOANTHROPOLOGY_3812740593686907410)],
        &[(0b10001, &ENTRY_PALEOANTHROPUS_7420869959409316912)],
        &[(0b10001, &ENTRY_PALEOATAVISM_8551400910343690690)],
        &[(0b10001, &ENTRY_PALEOATAVISTIC_10050677946807803791)],
    ],
    range: 6..=14,
};

static VARS_PALEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEI_CHILDREN),
    value: None,
};

pub static VARS_PALEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chthyologist"),
        dictgen::InsensitiveStr::Ascii("chthyology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEICHTHYOLOGIST_18367699513737958699)],
        &[(0b10001, &ENTRY_PALEICHTHYOLOGY_8302040066162628624)],
    ],
    range: 10..=12,
};

static VARS_PALEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEE_CHILDREN),
    value: None,
};

pub static VARS_PALEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("ntomology"),
        dictgen::InsensitiveStr::Ascii("thnologic"),
        dictgen::InsensitiveStr::Ascii("thnological"),
        dictgen::InsensitiveStr::Ascii("thnologist"),
        dictgen::InsensitiveStr::Ascii("thnology"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEENCEPHALON_17919159965626856547)],
        &[(0b00001, &ENTRY_PALEENTOMOLOGY_9853812566754690275)],
        &[(0b10001, &ENTRY_PALEETHNOLOGIC_14949290099499270450)],
        &[(0b10001, &ENTRY_PALEETHNOLOGICAL_10389145458276668226)],
        &[(0b10001, &ENTRY_PALEETHNOLOGIST_16035307690789850776)],
        &[(0b10001, &ENTRY_PALEETHNOLOGY_8564666823564344109)],
    ],
    range: 8..=11,
};

static VARS_PALEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALEA_CHILDREN),
    value: None,
};

pub static VARS_PALEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nthropic"),
        dictgen::InsensitiveStr::Ascii("rctic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_PALEANTHROPIC_5128209237270456861)],
        &[(0b11001, &ENTRY_PALEARCTIC_10203452201396606217)],
    ],
    range: 5..=8,
};

static VARS_PALA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALA_CHILDREN),
    value: None,
};

static VARS_PALA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_PALAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALAM_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PALAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAT_CHILDREN),
    value: None,
};

pub static VARS_PALAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PALATALIZATION_2924504919577641238)],
        &[(0b10010, &ENTRY_PALATALIZATIONS_7795389490222118981)],
        &[(0b10010, &ENTRY_PALATALIZE_16275238324442191490)],
        &[(0b10010, &ENTRY_PALATALIZED_17714539904743727901)],
        &[(0b10010, &ENTRY_PALATALIZES_14289910770533134417)],
        &[(0b10010, &ENTRY_PALATALIZING_3515198110356997816)],
        &[(0b01001, &ENTRY_PALATALIZATION_2924504919577641238)],
        &[(0b01001, &ENTRY_PALATALIZATIONS_7795389490222118981)],
        &[(0b01001, &ENTRY_PALATALIZE_16275238324442191490)],
        &[(0b01001, &ENTRY_PALATALIZED_17714539904743727901)],
        &[(0b01001, &ENTRY_PALATALIZES_14289910770533134417)],
        &[(0b01001, &ENTRY_PALATALIZING_3515198110356997816)],
        &[(0b10010, &ENTRY_PALATIZATION_15642824953699641821)],
        &[(0b10010, &ENTRY_PALATIZATIONS_17121847778628207370)],
        &[(0b10010, &ENTRY_PALATIZE_5498275993725862299)],
        &[(0b10010, &ENTRY_PALATIZES_14141187893507819752)],
        &[(0b01001, &ENTRY_PALATIZATION_15642824953699641821)],
        &[(0b01001, &ENTRY_PALATIZATIONS_17121847778628207370)],
        &[(0b01001, &ENTRY_PALATIZE_5498275993725862299)],
        &[(0b01001, &ENTRY_PALATIZES_14141187893507819752)],
    ],
    range: 3..=10,
};

static VARS_PALAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAM_CHILDREN),
    value: None,
};

pub static VARS_PALAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALAME_12060485423001427334)],
        &[(0b00001, &ENTRY_PALAME_12060485423001427334)],
    ],
    range: 1..=2,
};

static VARS_PALAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALAE_CHILDREN),
    value: None,
};

static VARS_PALAE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALAEA_NODE),
    None,
    None,
    None,
    Some(&VARS_PALAEE_NODE),
    None,
    None,
    None,
    Some(&VARS_PALAEI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_PALAEO_NODE),
    None,
    None,
    None,
    Some(&VARS_PALAES_NODE),
    Some(&VARS_PALAET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_PALAET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAET_CHILDREN),
    value: None,
};

pub static VARS_PALAET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("iology")],
    values: &[&[(0b11010, &ENTRY_PALETIOLOGY_10862221893256067090)]],
    range: 6..=6,
};

static VARS_PALAES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAES_CHILDREN),
    value: None,
};

pub static VARS_PALAES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tra"),
        dictgen::InsensitiveStr::Ascii("trae"),
        dictgen::InsensitiveStr::Ascii("tral"),
        dictgen::InsensitiveStr::Ascii("tras"),
        dictgen::InsensitiveStr::Ascii("trian"),
        dictgen::InsensitiveStr::Ascii("tric"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALESTRA_5229500943251203121)],
        &[(0b11010, &ENTRY_PALESTRAE_1477667196546852023)],
        &[(0b11010, &ENTRY_PALESTRAL_2129721318476523672)],
        &[(0b11010, &ENTRY_PALESTRAS_10577628877980961814)],
        &[(0b11010, &ENTRY_PALESTRIAN_16896525722710554753)],
        &[(0b11010, &ENTRY_PALESTRIC_13247296948328839180)],
    ],
    range: 3..=5,
};

static VARS_PALAEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_PALAEO_CHILDREN),
    value: None,
};

static VARS_PALAEO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_PALAEOA_NODE),
    Some(&VARS_PALAEOB_NODE),
    Some(&VARS_PALAEOC_NODE),
    Some(&VARS_PALAEOD_NODE),
    Some(&VARS_PALAEOE_NODE),
    Some(&VARS_PALAEOF_NODE),
    Some(&VARS_PALAEOG_NODE),
    Some(&VARS_PALAEOH_NODE),
    Some(&VARS_PALAEOI_NODE),
    None,
    None,
    Some(&VARS_PALAEOL_NODE),
    Some(&VARS_PALAEOM_NODE),
    Some(&VARS_PALAEON_NODE),
    None,
    Some(&VARS_PALAEOP_NODE),
    None,
    Some(&VARS_PALAEOR_NODE),
    Some(&VARS_PALAEOS_NODE),
    Some(&VARS_PALAEOT_NODE),
    None,
    Some(&VARS_PALAEOV_NODE),
    None,
    None,
    None,
    Some(&VARS_PALAEOZ_NODE),
];

static VARS_PALAEOZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOZ_CHILDREN),
    value: None,
};

pub static VARS_PALAEOZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oic"),
        dictgen::InsensitiveStr::Ascii("oologic"),
        dictgen::InsensitiveStr::Ascii("oological"),
        dictgen::InsensitiveStr::Ascii("oologies"),
        dictgen::InsensitiveStr::Ascii("oologist"),
        dictgen::InsensitiveStr::Ascii("oologists"),
        dictgen::InsensitiveStr::Ascii("oology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOZOIC_15539659693355565678)],
        &[(0b11010, &ENTRY_PALEOZOOLOGIC_15918765432702043975)],
        &[(0b11010, &ENTRY_PALEOZOOLOGICAL_8783617239969730799)],
        &[(0b11010, &ENTRY_PALEOZOOLOGIES_3410495526345315585)],
        &[(0b11010, &ENTRY_PALEOZOOLOGIST_18146472512848833302)],
        &[(0b11010, &ENTRY_PALEOZOOLOGISTS_16974824863261009461)],
        &[(0b11010, &ENTRY_PALEOZOOLOGY_1422962101591588438)],
    ],
    range: 3..=9,
};

static VARS_PALAEOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOV_CHILDREN),
    value: None,
};

pub static VARS_PALAEOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("olcanic")],
    values: &[&[(0b11010, &ENTRY_PALEOVOLCANIC_375156208850882906)]],
    range: 7..=7,
};

static VARS_PALAEOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOT_CHILDREN),
    value: None,
};

pub static VARS_PALAEOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("echnic"),
        dictgen::InsensitiveStr::Ascii("halamus"),
        dictgen::InsensitiveStr::Ascii("ropical"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOTECHNIC_15389758989633104362)],
        &[(0b11010, &ENTRY_PALEOTHALAMUS_7765630969377615058)],
        &[(0b11010, &ENTRY_PALEOTROPICAL_5321237610871013456)],
    ],
    range: 6..=7,
};

static VARS_PALAEOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOS_CHILDREN),
    value: None,
};

pub static VARS_PALAEOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("triatal"),
        dictgen::InsensitiveStr::Ascii("triatum"),
        dictgen::InsensitiveStr::Ascii("tylic"),
        dictgen::InsensitiveStr::Ascii("tyly"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOSTRIATAL_11075530959524135503)],
        &[(0b11010, &ENTRY_PALEOSTRIATUM_3018739928180146534)],
        &[(0b11010, &ENTRY_PALEOSTYLIC_7185491761609231755)],
        &[(0b11010, &ENTRY_PALEOSTYLY_16331580432550579450)],
    ],
    range: 4..=7,
};

static VARS_PALAEOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOR_CHILDREN),
    value: None,
};

pub static VARS_PALAEOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nithological"),
        dictgen::InsensitiveStr::Ascii("nithology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEORNITHOLOGICAL_1866733716411651985)],
        &[(0b11010, &ENTRY_PALEORNITHOLOGY_3476002279004463238)],
    ],
    range: 9..=12,
};

static VARS_PALAEOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOP_CHILDREN),
    value: None,
};

pub static VARS_PALAEOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("athologic"),
        dictgen::InsensitiveStr::Ascii("athological"),
        dictgen::InsensitiveStr::Ascii("athologies"),
        dictgen::InsensitiveStr::Ascii("athologist"),
        dictgen::InsensitiveStr::Ascii("athologists"),
        dictgen::InsensitiveStr::Ascii("athology"),
        dictgen::InsensitiveStr::Ascii("edology"),
        dictgen::InsensitiveStr::Ascii("hysiography"),
        dictgen::InsensitiveStr::Ascii("hysiology"),
        dictgen::InsensitiveStr::Ascii("hytic"),
        dictgen::InsensitiveStr::Ascii("hytological"),
        dictgen::InsensitiveStr::Ascii("hytologist"),
        dictgen::InsensitiveStr::Ascii("hytology"),
        dictgen::InsensitiveStr::Ascii("lain"),
        dictgen::InsensitiveStr::Ascii("otamology"),
        dictgen::InsensitiveStr::Ascii("sychic"),
        dictgen::InsensitiveStr::Ascii("sychological"),
        dictgen::InsensitiveStr::Ascii("sychology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOPATHOLOGIC_12214316584075954034)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGICAL_6887317455291404805)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGIES_14671677750367365866)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGIST_12270610216847457118)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGISTS_17271348023550711951)],
        &[(0b11010, &ENTRY_PALEOPATHOLOGY_5627090926175726231)],
        &[(0b11010, &ENTRY_PALEOPEDOLOGY_1197146382262396542)],
        &[(0b11010, &ENTRY_PALEOPHYSIOGRAPHY_12430780127473103003)],
        &[(0b11010, &ENTRY_PALEOPHYSIOLOGY_11536100909731884978)],
        &[(0b11010, &ENTRY_PALEOPHYTIC_11763578694401197746)],
        &[(0b11010, &ENTRY_PALEOPHYTOLOGICAL_11128259889095522921)],
        &[(0b11010, &ENTRY_PALEOPHYTOLOGIST_8077452540555712875)],
        &[(0b11010, &ENTRY_PALEOPHYTOLOGY_17976758756772027621)],
        &[(0b11010, &ENTRY_PALEOPLAIN_3909898326665799560)],
        &[(0b11010, &ENTRY_PALEOPOTAMOLOGY_5121637181893167860)],
        &[(0b11010, &ENTRY_PALEOPSYCHIC_4583882512800260814)],
        &[(0b11010, &ENTRY_PALEOPSYCHOLOGICAL_11882282799276562417)],
        &[(0b11010, &ENTRY_PALEOPSYCHOLOGY_283847755015723996)],
    ],
    range: 4..=12,
};

static VARS_PALAEON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEON_CHILDREN),
    value: None,
};

pub static VARS_PALAEON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tographic"),
        dictgen::InsensitiveStr::Ascii("tographical"),
        dictgen::InsensitiveStr::Ascii("tographies"),
        dictgen::InsensitiveStr::Ascii("tography"),
        dictgen::InsensitiveStr::Ascii("tol"),
        dictgen::InsensitiveStr::Ascii("tologic"),
        dictgen::InsensitiveStr::Ascii("tological"),
        dictgen::InsensitiveStr::Ascii("tologically"),
        dictgen::InsensitiveStr::Ascii("tologist"),
        dictgen::InsensitiveStr::Ascii("tologists"),
        dictgen::InsensitiveStr::Ascii("tology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEONTOGRAPHIC_14553442358192254400)],
        &[(0b11010, &ENTRY_PALEONTOGRAPHICAL_14600480157080012123)],
        &[(0b11010, &ENTRY_PALEONTOGRAPHIES_4145254269175447370)],
        &[(0b11010, &ENTRY_PALEONTOGRAPHY_7112963726296976935)],
        &[(0b11010, &ENTRY_PALEONTOL_12365596636789393329)],
        &[(0b11010, &ENTRY_PALEONTOLOGIC_17768892661333746888)],
        &[(0b10010, &ENTRY_PALEONTOLOGICAL_12663535461634576551)],
        &[(0b11010, &ENTRY_PALEONTOLOGICALLY_3574530926178177300)],
        &[(0b10010, &ENTRY_PALEONTOLOGIST_12247171017461904774)],
        &[(0b10010, &ENTRY_PALEONTOLOGISTS_13268509669082698999)],
        &[(0b10010, &ENTRY_PALEONTOLOGY_9348542274173969502)],
    ],
    range: 3..=11,
};

static VARS_PALAEOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOM_CHILDREN),
    value: None,
};

pub static VARS_PALAEOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnetism"),
        dictgen::InsensitiveStr::Ascii("agnetisms"),
        dictgen::InsensitiveStr::Ascii("etallic"),
        dictgen::InsensitiveStr::Ascii("eteorological"),
        dictgen::InsensitiveStr::Ascii("eteorology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOMAGNETISM_12747245265284798200)],
        &[(0b11010, &ENTRY_PALEOMAGNETISMS_12975495479790421940)],
        &[(0b11010, &ENTRY_PALEOMETALLIC_496020103900724451)],
        &[(0b11010, &ENTRY_PALEOMETEOROLOGICAL_550400106195388111)],
        &[(0b11010, &ENTRY_PALEOMETEOROLOGY_13517875046229169369)],
    ],
    range: 7..=13,
};

static VARS_PALAEOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOL_CHILDREN),
    value: None,
};

pub static VARS_PALAEOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atry"),
        dictgen::InsensitiveStr::Ascii("imnology"),
        dictgen::InsensitiveStr::Ascii("ith"),
        dictgen::InsensitiveStr::Ascii("ithic"),
        dictgen::InsensitiveStr::Ascii("ithical"),
        dictgen::InsensitiveStr::Ascii("ithist"),
        dictgen::InsensitiveStr::Ascii("ithoid"),
        dictgen::InsensitiveStr::Ascii("iths"),
        dictgen::InsensitiveStr::Ascii("ithy"),
        dictgen::InsensitiveStr::Ascii("ogical"),
        dictgen::InsensitiveStr::Ascii("ogist"),
        dictgen::InsensitiveStr::Ascii("ogy"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOLATRY_10924970429013530423)],
        &[(0b11010, &ENTRY_PALEOLIMNOLOGY_14150694516900017849)],
        &[(0b11010, &ENTRY_PALEOLITH_1045819319387817757)],
        &[(0b10010, &ENTRY_PALEOLITHIC_9773849440157812866)],
        &[(0b11010, &ENTRY_PALEOLITHICAL_2938847385029098541)],
        &[(0b11010, &ENTRY_PALEOLITHIST_5532799631229777418)],
        &[(0b11010, &ENTRY_PALEOLITHOID_13241766435280101823)],
        &[(0b11010, &ENTRY_PALEOLITHS_17748074122835398462)],
        &[(0b11010, &ENTRY_PALEOLITHY_10861400960502824252)],
        &[(0b11010, &ENTRY_PALEOLOGICAL_14540869198514592883)],
        &[(0b11010, &ENTRY_PALEOLOGIST_12695091568939120465)],
        &[(0b11010, &ENTRY_PALEOLOGY_14864767825292514427)],
    ],
    range: 3..=8,
};

static VARS_PALAEOI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOI_CHILDREN),
    value: None,
};

pub static VARS_PALAEOI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("chthyology")],
    values: &[&[(0b11010, &ENTRY_PALEOICHTHYOLOGY_7690182781909447343)]],
    range: 10..=10,
};

static VARS_PALAEOH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOH_CHILDREN),
    value: None,
};

pub static VARS_PALAEOH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erpetologist"),
        dictgen::InsensitiveStr::Ascii("erpetology"),
        dictgen::InsensitiveStr::Ascii("istology"),
        dictgen::InsensitiveStr::Ascii("ydrography"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOHERPETOLOGIST_2006506636872959347)],
        &[(0b11010, &ENTRY_PALEOHERPETOLOGY_6195422226443274584)],
        &[(0b11010, &ENTRY_PALEOHISTOLOGY_11971446365505053036)],
        &[(0b11010, &ENTRY_PALEOHYDROGRAPHY_16923732770996851993)],
    ],
    range: 8..=12,
};

static VARS_PALAEOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOG_CHILDREN),
    value: None,
};

pub static VARS_PALAEOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enesis"),
        dictgen::InsensitiveStr::Ascii("enetic"),
        dictgen::InsensitiveStr::Ascii("eographer"),
        dictgen::InsensitiveStr::Ascii("eographers"),
        dictgen::InsensitiveStr::Ascii("eographic"),
        dictgen::InsensitiveStr::Ascii("eographical"),
        dictgen::InsensitiveStr::Ascii("eographically"),
        dictgen::InsensitiveStr::Ascii("eographies"),
        dictgen::InsensitiveStr::Ascii("eography"),
        dictgen::InsensitiveStr::Ascii("eology"),
        dictgen::InsensitiveStr::Ascii("laciology"),
        dictgen::InsensitiveStr::Ascii("lyph"),
        dictgen::InsensitiveStr::Ascii("raph"),
        dictgen::InsensitiveStr::Ascii("raphic"),
        dictgen::InsensitiveStr::Ascii("raphical"),
        dictgen::InsensitiveStr::Ascii("raphically"),
        dictgen::InsensitiveStr::Ascii("raphist"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOGENESIS_3600166863543332590)],
        &[(0b11010, &ENTRY_PALEOGENETIC_1015196132875105067)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHER_6181412299853337706)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHERS_17871739223134050844)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHIC_7239153512084908161)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHICAL_8531426019765749589)],
        &[(0b11010, &ENTRY_PALEOGEOGRAPHICALLY_13029998877556984898)],
        &[(0b10010, &ENTRY_PALEOGEOGRAPHIES_4879378358799199366)],
        &[(0b10010, &ENTRY_PALEOGEOGRAPHY_9694730594843353950)],
        &[(0b11010, &ENTRY_PALEOGEOLOGY_1446971404483318371)],
        &[(0b11010, &ENTRY_PALEOGLACIOLOGY_1379886853019110102)],
        &[(0b11010, &ENTRY_PALEOGLYPH_15757196795062379228)],
        &[(0b11010, &ENTRY_PALEOGRAPH_12540277689198261106)],
        &[(0b11010, &ENTRY_PALEOGRAPHIC_13213503981348166251)],
        &[(0b11010, &ENTRY_PALEOGRAPHICAL_8773289818657734421)],
        &[(0b11010, &ENTRY_PALEOGRAPHICALLY_13565114456978434920)],
        &[(0b11010, &ENTRY_PALEOGRAPHIST_1276539096646670959)],
    ],
    range: 4..=13,
};

static VARS_PALAEOF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOF_CHILDREN),
    value: None,
};

pub static VARS_PALAEOF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("auna")],
    values: &[&[(0b11010, &ENTRY_PALEOFAUNA_9255676362516904097)]],
    range: 4..=4,
};

static VARS_PALAEOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOE_CHILDREN),
    value: None,
};

pub static VARS_PALAEOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cologic"),
        dictgen::InsensitiveStr::Ascii("cological"),
        dictgen::InsensitiveStr::Ascii("cologies"),
        dictgen::InsensitiveStr::Ascii("cologist"),
        dictgen::InsensitiveStr::Ascii("cologists"),
        dictgen::InsensitiveStr::Ascii("cology"),
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("ntomologic"),
        dictgen::InsensitiveStr::Ascii("ntomological"),
        dictgen::InsensitiveStr::Ascii("ntomologist"),
        dictgen::InsensitiveStr::Ascii("remology"),
        dictgen::InsensitiveStr::Ascii("thnic"),
        dictgen::InsensitiveStr::Ascii("thnography"),
        dictgen::InsensitiveStr::Ascii("thnologic"),
        dictgen::InsensitiveStr::Ascii("thnological"),
        dictgen::InsensitiveStr::Ascii("thnologist"),
        dictgen::InsensitiveStr::Ascii("thnology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOECOLOGIC_2338176615715809865)],
        &[(0b11010, &ENTRY_PALEOECOLOGICAL_11947291013008837430)],
        &[(0b10010, &ENTRY_PALEOECOLOGIES_11813930991122462231)],
        &[(0b11010, &ENTRY_PALEOECOLOGIST_6577271230726993315)],
        &[(0b11010, &ENTRY_PALEOECOLOGISTS_12793530961960552689)],
        &[(0b10010, &ENTRY_PALEOECOLOGY_9627329165537969229)],
        &[(0b11010, &ENTRY_PALEOENCEPHALON_12092496594413779771)],
        &[(0b11010, &ENTRY_PALEOENTOMOLOGIC_383886705450148741)],
        &[(0b11010, &ENTRY_PALEOENTOMOLOGICAL_13035092658337348165)],
        &[(0b11010, &ENTRY_PALEOENTOMOLOGIST_5711399062674583841)],
        &[(0b11010, &ENTRY_PALEOEREMOLOGY_4326619216815037045)],
        &[(0b11010, &ENTRY_PALEOETHNIC_2616697170182083042)],
        &[(0b11010, &ENTRY_PALEOETHNOGRAPHY_10029791943046919018)],
        &[(0b11010, &ENTRY_PALEOETHNOLOGIC_1647305402535030374)],
        &[(0b11010, &ENTRY_PALEOETHNOLOGICAL_4237301460218128665)],
        &[(0b11010, &ENTRY_PALEOETHNOLOGIST_7879442028488422184)],
        &[(0b11010, &ENTRY_PALEOETHNOLOGY_8500804609820740340)],
    ],
    range: 5..=12,
};

static VARS_PALAEOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOD_CHILDREN),
    value: None,
};

pub static VARS_PALAEOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("endrologic"),
        dictgen::InsensitiveStr::Ascii("endrological"),
        dictgen::InsensitiveStr::Ascii("endrologically"),
        dictgen::InsensitiveStr::Ascii("endrologist"),
        dictgen::InsensitiveStr::Ascii("endrology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEODENDROLOGIC_8085277507686382792)],
        &[(0b11010, &ENTRY_PALEODENDROLOGICAL_2041711262884531596)],
        &[(0b11010, &ENTRY_PALEODENDROLOGICALLY_3827473591390270826)],
        &[(0b11010, &ENTRY_PALEODENDROLOGIST_1101730449788449946)],
        &[(0b11010, &ENTRY_PALEODENDROLOGY_4540542604348310427)],
    ],
    range: 9..=14,
};

static VARS_PALAEOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOC_CHILDREN),
    value: None,
};

pub static VARS_PALAEOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eanography"),
        dictgen::InsensitiveStr::Ascii("horology"),
        dictgen::InsensitiveStr::Ascii("limatic"),
        dictgen::InsensitiveStr::Ascii("limatologic"),
        dictgen::InsensitiveStr::Ascii("limatological"),
        dictgen::InsensitiveStr::Ascii("limatologies"),
        dictgen::InsensitiveStr::Ascii("limatologist"),
        dictgen::InsensitiveStr::Ascii("limatologists"),
        dictgen::InsensitiveStr::Ascii("limatology"),
        dictgen::InsensitiveStr::Ascii("oncha"),
        dictgen::InsensitiveStr::Ascii("osmic"),
        dictgen::InsensitiveStr::Ascii("osmology"),
        dictgen::InsensitiveStr::Ascii("rystal"),
        dictgen::InsensitiveStr::Ascii("rystallic"),
        dictgen::InsensitiveStr::Ascii("rystalline"),
        dictgen::InsensitiveStr::Ascii("rystic"),
        dictgen::InsensitiveStr::Ascii("yclic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOCEANOGRAPHY_17101199344090437462)],
        &[(0b11010, &ENTRY_PALEOCHOROLOGY_5640429438972653065)],
        &[(0b11010, &ENTRY_PALEOCLIMATIC_4864976749151865103)],
        &[(0b11010, &ENTRY_PALEOCLIMATOLOGIC_526146125986738672)],
        &[(0b11010, &ENTRY_PALEOCLIMATOLOGICAL_1574786532199586705)],
        &[(0b10010, &ENTRY_PALEOCLIMATOLOGIES_5179884944969798580)],
        &[(0b11010, &ENTRY_PALEOCLIMATOLOGIST_6598866277215835335)],
        &[(0b11010, &ENTRY_PALEOCLIMATOLOGISTS_12743875895326058182)],
        &[(0b10010, &ENTRY_PALEOCLIMATOLOGY_15887222804850141365)],
        &[(0b11010, &ENTRY_PALEOCONCHA_17786127602602440622)],
        &[(0b11010, &ENTRY_PALEOCOSMIC_7194233103148258600)],
        &[(0b11010, &ENTRY_PALEOCOSMOLOGY_7229374416435600718)],
        &[(0b11010, &ENTRY_PALEOCRYSTAL_9876015479913580253)],
        &[(0b11010, &ENTRY_PALEOCRYSTALLIC_14538230435317171258)],
        &[(0b11010, &ENTRY_PALEOCRYSTALLINE_10365119975362565017)],
        &[(0b11010, &ENTRY_PALEOCRYSTIC_2695211631331372901)],
        &[(0b11010, &ENTRY_PALEOCYCLIC_1891041371707085992)],
    ],
    range: 5..=13,
};

static VARS_PALAEOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOB_CHILDREN),
    value: None,
};

pub static VARS_PALAEOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iogeography"),
        dictgen::InsensitiveStr::Ascii("iologic"),
        dictgen::InsensitiveStr::Ascii("iological"),
        dictgen::InsensitiveStr::Ascii("iologies"),
        dictgen::InsensitiveStr::Ascii("iologist"),
        dictgen::InsensitiveStr::Ascii("iologists"),
        dictgen::InsensitiveStr::Ascii("iology"),
        dictgen::InsensitiveStr::Ascii("otanic"),
        dictgen::InsensitiveStr::Ascii("otanical"),
        dictgen::InsensitiveStr::Ascii("otanically"),
        dictgen::InsensitiveStr::Ascii("otanies"),
        dictgen::InsensitiveStr::Ascii("otanist"),
        dictgen::InsensitiveStr::Ascii("otanists"),
        dictgen::InsensitiveStr::Ascii("otany"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOBIOGEOGRAPHY_12815064252785970775)],
        &[(0b11010, &ENTRY_PALEOBIOLOGIC_16440511702072730664)],
        &[(0b11010, &ENTRY_PALEOBIOLOGICAL_6984844449398043034)],
        &[(0b11010, &ENTRY_PALEOBIOLOGIES_9640345759259243883)],
        &[(0b11010, &ENTRY_PALEOBIOLOGIST_10727925421273428200)],
        &[(0b11010, &ENTRY_PALEOBIOLOGISTS_13074678415638321770)],
        &[(0b11010, &ENTRY_PALEOBIOLOGY_11504082211509448873)],
        &[(0b11010, &ENTRY_PALEOBOTANIC_4268740945431822060)],
        &[(0b11010, &ENTRY_PALEOBOTANICAL_15741271816715346651)],
        &[(0b11010, &ENTRY_PALEOBOTANICALLY_531809237195935810)],
        &[(0b11010, &ENTRY_PALEOBOTANIES_9907904145366116896)],
        &[(0b11010, &ENTRY_PALEOBOTANIST_899453557168994746)],
        &[(0b11010, &ENTRY_PALEOBOTANISTS_4400435446022569085)],
        &[(0b11010, &ENTRY_PALEOBOTANY_14491399323716171031)],
    ],
    range: 5..=11,
};

static VARS_PALAEOA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEOA_CHILDREN),
    value: None,
};

pub static VARS_PALAEOA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lchemical"),
        dictgen::InsensitiveStr::Ascii("nthropic"),
        dictgen::InsensitiveStr::Ascii("nthropography"),
        dictgen::InsensitiveStr::Ascii("nthropological"),
        dictgen::InsensitiveStr::Ascii("nthropologies"),
        dictgen::InsensitiveStr::Ascii("nthropologist"),
        dictgen::InsensitiveStr::Ascii("nthropologists"),
        dictgen::InsensitiveStr::Ascii("nthropology"),
        dictgen::InsensitiveStr::Ascii("nthropus"),
        dictgen::InsensitiveStr::Ascii("tavism"),
        dictgen::InsensitiveStr::Ascii("tavistic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEOALCHEMICAL_15713650654596147408)],
        &[(0b11010, &ENTRY_PALEOANTHROPIC_5954958120113844205)],
        &[(0b11010, &ENTRY_PALEOANTHROPOGRAPHY_9998212461382827548)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGICAL_18192493413636001900)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGIES_8205118955898337795)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGIST_17669887741894885204)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGISTS_4369638882884050551)],
        &[(0b11010, &ENTRY_PALEOANTHROPOLOGY_3812740593686907410)],
        &[(0b11010, &ENTRY_PALEOANTHROPUS_7420869959409316912)],
        &[(0b11010, &ENTRY_PALEOATAVISM_8551400910343690690)],
        &[(0b11010, &ENTRY_PALEOATAVISTIC_10050677946807803791)],
    ],
    range: 6..=14,
};

static VARS_PALAEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEI_CHILDREN),
    value: None,
};

pub static VARS_PALAEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chthyologist"),
        dictgen::InsensitiveStr::Ascii("chthyology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEICHTHYOLOGIST_18367699513737958699)],
        &[(0b11010, &ENTRY_PALEICHTHYOLOGY_8302040066162628624)],
    ],
    range: 10..=12,
};

static VARS_PALAEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEE_CHILDREN),
    value: None,
};

pub static VARS_PALAEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("ntomology"),
        dictgen::InsensitiveStr::Ascii("thnologic"),
        dictgen::InsensitiveStr::Ascii("thnological"),
        dictgen::InsensitiveStr::Ascii("thnologist"),
        dictgen::InsensitiveStr::Ascii("thnology"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEENCEPHALON_17919159965626856547)],
        &[(0b11010, &ENTRY_PALEENTOMOLOGY_9853812566754690275)],
        &[(0b11010, &ENTRY_PALEETHNOLOGIC_14949290099499270450)],
        &[(0b11010, &ENTRY_PALEETHNOLOGICAL_10389145458276668226)],
        &[(0b11010, &ENTRY_PALEETHNOLOGIST_16035307690789850776)],
        &[(0b11010, &ENTRY_PALEETHNOLOGY_8564666823564344109)],
    ],
    range: 8..=11,
};

static VARS_PALAEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PALAEA_CHILDREN),
    value: None,
};

pub static VARS_PALAEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nthropic"),
        dictgen::InsensitiveStr::Ascii("rctic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PALEANTHROPIC_5128209237270456861)],
        &[(0b10010, &ENTRY_PALEARCTIC_10203452201396606217)],
    ],
    range: 5..=8,
};

static VARS_PAJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAJ_CHILDREN),
    value: None,
};

pub static VARS_PAJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ama"),
        dictgen::InsensitiveStr::Ascii("amaed"),
        dictgen::InsensitiveStr::Ascii("amas"),
    ],
    values: &[
        &[(0b01001, &ENTRY_PAJAMA_6036010499883376406)],
        &[(0b00001, &ENTRY_PAJAMAED_5631330919975772121)],
        &[(0b01001, &ENTRY_PAJAMAS_2981078080473633806)],
    ],
    range: 3..=5,
};

static VARS_PAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAG_CHILDREN),
    value: None,
};

pub static VARS_PAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anisers"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizers"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("inae"),
        dictgen::InsensitiveStr::Ascii("ine"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAGANIZATION_6403498613271915860)],
        &[(0b10010, &ENTRY_PAGANIZATIONS_14987195852717725095)],
        &[(0b10010, &ENTRY_PAGANIZE_3365967695778839525)],
        &[(0b10010, &ENTRY_PAGANIZED_16558435393352092294)],
        &[(0b10010, &ENTRY_PAGANIZER_6489619638171822325)],
        &[(0b10010, &ENTRY_PAGANIZERS_2218453433509959012)],
        &[(0b10010, &ENTRY_PAGANIZES_16725516347835135653)],
        &[(0b10010, &ENTRY_PAGANIZING_17172254602210790902)],
        &[(0b01001, &ENTRY_PAGANIZATION_6403498613271915860)],
        &[(0b01001, &ENTRY_PAGANIZATIONS_14987195852717725095)],
        &[(0b01001, &ENTRY_PAGANIZE_3365967695778839525)],
        &[(0b01001, &ENTRY_PAGANIZED_16558435393352092294)],
        &[(0b01001, &ENTRY_PAGANIZER_6489619638171822325)],
        &[(0b01001, &ENTRY_PAGANIZERS_2218453433509959012)],
        &[(0b01001, &ENTRY_PAGANIZES_16725516347835135653)],
        &[(0b01001, &ENTRY_PAGANIZING_17172254602210790902)],
        &[(0b11010, &ENTRY_PAGINE_14470123767926692710)],
        &[(0b00001, &ENTRY_PAGINE_14470123767926692710)],
    ],
    range: 3..=10,
};

static VARS_PAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAE_CHILDREN),
    value: None,
};

pub static VARS_PAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("dagogism"),
        dictgen::InsensitiveStr::Ascii("datrophia"),
        dictgen::InsensitiveStr::Ascii("datrophy"),
        dictgen::InsensitiveStr::Ascii("derast"),
        dictgen::InsensitiveStr::Ascii("derastic"),
        dictgen::InsensitiveStr::Ascii("derastically"),
        dictgen::InsensitiveStr::Ascii("derasts"),
        dictgen::InsensitiveStr::Ascii("diatric"),
        dictgen::InsensitiveStr::Ascii("diatrician"),
        dictgen::InsensitiveStr::Ascii("diatricians"),
        dictgen::InsensitiveStr::Ascii("diatrics"),
        dictgen::InsensitiveStr::Ascii("diatry"),
        dictgen::InsensitiveStr::Ascii("dobaptism"),
        dictgen::InsensitiveStr::Ascii("dobaptist"),
        dictgen::InsensitiveStr::Ascii("dodontic"),
        dictgen::InsensitiveStr::Ascii("dodontics"),
        dictgen::InsensitiveStr::Ascii("dogeneses"),
        dictgen::InsensitiveStr::Ascii("dogenesis"),
        dictgen::InsensitiveStr::Ascii("dogenetic"),
        dictgen::InsensitiveStr::Ascii("dogenic"),
        dictgen::InsensitiveStr::Ascii("dological"),
        dictgen::InsensitiveStr::Ascii("dologies"),
        dictgen::InsensitiveStr::Ascii("dologist"),
        dictgen::InsensitiveStr::Ascii("dologists"),
        dictgen::InsensitiveStr::Ascii("dology"),
        dictgen::InsensitiveStr::Ascii("dometrical"),
        dictgen::InsensitiveStr::Ascii("domorphic"),
        dictgen::InsensitiveStr::Ascii("domorphism"),
        dictgen::InsensitiveStr::Ascii("domorphisms"),
        dictgen::InsensitiveStr::Ascii("domorphoses"),
        dictgen::InsensitiveStr::Ascii("domorphosis"),
        dictgen::InsensitiveStr::Ascii("dophile"),
        dictgen::InsensitiveStr::Ascii("dophiles"),
        dictgen::InsensitiveStr::Ascii("dophilia"),
        dictgen::InsensitiveStr::Ascii("dophiliac"),
        dictgen::InsensitiveStr::Ascii("dophiliacs"),
        dictgen::InsensitiveStr::Ascii("dophilias"),
        dictgen::InsensitiveStr::Ascii("dophilic"),
        dictgen::InsensitiveStr::Ascii("dotribe"),
        dictgen::InsensitiveStr::Ascii("dotrophic"),
        dictgen::InsensitiveStr::Ascii("dotrophist"),
        dictgen::InsensitiveStr::Ascii("dotrophy"),
    ],
    values: &[
        &[(0b10010, &ENTRY_PAEANIZE_8806779712541481579)],
        &[(0b10010, &ENTRY_PAEANIZES_5368855730242432342)],
        &[(0b01001, &ENTRY_PAEANIZE_8806779712541481579)],
        &[(0b01001, &ENTRY_PAEANIZES_5368855730242432342)],
        &[(0b11010, &ENTRY_PEDAGOGISM_2620385797924030298)],
        &[(0b11010, &ENTRY_PEDATROPHIA_11165730187451303309)],
        &[(0b11010, &ENTRY_PEDATROPHY_16866522103673061087)],
        &[(0b11010, &ENTRY_PEDERAST_1403668280826164388)],
        &[(0b11010, &ENTRY_PEDERASTIC_17115437534756487424)],
        &[(0b11010, &ENTRY_PEDERASTICALLY_1594944586317571210)],
        &[(0b11010, &ENTRY_PEDERASTS_10300182548635094556)],
        &[(0b10010, &ENTRY_PEDIATRIC_15313872787895414938)],
        &[(0b10010, &ENTRY_PEDIATRICIAN_4966154998070314122)],
        &[(0b10010, &ENTRY_PEDIATRICIANS_15463730532134461621)],
        &[(0b10010, &ENTRY_PEDIATRICS_13936732030428661587)],
        &[(0b11010, &ENTRY_PEDIATRY_2293953192712354696)],
        &[(0b11010, &ENTRY_PEDOBAPTISM_10804678125904355110)],
        &[(0b11010, &ENTRY_PEDOBAPTIST_17393232685703437549)],
        &[(0b11010, &ENTRY_PEDODONTIC_10829590082192845044)],
        &[(0b11010, &ENTRY_PEDODONTICS_5640137182749900289)],
        &[(0b11010, &ENTRY_PEDOGENESES_15579264777447032512)],
        &[(0b11010, &ENTRY_PEDOGENESIS_2691289146214329072)],
        &[(0b11010, &ENTRY_PEDOGENETIC_9300436022082143535)],
        &[(0b11010, &ENTRY_PEDOGENIC_15968023895342516337)],
        &[(0b11010, &ENTRY_PEDOLOGICAL_10471927294836257811)],
        &[(0b11010, &ENTRY_PEDOLOGIES_8776905115060190956)],
        &[(0b11010, &ENTRY_PEDOLOGIST_17875058654848962441)],
        &[(0b11010, &ENTRY_PEDOLOGISTS_1295482932093776852)],
        &[(0b11010, &ENTRY_PEDOLOGY_3417988831421593040)],
        &[(0b11010, &ENTRY_PEDOMETRICAL_11798284037226839595)],
        &[(0b11010, &ENTRY_PEDOMORPHIC_6860459212658075764)],
        &[(0b11010, &ENTRY_PEDOMORPHISM_1336265225990998891)],
        &[(0b11010, &ENTRY_PEDOMORPHISMS_16472332478041997069)],
        &[(0b11010, &ENTRY_PEDOMORPHOSES_11301460943449417276)],
        &[(0b11010, &ENTRY_PEDOMORPHOSIS_14966272193032820392)],
        &[(0b10010, &ENTRY_PEDOPHILE_9927986055882192373)],
        &[(0b10010, &ENTRY_PEDOPHILES_4655841018136971409)],
        &[(0b11010, &ENTRY_PEDOPHILIA_9946016916272449426)],
        &[(0b11010, &ENTRY_PEDOPHILIAC_875642557192171107)],
        &[(0b11010, &ENTRY_PEDOPHILIACS_9467101932093289852)],
        &[(0b11010, &ENTRY_PEDOPHILIAS_10406528979051385197)],
        &[(0b11010, &ENTRY_PEDOPHILIC_10586175930831437217)],
        &[(0b11010, &ENTRY_PEDOTRIBE_5791037896195905072)],
        &[(0b11010, &ENTRY_PEDOTROPHIC_4225819697418345119)],
        &[(0b11010, &ENTRY_PEDOTROPHIST_13613791383976217031)],
        &[(0b11010, &ENTRY_PEDOTROPHY_11224422965985252808)],
    ],
    range: 5..=12,
};

static VARS_PAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_PAC_CHILDREN),
    value: None,
};

pub static VARS_PAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hyaemia"),
        dictgen::InsensitiveStr::Ascii("hyemia"),
        dictgen::InsensitiveStr::Ascii("hyhaemia"),
        dictgen::InsensitiveStr::Ascii("hyhemia"),
        dictgen::InsensitiveStr::Ascii("ketisation"),
        dictgen::InsensitiveStr::Ascii("ketise"),
        dictgen::InsensitiveStr::Ascii("ketised"),
        dictgen::InsensitiveStr::Ascii("ketiser"),
        dictgen::InsensitiveStr::Ascii("ketisers"),
        dictgen::InsensitiveStr::Ascii("ketises"),
        dictgen::InsensitiveStr::Ascii("ketising"),
        dictgen::InsensitiveStr::Ascii("ketization"),
        dictgen::InsensitiveStr::Ascii("ketize"),
        dictgen::InsensitiveStr::Ascii("ketized"),
        dictgen::InsensitiveStr::Ascii("ketizer"),
        dictgen::InsensitiveStr::Ascii("ketizers"),
        dictgen::InsensitiveStr::Ascii("ketizes"),
        dictgen::InsensitiveStr::Ascii("ketizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_PACHYEMIA_2167378922137939193)],
        &[(0b10001, &ENTRY_PACHYEMIA_2167378922137939193)],
        &[(0b11010, &ENTRY_PACHYHEMIA_8064242457811444804)],
        &[(0b10001, &ENTRY_PACHYHEMIA_8064242457811444804)],
        &[(0b10010, &ENTRY_PACKETIZATION_16208754302696410419)],
        &[(0b10010, &ENTRY_PACKETIZE_5972448088884110761)],
        &[(0b10010, &ENTRY_PACKETIZED_8899832600620412912)],
        &[(0b10010, &ENTRY_PACKETIZER_16605776441937490688)],
        &[(0b10010, &ENTRY_PACKETIZERS_6524285336219061046)],
        &[(0b10010, &ENTRY_PACKETIZES_2813822036312110356)],
        &[(0b10010, &ENTRY_PACKETIZING_11521124697410978844)],
        &[(0b01001, &ENTRY_PACKETIZATION_16208754302696410419)],
        &[(0b01001, &ENTRY_PACKETIZE_5972448088884110761)],
        &[(0b01001, &ENTRY_PACKETIZED_8899832600620412912)],
        &[(0b01001, &ENTRY_PACKETIZER_16605776441937490688)],
        &[(0b01001, &ENTRY_PACKETIZERS_6524285336219061046)],
        &[(0b01001, &ENTRY_PACKETIZES_2813822036312110356)],
        &[(0b01001, &ENTRY_PACKETIZING_11521124697410978844)],
    ],
    range: 6..=10,
};

static VARS_O_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_O_CHILDREN),
    value: None,
};

static VARS_O_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_OB_NODE),
    Some(&VARS_OC_NODE),
    Some(&VARS_OD_NODE),
    Some(&VARS_OE_NODE),
    Some(&VARS_OF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_OL_NODE),
    Some(&VARS_OM_NODE),
    Some(&VARS_ON_NODE),
    Some(&VARS_OO_NODE),
    Some(&VARS_OP_NODE),
    None,
    Some(&VARS_OR_NODE),
    Some(&VARS_OS_NODE),
    Some(&VARS_OT_NODE),
    Some(&VARS_OU_NODE),
    Some(&VARS_OV_NODE),
    Some(&VARS_OW_NODE),
    Some(&VARS_OX_NODE),
    None,
    Some(&VARS_OZ_NODE),
];

static VARS_OZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OZ_CHILDREN),
    value: None,
};

pub static VARS_OZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aena"),
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("oena"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onisers"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizers"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OZENA_4969729645065668012)],
        &[
            (0b00001, &ENTRY_OZENA_12738332874299794404),
            (0b00001, &ENTRY_OZENA_4969729645065668012),
        ],
        &[(0b11010, &ENTRY_OZENA_12738332874299794404)],
        &[(0b10010, &ENTRY_OZONIZATION_3896308943103224579)],
        &[(0b10010, &ENTRY_OZONIZATIONS_502893906779520668)],
        &[(0b10010, &ENTRY_OZONIZE_17942847956579128151)],
        &[(0b10010, &ENTRY_OZONIZED_11239117268275093032)],
        &[(0b10010, &ENTRY_OZONIZER_3300785248284358800)],
        &[(0b10010, &ENTRY_OZONIZERS_3033483267089639714)],
        &[(0b10010, &ENTRY_OZONIZES_6522169179054787769)],
        &[(0b10010, &ENTRY_OZONIZING_4927916636257465073)],
        &[(0b01001, &ENTRY_OZONIZATION_3896308943103224579)],
        &[(0b01001, &ENTRY_OZONIZATIONS_502893906779520668)],
        &[(0b01001, &ENTRY_OZONIZE_17942847956579128151)],
        &[(0b01001, &ENTRY_OZONIZED_11239117268275093032)],
        &[(0b01001, &ENTRY_OZONIZER_3300785248284358800)],
        &[(0b01001, &ENTRY_OZONIZERS_3033483267089639714)],
        &[(0b01001, &ENTRY_OZONIZES_6522169179054787769)],
        &[(0b01001, &ENTRY_OZONIZING_4927916636257465073)],
    ],
    range: 3..=10,
};

static VARS_OX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OX_CHILDREN),
    value: None,
};

pub static VARS_OX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alaemia"),
        dictgen::InsensitiveStr::Ascii("alemia"),
        dictgen::InsensitiveStr::Ascii("idisabilities"),
        dictgen::InsensitiveStr::Ascii("idisability"),
        dictgen::InsensitiveStr::Ascii("idisable"),
        dictgen::InsensitiveStr::Ascii("idisables"),
        dictgen::InsensitiveStr::Ascii("idisation"),
        dictgen::InsensitiveStr::Ascii("idisations"),
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idised"),
        dictgen::InsensitiveStr::Ascii("idisement"),
        dictgen::InsensitiveStr::Ascii("idisements"),
        dictgen::InsensitiveStr::Ascii("idiser"),
        dictgen::InsensitiveStr::Ascii("idisers"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idising"),
        dictgen::InsensitiveStr::Ascii("idisings"),
        dictgen::InsensitiveStr::Ascii("idizabilities"),
        dictgen::InsensitiveStr::Ascii("idizability"),
        dictgen::InsensitiveStr::Ascii("idizable"),
        dictgen::InsensitiveStr::Ascii("idizables"),
        dictgen::InsensitiveStr::Ascii("idization"),
        dictgen::InsensitiveStr::Ascii("idizations"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idized"),
        dictgen::InsensitiveStr::Ascii("idizement"),
        dictgen::InsensitiveStr::Ascii("idizements"),
        dictgen::InsensitiveStr::Ascii("idizer"),
        dictgen::InsensitiveStr::Ascii("idizers"),
        dictgen::InsensitiveStr::Ascii("idizes"),
        dictgen::InsensitiveStr::Ascii("idizing"),
        dictgen::InsensitiveStr::Ascii("idizings"),
        dictgen::InsensitiveStr::Ascii("ygenisable"),
        dictgen::InsensitiveStr::Ascii("ygenisables"),
        dictgen::InsensitiveStr::Ascii("ygenise"),
        dictgen::InsensitiveStr::Ascii("ygenised"),
        dictgen::InsensitiveStr::Ascii("ygenisement"),
        dictgen::InsensitiveStr::Ascii("ygenisements"),
        dictgen::InsensitiveStr::Ascii("ygeniser"),
        dictgen::InsensitiveStr::Ascii("ygenisers"),
        dictgen::InsensitiveStr::Ascii("ygenises"),
        dictgen::InsensitiveStr::Ascii("ygenising"),
        dictgen::InsensitiveStr::Ascii("ygenizable"),
        dictgen::InsensitiveStr::Ascii("ygenizables"),
        dictgen::InsensitiveStr::Ascii("ygenize"),
        dictgen::InsensitiveStr::Ascii("ygenized"),
        dictgen::InsensitiveStr::Ascii("ygenizement"),
        dictgen::InsensitiveStr::Ascii("ygenizements"),
        dictgen::InsensitiveStr::Ascii("ygenizer"),
        dictgen::InsensitiveStr::Ascii("ygenizers"),
        dictgen::InsensitiveStr::Ascii("ygenizes"),
        dictgen::InsensitiveStr::Ascii("ygenizing"),
        dictgen::InsensitiveStr::Ascii("yhaematin"),
        dictgen::InsensitiveStr::Ascii("yhaemoglobin"),
        dictgen::InsensitiveStr::Ascii("yhaemoglobins"),
        dictgen::InsensitiveStr::Ascii("yhematin"),
        dictgen::InsensitiveStr::Ascii("yhemoglobin"),
        dictgen::InsensitiveStr::Ascii("yhemoglobins"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OXALEMIA_8359876312463994118)],
        &[(0b10001, &ENTRY_OXALEMIA_8359876312463994118)],
        &[(0b10010, &ENTRY_OXIDIZABILITIES_14142108330730081987)],
        &[(0b10010, &ENTRY_OXIDIZABILITY_17098615307353278078)],
        &[(0b10010, &ENTRY_OXIDIZABLE_13099591425208273704)],
        &[(0b10010, &ENTRY_OXIDIZABLES_14774967969017909671)],
        &[(0b10010, &ENTRY_OXIDIZATION_8640581345639188227)],
        &[(0b10010, &ENTRY_OXIDIZATIONS_18384605206557692188)],
        &[(0b10010, &ENTRY_OXIDIZE_14098521888186084656)],
        &[(0b10010, &ENTRY_OXIDIZED_863679133104485205)],
        &[(0b10010, &ENTRY_OXIDIZEMENT_3824208269824742167)],
        &[(0b10010, &ENTRY_OXIDIZEMENTS_2713172646044852097)],
        &[(0b10010, &ENTRY_OXIDIZER_8663348272113963982)],
        &[(0b10010, &ENTRY_OXIDIZERS_2504217545277966354)],
        &[(0b10010, &ENTRY_OXIDIZES_12570513258219136803)],
        &[(0b10010, &ENTRY_OXIDIZING_16524857865197942594)],
        &[(0b10010, &ENTRY_OXIDIZINGS_11236022938943463443)],
        &[(0b01001, &ENTRY_OXIDIZABILITIES_14142108330730081987)],
        &[(0b01001, &ENTRY_OXIDIZABILITY_17098615307353278078)],
        &[(0b01001, &ENTRY_OXIDIZABLE_13099591425208273704)],
        &[(0b01001, &ENTRY_OXIDIZABLES_14774967969017909671)],
        &[(0b01001, &ENTRY_OXIDIZATION_8640581345639188227)],
        &[(0b01001, &ENTRY_OXIDIZATIONS_18384605206557692188)],
        &[(0b01001, &ENTRY_OXIDIZE_14098521888186084656)],
        &[(0b01001, &ENTRY_OXIDIZED_863679133104485205)],
        &[(0b01001, &ENTRY_OXIDIZEMENT_3824208269824742167)],
        &[(0b01001, &ENTRY_OXIDIZEMENTS_2713172646044852097)],
        &[(0b01001, &ENTRY_OXIDIZER_8663348272113963982)],
        &[(0b01001, &ENTRY_OXIDIZERS_2504217545277966354)],
        &[(0b01001, &ENTRY_OXIDIZES_12570513258219136803)],
        &[(0b01001, &ENTRY_OXIDIZING_16524857865197942594)],
        &[(0b01001, &ENTRY_OXIDIZINGS_11236022938943463443)],
        &[(0b10010, &ENTRY_OXYGENIZABLE_17479103681379009352)],
        &[(0b10010, &ENTRY_OXYGENIZABLES_4594746039702721234)],
        &[(0b10010, &ENTRY_OXYGENIZE_17957343902815945531)],
        &[(0b10010, &ENTRY_OXYGENIZED_12741796950494986234)],
        &[(0b10010, &ENTRY_OXYGENIZEMENT_15662309540642399495)],
        &[(0b10010, &ENTRY_OXYGENIZEMENTS_6061271087856140584)],
        &[(0b10010, &ENTRY_OXYGENIZER_1558268197723031493)],
        &[(0b10010, &ENTRY_OXYGENIZERS_8437931482323607770)],
        &[(0b10010, &ENTRY_OXYGENIZES_12301201819705648739)],
        &[(0b10010, &ENTRY_OXYGENIZING_14936091316073194120)],
        &[(0b01001, &ENTRY_OXYGENIZABLE_17479103681379009352)],
        &[(0b01001, &ENTRY_OXYGENIZABLES_4594746039702721234)],
        &[(0b01001, &ENTRY_OXYGENIZE_17957343902815945531)],
        &[(0b01001, &ENTRY_OXYGENIZED_12741796950494986234)],
        &[(0b01001, &ENTRY_OXYGENIZEMENT_15662309540642399495)],
        &[(0b01001, &ENTRY_OXYGENIZEMENTS_6061271087856140584)],
        &[(0b01001, &ENTRY_OXYGENIZER_1558268197723031493)],
        &[(0b01001, &ENTRY_OXYGENIZERS_8437931482323607770)],
        &[(0b01001, &ENTRY_OXYGENIZES_12301201819705648739)],
        &[(0b01001, &ENTRY_OXYGENIZING_14936091316073194120)],
        &[(0b11010, &ENTRY_OXYHEMATIN_1679679880778856911)],
        &[(0b11010, &ENTRY_OXYHEMOGLOBIN_9033247027705350750)],
        &[(0b11010, &ENTRY_OXYHEMOGLOBINS_3513395291969542293)],
        &[(0b10001, &ENTRY_OXYHEMATIN_1679679880778856911)],
        &[(0b10001, &ENTRY_OXYHEMOGLOBIN_9033247027705350750)],
        &[(0b10001, &ENTRY_OXYHEMOGLOBINS_3513395291969542293)],
    ],
    range: 5..=13,
};

static VARS_OW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OW_CHILDREN),
    value: None,
};

pub static VARS_OW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ercome"),
        dictgen::InsensitiveStr::Ascii("erword"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("recome"),
        dictgen::InsensitiveStr::Ascii("reword"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OWER_3833680922718495358)],
        &[(0b00001, &ENTRY_OWERCOME_7825693961556665659)],
        &[(0b00001, &ENTRY_OWERWORD_11634074558985348166)],
        &[(0b11010, &ENTRY_OWER_3833680922718495358)],
        &[(0b11010, &ENTRY_OWERCOME_7825693961556665659)],
        &[(0b11010, &ENTRY_OWERWORD_11634074558985348166)],
    ],
    range: 2..=6,
};

static VARS_OV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_OV_CHILDREN),
    value: None,
};

static VARS_OV_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_OVA_NODE),
    None,
    None,
    None,
    Some(&VARS_OVE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_OVE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_OVE_CHILDREN),
    value: None,
};

static VARS_OVE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_OVER_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_OVER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_OVER_CHILDREN),
    value: None,
};

static VARS_OVER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_OVERA_NODE),
    Some(&VARS_OVERB_NODE),
    Some(&VARS_OVERC_NODE),
    Some(&VARS_OVERD_NODE),
    Some(&VARS_OVERE_NODE),
    Some(&VARS_OVERF_NODE),
    Some(&VARS_OVERG_NODE),
    Some(&VARS_OVERH_NODE),
    Some(&VARS_OVERI_NODE),
    Some(&VARS_OVERJ_NODE),
    None,
    Some(&VARS_OVERL_NODE),
    None,
    Some(&VARS_OVERN_NODE),
    None,
    None,
    None,
    Some(&VARS_OVERR_NODE),
    Some(&VARS_OVERS_NODE),
    None,
    Some(&VARS_OVERU_NODE),
    None,
    Some(&VARS_OVERW_NODE),
    None,
    None,
    None,
];

static VARS_OVERW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERW_CHILDREN),
    value: None,
};

pub static VARS_OVERW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("omanise"),
        dictgen::InsensitiveStr::Ascii("omanises"),
        dictgen::InsensitiveStr::Ascii("omanize"),
        dictgen::InsensitiveStr::Ascii("omanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERWOMANIZE_200946611941560951)],
        &[(0b10010, &ENTRY_OVERWOMANIZES_14746928621471259508)],
        &[(0b01001, &ENTRY_OVERWOMANIZE_200946611941560951)],
        &[(0b01001, &ENTRY_OVERWOMANIZES_14746928621471259508)],
    ],
    range: 7..=8,
};

static VARS_OVERU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERU_CHILDREN),
    value: None,
};

pub static VARS_OVERU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nionised"),
        dictgen::InsensitiveStr::Ascii("nioniseds"),
        dictgen::InsensitiveStr::Ascii("nionized"),
        dictgen::InsensitiveStr::Ascii("nionizeds"),
        dictgen::InsensitiveStr::Ascii("rbanisation"),
        dictgen::InsensitiveStr::Ascii("rbanisations"),
        dictgen::InsensitiveStr::Ascii("rbanization"),
        dictgen::InsensitiveStr::Ascii("rbanizations"),
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilization"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERUNIONIZED_4047937475394439730)],
        &[(0b10010, &ENTRY_OVERUNIONIZEDS_12564195815119338339)],
        &[(0b01001, &ENTRY_OVERUNIONIZED_4047937475394439730)],
        &[(0b01001, &ENTRY_OVERUNIONIZEDS_12564195815119338339)],
        &[(0b10010, &ENTRY_OVERURBANIZATION_5193813995283903294)],
        &[(0b10010, &ENTRY_OVERURBANIZATIONS_16844312525315293215)],
        &[(0b01001, &ENTRY_OVERURBANIZATION_5193813995283903294)],
        &[(0b01001, &ENTRY_OVERURBANIZATIONS_16844312525315293215)],
        &[(0b10010, &ENTRY_OVERUTILIZATION_11909002111381917615)],
        &[(0b01001, &ENTRY_OVERUTILIZATION_11909002111381917615)],
    ],
    range: 8..=12,
};

static VARS_OVERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERS_CHILDREN),
    value: None,
};

pub static VARS_OVERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entimentalise"),
        dictgen::InsensitiveStr::Ascii("entimentalises"),
        dictgen::InsensitiveStr::Ascii("entimentalize"),
        dictgen::InsensitiveStr::Ascii("entimentalizes"),
        dictgen::InsensitiveStr::Ascii("pecialisation"),
        dictgen::InsensitiveStr::Ascii("pecialisations"),
        dictgen::InsensitiveStr::Ascii("pecialise"),
        dictgen::InsensitiveStr::Ascii("pecialised"),
        dictgen::InsensitiveStr::Ascii("pecialises"),
        dictgen::InsensitiveStr::Ascii("pecialising"),
        dictgen::InsensitiveStr::Ascii("pecialization"),
        dictgen::InsensitiveStr::Ascii("pecializations"),
        dictgen::InsensitiveStr::Ascii("pecialize"),
        dictgen::InsensitiveStr::Ascii("pecialized"),
        dictgen::InsensitiveStr::Ascii("pecializes"),
        dictgen::InsensitiveStr::Ascii("pecializing"),
        dictgen::InsensitiveStr::Ascii("ystematise"),
        dictgen::InsensitiveStr::Ascii("ystematises"),
        dictgen::InsensitiveStr::Ascii("ystematize"),
        dictgen::InsensitiveStr::Ascii("ystematizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERSENTIMENTALIZE_2920069227773965746)],
        &[(0b10010, &ENTRY_OVERSENTIMENTALIZES_10334951405364037229)],
        &[(0b01001, &ENTRY_OVERSENTIMENTALIZE_2920069227773965746)],
        &[(0b01001, &ENTRY_OVERSENTIMENTALIZES_10334951405364037229)],
        &[(0b10010, &ENTRY_OVERSPECIALIZATION_9400215891169659422)],
        &[(0b10010, &ENTRY_OVERSPECIALIZATIONS_602774670593965924)],
        &[(0b10010, &ENTRY_OVERSPECIALIZE_9155848039135346764)],
        &[(0b10010, &ENTRY_OVERSPECIALIZED_10776456971324744822)],
        &[(0b10010, &ENTRY_OVERSPECIALIZES_5323874136922790809)],
        &[(0b10010, &ENTRY_OVERSPECIALIZING_13810584292392678750)],
        &[(0b01001, &ENTRY_OVERSPECIALIZATION_9400215891169659422)],
        &[(0b01001, &ENTRY_OVERSPECIALIZATIONS_602774670593965924)],
        &[(0b01001, &ENTRY_OVERSPECIALIZE_9155848039135346764)],
        &[(0b01001, &ENTRY_OVERSPECIALIZED_10776456971324744822)],
        &[(0b01001, &ENTRY_OVERSPECIALIZES_5323874136922790809)],
        &[(0b01001, &ENTRY_OVERSPECIALIZING_13810584292392678750)],
        &[(0b10010, &ENTRY_OVERSYSTEMATIZE_15317981286987240656)],
        &[(0b10010, &ENTRY_OVERSYSTEMATIZES_7828674482109481491)],
        &[(0b01001, &ENTRY_OVERSYSTEMATIZE_15317981286987240656)],
        &[(0b01001, &ENTRY_OVERSYSTEMATIZES_7828674482109481491)],
    ],
    range: 9..=14,
};

static VARS_OVERR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERR_CHILDREN),
    value: None,
};

pub static VARS_OVERR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apturise"),
        dictgen::InsensitiveStr::Ascii("apturises"),
        dictgen::InsensitiveStr::Ascii("apturize"),
        dictgen::InsensitiveStr::Ascii("apturizes"),
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERRAPTURIZE_3350211032805151786)],
        &[(0b10010, &ENTRY_OVERRAPTURIZES_4064312914205956145)],
        &[(0b01001, &ENTRY_OVERRAPTURIZE_3350211032805151786)],
        &[(0b01001, &ENTRY_OVERRAPTURIZES_4064312914205956145)],
        &[(0b10010, &ENTRY_OVERRATIONALIZE_14162691183665004674)],
        &[(0b10010, &ENTRY_OVERRATIONALIZES_1263206603271065559)],
        &[(0b01001, &ENTRY_OVERRATIONALIZE_14162691183665004674)],
        &[(0b01001, &ENTRY_OVERRATIONALIZES_1263206603271065559)],
    ],
    range: 8..=11,
};

static VARS_OVERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERN_CHILDREN),
    value: None,
};

pub static VARS_OVERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERNATIONALIZATION_16427980336477721392)],
        &[(0b10010, &ENTRY_OVERNATIONALIZATIONS_16720417975201334473)],
        &[(0b01001, &ENTRY_OVERNATIONALIZATION_16427980336477721392)],
        &[(0b01001, &ENTRY_OVERNATIONALIZATIONS_16720417975201334473)],
    ],
    range: 14..=15,
};

static VARS_OVERL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERL_CHILDREN),
    value: None,
};

pub static VARS_OVERL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abored"),
        dictgen::InsensitiveStr::Ascii("aboring"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("aboured"),
        dictgen::InsensitiveStr::Ascii("abouring"),
        dictgen::InsensitiveStr::Ascii("abours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OVERLABOR_4761949762410556291)],
        &[(0b00001, &ENTRY_OVERLABORED_2757049959631908045)],
        &[(0b00001, &ENTRY_OVERLABORING_15266943753097543372)],
        &[(0b00001, &ENTRY_OVERLABORS_15107230618633371659)],
        &[(0b11010, &ENTRY_OVERLABOR_4761949762410556291)],
        &[(0b11010, &ENTRY_OVERLABORED_2757049959631908045)],
        &[(0b11010, &ENTRY_OVERLABORING_15266943753097543372)],
        &[(0b11010, &ENTRY_OVERLABORS_15107230618633371659)],
    ],
    range: 4..=8,
};

static VARS_OVERJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERJ_CHILDREN),
    value: None,
};

pub static VARS_OVERJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("udgement"),
        dictgen::InsensitiveStr::Ascii("udgements"),
        dictgen::InsensitiveStr::Ascii("udgment"),
        dictgen::InsensitiveStr::Ascii("udgments"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OVERJUDGMENT_12325219415629312934)],
        &[(0b11010, &ENTRY_OVERJUDGMENTS_16817152636455142022)],
        &[(0b00001, &ENTRY_OVERJUDGMENT_12325219415629312934)],
        &[(0b00001, &ENTRY_OVERJUDGMENTS_16817152636455142022)],
    ],
    range: 7..=9,
};

static VARS_OVERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERI_CHILDREN),
    value: None,
};

pub static VARS_OVERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialisations"),
        dictgen::InsensitiveStr::Ascii("ndustrialise"),
        dictgen::InsensitiveStr::Ascii("ndustrialises"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
        dictgen::InsensitiveStr::Ascii("ndustrializations"),
        dictgen::InsensitiveStr::Ascii("ndustrialize"),
        dictgen::InsensitiveStr::Ascii("ndustrializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERINDUSTRIALIZATION_16044744419846949421)],
        &[(0b10010, &ENTRY_OVERINDUSTRIALIZATIONS_2479660567106903260)],
        &[(0b10010, &ENTRY_OVERINDUSTRIALIZE_7348456951187570038)],
        &[(0b10010, &ENTRY_OVERINDUSTRIALIZES_8736294717956607405)],
        &[(0b01001, &ENTRY_OVERINDUSTRIALIZATION_16044744419846949421)],
        &[(0b01001, &ENTRY_OVERINDUSTRIALIZATIONS_2479660567106903260)],
        &[(0b01001, &ENTRY_OVERINDUSTRIALIZE_7348456951187570038)],
        &[(0b01001, &ENTRY_OVERINDUSTRIALIZES_8736294717956607405)],
    ],
    range: 12..=17,
};

static VARS_OVERH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERH_CHILDREN),
    value: None,
};

pub static VARS_OVERH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onor"),
        dictgen::InsensitiveStr::Ascii("onors"),
        dictgen::InsensitiveStr::Ascii("onour"),
        dictgen::InsensitiveStr::Ascii("onours"),
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
    ],
    values: &[
        &[(0b10001, &ENTRY_OVERHONOR_7235171621843361158)],
        &[(0b10001, &ENTRY_OVERHONORS_10103397574554573266)],
        &[(0b11010, &ENTRY_OVERHONOR_7235171621843361158)],
        &[(0b11010, &ENTRY_OVERHONORS_10103397574554573266)],
        &[(0b10010, &ENTRY_OVERHUMANIZE_13455822973320239965)],
        &[(0b10010, &ENTRY_OVERHUMANIZES_14873101185551055589)],
        &[(0b01001, &ENTRY_OVERHUMANIZE_13455822973320239965)],
        &[(0b01001, &ENTRY_OVERHUMANIZES_14873101185551055589)],
    ],
    range: 4..=8,
};

static VARS_OVERG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERG_CHILDREN),
    value: None,
};

pub static VARS_OVERG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eneralise"),
        dictgen::InsensitiveStr::Ascii("eneralised"),
        dictgen::InsensitiveStr::Ascii("eneralises"),
        dictgen::InsensitiveStr::Ascii("eneralising"),
        dictgen::InsensitiveStr::Ascii("eneralize"),
        dictgen::InsensitiveStr::Ascii("eneralized"),
        dictgen::InsensitiveStr::Ascii("eneralizes"),
        dictgen::InsensitiveStr::Ascii("eneralizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERGENERALIZE_12617960222070124101)],
        &[(0b10010, &ENTRY_OVERGENERALIZED_8841918834486724985)],
        &[(0b10010, &ENTRY_OVERGENERALIZES_5216897570369112390)],
        &[(0b10010, &ENTRY_OVERGENERALIZING_10418526262017180256)],
        &[(0b01001, &ENTRY_OVERGENERALIZE_12617960222070124101)],
        &[(0b01001, &ENTRY_OVERGENERALIZED_8841918834486724985)],
        &[(0b01001, &ENTRY_OVERGENERALIZES_5216897570369112390)],
        &[(0b01001, &ENTRY_OVERGENERALIZING_10418526262017180256)],
    ],
    range: 9..=11,
};

static VARS_OVERF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERF_CHILDREN),
    value: None,
};

pub static VARS_OVERF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avorable"),
        dictgen::InsensitiveStr::Ascii("avorables"),
        dictgen::InsensitiveStr::Ascii("avorablies"),
        dictgen::InsensitiveStr::Ascii("avorably"),
        dictgen::InsensitiveStr::Ascii("avors"),
        dictgen::InsensitiveStr::Ascii("avour"),
        dictgen::InsensitiveStr::Ascii("avourable"),
        dictgen::InsensitiveStr::Ascii("avourables"),
        dictgen::InsensitiveStr::Ascii("avourablies"),
        dictgen::InsensitiveStr::Ascii("avourably"),
        dictgen::InsensitiveStr::Ascii("avours"),
        dictgen::InsensitiveStr::Ascii("ertilisation"),
        dictgen::InsensitiveStr::Ascii("ertilization"),
    ],
    values: &[
        &[(0b10001, &ENTRY_OVERFAVOR_2988640921037745317)],
        &[(0b10001, &ENTRY_OVERFAVORABLE_2253479099213937128)],
        &[(0b10001, &ENTRY_OVERFAVORABLES_13349672237716253716)],
        &[(0b10001, &ENTRY_OVERFAVORABLIES_12931915139716470778)],
        &[(0b10001, &ENTRY_OVERFAVORABLY_9201409646497245624)],
        &[(0b10001, &ENTRY_OVERFAVORS_7531387216996007889)],
        &[(0b11010, &ENTRY_OVERFAVOR_2988640921037745317)],
        &[(0b11010, &ENTRY_OVERFAVORABLE_2253479099213937128)],
        &[(0b11010, &ENTRY_OVERFAVORABLES_13349672237716253716)],
        &[(0b11010, &ENTRY_OVERFAVORABLIES_12931915139716470778)],
        &[(0b11010, &ENTRY_OVERFAVORABLY_9201409646497245624)],
        &[(0b11010, &ENTRY_OVERFAVORS_7531387216996007889)],
        &[(0b10010, &ENTRY_OVERFERTILIZATION_15333294448468078644)],
        &[(0b01001, &ENTRY_OVERFERTILIZATION_15333294448468078644)],
    ],
    range: 4..=12,
};

static VARS_OVERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERE_CHILDREN),
    value: None,
};

pub static VARS_OVERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("motionalise"),
        dictgen::InsensitiveStr::Ascii("motionalises"),
        dictgen::InsensitiveStr::Ascii("motionalize"),
        dictgen::InsensitiveStr::Ascii("motionalizes"),
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasised"),
        dictgen::InsensitiveStr::Ascii("mphasiser"),
        dictgen::InsensitiveStr::Ascii("mphasisers"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasising"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasized"),
        dictgen::InsensitiveStr::Ascii("mphasizer"),
        dictgen::InsensitiveStr::Ascii("mphasizers"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("mphasizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVEREMOTIONALIZE_3169525508710692200)],
        &[(0b10010, &ENTRY_OVEREMOTIONALIZES_8370132205966048150)],
        &[(0b01001, &ENTRY_OVEREMOTIONALIZE_3169525508710692200)],
        &[(0b01001, &ENTRY_OVEREMOTIONALIZES_8370132205966048150)],
        &[(0b10010, &ENTRY_OVEREMPHASIZE_9555654201029285273)],
        &[(0b10010, &ENTRY_OVEREMPHASIZED_10786070739152462413)],
        &[(0b10010, &ENTRY_OVEREMPHASIZER_3909831921528574703)],
        &[(0b10010, &ENTRY_OVEREMPHASIZERS_2232850070738046753)],
        &[(0b10010, &ENTRY_OVEREMPHASIZES_3357752816724585460)],
        &[(0b10010, &ENTRY_OVEREMPHASIZING_5600939134455436136)],
        &[(0b01001, &ENTRY_OVEREMPHASIZE_9555654201029285273)],
        &[(0b01001, &ENTRY_OVEREMPHASIZED_10786070739152462413)],
        &[(0b01001, &ENTRY_OVEREMPHASIZER_3909831921528574703)],
        &[(0b01001, &ENTRY_OVEREMPHASIZERS_2232850070738046753)],
        &[(0b01001, &ENTRY_OVEREMPHASIZES_3357752816724585460)],
        &[(0b01001, &ENTRY_OVEREMPHASIZING_5600939134455436136)],
    ],
    range: 8..=12,
};

static VARS_OVERD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERD_CHILDREN),
    value: None,
};

pub static VARS_OVERD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("octrinise"),
        dictgen::InsensitiveStr::Ascii("octrinises"),
        dictgen::InsensitiveStr::Ascii("octrinize"),
        dictgen::InsensitiveStr::Ascii("octrinizes"),
        dictgen::InsensitiveStr::Ascii("ramatise"),
        dictgen::InsensitiveStr::Ascii("ramatised"),
        dictgen::InsensitiveStr::Ascii("ramatises"),
        dictgen::InsensitiveStr::Ascii("ramatising"),
        dictgen::InsensitiveStr::Ascii("ramatize"),
        dictgen::InsensitiveStr::Ascii("ramatized"),
        dictgen::InsensitiveStr::Ascii("ramatizes"),
        dictgen::InsensitiveStr::Ascii("ramatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERDOCTRINIZE_6756558981699337418)],
        &[(0b10010, &ENTRY_OVERDOCTRINIZES_12501026687501771984)],
        &[(0b01001, &ENTRY_OVERDOCTRINIZE_6756558981699337418)],
        &[(0b01001, &ENTRY_OVERDOCTRINIZES_12501026687501771984)],
        &[(0b10010, &ENTRY_OVERDRAMATIZE_3991296625721922524)],
        &[(0b10010, &ENTRY_OVERDRAMATIZED_5081815422525179522)],
        &[(0b10010, &ENTRY_OVERDRAMATIZES_6361099448793870473)],
        &[(0b10010, &ENTRY_OVERDRAMATIZING_14402358516227867882)],
        &[(0b01001, &ENTRY_OVERDRAMATIZE_3991296625721922524)],
        &[(0b01001, &ENTRY_OVERDRAMATIZED_5081815422525179522)],
        &[(0b01001, &ENTRY_OVERDRAMATIZES_6361099448793870473)],
        &[(0b01001, &ENTRY_OVERDRAMATIZING_14402358516227867882)],
    ],
    range: 8..=10,
};

static VARS_OVERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERC_CHILDREN),
    value: None,
};

pub static VARS_OVERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apitalisation"),
        dictgen::InsensitiveStr::Ascii("apitalisations"),
        dictgen::InsensitiveStr::Ascii("apitalise"),
        dictgen::InsensitiveStr::Ascii("apitalised"),
        dictgen::InsensitiveStr::Ascii("apitalises"),
        dictgen::InsensitiveStr::Ascii("apitalising"),
        dictgen::InsensitiveStr::Ascii("apitalization"),
        dictgen::InsensitiveStr::Ascii("apitalizations"),
        dictgen::InsensitiveStr::Ascii("apitalize"),
        dictgen::InsensitiveStr::Ascii("apitalized"),
        dictgen::InsensitiveStr::Ascii("apitalizes"),
        dictgen::InsensitiveStr::Ascii("apitalizing"),
        dictgen::InsensitiveStr::Ascii("entralisation"),
        dictgen::InsensitiveStr::Ascii("entralisations"),
        dictgen::InsensitiveStr::Ascii("entralise"),
        dictgen::InsensitiveStr::Ascii("entralises"),
        dictgen::InsensitiveStr::Ascii("entralization"),
        dictgen::InsensitiveStr::Ascii("entralizations"),
        dictgen::InsensitiveStr::Ascii("entralize"),
        dictgen::InsensitiveStr::Ascii("entralizes"),
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilise"),
        dictgen::InsensitiveStr::Ascii("ivilises"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("ivilize"),
        dictgen::InsensitiveStr::Ascii("ivilizes"),
        dictgen::InsensitiveStr::Ascii("lamor"),
        dictgen::InsensitiveStr::Ascii("lamors"),
        dictgen::InsensitiveStr::Ascii("lamour"),
        dictgen::InsensitiveStr::Ascii("lamours"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("oloration"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olouration"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olours"),
        dictgen::InsensitiveStr::Ascii("riticise"),
        dictgen::InsensitiveStr::Ascii("riticises"),
        dictgen::InsensitiveStr::Ascii("riticize"),
        dictgen::InsensitiveStr::Ascii("riticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERCAPITALIZATION_1715510714642089999)],
        &[(0b10010, &ENTRY_OVERCAPITALIZATIONS_9484255788644671052)],
        &[(0b10010, &ENTRY_OVERCAPITALIZE_2424125715885515013)],
        &[(0b10010, &ENTRY_OVERCAPITALIZED_15472336958201224118)],
        &[(0b10010, &ENTRY_OVERCAPITALIZES_12752896418006053471)],
        &[(0b10010, &ENTRY_OVERCAPITALIZING_3902235346884105289)],
        &[(0b01001, &ENTRY_OVERCAPITALIZATION_1715510714642089999)],
        &[(0b01001, &ENTRY_OVERCAPITALIZATIONS_9484255788644671052)],
        &[(0b01001, &ENTRY_OVERCAPITALIZE_2424125715885515013)],
        &[(0b01001, &ENTRY_OVERCAPITALIZED_15472336958201224118)],
        &[(0b01001, &ENTRY_OVERCAPITALIZES_12752896418006053471)],
        &[(0b01001, &ENTRY_OVERCAPITALIZING_3902235346884105289)],
        &[(0b10010, &ENTRY_OVERCENTRALIZATION_7417308276149240356)],
        &[(0b10010, &ENTRY_OVERCENTRALIZATIONS_13210816604166532536)],
        &[(0b10010, &ENTRY_OVERCENTRALIZE_3364160969428038703)],
        &[(0b10010, &ENTRY_OVERCENTRALIZES_6657866211820141951)],
        &[(0b01001, &ENTRY_OVERCENTRALIZATION_7417308276149240356)],
        &[(0b01001, &ENTRY_OVERCENTRALIZATIONS_13210816604166532536)],
        &[(0b01001, &ENTRY_OVERCENTRALIZE_3364160969428038703)],
        &[(0b01001, &ENTRY_OVERCENTRALIZES_6657866211820141951)],
        &[(0b10010, &ENTRY_OVERCIVILIZATION_1403057627715817017)],
        &[(0b10010, &ENTRY_OVERCIVILIZATIONS_7279117740363755118)],
        &[(0b10010, &ENTRY_OVERCIVILIZE_4956758060913570060)],
        &[(0b10010, &ENTRY_OVERCIVILIZES_6686378897410983044)],
        &[(0b01001, &ENTRY_OVERCIVILIZATION_1403057627715817017)],
        &[(0b01001, &ENTRY_OVERCIVILIZATIONS_7279117740363755118)],
        &[(0b01001, &ENTRY_OVERCIVILIZE_4956758060913570060)],
        &[(0b01001, &ENTRY_OVERCIVILIZES_6686378897410983044)],
        &[(0b10001, &ENTRY_OVERCLAMOR_10459408943570121640)],
        &[(0b10001, &ENTRY_OVERCLAMORS_12504082063740601729)],
        &[(0b11010, &ENTRY_OVERCLAMOR_10459408943570121640)],
        &[(0b11010, &ENTRY_OVERCLAMORS_12504082063740601729)],
        &[(0b10001, &ENTRY_OVERCOLOR_6668121705049321640)],
        &[(0b00001, &ENTRY_OVERCOLORATION_12100936843984700781)],
        &[(0b10001, &ENTRY_OVERCOLORING_1527032230883157274)],
        &[(0b10001, &ENTRY_OVERCOLORS_13972470541416809937)],
        &[(0b11010, &ENTRY_OVERCOLOR_6668121705049321640)],
        &[(0b11010, &ENTRY_OVERCOLORATION_12100936843984700781)],
        &[(0b11010, &ENTRY_OVERCOLORING_1527032230883157274)],
        &[(0b11010, &ENTRY_OVERCOLORS_13972470541416809937)],
        &[(0b10010, &ENTRY_OVERCRITICIZE_11527670059794563047)],
        &[(0b10010, &ENTRY_OVERCRITICIZES_7375544340563907361)],
        &[(0b01001, &ENTRY_OVERCRITICIZE_11527670059794563047)],
        &[(0b01001, &ENTRY_OVERCRITICIZES_7375544340563907361)],
    ],
    range: 4..=14,
};

static VARS_OVERB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERB_CHILDREN),
    value: None,
};

pub static VARS_OVERB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rutalise"),
        dictgen::InsensitiveStr::Ascii("rutalises"),
        dictgen::InsensitiveStr::Ascii("rutalize"),
        dictgen::InsensitiveStr::Ascii("rutalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERBRUTALIZE_4691228052029488558)],
        &[(0b10010, &ENTRY_OVERBRUTALIZES_9064339525061788720)],
        &[(0b01001, &ENTRY_OVERBRUTALIZE_4691228052029488558)],
        &[(0b01001, &ENTRY_OVERBRUTALIZES_9064339525061788720)],
    ],
    range: 8..=9,
};

static VARS_OVERA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVERA_CHILDREN),
    value: None,
};

pub static VARS_OVERA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gonise"),
        dictgen::InsensitiveStr::Ascii("gonises"),
        dictgen::InsensitiveStr::Ascii("gonize"),
        dictgen::InsensitiveStr::Ascii("gonizes"),
        dictgen::InsensitiveStr::Ascii("nalyse"),
        dictgen::InsensitiveStr::Ascii("nalyses"),
        dictgen::InsensitiveStr::Ascii("nalyze"),
        dictgen::InsensitiveStr::Ascii("nalyzes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVERAGONIZE_5802299208135124812)],
        &[(0b10010, &ENTRY_OVERAGONIZES_8549625565440966790)],
        &[(0b01001, &ENTRY_OVERAGONIZE_5802299208135124812)],
        &[(0b01001, &ENTRY_OVERAGONIZES_8549625565440966790)],
        &[(0b10010, &ENTRY_OVERANALYZE_9859872370805897006)],
        &[(0b10010, &ENTRY_OVERANALYZES_8889145236404032723)],
        &[(0b01001, &ENTRY_OVERANALYZE_9859872370805897006)],
        &[(0b01001, &ENTRY_OVERANALYZES_8889145236404032723)],
    ],
    range: 6..=7,
};

static VARS_OVA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OVA_CHILDREN),
    value: None,
};

pub static VARS_OVA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("riectomised"),
        dictgen::InsensitiveStr::Ascii("riectomized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OVALIZATION_9544511535270367142)],
        &[(0b10010, &ENTRY_OVALIZATIONS_18438883105748297633)],
        &[(0b10010, &ENTRY_OVALIZE_5734650805819339558)],
        &[(0b10010, &ENTRY_OVALIZES_17889836495909704940)],
        &[(0b01001, &ENTRY_OVALIZATION_9544511535270367142)],
        &[(0b01001, &ENTRY_OVALIZATIONS_18438883105748297633)],
        &[(0b01001, &ENTRY_OVALIZE_5734650805819339558)],
        &[(0b01001, &ENTRY_OVALIZES_17889836495909704940)],
        &[(0b10010, &ENTRY_OVARIECTOMIZED_11885776630981991118)],
        &[(0b01001, &ENTRY_OVARIECTOMIZED_11885776630981991118)],
    ],
    range: 4..=11,
};

static VARS_OU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OU_CHILDREN),
    value: None,
};

pub static VARS_OU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rang"),
        dictgen::InsensitiveStr::Ascii("rangs"),
        dictgen::InsensitiveStr::Ascii("rologies"),
        dictgen::InsensitiveStr::Ascii("rology"),
        dictgen::InsensitiveStr::Ascii("rsel"),
        dictgen::InsensitiveStr::Ascii("tcaviled"),
        dictgen::InsensitiveStr::Ascii("tcaviling"),
        dictgen::InsensitiveStr::Ascii("tcavilled"),
        dictgen::InsensitiveStr::Ascii("tcavilling"),
        dictgen::InsensitiveStr::Ascii("tclamor"),
        dictgen::InsensitiveStr::Ascii("tclamors"),
        dictgen::InsensitiveStr::Ascii("tclamour"),
        dictgen::InsensitiveStr::Ascii("tclamours"),
        dictgen::InsensitiveStr::Ascii("terness"),
        dictgen::InsensitiveStr::Ascii("thumor"),
        dictgen::InsensitiveStr::Ascii("thumored"),
        dictgen::InsensitiveStr::Ascii("thumoring"),
        dictgen::InsensitiveStr::Ascii("thumors"),
        dictgen::InsensitiveStr::Ascii("thumour"),
        dictgen::InsensitiveStr::Ascii("thumoured"),
        dictgen::InsensitiveStr::Ascii("thumouring"),
        dictgen::InsensitiveStr::Ascii("thumours"),
        dictgen::InsensitiveStr::Ascii("thyperbolise"),
        dictgen::InsensitiveStr::Ascii("thyperbolises"),
        dictgen::InsensitiveStr::Ascii("thyperbolize"),
        dictgen::InsensitiveStr::Ascii("thyperbolizes"),
        dictgen::InsensitiveStr::Ascii("tlabor"),
        dictgen::InsensitiveStr::Ascii("tlabors"),
        dictgen::InsensitiveStr::Ascii("tlabour"),
        dictgen::InsensitiveStr::Ascii("tlabours"),
        dictgen::InsensitiveStr::Ascii("tluster"),
        dictgen::InsensitiveStr::Ascii("tlustre"),
        dictgen::InsensitiveStr::Ascii("tmaneuver"),
        dictgen::InsensitiveStr::Ascii("tmaneuvered"),
        dictgen::InsensitiveStr::Ascii("tmaneuvering"),
        dictgen::InsensitiveStr::Ascii("tmaneuvers"),
        dictgen::InsensitiveStr::Ascii("tmanoeuvre"),
        dictgen::InsensitiveStr::Ascii("tmanoeuvred"),
        dictgen::InsensitiveStr::Ascii("tmanoeuvres"),
        dictgen::InsensitiveStr::Ascii("tmanoeuvring"),
        dictgen::InsensitiveStr::Ascii("treness"),
        dictgen::InsensitiveStr::Ascii("trivaled"),
        dictgen::InsensitiveStr::Ascii("trivaling"),
        dictgen::InsensitiveStr::Ascii("trivalled"),
        dictgen::InsensitiveStr::Ascii("trivalling"),
        dictgen::InsensitiveStr::Ascii("tsavor"),
        dictgen::InsensitiveStr::Ascii("tsavoring"),
        dictgen::InsensitiveStr::Ascii("tsavors"),
        dictgen::InsensitiveStr::Ascii("tsavour"),
        dictgen::InsensitiveStr::Ascii("tsavouring"),
        dictgen::InsensitiveStr::Ascii("tsavours"),
        dictgen::InsensitiveStr::Ascii("tsplendor"),
        dictgen::InsensitiveStr::Ascii("tsplendors"),
        dictgen::InsensitiveStr::Ascii("tsplendour"),
        dictgen::InsensitiveStr::Ascii("tsplendours"),
        dictgen::InsensitiveStr::Ascii("ttyrannise"),
        dictgen::InsensitiveStr::Ascii("ttyrannises"),
        dictgen::InsensitiveStr::Ascii("ttyrannize"),
        dictgen::InsensitiveStr::Ascii("ttyrannizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ORANG_14748066994966584311)],
        &[(0b11010, &ENTRY_ORANGS_6364282221462306169)],
        &[(0b11010, &ENTRY_OROLOGIES_4057377307180654251)],
        &[(0b11010, &ENTRY_OROLOGY_12237949646354810674)],
        &[(0b11010, &ENTRY_ORSEL_8592125767374023328)],
        &[(0b00001, &ENTRY_OUTCAVILED_12328360919318201558)],
        &[(0b00001, &ENTRY_OUTCAVILING_15276360952144069881)],
        &[(0b11010, &ENTRY_OUTCAVILED_12328360919318201558)],
        &[(0b11010, &ENTRY_OUTCAVILING_15276360952144069881)],
        &[(0b10001, &ENTRY_OUTCLAMOR_12156695162252037981)],
        &[(0b10001, &ENTRY_OUTCLAMORS_11021687703035987388)],
        &[(0b11010, &ENTRY_OUTCLAMOR_12156695162252037981)],
        &[(0b11010, &ENTRY_OUTCLAMORS_11021687703035987388)],
        &[(0b00001, &ENTRY_OUTERNESS_5998443012461676237)],
        &[(0b10001, &ENTRY_OUTHUMOR_5098392887011091131)],
        &[(0b10001, &ENTRY_OUTHUMORED_5540858708658054473)],
        &[(0b10001, &ENTRY_OUTHUMORING_1785217446120505648)],
        &[(0b10001, &ENTRY_OUTHUMORS_12478246544150481705)],
        &[(0b11010, &ENTRY_OUTHUMOR_5098392887011091131)],
        &[(0b11010, &ENTRY_OUTHUMORED_5540858708658054473)],
        &[(0b11010, &ENTRY_OUTHUMORING_1785217446120505648)],
        &[(0b11010, &ENTRY_OUTHUMORS_12478246544150481705)],
        &[(0b10010, &ENTRY_OUTHYPERBOLIZE_3971022545298044678)],
        &[(0b10010, &ENTRY_OUTHYPERBOLIZES_10913122944201521464)],
        &[(0b01001, &ENTRY_OUTHYPERBOLIZE_3971022545298044678)],
        &[(0b01001, &ENTRY_OUTHYPERBOLIZES_10913122944201521464)],
        &[(0b10001, &ENTRY_OUTLABOR_550919659652857953)],
        &[(0b10001, &ENTRY_OUTLABORS_12800850946437857772)],
        &[(0b11010, &ENTRY_OUTLABOR_550919659652857953)],
        &[(0b11010, &ENTRY_OUTLABORS_12800850946437857772)],
        &[(0b00001, &ENTRY_OUTLUSTER_2880546633398900610)],
        &[(0b11010, &ENTRY_OUTLUSTER_2880546633398900610)],
        &[(0b01001, &ENTRY_OUTMANEUVER_7848671220965370292)],
        &[(0b01001, &ENTRY_OUTMANEUVERED_13287238199156602214)],
        &[(0b01001, &ENTRY_OUTMANEUVERING_13195408381106573303)],
        &[(0b01001, &ENTRY_OUTMANEUVERS_5720663247945549588)],
        &[(0b11010, &ENTRY_OUTMANEUVER_7848671220965370292)],
        &[(0b11010, &ENTRY_OUTMANEUVERED_13287238199156602214)],
        &[(0b11010, &ENTRY_OUTMANEUVERS_5720663247945549588)],
        &[(0b11010, &ENTRY_OUTMANEUVERING_13195408381106573303)],
        &[(0b11010, &ENTRY_OUTERNESS_5998443012461676237)],
        &[(0b00001, &ENTRY_OUTRIVALED_6741916464318823957)],
        &[(0b00001, &ENTRY_OUTRIVALING_1537376247789926348)],
        &[(0b11010, &ENTRY_OUTRIVALED_6741916464318823957)],
        &[(0b11010, &ENTRY_OUTRIVALING_1537376247789926348)],
        &[(0b10001, &ENTRY_OUTSAVOR_6310574424152508054)],
        &[(0b10001, &ENTRY_OUTSAVORING_18392288826685392376)],
        &[(0b10001, &ENTRY_OUTSAVORS_2256724312665537907)],
        &[(0b11010, &ENTRY_OUTSAVOR_6310574424152508054)],
        &[(0b11010, &ENTRY_OUTSAVORING_18392288826685392376)],
        &[(0b11010, &ENTRY_OUTSAVORS_2256724312665537907)],
        &[(0b10001, &ENTRY_OUTSPLENDOR_16970752322673709554)],
        &[(0b10001, &ENTRY_OUTSPLENDORS_8648344191546891056)],
        &[(0b11010, &ENTRY_OUTSPLENDOR_16970752322673709554)],
        &[(0b11010, &ENTRY_OUTSPLENDORS_8648344191546891056)],
        &[(0b10010, &ENTRY_OUTTYRANNIZE_4884886326342063919)],
        &[(0b10010, &ENTRY_OUTTYRANNIZES_2960809863014622911)],
        &[(0b01001, &ENTRY_OUTTYRANNIZE_4884886326342063919)],
        &[(0b01001, &ENTRY_OUTTYRANNIZES_2960809863014622911)],
    ],
    range: 4..=13,
};

static VARS_OT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OT_CHILDREN),
    value: None,
};

pub static VARS_OT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("haematoma"),
        dictgen::InsensitiveStr::Ascii("hematoma"),
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("tomanisation"),
        dictgen::InsensitiveStr::Ascii("tomanisations"),
        dictgen::InsensitiveStr::Ascii("tomanise"),
        dictgen::InsensitiveStr::Ascii("tomanises"),
        dictgen::InsensitiveStr::Ascii("tomanization"),
        dictgen::InsensitiveStr::Ascii("tomanizations"),
        dictgen::InsensitiveStr::Ascii("tomanize"),
        dictgen::InsensitiveStr::Ascii("tomanizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OTHEMATOMA_4021430710484496451)],
        &[(0b10001, &ENTRY_OTHEMATOMA_4021430710484496451)],
        &[(0b10001, &ENTRY_OTORRHEA_2158661830949996618)],
        &[(0b11010, &ENTRY_OTORRHEA_2158661830949996618)],
        &[(0b10010, &ENTRY_OTTOMANIZATION_17741266954268865266)],
        &[(0b10010, &ENTRY_OTTOMANIZATIONS_3775785848664183204)],
        &[(0b10010, &ENTRY_OTTOMANIZE_159832188922701678)],
        &[(0b10010, &ENTRY_OTTOMANIZES_15974697179327608437)],
        &[(0b01001, &ENTRY_OTTOMANIZATION_17741266954268865266)],
        &[(0b01001, &ENTRY_OTTOMANIZATIONS_3775785848664183204)],
        &[(0b01001, &ENTRY_OTTOMANIZE_159832188922701678)],
        &[(0b01001, &ENTRY_OTTOMANIZES_15974697179327608437)],
    ],
    range: 6..=13,
};

static VARS_OS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OS_CHILDREN),
    value: None,
};

pub static VARS_OS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("teopaedion"),
        dictgen::InsensitiveStr::Ascii("teopedion"),
        dictgen::InsensitiveStr::Ascii("tracisable"),
        dictgen::InsensitiveStr::Ascii("tracisables"),
        dictgen::InsensitiveStr::Ascii("tracisation"),
        dictgen::InsensitiveStr::Ascii("tracisations"),
        dictgen::InsensitiveStr::Ascii("tracise"),
        dictgen::InsensitiveStr::Ascii("tracised"),
        dictgen::InsensitiveStr::Ascii("traciser"),
        dictgen::InsensitiveStr::Ascii("tracisers"),
        dictgen::InsensitiveStr::Ascii("tracises"),
        dictgen::InsensitiveStr::Ascii("tracising"),
        dictgen::InsensitiveStr::Ascii("tracizable"),
        dictgen::InsensitiveStr::Ascii("tracizables"),
        dictgen::InsensitiveStr::Ascii("tracization"),
        dictgen::InsensitiveStr::Ascii("tracizations"),
        dictgen::InsensitiveStr::Ascii("tracize"),
        dictgen::InsensitiveStr::Ascii("tracized"),
        dictgen::InsensitiveStr::Ascii("tracizer"),
        dictgen::InsensitiveStr::Ascii("tracizers"),
        dictgen::InsensitiveStr::Ascii("tracizes"),
        dictgen::InsensitiveStr::Ascii("tracizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OSTEOPEDION_12694520751355978541)],
        &[(0b00001, &ENTRY_OSTEOPEDION_12694520751355978541)],
        &[(0b10010, &ENTRY_OSTRACIZABLE_14526333713080172694)],
        &[(0b10010, &ENTRY_OSTRACIZABLES_8680285522090921467)],
        &[(0b10010, &ENTRY_OSTRACIZATION_10262904227601137622)],
        &[(0b10010, &ENTRY_OSTRACIZATIONS_16496082549877562752)],
        &[(0b10010, &ENTRY_OSTRACIZE_17085330350778372244)],
        &[(0b10010, &ENTRY_OSTRACIZED_7612075679406147400)],
        &[(0b10010, &ENTRY_OSTRACIZER_17846167188643762430)],
        &[(0b10010, &ENTRY_OSTRACIZERS_6019099123580735229)],
        &[(0b10010, &ENTRY_OSTRACIZES_8432128811814349904)],
        &[(0b10010, &ENTRY_OSTRACIZING_15420091366101928007)],
        &[(0b01001, &ENTRY_OSTRACIZABLE_14526333713080172694)],
        &[(0b01001, &ENTRY_OSTRACIZABLES_8680285522090921467)],
        &[(0b01001, &ENTRY_OSTRACIZATION_10262904227601137622)],
        &[(0b01001, &ENTRY_OSTRACIZATIONS_16496082549877562752)],
        &[(0b01001, &ENTRY_OSTRACIZE_17085330350778372244)],
        &[(0b01001, &ENTRY_OSTRACIZED_7612075679406147400)],
        &[(0b01001, &ENTRY_OSTRACIZER_17846167188643762430)],
        &[(0b01001, &ENTRY_OSTRACIZERS_6019099123580735229)],
        &[(0b01001, &ENTRY_OSTRACIZES_8432128811814349904)],
        &[(0b01001, &ENTRY_OSTRACIZING_15420091366101928007)],
    ],
    range: 7..=12,
};

static VARS_OR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_OR_CHILDREN),
    value: None,
};

static VARS_OR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ORA_NODE),
    None,
    Some(&VARS_ORC_NODE),
    None,
    None,
    None,
    Some(&VARS_ORG_NODE),
    None,
    Some(&VARS_ORI_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ORN_NODE),
    Some(&VARS_ORO_NODE),
    Some(&VARS_ORP_NODE),
    None,
    None,
    Some(&VARS_ORS_NODE),
    Some(&VARS_ORT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ORT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORT_CHILDREN),
    value: None,
};

pub static VARS_ORT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hocenter"),
        dictgen::InsensitiveStr::Ascii("hocenters"),
        dictgen::InsensitiveStr::Ascii("hocentre"),
        dictgen::InsensitiveStr::Ascii("hocentres"),
        dictgen::InsensitiveStr::Ascii("hogonalisation"),
        dictgen::InsensitiveStr::Ascii("hogonalise"),
        dictgen::InsensitiveStr::Ascii("hogonalised"),
        dictgen::InsensitiveStr::Ascii("hogonalises"),
        dictgen::InsensitiveStr::Ascii("hogonalising"),
        dictgen::InsensitiveStr::Ascii("hogonalization"),
        dictgen::InsensitiveStr::Ascii("hogonalize"),
        dictgen::InsensitiveStr::Ascii("hogonalized"),
        dictgen::InsensitiveStr::Ascii("hogonalizes"),
        dictgen::InsensitiveStr::Ascii("hogonalizing"),
        dictgen::InsensitiveStr::Ascii("hographise"),
        dictgen::InsensitiveStr::Ascii("hographised"),
        dictgen::InsensitiveStr::Ascii("hographising"),
        dictgen::InsensitiveStr::Ascii("hographize"),
        dictgen::InsensitiveStr::Ascii("hographized"),
        dictgen::InsensitiveStr::Ascii("hographizing"),
        dictgen::InsensitiveStr::Ascii("hopaedia"),
        dictgen::InsensitiveStr::Ascii("hopaedic"),
        dictgen::InsensitiveStr::Ascii("hopaedical"),
        dictgen::InsensitiveStr::Ascii("hopaedicallier"),
        dictgen::InsensitiveStr::Ascii("hopaedicalliest"),
        dictgen::InsensitiveStr::Ascii("hopaedically"),
        dictgen::InsensitiveStr::Ascii("hopaedicer"),
        dictgen::InsensitiveStr::Ascii("hopaedicest"),
        dictgen::InsensitiveStr::Ascii("hopaedics"),
        dictgen::InsensitiveStr::Ascii("hopaedies"),
        dictgen::InsensitiveStr::Ascii("hopaedist"),
        dictgen::InsensitiveStr::Ascii("hopaedists"),
        dictgen::InsensitiveStr::Ascii("hopaedy"),
        dictgen::InsensitiveStr::Ascii("hopedia"),
        dictgen::InsensitiveStr::Ascii("hopedic"),
        dictgen::InsensitiveStr::Ascii("hopedical"),
        dictgen::InsensitiveStr::Ascii("hopedicallier"),
        dictgen::InsensitiveStr::Ascii("hopedicalliest"),
        dictgen::InsensitiveStr::Ascii("hopedically"),
        dictgen::InsensitiveStr::Ascii("hopedicer"),
        dictgen::InsensitiveStr::Ascii("hopedicest"),
        dictgen::InsensitiveStr::Ascii("hopedics"),
        dictgen::InsensitiveStr::Ascii("hopedies"),
        dictgen::InsensitiveStr::Ascii("hopedist"),
        dictgen::InsensitiveStr::Ascii("hopedists"),
        dictgen::InsensitiveStr::Ascii("hopedy"),
        dictgen::InsensitiveStr::Ascii("hopnea"),
        dictgen::InsensitiveStr::Ascii("hopneic"),
        dictgen::InsensitiveStr::Ascii("hopnoea"),
        dictgen::InsensitiveStr::Ascii("hopnoeic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ORTHOCENTER_9905926170374681677)],
        &[(0b00001, &ENTRY_ORTHOCENTERS_3251720815245763229)],
        &[(0b11010, &ENTRY_ORTHOCENTER_9905926170374681677)],
        &[(0b11010, &ENTRY_ORTHOCENTERS_3251720815245763229)],
        &[(0b10010, &ENTRY_ORTHOGONALIZATION_4179399411066144174)],
        &[(0b10010, &ENTRY_ORTHOGONALIZE_14210745318503216217)],
        &[(0b10010, &ENTRY_ORTHOGONALIZED_11695907609311865979)],
        &[(0b10010, &ENTRY_ORTHOGONALIZES_15773663260089545240)],
        &[(0b10010, &ENTRY_ORTHOGONALIZING_5565358582316743636)],
        &[(0b01001, &ENTRY_ORTHOGONALIZATION_4179399411066144174)],
        &[(0b01001, &ENTRY_ORTHOGONALIZE_14210745318503216217)],
        &[(0b01001, &ENTRY_ORTHOGONALIZED_11695907609311865979)],
        &[(0b01001, &ENTRY_ORTHOGONALIZES_15773663260089545240)],
        &[(0b01001, &ENTRY_ORTHOGONALIZING_5565358582316743636)],
        &[(0b10010, &ENTRY_ORTHOGRAPHIZE_8119365633244588200)],
        &[(0b10010, &ENTRY_ORTHOGRAPHIZED_15841004195944273148)],
        &[(0b10010, &ENTRY_ORTHOGRAPHIZING_12654761895220839085)],
        &[(0b01001, &ENTRY_ORTHOGRAPHIZE_8119365633244588200)],
        &[(0b01001, &ENTRY_ORTHOGRAPHIZED_15841004195944273148)],
        &[(0b01001, &ENTRY_ORTHOGRAPHIZING_12654761895220839085)],
        &[(0b11010, &ENTRY_ORTHOPEDIA_18262137889307359495)],
        &[(0b11010, &ENTRY_ORTHOPEDIC_9135417791155998491)],
        &[(0b11010, &ENTRY_ORTHOPEDICAL_14906990439117593315)],
        &[(0b11010, &ENTRY_ORTHOPEDICALLIER_14511187540003790188)],
        &[(0b11010, &ENTRY_ORTHOPEDICALLIEST_17074628747614047566)],
        &[(0b11010, &ENTRY_ORTHOPEDICALLY_2903115659825739595)],
        &[(0b11010, &ENTRY_ORTHOPEDICER_8700148210587724397)],
        &[(0b11010, &ENTRY_ORTHOPEDICEST_17143688116649480026)],
        &[(0b11010, &ENTRY_ORTHOPEDICS_5644296881757016383)],
        &[(0b11010, &ENTRY_ORTHOPEDIES_7682512558854583643)],
        &[(0b11010, &ENTRY_ORTHOPEDIST_5359875151039183204)],
        &[(0b11010, &ENTRY_ORTHOPEDISTS_10438971882131588623)],
        &[(0b11010, &ENTRY_ORTHOPEDY_3242137379321021471)],
        &[(0b10001, &ENTRY_ORTHOPEDIA_18262137889307359495)],
        &[(0b11001, &ENTRY_ORTHOPEDIC_9135417791155998491)],
        &[(0b10001, &ENTRY_ORTHOPEDICAL_14906990439117593315)],
        &[(0b10001, &ENTRY_ORTHOPEDICALLIER_14511187540003790188)],
        &[(0b10001, &ENTRY_ORTHOPEDICALLIEST_17074628747614047566)],
        &[(0b10001, &ENTRY_ORTHOPEDICALLY_2903115659825739595)],
        &[(0b11001, &ENTRY_ORTHOPEDICER_8700148210587724397)],
        &[(0b11001, &ENTRY_ORTHOPEDICEST_17143688116649480026)],
        &[(0b11001, &ENTRY_ORTHOPEDICS_5644296881757016383)],
        &[(0b10001, &ENTRY_ORTHOPEDIES_7682512558854583643)],
        &[(0b10001, &ENTRY_ORTHOPEDIST_5359875151039183204)],
        &[(0b10001, &ENTRY_ORTHOPEDISTS_10438971882131588623)],
        &[(0b10001, &ENTRY_ORTHOPEDY_3242137379321021471)],
        &[(0b00001, &ENTRY_ORTHOPNEA_11714074503904128615)],
        &[(0b00001, &ENTRY_ORTHOPNEIC_8403241060873536790)],
        &[(0b11010, &ENTRY_ORTHOPNEA_11714074503904128615)],
        &[(0b11010, &ENTRY_ORTHOPNEIC_8403241060873536790)],
    ],
    range: 6..=15,
};

static VARS_ORS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORS_CHILDREN),
    value: None,
};

pub static VARS_ORS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("el")],
    values: &[&[(0b00001, &ENTRY_ORSEL_8592125767374023328)]],
    range: 2..=2,
};

static VARS_ORP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORP_CHILDREN),
    value: None,
};

pub static VARS_ORP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hanise"),
        dictgen::InsensitiveStr::Ascii("hanises"),
        dictgen::InsensitiveStr::Ascii("hanize"),
        dictgen::InsensitiveStr::Ascii("hanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ORPHANIZE_11588568553833781059)],
        &[(0b10010, &ENTRY_ORPHANIZES_9097669333806624580)],
        &[(0b01001, &ENTRY_ORPHANIZE_11588568553833781059)],
        &[(0b01001, &ENTRY_ORPHANIZES_9097669333806624580)],
    ],
    range: 6..=7,
};

static VARS_ORO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORO_CHILDREN),
    value: None,
};

pub static VARS_ORO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("logies"),
        dictgen::InsensitiveStr::Ascii("logy"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OROLOGIES_4057377307180654251)],
        &[(0b00001, &ENTRY_OROLOGY_12237949646354810674)],
    ],
    range: 4..=6,
};

static VARS_ORN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORN_CHILDREN),
    value: None,
};

pub static VARS_ORN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amentalise"),
        dictgen::InsensitiveStr::Ascii("amentalises"),
        dictgen::InsensitiveStr::Ascii("amentalize"),
        dictgen::InsensitiveStr::Ascii("amentalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ORNAMENTALIZE_11798404068766485269)],
        &[(0b10010, &ENTRY_ORNAMENTALIZES_17286281591371268395)],
        &[(0b01001, &ENTRY_ORNAMENTALIZE_11798404068766485269)],
        &[(0b01001, &ENTRY_ORNAMENTALIZES_17286281591371268395)],
    ],
    range: 10..=11,
};

static VARS_ORI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORI_CHILDREN),
    value: None,
};

pub static VARS_ORI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entalisation"),
        dictgen::InsensitiveStr::Ascii("entalisations"),
        dictgen::InsensitiveStr::Ascii("entalise"),
        dictgen::InsensitiveStr::Ascii("entalised"),
        dictgen::InsensitiveStr::Ascii("entalises"),
        dictgen::InsensitiveStr::Ascii("entalising"),
        dictgen::InsensitiveStr::Ascii("entalization"),
        dictgen::InsensitiveStr::Ascii("entalizations"),
        dictgen::InsensitiveStr::Ascii("entalize"),
        dictgen::InsensitiveStr::Ascii("entalized"),
        dictgen::InsensitiveStr::Ascii("entalizes"),
        dictgen::InsensitiveStr::Ascii("entalizing"),
        dictgen::InsensitiveStr::Ascii("entisation"),
        dictgen::InsensitiveStr::Ascii("entisations"),
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entization"),
        dictgen::InsensitiveStr::Ascii("entizations"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ORIENTALIZATION_16408076822380414996)],
        &[(0b10010, &ENTRY_ORIENTALIZATIONS_11663753413845884425)],
        &[(0b10010, &ENTRY_ORIENTALIZE_15033142611450893882)],
        &[(0b10010, &ENTRY_ORIENTALIZED_12632548807615689147)],
        &[(0b10010, &ENTRY_ORIENTALIZES_16600052414672173758)],
        &[(0b10010, &ENTRY_ORIENTALIZING_13577294125296985019)],
        &[(0b01001, &ENTRY_ORIENTALIZATION_16408076822380414996)],
        &[(0b01001, &ENTRY_ORIENTALIZATIONS_11663753413845884425)],
        &[(0b01001, &ENTRY_ORIENTALIZE_15033142611450893882)],
        &[(0b01001, &ENTRY_ORIENTALIZED_12632548807615689147)],
        &[(0b01001, &ENTRY_ORIENTALIZES_16600052414672173758)],
        &[(0b01001, &ENTRY_ORIENTALIZING_13577294125296985019)],
        &[(0b10010, &ENTRY_ORIENTIZATION_15927365675673893265)],
        &[(0b10010, &ENTRY_ORIENTIZATIONS_10754218882392069685)],
        &[(0b10010, &ENTRY_ORIENTIZE_6500583041683891917)],
        &[(0b10010, &ENTRY_ORIENTIZES_11330269575495931584)],
        &[(0b01001, &ENTRY_ORIENTIZATION_15927365675673893265)],
        &[(0b01001, &ENTRY_ORIENTIZATIONS_10754218882392069685)],
        &[(0b01001, &ENTRY_ORIENTIZE_6500583041683891917)],
        &[(0b01001, &ENTRY_ORIENTIZES_11330269575495931584)],
    ],
    range: 6..=13,
};

static VARS_ORG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORG_CHILDREN),
    value: None,
};

pub static VARS_ORG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andie"),
        dictgen::InsensitiveStr::Ascii("andy"),
        dictgen::InsensitiveStr::Ascii("anisabilities"),
        dictgen::InsensitiveStr::Ascii("anisability"),
        dictgen::InsensitiveStr::Ascii("anisable"),
        dictgen::InsensitiveStr::Ascii("anisabler"),
        dictgen::InsensitiveStr::Ascii("anisables"),
        dictgen::InsensitiveStr::Ascii("anisablest"),
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisational"),
        dictgen::InsensitiveStr::Ascii("anisationaler"),
        dictgen::InsensitiveStr::Ascii("anisationalest"),
        dictgen::InsensitiveStr::Ascii("anisationallier"),
        dictgen::InsensitiveStr::Ascii("anisationalliest"),
        dictgen::InsensitiveStr::Ascii("anisationally"),
        dictgen::InsensitiveStr::Ascii("anisationals"),
        dictgen::InsensitiveStr::Ascii("anisationist"),
        dictgen::InsensitiveStr::Ascii("anisationists"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anisers"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anizabilities"),
        dictgen::InsensitiveStr::Ascii("anizability"),
        dictgen::InsensitiveStr::Ascii("anizable"),
        dictgen::InsensitiveStr::Ascii("anizabler"),
        dictgen::InsensitiveStr::Ascii("anizables"),
        dictgen::InsensitiveStr::Ascii("anizablest"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizational"),
        dictgen::InsensitiveStr::Ascii("anizationaler"),
        dictgen::InsensitiveStr::Ascii("anizationalest"),
        dictgen::InsensitiveStr::Ascii("anizationallier"),
        dictgen::InsensitiveStr::Ascii("anizationalliest"),
        dictgen::InsensitiveStr::Ascii("anizationally"),
        dictgen::InsensitiveStr::Ascii("anizationals"),
        dictgen::InsensitiveStr::Ascii("anizationist"),
        dictgen::InsensitiveStr::Ascii("anizationists"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizers"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
    ],
    values: &[
        &[(0b10011, &ENTRY_ORGANDY_17377013850024153081)],
        &[(0b01001, &ENTRY_ORGANDY_17377013850024153081)],
        &[(0b10010, &ENTRY_ORGANIZABILITIES_17928216122597123749)],
        &[(0b10010, &ENTRY_ORGANIZABILITY_11606263519927125050)],
        &[(0b10010, &ENTRY_ORGANIZABLE_8071054869331386545)],
        &[(0b10010, &ENTRY_ORGANIZABLER_16730726147732418422)],
        &[(0b10010, &ENTRY_ORGANIZABLES_3895944364193703180)],
        &[(0b10010, &ENTRY_ORGANIZABLEST_95216295824098143)],
        &[(0b10010, &ENTRY_ORGANIZATION_1183056542960920892)],
        &[(0b10010, &ENTRY_ORGANIZATIONAL_11623270165270540295)],
        &[(0b10010, &ENTRY_ORGANIZATIONALER_6873530680939021849)],
        &[(0b10010, &ENTRY_ORGANIZATIONALEST_13609364841796570141)],
        &[(0b10010, &ENTRY_ORGANIZATIONALLIER_5244336690983254999)],
        &[(0b10010, &ENTRY_ORGANIZATIONALLIEST_5857114456710165646)],
        &[(0b10010, &ENTRY_ORGANIZATIONALLY_3853665432127949386)],
        &[(0b10010, &ENTRY_ORGANIZATIONALS_10559236366326509118)],
        &[(0b10010, &ENTRY_ORGANIZATIONIST_7224361965665550626)],
        &[(0b10010, &ENTRY_ORGANIZATIONISTS_17058096744384947274)],
        &[(0b10010, &ENTRY_ORGANIZATIONS_18209440244615759048)],
        &[(0b10010, &ENTRY_ORGANIZE_12183139167602281526)],
        &[(0b10010, &ENTRY_ORGANIZED_12748056748294699226)],
        &[(0b10010, &ENTRY_ORGANIZER_15132700960835020128)],
        &[(0b10010, &ENTRY_ORGANIZERS_3523554258367195869)],
        &[(0b10010, &ENTRY_ORGANIZES_5740513370384106221)],
        &[(0b10010, &ENTRY_ORGANIZING_15958036800031360134)],
        &[(0b01001, &ENTRY_ORGANIZABILITIES_17928216122597123749)],
        &[(0b01001, &ENTRY_ORGANIZABILITY_11606263519927125050)],
        &[(0b01001, &ENTRY_ORGANIZABLE_8071054869331386545)],
        &[(0b01001, &ENTRY_ORGANIZABLER_16730726147732418422)],
        &[(0b01001, &ENTRY_ORGANIZABLES_3895944364193703180)],
        &[(0b01001, &ENTRY_ORGANIZABLEST_95216295824098143)],
        &[(0b01001, &ENTRY_ORGANIZATION_1183056542960920892)],
        &[(0b01001, &ENTRY_ORGANIZATIONAL_11623270165270540295)],
        &[(0b01001, &ENTRY_ORGANIZATIONALER_6873530680939021849)],
        &[(0b01001, &ENTRY_ORGANIZATIONALEST_13609364841796570141)],
        &[(0b01001, &ENTRY_ORGANIZATIONALLIER_5244336690983254999)],
        &[(0b01001, &ENTRY_ORGANIZATIONALLIEST_5857114456710165646)],
        &[(0b01001, &ENTRY_ORGANIZATIONALLY_3853665432127949386)],
        &[(0b01001, &ENTRY_ORGANIZATIONALS_10559236366326509118)],
        &[(0b01001, &ENTRY_ORGANIZATIONIST_7224361965665550626)],
        &[(0b01001, &ENTRY_ORGANIZATIONISTS_17058096744384947274)],
        &[(0b01001, &ENTRY_ORGANIZATIONS_18209440244615759048)],
        &[(0b01001, &ENTRY_ORGANIZE_12183139167602281526)],
        &[(0b01001, &ENTRY_ORGANIZED_12748056748294699226)],
        &[(0b01001, &ENTRY_ORGANIZER_15132700960835020128)],
        &[(0b01001, &ENTRY_ORGANIZERS_3523554258367195869)],
        &[(0b01001, &ENTRY_ORGANIZES_5740513370384106221)],
        &[(0b01001, &ENTRY_ORGANIZING_15958036800031360134)],
    ],
    range: 4..=16,
};

static VARS_ORC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORC_CHILDREN),
    value: None,
};

pub static VARS_ORC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hester"),
        dictgen::InsensitiveStr::Ascii("hestre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ORCHESTER_3438543331406974215)],
        &[(0b11010, &ENTRY_ORCHESTER_3438543331406974215)],
    ],
    range: 6..=6,
};

static VARS_ORA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ORA_CHILDREN),
    value: None,
};

pub static VARS_ORA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("ngise"),
        dictgen::InsensitiveStr::Ascii("ngises"),
        dictgen::InsensitiveStr::Ascii("ngize"),
        dictgen::InsensitiveStr::Ascii("ngizes"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ORALIZATION_14381971273730025874)],
        &[(0b10010, &ENTRY_ORALIZATIONS_8167551586215783500)],
        &[(0b10010, &ENTRY_ORALIZE_323213378900609037)],
        &[(0b10010, &ENTRY_ORALIZES_13092540530518911479)],
        &[(0b01001, &ENTRY_ORALIZATION_14381971273730025874)],
        &[(0b01001, &ENTRY_ORALIZATIONS_8167551586215783500)],
        &[(0b01001, &ENTRY_ORALIZE_323213378900609037)],
        &[(0b01001, &ENTRY_ORALIZES_13092540530518911479)],
        &[(0b10010, &ENTRY_ORANGIZE_8695259728466009401)],
        &[(0b10010, &ENTRY_ORANGIZES_6766010016440987313)],
        &[(0b01001, &ENTRY_ORANGIZE_8695259728466009401)],
        &[(0b01001, &ENTRY_ORANGIZES_6766010016440987313)],
        &[(0b10010, &ENTRY_ORATORIZE_10763244403747894729)],
        &[(0b10010, &ENTRY_ORATORIZES_7819252335974566625)],
        &[(0b01001, &ENTRY_ORATORIZE_10763244403747894729)],
        &[(0b01001, &ENTRY_ORATORIZES_7819252335974566625)],
    ],
    range: 4..=9,
};

static VARS_OP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OP_CHILDREN),
    value: None,
};

pub static VARS_OP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("erationalisation"),
        dictgen::InsensitiveStr::Ascii("erationalisations"),
        dictgen::InsensitiveStr::Ascii("erationalise"),
        dictgen::InsensitiveStr::Ascii("erationalised"),
        dictgen::InsensitiveStr::Ascii("erationalization"),
        dictgen::InsensitiveStr::Ascii("erationalizations"),
        dictgen::InsensitiveStr::Ascii("erationalize"),
        dictgen::InsensitiveStr::Ascii("erationalized"),
        dictgen::InsensitiveStr::Ascii("eratise"),
        dictgen::InsensitiveStr::Ascii("eratised"),
        dictgen::InsensitiveStr::Ascii("eratises"),
        dictgen::InsensitiveStr::Ascii("eratising"),
        dictgen::InsensitiveStr::Ascii("eratize"),
        dictgen::InsensitiveStr::Ascii("eratized"),
        dictgen::InsensitiveStr::Ascii("eratizes"),
        dictgen::InsensitiveStr::Ascii("eratizing"),
        dictgen::InsensitiveStr::Ascii("iniaster"),
        dictgen::InsensitiveStr::Ascii("iniastre"),
        dictgen::InsensitiveStr::Ascii("iniater"),
        dictgen::InsensitiveStr::Ascii("iniatre"),
        dictgen::InsensitiveStr::Ascii("timalisation"),
        dictgen::InsensitiveStr::Ascii("timalisations"),
        dictgen::InsensitiveStr::Ascii("timalise"),
        dictgen::InsensitiveStr::Ascii("timalised"),
        dictgen::InsensitiveStr::Ascii("timalises"),
        dictgen::InsensitiveStr::Ascii("timalising"),
        dictgen::InsensitiveStr::Ascii("timalization"),
        dictgen::InsensitiveStr::Ascii("timalizations"),
        dictgen::InsensitiveStr::Ascii("timalize"),
        dictgen::InsensitiveStr::Ascii("timalized"),
        dictgen::InsensitiveStr::Ascii("timalizes"),
        dictgen::InsensitiveStr::Ascii("timalizing"),
        dictgen::InsensitiveStr::Ascii("timisation"),
        dictgen::InsensitiveStr::Ascii("timisations"),
        dictgen::InsensitiveStr::Ascii("timise"),
        dictgen::InsensitiveStr::Ascii("timised"),
        dictgen::InsensitiveStr::Ascii("timiser"),
        dictgen::InsensitiveStr::Ascii("timisers"),
        dictgen::InsensitiveStr::Ascii("timises"),
        dictgen::InsensitiveStr::Ascii("timising"),
        dictgen::InsensitiveStr::Ascii("timization"),
        dictgen::InsensitiveStr::Ascii("timizations"),
        dictgen::InsensitiveStr::Ascii("timize"),
        dictgen::InsensitiveStr::Ascii("timized"),
        dictgen::InsensitiveStr::Ascii("timizer"),
        dictgen::InsensitiveStr::Ascii("timizers"),
        dictgen::InsensitiveStr::Ascii("timizes"),
        dictgen::InsensitiveStr::Ascii("timizing"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OPALED_11788692301205754513)],
        &[(0b10010, &ENTRY_OPALIZE_13284386352819052954)],
        &[(0b10010, &ENTRY_OPALIZED_13663629834424998715)],
        &[(0b10010, &ENTRY_OPALIZES_13162100843006512376)],
        &[(0b01001, &ENTRY_OPALIZE_13284386352819052954)],
        &[(0b01001, &ENTRY_OPALIZED_13663629834424998715)],
        &[(0b01001, &ENTRY_OPALIZES_13162100843006512376)],
        &[(0b11010, &ENTRY_OPALED_11788692301205754513)],
        &[(0b10010, &ENTRY_OPERATIONALIZATION_16110043926870456437)],
        &[(0b10010, &ENTRY_OPERATIONALIZATIONS_15714273084107805159)],
        &[(0b10010, &ENTRY_OPERATIONALIZE_2692806162887915024)],
        &[(0b10010, &ENTRY_OPERATIONALIZED_10694005742106318769)],
        &[(0b01001, &ENTRY_OPERATIONALIZATION_16110043926870456437)],
        &[(0b01001, &ENTRY_OPERATIONALIZATIONS_15714273084107805159)],
        &[(0b01001, &ENTRY_OPERATIONALIZE_2692806162887915024)],
        &[(0b01001, &ENTRY_OPERATIONALIZED_10694005742106318769)],
        &[(0b10010, &ENTRY_OPERATIZE_3052027238656154731)],
        &[(0b10010, &ENTRY_OPERATIZED_5105704374145792138)],
        &[(0b10010, &ENTRY_OPERATIZES_4708799086455482533)],
        &[(0b10010, &ENTRY_OPERATIZING_8904168123042897096)],
        &[(0b01001, &ENTRY_OPERATIZE_3052027238656154731)],
        &[(0b01001, &ENTRY_OPERATIZED_5105704374145792138)],
        &[(0b01001, &ENTRY_OPERATIZES_4708799086455482533)],
        &[(0b01001, &ENTRY_OPERATIZING_8904168123042897096)],
        &[(0b00001, &ENTRY_OPINIASTER_1982100576920314323)],
        &[(0b11010, &ENTRY_OPINIASTER_1982100576920314323)],
        &[(0b00001, &ENTRY_OPINIATER_8121394919829508808)],
        &[(0b11010, &ENTRY_OPINIATER_8121394919829508808)],
        &[(0b10010, &ENTRY_OPTIMALIZATION_17508577542812465721)],
        &[(0b10010, &ENTRY_OPTIMALIZATIONS_14704077527785732577)],
        &[(0b10010, &ENTRY_OPTIMALIZE_12220685864866355750)],
        &[(0b10010, &ENTRY_OPTIMALIZED_7555891306105308389)],
        &[(0b10010, &ENTRY_OPTIMALIZES_3228782827219559495)],
        &[(0b10010, &ENTRY_OPTIMALIZING_12458824693754631504)],
        &[(0b01001, &ENTRY_OPTIMALIZATION_17508577542812465721)],
        &[(0b01001, &ENTRY_OPTIMALIZATIONS_14704077527785732577)],
        &[(0b01001, &ENTRY_OPTIMALIZE_12220685864866355750)],
        &[(0b01001, &ENTRY_OPTIMALIZED_7555891306105308389)],
        &[(0b01001, &ENTRY_OPTIMALIZES_3228782827219559495)],
        &[(0b01001, &ENTRY_OPTIMALIZING_12458824693754631504)],
        &[(0b10010, &ENTRY_OPTIMIZATION_13814783904890834134)],
        &[(0b10010, &ENTRY_OPTIMIZATIONS_1194472855170942155)],
        &[(0b10010, &ENTRY_OPTIMIZE_1313335540043097536)],
        &[(0b10010, &ENTRY_OPTIMIZED_8242242244633121729)],
        &[(0b10010, &ENTRY_OPTIMIZER_520050784414587313)],
        &[(0b10010, &ENTRY_OPTIMIZERS_15572959853505310715)],
        &[(0b10010, &ENTRY_OPTIMIZES_12957185612694058626)],
        &[(0b10010, &ENTRY_OPTIMIZING_11401875964281836448)],
        &[(0b01001, &ENTRY_OPTIMIZATION_13814783904890834134)],
        &[(0b01001, &ENTRY_OPTIMIZATIONS_1194472855170942155)],
        &[(0b01001, &ENTRY_OPTIMIZE_1313335540043097536)],
        &[(0b01001, &ENTRY_OPTIMIZED_8242242244633121729)],
        &[(0b01001, &ENTRY_OPTIMIZER_520050784414587313)],
        &[(0b01001, &ENTRY_OPTIMIZERS_15572959853505310715)],
        &[(0b01001, &ENTRY_OPTIMIZES_12957185612694058626)],
        &[(0b01001, &ENTRY_OPTIMIZING_11401875964281836448)],
        &[(0b10010, &ENTRY_OPTIONALIZE_17761516814714768422)],
        &[(0b10010, &ENTRY_OPTIONALIZES_17211623898421470779)],
        &[(0b01001, &ENTRY_OPTIONALIZE_17761516814714768422)],
        &[(0b01001, &ENTRY_OPTIONALIZES_17211623898421470779)],
    ],
    range: 4..=17,
};

static VARS_OO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OO_CHILDREN),
    value: None,
};

pub static VARS_OO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("glea"),
        dictgen::InsensitiveStr::Ascii("gloea"),
        dictgen::InsensitiveStr::Ascii("phorectomise"),
        dictgen::InsensitiveStr::Ascii("phorectomised"),
        dictgen::InsensitiveStr::Ascii("phorectomises"),
        dictgen::InsensitiveStr::Ascii("phorectomising"),
        dictgen::InsensitiveStr::Ascii("phorectomize"),
        dictgen::InsensitiveStr::Ascii("phorectomized"),
        dictgen::InsensitiveStr::Ascii("phorectomizes"),
        dictgen::InsensitiveStr::Ascii("phorectomizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OOGLEA_4797962690992465162)],
        &[(0b11010, &ENTRY_OOGLEA_4797962690992465162)],
        &[(0b10010, &ENTRY_OOPHORECTOMIZE_6120142783855584835)],
        &[(0b10010, &ENTRY_OOPHORECTOMIZED_9646531786514422937)],
        &[(0b10010, &ENTRY_OOPHORECTOMIZES_149709679714797903)],
        &[(0b10010, &ENTRY_OOPHORECTOMIZING_6744915085700528874)],
        &[(0b01001, &ENTRY_OOPHORECTOMIZE_6120142783855584835)],
        &[(0b01001, &ENTRY_OOPHORECTOMIZED_9646531786514422937)],
        &[(0b01001, &ENTRY_OOPHORECTOMIZES_149709679714797903)],
        &[(0b01001, &ENTRY_OOPHORECTOMIZING_6744915085700528874)],
    ],
    range: 4..=14,
};

static VARS_ON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ON_CHILDREN),
    value: None,
};

pub static VARS_ON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eyer"),
        dictgen::InsensitiveStr::Ascii("eyers"),
        dictgen::InsensitiveStr::Ascii("eyre"),
        dictgen::InsensitiveStr::Ascii("eyres"),
        dictgen::InsensitiveStr::Ascii("ionised"),
        dictgen::InsensitiveStr::Ascii("ioniseds"),
        dictgen::InsensitiveStr::Ascii("ionized"),
        dictgen::InsensitiveStr::Ascii("ionizeds"),
        dictgen::InsensitiveStr::Ascii("tologise"),
        dictgen::InsensitiveStr::Ascii("tologize"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ONEYER_3113456979455149502)],
        &[(0b00001, &ENTRY_ONEYERS_732051306964839428)],
        &[(0b11010, &ENTRY_ONEYER_3113456979455149502)],
        &[(0b11010, &ENTRY_ONEYERS_732051306964839428)],
        &[(0b10010, &ENTRY_ONIONIZED_13175316651387656071)],
        &[(0b10010, &ENTRY_ONIONIZEDS_14087702405815459001)],
        &[(0b01001, &ENTRY_ONIONIZED_13175316651387656071)],
        &[(0b01001, &ENTRY_ONIONIZEDS_14087702405815459001)],
        &[(0b10010, &ENTRY_ONTOLOGIZE_16171100816417470761)],
        &[(0b01001, &ENTRY_ONTOLOGIZE_16171100816417470761)],
    ],
    range: 4..=8,
};

static VARS_OM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OM_CHILDREN),
    value: None,
};

pub static VARS_OM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ber"),
        dictgen::InsensitiveStr::Ascii("bers"),
        dictgen::InsensitiveStr::Ascii("bre"),
        dictgen::InsensitiveStr::Ascii("bres"),
        dictgen::InsensitiveStr::Ascii("elet"),
        dictgen::InsensitiveStr::Ascii("elets"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OMBER_3695322023364981830)],
        &[(0b00001, &ENTRY_OMBERS_15554244962838841551)],
        &[(0b11010, &ENTRY_OMBER_3695322023364981830)],
        &[(0b11010, &ENTRY_OMBERS_15554244962838841551)],
        &[(0b01001, &ENTRY_OMELET_7824462662732690545)],
        &[(0b01001, &ENTRY_OMELETS_1159437164748315894)],
    ],
    range: 3..=5,
};

static VARS_OL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OL_CHILDREN),
    value: None,
};

pub static VARS_OL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("igaemia"),
        dictgen::InsensitiveStr::Ascii("igemia"),
        dictgen::InsensitiveStr::Ascii("igocythaemia"),
        dictgen::InsensitiveStr::Ascii("igocythemia"),
        dictgen::InsensitiveStr::Ascii("pae"),
        dictgen::InsensitiveStr::Ascii("pe"),
        dictgen::InsensitiveStr::Ascii("ympianise"),
        dictgen::InsensitiveStr::Ascii("ympianises"),
        dictgen::InsensitiveStr::Ascii("ympianize"),
        dictgen::InsensitiveStr::Ascii("ympianizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OLIGEMIA_10907380054389841551)],
        &[(0b10001, &ENTRY_OLIGEMIA_10907380054389841551)],
        &[(0b11010, &ENTRY_OLIGOCYTHEMIA_4447810723170322323)],
        &[(0b10001, &ENTRY_OLIGOCYTHEMIA_4447810723170322323)],
        &[(0b11010, &ENTRY_OLPE_12607327020570739475)],
        &[(0b00001, &ENTRY_OLPE_12607327020570739475)],
        &[(0b10010, &ENTRY_OLYMPIANIZE_16666030921906448094)],
        &[(0b10010, &ENTRY_OLYMPIANIZES_15338190775391482293)],
        &[(0b01001, &ENTRY_OLYMPIANIZE_16666030921906448094)],
        &[(0b01001, &ENTRY_OLYMPIANIZES_15338190775391482293)],
    ],
    range: 2..=12,
};

static VARS_OF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OF_CHILDREN),
    value: None,
};

pub static VARS_OF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fence"),
        dictgen::InsensitiveStr::Ascii("fenceless"),
        dictgen::InsensitiveStr::Ascii("fencelesser"),
        dictgen::InsensitiveStr::Ascii("fencelesses"),
        dictgen::InsensitiveStr::Ascii("fencelessest"),
        dictgen::InsensitiveStr::Ascii("fencelessly"),
        dictgen::InsensitiveStr::Ascii("fences"),
        dictgen::InsensitiveStr::Ascii("fense"),
        dictgen::InsensitiveStr::Ascii("fenseless"),
        dictgen::InsensitiveStr::Ascii("fenselesser"),
        dictgen::InsensitiveStr::Ascii("fenselesses"),
        dictgen::InsensitiveStr::Ascii("fenselessest"),
        dictgen::InsensitiveStr::Ascii("fenselessly"),
        dictgen::InsensitiveStr::Ascii("fenses"),
        dictgen::InsensitiveStr::Ascii("ficialisation"),
        dictgen::InsensitiveStr::Ascii("ficialisations"),
        dictgen::InsensitiveStr::Ascii("ficialise"),
        dictgen::InsensitiveStr::Ascii("ficialises"),
        dictgen::InsensitiveStr::Ascii("ficialization"),
        dictgen::InsensitiveStr::Ascii("ficializations"),
        dictgen::InsensitiveStr::Ascii("ficialize"),
        dictgen::InsensitiveStr::Ascii("ficializes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_OFFENSE_7665506159023341249)],
        &[(0b11010, &ENTRY_OFFENSELESS_13868538846119764327)],
        &[(0b11010, &ENTRY_OFFENSELESSER_8750322905944062314)],
        &[(0b11010, &ENTRY_OFFENSELESSES_9194933418994630180)],
        &[(0b11010, &ENTRY_OFFENSELESSEST_15069248455544272907)],
        &[(0b11010, &ENTRY_OFFENSELESSLY_8614532241535438605)],
        &[(0b11010, &ENTRY_OFFENSES_17067991581389456500)],
        &[(0b01001, &ENTRY_OFFENSE_7665506159023341249)],
        &[(0b00001, &ENTRY_OFFENSELESS_13868538846119764327)],
        &[(0b00001, &ENTRY_OFFENSELESSER_8750322905944062314)],
        &[(0b00001, &ENTRY_OFFENSELESSES_9194933418994630180)],
        &[(0b00001, &ENTRY_OFFENSELESSEST_15069248455544272907)],
        &[(0b00001, &ENTRY_OFFENSELESSLY_8614532241535438605)],
        &[(0b01001, &ENTRY_OFFENSES_17067991581389456500)],
        &[(0b10010, &ENTRY_OFFICIALIZATION_12282151738176992879)],
        &[(0b10010, &ENTRY_OFFICIALIZATIONS_16572881069026493160)],
        &[(0b10010, &ENTRY_OFFICIALIZE_3115747240724358934)],
        &[(0b10010, &ENTRY_OFFICIALIZES_6105548396173328182)],
        &[(0b01001, &ENTRY_OFFICIALIZATION_12282151738176992879)],
        &[(0b01001, &ENTRY_OFFICIALIZATIONS_16572881069026493160)],
        &[(0b01001, &ENTRY_OFFICIALIZE_3115747240724358934)],
        &[(0b01001, &ENTRY_OFFICIALIZES_6105548396173328182)],
    ],
    range: 5..=14,
};

static VARS_OE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OE_CHILDREN),
    value: None,
};

pub static VARS_OE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("coid"),
        dictgen::InsensitiveStr::Ascii("cophobia"),
        dictgen::InsensitiveStr::Ascii("cumenic"),
        dictgen::InsensitiveStr::Ascii("cumenicalism"),
        dictgen::InsensitiveStr::Ascii("cumenicity"),
        dictgen::InsensitiveStr::Ascii("cumenism"),
        dictgen::InsensitiveStr::Ascii("cus"),
        dictgen::InsensitiveStr::Ascii("dema"),
        dictgen::InsensitiveStr::Ascii("demas"),
        dictgen::InsensitiveStr::Ascii("dematose"),
        dictgen::InsensitiveStr::Ascii("dematous"),
        dictgen::InsensitiveStr::Ascii("nocyte"),
        dictgen::InsensitiveStr::Ascii("nolic"),
        dictgen::InsensitiveStr::Ascii("nological"),
        dictgen::InsensitiveStr::Ascii("nologist"),
        dictgen::InsensitiveStr::Ascii("nologists"),
        dictgen::InsensitiveStr::Ascii("nomania"),
        dictgen::InsensitiveStr::Ascii("sophagal"),
        dictgen::InsensitiveStr::Ascii("sophagean"),
        dictgen::InsensitiveStr::Ascii("sophagi"),
        dictgen::InsensitiveStr::Ascii("sophagism"),
        dictgen::InsensitiveStr::Ascii("sophagismus"),
        dictgen::InsensitiveStr::Ascii("sophagitis"),
        dictgen::InsensitiveStr::Ascii("sophagus"),
        dictgen::InsensitiveStr::Ascii("sophaguses"),
        dictgen::InsensitiveStr::Ascii("stradiol"),
        dictgen::InsensitiveStr::Ascii("stradiols"),
        dictgen::InsensitiveStr::Ascii("stral"),
        dictgen::InsensitiveStr::Ascii("strin"),
        dictgen::InsensitiveStr::Ascii("strins"),
        dictgen::InsensitiveStr::Ascii("striol"),
        dictgen::InsensitiveStr::Ascii("striols"),
        dictgen::InsensitiveStr::Ascii("strogen"),
        dictgen::InsensitiveStr::Ascii("strogenic"),
        dictgen::InsensitiveStr::Ascii("strogens"),
        dictgen::InsensitiveStr::Ascii("strone"),
        dictgen::InsensitiveStr::Ascii("strones"),
        dictgen::InsensitiveStr::Ascii("strous"),
        dictgen::InsensitiveStr::Ascii("strual"),
        dictgen::InsensitiveStr::Ascii("struate"),
        dictgen::InsensitiveStr::Ascii("struation"),
        dictgen::InsensitiveStr::Ascii("strum"),
        dictgen::InsensitiveStr::Ascii("strums"),
        dictgen::InsensitiveStr::Ascii("strus"),
        dictgen::InsensitiveStr::Ascii("struses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ECOID_15718380068289810443)],
        &[(0b11010, &ENTRY_ECOPHOBIA_3341542489768933704)],
        &[(0b11010, &ENTRY_ECUMENIC_15780133217602967984)],
        &[(0b11010, &ENTRY_ECUMENICALISM_9305909791330696513)],
        &[(0b11010, &ENTRY_ECUMENICITY_12254763938003713900)],
        &[(0b11010, &ENTRY_ECUMENISM_18416002854149374979)],
        &[(0b11010, &ENTRY_ECUS_7337291910539278082)],
        &[(0b10010, &ENTRY_EDEMA_6018744134424908364)],
        &[(0b10010, &ENTRY_EDEMAS_7742566514366737816)],
        &[(0b10010, &ENTRY_EDEMATOSE_16851378643586465230)],
        &[(0b10010, &ENTRY_EDEMATOUS_2501565917049629990)],
        &[(0b11010, &ENTRY_ENOCYTE_5031071790616444705)],
        &[(0b11010, &ENTRY_ENOLIC_8677666364536262517)],
        &[(0b11010, &ENTRY_ENOLOGICAL_13435934594635959021)],
        &[(0b11010, &ENTRY_ENOLOGIST_7144439191139309152)],
        &[(0b11010, &ENTRY_ENOLOGISTS_17383228974239236048)],
        &[(0b11010, &ENTRY_ENOMANIA_2005674743319272403)],
        &[(0b11010, &ENTRY_ESOPHAGAL_17089437120427101379)],
        &[(0b11010, &ENTRY_ESOPHAGEAN_1258506141459731259)],
        &[(0b10010, &ENTRY_ESOPHAGI_16651245992122782472)],
        &[(0b11010, &ENTRY_ESOPHAGISM_11099656979396238835)],
        &[(0b11010, &ENTRY_ESOPHAGISMUS_6650076607428716726)],
        &[(0b11010, &ENTRY_ESOPHAGITIS_2344628816303730914)],
        &[(0b11010, &ENTRY_ESOPHAGUS_11192235604123814381)],
        &[(0b00010, &ENTRY_ESOPHAGI_16651245992122782472)],
        &[(0b11010, &ENTRY_ESTRADIOL_634787677538270649)],
        &[(0b11010, &ENTRY_ESTRADIOLS_6587359583583660465)],
        &[(0b11010, &ENTRY_ESTRAL_250960197285450439)],
        &[(0b11010, &ENTRY_ESTRIN_1271537042891040806)],
        &[(0b11010, &ENTRY_ESTRINS_11482863399944620630)],
        &[(0b11010, &ENTRY_ESTRIOL_5700840801301268453)],
        &[(0b11010, &ENTRY_ESTRIOLS_15504531823851684601)],
        &[(0b10010, &ENTRY_ESTROGEN_9296702706992805950)],
        &[(0b10010, &ENTRY_ESTROGENIC_9825757897324531986)],
        &[(0b10010, &ENTRY_ESTROGENS_13879624153768181446)],
        &[(0b11010, &ENTRY_ESTRONE_5235731124564419249)],
        &[(0b11010, &ENTRY_ESTRONES_396980696513423065)],
        &[(0b10010, &ENTRY_ESTROUS_3175557539569890653)],
        &[(0b11010, &ENTRY_ESTRUAL_2760322156873020612)],
        &[(0b11010, &ENTRY_ESTRUATE_9742423605759945651)],
        &[(0b11010, &ENTRY_ESTRUATION_528782982925379226)],
        &[(0b11010, &ENTRY_ESTRUM_80713081920872301)],
        &[(0b11010, &ENTRY_ESTRUMS_13425140989742183588)],
        &[(0b10010, &ENTRY_ESTRUS_12109407348878630371)],
        &[(0b10010, &ENTRY_ESTRUSES_10476871772114155317)],
    ],
    range: 3..=12,
};

static VARS_OD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OD_CHILDREN),
    value: None,
};

pub static VARS_OD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orful"),
        dictgen::InsensitiveStr::Ascii("orfuller"),
        dictgen::InsensitiveStr::Ascii("orfullest"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("oriser"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizer"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("orlesser"),
        dictgen::InsensitiveStr::Ascii("orlesses"),
        dictgen::InsensitiveStr::Ascii("orlessest"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourful"),
        dictgen::InsensitiveStr::Ascii("ourfuller"),
        dictgen::InsensitiveStr::Ascii("ourfullest"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ourlesser"),
        dictgen::InsensitiveStr::Ascii("ourlesses"),
        dictgen::InsensitiveStr::Ascii("ourlessest"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_ODOR_14195116284871916349)],
        &[(0b11001, &ENTRY_ODORED_2252339375387177943)],
        &[(0b11001, &ENTRY_ODORFUL_16899196923808811198)],
        &[(0b11001, &ENTRY_ODORFULLER_13616470430206634220)],
        &[(0b11001, &ENTRY_ODORFULLEST_17115559072799533041)],
        &[(0b10010, &ENTRY_ODORIZE_9626934429537178470)],
        &[(0b10010, &ENTRY_ODORIZED_12401728499096074253)],
        &[(0b10010, &ENTRY_ODORIZER_9703276154089227183)],
        &[(0b10010, &ENTRY_ODORIZES_14078045785775136097)],
        &[(0b10010, &ENTRY_ODORIZING_15240114282647188255)],
        &[(0b01001, &ENTRY_ODORIZE_9626934429537178470)],
        &[(0b01001, &ENTRY_ODORIZED_12401728499096074253)],
        &[(0b01001, &ENTRY_ODORIZER_9703276154089227183)],
        &[(0b01001, &ENTRY_ODORIZES_14078045785775136097)],
        &[(0b01001, &ENTRY_ODORIZING_15240114282647188255)],
        &[(0b11001, &ENTRY_ODORLESS_8490769064796870183)],
        &[(0b11001, &ENTRY_ODORLESSER_17075792343165727224)],
        &[(0b11001, &ENTRY_ODORLESSES_1268415129329322072)],
        &[(0b11001, &ENTRY_ODORLESSEST_1630943358374016605)],
        &[(0b11001, &ENTRY_ODORS_372602031562404386)],
        &[(0b11010, &ENTRY_ODOR_14195116284871916349)],
        &[(0b11010, &ENTRY_ODORED_2252339375387177943)],
        &[(0b11010, &ENTRY_ODORFUL_16899196923808811198)],
        &[(0b11010, &ENTRY_ODORFULLER_13616470430206634220)],
        &[(0b11010, &ENTRY_ODORFULLEST_17115559072799533041)],
        &[(0b11010, &ENTRY_ODORLESS_8490769064796870183)],
        &[(0b11010, &ENTRY_ODORLESSER_17075792343165727224)],
        &[(0b11010, &ENTRY_ODORLESSES_1268415129329322072)],
        &[(0b11010, &ENTRY_ODORLESSEST_1630943358374016605)],
        &[(0b11010, &ENTRY_ODORS_372602031562404386)],
    ],
    range: 2..=10,
};

static VARS_OC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OC_CHILDREN),
    value: None,
};

pub static VARS_OC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cidentalisation"),
        dictgen::InsensitiveStr::Ascii("cidentalisations"),
        dictgen::InsensitiveStr::Ascii("cidentalise"),
        dictgen::InsensitiveStr::Ascii("cidentalised"),
        dictgen::InsensitiveStr::Ascii("cidentalises"),
        dictgen::InsensitiveStr::Ascii("cidentalising"),
        dictgen::InsensitiveStr::Ascii("cidentalization"),
        dictgen::InsensitiveStr::Ascii("cidentalizations"),
        dictgen::InsensitiveStr::Ascii("cidentalize"),
        dictgen::InsensitiveStr::Ascii("cidentalized"),
        dictgen::InsensitiveStr::Ascii("cidentalizes"),
        dictgen::InsensitiveStr::Ascii("cidentalizing"),
        dictgen::InsensitiveStr::Ascii("her"),
        dictgen::InsensitiveStr::Ascii("hered"),
        dictgen::InsensitiveStr::Ascii("hering"),
        dictgen::InsensitiveStr::Ascii("herish"),
        dictgen::InsensitiveStr::Ascii("herous"),
        dictgen::InsensitiveStr::Ascii("herouser"),
        dictgen::InsensitiveStr::Ascii("herousest"),
        dictgen::InsensitiveStr::Ascii("herrer"),
        dictgen::InsensitiveStr::Ascii("herrest"),
        dictgen::InsensitiveStr::Ascii("hers"),
        dictgen::InsensitiveStr::Ascii("hery"),
        dictgen::InsensitiveStr::Ascii("hre"),
        dictgen::InsensitiveStr::Ascii("hred"),
        dictgen::InsensitiveStr::Ascii("hreish"),
        dictgen::InsensitiveStr::Ascii("hrer"),
        dictgen::InsensitiveStr::Ascii("hres"),
        dictgen::InsensitiveStr::Ascii("hrest"),
        dictgen::InsensitiveStr::Ascii("hrey"),
        dictgen::InsensitiveStr::Ascii("hring"),
        dictgen::InsensitiveStr::Ascii("yrrhoae"),
        dictgen::InsensitiveStr::Ascii("yrrhoe"),
    ],
    values: &[
        &[(0b10010, &ENTRY_OCCIDENTALIZATION_3769379737658488415)],
        &[(0b10010, &ENTRY_OCCIDENTALIZATIONS_8738201873109640995)],
        &[(0b10010, &ENTRY_OCCIDENTALIZE_14982167974023633691)],
        &[(0b10010, &ENTRY_OCCIDENTALIZED_10700323340151304771)],
        &[(0b10010, &ENTRY_OCCIDENTALIZES_11790781010835271497)],
        &[(0b10010, &ENTRY_OCCIDENTALIZING_7464247317028861929)],
        &[(0b01001, &ENTRY_OCCIDENTALIZATION_3769379737658488415)],
        &[(0b01001, &ENTRY_OCCIDENTALIZATIONS_8738201873109640995)],
        &[(0b01001, &ENTRY_OCCIDENTALIZE_14982167974023633691)],
        &[(0b01001, &ENTRY_OCCIDENTALIZED_10700323340151304771)],
        &[(0b01001, &ENTRY_OCCIDENTALIZES_11790781010835271497)],
        &[(0b01001, &ENTRY_OCCIDENTALIZING_7464247317028861929)],
        &[(0b00001, &ENTRY_OCHER_18444668755403044757)],
        &[(0b00001, &ENTRY_OCHERED_16209295361742850766)],
        &[(0b00001, &ENTRY_OCHERING_9981492660913249632)],
        &[(0b00001, &ENTRY_OCHERISH_13974738456690891637)],
        &[(0b00001, &ENTRY_OCHEROUS_12471251094160085620)],
        &[(0b00001, &ENTRY_OCHEROUSER_5814846539343037272)],
        &[(0b00001, &ENTRY_OCHEROUSEST_12442913746853846797)],
        &[(0b00001, &ENTRY_OCHERRER_17558493090638662388)],
        &[(0b00001, &ENTRY_OCHERREST_9858563234413281789)],
        &[(0b00001, &ENTRY_OCHERS_10191929869929788169)],
        &[(0b00001, &ENTRY_OCHERY_11959809883617627023)],
        &[(0b11010, &ENTRY_OCHER_18444668755403044757)],
        &[(0b11010, &ENTRY_OCHERED_16209295361742850766)],
        &[(0b11010, &ENTRY_OCHERISH_13974738456690891637)],
        &[(0b11010, &ENTRY_OCHERRER_17558493090638662388)],
        &[(0b11010, &ENTRY_OCHERS_10191929869929788169)],
        &[(0b11010, &ENTRY_OCHERREST_9858563234413281789)],
        &[(0b11010, &ENTRY_OCHERY_11959809883617627023)],
        &[(0b11010, &ENTRY_OCHERING_9981492660913249632)],
        &[(0b11010, &ENTRY_OCYRRHOE_15586534960542914241)],
        &[(0b00001, &ENTRY_OCYRRHOE_15586534960542914241)],
    ],
    range: 3..=16,
};

static VARS_OB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_OB_CHILDREN),
    value: None,
};

pub static VARS_OB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
        dictgen::InsensitiveStr::Ascii("jectisation"),
        dictgen::InsensitiveStr::Ascii("jectisations"),
        dictgen::InsensitiveStr::Ascii("jectise"),
        dictgen::InsensitiveStr::Ascii("jectises"),
        dictgen::InsensitiveStr::Ascii("jectivise"),
        dictgen::InsensitiveStr::Ascii("jectivised"),
        dictgen::InsensitiveStr::Ascii("jectivises"),
        dictgen::InsensitiveStr::Ascii("jectivising"),
        dictgen::InsensitiveStr::Ascii("jectivize"),
        dictgen::InsensitiveStr::Ascii("jectivized"),
        dictgen::InsensitiveStr::Ascii("jectivizes"),
        dictgen::InsensitiveStr::Ascii("jectivizing"),
        dictgen::InsensitiveStr::Ascii("jectization"),
        dictgen::InsensitiveStr::Ascii("jectizations"),
        dictgen::InsensitiveStr::Ascii("jectize"),
        dictgen::InsensitiveStr::Ascii("jectizes"),
        dictgen::InsensitiveStr::Ascii("livionise"),
        dictgen::InsensitiveStr::Ascii("livionises"),
        dictgen::InsensitiveStr::Ascii("livionize"),
        dictgen::InsensitiveStr::Ascii("livionizes"),
        dictgen::InsensitiveStr::Ascii("oe"),
    ],
    values: &[
        &[(0b00001, &ENTRY_OBE_3387122031217898278)],
        &[(0b10010, &ENTRY_OBELIZE_13327573059995603775)],
        &[(0b10010, &ENTRY_OBELIZED_8713779244189302123)],
        &[(0b10010, &ENTRY_OBELIZES_12711583286840300362)],
        &[(0b10010, &ENTRY_OBELIZING_10540895735990622314)],
        &[(0b01001, &ENTRY_OBELIZE_13327573059995603775)],
        &[(0b01001, &ENTRY_OBELIZED_8713779244189302123)],
        &[(0b01001, &ENTRY_OBELIZES_12711583286840300362)],
        &[(0b01001, &ENTRY_OBELIZING_10540895735990622314)],
        &[(0b10010, &ENTRY_OBJECTIZATION_1275857172671417186)],
        &[(0b10010, &ENTRY_OBJECTIZATIONS_6401266830241310518)],
        &[(0b10010, &ENTRY_OBJECTIZE_15875934894636197705)],
        &[(0b10010, &ENTRY_OBJECTIZES_6620023301989924349)],
        &[(0b10010, &ENTRY_OBJECTIVIZE_11255072833982793370)],
        &[(0b10010, &ENTRY_OBJECTIVIZED_5569615171626387785)],
        &[(0b10010, &ENTRY_OBJECTIVIZES_9154527217307669621)],
        &[(0b10010, &ENTRY_OBJECTIVIZING_13183716323700619199)],
        &[(0b01001, &ENTRY_OBJECTIVIZE_11255072833982793370)],
        &[(0b01001, &ENTRY_OBJECTIVIZED_5569615171626387785)],
        &[(0b01001, &ENTRY_OBJECTIVIZES_9154527217307669621)],
        &[(0b01001, &ENTRY_OBJECTIVIZING_13183716323700619199)],
        &[(0b01001, &ENTRY_OBJECTIZATION_1275857172671417186)],
        &[(0b01001, &ENTRY_OBJECTIZATIONS_6401266830241310518)],
        &[(0b01001, &ENTRY_OBJECTIZE_15875934894636197705)],
        &[(0b01001, &ENTRY_OBJECTIZES_6620023301989924349)],
        &[(0b10010, &ENTRY_OBLIVIONIZE_12722654593806151859)],
        &[(0b10010, &ENTRY_OBLIVIONIZES_1391399085902087900)],
        &[(0b01001, &ENTRY_OBLIVIONIZE_12722654593806151859)],
        &[(0b01001, &ENTRY_OBLIVIONIZES_1391399085902087900)],
        &[(0b11010, &ENTRY_OBE_3387122031217898278)],
    ],
    range: 1..=12,
};

static VARS_N_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_N_CHILDREN),
    value: None,
};

static VARS_N_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_NA_NODE),
    None,
    None,
    None,
    Some(&VARS_NE_NODE),
    None,
    None,
    None,
    Some(&VARS_NI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NU_NODE),
    None,
    None,
    None,
    Some(&VARS_NY_NODE),
    None,
];

static VARS_NY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NY_CHILDREN),
    value: None,
};

pub static VARS_NY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphaeum"),
        dictgen::InsensitiveStr::Ascii("mpheum"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NYMPHEUM_10481976698848445627)],
        &[(0b00001, &ENTRY_NYMPHEUM_10481976698848445627)],
    ],
    range: 6..=7,
};

static VARS_NU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NU_CHILDREN),
    value: None,
};

pub static VARS_NU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("clearisation"),
        dictgen::InsensitiveStr::Ascii("clearisations"),
        dictgen::InsensitiveStr::Ascii("clearise"),
        dictgen::InsensitiveStr::Ascii("clearised"),
        dictgen::InsensitiveStr::Ascii("clearises"),
        dictgen::InsensitiveStr::Ascii("clearising"),
        dictgen::InsensitiveStr::Ascii("clearization"),
        dictgen::InsensitiveStr::Ascii("clearizations"),
        dictgen::InsensitiveStr::Ascii("clearize"),
        dictgen::InsensitiveStr::Ascii("clearized"),
        dictgen::InsensitiveStr::Ascii("clearizes"),
        dictgen::InsensitiveStr::Ascii("clearizing"),
        dictgen::InsensitiveStr::Ascii("ptialise"),
        dictgen::InsensitiveStr::Ascii("ptialises"),
        dictgen::InsensitiveStr::Ascii("ptialize"),
        dictgen::InsensitiveStr::Ascii("ptializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NUCLEARIZATION_3118454623052463273)],
        &[(0b10010, &ENTRY_NUCLEARIZATIONS_6750475977451359321)],
        &[(0b10010, &ENTRY_NUCLEARIZE_16199083117905670972)],
        &[(0b10010, &ENTRY_NUCLEARIZED_3730672147144693200)],
        &[(0b10010, &ENTRY_NUCLEARIZES_11938247015587300181)],
        &[(0b10010, &ENTRY_NUCLEARIZING_8881830408497767903)],
        &[(0b01001, &ENTRY_NUCLEARIZATION_3118454623052463273)],
        &[(0b01001, &ENTRY_NUCLEARIZATIONS_6750475977451359321)],
        &[(0b01001, &ENTRY_NUCLEARIZE_16199083117905670972)],
        &[(0b01001, &ENTRY_NUCLEARIZED_3730672147144693200)],
        &[(0b01001, &ENTRY_NUCLEARIZES_11938247015587300181)],
        &[(0b01001, &ENTRY_NUCLEARIZING_8881830408497767903)],
        &[(0b10010, &ENTRY_NUPTIALIZE_260057599291493188)],
        &[(0b10010, &ENTRY_NUPTIALIZES_6702953704988138928)],
        &[(0b01001, &ENTRY_NUPTIALIZE_260057599291493188)],
        &[(0b01001, &ENTRY_NUPTIALIZES_6702953704988138928)],
    ],
    range: 8..=13,
};

static VARS_NO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NO_CHILDREN),
    value: None,
};

static VARS_NO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_NOA_NODE),
    None,
    None,
    Some(&VARS_NOD_NODE),
    Some(&VARS_NOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NOM_NODE),
    Some(&VARS_NON_NODE),
    None,
    None,
    None,
    Some(&VARS_NOR_NODE),
    Some(&VARS_NOS_NODE),
    Some(&VARS_NOT_NODE),
    Some(&VARS_NOU_NODE),
    Some(&VARS_NOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_NOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOV_CHILDREN),
    value: None,
};

pub static VARS_NOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("eliser"),
        dictgen::InsensitiveStr::Ascii("elisers"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizer"),
        dictgen::InsensitiveStr::Ascii("elizers"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
        dictgen::InsensitiveStr::Ascii("enae"),
        dictgen::InsensitiveStr::Ascii("ene"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NOVELIZATION_8956602949054590888)],
        &[(0b10010, &ENTRY_NOVELIZATIONS_10468098323494499586)],
        &[(0b10010, &ENTRY_NOVELIZE_9212839077174855051)],
        &[(0b10010, &ENTRY_NOVELIZED_15369631902763073587)],
        &[(0b10010, &ENTRY_NOVELIZER_16608816919992566365)],
        &[(0b10010, &ENTRY_NOVELIZERS_4056848164252264083)],
        &[(0b10010, &ENTRY_NOVELIZES_6422920218071722529)],
        &[(0b10010, &ENTRY_NOVELIZING_17848834665214118176)],
        &[(0b01001, &ENTRY_NOVELIZATION_8956602949054590888)],
        &[(0b01001, &ENTRY_NOVELIZATIONS_10468098323494499586)],
        &[(0b01001, &ENTRY_NOVELIZE_9212839077174855051)],
        &[(0b01001, &ENTRY_NOVELIZED_15369631902763073587)],
        &[(0b01001, &ENTRY_NOVELIZER_16608816919992566365)],
        &[(0b01001, &ENTRY_NOVELIZERS_4056848164252264083)],
        &[(0b01001, &ENTRY_NOVELIZES_6422920218071722529)],
        &[(0b01001, &ENTRY_NOVELIZING_17848834665214118176)],
        &[(0b11010, &ENTRY_NOVENE_2924055121197444180)],
        &[(0b00001, &ENTRY_NOVENE_2924055121197444180)],
    ],
    range: 3..=10,
};

static VARS_NOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOU_CHILDREN),
    value: None,
};

pub static VARS_NOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("rice"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NOUNIZE_14880574386923956271)],
        &[(0b10010, &ENTRY_NOUNIZES_10999252613540238861)],
        &[(0b01001, &ENTRY_NOUNIZE_14880574386923956271)],
        &[(0b01001, &ENTRY_NOUNIZES_10999252613540238861)],
        &[(0b11010, &ENTRY_NORICE_7719373850762953271)],
    ],
    range: 4..=5,
};

static VARS_NOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOT_CHILDREN),
    value: None,
};

pub static VARS_NOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arisation"),
        dictgen::InsensitiveStr::Ascii("arisations"),
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arization"),
        dictgen::InsensitiveStr::Ascii("arizations"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("hingise"),
        dictgen::InsensitiveStr::Ascii("hingises"),
        dictgen::InsensitiveStr::Ascii("hingize"),
        dictgen::InsensitiveStr::Ascii("hingizes"),
        dictgen::InsensitiveStr::Ascii("ogaea"),
        dictgen::InsensitiveStr::Ascii("ogea"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NOTARIZATION_17527694196005011234)],
        &[(0b10010, &ENTRY_NOTARIZATIONS_13448734109191848651)],
        &[(0b11010, &ENTRY_NOTARIZE_9890063397301391140)],
        &[(0b11010, &ENTRY_NOTARIZED_2113894921750376734)],
        &[(0b11010, &ENTRY_NOTARIZES_16852590610679722458)],
        &[(0b11010, &ENTRY_NOTARIZING_9414320864175848283)],
        &[(0b01001, &ENTRY_NOTARIZATION_17527694196005011234)],
        &[(0b01001, &ENTRY_NOTARIZATIONS_13448734109191848651)],
        &[(0b01001, &ENTRY_NOTARIZE_9890063397301391140)],
        &[(0b01001, &ENTRY_NOTARIZED_2113894921750376734)],
        &[(0b01001, &ENTRY_NOTARIZES_16852590610679722458)],
        &[(0b01001, &ENTRY_NOTARIZING_9414320864175848283)],
        &[(0b00001, &ENTRY_NOTER_15452359787871882248)],
        &[(0b10010, &ENTRY_NOTHINGIZE_17529460741124691591)],
        &[(0b10010, &ENTRY_NOTHINGIZES_14027925412325072532)],
        &[(0b01001, &ENTRY_NOTHINGIZE_17529460741124691591)],
        &[(0b01001, &ENTRY_NOTHINGIZES_14027925412325072532)],
        &[(0b11010, &ENTRY_NOTOGEA_12966682888446062914)],
        &[(0b00001, &ENTRY_NOTOGEA_12966682888446062914)],
        &[(0b11010, &ENTRY_NOTER_15452359787871882248)],
    ],
    range: 2..=10,
};

static VARS_NOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOS_CHILDREN),
    value: None,
};

pub static VARS_NOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ey"),
        dictgen::InsensitiveStr::Ascii("eys"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ohaemia"),
        dictgen::InsensitiveStr::Ascii("ohemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NOSY_12701039924678011332)],
        &[(0b11010, &ENTRY_NOSIES_3207226487419150754)],
        &[(0b10010, &ENTRY_NOSIZE_17677768185590899897)],
        &[(0b01001, &ENTRY_NOSIZE_17677768185590899897)],
        &[(0b11010, &ENTRY_NOSOHEMIA_14803479550852669947)],
        &[(0b10001, &ENTRY_NOSOHEMIA_14803479550852669947)],
    ],
    range: 2..=7,
};

static VARS_NOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOR_CHILDREN),
    value: None,
};

pub static VARS_NOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ice"),
        dictgen::InsensitiveStr::Ascii("malisable"),
        dictgen::InsensitiveStr::Ascii("malisation"),
        dictgen::InsensitiveStr::Ascii("malisations"),
        dictgen::InsensitiveStr::Ascii("malise"),
        dictgen::InsensitiveStr::Ascii("malised"),
        dictgen::InsensitiveStr::Ascii("maliser"),
        dictgen::InsensitiveStr::Ascii("malisers"),
        dictgen::InsensitiveStr::Ascii("malises"),
        dictgen::InsensitiveStr::Ascii("malising"),
        dictgen::InsensitiveStr::Ascii("malizable"),
        dictgen::InsensitiveStr::Ascii("malization"),
        dictgen::InsensitiveStr::Ascii("malizations"),
        dictgen::InsensitiveStr::Ascii("malize"),
        dictgen::InsensitiveStr::Ascii("malized"),
        dictgen::InsensitiveStr::Ascii("malizer"),
        dictgen::InsensitiveStr::Ascii("malizers"),
        dictgen::InsensitiveStr::Ascii("malizes"),
        dictgen::InsensitiveStr::Ascii("malizing"),
        dictgen::InsensitiveStr::Ascii("manisation"),
        dictgen::InsensitiveStr::Ascii("manisations"),
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("maniser"),
        dictgen::InsensitiveStr::Ascii("manisers"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manization"),
        dictgen::InsensitiveStr::Ascii("manizations"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizer"),
        dictgen::InsensitiveStr::Ascii("manizers"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("thernise"),
        dictgen::InsensitiveStr::Ascii("thernised"),
        dictgen::InsensitiveStr::Ascii("thernises"),
        dictgen::InsensitiveStr::Ascii("thernising"),
        dictgen::InsensitiveStr::Ascii("thernize"),
        dictgen::InsensitiveStr::Ascii("thernized"),
        dictgen::InsensitiveStr::Ascii("thernizes"),
        dictgen::InsensitiveStr::Ascii("thernizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NORICE_7719373850762953271)],
        &[(0b10010, &ENTRY_NORMALIZABLE_12714814257299821976)],
        &[(0b10010, &ENTRY_NORMALIZATION_17734536842587852393)],
        &[(0b10010, &ENTRY_NORMALIZATIONS_7144083295462081278)],
        &[(0b10010, &ENTRY_NORMALIZE_10079721671041412822)],
        &[(0b10010, &ENTRY_NORMALIZED_3189571370237847522)],
        &[(0b10010, &ENTRY_NORMALIZER_18084708139145944342)],
        &[(0b10010, &ENTRY_NORMALIZERS_3883605235812540174)],
        &[(0b10010, &ENTRY_NORMALIZES_7325443769699672094)],
        &[(0b10010, &ENTRY_NORMALIZING_9186993296151327414)],
        &[(0b01001, &ENTRY_NORMALIZABLE_12714814257299821976)],
        &[(0b01001, &ENTRY_NORMALIZATION_17734536842587852393)],
        &[(0b01001, &ENTRY_NORMALIZATIONS_7144083295462081278)],
        &[(0b01001, &ENTRY_NORMALIZE_10079721671041412822)],
        &[(0b01001, &ENTRY_NORMALIZED_3189571370237847522)],
        &[(0b01001, &ENTRY_NORMALIZER_18084708139145944342)],
        &[(0b01001, &ENTRY_NORMALIZERS_3883605235812540174)],
        &[(0b01001, &ENTRY_NORMALIZES_7325443769699672094)],
        &[(0b01001, &ENTRY_NORMALIZING_9186993296151327414)],
        &[(0b10010, &ENTRY_NORMANIZATION_16947119225150381222)],
        &[(0b10010, &ENTRY_NORMANIZATIONS_14581317840430300825)],
        &[(0b10010, &ENTRY_NORMANIZE_16686796116216318913)],
        &[(0b10010, &ENTRY_NORMANIZED_530025651553675599)],
        &[(0b10010, &ENTRY_NORMANIZER_6483132356324999352)],
        &[(0b10010, &ENTRY_NORMANIZERS_15592258832173314813)],
        &[(0b10010, &ENTRY_NORMANIZES_6751150550632176492)],
        &[(0b10010, &ENTRY_NORMANIZING_4320211489087339112)],
        &[(0b01001, &ENTRY_NORMANIZATION_16947119225150381222)],
        &[(0b01001, &ENTRY_NORMANIZATIONS_14581317840430300825)],
        &[(0b01001, &ENTRY_NORMANIZE_16686796116216318913)],
        &[(0b01001, &ENTRY_NORMANIZED_530025651553675599)],
        &[(0b01001, &ENTRY_NORMANIZER_6483132356324999352)],
        &[(0b01001, &ENTRY_NORMANIZERS_15592258832173314813)],
        &[(0b01001, &ENTRY_NORMANIZES_6751150550632176492)],
        &[(0b01001, &ENTRY_NORMANIZING_4320211489087339112)],
        &[(0b10010, &ENTRY_NORTHERNIZE_17423654317310933748)],
        &[(0b10010, &ENTRY_NORTHERNIZED_10171965562670427336)],
        &[(0b10010, &ENTRY_NORTHERNIZES_10191844020334839487)],
        &[(0b10010, &ENTRY_NORTHERNIZING_6205710759762367279)],
        &[(0b01001, &ENTRY_NORTHERNIZE_17423654317310933748)],
        &[(0b01001, &ENTRY_NORTHERNIZED_10171965562670427336)],
        &[(0b01001, &ENTRY_NORTHERNIZES_10191844020334839487)],
        &[(0b01001, &ENTRY_NORTHERNIZING_6205710759762367279)],
    ],
    range: 3..=11,
};

static VARS_NON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NON_CHILDREN),
    value: None,
};

static VARS_NON_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_NONA_NODE),
    None,
    Some(&VARS_NONC_NODE),
    Some(&VARS_NOND_NODE),
    Some(&VARS_NONE_NODE),
    Some(&VARS_NONF_NODE),
    Some(&VARS_NONG_NODE),
    Some(&VARS_NONH_NODE),
    Some(&VARS_NONI_NODE),
    None,
    None,
    Some(&VARS_NONL_NODE),
    Some(&VARS_NONM_NODE),
    Some(&VARS_NONN_NODE),
    Some(&VARS_NONO_NODE),
    Some(&VARS_NONP_NODE),
    None,
    Some(&VARS_NONR_NODE),
    Some(&VARS_NONS_NODE),
    Some(&VARS_NONT_NODE),
    Some(&VARS_NONU_NODE),
    Some(&VARS_NONV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_NONV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONV_CHILDREN),
    value: None,
};

pub static VARS_NONV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isualised"),
        dictgen::InsensitiveStr::Ascii("isualiseds"),
        dictgen::InsensitiveStr::Ascii("isualized"),
        dictgen::InsensitiveStr::Ascii("isualizeds"),
        dictgen::InsensitiveStr::Ascii("olatilised"),
        dictgen::InsensitiveStr::Ascii("olatiliseds"),
        dictgen::InsensitiveStr::Ascii("olatilized"),
        dictgen::InsensitiveStr::Ascii("olatilizeds"),
        dictgen::InsensitiveStr::Ascii("ulcanisable"),
        dictgen::InsensitiveStr::Ascii("ulcanisables"),
        dictgen::InsensitiveStr::Ascii("ulcanizable"),
        dictgen::InsensitiveStr::Ascii("ulcanizables"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONVISUALIZED_6861453340497684108)],
        &[(0b10010, &ENTRY_NONVISUALIZEDS_12906625611904739389)],
        &[(0b01001, &ENTRY_NONVISUALIZED_6861453340497684108)],
        &[(0b01001, &ENTRY_NONVISUALIZEDS_12906625611904739389)],
        &[(0b10010, &ENTRY_NONVOLATILIZED_16762619793860124905)],
        &[(0b10010, &ENTRY_NONVOLATILIZEDS_5921558007608409082)],
        &[(0b01001, &ENTRY_NONVOLATILIZED_16762619793860124905)],
        &[(0b01001, &ENTRY_NONVOLATILIZEDS_5921558007608409082)],
        &[(0b10010, &ENTRY_NONVULCANIZABLE_12072046253771095022)],
        &[(0b10010, &ENTRY_NONVULCANIZABLES_11079865157105755134)],
        &[(0b01001, &ENTRY_NONVULCANIZABLE_12072046253771095022)],
        &[(0b01001, &ENTRY_NONVULCANIZABLES_11079865157105755134)],
    ],
    range: 9..=12,
};

static VARS_NONU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONU_CHILDREN),
    value: None,
};

pub static VARS_NONU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tiliseds"),
        dictgen::InsensitiveStr::Ascii("tilized"),
        dictgen::InsensitiveStr::Ascii("tilizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONUTILIZED_10968594570869729046)],
        &[(0b10010, &ENTRY_NONUTILIZEDS_12596659071225395484)],
        &[(0b01001, &ENTRY_NONUTILIZED_10968594570869729046)],
        &[(0b01001, &ENTRY_NONUTILIZEDS_12596659071225395484)],
    ],
    range: 7..=8,
};

static VARS_NONT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONT_CHILDREN),
    value: None,
};

pub static VARS_NONT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emporising"),
        dictgen::InsensitiveStr::Ascii("emporisings"),
        dictgen::InsensitiveStr::Ascii("emporizing"),
        dictgen::InsensitiveStr::Ascii("emporizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONTEMPORIZING_14055181193950301881)],
        &[(0b10010, &ENTRY_NONTEMPORIZINGS_10874940771787214104)],
        &[(0b01001, &ENTRY_NONTEMPORIZING_14055181193950301881)],
        &[(0b01001, &ENTRY_NONTEMPORIZINGS_10874940771787214104)],
    ],
    range: 10..=11,
};

static VARS_NONS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONS_CHILDREN),
    value: None,
};

pub static VARS_NONS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chematised"),
        dictgen::InsensitiveStr::Ascii("chematiseds"),
        dictgen::InsensitiveStr::Ascii("chematized"),
        dictgen::InsensitiveStr::Ascii("chematizeds"),
        dictgen::InsensitiveStr::Ascii("ensitised"),
        dictgen::InsensitiveStr::Ascii("ensitiseds"),
        dictgen::InsensitiveStr::Ascii("ensitized"),
        dictgen::InsensitiveStr::Ascii("ensitizeds"),
        dictgen::InsensitiveStr::Ascii("pecialised"),
        dictgen::InsensitiveStr::Ascii("pecialiseds"),
        dictgen::InsensitiveStr::Ascii("pecialized"),
        dictgen::InsensitiveStr::Ascii("pecializeds"),
        dictgen::InsensitiveStr::Ascii("tandardised"),
        dictgen::InsensitiveStr::Ascii("tandardiseds"),
        dictgen::InsensitiveStr::Ascii("tandardized"),
        dictgen::InsensitiveStr::Ascii("tandardizeds"),
        dictgen::InsensitiveStr::Ascii("tylised"),
        dictgen::InsensitiveStr::Ascii("tyliseds"),
        dictgen::InsensitiveStr::Ascii("tylized"),
        dictgen::InsensitiveStr::Ascii("tylizeds"),
        dictgen::InsensitiveStr::Ascii("uccor"),
        dictgen::InsensitiveStr::Ascii("uccour"),
        dictgen::InsensitiveStr::Ascii("ympathiser"),
        dictgen::InsensitiveStr::Ascii("ympathisers"),
        dictgen::InsensitiveStr::Ascii("ympathizer"),
        dictgen::InsensitiveStr::Ascii("ympathizers"),
        dictgen::InsensitiveStr::Ascii("ynthesised"),
        dictgen::InsensitiveStr::Ascii("ynthesiseds"),
        dictgen::InsensitiveStr::Ascii("ynthesized"),
        dictgen::InsensitiveStr::Ascii("ynthesizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONSCHEMATIZED_3994267052359659886)],
        &[(0b10010, &ENTRY_NONSCHEMATIZEDS_8661436143168603744)],
        &[(0b01001, &ENTRY_NONSCHEMATIZED_3994267052359659886)],
        &[(0b01001, &ENTRY_NONSCHEMATIZEDS_8661436143168603744)],
        &[(0b10010, &ENTRY_NONSENSITIZED_16877012909978131488)],
        &[(0b10010, &ENTRY_NONSENSITIZEDS_6789040092514022355)],
        &[(0b01001, &ENTRY_NONSENSITIZED_16877012909978131488)],
        &[(0b01001, &ENTRY_NONSENSITIZEDS_6789040092514022355)],
        &[(0b10010, &ENTRY_NONSPECIALIZED_8228165017120418839)],
        &[(0b10010, &ENTRY_NONSPECIALIZEDS_13994167169575510057)],
        &[(0b01001, &ENTRY_NONSPECIALIZED_8228165017120418839)],
        &[(0b01001, &ENTRY_NONSPECIALIZEDS_13994167169575510057)],
        &[(0b10010, &ENTRY_NONSTANDARDIZED_10229344405930170027)],
        &[(0b10010, &ENTRY_NONSTANDARDIZEDS_108664461173603772)],
        &[(0b01001, &ENTRY_NONSTANDARDIZED_10229344405930170027)],
        &[(0b01001, &ENTRY_NONSTANDARDIZEDS_108664461173603772)],
        &[(0b10010, &ENTRY_NONSTYLIZED_11878483916633075909)],
        &[(0b10010, &ENTRY_NONSTYLIZEDS_10458605700653930018)],
        &[(0b01001, &ENTRY_NONSTYLIZED_11878483916633075909)],
        &[(0b01001, &ENTRY_NONSTYLIZEDS_10458605700653930018)],
        &[(0b00001, &ENTRY_NONSUCCOR_1588594977500462039)],
        &[(0b11010, &ENTRY_NONSUCCOR_1588594977500462039)],
        &[(0b10010, &ENTRY_NONSYMPATHIZER_10483044256492595530)],
        &[(0b10010, &ENTRY_NONSYMPATHIZERS_17703989460577560108)],
        &[(0b01001, &ENTRY_NONSYMPATHIZER_10483044256492595530)],
        &[(0b01001, &ENTRY_NONSYMPATHIZERS_17703989460577560108)],
        &[(0b10010, &ENTRY_NONSYNTHESIZED_1042593700062664928)],
        &[(0b10010, &ENTRY_NONSYNTHESIZEDS_16944487649499471214)],
        &[(0b01001, &ENTRY_NONSYNTHESIZED_1042593700062664928)],
        &[(0b01001, &ENTRY_NONSYNTHESIZEDS_16944487649499471214)],
    ],
    range: 5..=12,
};

static VARS_NONR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONR_CHILDREN),
    value: None,
};

pub static VARS_NONR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ationalised"),
        dictgen::InsensitiveStr::Ascii("ationaliseds"),
        dictgen::InsensitiveStr::Ascii("ationalized"),
        dictgen::InsensitiveStr::Ascii("ationalizeds"),
        dictgen::InsensitiveStr::Ascii("ealisation"),
        dictgen::InsensitiveStr::Ascii("ealisations"),
        dictgen::InsensitiveStr::Ascii("ealization"),
        dictgen::InsensitiveStr::Ascii("ealizations"),
        dictgen::InsensitiveStr::Ascii("ecognised"),
        dictgen::InsensitiveStr::Ascii("ecogniseds"),
        dictgen::InsensitiveStr::Ascii("ecognized"),
        dictgen::InsensitiveStr::Ascii("ecognizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONRATIONALIZED_3893321469385259750)],
        &[(0b10010, &ENTRY_NONRATIONALIZEDS_18331202286549559702)],
        &[(0b01001, &ENTRY_NONRATIONALIZED_3893321469385259750)],
        &[(0b01001, &ENTRY_NONRATIONALIZEDS_18331202286549559702)],
        &[(0b10010, &ENTRY_NONREALIZATION_13773240133730516692)],
        &[(0b10010, &ENTRY_NONREALIZATIONS_9898578985931514825)],
        &[(0b01001, &ENTRY_NONREALIZATION_13773240133730516692)],
        &[(0b01001, &ENTRY_NONREALIZATIONS_9898578985931514825)],
        &[(0b10010, &ENTRY_NONRECOGNIZED_5921644831413253839)],
        &[(0b10010, &ENTRY_NONRECOGNIZEDS_16936479754167964125)],
        &[(0b01001, &ENTRY_NONRECOGNIZED_5921644831413253839)],
        &[(0b01001, &ENTRY_NONRECOGNIZEDS_16936479754167964125)],
    ],
    range: 9..=12,
};

static VARS_NONP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONP_CHILDREN),
    value: None,
};

pub static VARS_NONP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arlor"),
        dictgen::InsensitiveStr::Ascii("arlors"),
        dictgen::InsensitiveStr::Ascii("arlour"),
        dictgen::InsensitiveStr::Ascii("arlours"),
        dictgen::InsensitiveStr::Ascii("enalised"),
        dictgen::InsensitiveStr::Ascii("enaliseds"),
        dictgen::InsensitiveStr::Ascii("enalized"),
        dictgen::InsensitiveStr::Ascii("enalizeds"),
        dictgen::InsensitiveStr::Ascii("hosphorised"),
        dictgen::InsensitiveStr::Ascii("hosphoriseds"),
        dictgen::InsensitiveStr::Ascii("hosphorized"),
        dictgen::InsensitiveStr::Ascii("hosphorizeds"),
        dictgen::InsensitiveStr::Ascii("olarisable"),
        dictgen::InsensitiveStr::Ascii("olarisables"),
        dictgen::InsensitiveStr::Ascii("olarised"),
        dictgen::InsensitiveStr::Ascii("olarising"),
        dictgen::InsensitiveStr::Ascii("olarisings"),
        dictgen::InsensitiveStr::Ascii("olarizable"),
        dictgen::InsensitiveStr::Ascii("olarizables"),
        dictgen::InsensitiveStr::Ascii("olarized"),
        dictgen::InsensitiveStr::Ascii("olarizing"),
        dictgen::InsensitiveStr::Ascii("olarizings"),
    ],
    values: &[
        &[(0b10001, &ENTRY_NONPARLOR_3613237573216443639)],
        &[(0b10001, &ENTRY_NONPARLORS_3253504681695686847)],
        &[(0b11010, &ENTRY_NONPARLOR_3613237573216443639)],
        &[(0b11010, &ENTRY_NONPARLORS_3253504681695686847)],
        &[(0b10010, &ENTRY_NONPENALIZED_15326313494103509289)],
        &[(0b10010, &ENTRY_NONPENALIZEDS_9532498621715242902)],
        &[(0b01001, &ENTRY_NONPENALIZED_15326313494103509289)],
        &[(0b01001, &ENTRY_NONPENALIZEDS_9532498621715242902)],
        &[(0b10010, &ENTRY_NONPHOSPHORIZED_3297546196819705879)],
        &[(0b10010, &ENTRY_NONPHOSPHORIZEDS_14940949194406297295)],
        &[(0b01001, &ENTRY_NONPHOSPHORIZED_3297546196819705879)],
        &[(0b01001, &ENTRY_NONPHOSPHORIZEDS_14940949194406297295)],
        &[(0b10010, &ENTRY_NONPOLARIZABLE_6616943736631357468)],
        &[(0b10010, &ENTRY_NONPOLARIZABLES_1893837066131069642)],
        &[(0b10010, &ENTRY_NONPOLARIZED_15305247587913084726)],
        &[(0b10010, &ENTRY_NONPOLARIZING_12712477465510092876)],
        &[(0b10010, &ENTRY_NONPOLARIZINGS_945000682506770397)],
        &[(0b01001, &ENTRY_NONPOLARIZABLE_6616943736631357468)],
        &[(0b01001, &ENTRY_NONPOLARIZABLES_1893837066131069642)],
        &[(0b01001, &ENTRY_NONPOLARIZED_15305247587913084726)],
        &[(0b01001, &ENTRY_NONPOLARIZING_12712477465510092876)],
        &[(0b01001, &ENTRY_NONPOLARIZINGS_945000682506770397)],
    ],
    range: 5..=12,
};

static VARS_NONO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONO_CHILDREN),
    value: None,
};

pub static VARS_NONO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecumenic"),
        dictgen::InsensitiveStr::Ascii("ecumenical"),
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("xidisable"),
        dictgen::InsensitiveStr::Ascii("xidisables"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidisings"),
        dictgen::InsensitiveStr::Ascii("xidizable"),
        dictgen::InsensitiveStr::Ascii("xidizables"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
        dictgen::InsensitiveStr::Ascii("xidizings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NONECUMENIC_10430255235079746866)],
        &[(0b11010, &ENTRY_NONECUMENICAL_6555547964120384081)],
        &[(0b10010, &ENTRY_NONORGANIZATION_5772986496320930609)],
        &[(0b10010, &ENTRY_NONORGANIZATIONS_12226603628664503880)],
        &[(0b01001, &ENTRY_NONORGANIZATION_5772986496320930609)],
        &[(0b01001, &ENTRY_NONORGANIZATIONS_12226603628664503880)],
        &[(0b10010, &ENTRY_NONOXIDIZABLE_17473608806098821507)],
        &[(0b10010, &ENTRY_NONOXIDIZABLES_9151331804972643676)],
        &[(0b10010, &ENTRY_NONOXIDIZING_16594445364457308574)],
        &[(0b10010, &ENTRY_NONOXIDIZINGS_14072069622049297509)],
        &[(0b01001, &ENTRY_NONOXIDIZABLE_17473608806098821507)],
        &[(0b01001, &ENTRY_NONOXIDIZABLES_9151331804972643676)],
        &[(0b01001, &ENTRY_NONOXIDIZING_16594445364457308574)],
        &[(0b01001, &ENTRY_NONOXIDIZINGS_14072069622049297509)],
    ],
    range: 8..=12,
};

static VARS_NONN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONN_CHILDREN),
    value: None,
};

pub static VARS_NONN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itrogenised"),
        dictgen::InsensitiveStr::Ascii("itrogeniseds"),
        dictgen::InsensitiveStr::Ascii("itrogenized"),
        dictgen::InsensitiveStr::Ascii("itrogenizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONNITROGENIZED_17798299881762861324)],
        &[(0b10010, &ENTRY_NONNITROGENIZEDS_725125946102913048)],
        &[(0b01001, &ENTRY_NONNITROGENIZED_17798299881762861324)],
        &[(0b01001, &ENTRY_NONNITROGENIZEDS_725125946102913048)],
    ],
    range: 11..=12,
};

static VARS_NONM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONM_CHILDREN),
    value: None,
};

pub static VARS_NONM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnetisable"),
        dictgen::InsensitiveStr::Ascii("agnetisables"),
        dictgen::InsensitiveStr::Ascii("agnetizable"),
        dictgen::InsensitiveStr::Ascii("agnetizables"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONMAGNETIZABLE_8373745056323317633)],
        &[(0b10010, &ENTRY_NONMAGNETIZABLES_2331502932397989651)],
        &[(0b01001, &ENTRY_NONMAGNETIZABLE_8373745056323317633)],
        &[(0b01001, &ENTRY_NONMAGNETIZABLES_2331502932397989651)],
    ],
    range: 11..=12,
};

static VARS_NONL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONL_CHILDREN),
    value: None,
};

pub static VARS_NONL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ocalised"),
        dictgen::InsensitiveStr::Ascii("ocaliseds"),
        dictgen::InsensitiveStr::Ascii("ocalized"),
        dictgen::InsensitiveStr::Ascii("ocalizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONLOCALIZED_11579777543530255255)],
        &[(0b10010, &ENTRY_NONLOCALIZEDS_12719123077518106411)],
        &[(0b01001, &ENTRY_NONLOCALIZED_11579777543530255255)],
        &[(0b01001, &ENTRY_NONLOCALIZEDS_12719123077518106411)],
    ],
    range: 8..=9,
};

static VARS_NONI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONI_CHILDREN),
    value: None,
};

pub static VARS_NONI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mmunised"),
        dictgen::InsensitiveStr::Ascii("mmuniseds"),
        dictgen::InsensitiveStr::Ascii("mmunized"),
        dictgen::InsensitiveStr::Ascii("mmunizeds"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniseds"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onisings"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizeds"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("onizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONIMMUNIZED_11380625262117673144)],
        &[(0b10010, &ENTRY_NONIMMUNIZEDS_17055826925642342411)],
        &[(0b01001, &ENTRY_NONIMMUNIZED_11380625262117673144)],
        &[(0b01001, &ENTRY_NONIMMUNIZEDS_17055826925642342411)],
        &[(0b10010, &ENTRY_NONIONIZED_5664164987361120441)],
        &[(0b10010, &ENTRY_NONIONIZEDS_15814635301210610227)],
        &[(0b10010, &ENTRY_NONIONIZING_13410823671297408563)],
        &[(0b10010, &ENTRY_NONIONIZINGS_5445645829414525604)],
        &[(0b01001, &ENTRY_NONIONIZED_5664164987361120441)],
        &[(0b01001, &ENTRY_NONIONIZEDS_15814635301210610227)],
        &[(0b01001, &ENTRY_NONIONIZING_13410823671297408563)],
        &[(0b01001, &ENTRY_NONIONIZINGS_5445645829414525604)],
    ],
    range: 6..=9,
};

static VARS_NONH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONH_CHILDREN),
    value: None,
};

pub static VARS_NONH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ydrolysable"),
        dictgen::InsensitiveStr::Ascii("ydrolysables"),
        dictgen::InsensitiveStr::Ascii("ydrolyzable"),
        dictgen::InsensitiveStr::Ascii("ydrolyzables"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NONHYDROLYZABLE_17480379980066317514)],
        &[(0b11010, &ENTRY_NONHYDROLYZABLES_6397422113685878077)],
        &[(0b00001, &ENTRY_NONHYDROLYZABLE_17480379980066317514)],
        &[(0b00001, &ENTRY_NONHYDROLYZABLES_6397422113685878077)],
    ],
    range: 11..=12,
};

static VARS_NONG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONG_CHILDREN),
    value: None,
};

pub static VARS_NONG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alvanised"),
        dictgen::InsensitiveStr::Ascii("alvaniseds"),
        dictgen::InsensitiveStr::Ascii("alvanized"),
        dictgen::InsensitiveStr::Ascii("alvanizeds"),
        dictgen::InsensitiveStr::Ascii("elatinising"),
        dictgen::InsensitiveStr::Ascii("elatinisings"),
        dictgen::InsensitiveStr::Ascii("elatinizing"),
        dictgen::InsensitiveStr::Ascii("elatinizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONGALVANIZED_1528399467041152337)],
        &[(0b10010, &ENTRY_NONGALVANIZEDS_3586524971953185452)],
        &[(0b01001, &ENTRY_NONGALVANIZED_1528399467041152337)],
        &[(0b01001, &ENTRY_NONGALVANIZEDS_3586524971953185452)],
        &[(0b10010, &ENTRY_NONGELATINIZING_14740547367338230024)],
        &[(0b10010, &ENTRY_NONGELATINIZINGS_14282185464661271575)],
        &[(0b01001, &ENTRY_NONGELATINIZING_14740547367338230024)],
        &[(0b01001, &ENTRY_NONGELATINIZINGS_14282185464661271575)],
    ],
    range: 9..=12,
};

static VARS_NONF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONF_CHILDREN),
    value: None,
};

pub static VARS_NONF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avorite"),
        dictgen::InsensitiveStr::Ascii("avorites"),
        dictgen::InsensitiveStr::Ascii("avourite"),
        dictgen::InsensitiveStr::Ascii("avourites"),
        dictgen::InsensitiveStr::Ascii("lavored"),
        dictgen::InsensitiveStr::Ascii("lavoured"),
        dictgen::InsensitiveStr::Ascii("ulfillment"),
        dictgen::InsensitiveStr::Ascii("ulfillments"),
        dictgen::InsensitiveStr::Ascii("ulfilment"),
        dictgen::InsensitiveStr::Ascii("ulfilments"),
    ],
    values: &[
        &[(0b10001, &ENTRY_NONFAVORITE_11831237877072163638)],
        &[(0b10001, &ENTRY_NONFAVORITES_1106515722402356082)],
        &[(0b11010, &ENTRY_NONFAVORITE_11831237877072163638)],
        &[(0b11010, &ENTRY_NONFAVORITES_1106515722402356082)],
        &[(0b10001, &ENTRY_NONFLAVORED_13086896565836313808)],
        &[(0b11010, &ENTRY_NONFLAVORED_13086896565836313808)],
        &[(0b00001, &ENTRY_NONFULFILLMENT_18150430088534928286)],
        &[(0b00001, &ENTRY_NONFULFILLMENTS_14148076271287069943)],
        &[(0b11010, &ENTRY_NONFULFILLMENT_18150430088534928286)],
        &[(0b11010, &ENTRY_NONFULFILLMENTS_14148076271287069943)],
    ],
    range: 7..=11,
};

static VARS_NONE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONE_CHILDREN),
    value: None,
};

pub static VARS_NONE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cumenic"),
        dictgen::InsensitiveStr::Ascii("cumenical"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("sthetical"),
        dictgen::InsensitiveStr::Ascii("sthetically"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NONECUMENIC_10430255235079746866)],
        &[(0b00001, &ENTRY_NONECUMENICAL_6555547964120384081)],
        &[(0b00001, &ENTRY_NONESTHETIC_1208061013275115321)],
        &[(0b00001, &ENTRY_NONESTHETICAL_10970138491194760413)],
        &[(0b00001, &ENTRY_NONESTHETICALLY_7037140941147025824)],
    ],
    range: 7..=11,
};

static VARS_NOND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOND_CHILDREN),
    value: None,
};

pub static VARS_NOND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emobilisation"),
        dictgen::InsensitiveStr::Ascii("emobilisations"),
        dictgen::InsensitiveStr::Ascii("emobilization"),
        dictgen::InsensitiveStr::Ascii("emobilizations"),
        dictgen::InsensitiveStr::Ascii("ialysing"),
        dictgen::InsensitiveStr::Ascii("ialysings"),
        dictgen::InsensitiveStr::Ascii("ialyzing"),
        dictgen::InsensitiveStr::Ascii("ialyzings"),
        dictgen::InsensitiveStr::Ascii("imensionalise"),
        dictgen::InsensitiveStr::Ascii("imensionalised"),
        dictgen::InsensitiveStr::Ascii("imensionalize"),
        dictgen::InsensitiveStr::Ascii("imensionalized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONDEMOBILIZATION_6660513033343601101)],
        &[(0b10010, &ENTRY_NONDEMOBILIZATIONS_15395019710602216415)],
        &[(0b01001, &ENTRY_NONDEMOBILIZATION_6660513033343601101)],
        &[(0b01001, &ENTRY_NONDEMOBILIZATIONS_15395019710602216415)],
        &[(0b11010, &ENTRY_NONDIALYZING_12492599878535719323)],
        &[(0b11010, &ENTRY_NONDIALYZINGS_1819109722847384802)],
        &[(0b00001, &ENTRY_NONDIALYZING_12492599878535719323)],
        &[(0b00001, &ENTRY_NONDIALYZINGS_1819109722847384802)],
        &[(0b10010, &ENTRY_NONDIMENSIONALIZE_272579664848581202)],
        &[(0b10010, &ENTRY_NONDIMENSIONALIZED_585813489289304634)],
        &[(0b01001, &ENTRY_NONDIMENSIONALIZE_272579664848581202)],
        &[(0b01001, &ENTRY_NONDIMENSIONALIZED_585813489289304634)],
    ],
    range: 8..=14,
};

static VARS_NONC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONC_CHILDREN),
    value: None,
};

pub static VARS_NONC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anonisation"),
        dictgen::InsensitiveStr::Ascii("anonisations"),
        dictgen::InsensitiveStr::Ascii("anonization"),
        dictgen::InsensitiveStr::Ascii("anonizations"),
        dictgen::InsensitiveStr::Ascii("artelised"),
        dictgen::InsensitiveStr::Ascii("arteliseds"),
        dictgen::InsensitiveStr::Ascii("artelized"),
        dictgen::InsensitiveStr::Ascii("artelizeds"),
        dictgen::InsensitiveStr::Ascii("atechisable"),
        dictgen::InsensitiveStr::Ascii("atechisables"),
        dictgen::InsensitiveStr::Ascii("atechizable"),
        dictgen::InsensitiveStr::Ascii("atechizables"),
        dictgen::InsensitiveStr::Ascii("ivilised"),
        dictgen::InsensitiveStr::Ascii("iviliseds"),
        dictgen::InsensitiveStr::Ascii("ivilized"),
        dictgen::InsensitiveStr::Ascii("ivilizeds"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olorabilities"),
        dictgen::InsensitiveStr::Ascii("olorability"),
        dictgen::InsensitiveStr::Ascii("olorable"),
        dictgen::InsensitiveStr::Ascii("olorableness"),
        dictgen::InsensitiveStr::Ascii("olorables"),
        dictgen::InsensitiveStr::Ascii("olorablies"),
        dictgen::InsensitiveStr::Ascii("olorably"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("olorer"),
        dictgen::InsensitiveStr::Ascii("olorers"),
        dictgen::InsensitiveStr::Ascii("olorfast"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olorings"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olourabilities"),
        dictgen::InsensitiveStr::Ascii("olourability"),
        dictgen::InsensitiveStr::Ascii("olourable"),
        dictgen::InsensitiveStr::Ascii("olourableness"),
        dictgen::InsensitiveStr::Ascii("olourables"),
        dictgen::InsensitiveStr::Ascii("olourablies"),
        dictgen::InsensitiveStr::Ascii("olourably"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olourer"),
        dictgen::InsensitiveStr::Ascii("olourers"),
        dictgen::InsensitiveStr::Ascii("olourfast"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olourings"),
        dictgen::InsensitiveStr::Ascii("olours"),
        dictgen::InsensitiveStr::Ascii("rystallisable"),
        dictgen::InsensitiveStr::Ascii("rystallisables"),
        dictgen::InsensitiveStr::Ascii("rystallised"),
        dictgen::InsensitiveStr::Ascii("rystalliseds"),
        dictgen::InsensitiveStr::Ascii("rystallising"),
        dictgen::InsensitiveStr::Ascii("rystallisings"),
        dictgen::InsensitiveStr::Ascii("rystallizable"),
        dictgen::InsensitiveStr::Ascii("rystallizables"),
        dictgen::InsensitiveStr::Ascii("rystallized"),
        dictgen::InsensitiveStr::Ascii("rystallizeds"),
        dictgen::InsensitiveStr::Ascii("rystallizing"),
        dictgen::InsensitiveStr::Ascii("rystallizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NONCANONIZATION_9329656712506044964)],
        &[(0b10010, &ENTRY_NONCANONIZATIONS_2832925098301127962)],
        &[(0b01001, &ENTRY_NONCANONIZATION_9329656712506044964)],
        &[(0b01001, &ENTRY_NONCANONIZATIONS_2832925098301127962)],
        &[(0b10010, &ENTRY_NONCARTELIZED_17883347662972154558)],
        &[(0b10010, &ENTRY_NONCARTELIZEDS_6224481369445744702)],
        &[(0b01001, &ENTRY_NONCARTELIZED_17883347662972154558)],
        &[(0b01001, &ENTRY_NONCARTELIZEDS_6224481369445744702)],
        &[(0b10010, &ENTRY_NONCATECHIZABLE_6818147642459223938)],
        &[(0b10010, &ENTRY_NONCATECHIZABLES_1199579288294266838)],
        &[(0b01001, &ENTRY_NONCATECHIZABLE_6818147642459223938)],
        &[(0b01001, &ENTRY_NONCATECHIZABLES_1199579288294266838)],
        &[(0b10010, &ENTRY_NONCIVILIZED_13516038359663624972)],
        &[(0b10010, &ENTRY_NONCIVILIZEDS_17407321793870403443)],
        &[(0b01001, &ENTRY_NONCIVILIZED_13516038359663624972)],
        &[(0b01001, &ENTRY_NONCIVILIZEDS_17407321793870403443)],
        &[(0b10001, &ENTRY_NONCOLOR_5467547533211492252)],
        &[(0b10001, &ENTRY_NONCOLORABILITIES_5039233789889736316)],
        &[(0b10001, &ENTRY_NONCOLORABILITY_7944763850740895408)],
        &[(0b10001, &ENTRY_NONCOLORABLE_12376456308958823880)],
        &[(0b10001, &ENTRY_NONCOLORABLENESS_1350486861839326465)],
        &[(0b10001, &ENTRY_NONCOLORABLES_7325099716303232276)],
        &[(0b10001, &ENTRY_NONCOLORABLIES_17005629715844099167)],
        &[(0b10001, &ENTRY_NONCOLORABLY_11724968183544783704)],
        &[(0b10001, &ENTRY_NONCOLORED_18370430231269037309)],
        &[(0b10001, &ENTRY_NONCOLORER_12435033179338868994)],
        &[(0b10001, &ENTRY_NONCOLORERS_17289446610135868746)],
        &[(0b10001, &ENTRY_NONCOLORFAST_12713143494448033510)],
        &[(0b10001, &ENTRY_NONCOLORING_2794432948648709598)],
        &[(0b10001, &ENTRY_NONCOLORINGS_10202008108226728546)],
        &[(0b10001, &ENTRY_NONCOLORS_4340941599912184140)],
        &[(0b11010, &ENTRY_NONCOLOR_5467547533211492252)],
        &[(0b11010, &ENTRY_NONCOLORABILITIES_5039233789889736316)],
        &[(0b11010, &ENTRY_NONCOLORABILITY_7944763850740895408)],
        &[(0b11010, &ENTRY_NONCOLORABLE_12376456308958823880)],
        &[(0b11010, &ENTRY_NONCOLORABLENESS_1350486861839326465)],
        &[(0b11010, &ENTRY_NONCOLORABLES_7325099716303232276)],
        &[(0b11010, &ENTRY_NONCOLORABLIES_17005629715844099167)],
        &[(0b11010, &ENTRY_NONCOLORABLY_11724968183544783704)],
        &[(0b11010, &ENTRY_NONCOLORED_18370430231269037309)],
        &[(0b11010, &ENTRY_NONCOLORER_12435033179338868994)],
        &[(0b11010, &ENTRY_NONCOLORERS_17289446610135868746)],
        &[(0b11010, &ENTRY_NONCOLORFAST_12713143494448033510)],
        &[(0b11010, &ENTRY_NONCOLORING_2794432948648709598)],
        &[(0b11010, &ENTRY_NONCOLORINGS_10202008108226728546)],
        &[(0b11010, &ENTRY_NONCOLORS_4340941599912184140)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZABLE_18330324258416108892)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZABLES_14085684766217602758)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZED_6387561216013434881)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZEDS_15212825180251803633)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZING_12893893992637420505)],
        &[(0b10010, &ENTRY_NONCRYSTALLIZINGS_12541253564548752834)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZABLE_18330324258416108892)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZABLES_14085684766217602758)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZED_6387561216013434881)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZEDS_15212825180251803633)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZING_12893893992637420505)],
        &[(0b01001, &ENTRY_NONCRYSTALLIZINGS_12541253564548752834)],
    ],
    range: 4..=14,
};

static VARS_NONA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NONA_CHILDREN),
    value: None,
};

pub static VARS_NONA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cknowledgement"),
        dictgen::InsensitiveStr::Ascii("cknowledgements"),
        dictgen::InsensitiveStr::Ascii("cknowledgment"),
        dictgen::InsensitiveStr::Ascii("cknowledgments"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("esthetical"),
        dictgen::InsensitiveStr::Ascii("esthetically"),
        dictgen::InsensitiveStr::Ascii("naemic"),
        dictgen::InsensitiveStr::Ascii("naesthetised"),
        dictgen::InsensitiveStr::Ascii("naesthetized"),
        dictgen::InsensitiveStr::Ascii("nemic"),
        dictgen::InsensitiveStr::Ascii("nesthetized"),
        dictgen::InsensitiveStr::Ascii("postatising"),
        dictgen::InsensitiveStr::Ascii("postatisings"),
        dictgen::InsensitiveStr::Ascii("postatizing"),
        dictgen::InsensitiveStr::Ascii("postatizings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NONACKNOWLEDGMENT_17338469733725282328)],
        &[(0b11010, &ENTRY_NONACKNOWLEDGMENTS_6963033554085365688)],
        &[(0b00001, &ENTRY_NONACKNOWLEDGMENT_17338469733725282328)],
        &[(0b00001, &ENTRY_NONACKNOWLEDGMENTS_6963033554085365688)],
        &[(0b11010, &ENTRY_NONESTHETIC_1208061013275115321)],
        &[(0b11010, &ENTRY_NONESTHETICAL_10970138491194760413)],
        &[(0b11010, &ENTRY_NONESTHETICALLY_7037140941147025824)],
        &[(0b11010, &ENTRY_NONANEMIC_973581033440143676)],
        &[(0b10010, &ENTRY_NONANESTHETIZED_12181903245888735253)],
        &[(0b01000, &ENTRY_NONANESTHETIZED_12181903245888735253)],
        &[(0b10001, &ENTRY_NONANEMIC_973581033440143676)],
        &[(0b00001, &ENTRY_NONANESTHETIZED_12181903245888735253)],
        &[(0b10010, &ENTRY_NONAPOSTATIZING_13854890087671968811)],
        &[(0b10010, &ENTRY_NONAPOSTATIZINGS_11913102920540330783)],
        &[(0b01001, &ENTRY_NONAPOSTATIZING_13854890087671968811)],
        &[(0b01001, &ENTRY_NONAPOSTATIZINGS_11913102920540330783)],
    ],
    range: 5..=15,
};

static VARS_NOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOM_CHILDREN),
    value: None,
};

pub static VARS_NOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adisation"),
        dictgen::InsensitiveStr::Ascii("adisations"),
        dictgen::InsensitiveStr::Ascii("adise"),
        dictgen::InsensitiveStr::Ascii("adised"),
        dictgen::InsensitiveStr::Ascii("adises"),
        dictgen::InsensitiveStr::Ascii("adising"),
        dictgen::InsensitiveStr::Ascii("adization"),
        dictgen::InsensitiveStr::Ascii("adizations"),
        dictgen::InsensitiveStr::Ascii("adize"),
        dictgen::InsensitiveStr::Ascii("adized"),
        dictgen::InsensitiveStr::Ascii("adizes"),
        dictgen::InsensitiveStr::Ascii("adizing"),
        dictgen::InsensitiveStr::Ascii("inalisation"),
        dictgen::InsensitiveStr::Ascii("inalisations"),
        dictgen::InsensitiveStr::Ascii("inalise"),
        dictgen::InsensitiveStr::Ascii("inalised"),
        dictgen::InsensitiveStr::Ascii("inalises"),
        dictgen::InsensitiveStr::Ascii("inalising"),
        dictgen::InsensitiveStr::Ascii("inalization"),
        dictgen::InsensitiveStr::Ascii("inalizations"),
        dictgen::InsensitiveStr::Ascii("inalize"),
        dictgen::InsensitiveStr::Ascii("inalized"),
        dictgen::InsensitiveStr::Ascii("inalizes"),
        dictgen::InsensitiveStr::Ascii("inalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NOMADIZATION_5090523635235285740)],
        &[(0b10010, &ENTRY_NOMADIZATIONS_1532482483093905182)],
        &[(0b10010, &ENTRY_NOMADIZE_5598669829068348168)],
        &[(0b10010, &ENTRY_NOMADIZED_3822219892599792814)],
        &[(0b10010, &ENTRY_NOMADIZES_3777017109817176072)],
        &[(0b10010, &ENTRY_NOMADIZING_7146960705248823561)],
        &[(0b01001, &ENTRY_NOMADIZATION_5090523635235285740)],
        &[(0b01001, &ENTRY_NOMADIZATIONS_1532482483093905182)],
        &[(0b01001, &ENTRY_NOMADIZE_5598669829068348168)],
        &[(0b01001, &ENTRY_NOMADIZED_3822219892599792814)],
        &[(0b01001, &ENTRY_NOMADIZES_3777017109817176072)],
        &[(0b01001, &ENTRY_NOMADIZING_7146960705248823561)],
        &[(0b10010, &ENTRY_NOMINALIZATION_7373401604669335356)],
        &[(0b10010, &ENTRY_NOMINALIZATIONS_16075171424950015123)],
        &[(0b10010, &ENTRY_NOMINALIZE_18405230656463200401)],
        &[(0b10010, &ENTRY_NOMINALIZED_2433981011225381934)],
        &[(0b10010, &ENTRY_NOMINALIZES_11706660389598219223)],
        &[(0b10010, &ENTRY_NOMINALIZING_5020709823407382402)],
        &[(0b01001, &ENTRY_NOMINALIZATION_7373401604669335356)],
        &[(0b01001, &ENTRY_NOMINALIZATIONS_16075171424950015123)],
        &[(0b01001, &ENTRY_NOMINALIZE_18405230656463200401)],
        &[(0b01001, &ENTRY_NOMINALIZED_2433981011225381934)],
        &[(0b01001, &ENTRY_NOMINALIZES_11706660389598219223)],
        &[(0b01001, &ENTRY_NOMINALIZING_5020709823407382402)],
    ],
    range: 5..=12,
};

static VARS_NOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOE_CHILDREN),
    value: None,
};

pub static VARS_NOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("mon")],
    values: &[&[(0b00001, &ENTRY_NOEMON_4394201647553814248)]],
    range: 3..=3,
};

static VARS_NOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOD_CHILDREN),
    value: None,
};

pub static VARS_NOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NODALIZE_12159557011270389807)],
        &[(0b10010, &ENTRY_NODALIZED_3309145199722035721)],
        &[(0b10010, &ENTRY_NODALIZES_4523050365791573110)],
        &[(0b10010, &ENTRY_NODALIZING_594971843591353653)],
        &[(0b01001, &ENTRY_NODALIZE_12159557011270389807)],
        &[(0b01001, &ENTRY_NODALIZED_3309145199722035721)],
        &[(0b01001, &ENTRY_NODALIZES_4523050365791573110)],
        &[(0b01001, &ENTRY_NODALIZING_594971843591353653)],
        &[(0b10010, &ENTRY_NODULIZE_15512444632148288619)],
        &[(0b10010, &ENTRY_NODULIZES_15781173051962781870)],
        &[(0b01001, &ENTRY_NODULIZE_15512444632148288619)],
        &[(0b01001, &ENTRY_NODULIZES_15781173051962781870)],
    ],
    range: 5..=7,
};

static VARS_NOA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NOA_CHILDREN),
    value: None,
};

pub static VARS_NOA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("emon")],
    values: &[&[(0b11010, &ENTRY_NOEMON_4394201647553814248)]],
    range: 4..=4,
};

static VARS_NI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NI_CHILDREN),
    value: None,
};

static VARS_NI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_NIC_NODE),
    None,
    Some(&VARS_NIE_NODE),
    None,
    Some(&VARS_NIG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NIP_NODE),
    None,
    None,
    None,
    Some(&VARS_NIT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_NIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIT_CHILDREN),
    value: None,
};

pub static VARS_NIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("ridisation"),
        dictgen::InsensitiveStr::Ascii("ridisations"),
        dictgen::InsensitiveStr::Ascii("ridise"),
        dictgen::InsensitiveStr::Ascii("ridises"),
        dictgen::InsensitiveStr::Ascii("ridization"),
        dictgen::InsensitiveStr::Ascii("ridizations"),
        dictgen::InsensitiveStr::Ascii("ridize"),
        dictgen::InsensitiveStr::Ascii("ridizes"),
        dictgen::InsensitiveStr::Ascii("rogenisation"),
        dictgen::InsensitiveStr::Ascii("rogenisations"),
        dictgen::InsensitiveStr::Ascii("rogenise"),
        dictgen::InsensitiveStr::Ascii("rogenised"),
        dictgen::InsensitiveStr::Ascii("rogenises"),
        dictgen::InsensitiveStr::Ascii("rogenising"),
        dictgen::InsensitiveStr::Ascii("rogenization"),
        dictgen::InsensitiveStr::Ascii("rogenizations"),
        dictgen::InsensitiveStr::Ascii("rogenize"),
        dictgen::InsensitiveStr::Ascii("rogenized"),
        dictgen::InsensitiveStr::Ascii("rogenizes"),
        dictgen::InsensitiveStr::Ascii("rogenizing"),
        dictgen::InsensitiveStr::Ascii("roglycerin"),
        dictgen::InsensitiveStr::Ascii("roglycerins"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NIGHT_14987521283100092371)],
        &[(0b00001, &ENTRY_NITER_4595235793148205687)],
        &[(0b00001, &ENTRY_NITERS_16573156181732403678)],
        &[(0b00001, &ENTRY_NIGHTS_5649998703829678181)],
        &[(0b11010, &ENTRY_NITER_4595235793148205687)],
        &[(0b11010, &ENTRY_NITERS_16573156181732403678)],
        &[(0b10010, &ENTRY_NITRIDIZATION_918307471678159167)],
        &[(0b10010, &ENTRY_NITRIDIZATIONS_14592567393639183415)],
        &[(0b10010, &ENTRY_NITRIDIZE_3954957349928071706)],
        &[(0b10010, &ENTRY_NITRIDIZES_12957996406667120411)],
        &[(0b01001, &ENTRY_NITRIDIZATION_918307471678159167)],
        &[(0b01001, &ENTRY_NITRIDIZATIONS_14592567393639183415)],
        &[(0b01001, &ENTRY_NITRIDIZE_3954957349928071706)],
        &[(0b01001, &ENTRY_NITRIDIZES_12957996406667120411)],
        &[(0b10010, &ENTRY_NITROGENIZATION_6151589440794972943)],
        &[(0b10010, &ENTRY_NITROGENIZATIONS_13338438366989347773)],
        &[(0b10010, &ENTRY_NITROGENIZE_16291478229609855163)],
        &[(0b10010, &ENTRY_NITROGENIZED_663379866855711530)],
        &[(0b10010, &ENTRY_NITROGENIZES_10797847040215921780)],
        &[(0b10010, &ENTRY_NITROGENIZING_10415054578773246298)],
        &[(0b01001, &ENTRY_NITROGENIZATION_6151589440794972943)],
        &[(0b01001, &ENTRY_NITROGENIZATIONS_13338438366989347773)],
        &[(0b01001, &ENTRY_NITROGENIZE_16291478229609855163)],
        &[(0b01001, &ENTRY_NITROGENIZED_663379866855711530)],
        &[(0b01001, &ENTRY_NITROGENIZES_10797847040215921780)],
        &[(0b01001, &ENTRY_NITROGENIZING_10415054578773246298)],
        &[(0b01001, &ENTRY_NITROGLYCERIN_4194108955596109456)],
        &[(0b01001, &ENTRY_NITROGLYCERINS_9899854160405414012)],
    ],
    range: 1..=13,
};

static VARS_NIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIP_CHILDREN),
    value: None,
};

pub static VARS_NIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ponise"),
        dictgen::InsensitiveStr::Ascii("ponises"),
        dictgen::InsensitiveStr::Ascii("ponize"),
        dictgen::InsensitiveStr::Ascii("ponizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NIPPONIZE_12246878098196982084)],
        &[(0b10010, &ENTRY_NIPPONIZES_10653241792290236524)],
        &[(0b01001, &ENTRY_NIPPONIZE_12246878098196982084)],
        &[(0b01001, &ENTRY_NIPPONIZES_10653241792290236524)],
    ],
    range: 6..=7,
};

static VARS_NIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIG_CHILDREN),
    value: None,
};

pub static VARS_NIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("gardise"),
        dictgen::InsensitiveStr::Ascii("gardised"),
        dictgen::InsensitiveStr::Ascii("gardises"),
        dictgen::InsensitiveStr::Ascii("gardising"),
        dictgen::InsensitiveStr::Ascii("gardize"),
        dictgen::InsensitiveStr::Ascii("gardized"),
        dictgen::InsensitiveStr::Ascii("gardizes"),
        dictgen::InsensitiveStr::Ascii("gardizing"),
        dictgen::InsensitiveStr::Ascii("htingalise"),
        dictgen::InsensitiveStr::Ascii("htingalises"),
        dictgen::InsensitiveStr::Ascii("htingalize"),
        dictgen::InsensitiveStr::Ascii("htingalizes"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NIGER_16049018308884616636)],
        &[(0b10010, &ENTRY_NIGGARDIZE_9495324465695451733)],
        &[(0b10010, &ENTRY_NIGGARDIZED_4556331947580220081)],
        &[(0b10010, &ENTRY_NIGGARDIZES_9198874245006328236)],
        &[(0b10010, &ENTRY_NIGGARDIZING_16355093388438094971)],
        &[(0b01001, &ENTRY_NIGGARDIZE_9495324465695451733)],
        &[(0b01001, &ENTRY_NIGGARDIZED_4556331947580220081)],
        &[(0b01001, &ENTRY_NIGGARDIZES_9198874245006328236)],
        &[(0b01001, &ENTRY_NIGGARDIZING_16355093388438094971)],
        &[(0b10010, &ENTRY_NIGHTINGALIZE_16413718384136912486)],
        &[(0b10010, &ENTRY_NIGHTINGALIZES_17007067660163973561)],
        &[(0b01001, &ENTRY_NIGHTINGALIZE_16413718384136912486)],
        &[(0b01001, &ENTRY_NIGHTINGALIZES_17007067660163973561)],
        &[(0b11010, &ENTRY_NIGER_16049018308884616636)],
    ],
    range: 2..=11,
};

static VARS_NIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIE_CHILDREN),
    value: None,
};

pub static VARS_NIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lloed"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NIELLED_8727132034411172563)],
        &[(0b11010, &ENTRY_NIELLED_8727132034411172563)],
    ],
    range: 4..=5,
};

static VARS_NIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NIC_CHILDREN),
    value: None,
};

pub static VARS_NIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("keled"),
        dictgen::InsensitiveStr::Ascii("keling"),
        dictgen::InsensitiveStr::Ascii("kelisation"),
        dictgen::InsensitiveStr::Ascii("kelisations"),
        dictgen::InsensitiveStr::Ascii("kelise"),
        dictgen::InsensitiveStr::Ascii("kelised"),
        dictgen::InsensitiveStr::Ascii("kelises"),
        dictgen::InsensitiveStr::Ascii("kelising"),
        dictgen::InsensitiveStr::Ascii("kelization"),
        dictgen::InsensitiveStr::Ascii("kelizations"),
        dictgen::InsensitiveStr::Ascii("kelize"),
        dictgen::InsensitiveStr::Ascii("kelized"),
        dictgen::InsensitiveStr::Ascii("kelizes"),
        dictgen::InsensitiveStr::Ascii("kelizing"),
        dictgen::InsensitiveStr::Ascii("kelled"),
        dictgen::InsensitiveStr::Ascii("kelling"),
        dictgen::InsensitiveStr::Ascii("otinise"),
        dictgen::InsensitiveStr::Ascii("otinised"),
        dictgen::InsensitiveStr::Ascii("otinises"),
        dictgen::InsensitiveStr::Ascii("otinising"),
        dictgen::InsensitiveStr::Ascii("otinize"),
        dictgen::InsensitiveStr::Ascii("otinized"),
        dictgen::InsensitiveStr::Ascii("otinizes"),
        dictgen::InsensitiveStr::Ascii("otinizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NICKELED_79394617530411001)],
        &[(0b00001, &ENTRY_NICKELING_16355800754604695372)],
        &[(0b10010, &ENTRY_NICKELIZATION_7986732926112090831)],
        &[(0b10010, &ENTRY_NICKELIZATIONS_12072034603175460493)],
        &[(0b10010, &ENTRY_NICKELIZE_1630536975440683928)],
        &[(0b10010, &ENTRY_NICKELIZED_8559493918735882579)],
        &[(0b10010, &ENTRY_NICKELIZES_2249308293478484590)],
        &[(0b10010, &ENTRY_NICKELIZING_6984381739697155028)],
        &[(0b01001, &ENTRY_NICKELIZATION_7986732926112090831)],
        &[(0b01001, &ENTRY_NICKELIZATIONS_12072034603175460493)],
        &[(0b01001, &ENTRY_NICKELIZE_1630536975440683928)],
        &[(0b01001, &ENTRY_NICKELIZED_8559493918735882579)],
        &[(0b01001, &ENTRY_NICKELIZES_2249308293478484590)],
        &[(0b01001, &ENTRY_NICKELIZING_6984381739697155028)],
        &[(0b11010, &ENTRY_NICKELED_79394617530411001)],
        &[(0b11010, &ENTRY_NICKELING_16355800754604695372)],
        &[(0b10010, &ENTRY_NICOTINIZE_3100679005969423604)],
        &[(0b10010, &ENTRY_NICOTINIZED_3516805459803022861)],
        &[(0b10010, &ENTRY_NICOTINIZES_10178848077465194416)],
        &[(0b10010, &ENTRY_NICOTINIZING_4147158847775395200)],
        &[(0b01001, &ENTRY_NICOTINIZE_3100679005969423604)],
        &[(0b01001, &ENTRY_NICOTINIZED_3516805459803022861)],
        &[(0b01001, &ENTRY_NICOTINIZES_10178848077465194416)],
        &[(0b01001, &ENTRY_NICOTINIZING_4147158847775395200)],
    ],
    range: 5..=11,
};

static VARS_NE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NE_CHILDREN),
    value: None,
};

static VARS_NE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_NEB_NODE),
    Some(&VARS_NEC_NODE),
    None,
    Some(&VARS_NEE_NODE),
    None,
    Some(&VARS_NEG_NODE),
    None,
    Some(&VARS_NEI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NEO_NODE),
    Some(&VARS_NEP_NODE),
    None,
    Some(&VARS_NER_NODE),
    Some(&VARS_NES_NODE),
    Some(&VARS_NET_NODE),
    Some(&VARS_NEU_NODE),
    Some(&VARS_NEV_NODE),
    Some(&VARS_NEW_NODE),
    None,
    None,
    None,
];

static VARS_NEW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEW_CHILDREN),
    value: None,
};

pub static VARS_NEW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("spaperised"),
        dictgen::InsensitiveStr::Ascii("spaperiseds"),
        dictgen::InsensitiveStr::Ascii("spaperized"),
        dictgen::InsensitiveStr::Ascii("spaperizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NEWMANIZE_16791511810220024252)],
        &[(0b10010, &ENTRY_NEWMANIZED_4174574011419796555)],
        &[(0b10010, &ENTRY_NEWMANIZES_2270185545274776704)],
        &[(0b10010, &ENTRY_NEWMANIZING_13785785322413856)],
        &[(0b01001, &ENTRY_NEWMANIZE_16791511810220024252)],
        &[(0b01001, &ENTRY_NEWMANIZED_4174574011419796555)],
        &[(0b01001, &ENTRY_NEWMANIZES_2270185545274776704)],
        &[(0b01001, &ENTRY_NEWMANIZING_13785785322413856)],
        &[(0b10010, &ENTRY_NEWSPAPERIZED_11230142060641724740)],
        &[(0b10010, &ENTRY_NEWSPAPERIZEDS_15846237086308072144)],
        &[(0b01001, &ENTRY_NEWSPAPERIZED_11230142060641724740)],
        &[(0b01001, &ENTRY_NEWSPAPERIZEDS_15846237086308072144)],
    ],
    range: 6..=11,
};

static VARS_NEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEV_CHILDREN),
    value: None,
};

pub static VARS_NEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("oid"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NEVES_16616131966640754583)],
        &[(0b00001, &ENTRY_NEVOID_9949690720573904750)],
    ],
    range: 2..=3,
};

static VARS_NEU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEU_CHILDREN),
    value: None,
};

pub static VARS_NEU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("repithelium"),
        dictgen::InsensitiveStr::Ascii("rocele"),
        dictgen::InsensitiveStr::Ascii("rocelian"),
        dictgen::InsensitiveStr::Ascii("rocoele"),
        dictgen::InsensitiveStr::Ascii("rocoelian"),
        dictgen::InsensitiveStr::Ascii("roepithelium"),
        dictgen::InsensitiveStr::Ascii("roticise"),
        dictgen::InsensitiveStr::Ascii("roticises"),
        dictgen::InsensitiveStr::Ascii("roticize"),
        dictgen::InsensitiveStr::Ascii("roticizes"),
        dictgen::InsensitiveStr::Ascii("tralisation"),
        dictgen::InsensitiveStr::Ascii("tralisations"),
        dictgen::InsensitiveStr::Ascii("tralise"),
        dictgen::InsensitiveStr::Ascii("tralised"),
        dictgen::InsensitiveStr::Ascii("traliser"),
        dictgen::InsensitiveStr::Ascii("tralisers"),
        dictgen::InsensitiveStr::Ascii("tralises"),
        dictgen::InsensitiveStr::Ascii("tralising"),
        dictgen::InsensitiveStr::Ascii("tralization"),
        dictgen::InsensitiveStr::Ascii("tralizations"),
        dictgen::InsensitiveStr::Ascii("tralize"),
        dictgen::InsensitiveStr::Ascii("tralized"),
        dictgen::InsensitiveStr::Ascii("tralizer"),
        dictgen::InsensitiveStr::Ascii("tralizers"),
        dictgen::InsensitiveStr::Ascii("tralizes"),
        dictgen::InsensitiveStr::Ascii("tralizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NEUREPITHELIUM_14522596466559359420)],
        &[(0b00001, &ENTRY_NEUROCELE_2114330714669438819)],
        &[(0b00001, &ENTRY_NEUROCELIAN_15377871369214360497)],
        &[(0b11010, &ENTRY_NEUROCELE_2114330714669438819)],
        &[(0b11010, &ENTRY_NEUROCELIAN_15377871369214360497)],
        &[(0b11010, &ENTRY_NEUREPITHELIUM_14522596466559359420)],
        &[(0b10010, &ENTRY_NEUROTICIZE_466460899480966122)],
        &[(0b10010, &ENTRY_NEUROTICIZES_10740992291539730077)],
        &[(0b01001, &ENTRY_NEUROTICIZE_466460899480966122)],
        &[(0b01001, &ENTRY_NEUROTICIZES_10740992291539730077)],
        &[(0b10010, &ENTRY_NEUTRALIZATION_13307816516042724010)],
        &[(0b10010, &ENTRY_NEUTRALIZATIONS_11864407426607384673)],
        &[(0b10010, &ENTRY_NEUTRALIZE_9266551307665544200)],
        &[(0b10010, &ENTRY_NEUTRALIZED_7515753592094537387)],
        &[(0b10010, &ENTRY_NEUTRALIZER_5629768343757464420)],
        &[(0b10010, &ENTRY_NEUTRALIZERS_12980250547097955526)],
        &[(0b10010, &ENTRY_NEUTRALIZES_9070000728487662463)],
        &[(0b10010, &ENTRY_NEUTRALIZING_13668110192955702906)],
        &[(0b01001, &ENTRY_NEUTRALIZATION_13307816516042724010)],
        &[(0b01001, &ENTRY_NEUTRALIZATIONS_11864407426607384673)],
        &[(0b01001, &ENTRY_NEUTRALIZE_9266551307665544200)],
        &[(0b01001, &ENTRY_NEUTRALIZED_7515753592094537387)],
        &[(0b01001, &ENTRY_NEUTRALIZER_5629768343757464420)],
        &[(0b01001, &ENTRY_NEUTRALIZERS_12980250547097955526)],
        &[(0b01001, &ENTRY_NEUTRALIZES_9070000728487662463)],
        &[(0b01001, &ENTRY_NEUTRALIZING_13668110192955702906)],
    ],
    range: 6..=12,
};

static VARS_NET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NET_CHILDREN),
    value: None,
};

pub static VARS_NET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("t"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NET_6832594804491488620)],
        &[(0b10010, &ENTRY_NETS_4660053216118079303)],
    ],
    range: 1..=2,
};

static VARS_NES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NES_CHILDREN),
    value: None,
};

pub static VARS_NES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("slerise"),
        dictgen::InsensitiveStr::Ascii("slerised"),
        dictgen::InsensitiveStr::Ascii("slerising"),
        dictgen::InsensitiveStr::Ascii("slerize"),
        dictgen::InsensitiveStr::Ascii("slerized"),
        dictgen::InsensitiveStr::Ascii("slerizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NESSLERIZE_6021492543047774975)],
        &[(0b10010, &ENTRY_NESSLERIZED_1142327510849274666)],
        &[(0b10010, &ENTRY_NESSLERIZING_15229221485702009447)],
        &[(0b01001, &ENTRY_NESSLERIZE_6021492543047774975)],
        &[(0b01001, &ENTRY_NESSLERIZED_1142327510849274666)],
        &[(0b01001, &ENTRY_NESSLERIZING_15229221485702009447)],
    ],
    range: 7..=9,
};

static VARS_NER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NER_CHILDREN),
    value: None,
};

pub static VARS_NER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b11010, &ENTRY_NEER_16355605982802851825)]],
    range: 1..=1,
};

static VARS_NEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEP_CHILDREN),
    value: None,
};

pub static VARS_NEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hrectomise"),
        dictgen::InsensitiveStr::Ascii("hrectomised"),
        dictgen::InsensitiveStr::Ascii("hrectomising"),
        dictgen::InsensitiveStr::Ascii("hrectomize"),
        dictgen::InsensitiveStr::Ascii("hrectomized"),
        dictgen::InsensitiveStr::Ascii("hrectomizing"),
        dictgen::InsensitiveStr::Ascii("hrocele"),
        dictgen::InsensitiveStr::Ascii("hrocoele"),
        dictgen::InsensitiveStr::Ascii("hrotomise"),
        dictgen::InsensitiveStr::Ascii("hrotomize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NEPHRECTOMIZE_6279842878206648888)],
        &[(0b10010, &ENTRY_NEPHRECTOMIZED_14132201559620241794)],
        &[(0b10010, &ENTRY_NEPHRECTOMIZING_3756994676330441516)],
        &[(0b01001, &ENTRY_NEPHRECTOMIZE_6279842878206648888)],
        &[(0b01001, &ENTRY_NEPHRECTOMIZED_14132201559620241794)],
        &[(0b01001, &ENTRY_NEPHRECTOMIZING_3756994676330441516)],
        &[(0b00001, &ENTRY_NEPHROCELE_10380393167970214732)],
        &[(0b11010, &ENTRY_NEPHROCELE_10380393167970214732)],
        &[(0b10010, &ENTRY_NEPHROTOMIZE_710864125503808530)],
        &[(0b01001, &ENTRY_NEPHROTOMIZE_710864125503808530)],
    ],
    range: 7..=12,
};

static VARS_NEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEO_CHILDREN),
    value: None,
};

pub static VARS_NEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("encephalon"),
        dictgen::InsensitiveStr::Ascii("gaea"),
        dictgen::InsensitiveStr::Ascii("gaeal"),
        dictgen::InsensitiveStr::Ascii("gaean"),
        dictgen::InsensitiveStr::Ascii("gaeic"),
        dictgen::InsensitiveStr::Ascii("gea"),
        dictgen::InsensitiveStr::Ascii("geal"),
        dictgen::InsensitiveStr::Ascii("gean"),
        dictgen::InsensitiveStr::Ascii("geic"),
        dictgen::InsensitiveStr::Ascii("logisation"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logization"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("paganise"),
        dictgen::InsensitiveStr::Ascii("paganised"),
        dictgen::InsensitiveStr::Ascii("paganises"),
        dictgen::InsensitiveStr::Ascii("paganising"),
        dictgen::InsensitiveStr::Ascii("paganize"),
        dictgen::InsensitiveStr::Ascii("paganized"),
        dictgen::InsensitiveStr::Ascii("paganizes"),
        dictgen::InsensitiveStr::Ascii("paganizing"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terised"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terising"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terized"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("terizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NEENCEPHALON_14187652725536427083)],
        &[(0b11010, &ENTRY_NEOGEA_9787783155573130223)],
        &[(0b11010, &ENTRY_NEOGEAL_9764750913530112822)],
        &[(0b11010, &ENTRY_NEOGEAN_16331008238049777934)],
        &[(0b11010, &ENTRY_NEOGEIC_15111494082202179702)],
        &[(0b00001, &ENTRY_NEOGEA_9787783155573130223)],
        &[(0b00001, &ENTRY_NEOGEAL_9764750913530112822)],
        &[(0b00001, &ENTRY_NEOGEAN_16331008238049777934)],
        &[(0b00001, &ENTRY_NEOGEIC_15111494082202179702)],
        &[(0b10010, &ENTRY_NEOLOGIZATION_6696109817982643101)],
        &[(0b10010, &ENTRY_NEOLOGIZE_10244910510400951586)],
        &[(0b10010, &ENTRY_NEOLOGIZED_5268649546982345213)],
        &[(0b10010, &ENTRY_NEOLOGIZES_6887678104239943468)],
        &[(0b10010, &ENTRY_NEOLOGIZING_11083245698014675505)],
        &[(0b01001, &ENTRY_NEOLOGIZATION_6696109817982643101)],
        &[(0b01001, &ENTRY_NEOLOGIZE_10244910510400951586)],
        &[(0b01001, &ENTRY_NEOLOGIZED_5268649546982345213)],
        &[(0b01001, &ENTRY_NEOLOGIZES_6887678104239943468)],
        &[(0b01001, &ENTRY_NEOLOGIZING_11083245698014675505)],
        &[(0b10010, &ENTRY_NEOPAGANIZE_11390513205223371956)],
        &[(0b10010, &ENTRY_NEOPAGANIZED_4855624186586381064)],
        &[(0b10010, &ENTRY_NEOPAGANIZES_10627781041046310586)],
        &[(0b10010, &ENTRY_NEOPAGANIZING_13517084271492557770)],
        &[(0b01001, &ENTRY_NEOPAGANIZE_11390513205223371956)],
        &[(0b01001, &ENTRY_NEOPAGANIZED_4855624186586381064)],
        &[(0b01001, &ENTRY_NEOPAGANIZES_10627781041046310586)],
        &[(0b01001, &ENTRY_NEOPAGANIZING_13517084271492557770)],
        &[(0b10010, &ENTRY_NEOTERIZE_18178784763221053575)],
        &[(0b10010, &ENTRY_NEOTERIZED_8566631801629908756)],
        &[(0b10010, &ENTRY_NEOTERIZES_11131918151181201147)],
        &[(0b10010, &ENTRY_NEOTERIZING_1718278886797679099)],
        &[(0b01001, &ENTRY_NEOTERIZE_18178784763221053575)],
        &[(0b01001, &ENTRY_NEOTERIZED_8566631801629908756)],
        &[(0b01001, &ENTRY_NEOTERIZES_11131918151181201147)],
        &[(0b01001, &ENTRY_NEOTERIZING_1718278886797679099)],
    ],
    range: 3..=10,
};

static VARS_NEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEI_CHILDREN),
    value: None,
};

pub static VARS_NEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ghbor"),
        dictgen::InsensitiveStr::Ascii("ghbored"),
        dictgen::InsensitiveStr::Ascii("ghborer"),
        dictgen::InsensitiveStr::Ascii("ghborers"),
        dictgen::InsensitiveStr::Ascii("ghboress"),
        dictgen::InsensitiveStr::Ascii("ghborhood"),
        dictgen::InsensitiveStr::Ascii("ghborhoods"),
        dictgen::InsensitiveStr::Ascii("ghboring"),
        dictgen::InsensitiveStr::Ascii("ghborings"),
        dictgen::InsensitiveStr::Ascii("ghborless"),
        dictgen::InsensitiveStr::Ascii("ghborlesser"),
        dictgen::InsensitiveStr::Ascii("ghborlesses"),
        dictgen::InsensitiveStr::Ascii("ghborlessest"),
        dictgen::InsensitiveStr::Ascii("ghborlier"),
        dictgen::InsensitiveStr::Ascii("ghborliest"),
        dictgen::InsensitiveStr::Ascii("ghborlike"),
        dictgen::InsensitiveStr::Ascii("ghborlikes"),
        dictgen::InsensitiveStr::Ascii("ghborliness"),
        dictgen::InsensitiveStr::Ascii("ghborlinesses"),
        dictgen::InsensitiveStr::Ascii("ghborly"),
        dictgen::InsensitiveStr::Ascii("ghbors"),
        dictgen::InsensitiveStr::Ascii("ghborship"),
        dictgen::InsensitiveStr::Ascii("ghborships"),
        dictgen::InsensitiveStr::Ascii("ghbour"),
        dictgen::InsensitiveStr::Ascii("ghboured"),
        dictgen::InsensitiveStr::Ascii("ghbourer"),
        dictgen::InsensitiveStr::Ascii("ghbourers"),
        dictgen::InsensitiveStr::Ascii("ghbouress"),
        dictgen::InsensitiveStr::Ascii("ghbourhood"),
        dictgen::InsensitiveStr::Ascii("ghbourhoods"),
        dictgen::InsensitiveStr::Ascii("ghbouring"),
        dictgen::InsensitiveStr::Ascii("ghbourings"),
        dictgen::InsensitiveStr::Ascii("ghbourless"),
        dictgen::InsensitiveStr::Ascii("ghbourlesser"),
        dictgen::InsensitiveStr::Ascii("ghbourlesses"),
        dictgen::InsensitiveStr::Ascii("ghbourlessest"),
        dictgen::InsensitiveStr::Ascii("ghbourlier"),
        dictgen::InsensitiveStr::Ascii("ghbourliest"),
        dictgen::InsensitiveStr::Ascii("ghbourlike"),
        dictgen::InsensitiveStr::Ascii("ghbourlikes"),
        dictgen::InsensitiveStr::Ascii("ghbourliness"),
        dictgen::InsensitiveStr::Ascii("ghbourlinesses"),
        dictgen::InsensitiveStr::Ascii("ghbourly"),
        dictgen::InsensitiveStr::Ascii("ghbours"),
        dictgen::InsensitiveStr::Ascii("ghbourship"),
        dictgen::InsensitiveStr::Ascii("ghbourships"),
    ],
    values: &[
        &[(0b11001, &ENTRY_NEIGHBOR_15130524761824710478)],
        &[(0b11001, &ENTRY_NEIGHBORED_2912814830482160893)],
        &[(0b10001, &ENTRY_NEIGHBORER_17586595116108205470)],
        &[(0b10001, &ENTRY_NEIGHBORERS_12831530063051977068)],
        &[(0b10001, &ENTRY_NEIGHBORESS_15381332977975372239)],
        &[(0b11001, &ENTRY_NEIGHBORHOOD_6116964286671033961)],
        &[(0b11001, &ENTRY_NEIGHBORHOODS_4358229838170310740)],
        &[(0b11001, &ENTRY_NEIGHBORING_9395767208036463789)],
        &[(0b11001, &ENTRY_NEIGHBORINGS_8765293309645015940)],
        &[(0b10001, &ENTRY_NEIGHBORLESS_72307819983757150)],
        &[(0b10001, &ENTRY_NEIGHBORLESSER_3537443539054487075)],
        &[(0b10001, &ENTRY_NEIGHBORLESSES_10894054956429025321)],
        &[(0b10001, &ENTRY_NEIGHBORLESSEST_12407898951734692417)],
        &[(0b11001, &ENTRY_NEIGHBORLIER_16947297940053670257)],
        &[(0b11001, &ENTRY_NEIGHBORLIEST_494551750304702586)],
        &[(0b10001, &ENTRY_NEIGHBORLIKE_6526293139640864889)],
        &[(0b10001, &ENTRY_NEIGHBORLIKES_6802496983970655984)],
        &[(0b10001, &ENTRY_NEIGHBORLINESS_10350752649415350302)],
        &[(0b10001, &ENTRY_NEIGHBORLINESSES_9492824420251662178)],
        &[(0b11001, &ENTRY_NEIGHBORLY_3913130996486820034)],
        &[(0b11001, &ENTRY_NEIGHBORS_7906396218629885032)],
        &[(0b10001, &ENTRY_NEIGHBORSHIP_7342829838404157081)],
        &[(0b10001, &ENTRY_NEIGHBORSHIPS_16234487844856724822)],
        &[(0b11010, &ENTRY_NEIGHBOR_15130524761824710478)],
        &[(0b11010, &ENTRY_NEIGHBORED_2912814830482160893)],
        &[(0b11010, &ENTRY_NEIGHBORER_17586595116108205470)],
        &[(0b11010, &ENTRY_NEIGHBORERS_12831530063051977068)],
        &[(0b11010, &ENTRY_NEIGHBORESS_15381332977975372239)],
        &[(0b11010, &ENTRY_NEIGHBORHOOD_6116964286671033961)],
        &[(0b11010, &ENTRY_NEIGHBORHOODS_4358229838170310740)],
        &[(0b11010, &ENTRY_NEIGHBORING_9395767208036463789)],
        &[(0b11010, &ENTRY_NEIGHBORINGS_8765293309645015940)],
        &[(0b11010, &ENTRY_NEIGHBORLESS_72307819983757150)],
        &[(0b11010, &ENTRY_NEIGHBORLESSER_3537443539054487075)],
        &[(0b11010, &ENTRY_NEIGHBORLESSES_10894054956429025321)],
        &[(0b11010, &ENTRY_NEIGHBORLESSEST_12407898951734692417)],
        &[(0b11010, &ENTRY_NEIGHBORLIER_16947297940053670257)],
        &[(0b11010, &ENTRY_NEIGHBORLIEST_494551750304702586)],
        &[(0b11010, &ENTRY_NEIGHBORLIKE_6526293139640864889)],
        &[(0b11010, &ENTRY_NEIGHBORLIKES_6802496983970655984)],
        &[(0b11010, &ENTRY_NEIGHBORLINESS_10350752649415350302)],
        &[(0b11010, &ENTRY_NEIGHBORLINESSES_9492824420251662178)],
        &[(0b11010, &ENTRY_NEIGHBORLY_3913130996486820034)],
        &[(0b11010, &ENTRY_NEIGHBORS_7906396218629885032)],
        &[(0b11010, &ENTRY_NEIGHBORSHIP_7342829838404157081)],
        &[(0b11010, &ENTRY_NEIGHBORSHIPS_16234487844856724822)],
    ],
    range: 5..=14,
};

static VARS_NEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEG_CHILDREN),
    value: None,
};

pub static VARS_NEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lig"),
        dictgen::InsensitiveStr::Ascii("ligs"),
        dictgen::InsensitiveStr::Ascii("ritise"),
        dictgen::InsensitiveStr::Ascii("ritised"),
        dictgen::InsensitiveStr::Ascii("ritising"),
        dictgen::InsensitiveStr::Ascii("ritize"),
        dictgen::InsensitiveStr::Ascii("ritized"),
        dictgen::InsensitiveStr::Ascii("ritizing"),
        dictgen::InsensitiveStr::Ascii("roisation"),
        dictgen::InsensitiveStr::Ascii("roisations"),
        dictgen::InsensitiveStr::Ascii("roise"),
        dictgen::InsensitiveStr::Ascii("roised"),
        dictgen::InsensitiveStr::Ascii("roises"),
        dictgen::InsensitiveStr::Ascii("roising"),
        dictgen::InsensitiveStr::Ascii("roization"),
        dictgen::InsensitiveStr::Ascii("roizations"),
        dictgen::InsensitiveStr::Ascii("roize"),
        dictgen::InsensitiveStr::Ascii("roized"),
        dictgen::InsensitiveStr::Ascii("roizes"),
        dictgen::InsensitiveStr::Ascii("roizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NEGLIGEE_14354404705992424135)],
        &[(0b00001, &ENTRY_NEGLIGEES_10333702368994566972)],
        &[(0b10010, &ENTRY_NEGRITIZE_11369199419932636812)],
        &[(0b10010, &ENTRY_NEGRITIZED_10107617084750061015)],
        &[(0b10010, &ENTRY_NEGRITIZING_9349037264957140834)],
        &[(0b01001, &ENTRY_NEGRITIZE_11369199419932636812)],
        &[(0b01001, &ENTRY_NEGRITIZED_10107617084750061015)],
        &[(0b01001, &ENTRY_NEGRITIZING_9349037264957140834)],
        &[(0b10010, &ENTRY_NEGROIZATION_8048386169561232415)],
        &[(0b10010, &ENTRY_NEGROIZATIONS_3358353493795107975)],
        &[(0b10010, &ENTRY_NEGROIZE_17106092591780439486)],
        &[(0b10010, &ENTRY_NEGROIZED_16504978671697700797)],
        &[(0b10010, &ENTRY_NEGROIZES_17958324040947623577)],
        &[(0b10010, &ENTRY_NEGROIZING_13585645509887530683)],
        &[(0b01001, &ENTRY_NEGROIZATION_8048386169561232415)],
        &[(0b01001, &ENTRY_NEGROIZATIONS_3358353493795107975)],
        &[(0b01001, &ENTRY_NEGROIZE_17106092591780439486)],
        &[(0b01001, &ENTRY_NEGROIZED_16504978671697700797)],
        &[(0b01001, &ENTRY_NEGROIZES_17958324040947623577)],
        &[(0b01001, &ENTRY_NEGROIZING_13585645509887530683)],
    ],
    range: 3..=10,
};

static VARS_NEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEE_CHILDREN),
    value: None,
};

pub static VARS_NEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bor"),
        dictgen::InsensitiveStr::Ascii("bour"),
        dictgen::InsensitiveStr::Ascii("ncephalon"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b00001, &ENTRY_NEEBOR_16062401850643862888)],
        &[(0b11010, &ENTRY_NEEBOR_16062401850643862888)],
        &[(0b00001, &ENTRY_NEENCEPHALON_14187652725536427083)],
        &[(0b00001, &ENTRY_NEER_16355605982802851825)],
    ],
    range: 1..=9,
};

static VARS_NEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEC_CHILDREN),
    value: None,
};

pub static VARS_NEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("raemia"),
        dictgen::InsensitiveStr::Ascii("remia"),
        dictgen::InsensitiveStr::Ascii("rotise"),
        dictgen::InsensitiveStr::Ascii("rotised"),
        dictgen::InsensitiveStr::Ascii("rotises"),
        dictgen::InsensitiveStr::Ascii("rotising"),
        dictgen::InsensitiveStr::Ascii("rotize"),
        dictgen::InsensitiveStr::Ascii("rotized"),
        dictgen::InsensitiveStr::Ascii("rotizes"),
        dictgen::InsensitiveStr::Ascii("rotizing"),
        dictgen::InsensitiveStr::Ascii("tarise"),
        dictgen::InsensitiveStr::Ascii("tarised"),
        dictgen::InsensitiveStr::Ascii("tarises"),
        dictgen::InsensitiveStr::Ascii("tarising"),
        dictgen::InsensitiveStr::Ascii("tarize"),
        dictgen::InsensitiveStr::Ascii("tarized"),
        dictgen::InsensitiveStr::Ascii("tarizes"),
        dictgen::InsensitiveStr::Ascii("tarizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NECREMIA_8881652998895232422)],
        &[(0b10001, &ENTRY_NECREMIA_8881652998895232422)],
        &[(0b10010, &ENTRY_NECROTIZE_299626418760955858)],
        &[(0b10010, &ENTRY_NECROTIZED_8062669837805248834)],
        &[(0b10010, &ENTRY_NECROTIZES_4216987069255944678)],
        &[(0b10010, &ENTRY_NECROTIZING_3362205721608894420)],
        &[(0b01001, &ENTRY_NECROTIZE_299626418760955858)],
        &[(0b01001, &ENTRY_NECROTIZED_8062669837805248834)],
        &[(0b01001, &ENTRY_NECROTIZES_4216987069255944678)],
        &[(0b01001, &ENTRY_NECROTIZING_3362205721608894420)],
        &[(0b10010, &ENTRY_NECTARIZE_9385124234314658628)],
        &[(0b10010, &ENTRY_NECTARIZED_7371569570789937934)],
        &[(0b10010, &ENTRY_NECTARIZES_1030386415882779696)],
        &[(0b10010, &ENTRY_NECTARIZING_4549880248278053146)],
        &[(0b01001, &ENTRY_NECTARIZE_9385124234314658628)],
        &[(0b01001, &ENTRY_NECTARIZED_7371569570789937934)],
        &[(0b01001, &ENTRY_NECTARIZES_1030386415882779696)],
        &[(0b01001, &ENTRY_NECTARIZING_4549880248278053146)],
    ],
    range: 5..=8,
};

static VARS_NEB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NEB_CHILDREN),
    value: None,
};

pub static VARS_NEB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ulisation"),
        dictgen::InsensitiveStr::Ascii("ulisations"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulised"),
        dictgen::InsensitiveStr::Ascii("uliser"),
        dictgen::InsensitiveStr::Ascii("ulisers"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulising"),
        dictgen::InsensitiveStr::Ascii("ulization"),
        dictgen::InsensitiveStr::Ascii("ulizations"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulized"),
        dictgen::InsensitiveStr::Ascii("ulizer"),
        dictgen::InsensitiveStr::Ascii("ulizers"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
        dictgen::InsensitiveStr::Ascii("ulizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NEBULARIZATION_1442476582031071023)],
        &[(0b10010, &ENTRY_NEBULARIZATIONS_1344096708238928724)],
        &[(0b10010, &ENTRY_NEBULARIZE_17777801976084935302)],
        &[(0b10010, &ENTRY_NEBULARIZES_8057540089264214439)],
        &[(0b01001, &ENTRY_NEBULARIZATION_1442476582031071023)],
        &[(0b01001, &ENTRY_NEBULARIZATIONS_1344096708238928724)],
        &[(0b01001, &ENTRY_NEBULARIZE_17777801976084935302)],
        &[(0b01001, &ENTRY_NEBULARIZES_8057540089264214439)],
        &[(0b10010, &ENTRY_NEBULIZATION_7326585684837997543)],
        &[(0b10010, &ENTRY_NEBULIZATIONS_14508912644751833294)],
        &[(0b10010, &ENTRY_NEBULIZE_7330295268077282680)],
        &[(0b10010, &ENTRY_NEBULIZED_12800682353119589181)],
        &[(0b10010, &ENTRY_NEBULIZER_7516977077379919232)],
        &[(0b10010, &ENTRY_NEBULIZERS_5318245889291026270)],
        &[(0b10010, &ENTRY_NEBULIZES_12715200246675490972)],
        &[(0b10010, &ENTRY_NEBULIZING_7453907449334963722)],
        &[(0b01001, &ENTRY_NEBULIZATION_7326585684837997543)],
        &[(0b01001, &ENTRY_NEBULIZATIONS_14508912644751833294)],
        &[(0b01001, &ENTRY_NEBULIZE_7330295268077282680)],
        &[(0b01001, &ENTRY_NEBULIZED_12800682353119589181)],
        &[(0b01001, &ENTRY_NEBULIZER_7516977077379919232)],
        &[(0b01001, &ENTRY_NEBULIZERS_5318245889291026270)],
        &[(0b01001, &ENTRY_NEBULIZES_12715200246675490972)],
        &[(0b01001, &ENTRY_NEBULIZING_7453907449334963722)],
    ],
    range: 5..=12,
};

static VARS_NA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_NA_CHILDREN),
    value: None,
};

static VARS_NA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_NAB_NODE),
    None,
    None,
    Some(&VARS_NAE_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_NAK_NODE),
    None,
    None,
    Some(&VARS_NAN_NODE),
    None,
    Some(&VARS_NAP_NODE),
    None,
    Some(&VARS_NAR_NODE),
    Some(&VARS_NAS_NODE),
    Some(&VARS_NAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_NAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAT_CHILDREN),
    value: None,
};

pub static VARS_NAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ionalisation"),
        dictgen::InsensitiveStr::Ascii("ionalisations"),
        dictgen::InsensitiveStr::Ascii("ionalise"),
        dictgen::InsensitiveStr::Ascii("ionalised"),
        dictgen::InsensitiveStr::Ascii("ionaliser"),
        dictgen::InsensitiveStr::Ascii("ionalisers"),
        dictgen::InsensitiveStr::Ascii("ionalises"),
        dictgen::InsensitiveStr::Ascii("ionalising"),
        dictgen::InsensitiveStr::Ascii("ionalization"),
        dictgen::InsensitiveStr::Ascii("ionalizations"),
        dictgen::InsensitiveStr::Ascii("ionalize"),
        dictgen::InsensitiveStr::Ascii("ionalized"),
        dictgen::InsensitiveStr::Ascii("ionalizer"),
        dictgen::InsensitiveStr::Ascii("ionalizers"),
        dictgen::InsensitiveStr::Ascii("ionalizes"),
        dictgen::InsensitiveStr::Ascii("ionalizing"),
        dictgen::InsensitiveStr::Ascii("uralisation"),
        dictgen::InsensitiveStr::Ascii("uralisations"),
        dictgen::InsensitiveStr::Ascii("uralise"),
        dictgen::InsensitiveStr::Ascii("uralised"),
        dictgen::InsensitiveStr::Ascii("uraliser"),
        dictgen::InsensitiveStr::Ascii("uralisers"),
        dictgen::InsensitiveStr::Ascii("uralises"),
        dictgen::InsensitiveStr::Ascii("uralising"),
        dictgen::InsensitiveStr::Ascii("uralization"),
        dictgen::InsensitiveStr::Ascii("uralizations"),
        dictgen::InsensitiveStr::Ascii("uralize"),
        dictgen::InsensitiveStr::Ascii("uralized"),
        dictgen::InsensitiveStr::Ascii("uralizer"),
        dictgen::InsensitiveStr::Ascii("uralizers"),
        dictgen::InsensitiveStr::Ascii("uralizes"),
        dictgen::InsensitiveStr::Ascii("uralizing"),
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NATIONALIZATION_5030239828494323305)],
        &[(0b10010, &ENTRY_NATIONALIZATIONS_14362871039185775397)],
        &[(0b10010, &ENTRY_NATIONALIZE_3677566152660435624)],
        &[(0b10010, &ENTRY_NATIONALIZED_15312908113627604965)],
        &[(0b10010, &ENTRY_NATIONALIZER_456791214714633888)],
        &[(0b10010, &ENTRY_NATIONALIZERS_9687329251077026772)],
        &[(0b10010, &ENTRY_NATIONALIZES_7334356969812316358)],
        &[(0b10010, &ENTRY_NATIONALIZING_17435368859041352405)],
        &[(0b01001, &ENTRY_NATIONALIZATION_5030239828494323305)],
        &[(0b01001, &ENTRY_NATIONALIZATIONS_14362871039185775397)],
        &[(0b01001, &ENTRY_NATIONALIZE_3677566152660435624)],
        &[(0b01001, &ENTRY_NATIONALIZED_15312908113627604965)],
        &[(0b01001, &ENTRY_NATIONALIZER_456791214714633888)],
        &[(0b01001, &ENTRY_NATIONALIZERS_9687329251077026772)],
        &[(0b01001, &ENTRY_NATIONALIZES_7334356969812316358)],
        &[(0b01001, &ENTRY_NATIONALIZING_17435368859041352405)],
        &[(0b10010, &ENTRY_NATURALIZATION_13649717526845265802)],
        &[(0b10010, &ENTRY_NATURALIZATIONS_15254179979354541579)],
        &[(0b10010, &ENTRY_NATURALIZE_9796455531783123727)],
        &[(0b10010, &ENTRY_NATURALIZED_4933991430461897776)],
        &[(0b10010, &ENTRY_NATURALIZER_8651942411110778048)],
        &[(0b10010, &ENTRY_NATURALIZERS_3438182303380931640)],
        &[(0b10010, &ENTRY_NATURALIZES_11977053730621144210)],
        &[(0b10010, &ENTRY_NATURALIZING_3716716428508245601)],
        &[(0b01001, &ENTRY_NATURALIZATION_13649717526845265802)],
        &[(0b01001, &ENTRY_NATURALIZATIONS_15254179979354541579)],
        &[(0b01001, &ENTRY_NATURALIZE_9796455531783123727)],
        &[(0b01001, &ENTRY_NATURALIZED_4933991430461897776)],
        &[(0b01001, &ENTRY_NATURALIZER_8651942411110778048)],
        &[(0b01001, &ENTRY_NATURALIZERS_3438182303380931640)],
        &[(0b01001, &ENTRY_NATURALIZES_11977053730621144210)],
        &[(0b01001, &ENTRY_NATURALIZING_3716716428508245601)],
        &[(0b10010, &ENTRY_NATURIZE_5972806093795696733)],
        &[(0b10010, &ENTRY_NATURIZES_9658576256155624005)],
        &[(0b01001, &ENTRY_NATURIZE_5972806093795696733)],
        &[(0b01001, &ENTRY_NATURIZES_9658576256155624005)],
    ],
    range: 5..=13,
};

static VARS_NAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAS_CHILDREN),
    value: None,
};

pub static VARS_NAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NASALIZATION_2558206430420024353)],
        &[(0b10010, &ENTRY_NASALIZATIONS_6303999372164951387)],
        &[(0b10010, &ENTRY_NASALIZE_15126394964863135289)],
        &[(0b10010, &ENTRY_NASALIZED_1174190894841693819)],
        &[(0b10010, &ENTRY_NASALIZES_10310087698573638162)],
        &[(0b10010, &ENTRY_NASALIZING_6931257761484940459)],
        &[(0b01001, &ENTRY_NASALIZATION_2558206430420024353)],
        &[(0b01001, &ENTRY_NASALIZATIONS_6303999372164951387)],
        &[(0b01001, &ENTRY_NASALIZE_15126394964863135289)],
        &[(0b01001, &ENTRY_NASALIZED_1174190894841693819)],
        &[(0b01001, &ENTRY_NASALIZES_10310087698573638162)],
        &[(0b01001, &ENTRY_NASALIZING_6931257761484940459)],
    ],
    range: 5..=10,
};

static VARS_NAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAR_CHILDREN),
    value: None,
};

pub static VARS_NAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cotisation"),
        dictgen::InsensitiveStr::Ascii("cotisations"),
        dictgen::InsensitiveStr::Ascii("cotise"),
        dictgen::InsensitiveStr::Ascii("cotised"),
        dictgen::InsensitiveStr::Ascii("cotises"),
        dictgen::InsensitiveStr::Ascii("cotising"),
        dictgen::InsensitiveStr::Ascii("cotization"),
        dictgen::InsensitiveStr::Ascii("cotizations"),
        dictgen::InsensitiveStr::Ascii("cotize"),
        dictgen::InsensitiveStr::Ascii("cotized"),
        dictgen::InsensitiveStr::Ascii("cotizes"),
        dictgen::InsensitiveStr::Ascii("cotizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NARCOTIZATION_3430955045881256247)],
        &[(0b10010, &ENTRY_NARCOTIZATIONS_7260107127336221603)],
        &[(0b10010, &ENTRY_NARCOTIZE_13643890971498648567)],
        &[(0b10010, &ENTRY_NARCOTIZED_1310082531152390964)],
        &[(0b10010, &ENTRY_NARCOTIZES_4192091924295649919)],
        &[(0b10010, &ENTRY_NARCOTIZING_5620876720588895066)],
        &[(0b01001, &ENTRY_NARCOTIZATION_3430955045881256247)],
        &[(0b01001, &ENTRY_NARCOTIZATIONS_7260107127336221603)],
        &[(0b01001, &ENTRY_NARCOTIZE_13643890971498648567)],
        &[(0b01001, &ENTRY_NARCOTIZED_1310082531152390964)],
        &[(0b01001, &ENTRY_NARCOTIZES_4192091924295649919)],
        &[(0b01001, &ENTRY_NARCOTIZING_5620876720588895066)],
    ],
    range: 6..=11,
};

static VARS_NAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAP_CHILDREN),
    value: None,
};

pub static VARS_NAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aea"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("hthalise"),
        dictgen::InsensitiveStr::Ascii("hthalised"),
        dictgen::InsensitiveStr::Ascii("hthalises"),
        dictgen::InsensitiveStr::Ascii("hthalising"),
        dictgen::InsensitiveStr::Ascii("hthalize"),
        dictgen::InsensitiveStr::Ascii("hthalized"),
        dictgen::InsensitiveStr::Ascii("hthalizes"),
        dictgen::InsensitiveStr::Ascii("hthalizing"),
        dictgen::InsensitiveStr::Ascii("oleonise"),
        dictgen::InsensitiveStr::Ascii("oleonises"),
        dictgen::InsensitiveStr::Ascii("oleonize"),
        dictgen::InsensitiveStr::Ascii("oleonizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NAPEA_2703553051209012323)],
        &[(0b00001, &ENTRY_NAPEA_2703553051209012323)],
        &[(0b10010, &ENTRY_NAPHTHALIZE_645547962499339602)],
        &[(0b10010, &ENTRY_NAPHTHALIZED_8961699346078499371)],
        &[(0b10010, &ENTRY_NAPHTHALIZES_9924625418222001512)],
        &[(0b10010, &ENTRY_NAPHTHALIZING_11494531894116033269)],
        &[(0b01001, &ENTRY_NAPHTHALIZE_645547962499339602)],
        &[(0b01001, &ENTRY_NAPHTHALIZED_8961699346078499371)],
        &[(0b01001, &ENTRY_NAPHTHALIZES_9924625418222001512)],
        &[(0b01001, &ENTRY_NAPHTHALIZING_11494531894116033269)],
        &[(0b10010, &ENTRY_NAPOLEONIZE_13711321813606941055)],
        &[(0b10010, &ENTRY_NAPOLEONIZES_12197992751496441870)],
        &[(0b01001, &ENTRY_NAPOLEONIZE_13711321813606941055)],
        &[(0b01001, &ENTRY_NAPOLEONIZES_12197992751496441870)],
    ],
    range: 2..=10,
};

static VARS_NAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAN_CHILDREN),
    value: None,
};

pub static VARS_NAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ogram"),
        dictgen::InsensitiveStr::Ascii("ogramme"),
        dictgen::InsensitiveStr::Ascii("ogrammes"),
        dictgen::InsensitiveStr::Ascii("ograms"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ometers"),
        dictgen::InsensitiveStr::Ascii("ometre"),
        dictgen::InsensitiveStr::Ascii("ometres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NANIZATION_8428761032922909057)],
        &[(0b10010, &ENTRY_NANIZATIONS_11464371774336189159)],
        &[(0b01001, &ENTRY_NANIZATION_8428761032922909057)],
        &[(0b01001, &ENTRY_NANIZATIONS_11464371774336189159)],
        &[(0b01001, &ENTRY_NANOGRAM_4215530022714871260)],
        &[(0b10010, &ENTRY_NANOGRAM_4215530022714871260)],
        &[(0b10010, &ENTRY_NANOGRAMS_9429141690600922745)],
        &[(0b01001, &ENTRY_NANOGRAMS_9429141690600922745)],
        &[(0b01001, &ENTRY_NANOMETER_17796927790461720149)],
        &[(0b01001, &ENTRY_NANOMETERS_11762757652710548689)],
        &[(0b11010, &ENTRY_NANOMETER_17796927790461720149)],
        &[(0b11010, &ENTRY_NANOMETERS_11762757652710548689)],
    ],
    range: 5..=8,
};

static VARS_NAK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAK_CHILDREN),
    value: None,
};

pub static VARS_NAK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edise"),
        dictgen::InsensitiveStr::Ascii("edises"),
        dictgen::InsensitiveStr::Ascii("edize"),
        dictgen::InsensitiveStr::Ascii("edizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_NAKEDIZE_4521587020024219245)],
        &[(0b10010, &ENTRY_NAKEDIZES_2791254265493929089)],
        &[(0b01001, &ENTRY_NAKEDIZE_4521587020024219245)],
        &[(0b01001, &ENTRY_NAKEDIZES_2791254265493929089)],
    ],
    range: 5..=6,
};

static VARS_NAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAE_CHILDREN),
    value: None,
};

pub static VARS_NAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ves"),
        dictgen::InsensitiveStr::Ascii("void"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NEVES_16616131966640754583)],
        &[(0b11010, &ENTRY_NEVOID_9949690720573904750)],
    ],
    range: 3..=4,
};

static VARS_NAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_NAB_CHILDREN),
    value: None,
};

pub static VARS_NAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ataeans"),
        dictgen::InsensitiveStr::Ascii("ateans"),
        dictgen::InsensitiveStr::Ascii("athaean"),
        dictgen::InsensitiveStr::Ascii("athean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_NABATEANS_3600480999719306802)],
        &[(0b00001, &ENTRY_NABATEANS_3600480999719306802)],
        &[(0b11010, &ENTRY_NABATHEAN_18347716128449108020)],
        &[(0b00001, &ENTRY_NABATHEAN_18347716128449108020)],
    ],
    range: 6..=7,
};

static VARS_M_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_M_CHILDREN),
    value: None,
};

static VARS_M_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MA_NODE),
    None,
    None,
    None,
    Some(&VARS_ME_NODE),
    None,
    None,
    None,
    Some(&VARS_MI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MU_NODE),
    None,
    None,
    None,
    Some(&VARS_MY_NODE),
    None,
];

static VARS_MY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MY_CHILDREN),
    value: None,
};

static VARS_MY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_MYC_NODE),
    None,
    Some(&VARS_MYE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MYL_NODE),
    None,
    None,
    Some(&VARS_MYO_NODE),
    None,
    None,
    Some(&VARS_MYR_NODE),
    Some(&VARS_MYS_NODE),
    Some(&VARS_MYT_NODE),
    None,
    None,
    None,
    Some(&VARS_MYX_NODE),
    None,
    None,
];

static VARS_MYX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYX_CHILDREN),
    value: None,
};

pub static VARS_MYX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("ameba"),
        dictgen::InsensitiveStr::Ascii("amoeba"),
        dictgen::InsensitiveStr::Ascii("edema"),
        dictgen::InsensitiveStr::Ascii("edemas"),
        dictgen::InsensitiveStr::Ascii("edematous"),
        dictgen::InsensitiveStr::Ascii("edemic"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("oedema"),
        dictgen::InsensitiveStr::Ascii("oedemas"),
        dictgen::InsensitiveStr::Ascii("oedematous"),
        dictgen::InsensitiveStr::Ascii("oedemic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MYXEMIA_10745005304996222059)],
        &[(0b00001, &ENTRY_MYXAMEBA_3121975824630761163)],
        &[(0b11010, &ENTRY_MYXAMEBA_3121975824630761163)],
        &[(0b11001, &ENTRY_MYXEDEMA_16077318576777540086)],
        &[(0b11001, &ENTRY_MYXEDEMAS_2503279100646867910)],
        &[(0b10001, &ENTRY_MYXEDEMATOUS_11999883566777710815)],
        &[(0b10001, &ENTRY_MYXEDEMIC_2015128688140769365)],
        &[(0b10001, &ENTRY_MYXEMIA_10745005304996222059)],
        &[(0b10010, &ENTRY_MYXEDEMA_16077318576777540086)],
        &[(0b10010, &ENTRY_MYXEDEMAS_2503279100646867910)],
        &[(0b11010, &ENTRY_MYXEDEMATOUS_11999883566777710815)],
        &[(0b11010, &ENTRY_MYXEDEMIC_2015128688140769365)],
    ],
    range: 4..=10,
};

static VARS_MYT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYT_CHILDREN),
    value: None,
};

pub static VARS_MYT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hicisation"),
        dictgen::InsensitiveStr::Ascii("hicise"),
        dictgen::InsensitiveStr::Ascii("hicised"),
        dictgen::InsensitiveStr::Ascii("hiciser"),
        dictgen::InsensitiveStr::Ascii("hicisers"),
        dictgen::InsensitiveStr::Ascii("hicises"),
        dictgen::InsensitiveStr::Ascii("hicising"),
        dictgen::InsensitiveStr::Ascii("hicization"),
        dictgen::InsensitiveStr::Ascii("hicize"),
        dictgen::InsensitiveStr::Ascii("hicized"),
        dictgen::InsensitiveStr::Ascii("hicizer"),
        dictgen::InsensitiveStr::Ascii("hicizers"),
        dictgen::InsensitiveStr::Ascii("hicizes"),
        dictgen::InsensitiveStr::Ascii("hicizing"),
        dictgen::InsensitiveStr::Ascii("hise"),
        dictgen::InsensitiveStr::Ascii("hised"),
        dictgen::InsensitiveStr::Ascii("hises"),
        dictgen::InsensitiveStr::Ascii("hising"),
        dictgen::InsensitiveStr::Ascii("hize"),
        dictgen::InsensitiveStr::Ascii("hized"),
        dictgen::InsensitiveStr::Ascii("hizes"),
        dictgen::InsensitiveStr::Ascii("hizing"),
        dictgen::InsensitiveStr::Ascii("hologisation"),
        dictgen::InsensitiveStr::Ascii("hologisations"),
        dictgen::InsensitiveStr::Ascii("hologise"),
        dictgen::InsensitiveStr::Ascii("hologised"),
        dictgen::InsensitiveStr::Ascii("hologiser"),
        dictgen::InsensitiveStr::Ascii("hologisers"),
        dictgen::InsensitiveStr::Ascii("hologises"),
        dictgen::InsensitiveStr::Ascii("hologising"),
        dictgen::InsensitiveStr::Ascii("hologization"),
        dictgen::InsensitiveStr::Ascii("hologizations"),
        dictgen::InsensitiveStr::Ascii("hologize"),
        dictgen::InsensitiveStr::Ascii("hologized"),
        dictgen::InsensitiveStr::Ascii("hologizer"),
        dictgen::InsensitiveStr::Ascii("hologizers"),
        dictgen::InsensitiveStr::Ascii("hologizes"),
        dictgen::InsensitiveStr::Ascii("hologizing"),
        dictgen::InsensitiveStr::Ascii("hopeic"),
        dictgen::InsensitiveStr::Ascii("hopeist"),
        dictgen::InsensitiveStr::Ascii("hopoeic"),
        dictgen::InsensitiveStr::Ascii("hopoeist"),
        dictgen::InsensitiveStr::Ascii("hopoetise"),
        dictgen::InsensitiveStr::Ascii("hopoetised"),
        dictgen::InsensitiveStr::Ascii("hopoetising"),
        dictgen::InsensitiveStr::Ascii("hopoetize"),
        dictgen::InsensitiveStr::Ascii("hopoetized"),
        dictgen::InsensitiveStr::Ascii("hopoetizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MYTHICIZATION_4467730647442451023)],
        &[(0b10010, &ENTRY_MYTHICIZE_994451185735413970)],
        &[(0b10010, &ENTRY_MYTHICIZED_4137264042093387147)],
        &[(0b10010, &ENTRY_MYTHICIZER_17943353036856898639)],
        &[(0b10010, &ENTRY_MYTHICIZERS_10056546919744418175)],
        &[(0b10010, &ENTRY_MYTHICIZES_1828039457047215420)],
        &[(0b10010, &ENTRY_MYTHICIZING_8980222790322037836)],
        &[(0b01001, &ENTRY_MYTHICIZATION_4467730647442451023)],
        &[(0b01001, &ENTRY_MYTHICIZE_994451185735413970)],
        &[(0b01001, &ENTRY_MYTHICIZED_4137264042093387147)],
        &[(0b01001, &ENTRY_MYTHICIZER_17943353036856898639)],
        &[(0b01001, &ENTRY_MYTHICIZERS_10056546919744418175)],
        &[(0b01001, &ENTRY_MYTHICIZES_1828039457047215420)],
        &[(0b01001, &ENTRY_MYTHICIZING_8980222790322037836)],
        &[(0b10010, &ENTRY_MYTHIZE_9908305862028630928)],
        &[(0b10010, &ENTRY_MYTHIZED_17571926043024947437)],
        &[(0b10010, &ENTRY_MYTHIZES_1545681173644864391)],
        &[(0b10010, &ENTRY_MYTHIZING_10503929080533408341)],
        &[(0b01001, &ENTRY_MYTHIZE_9908305862028630928)],
        &[(0b01001, &ENTRY_MYTHIZED_17571926043024947437)],
        &[(0b01001, &ENTRY_MYTHIZES_1545681173644864391)],
        &[(0b01001, &ENTRY_MYTHIZING_10503929080533408341)],
        &[(0b10010, &ENTRY_MYTHOLOGIZATION_13010847986648537402)],
        &[(0b10010, &ENTRY_MYTHOLOGIZATIONS_3274680051911037587)],
        &[(0b10010, &ENTRY_MYTHOLOGIZE_934719101789293180)],
        &[(0b10010, &ENTRY_MYTHOLOGIZED_7891244640375123566)],
        &[(0b10010, &ENTRY_MYTHOLOGIZER_5433148033004398505)],
        &[(0b10010, &ENTRY_MYTHOLOGIZERS_14789426233370867155)],
        &[(0b10010, &ENTRY_MYTHOLOGIZES_7585510101718085489)],
        &[(0b10010, &ENTRY_MYTHOLOGIZING_13752169083408188946)],
        &[(0b01001, &ENTRY_MYTHOLOGIZATION_13010847986648537402)],
        &[(0b01001, &ENTRY_MYTHOLOGIZATIONS_3274680051911037587)],
        &[(0b01001, &ENTRY_MYTHOLOGIZE_934719101789293180)],
        &[(0b01001, &ENTRY_MYTHOLOGIZED_7891244640375123566)],
        &[(0b01001, &ENTRY_MYTHOLOGIZER_5433148033004398505)],
        &[(0b01001, &ENTRY_MYTHOLOGIZERS_14789426233370867155)],
        &[(0b01001, &ENTRY_MYTHOLOGIZES_7585510101718085489)],
        &[(0b01001, &ENTRY_MYTHOLOGIZING_13752169083408188946)],
        &[(0b00001, &ENTRY_MYTHOPEIC_5553162771527570838)],
        &[(0b00001, &ENTRY_MYTHOPEIST_2404759549078344350)],
        &[(0b11010, &ENTRY_MYTHOPEIC_5553162771527570838)],
        &[(0b11010, &ENTRY_MYTHOPEIST_2404759549078344350)],
        &[(0b10010, &ENTRY_MYTHOPOETIZE_812399287360499791)],
        &[(0b10010, &ENTRY_MYTHOPOETIZED_10722688976092427157)],
        &[(0b10010, &ENTRY_MYTHOPOETIZING_9650923068555803994)],
        &[(0b01001, &ENTRY_MYTHOPOETIZE_812399287360499791)],
        &[(0b01001, &ENTRY_MYTHOPOETIZED_10722688976092427157)],
        &[(0b01001, &ENTRY_MYTHOPOETIZING_9650923068555803994)],
    ],
    range: 4..=13,
};

static VARS_MYS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYS_CHILDREN),
    value: None,
};

pub static VARS_MYS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MYSTICIZE_9971453281076771770)],
        &[(0b10010, &ENTRY_MYSTICIZES_13649076160811622608)],
        &[(0b01001, &ENTRY_MYSTICIZE_9971453281076771770)],
        &[(0b01001, &ENTRY_MYSTICIZES_13649076160811622608)],
    ],
    range: 6..=7,
};

static VARS_MYR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYR_CHILDREN),
    value: None,
};

pub static VARS_MYR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialiter"),
        dictgen::InsensitiveStr::Ascii("ialitre"),
        dictgen::InsensitiveStr::Ascii("iameter"),
        dictgen::InsensitiveStr::Ascii("iametre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MYRIALITER_6139987841651830761)],
        &[(0b11010, &ENTRY_MYRIALITER_6139987841651830761)],
        &[(0b00001, &ENTRY_MYRIAMETER_284114791865990119)],
        &[(0b11010, &ENTRY_MYRIAMETER_284114791865990119)],
    ],
    range: 7..=7,
};

static VARS_MYO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYO_CHILDREN),
    value: None,
};

pub static VARS_MYO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cele"),
        dictgen::InsensitiveStr::Ascii("coele"),
        dictgen::InsensitiveStr::Ascii("haematin"),
        dictgen::InsensitiveStr::Ascii("hematin"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MYOCELE_6155543281988825635)],
        &[(0b11010, &ENTRY_MYOCELE_6155543281988825635)],
        &[(0b11010, &ENTRY_MYOHEMATIN_7139519405799594952)],
        &[(0b10001, &ENTRY_MYOHEMATIN_7139519405799594952)],
    ],
    range: 4..=8,
};

static VARS_MYL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYL_CHILDREN),
    value: None,
};

pub static VARS_MYL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onitisation"),
        dictgen::InsensitiveStr::Ascii("onitisations"),
        dictgen::InsensitiveStr::Ascii("onitise"),
        dictgen::InsensitiveStr::Ascii("onitised"),
        dictgen::InsensitiveStr::Ascii("onitises"),
        dictgen::InsensitiveStr::Ascii("onitising"),
        dictgen::InsensitiveStr::Ascii("onitization"),
        dictgen::InsensitiveStr::Ascii("onitizations"),
        dictgen::InsensitiveStr::Ascii("onitize"),
        dictgen::InsensitiveStr::Ascii("onitized"),
        dictgen::InsensitiveStr::Ascii("onitizes"),
        dictgen::InsensitiveStr::Ascii("onitizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MYLONITIZATION_14207571191895224414)],
        &[(0b10010, &ENTRY_MYLONITIZATIONS_8987230193080175923)],
        &[(0b10010, &ENTRY_MYLONITIZE_8331820604780621489)],
        &[(0b10010, &ENTRY_MYLONITIZED_1836771186609206852)],
        &[(0b10010, &ENTRY_MYLONITIZES_9054608438172135078)],
        &[(0b10010, &ENTRY_MYLONITIZING_10075181248707997045)],
        &[(0b01001, &ENTRY_MYLONITIZATION_14207571191895224414)],
        &[(0b01001, &ENTRY_MYLONITIZATIONS_8987230193080175923)],
        &[(0b01001, &ENTRY_MYLONITIZE_8331820604780621489)],
        &[(0b01001, &ENTRY_MYLONITIZED_1836771186609206852)],
        &[(0b01001, &ENTRY_MYLONITIZES_9054608438172135078)],
        &[(0b01001, &ENTRY_MYLONITIZING_10075181248707997045)],
    ],
    range: 7..=12,
};

static VARS_MYE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYE_CHILDREN),
    value: None,
};

pub static VARS_MYE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("linisation"),
        dictgen::InsensitiveStr::Ascii("linisations"),
        dictgen::InsensitiveStr::Ascii("linization"),
        dictgen::InsensitiveStr::Ascii("linizations"),
        dictgen::InsensitiveStr::Ascii("locele"),
        dictgen::InsensitiveStr::Ascii("locoele"),
        dictgen::InsensitiveStr::Ascii("locythaemia"),
        dictgen::InsensitiveStr::Ascii("locythemia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MYELINIZATION_13458271670402434224)],
        &[(0b10010, &ENTRY_MYELINIZATIONS_969486317082261560)],
        &[(0b01001, &ENTRY_MYELINIZATION_13458271670402434224)],
        &[(0b01001, &ENTRY_MYELINIZATIONS_969486317082261560)],
        &[(0b00001, &ENTRY_MYELOCELE_11426053315237704792)],
        &[(0b11010, &ENTRY_MYELOCELE_11426053315237704792)],
        &[(0b11010, &ENTRY_MYELOCYTHEMIA_1216815045707461282)],
        &[(0b10001, &ENTRY_MYELOCYTHEMIA_1216815045707461282)],
    ],
    range: 6..=11,
};

static VARS_MYC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MYC_CHILDREN),
    value: None,
};

pub static VARS_MYC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ohaemia"),
        dictgen::InsensitiveStr::Ascii("ohemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MYCOHEMIA_14011500395634142073)],
        &[(0b10001, &ENTRY_MYCOHEMIA_14011500395634142073)],
    ],
    range: 6..=7,
};

static VARS_MU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MU_CHILDREN),
    value: None,
};

static VARS_MU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_MUC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MUL_NODE),
    Some(&VARS_MUM_NODE),
    Some(&VARS_MUN_NODE),
    None,
    None,
    None,
    Some(&VARS_MUR_NODE),
    Some(&VARS_MUS_NODE),
    Some(&VARS_MUT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_MUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUT_CHILDREN),
    value: None,
};

pub static VARS_MUT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agenise"),
        dictgen::InsensitiveStr::Ascii("agenised"),
        dictgen::InsensitiveStr::Ascii("agenises"),
        dictgen::InsensitiveStr::Ascii("agenising"),
        dictgen::InsensitiveStr::Ascii("agenize"),
        dictgen::InsensitiveStr::Ascii("agenized"),
        dictgen::InsensitiveStr::Ascii("agenizes"),
        dictgen::InsensitiveStr::Ascii("agenizing"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MUTAGENIZE_13512560099179859556)],
        &[(0b10010, &ENTRY_MUTAGENIZED_11416012132208663302)],
        &[(0b10010, &ENTRY_MUTAGENIZES_12316350538332027237)],
        &[(0b10010, &ENTRY_MUTAGENIZING_94769575082965039)],
        &[(0b01001, &ENTRY_MUTAGENIZE_13512560099179859556)],
        &[(0b01001, &ENTRY_MUTAGENIZED_11416012132208663302)],
        &[(0b01001, &ENTRY_MUTAGENIZES_12316350538332027237)],
        &[(0b01001, &ENTRY_MUTAGENIZING_94769575082965039)],
        &[(0b10010, &ENTRY_MUTUALIZATION_148927225642760299)],
        &[(0b10010, &ENTRY_MUTUALIZATIONS_8022089842546520715)],
        &[(0b10010, &ENTRY_MUTUALIZE_9884428022614368321)],
        &[(0b10010, &ENTRY_MUTUALIZED_16677934514596854802)],
        &[(0b10010, &ENTRY_MUTUALIZES_12491858123359748428)],
        &[(0b10010, &ENTRY_MUTUALIZING_5941204778850827823)],
        &[(0b01001, &ENTRY_MUTUALIZATION_148927225642760299)],
        &[(0b01001, &ENTRY_MUTUALIZATIONS_8022089842546520715)],
        &[(0b01001, &ENTRY_MUTUALIZE_9884428022614368321)],
        &[(0b01001, &ENTRY_MUTUALIZED_16677934514596854802)],
        &[(0b01001, &ENTRY_MUTUALIZES_12491858123359748428)],
        &[(0b01001, &ENTRY_MUTUALIZING_5941204778850827823)],
    ],
    range: 6..=11,
};

static VARS_MUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUS_CHILDREN),
    value: None,
};

pub static VARS_MUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cularise"),
        dictgen::InsensitiveStr::Ascii("cularises"),
        dictgen::InsensitiveStr::Ascii("cularize"),
        dictgen::InsensitiveStr::Ascii("cularizes"),
        dictgen::InsensitiveStr::Ascii("eumise"),
        dictgen::InsensitiveStr::Ascii("eumises"),
        dictgen::InsensitiveStr::Ascii("eumize"),
        dictgen::InsensitiveStr::Ascii("eumizes"),
        dictgen::InsensitiveStr::Ascii("icalisation"),
        dictgen::InsensitiveStr::Ascii("icalisations"),
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalised"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalising"),
        dictgen::InsensitiveStr::Ascii("icalization"),
        dictgen::InsensitiveStr::Ascii("icalizations"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalized"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
        dictgen::InsensitiveStr::Ascii("icalizing"),
        dictgen::InsensitiveStr::Ascii("tache"),
        dictgen::InsensitiveStr::Ascii("tached"),
        dictgen::InsensitiveStr::Ascii("taches"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MUSCULARIZE_398052939754954428)],
        &[(0b10010, &ENTRY_MUSCULARIZES_10614722597220369532)],
        &[(0b01001, &ENTRY_MUSCULARIZE_398052939754954428)],
        &[(0b01001, &ENTRY_MUSCULARIZES_10614722597220369532)],
        &[(0b10010, &ENTRY_MUSEUMIZE_7842047323081517378)],
        &[(0b10010, &ENTRY_MUSEUMIZES_14658763738317667704)],
        &[(0b01001, &ENTRY_MUSEUMIZE_7842047323081517378)],
        &[(0b01001, &ENTRY_MUSEUMIZES_14658763738317667704)],
        &[(0b10010, &ENTRY_MUSICALIZATION_5418765001607453254)],
        &[(0b10010, &ENTRY_MUSICALIZATIONS_8007008082374895856)],
        &[(0b10010, &ENTRY_MUSICALIZE_14105870209904150736)],
        &[(0b10010, &ENTRY_MUSICALIZED_1534933012029862697)],
        &[(0b10010, &ENTRY_MUSICALIZES_15122018268806895726)],
        &[(0b10010, &ENTRY_MUSICALIZING_5444115698838018843)],
        &[(0b01001, &ENTRY_MUSICALIZATION_5418765001607453254)],
        &[(0b01001, &ENTRY_MUSICALIZATIONS_8007008082374895856)],
        &[(0b01001, &ENTRY_MUSICALIZE_14105870209904150736)],
        &[(0b01001, &ENTRY_MUSICALIZED_1534933012029862697)],
        &[(0b01001, &ENTRY_MUSICALIZES_15122018268806895726)],
        &[(0b01001, &ENTRY_MUSICALIZING_5444115698838018843)],
        &[(0b01001, &ENTRY_MUSTACHE_10319903289050174029)],
        &[(0b00001, &ENTRY_MUSTACHED_2206075060724165943)],
        &[(0b01001, &ENTRY_MUSTACHES_16686627673297841138)],
    ],
    range: 5..=12,
};

static VARS_MUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUR_CHILDREN),
    value: None,
};

pub static VARS_MUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aena"),
        dictgen::InsensitiveStr::Ascii("aenas"),
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("enas"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MURENA_18139482623728905615)],
        &[(0b11010, &ENTRY_MURENAS_6329923349315548065)],
        &[(0b00001, &ENTRY_MURENA_18139482623728905615)],
        &[(0b00001, &ENTRY_MURENAS_6329923349315548065)],
    ],
    range: 3..=5,
};

static VARS_MUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUN_CHILDREN),
    value: None,
};

pub static VARS_MUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icipalisation"),
        dictgen::InsensitiveStr::Ascii("icipalisations"),
        dictgen::InsensitiveStr::Ascii("icipalise"),
        dictgen::InsensitiveStr::Ascii("icipalised"),
        dictgen::InsensitiveStr::Ascii("icipaliser"),
        dictgen::InsensitiveStr::Ascii("icipalisers"),
        dictgen::InsensitiveStr::Ascii("icipalises"),
        dictgen::InsensitiveStr::Ascii("icipalising"),
        dictgen::InsensitiveStr::Ascii("icipalization"),
        dictgen::InsensitiveStr::Ascii("icipalizations"),
        dictgen::InsensitiveStr::Ascii("icipalize"),
        dictgen::InsensitiveStr::Ascii("icipalized"),
        dictgen::InsensitiveStr::Ascii("icipalizer"),
        dictgen::InsensitiveStr::Ascii("icipalizers"),
        dictgen::InsensitiveStr::Ascii("icipalizes"),
        dictgen::InsensitiveStr::Ascii("icipalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MUNICIPALIZATION_9575521026368095408)],
        &[(0b10010, &ENTRY_MUNICIPALIZATIONS_6370526343367980395)],
        &[(0b10010, &ENTRY_MUNICIPALIZE_1907378831809176828)],
        &[(0b10010, &ENTRY_MUNICIPALIZED_13952457825214732598)],
        &[(0b10010, &ENTRY_MUNICIPALIZER_5812211793259788814)],
        &[(0b10010, &ENTRY_MUNICIPALIZERS_15756045224107050768)],
        &[(0b10010, &ENTRY_MUNICIPALIZES_14135230958620370966)],
        &[(0b10010, &ENTRY_MUNICIPALIZING_3968102490959965181)],
        &[(0b01001, &ENTRY_MUNICIPALIZATION_9575521026368095408)],
        &[(0b01001, &ENTRY_MUNICIPALIZATIONS_6370526343367980395)],
        &[(0b01001, &ENTRY_MUNICIPALIZE_1907378831809176828)],
        &[(0b01001, &ENTRY_MUNICIPALIZED_13952457825214732598)],
        &[(0b01001, &ENTRY_MUNICIPALIZER_5812211793259788814)],
        &[(0b01001, &ENTRY_MUNICIPALIZERS_15756045224107050768)],
        &[(0b01001, &ENTRY_MUNICIPALIZES_14135230958620370966)],
        &[(0b01001, &ENTRY_MUNICIPALIZING_3968102490959965181)],
    ],
    range: 9..=14,
};

static VARS_MUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUM_CHILDREN),
    value: None,
};

pub static VARS_MUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b10010, &ENTRY_MOMS_301669076590401125)]],
    range: 1..=1,
};

static VARS_MUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUL_CHILDREN),
    value: None,
};

pub static VARS_MUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ticolor"),
        dictgen::InsensitiveStr::Ascii("ticolored"),
        dictgen::InsensitiveStr::Ascii("ticoloredder"),
        dictgen::InsensitiveStr::Ascii("ticoloreddest"),
        dictgen::InsensitiveStr::Ascii("ticolorous"),
        dictgen::InsensitiveStr::Ascii("ticolors"),
        dictgen::InsensitiveStr::Ascii("ticolour"),
        dictgen::InsensitiveStr::Ascii("ticoloured"),
        dictgen::InsensitiveStr::Ascii("ticolouredder"),
        dictgen::InsensitiveStr::Ascii("ticoloureddest"),
        dictgen::InsensitiveStr::Ascii("ticolourous"),
        dictgen::InsensitiveStr::Ascii("ticolours"),
        dictgen::InsensitiveStr::Ascii("tifibered"),
        dictgen::InsensitiveStr::Ascii("tifibereds"),
        dictgen::InsensitiveStr::Ascii("tifibred"),
        dictgen::InsensitiveStr::Ascii("tifibreds"),
        dictgen::InsensitiveStr::Ascii("tileveled"),
        dictgen::InsensitiveStr::Ascii("tilevelled"),
    ],
    values: &[
        &[(0b10001, &ENTRY_MULTICOLOR_784422909619173390)],
        &[(0b10001, &ENTRY_MULTICOLORED_1099974154350113974)],
        &[(0b10001, &ENTRY_MULTICOLOREDDER_3341008599097650171)],
        &[(0b10001, &ENTRY_MULTICOLOREDDEST_7461907494166966856)],
        &[(0b00001, &ENTRY_MULTICOLOROUS_6201278565370964976)],
        &[(0b10001, &ENTRY_MULTICOLORS_2420068264028973832)],
        &[(0b11010, &ENTRY_MULTICOLOR_784422909619173390)],
        &[(0b11010, &ENTRY_MULTICOLORED_1099974154350113974)],
        &[(0b11010, &ENTRY_MULTICOLOREDDER_3341008599097650171)],
        &[(0b11010, &ENTRY_MULTICOLOREDDEST_7461907494166966856)],
        &[(0b11010, &ENTRY_MULTICOLOROUS_6201278565370964976)],
        &[(0b11010, &ENTRY_MULTICOLORS_2420068264028973832)],
        &[(0b00001, &ENTRY_MULTIFIBERED_7572219282880475426)],
        &[(0b00001, &ENTRY_MULTIFIBEREDS_5927344967497839466)],
        &[(0b11010, &ENTRY_MULTIFIBERED_7572219282880475426)],
        &[(0b11010, &ENTRY_MULTIFIBEREDS_5927344967497839466)],
        &[(0b00001, &ENTRY_MULTILEVELED_7194174376853857456)],
        &[(0b11010, &ENTRY_MULTILEVELED_7194174376853857456)],
    ],
    range: 7..=14,
};

static VARS_MUC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MUC_CHILDREN),
    value: None,
};

pub static VARS_MUC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("osae"),
        dictgen::InsensitiveStr::Ascii("ose"),
    ],
    values: &[
        &[(0b10001, &ENTRY_MUCORRHEA_8295999192288067270)],
        &[(0b11010, &ENTRY_MUCORRHEA_8295999192288067270)],
        &[(0b11010, &ENTRY_MUCOSE_11672488603107743330)],
        &[(0b00001, &ENTRY_MUCOSE_11672488603107743330)],
    ],
    range: 3..=7,
};

static VARS_MO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MO_CHILDREN),
    value: None,
};

static VARS_MO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_MOB_NODE),
    None,
    Some(&VARS_MOD_NODE),
    Some(&VARS_MOE_NODE),
    None,
    Some(&VARS_MOG_NODE),
    Some(&VARS_MOH_NODE),
    Some(&VARS_MOI_NODE),
    None,
    None,
    Some(&VARS_MOL_NODE),
    Some(&VARS_MOM_NODE),
    Some(&VARS_MON_NODE),
    None,
    None,
    None,
    Some(&VARS_MOR_NODE),
    Some(&VARS_MOS_NODE),
    Some(&VARS_MOT_NODE),
    Some(&VARS_MOU_NODE),
    Some(&VARS_MOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_MOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOV_CHILDREN),
    value: None,
};

pub static VARS_MOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("eability")],
    values: &[&[(0b00001, &ENTRY_MOVABILITY_11870011406697694199)]],
    range: 8..=8,
};

static VARS_MOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOU_CHILDREN),
    value: None,
};

pub static VARS_MOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ld"),
        dictgen::InsensitiveStr::Ascii("lded"),
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("ldered"),
        dictgen::InsensitiveStr::Ascii("ldering"),
        dictgen::InsensitiveStr::Ascii("lders"),
        dictgen::InsensitiveStr::Ascii("ldier"),
        dictgen::InsensitiveStr::Ascii("ldiest"),
        dictgen::InsensitiveStr::Ascii("lding"),
        dictgen::InsensitiveStr::Ascii("ldings"),
        dictgen::InsensitiveStr::Ascii("lds"),
        dictgen::InsensitiveStr::Ascii("ldy"),
        dictgen::InsensitiveStr::Ascii("lt"),
        dictgen::InsensitiveStr::Ascii("lted"),
        dictgen::InsensitiveStr::Ascii("lting"),
        dictgen::InsensitiveStr::Ascii("lts"),
        dictgen::InsensitiveStr::Ascii("rne"),
        dictgen::InsensitiveStr::Ascii("rningly"),
        dictgen::InsensitiveStr::Ascii("stache"),
        dictgen::InsensitiveStr::Ascii("stached"),
        dictgen::InsensitiveStr::Ascii("staches"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MOLD_4204617930046953090)],
        &[(0b11010, &ENTRY_MOLDED_4867396599674557897)],
        &[(0b11010, &ENTRY_MOLDER_5468513924454038075)],
        &[(0b11010, &ENTRY_MOLDERED_13806811290362462856)],
        &[(0b11010, &ENTRY_MOLDERING_761432945987723341)],
        &[(0b11010, &ENTRY_MOLDERS_10624195404241411222)],
        &[(0b11010, &ENTRY_MOLDIER_17925953827043179593)],
        &[(0b11010, &ENTRY_MOLDIEST_11552700490364540702)],
        &[(0b11010, &ENTRY_MOLDING_16972516311440379476)],
        &[(0b11010, &ENTRY_MOLDINGS_11877581157093154122)],
        &[(0b11010, &ENTRY_MOLDS_209402696956725647)],
        &[(0b11010, &ENTRY_MOLDY_15469792360276639207)],
        &[(0b11010, &ENTRY_MOLT_13673484917001179046)],
        &[(0b11010, &ENTRY_MOLTED_13851575492873022320)],
        &[(0b11010, &ENTRY_MOLTING_8969305985716783845)],
        &[(0b11010, &ENTRY_MOLTS_10499278002715999239)],
        &[(0b11010, &ENTRY_MORNE_17753311726489354450)],
        &[(0b11010, &ENTRY_MORNINGLY_14399084090041736439)],
        &[(0b11010, &ENTRY_MUSTACHE_10319903289050174029)],
        &[(0b11010, &ENTRY_MUSTACHED_2206075060724165943)],
        &[(0b11010, &ENTRY_MUSTACHES_16686627673297841138)],
    ],
    range: 2..=7,
};

static VARS_MOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOT_CHILDREN),
    value: None,
};

pub static VARS_MOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOTORIZATION_117868153865960407)],
        &[(0b10010, &ENTRY_MOTORIZATIONS_3171453995120539506)],
        &[(0b10010, &ENTRY_MOTORIZE_9953616205839376436)],
        &[(0b10010, &ENTRY_MOTORIZED_15195580542726305660)],
        &[(0b10010, &ENTRY_MOTORIZES_4685593754649773687)],
        &[(0b10010, &ENTRY_MOTORIZING_6409716101426652084)],
        &[(0b01001, &ENTRY_MOTORIZATION_117868153865960407)],
        &[(0b01001, &ENTRY_MOTORIZATIONS_3171453995120539506)],
        &[(0b01001, &ENTRY_MOTORIZE_9953616205839376436)],
        &[(0b01001, &ENTRY_MOTORIZED_15195580542726305660)],
        &[(0b01001, &ENTRY_MOTORIZES_4685593754649773687)],
        &[(0b01001, &ENTRY_MOTORIZING_6409716101426652084)],
    ],
    range: 5..=10,
};

static VARS_MOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOS_CHILDREN),
    value: None,
};

pub static VARS_MOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lemise"),
        dictgen::InsensitiveStr::Ascii("lemises"),
        dictgen::InsensitiveStr::Ascii("lemize"),
        dictgen::InsensitiveStr::Ascii("lemizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOSLEMIZE_16249209972322086947)],
        &[(0b10010, &ENTRY_MOSLEMIZES_18082869512875046805)],
        &[(0b01001, &ENTRY_MOSLEMIZE_16249209972322086947)],
        &[(0b01001, &ENTRY_MOSLEMIZES_18082869512875046805)],
    ],
    range: 6..=7,
};

static VARS_MOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MOR_CHILDREN),
    value: None,
};

static VARS_MOR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MORA_NODE),
    Some(&VARS_MORB_NODE),
    None,
    None,
    Some(&VARS_MORE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MORN_NODE),
    None,
    Some(&VARS_MORP_NODE),
    None,
    None,
    Some(&VARS_MORS_NODE),
    Some(&VARS_MORT_NODE),
    Some(&VARS_MORU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_MORU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORU_CHILDREN),
    value: None,
};

pub static VARS_MORU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lae"),
        dictgen::InsensitiveStr::Ascii("le"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MORULE_2744607879952026701)],
        &[(0b00001, &ENTRY_MORULE_2744607879952026701)],
    ],
    range: 2..=3,
};

static VARS_MORT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORT_CHILDREN),
    value: None,
};

pub static VARS_MORT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MORTALIZE_9043410404777963563)],
        &[(0b10010, &ENTRY_MORTALIZED_16634602645317905204)],
        &[(0b10010, &ENTRY_MORTALIZES_1136538908901890872)],
        &[(0b10010, &ENTRY_MORTALIZING_13683327146873296741)],
        &[(0b01001, &ENTRY_MORTALIZE_9043410404777963563)],
        &[(0b01001, &ENTRY_MORTALIZED_16634602645317905204)],
        &[(0b01001, &ENTRY_MORTALIZES_1136538908901890872)],
        &[(0b01001, &ENTRY_MORTALIZING_13683327146873296741)],
        &[(0b10010, &ENTRY_MORTARIZE_7482329915364487009)],
        &[(0b10010, &ENTRY_MORTARIZES_9581033940816475263)],
        &[(0b01001, &ENTRY_MORTARIZE_7482329915364487009)],
        &[(0b01001, &ENTRY_MORTARIZES_9581033940816475263)],
    ],
    range: 5..=7,
};

static VARS_MORS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORS_CHILDREN),
    value: None,
};

pub static VARS_MORS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MORSELED_6287732670299985987)],
        &[(0b00001, &ENTRY_MORSELING_3778440818761410189)],
        &[(0b10010, &ENTRY_MORSELIZATION_2667568239096574036)],
        &[(0b10010, &ENTRY_MORSELIZATIONS_13741092004731619491)],
        &[(0b10010, &ENTRY_MORSELIZE_737147545384494790)],
        &[(0b10010, &ENTRY_MORSELIZES_1717809719310113488)],
        &[(0b01001, &ENTRY_MORSELIZATION_2667568239096574036)],
        &[(0b01001, &ENTRY_MORSELIZATIONS_13741092004731619491)],
        &[(0b01001, &ENTRY_MORSELIZE_737147545384494790)],
        &[(0b01001, &ENTRY_MORSELIZES_1717809719310113488)],
        &[(0b11010, &ENTRY_MORSELED_6287732670299985987)],
        &[(0b11010, &ENTRY_MORSELING_3778440818761410189)],
    ],
    range: 4..=10,
};

static VARS_MORP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORP_CHILDREN),
    value: None,
};

pub static VARS_MORP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hinisation"),
        dictgen::InsensitiveStr::Ascii("hinisations"),
        dictgen::InsensitiveStr::Ascii("hinise"),
        dictgen::InsensitiveStr::Ascii("hinises"),
        dictgen::InsensitiveStr::Ascii("hinization"),
        dictgen::InsensitiveStr::Ascii("hinizations"),
        dictgen::InsensitiveStr::Ascii("hinize"),
        dictgen::InsensitiveStr::Ascii("hinizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MORPHINIZATION_11750424731639276917)],
        &[(0b10010, &ENTRY_MORPHINIZATIONS_1979094451135743390)],
        &[(0b10010, &ENTRY_MORPHINIZE_6910565647915854125)],
        &[(0b10010, &ENTRY_MORPHINIZES_16172356110250914168)],
        &[(0b01001, &ENTRY_MORPHINIZATION_11750424731639276917)],
        &[(0b01001, &ENTRY_MORPHINIZATIONS_1979094451135743390)],
        &[(0b01001, &ENTRY_MORPHINIZE_6910565647915854125)],
        &[(0b01001, &ENTRY_MORPHINIZES_16172356110250914168)],
    ],
    range: 6..=11,
};

static VARS_MORN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORN_CHILDREN),
    value: None,
};

pub static VARS_MORN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ingly"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MORNE_17753311726489354450)],
        &[(0b00001, &ENTRY_MORNINGLY_14399084090041736439)],
    ],
    range: 1..=5,
};

static VARS_MORE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORE_CHILDREN),
    value: None,
};

pub static VARS_MORE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("a")],
    values: &[&[(0b00001, &ENTRY_MOREA_13514469338224390305)]],
    range: 1..=1,
};

static VARS_MORB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORB_CHILDREN),
    value: None,
};

pub static VARS_MORB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MORBIDIZE_4422039069430263560)],
        &[(0b10010, &ENTRY_MORBIDIZES_2796191092499149016)],
        &[(0b01001, &ENTRY_MORBIDIZE_4422039069430263560)],
        &[(0b01001, &ENTRY_MORBIDIZES_2796191092499149016)],
    ],
    range: 5..=6,
};

static VARS_MORA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MORA_CHILDREN),
    value: None,
};

pub static VARS_MORA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lisinglies"),
        dictgen::InsensitiveStr::Ascii("lisingly"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
        dictgen::InsensitiveStr::Ascii("lizinglies"),
        dictgen::InsensitiveStr::Ascii("lizingly"),
        dictgen::InsensitiveStr::Ascii("vianised"),
        dictgen::InsensitiveStr::Ascii("vianiseds"),
        dictgen::InsensitiveStr::Ascii("vianized"),
        dictgen::InsensitiveStr::Ascii("vianizeds"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MOREA_13514469338224390305)],
        &[(0b10010, &ENTRY_MORALIZATION_10080916313324833740)],
        &[(0b10010, &ENTRY_MORALIZATIONS_8810473373046257875)],
        &[(0b10010, &ENTRY_MORALIZE_18364245712417706650)],
        &[(0b10010, &ENTRY_MORALIZED_2663438308555906556)],
        &[(0b10010, &ENTRY_MORALIZER_4648462715987842582)],
        &[(0b10010, &ENTRY_MORALIZERS_3365413932300602681)],
        &[(0b10010, &ENTRY_MORALIZES_9224440599258696137)],
        &[(0b10010, &ENTRY_MORALIZING_3926799554184116665)],
        &[(0b10010, &ENTRY_MORALIZINGLIES_10462617487774496885)],
        &[(0b10010, &ENTRY_MORALIZINGLY_16347045591954328801)],
        &[(0b01001, &ENTRY_MORALIZATION_10080916313324833740)],
        &[(0b01001, &ENTRY_MORALIZATIONS_8810473373046257875)],
        &[(0b01001, &ENTRY_MORALIZE_18364245712417706650)],
        &[(0b01001, &ENTRY_MORALIZED_2663438308555906556)],
        &[(0b01001, &ENTRY_MORALIZER_4648462715987842582)],
        &[(0b01001, &ENTRY_MORALIZERS_3365413932300602681)],
        &[(0b01001, &ENTRY_MORALIZES_9224440599258696137)],
        &[(0b01001, &ENTRY_MORALIZING_3926799554184116665)],
        &[(0b01001, &ENTRY_MORALIZINGLIES_10462617487774496885)],
        &[(0b01001, &ENTRY_MORALIZINGLY_16347045591954328801)],
        &[(0b10010, &ENTRY_MORAVIANIZED_5701551634682247117)],
        &[(0b10010, &ENTRY_MORAVIANIZEDS_787565801428409365)],
        &[(0b01001, &ENTRY_MORAVIANIZED_5701551634682247117)],
        &[(0b01001, &ENTRY_MORAVIANIZEDS_787565801428409365)],
    ],
    range: 2..=10,
};

static VARS_MON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MON_CHILDREN),
    value: None,
};

static VARS_MON_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MONA_NODE),
    None,
    None,
    None,
    Some(&VARS_MONE_NODE),
    None,
    Some(&VARS_MONG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MONO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MONU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_MONU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONU_CHILDREN),
    value: None,
};

pub static VARS_MONU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mentalisation"),
        dictgen::InsensitiveStr::Ascii("mentalisations"),
        dictgen::InsensitiveStr::Ascii("mentalise"),
        dictgen::InsensitiveStr::Ascii("mentalised"),
        dictgen::InsensitiveStr::Ascii("mentalises"),
        dictgen::InsensitiveStr::Ascii("mentalising"),
        dictgen::InsensitiveStr::Ascii("mentalization"),
        dictgen::InsensitiveStr::Ascii("mentalizations"),
        dictgen::InsensitiveStr::Ascii("mentalize"),
        dictgen::InsensitiveStr::Ascii("mentalized"),
        dictgen::InsensitiveStr::Ascii("mentalizes"),
        dictgen::InsensitiveStr::Ascii("mentalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MONUMENTALIZATION_121908154863154321)],
        &[(0b10010, &ENTRY_MONUMENTALIZATIONS_14017609465373541851)],
        &[(0b10010, &ENTRY_MONUMENTALIZE_2877387938202021398)],
        &[(0b10010, &ENTRY_MONUMENTALIZED_10548767854996105071)],
        &[(0b10010, &ENTRY_MONUMENTALIZES_5130414847256959479)],
        &[(0b10010, &ENTRY_MONUMENTALIZING_8178737988254793694)],
        &[(0b01001, &ENTRY_MONUMENTALIZATION_121908154863154321)],
        &[(0b01001, &ENTRY_MONUMENTALIZATIONS_14017609465373541851)],
        &[(0b01001, &ENTRY_MONUMENTALIZE_2877387938202021398)],
        &[(0b01001, &ENTRY_MONUMENTALIZED_10548767854996105071)],
        &[(0b01001, &ENTRY_MONUMENTALIZES_5130414847256959479)],
        &[(0b01001, &ENTRY_MONUMENTALIZING_8178737988254793694)],
    ],
    range: 9..=14,
};

static VARS_MONO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONO_CHILDREN),
    value: None,
};

pub static VARS_MONO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chordise"),
        dictgen::InsensitiveStr::Ascii("chordises"),
        dictgen::InsensitiveStr::Ascii("chordize"),
        dictgen::InsensitiveStr::Ascii("chordizes"),
        dictgen::InsensitiveStr::Ascii("ecian"),
        dictgen::InsensitiveStr::Ascii("estrous"),
        dictgen::InsensitiveStr::Ascii("log"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("logs"),
        dictgen::InsensitiveStr::Ascii("loguise"),
        dictgen::InsensitiveStr::Ascii("loguised"),
        dictgen::InsensitiveStr::Ascii("loguises"),
        dictgen::InsensitiveStr::Ascii("loguising"),
        dictgen::InsensitiveStr::Ascii("loguize"),
        dictgen::InsensitiveStr::Ascii("loguized"),
        dictgen::InsensitiveStr::Ascii("loguizes"),
        dictgen::InsensitiveStr::Ascii("loguizing"),
        dictgen::InsensitiveStr::Ascii("metalism"),
        dictgen::InsensitiveStr::Ascii("metalist"),
        dictgen::InsensitiveStr::Ascii("metallism"),
        dictgen::InsensitiveStr::Ascii("metallist"),
        dictgen::InsensitiveStr::Ascii("phthongise"),
        dictgen::InsensitiveStr::Ascii("phthongised"),
        dictgen::InsensitiveStr::Ascii("phthongises"),
        dictgen::InsensitiveStr::Ascii("phthongising"),
        dictgen::InsensitiveStr::Ascii("phthongize"),
        dictgen::InsensitiveStr::Ascii("phthongized"),
        dictgen::InsensitiveStr::Ascii("phthongizes"),
        dictgen::InsensitiveStr::Ascii("phthongizing"),
        dictgen::InsensitiveStr::Ascii("polisable"),
        dictgen::InsensitiveStr::Ascii("polisables"),
        dictgen::InsensitiveStr::Ascii("polisation"),
        dictgen::InsensitiveStr::Ascii("polisations"),
        dictgen::InsensitiveStr::Ascii("polise"),
        dictgen::InsensitiveStr::Ascii("polised"),
        dictgen::InsensitiveStr::Ascii("poliser"),
        dictgen::InsensitiveStr::Ascii("polisers"),
        dictgen::InsensitiveStr::Ascii("polises"),
        dictgen::InsensitiveStr::Ascii("polising"),
        dictgen::InsensitiveStr::Ascii("polizable"),
        dictgen::InsensitiveStr::Ascii("polizables"),
        dictgen::InsensitiveStr::Ascii("polization"),
        dictgen::InsensitiveStr::Ascii("polizations"),
        dictgen::InsensitiveStr::Ascii("polize"),
        dictgen::InsensitiveStr::Ascii("polized"),
        dictgen::InsensitiveStr::Ascii("polizer"),
        dictgen::InsensitiveStr::Ascii("polizers"),
        dictgen::InsensitiveStr::Ascii("polizes"),
        dictgen::InsensitiveStr::Ascii("polizing"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MONOCHORDIZE_16797802444325265589)],
        &[(0b10010, &ENTRY_MONOCHORDIZES_3579118842327693619)],
        &[(0b01001, &ENTRY_MONOCHORDIZE_16797802444325265589)],
        &[(0b01001, &ENTRY_MONOCHORDIZES_3579118842327693619)],
        &[(0b11010, &ENTRY_MONECIAN_4879335142867519038)],
        &[(0b11010, &ENTRY_MONESTROUS_18265353223508436919)],
        &[(0b00001, &ENTRY_MONOLOGUE_817979629647456661)],
        &[(0b10010, &ENTRY_MONOLOGIZE_4785562031381064606)],
        &[(0b10010, &ENTRY_MONOLOGIZED_213349531977540597)],
        &[(0b10010, &ENTRY_MONOLOGIZES_1530471276833382712)],
        &[(0b10010, &ENTRY_MONOLOGIZING_12574433078846769687)],
        &[(0b01001, &ENTRY_MONOLOGIZE_4785562031381064606)],
        &[(0b01001, &ENTRY_MONOLOGIZED_213349531977540597)],
        &[(0b01001, &ENTRY_MONOLOGIZES_1530471276833382712)],
        &[(0b01001, &ENTRY_MONOLOGIZING_12574433078846769687)],
        &[(0b00001, &ENTRY_MONOLOGUES_14056042492962235985)],
        &[(0b10010, &ENTRY_MONOLOGUIZE_7317088988238212245)],
        &[(0b10010, &ENTRY_MONOLOGUIZED_12070685860799121235)],
        &[(0b10010, &ENTRY_MONOLOGUIZES_8634308732447205916)],
        &[(0b10010, &ENTRY_MONOLOGUIZING_4287361179938192317)],
        &[(0b01001, &ENTRY_MONOLOGUIZE_7317088988238212245)],
        &[(0b01001, &ENTRY_MONOLOGUIZED_12070685860799121235)],
        &[(0b01001, &ENTRY_MONOLOGUIZES_8634308732447205916)],
        &[(0b01001, &ENTRY_MONOLOGUIZING_4287361179938192317)],
        &[(0b00001, &ENTRY_MONOMETALISM_8091416002209379789)],
        &[(0b00001, &ENTRY_MONOMETALIST_5609217238808194836)],
        &[(0b11010, &ENTRY_MONOMETALISM_8091416002209379789)],
        &[(0b11010, &ENTRY_MONOMETALIST_5609217238808194836)],
        &[(0b10010, &ENTRY_MONOPHTHONGIZE_15612903189375621340)],
        &[(0b10010, &ENTRY_MONOPHTHONGIZED_4506738263874777552)],
        &[(0b10010, &ENTRY_MONOPHTHONGIZES_3173126843603137132)],
        &[(0b10010, &ENTRY_MONOPHTHONGIZING_14459102910824259938)],
        &[(0b01001, &ENTRY_MONOPHTHONGIZE_15612903189375621340)],
        &[(0b01001, &ENTRY_MONOPHTHONGIZED_4506738263874777552)],
        &[(0b01001, &ENTRY_MONOPHTHONGIZES_3173126843603137132)],
        &[(0b01001, &ENTRY_MONOPHTHONGIZING_14459102910824259938)],
        &[(0b10010, &ENTRY_MONOPOLIZABLE_1632547963531180162)],
        &[(0b10010, &ENTRY_MONOPOLIZABLES_12699234714582217629)],
        &[(0b10010, &ENTRY_MONOPOLIZATION_1307231799538469152)],
        &[(0b10010, &ENTRY_MONOPOLIZATIONS_6331549890119342959)],
        &[(0b10010, &ENTRY_MONOPOLIZE_8487708636905491508)],
        &[(0b10010, &ENTRY_MONOPOLIZED_10461001871096365991)],
        &[(0b10010, &ENTRY_MONOPOLIZER_4531543055588283266)],
        &[(0b10010, &ENTRY_MONOPOLIZERS_10073312732774245724)],
        &[(0b10010, &ENTRY_MONOPOLIZES_6838092214769726019)],
        &[(0b10010, &ENTRY_MONOPOLIZING_13178768662367110962)],
        &[(0b01001, &ENTRY_MONOPOLIZABLE_1632547963531180162)],
        &[(0b01001, &ENTRY_MONOPOLIZABLES_12699234714582217629)],
        &[(0b01001, &ENTRY_MONOPOLIZATION_1307231799538469152)],
        &[(0b01001, &ENTRY_MONOPOLIZATIONS_6331549890119342959)],
        &[(0b01001, &ENTRY_MONOPOLIZE_8487708636905491508)],
        &[(0b01001, &ENTRY_MONOPOLIZED_10461001871096365991)],
        &[(0b01001, &ENTRY_MONOPOLIZER_4531543055588283266)],
        &[(0b01001, &ENTRY_MONOPOLIZERS_10073312732774245724)],
        &[(0b01001, &ENTRY_MONOPOLIZES_6838092214769726019)],
        &[(0b01001, &ENTRY_MONOPOLIZING_13178768662367110962)],
        &[(0b10010, &ENTRY_MONOTONIZE_4339817040805963103)],
        &[(0b10010, &ENTRY_MONOTONIZES_771494355341239370)],
        &[(0b01001, &ENTRY_MONOTONIZE_4339817040805963103)],
        &[(0b01001, &ENTRY_MONOTONIZES_771494355341239370)],
    ],
    range: 3..=12,
};

static VARS_MONG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONG_CHILDREN),
    value: None,
};

pub static VARS_MONG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
        dictgen::InsensitiveStr::Ascii("relisation"),
        dictgen::InsensitiveStr::Ascii("relisations"),
        dictgen::InsensitiveStr::Ascii("relise"),
        dictgen::InsensitiveStr::Ascii("relised"),
        dictgen::InsensitiveStr::Ascii("reliser"),
        dictgen::InsensitiveStr::Ascii("relises"),
        dictgen::InsensitiveStr::Ascii("relising"),
        dictgen::InsensitiveStr::Ascii("relization"),
        dictgen::InsensitiveStr::Ascii("relizations"),
        dictgen::InsensitiveStr::Ascii("relize"),
        dictgen::InsensitiveStr::Ascii("relized"),
        dictgen::InsensitiveStr::Ascii("relizer"),
        dictgen::InsensitiveStr::Ascii("relizes"),
        dictgen::InsensitiveStr::Ascii("relizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MONGOLIZE_3876217931633008306)],
        &[(0b10010, &ENTRY_MONGOLIZED_7180490123154768644)],
        &[(0b10010, &ENTRY_MONGOLIZES_14233973300159557786)],
        &[(0b10010, &ENTRY_MONGOLIZING_316291781280258543)],
        &[(0b01001, &ENTRY_MONGOLIZE_3876217931633008306)],
        &[(0b01001, &ENTRY_MONGOLIZED_7180490123154768644)],
        &[(0b01001, &ENTRY_MONGOLIZES_14233973300159557786)],
        &[(0b01001, &ENTRY_MONGOLIZING_316291781280258543)],
        &[(0b10010, &ENTRY_MONGRELIZATION_4498531267273755020)],
        &[(0b10010, &ENTRY_MONGRELIZATIONS_4344310052877835528)],
        &[(0b10010, &ENTRY_MONGRELIZE_9330914540755997377)],
        &[(0b10010, &ENTRY_MONGRELIZED_337807322341455274)],
        &[(0b10010, &ENTRY_MONGRELIZER_820251071432420034)],
        &[(0b10010, &ENTRY_MONGRELIZES_12163647302918101422)],
        &[(0b10010, &ENTRY_MONGRELIZING_3846168385938703815)],
        &[(0b01001, &ENTRY_MONGRELIZATION_4498531267273755020)],
        &[(0b01001, &ENTRY_MONGRELIZATIONS_4344310052877835528)],
        &[(0b01001, &ENTRY_MONGRELIZE_9330914540755997377)],
        &[(0b01001, &ENTRY_MONGRELIZED_337807322341455274)],
        &[(0b01001, &ENTRY_MONGRELIZER_820251071432420034)],
        &[(0b01001, &ENTRY_MONGRELIZES_12163647302918101422)],
        &[(0b01001, &ENTRY_MONGRELIZING_3846168385938703815)],
    ],
    range: 5..=11,
};

static VARS_MONE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONE_CHILDREN),
    value: None,
};

pub static VARS_MONE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cian"),
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("strous"),
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tisations"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tizations"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MONECIAN_4879335142867519038)],
        &[(0b00001, &ENTRY_MONOECIOUS_16926061790085197953)],
        &[(0b00001, &ENTRY_MONESTROUS_18265353223508436919)],
        &[(0b10010, &ENTRY_MONETIZATION_14707832132850700848)],
        &[(0b10010, &ENTRY_MONETIZATIONS_17875812136896605805)],
        &[(0b10010, &ENTRY_MONETIZE_11872297589880053114)],
        &[(0b10010, &ENTRY_MONETIZED_16824817034586571013)],
        &[(0b10010, &ENTRY_MONETIZES_10634709768412203424)],
        &[(0b10010, &ENTRY_MONETIZING_15158826539636538785)],
        &[(0b01001, &ENTRY_MONETIZATION_14707832132850700848)],
        &[(0b01001, &ENTRY_MONETIZATIONS_17875812136896605805)],
        &[(0b01001, &ENTRY_MONETIZE_11872297589880053114)],
        &[(0b01001, &ENTRY_MONETIZED_16824817034586571013)],
        &[(0b01001, &ENTRY_MONETIZES_10634709768412203424)],
        &[(0b01001, &ENTRY_MONETIZING_15158826539636538785)],
    ],
    range: 4..=9,
};

static VARS_MONA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MONA_CHILDREN),
    value: None,
};

pub static VARS_MONA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rchise"),
        dictgen::InsensitiveStr::Ascii("rchised"),
        dictgen::InsensitiveStr::Ascii("rchiser"),
        dictgen::InsensitiveStr::Ascii("rchisers"),
        dictgen::InsensitiveStr::Ascii("rchises"),
        dictgen::InsensitiveStr::Ascii("rchising"),
        dictgen::InsensitiveStr::Ascii("rchize"),
        dictgen::InsensitiveStr::Ascii("rchized"),
        dictgen::InsensitiveStr::Ascii("rchizer"),
        dictgen::InsensitiveStr::Ascii("rchizers"),
        dictgen::InsensitiveStr::Ascii("rchizes"),
        dictgen::InsensitiveStr::Ascii("rchizing"),
        dictgen::InsensitiveStr::Ascii("sticise"),
        dictgen::InsensitiveStr::Ascii("sticises"),
        dictgen::InsensitiveStr::Ascii("sticize"),
        dictgen::InsensitiveStr::Ascii("sticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MONARCHIZE_15594788008045550047)],
        &[(0b10010, &ENTRY_MONARCHIZED_5463371092470864555)],
        &[(0b10010, &ENTRY_MONARCHIZER_855097092908696109)],
        &[(0b10010, &ENTRY_MONARCHIZERS_16942324140335093566)],
        &[(0b10010, &ENTRY_MONARCHIZES_6119101542364042858)],
        &[(0b10010, &ENTRY_MONARCHIZING_8557056119920625430)],
        &[(0b01001, &ENTRY_MONARCHIZE_15594788008045550047)],
        &[(0b01001, &ENTRY_MONARCHIZED_5463371092470864555)],
        &[(0b01001, &ENTRY_MONARCHIZER_855097092908696109)],
        &[(0b01001, &ENTRY_MONARCHIZERS_16942324140335093566)],
        &[(0b01001, &ENTRY_MONARCHIZES_6119101542364042858)],
        &[(0b01001, &ENTRY_MONARCHIZING_8557056119920625430)],
        &[(0b10010, &ENTRY_MONASTICIZE_5086142104694058939)],
        &[(0b10010, &ENTRY_MONASTICIZES_11754670453138255334)],
        &[(0b01001, &ENTRY_MONASTICIZE_5086142104694058939)],
        &[(0b01001, &ENTRY_MONASTICIZES_11754670453138255334)],
    ],
    range: 6..=8,
};

static VARS_MOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOM_CHILDREN),
    value: Some(&[(0b01001, &ENTRY_MOM_1933585215034313561)]),
};

pub static VARS_MOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b01001, &ENTRY_MOMS_301669076590401125)]],
    range: 1..=1,
};

static VARS_MOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOL_CHILDREN),
    value: None,
};

pub static VARS_MOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arisation"),
        dictgen::InsensitiveStr::Ascii("arisations"),
        dictgen::InsensitiveStr::Ascii("arization"),
        dictgen::InsensitiveStr::Ascii("arizations"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ded"),
        dictgen::InsensitiveStr::Ascii("der"),
        dictgen::InsensitiveStr::Ascii("dered"),
        dictgen::InsensitiveStr::Ascii("dering"),
        dictgen::InsensitiveStr::Ascii("ders"),
        dictgen::InsensitiveStr::Ascii("dier"),
        dictgen::InsensitiveStr::Ascii("diest"),
        dictgen::InsensitiveStr::Ascii("ding"),
        dictgen::InsensitiveStr::Ascii("dings"),
        dictgen::InsensitiveStr::Ascii("ds"),
        dictgen::InsensitiveStr::Ascii("dy"),
        dictgen::InsensitiveStr::Ascii("lusk"),
        dictgen::InsensitiveStr::Ascii("luskan"),
        dictgen::InsensitiveStr::Ascii("lusks"),
        dictgen::InsensitiveStr::Ascii("ochise"),
        dictgen::InsensitiveStr::Ascii("ochised"),
        dictgen::InsensitiveStr::Ascii("ochises"),
        dictgen::InsensitiveStr::Ascii("ochising"),
        dictgen::InsensitiveStr::Ascii("ochize"),
        dictgen::InsensitiveStr::Ascii("ochized"),
        dictgen::InsensitiveStr::Ascii("ochizes"),
        dictgen::InsensitiveStr::Ascii("ochizing"),
        dictgen::InsensitiveStr::Ascii("t"),
        dictgen::InsensitiveStr::Ascii("ted"),
        dictgen::InsensitiveStr::Ascii("ting"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOLARIZATION_17680920592577594623)],
        &[(0b10010, &ENTRY_MOLARIZATIONS_12398118473905254189)],
        &[(0b01001, &ENTRY_MOLARIZATION_17680920592577594623)],
        &[(0b01001, &ENTRY_MOLARIZATIONS_12398118473905254189)],
        &[(0b11001, &ENTRY_MOLD_4204617930046953090)],
        &[(0b11001, &ENTRY_MOLDED_4867396599674557897)],
        &[(0b10001, &ENTRY_MOLDER_5468513924454038075)],
        &[(0b10001, &ENTRY_MOLDERED_13806811290362462856)],
        &[(0b10001, &ENTRY_MOLDERING_761432945987723341)],
        &[(0b10001, &ENTRY_MOLDERS_10624195404241411222)],
        &[(0b11001, &ENTRY_MOLDIER_17925953827043179593)],
        &[(0b11001, &ENTRY_MOLDIEST_11552700490364540702)],
        &[(0b11001, &ENTRY_MOLDING_16972516311440379476)],
        &[(0b11001, &ENTRY_MOLDINGS_11877581157093154122)],
        &[(0b11001, &ENTRY_MOLDS_209402696956725647)],
        &[(0b11001, &ENTRY_MOLDY_15469792360276639207)],
        &[(0b00001, &ENTRY_MOLLUSK_11723969351177528383)],
        &[(0b00001, &ENTRY_MOLLUSCAN_1214531649444858741)],
        &[(0b00001, &ENTRY_MOLLUSKS_7855528336644805045)],
        &[(0b10010, &ENTRY_MOLOCHIZE_10281963447149464183)],
        &[(0b10010, &ENTRY_MOLOCHIZED_9592437975186863992)],
        &[(0b10010, &ENTRY_MOLOCHIZES_5328704096373944300)],
        &[(0b10010, &ENTRY_MOLOCHIZING_4942125478827957915)],
        &[(0b01001, &ENTRY_MOLOCHIZE_10281963447149464183)],
        &[(0b01001, &ENTRY_MOLOCHIZED_9592437975186863992)],
        &[(0b01001, &ENTRY_MOLOCHIZES_5328704096373944300)],
        &[(0b01001, &ENTRY_MOLOCHIZING_4942125478827957915)],
        &[(0b10001, &ENTRY_MOLT_13673484917001179046)],
        &[(0b10001, &ENTRY_MOLTED_13851575492873022320)],
        &[(0b10001, &ENTRY_MOLTING_8969305985716783845)],
        &[(0b10001, &ENTRY_MOLTS_10499278002715999239)],
    ],
    range: 1..=10,
};

static VARS_MOI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOI_CHILDREN),
    value: None,
};

pub static VARS_MOI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sturisation"),
        dictgen::InsensitiveStr::Ascii("sturise"),
        dictgen::InsensitiveStr::Ascii("sturised"),
        dictgen::InsensitiveStr::Ascii("sturiser"),
        dictgen::InsensitiveStr::Ascii("sturisers"),
        dictgen::InsensitiveStr::Ascii("sturises"),
        dictgen::InsensitiveStr::Ascii("sturising"),
        dictgen::InsensitiveStr::Ascii("sturization"),
        dictgen::InsensitiveStr::Ascii("sturize"),
        dictgen::InsensitiveStr::Ascii("sturized"),
        dictgen::InsensitiveStr::Ascii("sturizer"),
        dictgen::InsensitiveStr::Ascii("sturizers"),
        dictgen::InsensitiveStr::Ascii("sturizes"),
        dictgen::InsensitiveStr::Ascii("sturizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOISTURIZATION_14359328382639845392)],
        &[(0b10010, &ENTRY_MOISTURIZE_7565680035125417251)],
        &[(0b10010, &ENTRY_MOISTURIZED_3672738717919459176)],
        &[(0b10010, &ENTRY_MOISTURIZER_15515955640030709734)],
        &[(0b10010, &ENTRY_MOISTURIZERS_3778922692605477146)],
        &[(0b10010, &ENTRY_MOISTURIZES_12009510094905479817)],
        &[(0b10010, &ENTRY_MOISTURIZING_13406294210722157217)],
        &[(0b01001, &ENTRY_MOISTURIZATION_14359328382639845392)],
        &[(0b01001, &ENTRY_MOISTURIZE_7565680035125417251)],
        &[(0b01001, &ENTRY_MOISTURIZED_3672738717919459176)],
        &[(0b01001, &ENTRY_MOISTURIZER_15515955640030709734)],
        &[(0b01001, &ENTRY_MOISTURIZERS_3778922692605477146)],
        &[(0b01001, &ENTRY_MOISTURIZES_12009510094905479817)],
        &[(0b01001, &ENTRY_MOISTURIZING_13406294210722157217)],
    ],
    range: 7..=11,
};

static VARS_MOH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOH_CHILDREN),
    value: None,
};

pub static VARS_MOH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ammedanisation"),
        dictgen::InsensitiveStr::Ascii("ammedanisations"),
        dictgen::InsensitiveStr::Ascii("ammedanise"),
        dictgen::InsensitiveStr::Ascii("ammedanised"),
        dictgen::InsensitiveStr::Ascii("ammedanises"),
        dictgen::InsensitiveStr::Ascii("ammedanising"),
        dictgen::InsensitiveStr::Ascii("ammedanization"),
        dictgen::InsensitiveStr::Ascii("ammedanizations"),
        dictgen::InsensitiveStr::Ascii("ammedanize"),
        dictgen::InsensitiveStr::Ascii("ammedanized"),
        dictgen::InsensitiveStr::Ascii("ammedanizes"),
        dictgen::InsensitiveStr::Ascii("ammedanizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOHAMMEDANIZATION_4942477043569377601)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZATIONS_4617417514155359733)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZE_2941075096626155541)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZED_9776130510036028314)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZES_18373426896542622891)],
        &[(0b10010, &ENTRY_MOHAMMEDANIZING_1483796922327274666)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZATION_4942477043569377601)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZATIONS_4617417514155359733)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZE_2941075096626155541)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZED_9776130510036028314)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZES_18373426896542622891)],
        &[(0b01001, &ENTRY_MOHAMMEDANIZING_1483796922327274666)],
    ],
    range: 10..=15,
};

static VARS_MOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOG_CHILDREN),
    value: None,
};

pub static VARS_MOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("gy")],
    values: &[&[(0b10011, &ENTRY_MOGGY_579730209646920518)]],
    range: 2..=2,
};

static VARS_MOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOE_CHILDREN),
    value: None,
};

pub static VARS_MOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ck"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("llon"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MECK_5443554356343726238)],
        &[(0b11010, &ENTRY_MED_5581722660439194258)],
        &[(0b11010, &ENTRY_MELLON_391954139899810285)],
    ],
    range: 1..=4,
};

static VARS_MOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOD_CHILDREN),
    value: None,
};

pub static VARS_MOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
        dictgen::InsensitiveStr::Ascii("ernisable"),
        dictgen::InsensitiveStr::Ascii("ernisables"),
        dictgen::InsensitiveStr::Ascii("ernisation"),
        dictgen::InsensitiveStr::Ascii("ernisations"),
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernised"),
        dictgen::InsensitiveStr::Ascii("erniser"),
        dictgen::InsensitiveStr::Ascii("ernisers"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernising"),
        dictgen::InsensitiveStr::Ascii("ernizable"),
        dictgen::InsensitiveStr::Ascii("ernizables"),
        dictgen::InsensitiveStr::Ascii("ernization"),
        dictgen::InsensitiveStr::Ascii("ernizations"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernized"),
        dictgen::InsensitiveStr::Ascii("ernizer"),
        dictgen::InsensitiveStr::Ascii("ernizers"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
        dictgen::InsensitiveStr::Ascii("ernizing"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MODALIZE_5407143044061821916)],
        &[(0b10010, &ENTRY_MODALIZES_16162099476273051141)],
        &[(0b01001, &ENTRY_MODALIZE_5407143044061821916)],
        &[(0b01001, &ENTRY_MODALIZES_16162099476273051141)],
        &[(0b00001, &ENTRY_MODELED_11484485171487146129)],
        &[(0b00001, &ENTRY_MODELER_15810368749048552373)],
        &[(0b00001, &ENTRY_MODELERS_1650738308079465867)],
        &[(0b00001, &ENTRY_MODELING_16661180513183857784)],
        &[(0b00001, &ENTRY_MODELINGS_7972192595739783612)],
        &[(0b11010, &ENTRY_MODELED_11484485171487146129)],
        &[(0b11010, &ENTRY_MODELER_15810368749048552373)],
        &[(0b11010, &ENTRY_MODELERS_1650738308079465867)],
        &[(0b11010, &ENTRY_MODELING_16661180513183857784)],
        &[(0b11010, &ENTRY_MODELINGS_7972192595739783612)],
        &[(0b10010, &ENTRY_MODERNIZABLE_18104998027667857415)],
        &[(0b10010, &ENTRY_MODERNIZABLES_10916683662176279423)],
        &[(0b10010, &ENTRY_MODERNIZATION_12042012760824050298)],
        &[(0b10010, &ENTRY_MODERNIZATIONS_3434518085505458555)],
        &[(0b10010, &ENTRY_MODERNIZE_16764604267655437202)],
        &[(0b10010, &ENTRY_MODERNIZED_2831927114827207033)],
        &[(0b10010, &ENTRY_MODERNIZER_18085383743865602462)],
        &[(0b10010, &ENTRY_MODERNIZERS_7055005025004923190)],
        &[(0b10010, &ENTRY_MODERNIZES_9697284314317925697)],
        &[(0b10010, &ENTRY_MODERNIZING_12238279341877582234)],
        &[(0b01001, &ENTRY_MODERNIZABLE_18104998027667857415)],
        &[(0b01001, &ENTRY_MODERNIZABLES_10916683662176279423)],
        &[(0b01001, &ENTRY_MODERNIZATION_12042012760824050298)],
        &[(0b01001, &ENTRY_MODERNIZATIONS_3434518085505458555)],
        &[(0b01001, &ENTRY_MODERNIZE_16764604267655437202)],
        &[(0b01001, &ENTRY_MODERNIZED_2831927114827207033)],
        &[(0b01001, &ENTRY_MODERNIZER_18085383743865602462)],
        &[(0b01001, &ENTRY_MODERNIZERS_7055005025004923190)],
        &[(0b01001, &ENTRY_MODERNIZES_9697284314317925697)],
        &[(0b01001, &ENTRY_MODERNIZING_12238279341877582234)],
        &[(0b10010, &ENTRY_MODULARIZATION_3680687403533449721)],
        &[(0b10010, &ENTRY_MODULARIZE_7661020760191995153)],
        &[(0b10010, &ENTRY_MODULARIZED_13090071993675981622)],
        &[(0b10010, &ENTRY_MODULARIZES_734923478071063897)],
        &[(0b10010, &ENTRY_MODULARIZING_15219616854242753285)],
        &[(0b01001, &ENTRY_MODULARIZATION_3680687403533449721)],
        &[(0b01001, &ENTRY_MODULARIZE_7661020760191995153)],
        &[(0b01001, &ENTRY_MODULARIZED_13090071993675981622)],
        &[(0b01001, &ENTRY_MODULARIZES_734923478071063897)],
        &[(0b01001, &ENTRY_MODULARIZING_15219616854242753285)],
    ],
    range: 4..=11,
};

static VARS_MOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MOB_CHILDREN),
    value: None,
};

pub static VARS_MOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilisable"),
        dictgen::InsensitiveStr::Ascii("ilisabler"),
        dictgen::InsensitiveStr::Ascii("ilisables"),
        dictgen::InsensitiveStr::Ascii("ilisablest"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("iliser"),
        dictgen::InsensitiveStr::Ascii("ilisers"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilizable"),
        dictgen::InsensitiveStr::Ascii("ilizabler"),
        dictgen::InsensitiveStr::Ascii("ilizables"),
        dictgen::InsensitiveStr::Ascii("ilizablest"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizer"),
        dictgen::InsensitiveStr::Ascii("ilizers"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MOBILIZABLE_12252941647214817128)],
        &[(0b10010, &ENTRY_MOBILIZABLER_10904297470856896702)],
        &[(0b10010, &ENTRY_MOBILIZABLES_4178976069735614840)],
        &[(0b10010, &ENTRY_MOBILIZABLEST_15444054356148134406)],
        &[(0b10010, &ENTRY_MOBILIZATION_12561905628389471063)],
        &[(0b10010, &ENTRY_MOBILIZATIONS_2426490826167845431)],
        &[(0b10010, &ENTRY_MOBILIZE_4102809031800805050)],
        &[(0b10010, &ENTRY_MOBILIZED_13415546459102928772)],
        &[(0b10010, &ENTRY_MOBILIZER_12434984457191425108)],
        &[(0b10010, &ENTRY_MOBILIZERS_13019397665994940764)],
        &[(0b10010, &ENTRY_MOBILIZES_17265459453729317116)],
        &[(0b10010, &ENTRY_MOBILIZING_1050354789096204914)],
        &[(0b01001, &ENTRY_MOBILIZABLE_12252941647214817128)],
        &[(0b01001, &ENTRY_MOBILIZABLER_10904297470856896702)],
        &[(0b01001, &ENTRY_MOBILIZABLES_4178976069735614840)],
        &[(0b01001, &ENTRY_MOBILIZABLEST_15444054356148134406)],
        &[(0b01001, &ENTRY_MOBILIZATION_12561905628389471063)],
        &[(0b01001, &ENTRY_MOBILIZATIONS_2426490826167845431)],
        &[(0b01001, &ENTRY_MOBILIZE_4102809031800805050)],
        &[(0b01001, &ENTRY_MOBILIZED_13415546459102928772)],
        &[(0b01001, &ENTRY_MOBILIZER_12434984457191425108)],
        &[(0b01001, &ENTRY_MOBILIZERS_13019397665994940764)],
        &[(0b01001, &ENTRY_MOBILIZES_17265459453729317116)],
        &[(0b01001, &ENTRY_MOBILIZING_1050354789096204914)],
    ],
    range: 5..=10,
};

static VARS_MI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MI_CHILDREN),
    value: None,
};

static VARS_MI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MIA_NODE),
    None,
    Some(&VARS_MIC_NODE),
    Some(&VARS_MID_NODE),
    None,
    None,
    Some(&VARS_MIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_MIL_NODE),
    None,
    Some(&VARS_MIN_NODE),
    None,
    None,
    None,
    Some(&VARS_MIR_NODE),
    Some(&VARS_MIS_NODE),
    Some(&VARS_MIT_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MIZ_NODE),
];

static VARS_MIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIZ_CHILDREN),
    value: None,
};

pub static VARS_MIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b01001, &ENTRY_MIZE_2563563095806882396)]],
    range: 1..=1,
};

static VARS_MIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIT_CHILDREN),
    value: None,
};

pub static VARS_MIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ered"),
        dictgen::InsensitiveStr::Ascii("erer"),
        dictgen::InsensitiveStr::Ascii("erflower"),
        dictgen::InsensitiveStr::Ascii("ering"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("erwort"),
        dictgen::InsensitiveStr::Ascii("erworts"),
        dictgen::InsensitiveStr::Ascii("hridatise"),
        dictgen::InsensitiveStr::Ascii("hridatised"),
        dictgen::InsensitiveStr::Ascii("hridatises"),
        dictgen::InsensitiveStr::Ascii("hridatising"),
        dictgen::InsensitiveStr::Ascii("hridatize"),
        dictgen::InsensitiveStr::Ascii("hridatized"),
        dictgen::InsensitiveStr::Ascii("hridatizes"),
        dictgen::InsensitiveStr::Ascii("hridatizing"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("reflower"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("rewort"),
        dictgen::InsensitiveStr::Ascii("reworts"),
        dictgen::InsensitiveStr::Ascii("ring"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MITER_5926274060174606640)],
        &[(0b00001, &ENTRY_MITERED_5787585051744125345)],
        &[(0b00001, &ENTRY_MITERER_825284550887492153)],
        &[(0b00001, &ENTRY_MITERFLOWER_5319553020008949441)],
        &[(0b00001, &ENTRY_MITERING_4790682826218652875)],
        &[(0b00001, &ENTRY_MITERS_14490210158644236688)],
        &[(0b00001, &ENTRY_MITERWORT_1811552736091417438)],
        &[(0b00001, &ENTRY_MITERWORTS_2595793822662820807)],
        &[(0b10010, &ENTRY_MITHRIDATIZE_10215083672393880782)],
        &[(0b10010, &ENTRY_MITHRIDATIZED_11801964586289066812)],
        &[(0b10010, &ENTRY_MITHRIDATIZES_10858785786810308998)],
        &[(0b10010, &ENTRY_MITHRIDATIZING_9625317964263865406)],
        &[(0b01001, &ENTRY_MITHRIDATIZE_10215083672393880782)],
        &[(0b01001, &ENTRY_MITHRIDATIZED_11801964586289066812)],
        &[(0b01001, &ENTRY_MITHRIDATIZES_10858785786810308998)],
        &[(0b01001, &ENTRY_MITHRIDATIZING_9625317964263865406)],
        &[(0b11010, &ENTRY_MITER_5926274060174606640)],
        &[(0b11010, &ENTRY_MITERED_5787585051744125345)],
        &[(0b11010, &ENTRY_MITERFLOWER_5319553020008949441)],
        &[(0b11010, &ENTRY_MITERER_825284550887492153)],
        &[(0b11010, &ENTRY_MITERS_14490210158644236688)],
        &[(0b11010, &ENTRY_MITERWORT_1811552736091417438)],
        &[(0b11010, &ENTRY_MITERWORTS_2595793822662820807)],
        &[(0b11010, &ENTRY_MITERING_4790682826218652875)],
    ],
    range: 2..=11,
};

static VARS_MIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MIS_CHILDREN),
    value: None,
};

static VARS_MIS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MISA_NODE),
    Some(&VARS_MISB_NODE),
    Some(&VARS_MISC_NODE),
    Some(&VARS_MISD_NODE),
    Some(&VARS_MISE_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_MISJ_NODE),
    None,
    Some(&VARS_MISL_NODE),
    None,
    None,
    Some(&VARS_MISO_NODE),
    Some(&VARS_MISP_NODE),
    None,
    Some(&VARS_MISR_NODE),
    Some(&VARS_MISS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_MISS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISS_CHILDREN),
    value: None,
};

pub static VARS_MISS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ionarise"),
        dictgen::InsensitiveStr::Ascii("ionarised"),
        dictgen::InsensitiveStr::Ascii("ionarises"),
        dictgen::InsensitiveStr::Ascii("ionarising"),
        dictgen::InsensitiveStr::Ascii("ionarize"),
        dictgen::InsensitiveStr::Ascii("ionarized"),
        dictgen::InsensitiveStr::Ascii("ionarizes"),
        dictgen::InsensitiveStr::Ascii("ionarizing"),
        dictgen::InsensitiveStr::Ascii("ionisation"),
        dictgen::InsensitiveStr::Ascii("ionise"),
        dictgen::InsensitiveStr::Ascii("ionised"),
        dictgen::InsensitiveStr::Ascii("ioniser"),
        dictgen::InsensitiveStr::Ascii("ionisers"),
        dictgen::InsensitiveStr::Ascii("ionises"),
        dictgen::InsensitiveStr::Ascii("ionising"),
        dictgen::InsensitiveStr::Ascii("ionization"),
        dictgen::InsensitiveStr::Ascii("ionize"),
        dictgen::InsensitiveStr::Ascii("ionized"),
        dictgen::InsensitiveStr::Ascii("ionizer"),
        dictgen::InsensitiveStr::Ascii("ionizers"),
        dictgen::InsensitiveStr::Ascii("ionizes"),
        dictgen::InsensitiveStr::Ascii("ionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISSIONARIZE_9166622119973962629)],
        &[(0b10010, &ENTRY_MISSIONARIZED_7112814104506945817)],
        &[(0b10010, &ENTRY_MISSIONARIZES_13632702496680971142)],
        &[(0b10010, &ENTRY_MISSIONARIZING_15494487339870146163)],
        &[(0b01001, &ENTRY_MISSIONARIZE_9166622119973962629)],
        &[(0b01001, &ENTRY_MISSIONARIZED_7112814104506945817)],
        &[(0b01001, &ENTRY_MISSIONARIZES_13632702496680971142)],
        &[(0b01001, &ENTRY_MISSIONARIZING_15494487339870146163)],
        &[(0b10010, &ENTRY_MISSIONIZATION_3188593491464992438)],
        &[(0b10010, &ENTRY_MISSIONIZE_4938980905954929367)],
        &[(0b10010, &ENTRY_MISSIONIZED_17672523180481949130)],
        &[(0b10010, &ENTRY_MISSIONIZER_16128334848487303471)],
        &[(0b10010, &ENTRY_MISSIONIZERS_9999401875646897234)],
        &[(0b10010, &ENTRY_MISSIONIZES_14585446178899362762)],
        &[(0b10010, &ENTRY_MISSIONIZING_7220648756581988180)],
        &[(0b01001, &ENTRY_MISSIONIZATION_3188593491464992438)],
        &[(0b01001, &ENTRY_MISSIONIZE_4938980905954929367)],
        &[(0b01001, &ENTRY_MISSIONIZED_17672523180481949130)],
        &[(0b01001, &ENTRY_MISSIONIZER_16128334848487303471)],
        &[(0b01001, &ENTRY_MISSIONIZERS_9999401875646897234)],
        &[(0b01001, &ENTRY_MISSIONIZES_14585446178899362762)],
        &[(0b01001, &ENTRY_MISSIONIZING_7220648756581988180)],
    ],
    range: 6..=10,
};

static VARS_MISR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISR_CHILDREN),
    value: None,
};

pub static VARS_MISR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
        dictgen::InsensitiveStr::Ascii("ecognise"),
        dictgen::InsensitiveStr::Ascii("ecognises"),
        dictgen::InsensitiveStr::Ascii("ecognize"),
        dictgen::InsensitiveStr::Ascii("ecognizes"),
        dictgen::InsensitiveStr::Ascii("outeing"),
        dictgen::InsensitiveStr::Ascii("outing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISREALIZE_3770533395070542679)],
        &[(0b10010, &ENTRY_MISREALIZES_6455083844071414450)],
        &[(0b01001, &ENTRY_MISREALIZE_3770533395070542679)],
        &[(0b01001, &ENTRY_MISREALIZES_6455083844071414450)],
        &[(0b10010, &ENTRY_MISRECOGNIZE_7512259793232915009)],
        &[(0b10010, &ENTRY_MISRECOGNIZES_18195281488073038600)],
        &[(0b01001, &ENTRY_MISRECOGNIZE_7512259793232915009)],
        &[(0b01001, &ENTRY_MISRECOGNIZES_18195281488073038600)],
        &[(0b11010, &ENTRY_MISROUTING_16866807267371825983)],
        &[(0b00001, &ENTRY_MISROUTING_16866807267371825983)],
    ],
    range: 6..=9,
};

static VARS_MISP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISP_CHILDREN),
    value: None,
};

pub static VARS_MISP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("risal"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rizal"),
        dictgen::InsensitiveStr::Ascii("rizer"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISPRIZAL_9950323538351898149)],
        &[(0b11010, &ENTRY_MISPRIZE_3879577188385927221)],
        &[(0b11010, &ENTRY_MISPRIZED_201951729530329597)],
        &[(0b10010, &ENTRY_MISPRIZER_14657854399118585515)],
        &[(0b11010, &ENTRY_MISPRIZES_12171617639005381197)],
        &[(0b11010, &ENTRY_MISPRIZING_8754659322217023153)],
        &[(0b01001, &ENTRY_MISPRIZAL_9950323538351898149)],
        &[(0b01001, &ENTRY_MISPRIZER_14657854399118585515)],
    ],
    range: 4..=6,
};

static VARS_MISO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISO_CHILDREN),
    value: None,
};

pub static VARS_MISO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("paedia"),
        dictgen::InsensitiveStr::Ascii("paedism"),
        dictgen::InsensitiveStr::Ascii("paedist"),
        dictgen::InsensitiveStr::Ascii("pedia"),
        dictgen::InsensitiveStr::Ascii("pedism"),
        dictgen::InsensitiveStr::Ascii("pedist"),
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MISOPEDIA_7178332077163005269)],
        &[(0b11010, &ENTRY_MISOPEDISM_6542233660865950036)],
        &[(0b11010, &ENTRY_MISOPEDIST_6283172222250787222)],
        &[(0b10001, &ENTRY_MISOPEDIA_7178332077163005269)],
        &[(0b10001, &ENTRY_MISOPEDISM_6542233660865950036)],
        &[(0b10001, &ENTRY_MISOPEDIST_6283172222250787222)],
        &[(0b10010, &ENTRY_MISORGANIZATION_424938788016993526)],
        &[(0b10010, &ENTRY_MISORGANIZATIONS_15826994608931053543)],
        &[(0b10010, &ENTRY_MISORGANIZE_5050999531140182922)],
        &[(0b10010, &ENTRY_MISORGANIZES_15277883172814079121)],
        &[(0b01001, &ENTRY_MISORGANIZATION_424938788016993526)],
        &[(0b01001, &ENTRY_MISORGANIZATIONS_15826994608931053543)],
        &[(0b01001, &ENTRY_MISORGANIZE_5050999531140182922)],
        &[(0b01001, &ENTRY_MISORGANIZES_15277883172814079121)],
    ],
    range: 5..=12,
};

static VARS_MISL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISL_CHILDREN),
    value: None,
};

pub static VARS_MISL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abeled"),
        dictgen::InsensitiveStr::Ascii("abeling"),
        dictgen::InsensitiveStr::Ascii("abelled"),
        dictgen::InsensitiveStr::Ascii("abelling"),
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abored"),
        dictgen::InsensitiveStr::Ascii("aboring"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("aboured"),
        dictgen::InsensitiveStr::Ascii("abouring"),
        dictgen::InsensitiveStr::Ascii("abours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MISLABELED_11561074022001091176)],
        &[(0b00001, &ENTRY_MISLABELING_6355454506170956328)],
        &[(0b11010, &ENTRY_MISLABELED_11561074022001091176)],
        &[(0b11010, &ENTRY_MISLABELING_6355454506170956328)],
        &[(0b10001, &ENTRY_MISLABOR_2521634739502370747)],
        &[(0b10001, &ENTRY_MISLABORED_11357890207265877782)],
        &[(0b10001, &ENTRY_MISLABORING_3935355170149150597)],
        &[(0b10001, &ENTRY_MISLABORS_12989629945052355383)],
        &[(0b11010, &ENTRY_MISLABOR_2521634739502370747)],
        &[(0b11010, &ENTRY_MISLABORED_11357890207265877782)],
        &[(0b11010, &ENTRY_MISLABORING_3935355170149150597)],
        &[(0b11010, &ENTRY_MISLABORS_12989629945052355383)],
    ],
    range: 4..=8,
};

static VARS_MISJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISJ_CHILDREN),
    value: None,
};

pub static VARS_MISJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("udgement"),
        dictgen::InsensitiveStr::Ascii("udgements"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MISJUDGMENT_7815182386368600232)],
        &[(0b11010, &ENTRY_MISJUDGMENTS_15088301739266707294)],
    ],
    range: 8..=9,
};

static VARS_MISE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISE_CHILDREN),
    value: Some(&[(0b10010, &ENTRY_MIZE_2563563095806882396)]),
};

pub static VARS_MISE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISEMPHASIZE_8403241665905587325)],
        &[(0b10010, &ENTRY_MISEMPHASIZES_16801626349198066449)],
        &[(0b01001, &ENTRY_MISEMPHASIZE_8403241665905587325)],
        &[(0b01001, &ENTRY_MISEMPHASIZES_16801626349198066449)],
    ],
    range: 8..=9,
};

static VARS_MISD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISD_CHILDREN),
    value: None,
};

pub static VARS_MISD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emeanor"),
        dictgen::InsensitiveStr::Ascii("emeanors"),
        dictgen::InsensitiveStr::Ascii("emeanour"),
        dictgen::InsensitiveStr::Ascii("emeanours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_MISDEMEANOR_12584005266066485554)],
        &[(0b11001, &ENTRY_MISDEMEANORS_16426839555682853683)],
        &[(0b11010, &ENTRY_MISDEMEANOR_12584005266066485554)],
        &[(0b11010, &ENTRY_MISDEMEANORS_16426839555682853683)],
    ],
    range: 7..=9,
};

static VARS_MISC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISC_CHILDREN),
    value: None,
};

pub static VARS_MISC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anonise"),
        dictgen::InsensitiveStr::Ascii("anonises"),
        dictgen::InsensitiveStr::Ascii("anonize"),
        dictgen::InsensitiveStr::Ascii("anonizes"),
        dictgen::InsensitiveStr::Ascii("haracterisation"),
        dictgen::InsensitiveStr::Ascii("haracterisations"),
        dictgen::InsensitiveStr::Ascii("haracterise"),
        dictgen::InsensitiveStr::Ascii("haracterises"),
        dictgen::InsensitiveStr::Ascii("haracterization"),
        dictgen::InsensitiveStr::Ascii("haracterizations"),
        dictgen::InsensitiveStr::Ascii("haracterize"),
        dictgen::InsensitiveStr::Ascii("haracterizes"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("oloration"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olouration"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISCANONIZE_9609660140189549896)],
        &[(0b10010, &ENTRY_MISCANONIZES_3620605581508255824)],
        &[(0b01001, &ENTRY_MISCANONIZE_9609660140189549896)],
        &[(0b01001, &ENTRY_MISCANONIZES_3620605581508255824)],
        &[(0b10010, &ENTRY_MISCHARACTERIZATION_2446223644330426559)],
        &[(0b10010, &ENTRY_MISCHARACTERIZATIONS_9820262910491559476)],
        &[(0b10010, &ENTRY_MISCHARACTERIZE_14909915885126227137)],
        &[(0b10010, &ENTRY_MISCHARACTERIZES_6539624896226097074)],
        &[(0b01001, &ENTRY_MISCHARACTERIZATION_2446223644330426559)],
        &[(0b01001, &ENTRY_MISCHARACTERIZATIONS_9820262910491559476)],
        &[(0b01001, &ENTRY_MISCHARACTERIZE_14909915885126227137)],
        &[(0b01001, &ENTRY_MISCHARACTERIZES_6539624896226097074)],
        &[(0b10001, &ENTRY_MISCOLOR_18269855271059857487)],
        &[(0b00001, &ENTRY_MISCOLORATION_6928531033755254197)],
        &[(0b10001, &ENTRY_MISCOLORED_6650096186765477181)],
        &[(0b10001, &ENTRY_MISCOLORING_12066623990129129026)],
        &[(0b10001, &ENTRY_MISCOLORS_6442863367431484314)],
        &[(0b11010, &ENTRY_MISCOLOR_18269855271059857487)],
        &[(0b11010, &ENTRY_MISCOLORATION_6928531033755254197)],
        &[(0b11010, &ENTRY_MISCOLORED_6650096186765477181)],
        &[(0b11010, &ENTRY_MISCOLORING_12066623990129129026)],
        &[(0b11010, &ENTRY_MISCOLORS_6442863367431484314)],
    ],
    range: 4..=16,
};

static VARS_MISB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISB_CHILDREN),
    value: None,
};

pub static VARS_MISB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
        dictgen::InsensitiveStr::Ascii("ehavior"),
        dictgen::InsensitiveStr::Ascii("ehaviors"),
        dictgen::InsensitiveStr::Ascii("ehaviour"),
        dictgen::InsensitiveStr::Ascii("ehaviours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISBAPTIZE_3680575039131375475)],
        &[(0b10010, &ENTRY_MISBAPTIZES_7471355898746773980)],
        &[(0b01001, &ENTRY_MISBAPTIZE_3680575039131375475)],
        &[(0b01001, &ENTRY_MISBAPTIZES_7471355898746773980)],
        &[(0b10001, &ENTRY_MISBEHAVIOR_540636700073252665)],
        &[(0b10001, &ENTRY_MISBEHAVIORS_5196208905035156615)],
        &[(0b11010, &ENTRY_MISBEHAVIOR_540636700073252665)],
        &[(0b11010, &ENTRY_MISBEHAVIORS_5196208905035156615)],
    ],
    range: 6..=9,
};

static VARS_MISA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MISA_CHILDREN),
    value: None,
};

pub static VARS_MISA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dvise"),
        dictgen::InsensitiveStr::Ascii("dvize"),
        dictgen::InsensitiveStr::Ascii("lphabetise"),
        dictgen::InsensitiveStr::Ascii("lphabetises"),
        dictgen::InsensitiveStr::Ascii("lphabetize"),
        dictgen::InsensitiveStr::Ascii("lphabetizes"),
        dictgen::InsensitiveStr::Ascii("nthropise"),
        dictgen::InsensitiveStr::Ascii("nthropised"),
        dictgen::InsensitiveStr::Ascii("nthropises"),
        dictgen::InsensitiveStr::Ascii("nthropising"),
        dictgen::InsensitiveStr::Ascii("nthropize"),
        dictgen::InsensitiveStr::Ascii("nthropized"),
        dictgen::InsensitiveStr::Ascii("nthropizes"),
        dictgen::InsensitiveStr::Ascii("nthropizing"),
        dictgen::InsensitiveStr::Ascii("uthorisation"),
        dictgen::InsensitiveStr::Ascii("uthorisations"),
        dictgen::InsensitiveStr::Ascii("uthorise"),
        dictgen::InsensitiveStr::Ascii("uthorises"),
        dictgen::InsensitiveStr::Ascii("uthorization"),
        dictgen::InsensitiveStr::Ascii("uthorizations"),
        dictgen::InsensitiveStr::Ascii("uthorize"),
        dictgen::InsensitiveStr::Ascii("uthorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MISADVIZE_16409133113491535237)],
        &[(0b01001, &ENTRY_MISADVIZE_16409133113491535237)],
        &[(0b10010, &ENTRY_MISALPHABETIZE_11925476407502455282)],
        &[(0b10010, &ENTRY_MISALPHABETIZES_16788559393069866256)],
        &[(0b01001, &ENTRY_MISALPHABETIZE_11925476407502455282)],
        &[(0b01001, &ENTRY_MISALPHABETIZES_16788559393069866256)],
        &[(0b10010, &ENTRY_MISANTHROPIZE_1922550089268916167)],
        &[(0b10010, &ENTRY_MISANTHROPIZED_11727139559415514846)],
        &[(0b10010, &ENTRY_MISANTHROPIZES_3973773355167530030)],
        &[(0b10010, &ENTRY_MISANTHROPIZING_17542823159662397794)],
        &[(0b01001, &ENTRY_MISANTHROPIZE_1922550089268916167)],
        &[(0b01001, &ENTRY_MISANTHROPIZED_11727139559415514846)],
        &[(0b01001, &ENTRY_MISANTHROPIZES_3973773355167530030)],
        &[(0b01001, &ENTRY_MISANTHROPIZING_17542823159662397794)],
        &[(0b10010, &ENTRY_MISAUTHORIZATION_3255527742163937042)],
        &[(0b10010, &ENTRY_MISAUTHORIZATIONS_18193977628681315405)],
        &[(0b10010, &ENTRY_MISAUTHORIZE_3226310660966698523)],
        &[(0b10010, &ENTRY_MISAUTHORIZES_15338039315356738476)],
        &[(0b01001, &ENTRY_MISAUTHORIZATION_3255527742163937042)],
        &[(0b01001, &ENTRY_MISAUTHORIZATIONS_18193977628681315405)],
        &[(0b01001, &ENTRY_MISAUTHORIZE_3226310660966698523)],
        &[(0b01001, &ENTRY_MISAUTHORIZES_15338039315356738476)],
    ],
    range: 5..=13,
};

static VARS_MIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIR_CHILDREN),
    value: None,
};

pub static VARS_MIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aculise"),
        dictgen::InsensitiveStr::Ascii("aculised"),
        dictgen::InsensitiveStr::Ascii("aculises"),
        dictgen::InsensitiveStr::Ascii("aculising"),
        dictgen::InsensitiveStr::Ascii("aculize"),
        dictgen::InsensitiveStr::Ascii("aculized"),
        dictgen::InsensitiveStr::Ascii("aculizes"),
        dictgen::InsensitiveStr::Ascii("aculizing"),
        dictgen::InsensitiveStr::Ascii("rorise"),
        dictgen::InsensitiveStr::Ascii("rorises"),
        dictgen::InsensitiveStr::Ascii("rorize"),
        dictgen::InsensitiveStr::Ascii("rorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MIRACULIZE_1182386821971852529)],
        &[(0b10010, &ENTRY_MIRACULIZED_6177671402487877323)],
        &[(0b10010, &ENTRY_MIRACULIZES_1343333849395320346)],
        &[(0b10010, &ENTRY_MIRACULIZING_8288198734632161015)],
        &[(0b01001, &ENTRY_MIRACULIZE_1182386821971852529)],
        &[(0b01001, &ENTRY_MIRACULIZED_6177671402487877323)],
        &[(0b01001, &ENTRY_MIRACULIZES_1343333849395320346)],
        &[(0b01001, &ENTRY_MIRACULIZING_8288198734632161015)],
        &[(0b10010, &ENTRY_MIRRORIZE_11945337347676406290)],
        &[(0b10010, &ENTRY_MIRRORIZES_5236007942143840949)],
        &[(0b01001, &ENTRY_MIRRORIZE_11945337347676406290)],
        &[(0b01001, &ENTRY_MIRRORIZES_5236007942143840949)],
    ],
    range: 6..=9,
};

static VARS_MIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIN_CHILDREN),
    value: None,
};

pub static VARS_MIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eralisable"),
        dictgen::InsensitiveStr::Ascii("eralisables"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralised"),
        dictgen::InsensitiveStr::Ascii("eraliser"),
        dictgen::InsensitiveStr::Ascii("eralisers"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralising"),
        dictgen::InsensitiveStr::Ascii("eralizable"),
        dictgen::InsensitiveStr::Ascii("eralizables"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralized"),
        dictgen::InsensitiveStr::Ascii("eralizer"),
        dictgen::InsensitiveStr::Ascii("eralizers"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("eralizing"),
        dictgen::InsensitiveStr::Ascii("eralogise"),
        dictgen::InsensitiveStr::Ascii("eralogised"),
        dictgen::InsensitiveStr::Ascii("eralogises"),
        dictgen::InsensitiveStr::Ascii("eralogising"),
        dictgen::InsensitiveStr::Ascii("eralogize"),
        dictgen::InsensitiveStr::Ascii("eralogized"),
        dictgen::InsensitiveStr::Ascii("eralogizes"),
        dictgen::InsensitiveStr::Ascii("eralogizing"),
        dictgen::InsensitiveStr::Ascii("iaturisation"),
        dictgen::InsensitiveStr::Ascii("iaturisations"),
        dictgen::InsensitiveStr::Ascii("iaturise"),
        dictgen::InsensitiveStr::Ascii("iaturised"),
        dictgen::InsensitiveStr::Ascii("iaturises"),
        dictgen::InsensitiveStr::Ascii("iaturising"),
        dictgen::InsensitiveStr::Ascii("iaturization"),
        dictgen::InsensitiveStr::Ascii("iaturizations"),
        dictgen::InsensitiveStr::Ascii("iaturize"),
        dictgen::InsensitiveStr::Ascii("iaturized"),
        dictgen::InsensitiveStr::Ascii("iaturizes"),
        dictgen::InsensitiveStr::Ascii("iaturizing"),
        dictgen::InsensitiveStr::Ascii("ibusses"),
        dictgen::InsensitiveStr::Ascii("imisation"),
        dictgen::InsensitiveStr::Ascii("imisations"),
        dictgen::InsensitiveStr::Ascii("imise"),
        dictgen::InsensitiveStr::Ascii("imised"),
        dictgen::InsensitiveStr::Ascii("imiser"),
        dictgen::InsensitiveStr::Ascii("imisers"),
        dictgen::InsensitiveStr::Ascii("imises"),
        dictgen::InsensitiveStr::Ascii("imising"),
        dictgen::InsensitiveStr::Ascii("imization"),
        dictgen::InsensitiveStr::Ascii("imizations"),
        dictgen::InsensitiveStr::Ascii("imize"),
        dictgen::InsensitiveStr::Ascii("imized"),
        dictgen::InsensitiveStr::Ascii("imizer"),
        dictgen::InsensitiveStr::Ascii("imizers"),
        dictgen::InsensitiveStr::Ascii("imizes"),
        dictgen::InsensitiveStr::Ascii("imizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MINERALIZABLE_14273899251330384981)],
        &[(0b10010, &ENTRY_MINERALIZABLES_4251810902045295819)],
        &[(0b10010, &ENTRY_MINERALIZATION_3564945156895387848)],
        &[(0b10010, &ENTRY_MINERALIZATIONS_12229839998070627902)],
        &[(0b10010, &ENTRY_MINERALIZE_1571843507697484066)],
        &[(0b10010, &ENTRY_MINERALIZED_15703772425518702501)],
        &[(0b10010, &ENTRY_MINERALIZER_17761278028415775424)],
        &[(0b10010, &ENTRY_MINERALIZERS_10953203791829252058)],
        &[(0b10010, &ENTRY_MINERALIZES_4329461307318398064)],
        &[(0b10010, &ENTRY_MINERALIZING_2370850438844276958)],
        &[(0b01001, &ENTRY_MINERALIZABLE_14273899251330384981)],
        &[(0b01001, &ENTRY_MINERALIZABLES_4251810902045295819)],
        &[(0b01001, &ENTRY_MINERALIZATION_3564945156895387848)],
        &[(0b01001, &ENTRY_MINERALIZATIONS_12229839998070627902)],
        &[(0b01001, &ENTRY_MINERALIZE_1571843507697484066)],
        &[(0b01001, &ENTRY_MINERALIZED_15703772425518702501)],
        &[(0b01001, &ENTRY_MINERALIZER_17761278028415775424)],
        &[(0b01001, &ENTRY_MINERALIZERS_10953203791829252058)],
        &[(0b01001, &ENTRY_MINERALIZES_4329461307318398064)],
        &[(0b01001, &ENTRY_MINERALIZING_2370850438844276958)],
        &[(0b10010, &ENTRY_MINERALOGIZE_3875128191048540734)],
        &[(0b10010, &ENTRY_MINERALOGIZED_17528204496484253594)],
        &[(0b10010, &ENTRY_MINERALOGIZES_6295241220342366538)],
        &[(0b10010, &ENTRY_MINERALOGIZING_8320404481105461267)],
        &[(0b01001, &ENTRY_MINERALOGIZE_3875128191048540734)],
        &[(0b01001, &ENTRY_MINERALOGIZED_17528204496484253594)],
        &[(0b01001, &ENTRY_MINERALOGIZES_6295241220342366538)],
        &[(0b01001, &ENTRY_MINERALOGIZING_8320404481105461267)],
        &[(0b10010, &ENTRY_MINIATURIZATION_931417921282710006)],
        &[(0b10010, &ENTRY_MINIATURIZATIONS_16792332801073740235)],
        &[(0b10010, &ENTRY_MINIATURIZE_10753419860525211240)],
        &[(0b10010, &ENTRY_MINIATURIZED_2523726741957158389)],
        &[(0b10010, &ENTRY_MINIATURIZES_16030635425775930230)],
        &[(0b10010, &ENTRY_MINIATURIZING_9528377556061969785)],
        &[(0b01001, &ENTRY_MINIATURIZATION_931417921282710006)],
        &[(0b01001, &ENTRY_MINIATURIZATIONS_16792332801073740235)],
        &[(0b01001, &ENTRY_MINIATURIZE_10753419860525211240)],
        &[(0b01001, &ENTRY_MINIATURIZED_2523726741957158389)],
        &[(0b01001, &ENTRY_MINIATURIZES_16030635425775930230)],
        &[(0b01001, &ENTRY_MINIATURIZING_9528377556061969785)],
        &[(0b00001, &ENTRY_MINIBUSES_14356738777892083785)],
        &[(0b10010, &ENTRY_MINIMIZATION_351034506335182236)],
        &[(0b10010, &ENTRY_MINIMIZATIONS_9759567247144361189)],
        &[(0b10010, &ENTRY_MINIMIZE_3707349867421055069)],
        &[(0b10010, &ENTRY_MINIMIZED_3517153139897541686)],
        &[(0b10010, &ENTRY_MINIMIZER_10298751688725307286)],
        &[(0b10010, &ENTRY_MINIMIZERS_3982433450924782557)],
        &[(0b10010, &ENTRY_MINIMIZES_11720225532340588601)],
        &[(0b10010, &ENTRY_MINIMIZING_6587400313450683054)],
        &[(0b01001, &ENTRY_MINIMIZATION_351034506335182236)],
        &[(0b01001, &ENTRY_MINIMIZATIONS_9759567247144361189)],
        &[(0b01001, &ENTRY_MINIMIZE_3707349867421055069)],
        &[(0b01001, &ENTRY_MINIMIZED_3517153139897541686)],
        &[(0b01001, &ENTRY_MINIMIZER_10298751688725307286)],
        &[(0b01001, &ENTRY_MINIMIZERS_3982433450924782557)],
        &[(0b01001, &ENTRY_MINIMIZES_11720225532340588601)],
        &[(0b01001, &ENTRY_MINIMIZING_6587400313450683054)],
    ],
    range: 5..=13,
};

static VARS_MIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIL_CHILDREN),
    value: None,
};

pub static VARS_MIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itarisation"),
        dictgen::InsensitiveStr::Ascii("itarisations"),
        dictgen::InsensitiveStr::Ascii("itarise"),
        dictgen::InsensitiveStr::Ascii("itarised"),
        dictgen::InsensitiveStr::Ascii("itarises"),
        dictgen::InsensitiveStr::Ascii("itarising"),
        dictgen::InsensitiveStr::Ascii("itarization"),
        dictgen::InsensitiveStr::Ascii("itarizations"),
        dictgen::InsensitiveStr::Ascii("itarize"),
        dictgen::InsensitiveStr::Ascii("itarized"),
        dictgen::InsensitiveStr::Ascii("itarizes"),
        dictgen::InsensitiveStr::Ascii("itarizing"),
        dictgen::InsensitiveStr::Ascii("ligramme"),
        dictgen::InsensitiveStr::Ascii("ligrammes"),
        dictgen::InsensitiveStr::Ascii("liliter"),
        dictgen::InsensitiveStr::Ascii("liliters"),
        dictgen::InsensitiveStr::Ascii("lilitre"),
        dictgen::InsensitiveStr::Ascii("lilitres"),
        dictgen::InsensitiveStr::Ascii("limeter"),
        dictgen::InsensitiveStr::Ascii("limeters"),
        dictgen::InsensitiveStr::Ascii("limetre"),
        dictgen::InsensitiveStr::Ascii("limetres"),
        dictgen::InsensitiveStr::Ascii("lionise"),
        dictgen::InsensitiveStr::Ascii("lionises"),
        dictgen::InsensitiveStr::Ascii("lionize"),
        dictgen::InsensitiveStr::Ascii("lionizes"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonised"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonising"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonized"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
        dictgen::InsensitiveStr::Ascii("tonizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MILITARIZATION_554898038906981603)],
        &[(0b10010, &ENTRY_MILITARIZATIONS_16041396934802500390)],
        &[(0b10010, &ENTRY_MILITARIZE_8711049019051151425)],
        &[(0b10010, &ENTRY_MILITARIZED_11151514891666757640)],
        &[(0b10010, &ENTRY_MILITARIZES_5992491948437878542)],
        &[(0b10010, &ENTRY_MILITARIZING_17081897557386742850)],
        &[(0b01001, &ENTRY_MILITARIZATION_554898038906981603)],
        &[(0b01001, &ENTRY_MILITARIZATIONS_16041396934802500390)],
        &[(0b01001, &ENTRY_MILITARIZE_8711049019051151425)],
        &[(0b01001, &ENTRY_MILITARIZED_11151514891666757640)],
        &[(0b01001, &ENTRY_MILITARIZES_5992491948437878542)],
        &[(0b01001, &ENTRY_MILITARIZING_17081897557386742850)],
        &[(0b11010, &ENTRY_MILLIGRAM_16796984474169779303)],
        &[(0b11010, &ENTRY_MILLIGRAMS_7781869386637459768)],
        &[(0b00001, &ENTRY_MILLILITER_12944386636303269905)],
        &[(0b00001, &ENTRY_MILLILITERS_3119249389919852365)],
        &[(0b11010, &ENTRY_MILLILITER_12944386636303269905)],
        &[(0b11010, &ENTRY_MILLILITERS_3119249389919852365)],
        &[(0b00001, &ENTRY_MILLIMETER_987431015131963906)],
        &[(0b00001, &ENTRY_MILLIMETERS_5241583042561099229)],
        &[(0b11010, &ENTRY_MILLIMETER_987431015131963906)],
        &[(0b11010, &ENTRY_MILLIMETERS_5241583042561099229)],
        &[(0b10010, &ENTRY_MILLIONIZE_7107796536009410307)],
        &[(0b10010, &ENTRY_MILLIONIZES_14672317174442674555)],
        &[(0b01001, &ENTRY_MILLIONIZE_7107796536009410307)],
        &[(0b01001, &ENTRY_MILLIONIZES_14672317174442674555)],
        &[(0b10010, &ENTRY_MILTONIZE_2990759727618280610)],
        &[(0b10010, &ENTRY_MILTONIZED_881674982771846921)],
        &[(0b10010, &ENTRY_MILTONIZES_10249327127226251005)],
        &[(0b10010, &ENTRY_MILTONIZING_57382712508205881)],
        &[(0b01001, &ENTRY_MILTONIZE_2990759727618280610)],
        &[(0b01001, &ENTRY_MILTONIZED_881674982771846921)],
        &[(0b01001, &ENTRY_MILTONIZES_10249327127226251005)],
        &[(0b01001, &ENTRY_MILTONIZING_57382712508205881)],
    ],
    range: 6..=12,
};

static VARS_MIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIG_CHILDREN),
    value: None,
};

pub static VARS_MIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("niardise"),
        dictgen::InsensitiveStr::Ascii("niardize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MIGNIARDIZE_4590904890151973573)],
        &[(0b01001, &ENTRY_MIGNIARDIZE_4590904890151973573)],
    ],
    range: 8..=8,
};

static VARS_MID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MID_CHILDREN),
    value: None,
};

pub static VARS_MID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("landise"),
        dictgen::InsensitiveStr::Ascii("landises"),
        dictgen::InsensitiveStr::Ascii("landize"),
        dictgen::InsensitiveStr::Ascii("landizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MIDLANDIZE_3510194189738166244)],
        &[(0b10010, &ENTRY_MIDLANDIZES_6424533152072180816)],
        &[(0b01001, &ENTRY_MIDLANDIZE_3510194189738166244)],
        &[(0b01001, &ENTRY_MIDLANDIZES_6424533152072180816)],
    ],
    range: 7..=8,
};

static VARS_MIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MIC_CHILDREN),
    value: None,
};

static VARS_MIC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_MICE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MICR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_MICR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MICR_CHILDREN),
    value: None,
};

pub static VARS_MICR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthete"),
        dictgen::InsensitiveStr::Ascii("esthete"),
        dictgen::InsensitiveStr::Ascii("ocolorimeter"),
        dictgen::InsensitiveStr::Ascii("ocolorimetric"),
        dictgen::InsensitiveStr::Ascii("ocolorimetrically"),
        dictgen::InsensitiveStr::Ascii("ocolorimetry"),
        dictgen::InsensitiveStr::Ascii("ocolourimeter"),
        dictgen::InsensitiveStr::Ascii("ocolourimetric"),
        dictgen::InsensitiveStr::Ascii("ocolourimetrically"),
        dictgen::InsensitiveStr::Ascii("ocolourimetry"),
        dictgen::InsensitiveStr::Ascii("oliter"),
        dictgen::InsensitiveStr::Ascii("oliters"),
        dictgen::InsensitiveStr::Ascii("olitre"),
        dictgen::InsensitiveStr::Ascii("olitres"),
        dictgen::InsensitiveStr::Ascii("ometre"),
        dictgen::InsensitiveStr::Ascii("ometres"),
        dictgen::InsensitiveStr::Ascii("omillimeter"),
        dictgen::InsensitiveStr::Ascii("omillimeters"),
        dictgen::InsensitiveStr::Ascii("omillimetre"),
        dictgen::InsensitiveStr::Ascii("omillimetres"),
        dictgen::InsensitiveStr::Ascii("ominiaturisation"),
        dictgen::InsensitiveStr::Ascii("ominiaturisations"),
        dictgen::InsensitiveStr::Ascii("ominiaturise"),
        dictgen::InsensitiveStr::Ascii("ominiaturised"),
        dictgen::InsensitiveStr::Ascii("ominiaturiser"),
        dictgen::InsensitiveStr::Ascii("ominiaturisers"),
        dictgen::InsensitiveStr::Ascii("ominiaturises"),
        dictgen::InsensitiveStr::Ascii("ominiaturising"),
        dictgen::InsensitiveStr::Ascii("ominiaturization"),
        dictgen::InsensitiveStr::Ascii("ominiaturizations"),
        dictgen::InsensitiveStr::Ascii("ominiaturize"),
        dictgen::InsensitiveStr::Ascii("ominiaturized"),
        dictgen::InsensitiveStr::Ascii("ominiaturizer"),
        dictgen::InsensitiveStr::Ascii("ominiaturizers"),
        dictgen::InsensitiveStr::Ascii("ominiaturizes"),
        dictgen::InsensitiveStr::Ascii("ominiaturizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("opalaeontologies"),
        dictgen::InsensitiveStr::Ascii("opalaeontologist"),
        dictgen::InsensitiveStr::Ascii("opalaeontologists"),
        dictgen::InsensitiveStr::Ascii("opalaeontology"),
        dictgen::InsensitiveStr::Ascii("opaleontologies"),
        dictgen::InsensitiveStr::Ascii("opaleontologist"),
        dictgen::InsensitiveStr::Ascii("opaleontologists"),
        dictgen::InsensitiveStr::Ascii("opaleontology"),
        dictgen::InsensitiveStr::Ascii("opolarisation"),
        dictgen::InsensitiveStr::Ascii("opolarisations"),
        dictgen::InsensitiveStr::Ascii("opolarization"),
        dictgen::InsensitiveStr::Ascii("opolarizations"),
        dictgen::InsensitiveStr::Ascii("oscopise"),
        dictgen::InsensitiveStr::Ascii("oscopises"),
        dictgen::InsensitiveStr::Ascii("oscopize"),
        dictgen::InsensitiveStr::Ascii("oscopizes"),
        dictgen::InsensitiveStr::Ascii("osphaeric"),
        dictgen::InsensitiveStr::Ascii("ospheric"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MICRESTHETE_13540257889635101070)],
        &[(0b00001, &ENTRY_MICRESTHETE_13540257889635101070)],
        &[(0b00001, &ENTRY_MICROCOLORIMETER_9779301620192455553)],
        &[(0b00001, &ENTRY_MICROCOLORIMETRIC_16293154471196561257)],
        &[(0b00001, &ENTRY_MICROCOLORIMETRICALLY_642505822013488513)],
        &[(0b00001, &ENTRY_MICROCOLORIMETRY_4008745178077342383)],
        &[(0b11010, &ENTRY_MICROCOLORIMETER_9779301620192455553)],
        &[(0b11010, &ENTRY_MICROCOLORIMETRIC_16293154471196561257)],
        &[(0b11010, &ENTRY_MICROCOLORIMETRICALLY_642505822013488513)],
        &[(0b11010, &ENTRY_MICROCOLORIMETRY_4008745178077342383)],
        &[(0b00001, &ENTRY_MICROLITER_10382843459472870945)],
        &[(0b00001, &ENTRY_MICROLITERS_4102248640329342657)],
        &[(0b11010, &ENTRY_MICROLITER_10382843459472870945)],
        &[(0b11010, &ENTRY_MICROLITERS_4102248640329342657)],
        &[(0b11010, &ENTRY_MICROMETER_15592109948820978579)],
        &[(0b11010, &ENTRY_MICROMETERS_5540877797236666596)],
        &[(0b00001, &ENTRY_MICROMILLIMETER_10473316398408026315)],
        &[(0b00001, &ENTRY_MICROMILLIMETERS_3079930143003610243)],
        &[(0b11010, &ENTRY_MICROMILLIMETER_10473316398408026315)],
        &[(0b11010, &ENTRY_MICROMILLIMETERS_3079930143003610243)],
        &[(0b10010, &ENTRY_MICROMINIATURIZATION_5346373952330274164)],
        &[(0b10010, &ENTRY_MICROMINIATURIZATIONS_13306479844907705540)],
        &[(0b10010, &ENTRY_MICROMINIATURIZE_9621429765821925702)],
        &[(0b10010, &ENTRY_MICROMINIATURIZED_17716034338321519125)],
        &[(0b10010, &ENTRY_MICROMINIATURIZER_9056244455912922848)],
        &[(0b10010, &ENTRY_MICROMINIATURIZERS_16112810702387401879)],
        &[(0b10010, &ENTRY_MICROMINIATURIZES_7333398841442349207)],
        &[(0b10010, &ENTRY_MICROMINIATURIZING_9157788742498342217)],
        &[(0b01001, &ENTRY_MICROMINIATURIZATION_5346373952330274164)],
        &[(0b01001, &ENTRY_MICROMINIATURIZATIONS_13306479844907705540)],
        &[(0b01001, &ENTRY_MICROMINIATURIZE_9621429765821925702)],
        &[(0b01001, &ENTRY_MICROMINIATURIZED_17716034338321519125)],
        &[(0b01001, &ENTRY_MICROMINIATURIZER_9056244455912922848)],
        &[(0b01001, &ENTRY_MICROMINIATURIZERS_16112810702387401879)],
        &[(0b01001, &ENTRY_MICROMINIATURIZES_7333398841442349207)],
        &[(0b01001, &ENTRY_MICROMINIATURIZING_9157788742498342217)],
        &[(0b10010, &ENTRY_MICRONIZATION_14140336681875685306)],
        &[(0b10010, &ENTRY_MICRONIZATIONS_14323368720092109048)],
        &[(0b10010, &ENTRY_MICRONIZE_17244565019586455413)],
        &[(0b10010, &ENTRY_MICRONIZES_11026427189011331369)],
        &[(0b01001, &ENTRY_MICRONIZATION_14140336681875685306)],
        &[(0b01001, &ENTRY_MICRONIZATIONS_14323368720092109048)],
        &[(0b01001, &ENTRY_MICRONIZE_17244565019586455413)],
        &[(0b01001, &ENTRY_MICRONIZES_11026427189011331369)],
        &[(0b11010, &ENTRY_MICROPALEONTOLOGIES_15673084178324778221)],
        &[(0b11010, &ENTRY_MICROPALEONTOLOGIST_10484705778286496383)],
        &[(0b11010, &ENTRY_MICROPALEONTOLOGISTS_9981502590596153564)],
        &[(0b11010, &ENTRY_MICROPALEONTOLOGY_12524199822545327475)],
        &[(0b10001, &ENTRY_MICROPALEONTOLOGIES_15673084178324778221)],
        &[(0b10001, &ENTRY_MICROPALEONTOLOGIST_10484705778286496383)],
        &[(0b10001, &ENTRY_MICROPALEONTOLOGISTS_9981502590596153564)],
        &[(0b10001, &ENTRY_MICROPALEONTOLOGY_12524199822545327475)],
        &[(0b10010, &ENTRY_MICROPOLARIZATION_7875633180146454277)],
        &[(0b10010, &ENTRY_MICROPOLARIZATIONS_1657538137031140510)],
        &[(0b01001, &ENTRY_MICROPOLARIZATION_7875633180146454277)],
        &[(0b01001, &ENTRY_MICROPOLARIZATIONS_1657538137031140510)],
        &[(0b10010, &ENTRY_MICROSCOPIZE_9785839938855486861)],
        &[(0b10010, &ENTRY_MICROSCOPIZES_9765068257112932239)],
        &[(0b01001, &ENTRY_MICROSCOPIZE_9785839938855486861)],
        &[(0b01001, &ENTRY_MICROSCOPIZES_9765068257112932239)],
        &[(0b11010, &ENTRY_MICROSPHERIC_5773029873068865214)],
        &[(0b00001, &ENTRY_MICROSPHERIC_5773029873068865214)],
    ],
    range: 5..=18,
};

static VARS_MICE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MICE_CHILDREN),
    value: None,
};

pub static VARS_MICE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("llae"),
        dictgen::InsensitiveStr::Ascii("lle"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MICELLE_16974791499278810684)],
        &[(0b00001, &ENTRY_MICELLE_16974791499278810684)],
    ],
    range: 3..=4,
};

static VARS_MIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MIA_CHILDREN),
    value: None,
};

pub static VARS_MIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ow"),
        dictgen::InsensitiveStr::Ascii("owed"),
        dictgen::InsensitiveStr::Ascii("owing"),
        dictgen::InsensitiveStr::Ascii("ows"),
    ],
    values: &[
        &[(0b10011, &ENTRY_MEOW_13843661663170128965)],
        &[(0b10011, &ENTRY_MEOWED_15719981813416166348)],
        &[(0b10011, &ENTRY_MEOWING_11150494275483966586)],
        &[(0b10011, &ENTRY_MEOWS_11643488271672592790)],
    ],
    range: 2..=5,
};

static VARS_ME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ME_CHILDREN),
    value: None,
};

static VARS_ME_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MEA_NODE),
    None,
    Some(&VARS_MEC_NODE),
    Some(&VARS_MED_NODE),
    None,
    None,
    Some(&VARS_MEG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_MEL_NODE),
    Some(&VARS_MEM_NODE),
    Some(&VARS_MEN_NODE),
    None,
    Some(&VARS_MEP_NODE),
    None,
    Some(&VARS_MER_NODE),
    Some(&VARS_MES_NODE),
    Some(&VARS_MET_NODE),
    None,
    None,
    None,
    Some(&VARS_MEX_NODE),
    None,
    None,
];

static VARS_MEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEX_CHILDREN),
    value: None,
};

pub static VARS_MEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icanise"),
        dictgen::InsensitiveStr::Ascii("icanises"),
        dictgen::InsensitiveStr::Ascii("icanize"),
        dictgen::InsensitiveStr::Ascii("icanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MEXICANIZE_15398963488252123589)],
        &[(0b10010, &ENTRY_MEXICANIZES_17616790503217011839)],
        &[(0b01001, &ENTRY_MEXICANIZE_15398963488252123589)],
        &[(0b01001, &ENTRY_MEXICANIZES_17616790503217011839)],
    ],
    range: 7..=8,
};

static VARS_MET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MET_CHILDREN),
    value: None,
};

static VARS_MET_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_META_NODE),
    None,
    None,
    None,
    Some(&VARS_METE_NODE),
    None,
    None,
    Some(&VARS_METH_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_METO_NODE),
    None,
    None,
    Some(&VARS_METR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_METR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METR_CHILDREN),
    value: None,
};

pub static VARS_METR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("egram"),
        dictgen::InsensitiveStr::Ascii("eless"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("eship"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("opolitanisation"),
        dictgen::InsensitiveStr::Ascii("opolitanise"),
        dictgen::InsensitiveStr::Ascii("opolitanised"),
        dictgen::InsensitiveStr::Ascii("opolitanises"),
        dictgen::InsensitiveStr::Ascii("opolitanising"),
        dictgen::InsensitiveStr::Ascii("opolitanization"),
        dictgen::InsensitiveStr::Ascii("opolitanize"),
        dictgen::InsensitiveStr::Ascii("opolitanized"),
        dictgen::InsensitiveStr::Ascii("opolitanizes"),
        dictgen::InsensitiveStr::Ascii("opolitanizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_METER_16566716494062015891)],
        &[(0b11010, &ENTRY_METERGRAM_1724413366267016112)],
        &[(0b11010, &ENTRY_METERLESS_17184210016380634977)],
        &[(0b11010, &ENTRY_METERS_17916328899664667470)],
        &[(0b11010, &ENTRY_METERSHIP_12369315169127590637)],
        &[(0b10010, &ENTRY_METRICIZE_11822854746535929298)],
        &[(0b10010, &ENTRY_METRICIZED_6875699536327305118)],
        &[(0b10010, &ENTRY_METRICIZES_12116163869340692775)],
        &[(0b10010, &ENTRY_METRICIZING_2068512533974319795)],
        &[(0b01001, &ENTRY_METRICIZE_11822854746535929298)],
        &[(0b01001, &ENTRY_METRICIZED_6875699536327305118)],
        &[(0b01001, &ENTRY_METRICIZES_12116163869340692775)],
        &[(0b01001, &ENTRY_METRICIZING_2068512533974319795)],
        &[(0b10010, &ENTRY_METRIZE_15001229744107948253)],
        &[(0b01001, &ENTRY_METRIZE_15001229744107948253)],
        &[(0b10010, &ENTRY_METROPOLITANIZATION_1438949631637766421)],
        &[(0b10010, &ENTRY_METROPOLITANIZE_289702428142359755)],
        &[(0b10010, &ENTRY_METROPOLITANIZED_17050622815392025985)],
        &[(0b10010, &ENTRY_METROPOLITANIZES_9226183384925850337)],
        &[(0b10010, &ENTRY_METROPOLITANIZING_7898407017719054595)],
        &[(0b01001, &ENTRY_METROPOLITANIZATION_1438949631637766421)],
        &[(0b01001, &ENTRY_METROPOLITANIZE_289702428142359755)],
        &[(0b01001, &ENTRY_METROPOLITANIZED_17050622815392025985)],
        &[(0b01001, &ENTRY_METROPOLITANIZES_9226183384925850337)],
        &[(0b01001, &ENTRY_METROPOLITANIZING_7898407017719054595)],
    ],
    range: 1..=15,
};

static VARS_METO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METO_CHILDREN),
    value: None,
};

pub static VARS_METO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("estrus"),
        dictgen::InsensitiveStr::Ascii("pae"),
        dictgen::InsensitiveStr::Ascii("pe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_METESTRUS_11103578253154514948)],
        &[(0b11010, &ENTRY_METOPE_13902530583208981134)],
        &[(0b00001, &ENTRY_METOPE_13902530583208981134)],
    ],
    range: 2..=6,
};

static VARS_METH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METH_CHILDREN),
    value: None,
};

pub static VARS_METH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemoglobin"),
        dictgen::InsensitiveStr::Ascii("emoglobin"),
        dictgen::InsensitiveStr::Ascii("odisation"),
        dictgen::InsensitiveStr::Ascii("odisations"),
        dictgen::InsensitiveStr::Ascii("odise"),
        dictgen::InsensitiveStr::Ascii("odised"),
        dictgen::InsensitiveStr::Ascii("odiser"),
        dictgen::InsensitiveStr::Ascii("odisers"),
        dictgen::InsensitiveStr::Ascii("odises"),
        dictgen::InsensitiveStr::Ascii("odising"),
        dictgen::InsensitiveStr::Ascii("odization"),
        dictgen::InsensitiveStr::Ascii("odizations"),
        dictgen::InsensitiveStr::Ascii("odize"),
        dictgen::InsensitiveStr::Ascii("odized"),
        dictgen::InsensitiveStr::Ascii("odizer"),
        dictgen::InsensitiveStr::Ascii("odizers"),
        dictgen::InsensitiveStr::Ascii("odizes"),
        dictgen::InsensitiveStr::Ascii("odizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_METHEMOGLOBIN_17726338295789945777)],
        &[(0b10001, &ENTRY_METHEMOGLOBIN_17726338295789945777)],
        &[(0b10010, &ENTRY_METHODIZATION_9510256614122744050)],
        &[(0b10010, &ENTRY_METHODIZATIONS_17570359377170798664)],
        &[(0b10010, &ENTRY_METHODIZE_18133455300099242110)],
        &[(0b10010, &ENTRY_METHODIZED_418361387379361383)],
        &[(0b10010, &ENTRY_METHODIZER_14823424149101284464)],
        &[(0b10010, &ENTRY_METHODIZERS_11335706115632934821)],
        &[(0b10010, &ENTRY_METHODIZES_12827878129958986497)],
        &[(0b10010, &ENTRY_METHODIZING_12934705350925516475)],
        &[(0b01001, &ENTRY_METHODIZATION_9510256614122744050)],
        &[(0b01001, &ENTRY_METHODIZATIONS_17570359377170798664)],
        &[(0b01001, &ENTRY_METHODIZE_18133455300099242110)],
        &[(0b01001, &ENTRY_METHODIZED_418361387379361383)],
        &[(0b01001, &ENTRY_METHODIZER_14823424149101284464)],
        &[(0b01001, &ENTRY_METHODIZERS_11335706115632934821)],
        &[(0b01001, &ENTRY_METHODIZES_12827878129958986497)],
        &[(0b01001, &ENTRY_METHODIZING_12934705350925516475)],
    ],
    range: 5..=10,
};

static VARS_METE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METE_CHILDREN),
    value: None,
};

pub static VARS_METE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("rgram"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rship"),
        dictgen::InsensitiveStr::Ascii("strus"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METEORIZATION_14474673158367138477)],
        &[(0b10010, &ENTRY_METEORIZATIONS_15135490425317605435)],
        &[(0b10010, &ENTRY_METEORIZE_15789282159199256879)],
        &[(0b10010, &ENTRY_METEORIZES_5350547156830180970)],
        &[(0b01001, &ENTRY_METEORIZATION_14474673158367138477)],
        &[(0b01001, &ENTRY_METEORIZATIONS_15135490425317605435)],
        &[(0b01001, &ENTRY_METEORIZE_15789282159199256879)],
        &[(0b01001, &ENTRY_METEORIZES_5350547156830180970)],
        &[(0b00001, &ENTRY_METERGRAM_1724413366267016112)],
        &[(0b00001, &ENTRY_METERLESS_17184210016380634977)],
        &[(0b00001, &ENTRY_METERSHIP_12369315169127590637)],
        &[(0b00001, &ENTRY_METESTRUS_11103578253154514948)],
    ],
    range: 5..=10,
};

static VARS_META_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_META_CHILDREN),
    value: None,
};

static VARS_META_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_METAB_NODE),
    Some(&VARS_METAC_NODE),
    None,
    None,
    None,
    Some(&VARS_METAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_METAL_NODE),
    Some(&VARS_METAM_NODE),
    None,
    None,
    Some(&VARS_METAP_NODE),
    None,
    None,
    Some(&VARS_METAS_NODE),
    Some(&VARS_METAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_METAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAT_CHILDREN),
    value: None,
};

pub static VARS_METAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hesise"),
        dictgen::InsensitiveStr::Ascii("hesised"),
        dictgen::InsensitiveStr::Ascii("hesises"),
        dictgen::InsensitiveStr::Ascii("hesising"),
        dictgen::InsensitiveStr::Ascii("hesize"),
        dictgen::InsensitiveStr::Ascii("hesized"),
        dictgen::InsensitiveStr::Ascii("hesizes"),
        dictgen::InsensitiveStr::Ascii("hesizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METATHESIZE_7314132290356926964)],
        &[(0b10010, &ENTRY_METATHESIZED_8943865811121602848)],
        &[(0b10010, &ENTRY_METATHESIZES_8073648188585933262)],
        &[(0b10010, &ENTRY_METATHESIZING_6771620324906770468)],
        &[(0b01001, &ENTRY_METATHESIZE_7314132290356926964)],
        &[(0b01001, &ENTRY_METATHESIZED_8943865811121602848)],
        &[(0b01001, &ENTRY_METATHESIZES_8073648188585933262)],
        &[(0b01001, &ENTRY_METATHESIZING_6771620324906770468)],
    ],
    range: 6..=8,
};

static VARS_METAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAS_CHILDREN),
    value: None,
};

pub static VARS_METAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tasise"),
        dictgen::InsensitiveStr::Ascii("tasised"),
        dictgen::InsensitiveStr::Ascii("tasises"),
        dictgen::InsensitiveStr::Ascii("tasising"),
        dictgen::InsensitiveStr::Ascii("tasize"),
        dictgen::InsensitiveStr::Ascii("tasized"),
        dictgen::InsensitiveStr::Ascii("tasizes"),
        dictgen::InsensitiveStr::Ascii("tasizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METASTASIZE_14424064478553972270)],
        &[(0b10010, &ENTRY_METASTASIZED_7988308203364783556)],
        &[(0b10010, &ENTRY_METASTASIZES_14097418011255033225)],
        &[(0b10010, &ENTRY_METASTASIZING_4346860356285509431)],
        &[(0b01001, &ENTRY_METASTASIZE_14424064478553972270)],
        &[(0b01001, &ENTRY_METASTASIZED_7988308203364783556)],
        &[(0b01001, &ENTRY_METASTASIZES_14097418011255033225)],
        &[(0b01001, &ENTRY_METASTASIZING_4346860356285509431)],
    ],
    range: 6..=8,
};

static VARS_METAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAP_CHILDREN),
    value: None,
};

pub static VARS_METAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("honise"),
        dictgen::InsensitiveStr::Ascii("honises"),
        dictgen::InsensitiveStr::Ascii("honize"),
        dictgen::InsensitiveStr::Ascii("honizes"),
        dictgen::InsensitiveStr::Ascii("horise"),
        dictgen::InsensitiveStr::Ascii("horises"),
        dictgen::InsensitiveStr::Ascii("horize"),
        dictgen::InsensitiveStr::Ascii("horizes"),
        dictgen::InsensitiveStr::Ascii("hysicise"),
        dictgen::InsensitiveStr::Ascii("hysicises"),
        dictgen::InsensitiveStr::Ascii("hysicize"),
        dictgen::InsensitiveStr::Ascii("hysicizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METAPHONIZE_957416918868098710)],
        &[(0b10010, &ENTRY_METAPHONIZES_10502975870853971385)],
        &[(0b01001, &ENTRY_METAPHONIZE_957416918868098710)],
        &[(0b01001, &ENTRY_METAPHONIZES_10502975870853971385)],
        &[(0b10010, &ENTRY_METAPHORIZE_4064664541866675399)],
        &[(0b10010, &ENTRY_METAPHORIZES_12240673682831942337)],
        &[(0b01001, &ENTRY_METAPHORIZE_4064664541866675399)],
        &[(0b01001, &ENTRY_METAPHORIZES_12240673682831942337)],
        &[(0b10010, &ENTRY_METAPHYSICIZE_2295151515066980674)],
        &[(0b10010, &ENTRY_METAPHYSICIZES_8743324838290261598)],
        &[(0b01001, &ENTRY_METAPHYSICIZE_2295151515066980674)],
        &[(0b01001, &ENTRY_METAPHYSICIZES_8743324838290261598)],
    ],
    range: 6..=9,
};

static VARS_METAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAM_CHILDREN),
    value: None,
};

pub static VARS_METAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("eriseds"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METAMERIZATION_2147110593558933265)],
        &[(0b10010, &ENTRY_METAMERIZATIONS_613063263580719403)],
        &[(0b10010, &ENTRY_METAMERIZED_10579453458080805856)],
        &[(0b10010, &ENTRY_METAMERIZEDS_4467995640688317236)],
        &[(0b01001, &ENTRY_METAMERIZATION_2147110593558933265)],
        &[(0b01001, &ENTRY_METAMERIZATIONS_613063263580719403)],
        &[(0b01001, &ENTRY_METAMERIZED_10579453458080805856)],
        &[(0b01001, &ENTRY_METAMERIZEDS_4467995640688317236)],
    ],
    range: 6..=10,
};

static VARS_METAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAL_CHILDREN),
    value: None,
};

pub static VARS_METAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_METALED_11411260958286166568)],
        &[(0b01001, &ENTRY_METALING_10131130132844817603)],
        &[(0b00001, &ENTRY_METALIZATION_2737656944192418067)],
        &[(0b00001, &ENTRY_METALIZATIONS_12814245870584390497)],
        &[(0b00001, &ENTRY_METALIZE_10265648959816292880)],
        &[(0b00001, &ENTRY_METALIZED_13873262702122532833)],
        &[(0b00001, &ENTRY_METALIZES_15413109627770746740)],
        &[(0b00001, &ENTRY_METALIZING_10340234665862306631)],
        &[(0b11010, &ENTRY_METALED_11411260958286166568)],
        &[(0b11010, &ENTRY_METALING_10131130132844817603)],
        &[(0b10010, &ENTRY_METALIZATION_2737656944192418067)],
        &[(0b10010, &ENTRY_METALIZATIONS_12814245870584390497)],
        &[(0b10010, &ENTRY_METALIZE_10265648959816292880)],
        &[(0b10010, &ENTRY_METALIZED_13873262702122532833)],
        &[(0b10010, &ENTRY_METALIZES_15413109627770746740)],
        &[(0b10010, &ENTRY_METALIZING_10340234665862306631)],
        &[(0b01000, &ENTRY_METALIZATION_2737656944192418067)],
        &[(0b01000, &ENTRY_METALIZATIONS_12814245870584390497)],
        &[(0b01000, &ENTRY_METALIZE_10265648959816292880)],
        &[(0b01000, &ENTRY_METALIZED_13873262702122532833)],
        &[(0b01000, &ENTRY_METALIZES_15413109627770746740)],
        &[(0b01000, &ENTRY_METALIZING_10340234665862306631)],
    ],
    range: 2..=9,
};

static VARS_METAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAG_CHILDREN),
    value: None,
};

pub static VARS_METAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rabolise"),
        dictgen::InsensitiveStr::Ascii("rabolised"),
        dictgen::InsensitiveStr::Ascii("rabolises"),
        dictgen::InsensitiveStr::Ascii("rabolising"),
        dictgen::InsensitiveStr::Ascii("rabolize"),
        dictgen::InsensitiveStr::Ascii("rabolized"),
        dictgen::InsensitiveStr::Ascii("rabolizes"),
        dictgen::InsensitiveStr::Ascii("rabolizing"),
        dictgen::InsensitiveStr::Ascii("robolise"),
        dictgen::InsensitiveStr::Ascii("robolised"),
        dictgen::InsensitiveStr::Ascii("robolises"),
        dictgen::InsensitiveStr::Ascii("robolising"),
        dictgen::InsensitiveStr::Ascii("robolize"),
        dictgen::InsensitiveStr::Ascii("robolized"),
        dictgen::InsensitiveStr::Ascii("robolizes"),
        dictgen::InsensitiveStr::Ascii("robolizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METAGRABOLIZE_4339239122760344200)],
        &[(0b10010, &ENTRY_METAGRABOLIZED_13543497967392033141)],
        &[(0b10010, &ENTRY_METAGRABOLIZES_14921829028195999540)],
        &[(0b10010, &ENTRY_METAGRABOLIZING_10957957182586459380)],
        &[(0b01001, &ENTRY_METAGRABOLIZE_4339239122760344200)],
        &[(0b01001, &ENTRY_METAGRABOLIZED_13543497967392033141)],
        &[(0b01001, &ENTRY_METAGRABOLIZES_14921829028195999540)],
        &[(0b01001, &ENTRY_METAGRABOLIZING_10957957182586459380)],
        &[(0b10010, &ENTRY_METAGROBOLIZE_3274575390383359935)],
        &[(0b10010, &ENTRY_METAGROBOLIZED_7134519687053222286)],
        &[(0b10010, &ENTRY_METAGROBOLIZES_10659207287620041997)],
        &[(0b10010, &ENTRY_METAGROBOLIZING_16754461244152950181)],
        &[(0b01001, &ENTRY_METAGROBOLIZE_3274575390383359935)],
        &[(0b01001, &ENTRY_METAGROBOLIZED_7134519687053222286)],
        &[(0b01001, &ENTRY_METAGROBOLIZES_10659207287620041997)],
        &[(0b01001, &ENTRY_METAGROBOLIZING_16754461244152950181)],
    ],
    range: 8..=10,
};

static VARS_METAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAC_CHILDREN),
    value: None,
};

pub static VARS_METAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_METACENTER_12861464410788453410)],
        &[(0b00001, &ENTRY_METACENTERS_10602862670736052985)],
        &[(0b11010, &ENTRY_METACENTER_12861464410788453410)],
        &[(0b11010, &ENTRY_METACENTERS_10602862670736052985)],
    ],
    range: 5..=6,
};

static VARS_METAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_METAB_CHILDREN),
    value: None,
};

pub static VARS_METAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olisable"),
        dictgen::InsensitiveStr::Ascii("olisables"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olizable"),
        dictgen::InsensitiveStr::Ascii("olizables"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_METABOLIZABLE_9746555623918169812)],
        &[(0b10010, &ENTRY_METABOLIZABLES_10614491304432551547)],
        &[(0b10010, &ENTRY_METABOLIZE_12396682712077398162)],
        &[(0b10010, &ENTRY_METABOLIZED_13396525183658045150)],
        &[(0b10010, &ENTRY_METABOLIZES_9009933951399545406)],
        &[(0b10010, &ENTRY_METABOLIZING_16268020869626432724)],
        &[(0b01001, &ENTRY_METABOLIZABLE_9746555623918169812)],
        &[(0b01001, &ENTRY_METABOLIZABLES_10614491304432551547)],
        &[(0b01001, &ENTRY_METABOLIZE_12396682712077398162)],
        &[(0b01001, &ENTRY_METABOLIZED_13396525183658045150)],
        &[(0b01001, &ENTRY_METABOLIZES_9009933951399545406)],
        &[(0b01001, &ENTRY_METABOLIZING_16268020869626432724)],
    ],
    range: 5..=9,
};

static VARS_MES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MES_CHILDREN),
    value: None,
};

pub static VARS_MES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("merisabilities"),
        dictgen::InsensitiveStr::Ascii("merisability"),
        dictgen::InsensitiveStr::Ascii("merisable"),
        dictgen::InsensitiveStr::Ascii("merisables"),
        dictgen::InsensitiveStr::Ascii("merisation"),
        dictgen::InsensitiveStr::Ascii("merisations"),
        dictgen::InsensitiveStr::Ascii("merise"),
        dictgen::InsensitiveStr::Ascii("merised"),
        dictgen::InsensitiveStr::Ascii("meriser"),
        dictgen::InsensitiveStr::Ascii("merisers"),
        dictgen::InsensitiveStr::Ascii("merises"),
        dictgen::InsensitiveStr::Ascii("merising"),
        dictgen::InsensitiveStr::Ascii("merizabilities"),
        dictgen::InsensitiveStr::Ascii("merizability"),
        dictgen::InsensitiveStr::Ascii("merizable"),
        dictgen::InsensitiveStr::Ascii("merizables"),
        dictgen::InsensitiveStr::Ascii("merization"),
        dictgen::InsensitiveStr::Ascii("merizations"),
        dictgen::InsensitiveStr::Ascii("merize"),
        dictgen::InsensitiveStr::Ascii("merized"),
        dictgen::InsensitiveStr::Ascii("merizer"),
        dictgen::InsensitiveStr::Ascii("merizers"),
        dictgen::InsensitiveStr::Ascii("merizes"),
        dictgen::InsensitiveStr::Ascii("merizing"),
        dictgen::InsensitiveStr::Ascii("oglea"),
        dictgen::InsensitiveStr::Ascii("ogleal"),
        dictgen::InsensitiveStr::Ascii("ogleas"),
        dictgen::InsensitiveStr::Ascii("ogloea"),
        dictgen::InsensitiveStr::Ascii("ogloeal"),
        dictgen::InsensitiveStr::Ascii("ogloeas"),
        dictgen::InsensitiveStr::Ascii("prise"),
        dictgen::InsensitiveStr::Ascii("prises"),
        dictgen::InsensitiveStr::Ascii("prize"),
        dictgen::InsensitiveStr::Ascii("prizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MESMERIZABILITIES_2235333359977552261)],
        &[(0b10010, &ENTRY_MESMERIZABILITY_10832984732093003313)],
        &[(0b10010, &ENTRY_MESMERIZABLE_1707311909740579070)],
        &[(0b10010, &ENTRY_MESMERIZABLES_18311050620178554784)],
        &[(0b10010, &ENTRY_MESMERIZATION_8961271965340064710)],
        &[(0b10010, &ENTRY_MESMERIZATIONS_7650562438007026759)],
        &[(0b10010, &ENTRY_MESMERIZE_8247464516832987079)],
        &[(0b10010, &ENTRY_MESMERIZED_14030290228729285174)],
        &[(0b10010, &ENTRY_MESMERIZER_12079073180184450954)],
        &[(0b10010, &ENTRY_MESMERIZERS_2175164108172756867)],
        &[(0b10010, &ENTRY_MESMERIZES_3470825852692700157)],
        &[(0b10010, &ENTRY_MESMERIZING_9747635351758180951)],
        &[(0b01001, &ENTRY_MESMERIZABILITIES_2235333359977552261)],
        &[(0b01001, &ENTRY_MESMERIZABILITY_10832984732093003313)],
        &[(0b01001, &ENTRY_MESMERIZABLE_1707311909740579070)],
        &[(0b01001, &ENTRY_MESMERIZABLES_18311050620178554784)],
        &[(0b01001, &ENTRY_MESMERIZATION_8961271965340064710)],
        &[(0b01001, &ENTRY_MESMERIZATIONS_7650562438007026759)],
        &[(0b01001, &ENTRY_MESMERIZE_8247464516832987079)],
        &[(0b01001, &ENTRY_MESMERIZED_14030290228729285174)],
        &[(0b01001, &ENTRY_MESMERIZER_12079073180184450954)],
        &[(0b01001, &ENTRY_MESMERIZERS_2175164108172756867)],
        &[(0b01001, &ENTRY_MESMERIZES_3470825852692700157)],
        &[(0b01001, &ENTRY_MESMERIZING_9747635351758180951)],
        &[(0b00001, &ENTRY_MESOGLEA_18368820102082494563)],
        &[(0b00001, &ENTRY_MESOGLEAL_1179622660000981537)],
        &[(0b00001, &ENTRY_MESOGLEAS_15641828554859977983)],
        &[(0b11010, &ENTRY_MESOGLEA_18368820102082494563)],
        &[(0b11010, &ENTRY_MESOGLEAL_1179622660000981537)],
        &[(0b11010, &ENTRY_MESOGLEAS_15641828554859977983)],
        &[(0b10010, &ENTRY_MESPRIZE_626385901018439636)],
        &[(0b10010, &ENTRY_MESPRIZES_634955430244876338)],
        &[(0b01001, &ENTRY_MESPRIZE_626385901018439636)],
        &[(0b01001, &ENTRY_MESPRIZES_634955430244876338)],
    ],
    range: 5..=14,
};

static VARS_MER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MER_CHILDREN),
    value: None,
};

pub static VARS_MER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("cerisation"),
        dictgen::InsensitiveStr::Ascii("cerisations"),
        dictgen::InsensitiveStr::Ascii("cerise"),
        dictgen::InsensitiveStr::Ascii("cerised"),
        dictgen::InsensitiveStr::Ascii("ceriser"),
        dictgen::InsensitiveStr::Ascii("cerisers"),
        dictgen::InsensitiveStr::Ascii("cerises"),
        dictgen::InsensitiveStr::Ascii("cerising"),
        dictgen::InsensitiveStr::Ascii("cerization"),
        dictgen::InsensitiveStr::Ascii("cerizations"),
        dictgen::InsensitiveStr::Ascii("cerize"),
        dictgen::InsensitiveStr::Ascii("cerized"),
        dictgen::InsensitiveStr::Ascii("cerizer"),
        dictgen::InsensitiveStr::Ascii("cerizers"),
        dictgen::InsensitiveStr::Ascii("cerizes"),
        dictgen::InsensitiveStr::Ascii("cerizing"),
        dictgen::InsensitiveStr::Ascii("curialisation"),
        dictgen::InsensitiveStr::Ascii("curialisations"),
        dictgen::InsensitiveStr::Ascii("curialise"),
        dictgen::InsensitiveStr::Ascii("curialised"),
        dictgen::InsensitiveStr::Ascii("curialises"),
        dictgen::InsensitiveStr::Ascii("curialising"),
        dictgen::InsensitiveStr::Ascii("curialization"),
        dictgen::InsensitiveStr::Ascii("curializations"),
        dictgen::InsensitiveStr::Ascii("curialize"),
        dictgen::InsensitiveStr::Ascii("curialized"),
        dictgen::InsensitiveStr::Ascii("curializes"),
        dictgen::InsensitiveStr::Ascii("curializing"),
        dictgen::InsensitiveStr::Ascii("curise"),
        dictgen::InsensitiveStr::Ascii("curised"),
        dictgen::InsensitiveStr::Ascii("curises"),
        dictgen::InsensitiveStr::Ascii("curising"),
        dictgen::InsensitiveStr::Ascii("curize"),
        dictgen::InsensitiveStr::Ascii("curized"),
        dictgen::InsensitiveStr::Ascii("curizes"),
        dictgen::InsensitiveStr::Ascii("curizing"),
        dictgen::InsensitiveStr::Ascii("oae"),
        dictgen::InsensitiveStr::Ascii("oe"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MERA_2238379545822097898)],
        &[(0b10010, &ENTRY_MERCERIZATION_14891932795764931552)],
        &[(0b10010, &ENTRY_MERCERIZATIONS_12875656223878026724)],
        &[(0b10010, &ENTRY_MERCERIZE_15182792491441059447)],
        &[(0b10010, &ENTRY_MERCERIZED_12441200842633397226)],
        &[(0b10010, &ENTRY_MERCERIZER_2628289242439953198)],
        &[(0b10010, &ENTRY_MERCERIZERS_231878388937737223)],
        &[(0b10010, &ENTRY_MERCERIZES_11625551039561273101)],
        &[(0b10010, &ENTRY_MERCERIZING_12341499939260844341)],
        &[(0b01001, &ENTRY_MERCERIZATION_14891932795764931552)],
        &[(0b01001, &ENTRY_MERCERIZATIONS_12875656223878026724)],
        &[(0b01001, &ENTRY_MERCERIZE_15182792491441059447)],
        &[(0b01001, &ENTRY_MERCERIZED_12441200842633397226)],
        &[(0b01001, &ENTRY_MERCERIZER_2628289242439953198)],
        &[(0b01001, &ENTRY_MERCERIZERS_231878388937737223)],
        &[(0b01001, &ENTRY_MERCERIZES_11625551039561273101)],
        &[(0b01001, &ENTRY_MERCERIZING_12341499939260844341)],
        &[(0b10010, &ENTRY_MERCURIALIZATION_12125945095948399146)],
        &[(0b10010, &ENTRY_MERCURIALIZATIONS_12336168913360947002)],
        &[(0b10010, &ENTRY_MERCURIALIZE_3364801806643879631)],
        &[(0b10010, &ENTRY_MERCURIALIZED_6385834004082463546)],
        &[(0b10010, &ENTRY_MERCURIALIZES_1343259582893080731)],
        &[(0b10010, &ENTRY_MERCURIALIZING_10236574536722882122)],
        &[(0b01001, &ENTRY_MERCURIALIZATION_12125945095948399146)],
        &[(0b01001, &ENTRY_MERCURIALIZATIONS_12336168913360947002)],
        &[(0b01001, &ENTRY_MERCURIALIZE_3364801806643879631)],
        &[(0b01001, &ENTRY_MERCURIALIZED_6385834004082463546)],
        &[(0b01001, &ENTRY_MERCURIALIZES_1343259582893080731)],
        &[(0b01001, &ENTRY_MERCURIALIZING_10236574536722882122)],
        &[(0b10010, &ENTRY_MERCURIZE_17518451926892582183)],
        &[(0b10010, &ENTRY_MERCURIZED_4260915582458843031)],
        &[(0b10010, &ENTRY_MERCURIZES_1462619783730817794)],
        &[(0b10010, &ENTRY_MERCURIZING_13905940081457194303)],
        &[(0b01001, &ENTRY_MERCURIZE_17518451926892582183)],
        &[(0b01001, &ENTRY_MERCURIZED_4260915582458843031)],
        &[(0b01001, &ENTRY_MERCURIZES_1462619783730817794)],
        &[(0b01001, &ENTRY_MERCURIZING_13905940081457194303)],
        &[(0b11010, &ENTRY_MEROE_450227222285392193)],
        &[(0b00001, &ENTRY_MEROE_450227222285392193)],
    ],
    range: 1..=14,
};

static VARS_MEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEP_CHILDREN),
    value: None,
};

pub static VARS_MEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hitinae"),
        dictgen::InsensitiveStr::Ascii("hitine"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MEPHITINE_5769700321158530059)],
        &[(0b00001, &ENTRY_MEPHITINE_5769700321158530059)],
    ],
    range: 6..=7,
};

static VARS_MEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEN_CHILDREN),
    value: None,
};

pub static VARS_MEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ad"),
        dictgen::InsensitiveStr::Ascii("adic"),
        dictgen::InsensitiveStr::Ascii("ads"),
        dictgen::InsensitiveStr::Ascii("delise"),
        dictgen::InsensitiveStr::Ascii("delises"),
        dictgen::InsensitiveStr::Ascii("delize"),
        dictgen::InsensitiveStr::Ascii("delizes"),
        dictgen::InsensitiveStr::Ascii("ingorrhea"),
        dictgen::InsensitiveStr::Ascii("ingorrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrheas"),
        dictgen::InsensitiveStr::Ascii("orrheic"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhoeas"),
        dictgen::InsensitiveStr::Ascii("orrhoeic"),
        dictgen::InsensitiveStr::Ascii("sae"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("talisation"),
        dictgen::InsensitiveStr::Ascii("talisations"),
        dictgen::InsensitiveStr::Ascii("talise"),
        dictgen::InsensitiveStr::Ascii("talises"),
        dictgen::InsensitiveStr::Ascii("talization"),
        dictgen::InsensitiveStr::Ascii("talizations"),
        dictgen::InsensitiveStr::Ascii("talize"),
        dictgen::InsensitiveStr::Ascii("talizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MAENAD_6687371101734029319)],
        &[(0b00001, &ENTRY_MAENADIC_15288928011763831510)],
        &[(0b00001, &ENTRY_MAENADS_7925698232866691077)],
        &[(0b10010, &ENTRY_MENDELIZE_13155598837739586689)],
        &[(0b10010, &ENTRY_MENDELIZES_11591249054331616238)],
        &[(0b01001, &ENTRY_MENDELIZE_13155598837739586689)],
        &[(0b01001, &ENTRY_MENDELIZES_11591249054331616238)],
        &[(0b10001, &ENTRY_MENINGORRHEA_2384221611932253259)],
        &[(0b11010, &ENTRY_MENINGORRHEA_2384221611932253259)],
        &[(0b10001, &ENTRY_MENORRHEA_7798588011650236994)],
        &[(0b10001, &ENTRY_MENORRHEAS_2672863015361396457)],
        &[(0b10001, &ENTRY_MENORRHEIC_7610022187186673774)],
        &[(0b11010, &ENTRY_MENORRHEA_7798588011650236994)],
        &[(0b11010, &ENTRY_MENORRHEAS_2672863015361396457)],
        &[(0b11010, &ENTRY_MENORRHEIC_7610022187186673774)],
        &[(0b11010, &ENTRY_MENSE_16673844012933097881)],
        &[(0b00001, &ENTRY_MENSE_16673844012933097881)],
        &[(0b10010, &ENTRY_MENTALIZATION_6058534137827415789)],
        &[(0b10010, &ENTRY_MENTALIZATIONS_14912536060408920277)],
        &[(0b10010, &ENTRY_MENTALIZE_1038523375536757780)],
        &[(0b10010, &ENTRY_MENTALIZES_12647784615922375764)],
        &[(0b01001, &ENTRY_MENTALIZATION_6058534137827415789)],
        &[(0b01001, &ENTRY_MENTALIZATIONS_14912536060408920277)],
        &[(0b01001, &ENTRY_MENTALIZE_1038523375536757780)],
        &[(0b01001, &ENTRY_MENTALIZES_12647784615922375764)],
    ],
    range: 2..=11,
};

static VARS_MEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEM_CHILDREN),
    value: None,
};

pub static VARS_MEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orialisation"),
        dictgen::InsensitiveStr::Ascii("orialisations"),
        dictgen::InsensitiveStr::Ascii("orialise"),
        dictgen::InsensitiveStr::Ascii("orialised"),
        dictgen::InsensitiveStr::Ascii("orialiser"),
        dictgen::InsensitiveStr::Ascii("orialisers"),
        dictgen::InsensitiveStr::Ascii("orialises"),
        dictgen::InsensitiveStr::Ascii("orialising"),
        dictgen::InsensitiveStr::Ascii("orialization"),
        dictgen::InsensitiveStr::Ascii("orializations"),
        dictgen::InsensitiveStr::Ascii("orialize"),
        dictgen::InsensitiveStr::Ascii("orialized"),
        dictgen::InsensitiveStr::Ascii("orializer"),
        dictgen::InsensitiveStr::Ascii("orializers"),
        dictgen::InsensitiveStr::Ascii("orializes"),
        dictgen::InsensitiveStr::Ascii("orializing"),
        dictgen::InsensitiveStr::Ascii("orisable"),
        dictgen::InsensitiveStr::Ascii("orisables"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("oriser"),
        dictgen::InsensitiveStr::Ascii("orisers"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orizable"),
        dictgen::InsensitiveStr::Ascii("orizables"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizer"),
        dictgen::InsensitiveStr::Ascii("orizers"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MEMORIALIZATION_8125433852548617131)],
        &[(0b10010, &ENTRY_MEMORIALIZATIONS_15285671033015235264)],
        &[(0b10010, &ENTRY_MEMORIALIZE_12843972171438242442)],
        &[(0b10010, &ENTRY_MEMORIALIZED_11248998509134482621)],
        &[(0b10010, &ENTRY_MEMORIALIZER_188024871039509941)],
        &[(0b10010, &ENTRY_MEMORIALIZERS_3516900229786026104)],
        &[(0b10010, &ENTRY_MEMORIALIZES_15034789887931696988)],
        &[(0b10010, &ENTRY_MEMORIALIZING_4629190360507969042)],
        &[(0b01001, &ENTRY_MEMORIALIZATION_8125433852548617131)],
        &[(0b01001, &ENTRY_MEMORIALIZATIONS_15285671033015235264)],
        &[(0b01001, &ENTRY_MEMORIALIZE_12843972171438242442)],
        &[(0b01001, &ENTRY_MEMORIALIZED_11248998509134482621)],
        &[(0b01001, &ENTRY_MEMORIALIZER_188024871039509941)],
        &[(0b01001, &ENTRY_MEMORIALIZERS_3516900229786026104)],
        &[(0b01001, &ENTRY_MEMORIALIZES_15034789887931696988)],
        &[(0b01001, &ENTRY_MEMORIALIZING_4629190360507969042)],
        &[(0b10010, &ENTRY_MEMORIZABLE_11352668762729937122)],
        &[(0b10010, &ENTRY_MEMORIZABLES_17876290914617649824)],
        &[(0b10010, &ENTRY_MEMORIZATION_11518051927242789602)],
        &[(0b10010, &ENTRY_MEMORIZATIONS_17836564012509783241)],
        &[(0b10010, &ENTRY_MEMORIZE_3326918095136387049)],
        &[(0b10010, &ENTRY_MEMORIZED_18012206033008846662)],
        &[(0b10010, &ENTRY_MEMORIZER_3044267375638741545)],
        &[(0b10010, &ENTRY_MEMORIZERS_5910795194513615614)],
        &[(0b10010, &ENTRY_MEMORIZES_6598457048183240033)],
        &[(0b10010, &ENTRY_MEMORIZING_10196488108085766880)],
        &[(0b01001, &ENTRY_MEMORIZABLE_11352668762729937122)],
        &[(0b01001, &ENTRY_MEMORIZABLES_17876290914617649824)],
        &[(0b01001, &ENTRY_MEMORIZATION_11518051927242789602)],
        &[(0b01001, &ENTRY_MEMORIZATIONS_17836564012509783241)],
        &[(0b01001, &ENTRY_MEMORIZE_3326918095136387049)],
        &[(0b01001, &ENTRY_MEMORIZED_18012206033008846662)],
        &[(0b01001, &ENTRY_MEMORIZER_3044267375638741545)],
        &[(0b01001, &ENTRY_MEMORIZERS_5910795194513615614)],
        &[(0b01001, &ENTRY_MEMORIZES_6598457048183240033)],
        &[(0b01001, &ENTRY_MEMORIZING_10196488108085766880)],
    ],
    range: 5..=13,
};

static VARS_MEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEL_CHILDREN),
    value: None,
};

pub static VARS_MEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aena"),
        dictgen::InsensitiveStr::Ascii("aenic"),
        dictgen::InsensitiveStr::Ascii("anaemia"),
        dictgen::InsensitiveStr::Ascii("anaemic"),
        dictgen::InsensitiveStr::Ascii("anemia"),
        dictgen::InsensitiveStr::Ascii("anemic"),
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("enic"),
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("ie"),
        dictgen::InsensitiveStr::Ascii("inae"),
        dictgen::InsensitiveStr::Ascii("ine"),
        dictgen::InsensitiveStr::Ascii("itaemia"),
        dictgen::InsensitiveStr::Ascii("itemia"),
        dictgen::InsensitiveStr::Ascii("ithaemia"),
        dictgen::InsensitiveStr::Ascii("ithemia"),
        dictgen::InsensitiveStr::Ascii("lon"),
        dictgen::InsensitiveStr::Ascii("odisation"),
        dictgen::InsensitiveStr::Ascii("odise"),
        dictgen::InsensitiveStr::Ascii("odised"),
        dictgen::InsensitiveStr::Ascii("odiser"),
        dictgen::InsensitiveStr::Ascii("odises"),
        dictgen::InsensitiveStr::Ascii("odising"),
        dictgen::InsensitiveStr::Ascii("odization"),
        dictgen::InsensitiveStr::Ascii("odize"),
        dictgen::InsensitiveStr::Ascii("odized"),
        dictgen::InsensitiveStr::Ascii("odizer"),
        dictgen::InsensitiveStr::Ascii("odizes"),
        dictgen::InsensitiveStr::Ascii("odizing"),
        dictgen::InsensitiveStr::Ascii("odramatisation"),
        dictgen::InsensitiveStr::Ascii("odramatise"),
        dictgen::InsensitiveStr::Ascii("odramatised"),
        dictgen::InsensitiveStr::Ascii("odramatises"),
        dictgen::InsensitiveStr::Ascii("odramatising"),
        dictgen::InsensitiveStr::Ascii("odramatization"),
        dictgen::InsensitiveStr::Ascii("odramatize"),
        dictgen::InsensitiveStr::Ascii("odramatized"),
        dictgen::InsensitiveStr::Ascii("odramatizes"),
        dictgen::InsensitiveStr::Ascii("odramatizing"),
        dictgen::InsensitiveStr::Ascii("oe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MELENA_17340470388387299570)],
        &[(0b11010, &ENTRY_MELENIC_2894828040941053782)],
        &[(0b11010, &ENTRY_MELANEMIA_3627025763487786313)],
        &[(0b11010, &ENTRY_MELANEMIC_13613605974584449832)],
        &[(0b10001, &ENTRY_MELANEMIA_3627025763487786313)],
        &[(0b10001, &ENTRY_MELANEMIC_13613605974584449832)],
        &[(0b10010, &ENTRY_MELANIZATION_4310350431255787228)],
        &[(0b10010, &ENTRY_MELANIZE_7849072016729938941)],
        &[(0b10010, &ENTRY_MELANIZED_5005801037460172353)],
        &[(0b10010, &ENTRY_MELANIZES_4272022967769484050)],
        &[(0b10010, &ENTRY_MELANIZING_874608171361269844)],
        &[(0b01001, &ENTRY_MELANIZATION_4310350431255787228)],
        &[(0b01001, &ENTRY_MELANIZE_7849072016729938941)],
        &[(0b01001, &ENTRY_MELANIZED_5005801037460172353)],
        &[(0b01001, &ENTRY_MELANIZES_4272022967769484050)],
        &[(0b01001, &ENTRY_MELANIZING_874608171361269844)],
        &[(0b00001, &ENTRY_MELE_14922314763041738254)],
        &[(0b00001, &ENTRY_MELENA_17340470388387299570)],
        &[(0b00001, &ENTRY_MELENIC_2894828040941053782)],
        &[(0b11010, &ENTRY_MELIE_11824537289201512564)],
        &[(0b00001, &ENTRY_MELIE_11824537289201512564)],
        &[(0b11010, &ENTRY_MELINE_10641747453274309529)],
        &[(0b00001, &ENTRY_MELINE_10641747453274309529)],
        &[(0b11010, &ENTRY_MELITEMIA_2708409562640762486)],
        &[(0b00001, &ENTRY_MELITEMIA_2708409562640762486)],
        &[(0b11010, &ENTRY_MELITHEMIA_7590421864945761846)],
        &[(0b00001, &ENTRY_MELITHEMIA_7590421864945761846)],
        &[(0b00001, &ENTRY_MELLON_391954139899810285)],
        &[(0b10010, &ENTRY_MELODIZATION_7432583061443164587)],
        &[(0b10010, &ENTRY_MELODIZE_7738216678825813559)],
        &[(0b10010, &ENTRY_MELODIZED_7315404446965573837)],
        &[(0b10010, &ENTRY_MELODIZER_17176341135857748154)],
        &[(0b10010, &ENTRY_MELODIZES_355127131421165026)],
        &[(0b10010, &ENTRY_MELODIZING_13910918430639522337)],
        &[(0b01001, &ENTRY_MELODIZATION_7432583061443164587)],
        &[(0b01001, &ENTRY_MELODIZE_7738216678825813559)],
        &[(0b01001, &ENTRY_MELODIZED_7315404446965573837)],
        &[(0b01001, &ENTRY_MELODIZER_17176341135857748154)],
        &[(0b01001, &ENTRY_MELODIZES_355127131421165026)],
        &[(0b01001, &ENTRY_MELODIZING_13910918430639522337)],
        &[(0b10010, &ENTRY_MELODRAMATIZATION_17884213093816048338)],
        &[(0b10010, &ENTRY_MELODRAMATIZE_3695641167123938020)],
        &[(0b10010, &ENTRY_MELODRAMATIZED_4520313047331582327)],
        &[(0b10010, &ENTRY_MELODRAMATIZES_1590401015443283848)],
        &[(0b10010, &ENTRY_MELODRAMATIZING_11653694285687179428)],
        &[(0b01001, &ENTRY_MELODRAMATIZATION_17884213093816048338)],
        &[(0b01001, &ENTRY_MELODRAMATIZE_3695641167123938020)],
        &[(0b01001, &ENTRY_MELODRAMATIZED_4520313047331582327)],
        &[(0b01001, &ENTRY_MELODRAMATIZES_1590401015443283848)],
        &[(0b01001, &ENTRY_MELODRAMATIZING_11653694285687179428)],
        &[(0b11010, &ENTRY_MELE_14922314763041738254)],
    ],
    range: 1..=14,
};

static VARS_MEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEG_CHILDREN),
    value: None,
};

pub static VARS_MEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aerg"),
        dictgen::InsensitiveStr::Ascii("ameter"),
        dictgen::InsensitiveStr::Ascii("ametre"),
        dictgen::InsensitiveStr::Ascii("bote"),
        dictgen::InsensitiveStr::Ascii("erg"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MEGERG_17050520432197903681)],
        &[(0b00001, &ENTRY_MEGAMETER_1943008536807311428)],
        &[(0b11010, &ENTRY_MEGAMETER_1943008536807311428)],
        &[(0b00001, &ENTRY_MEGBOTE_6305017947026218797)],
        &[(0b00001, &ENTRY_MEGERG_17050520432197903681)],
    ],
    range: 3..=6,
};

static VARS_MED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MED_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_MED_5581722660439194258)]),
};

static VARS_MED_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MEDA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MEDI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_MEDI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEDI_CHILDREN),
    value: None,
};

pub static VARS_MEDI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aeval"),
        dictgen::InsensitiveStr::Ascii("aevalism"),
        dictgen::InsensitiveStr::Ascii("aevalisms"),
        dictgen::InsensitiveStr::Ascii("aevals"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("atisation"),
        dictgen::InsensitiveStr::Ascii("atisations"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atised"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atising"),
        dictgen::InsensitiveStr::Ascii("atization"),
        dictgen::InsensitiveStr::Ascii("atizations"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atized"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("atizing"),
        dictgen::InsensitiveStr::Ascii("calisation"),
        dictgen::InsensitiveStr::Ascii("calisations"),
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calised"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calising"),
        dictgen::InsensitiveStr::Ascii("calization"),
        dictgen::InsensitiveStr::Ascii("calizations"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calized"),
        dictgen::InsensitiveStr::Ascii("calizes"),
        dictgen::InsensitiveStr::Ascii("calizing"),
        dictgen::InsensitiveStr::Ascii("evalism"),
        dictgen::InsensitiveStr::Ascii("evalisms"),
        dictgen::InsensitiveStr::Ascii("evally"),
        dictgen::InsensitiveStr::Ascii("terraneanisation"),
        dictgen::InsensitiveStr::Ascii("terraneanisations"),
        dictgen::InsensitiveStr::Ascii("terraneanise"),
        dictgen::InsensitiveStr::Ascii("terraneanises"),
        dictgen::InsensitiveStr::Ascii("terraneanization"),
        dictgen::InsensitiveStr::Ascii("terraneanizations"),
        dictgen::InsensitiveStr::Ascii("terraneanize"),
        dictgen::InsensitiveStr::Ascii("terraneanizes"),
        dictgen::InsensitiveStr::Ascii("umisation"),
        dictgen::InsensitiveStr::Ascii("umisations"),
        dictgen::InsensitiveStr::Ascii("umise"),
        dictgen::InsensitiveStr::Ascii("umises"),
        dictgen::InsensitiveStr::Ascii("umization"),
        dictgen::InsensitiveStr::Ascii("umizations"),
        dictgen::InsensitiveStr::Ascii("umize"),
        dictgen::InsensitiveStr::Ascii("umizes"),
    ],
    values: &[
        &[(0b10011, &ENTRY_MEDIEVAL_1008732004874495105)],
        &[(0b11010, &ENTRY_MEDIEVALISM_7626307190061100596)],
        &[(0b11010, &ENTRY_MEDIEVALISMS_13648693867116920259)],
        &[(0b10011, &ENTRY_MEDIEVALS_13173357713744728823)],
        &[(0b10010, &ENTRY_MEDIALIZATION_11201086450154584377)],
        &[(0b10010, &ENTRY_MEDIALIZATIONS_9266737235252383366)],
        &[(0b10010, &ENTRY_MEDIALIZE_15964854162951169156)],
        &[(0b10010, &ENTRY_MEDIALIZES_9158496365414473522)],
        &[(0b01001, &ENTRY_MEDIALIZATION_11201086450154584377)],
        &[(0b01001, &ENTRY_MEDIALIZATIONS_9266737235252383366)],
        &[(0b01001, &ENTRY_MEDIALIZE_15964854162951169156)],
        &[(0b01001, &ENTRY_MEDIALIZES_9158496365414473522)],
        &[(0b10010, &ENTRY_MEDIATIZATION_13943602012568749747)],
        &[(0b10010, &ENTRY_MEDIATIZATIONS_16197242107778706785)],
        &[(0b10010, &ENTRY_MEDIATIZE_14921357820800349052)],
        &[(0b10010, &ENTRY_MEDIATIZED_16310994672212204317)],
        &[(0b10010, &ENTRY_MEDIATIZES_945460647564073412)],
        &[(0b10010, &ENTRY_MEDIATIZING_3100095196162520920)],
        &[(0b01001, &ENTRY_MEDIATIZATION_13943602012568749747)],
        &[(0b01001, &ENTRY_MEDIATIZATIONS_16197242107778706785)],
        &[(0b01001, &ENTRY_MEDIATIZE_14921357820800349052)],
        &[(0b01001, &ENTRY_MEDIATIZED_16310994672212204317)],
        &[(0b01001, &ENTRY_MEDIATIZES_945460647564073412)],
        &[(0b01001, &ENTRY_MEDIATIZING_3100095196162520920)],
        &[(0b10010, &ENTRY_MEDICALIZATION_2111892448928052093)],
        &[(0b10010, &ENTRY_MEDICALIZATIONS_16089901682373921411)],
        &[(0b10010, &ENTRY_MEDICALIZE_17606487197661150257)],
        &[(0b10010, &ENTRY_MEDICALIZED_10409251504127363635)],
        &[(0b10010, &ENTRY_MEDICALIZES_10125506143660647869)],
        &[(0b10010, &ENTRY_MEDICALIZING_4417395695056553530)],
        &[(0b01001, &ENTRY_MEDICALIZATION_2111892448928052093)],
        &[(0b01001, &ENTRY_MEDICALIZATIONS_16089901682373921411)],
        &[(0b01001, &ENTRY_MEDICALIZE_17606487197661150257)],
        &[(0b01001, &ENTRY_MEDICALIZED_10409251504127363635)],
        &[(0b01001, &ENTRY_MEDICALIZES_10125506143660647869)],
        &[(0b01001, &ENTRY_MEDICALIZING_4417395695056553530)],
        &[(0b00001, &ENTRY_MEDIEVALISM_7626307190061100596)],
        &[(0b00001, &ENTRY_MEDIEVALISMS_13648693867116920259)],
        &[(0b00001, &ENTRY_MEDIEVALLY_4074376096099201747)],
        &[(0b10010, &ENTRY_MEDITERRANEANIZATION_14068923875498088797)],
        &[(0b10010, &ENTRY_MEDITERRANEANIZATIONS_14143064455240736635)],
        &[(0b10010, &ENTRY_MEDITERRANEANIZE_3216295787007797019)],
        &[(0b10010, &ENTRY_MEDITERRANEANIZES_4936465023428726899)],
        &[(0b01001, &ENTRY_MEDITERRANEANIZATION_14068923875498088797)],
        &[(0b01001, &ENTRY_MEDITERRANEANIZATIONS_14143064455240736635)],
        &[(0b01001, &ENTRY_MEDITERRANEANIZE_3216295787007797019)],
        &[(0b01001, &ENTRY_MEDITERRANEANIZES_4936465023428726899)],
        &[(0b10010, &ENTRY_MEDIUMIZATION_13781773160846845668)],
        &[(0b10010, &ENTRY_MEDIUMIZATIONS_9700104300417877036)],
        &[(0b10010, &ENTRY_MEDIUMIZE_3727858729697566964)],
        &[(0b10010, &ENTRY_MEDIUMIZES_13996371956875882510)],
        &[(0b01001, &ENTRY_MEDIUMIZATION_13781773160846845668)],
        &[(0b01001, &ENTRY_MEDIUMIZATIONS_9700104300417877036)],
        &[(0b01001, &ENTRY_MEDIUMIZE_3727858729697566964)],
        &[(0b01001, &ENTRY_MEDIUMIZES_13996371956875882510)],
    ],
    range: 5..=17,
};

static VARS_MEDA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEDA_CHILDREN),
    value: None,
};

pub static VARS_MEDA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("list"),
        dictgen::InsensitiveStr::Ascii("lists"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("llist"),
        dictgen::InsensitiveStr::Ascii("llists"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MEDALED_9329802324825433304)],
        &[(0b00001, &ENTRY_MEDALING_15272839155813995206)],
        &[(0b10010, &ENTRY_MEDALIZE_6428378184574445930)],
        &[(0b10010, &ENTRY_MEDALIZES_8369354423782443921)],
        &[(0b00001, &ENTRY_MEDALIST_3813713439469975305)],
        &[(0b00001, &ENTRY_MEDALISTS_14543293296180708193)],
        &[(0b01001, &ENTRY_MEDALIZE_6428378184574445930)],
        &[(0b01001, &ENTRY_MEDALIZES_8369354423782443921)],
        &[(0b11010, &ENTRY_MEDALED_9329802324825433304)],
        &[(0b11010, &ENTRY_MEDALING_15272839155813995206)],
        &[(0b11010, &ENTRY_MEDALIST_3813713439469975305)],
        &[(0b11010, &ENTRY_MEDALISTS_14543293296180708193)],
    ],
    range: 3..=6,
};

static VARS_MEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEC_CHILDREN),
    value: None,
};

pub static VARS_MEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hanicalisation"),
        dictgen::InsensitiveStr::Ascii("hanicalisations"),
        dictgen::InsensitiveStr::Ascii("hanicalise"),
        dictgen::InsensitiveStr::Ascii("hanicalises"),
        dictgen::InsensitiveStr::Ascii("hanicalization"),
        dictgen::InsensitiveStr::Ascii("hanicalizations"),
        dictgen::InsensitiveStr::Ascii("hanicalize"),
        dictgen::InsensitiveStr::Ascii("hanicalizes"),
        dictgen::InsensitiveStr::Ascii("hanisable"),
        dictgen::InsensitiveStr::Ascii("hanisation"),
        dictgen::InsensitiveStr::Ascii("hanisations"),
        dictgen::InsensitiveStr::Ascii("hanise"),
        dictgen::InsensitiveStr::Ascii("hanised"),
        dictgen::InsensitiveStr::Ascii("haniser"),
        dictgen::InsensitiveStr::Ascii("hanisers"),
        dictgen::InsensitiveStr::Ascii("hanises"),
        dictgen::InsensitiveStr::Ascii("hanising"),
        dictgen::InsensitiveStr::Ascii("hanizable"),
        dictgen::InsensitiveStr::Ascii("hanization"),
        dictgen::InsensitiveStr::Ascii("hanizations"),
        dictgen::InsensitiveStr::Ascii("hanize"),
        dictgen::InsensitiveStr::Ascii("hanized"),
        dictgen::InsensitiveStr::Ascii("hanizer"),
        dictgen::InsensitiveStr::Ascii("hanizers"),
        dictgen::InsensitiveStr::Ascii("hanizes"),
        dictgen::InsensitiveStr::Ascii("hanizing"),
        dictgen::InsensitiveStr::Ascii("k"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MECHANICALIZATION_13195949433368378540)],
        &[(0b10010, &ENTRY_MECHANICALIZATIONS_17519748869411038519)],
        &[(0b10010, &ENTRY_MECHANICALIZE_12176998180861896123)],
        &[(0b10010, &ENTRY_MECHANICALIZES_11069973531634237808)],
        &[(0b01001, &ENTRY_MECHANICALIZATION_13195949433368378540)],
        &[(0b01001, &ENTRY_MECHANICALIZATIONS_17519748869411038519)],
        &[(0b01001, &ENTRY_MECHANICALIZE_12176998180861896123)],
        &[(0b01001, &ENTRY_MECHANICALIZES_11069973531634237808)],
        &[(0b10010, &ENTRY_MECHANIZABLE_4433487534726381759)],
        &[(0b10010, &ENTRY_MECHANIZATION_15363685468899666275)],
        &[(0b10010, &ENTRY_MECHANIZATIONS_16698691905505593378)],
        &[(0b10010, &ENTRY_MECHANIZE_14053959373358803371)],
        &[(0b10010, &ENTRY_MECHANIZED_12614146981841365583)],
        &[(0b10010, &ENTRY_MECHANIZER_1668821815609902700)],
        &[(0b10010, &ENTRY_MECHANIZERS_4315044385466386260)],
        &[(0b10010, &ENTRY_MECHANIZES_15199857738602551511)],
        &[(0b10010, &ENTRY_MECHANIZING_15496014639333728081)],
        &[(0b01001, &ENTRY_MECHANIZABLE_4433487534726381759)],
        &[(0b01001, &ENTRY_MECHANIZATION_15363685468899666275)],
        &[(0b01001, &ENTRY_MECHANIZATIONS_16698691905505593378)],
        &[(0b01001, &ENTRY_MECHANIZE_14053959373358803371)],
        &[(0b01001, &ENTRY_MECHANIZED_12614146981841365583)],
        &[(0b01001, &ENTRY_MECHANIZER_1668821815609902700)],
        &[(0b01001, &ENTRY_MECHANIZERS_4315044385466386260)],
        &[(0b01001, &ENTRY_MECHANIZES_15199857738602551511)],
        &[(0b01001, &ENTRY_MECHANIZING_15496014639333728081)],
        &[(0b00001, &ENTRY_MECK_5443554356343726238)],
    ],
    range: 1..=15,
};

static VARS_MEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MEA_CHILDREN),
    value: None,
};

pub static VARS_MEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ger"),
        dictgen::InsensitiveStr::Ascii("gerrer"),
        dictgen::InsensitiveStr::Ascii("gerrest"),
        dictgen::InsensitiveStr::Ascii("gre"),
        dictgen::InsensitiveStr::Ascii("grer"),
        dictgen::InsensitiveStr::Ascii("grest"),
        dictgen::InsensitiveStr::Ascii("ndrine"),
        dictgen::InsensitiveStr::Ascii("ndriniform"),
    ],
    values: &[
        &[(0b01001, &ENTRY_MEAGER_7974525186540147476)],
        &[(0b01001, &ENTRY_MEAGERRER_1795995436389544325)],
        &[(0b01001, &ENTRY_MEAGERREST_12190905609167997105)],
        &[(0b11010, &ENTRY_MEAGER_7974525186540147476)],
        &[(0b11010, &ENTRY_MEAGERRER_1795995436389544325)],
        &[(0b11010, &ENTRY_MEAGERREST_12190905609167997105)],
        &[(0b00001, &ENTRY_MEANDRINE_15281745123487615934)],
        &[(0b00001, &ENTRY_MEANDRINIFORM_8185091047283393921)],
    ],
    range: 3..=10,
};

static VARS_MA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MA_CHILDREN),
    value: None,
};

static VARS_MA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_MAA_NODE),
    None,
    Some(&VARS_MAC_NODE),
    Some(&VARS_MAD_NODE),
    Some(&VARS_MAE_NODE),
    None,
    Some(&VARS_MAG_NODE),
    Some(&VARS_MAH_NODE),
    Some(&VARS_MAI_NODE),
    Some(&VARS_MAJ_NODE),
    None,
    Some(&VARS_MAL_NODE),
    None,
    Some(&VARS_MAN_NODE),
    None,
    None,
    None,
    Some(&VARS_MAR_NODE),
    Some(&VARS_MAS_NODE),
    Some(&VARS_MAT_NODE),
    Some(&VARS_MAU_NODE),
    None,
    None,
    Some(&VARS_MAX_NODE),
    None,
    None,
];

static VARS_MAX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAX_CHILDREN),
    value: None,
};

pub static VARS_MAX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imisation"),
        dictgen::InsensitiveStr::Ascii("imisations"),
        dictgen::InsensitiveStr::Ascii("imise"),
        dictgen::InsensitiveStr::Ascii("imised"),
        dictgen::InsensitiveStr::Ascii("imiser"),
        dictgen::InsensitiveStr::Ascii("imisers"),
        dictgen::InsensitiveStr::Ascii("imises"),
        dictgen::InsensitiveStr::Ascii("imising"),
        dictgen::InsensitiveStr::Ascii("imization"),
        dictgen::InsensitiveStr::Ascii("imizations"),
        dictgen::InsensitiveStr::Ascii("imize"),
        dictgen::InsensitiveStr::Ascii("imized"),
        dictgen::InsensitiveStr::Ascii("imizer"),
        dictgen::InsensitiveStr::Ascii("imizers"),
        dictgen::InsensitiveStr::Ascii("imizes"),
        dictgen::InsensitiveStr::Ascii("imizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAXIMIZATION_17686901393811165015)],
        &[(0b10010, &ENTRY_MAXIMIZATIONS_12790030751333652900)],
        &[(0b10010, &ENTRY_MAXIMIZE_14091219846433103895)],
        &[(0b10010, &ENTRY_MAXIMIZED_6250109018079854572)],
        &[(0b10010, &ENTRY_MAXIMIZER_17946247253592585241)],
        &[(0b10010, &ENTRY_MAXIMIZERS_8260289730206734033)],
        &[(0b10010, &ENTRY_MAXIMIZES_3401038828375121966)],
        &[(0b10010, &ENTRY_MAXIMIZING_14134060054459323774)],
        &[(0b01001, &ENTRY_MAXIMIZATION_17686901393811165015)],
        &[(0b01001, &ENTRY_MAXIMIZATIONS_12790030751333652900)],
        &[(0b01001, &ENTRY_MAXIMIZE_14091219846433103895)],
        &[(0b01001, &ENTRY_MAXIMIZED_6250109018079854572)],
        &[(0b01001, &ENTRY_MAXIMIZER_17946247253592585241)],
        &[(0b01001, &ENTRY_MAXIMIZERS_8260289730206734033)],
        &[(0b01001, &ENTRY_MAXIMIZES_3401038828375121966)],
        &[(0b01001, &ENTRY_MAXIMIZING_14134060054459323774)],
    ],
    range: 5..=10,
};

static VARS_MAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAU_CHILDREN),
    value: None,
};

pub static VARS_MAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dlinise"),
        dictgen::InsensitiveStr::Ascii("dlinises"),
        dictgen::InsensitiveStr::Ascii("dlinize"),
        dictgen::InsensitiveStr::Ascii("dlinizes"),
        dictgen::InsensitiveStr::Ascii("ger"),
        dictgen::InsensitiveStr::Ascii("gre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAUDLINIZE_10546890191792171390)],
        &[(0b10010, &ENTRY_MAUDLINIZES_6015159066732084897)],
        &[(0b01001, &ENTRY_MAUDLINIZE_10546890191792171390)],
        &[(0b01001, &ENTRY_MAUDLINIZES_6015159066732084897)],
        &[(0b00001, &ENTRY_MAUGER_2687308112141368893)],
        &[(0b11010, &ENTRY_MAUGER_2687308112141368893)],
    ],
    range: 3..=8,
};

static VARS_MAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAT_CHILDREN),
    value: None,
};

pub static VARS_MAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erialisation"),
        dictgen::InsensitiveStr::Ascii("erialisations"),
        dictgen::InsensitiveStr::Ascii("erialise"),
        dictgen::InsensitiveStr::Ascii("erialised"),
        dictgen::InsensitiveStr::Ascii("erialiser"),
        dictgen::InsensitiveStr::Ascii("erialisers"),
        dictgen::InsensitiveStr::Ascii("erialises"),
        dictgen::InsensitiveStr::Ascii("erialising"),
        dictgen::InsensitiveStr::Ascii("erialization"),
        dictgen::InsensitiveStr::Ascii("erializations"),
        dictgen::InsensitiveStr::Ascii("erialize"),
        dictgen::InsensitiveStr::Ascii("erialized"),
        dictgen::InsensitiveStr::Ascii("erializer"),
        dictgen::InsensitiveStr::Ascii("erializers"),
        dictgen::InsensitiveStr::Ascii("erializes"),
        dictgen::InsensitiveStr::Ascii("erializing"),
        dictgen::InsensitiveStr::Ascii("ernalise"),
        dictgen::InsensitiveStr::Ascii("ernalised"),
        dictgen::InsensitiveStr::Ascii("ernalises"),
        dictgen::InsensitiveStr::Ascii("ernalising"),
        dictgen::InsensitiveStr::Ascii("ernalize"),
        dictgen::InsensitiveStr::Ascii("ernalized"),
        dictgen::InsensitiveStr::Ascii("ernalizes"),
        dictgen::InsensitiveStr::Ascii("ernalizing"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("h"),
        dictgen::InsensitiveStr::Ascii("hematicise"),
        dictgen::InsensitiveStr::Ascii("hematicised"),
        dictgen::InsensitiveStr::Ascii("hematicises"),
        dictgen::InsensitiveStr::Ascii("hematicising"),
        dictgen::InsensitiveStr::Ascii("hematicize"),
        dictgen::InsensitiveStr::Ascii("hematicized"),
        dictgen::InsensitiveStr::Ascii("hematicizes"),
        dictgen::InsensitiveStr::Ascii("hematicizing"),
        dictgen::InsensitiveStr::Ascii("hematisation"),
        dictgen::InsensitiveStr::Ascii("hematisations"),
        dictgen::InsensitiveStr::Ascii("hematise"),
        dictgen::InsensitiveStr::Ascii("hematised"),
        dictgen::InsensitiveStr::Ascii("hematises"),
        dictgen::InsensitiveStr::Ascii("hematising"),
        dictgen::InsensitiveStr::Ascii("hematization"),
        dictgen::InsensitiveStr::Ascii("hematizations"),
        dictgen::InsensitiveStr::Ascii("hematize"),
        dictgen::InsensitiveStr::Ascii("hematized"),
        dictgen::InsensitiveStr::Ascii("hematizes"),
        dictgen::InsensitiveStr::Ascii("hematizing"),
        dictgen::InsensitiveStr::Ascii("hs"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("ronise"),
        dictgen::InsensitiveStr::Ascii("ronised"),
        dictgen::InsensitiveStr::Ascii("ronises"),
        dictgen::InsensitiveStr::Ascii("ronising"),
        dictgen::InsensitiveStr::Ascii("ronize"),
        dictgen::InsensitiveStr::Ascii("ronized"),
        dictgen::InsensitiveStr::Ascii("ronizes"),
        dictgen::InsensitiveStr::Ascii("ronizing"),
        dictgen::InsensitiveStr::Ascii("thaean"),
        dictgen::InsensitiveStr::Ascii("thean"),
        dictgen::InsensitiveStr::Ascii("ts"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MATERIALIZATION_5296659211080369904)],
        &[(0b10010, &ENTRY_MATERIALIZATIONS_17630215875011801689)],
        &[(0b10010, &ENTRY_MATERIALIZE_9377213878887487379)],
        &[(0b10010, &ENTRY_MATERIALIZED_4701762194516141918)],
        &[(0b10010, &ENTRY_MATERIALIZER_13633659159147435019)],
        &[(0b10010, &ENTRY_MATERIALIZERS_6264608460867840474)],
        &[(0b10010, &ENTRY_MATERIALIZES_2541163433716035330)],
        &[(0b10010, &ENTRY_MATERIALIZING_3756046117234473798)],
        &[(0b01001, &ENTRY_MATERIALIZATION_5296659211080369904)],
        &[(0b01001, &ENTRY_MATERIALIZATIONS_17630215875011801689)],
        &[(0b01001, &ENTRY_MATERIALIZE_9377213878887487379)],
        &[(0b01001, &ENTRY_MATERIALIZED_4701762194516141918)],
        &[(0b01001, &ENTRY_MATERIALIZER_13633659159147435019)],
        &[(0b01001, &ENTRY_MATERIALIZERS_6264608460867840474)],
        &[(0b01001, &ENTRY_MATERIALIZES_2541163433716035330)],
        &[(0b01001, &ENTRY_MATERIALIZING_3756046117234473798)],
        &[(0b10010, &ENTRY_MATERNALIZE_7041307337797140902)],
        &[(0b10010, &ENTRY_MATERNALIZED_14227156040020017965)],
        &[(0b10010, &ENTRY_MATERNALIZES_12888734571883158030)],
        &[(0b10010, &ENTRY_MATERNALIZING_9640631765141610049)],
        &[(0b01001, &ENTRY_MATERNALIZE_7041307337797140902)],
        &[(0b01001, &ENTRY_MATERNALIZED_14227156040020017965)],
        &[(0b01001, &ENTRY_MATERNALIZES_12888734571883158030)],
        &[(0b01001, &ENTRY_MATERNALIZING_9640631765141610049)],
        &[(0b00001, &ENTRY_MATERS_3979439194038338784)],
        &[(0b01001, &ENTRY_MATH_11175287041460200362)],
        &[(0b10010, &ENTRY_MATHEMATICIZE_7017138034488316601)],
        &[(0b10010, &ENTRY_MATHEMATICIZED_2954775980735308228)],
        &[(0b10010, &ENTRY_MATHEMATICIZES_17239793732172029302)],
        &[(0b10010, &ENTRY_MATHEMATICIZING_18356289396973675487)],
        &[(0b01001, &ENTRY_MATHEMATICIZE_7017138034488316601)],
        &[(0b01001, &ENTRY_MATHEMATICIZED_2954775980735308228)],
        &[(0b01001, &ENTRY_MATHEMATICIZES_17239793732172029302)],
        &[(0b01001, &ENTRY_MATHEMATICIZING_18356289396973675487)],
        &[(0b10010, &ENTRY_MATHEMATIZATION_11635475143822716979)],
        &[(0b10010, &ENTRY_MATHEMATIZATIONS_5363665293954590339)],
        &[(0b10010, &ENTRY_MATHEMATIZE_15749632280370319229)],
        &[(0b10010, &ENTRY_MATHEMATIZED_10141209090401217221)],
        &[(0b10010, &ENTRY_MATHEMATIZES_17426361020400634879)],
        &[(0b10010, &ENTRY_MATHEMATIZING_7031390654186090211)],
        &[(0b01001, &ENTRY_MATHEMATIZATION_11635475143822716979)],
        &[(0b01001, &ENTRY_MATHEMATIZATIONS_5363665293954590339)],
        &[(0b01001, &ENTRY_MATHEMATIZE_15749632280370319229)],
        &[(0b01001, &ENTRY_MATHEMATIZED_10141209090401217221)],
        &[(0b01001, &ENTRY_MATHEMATIZES_17426361020400634879)],
        &[(0b01001, &ENTRY_MATHEMATIZING_7031390654186090211)],
        &[(0b10010, &ENTRY_MATH_11175287041460200362)],
        &[(0b11010, &ENTRY_MATERS_3979439194038338784)],
        &[(0b10010, &ENTRY_MATRONIZE_16335366679027459825)],
        &[(0b10010, &ENTRY_MATRONIZED_8674819809422970452)],
        &[(0b10010, &ENTRY_MATRONIZES_15227868328935007900)],
        &[(0b10010, &ENTRY_MATRONIZING_12987677453307989351)],
        &[(0b01001, &ENTRY_MATRONIZE_16335366679027459825)],
        &[(0b01001, &ENTRY_MATRONIZED_8674819809422970452)],
        &[(0b01001, &ENTRY_MATRONIZES_15227868328935007900)],
        &[(0b01001, &ENTRY_MATRONIZING_12987677453307989351)],
        &[(0b11010, &ENTRY_MATTHEAN_2316545087345878827)],
        &[(0b00001, &ENTRY_MATTHEAN_2316545087345878827)],
        &[(0b10011, &ENTRY_MATS_9463160410734197553)],
    ],
    range: 1..=13,
};

static VARS_MAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAS_CHILDREN),
    value: None,
};

pub static VARS_MAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("culinisation"),
        dictgen::InsensitiveStr::Ascii("culinisations"),
        dictgen::InsensitiveStr::Ascii("culinise"),
        dictgen::InsensitiveStr::Ascii("culinised"),
        dictgen::InsensitiveStr::Ascii("culinises"),
        dictgen::InsensitiveStr::Ascii("culinising"),
        dictgen::InsensitiveStr::Ascii("culinization"),
        dictgen::InsensitiveStr::Ascii("culinizations"),
        dictgen::InsensitiveStr::Ascii("culinize"),
        dictgen::InsensitiveStr::Ascii("culinized"),
        dictgen::InsensitiveStr::Ascii("culinizes"),
        dictgen::InsensitiveStr::Ascii("culinizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MASCULINIZATION_7323122115632941475)],
        &[(0b10010, &ENTRY_MASCULINIZATIONS_1451484167256544517)],
        &[(0b10010, &ENTRY_MASCULINIZE_8705445680236042472)],
        &[(0b10010, &ENTRY_MASCULINIZED_4130985713898111785)],
        &[(0b10010, &ENTRY_MASCULINIZES_8331218415317018409)],
        &[(0b10010, &ENTRY_MASCULINIZING_5615550210892317542)],
        &[(0b01001, &ENTRY_MASCULINIZATION_7323122115632941475)],
        &[(0b01001, &ENTRY_MASCULINIZATIONS_1451484167256544517)],
        &[(0b01001, &ENTRY_MASCULINIZE_8705445680236042472)],
        &[(0b01001, &ENTRY_MASCULINIZED_4130985713898111785)],
        &[(0b01001, &ENTRY_MASCULINIZES_8331218415317018409)],
        &[(0b01001, &ENTRY_MASCULINIZING_5615550210892317542)],
    ],
    range: 8..=13,
};

static VARS_MAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_MAR_CHILDREN),
    value: None,
};

static VARS_MAR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_MARB_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_MARG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MARM_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_MARS_NODE),
    Some(&VARS_MART_NODE),
    None,
    Some(&VARS_MARV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_MARV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARV_CHILDREN),
    value: None,
};

pub static VARS_MARV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellous"),
        dictgen::InsensitiveStr::Ascii("ellouser"),
        dictgen::InsensitiveStr::Ascii("ellousest"),
        dictgen::InsensitiveStr::Ascii("ellouslier"),
        dictgen::InsensitiveStr::Ascii("ellousliest"),
        dictgen::InsensitiveStr::Ascii("ellously"),
        dictgen::InsensitiveStr::Ascii("ellousness"),
        dictgen::InsensitiveStr::Ascii("ellousnesses"),
        dictgen::InsensitiveStr::Ascii("elous"),
        dictgen::InsensitiveStr::Ascii("elouser"),
        dictgen::InsensitiveStr::Ascii("elousest"),
        dictgen::InsensitiveStr::Ascii("elouslier"),
        dictgen::InsensitiveStr::Ascii("elousliest"),
        dictgen::InsensitiveStr::Ascii("elously"),
        dictgen::InsensitiveStr::Ascii("elousness"),
        dictgen::InsensitiveStr::Ascii("elousnesses"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MARVELED_13640251601440341072)],
        &[(0b00001, &ENTRY_MARVELER_5290759214700539442)],
        &[(0b00001, &ENTRY_MARVELING_17712338885593648087)],
        &[(0b11010, &ENTRY_MARVELED_13640251601440341072)],
        &[(0b11010, &ENTRY_MARVELER_5290759214700539442)],
        &[(0b11010, &ENTRY_MARVELING_17712338885593648087)],
        &[(0b11010, &ENTRY_MARVELOUS_12913405657225800048)],
        &[(0b11010, &ENTRY_MARVELOUSER_9300773522759351631)],
        &[(0b11010, &ENTRY_MARVELOUSEST_4909905498549424330)],
        &[(0b11010, &ENTRY_MARVELOUSLIER_15522555805023104308)],
        &[(0b11010, &ENTRY_MARVELOUSLIEST_787848875312131772)],
        &[(0b11010, &ENTRY_MARVELOUSLY_9085447356318740108)],
        &[(0b11010, &ENTRY_MARVELOUSNESS_7406444444223070939)],
        &[(0b11010, &ENTRY_MARVELOUSNESSES_15463361151017896116)],
        &[(0b00001, &ENTRY_MARVELOUS_12913405657225800048)],
        &[(0b00001, &ENTRY_MARVELOUSER_9300773522759351631)],
        &[(0b00001, &ENTRY_MARVELOUSEST_4909905498549424330)],
        &[(0b00001, &ENTRY_MARVELOUSLIER_15522555805023104308)],
        &[(0b00001, &ENTRY_MARVELOUSLIEST_787848875312131772)],
        &[(0b00001, &ENTRY_MARVELOUSLY_9085447356318740108)],
        &[(0b00001, &ENTRY_MARVELOUSNESS_7406444444223070939)],
        &[(0b00001, &ENTRY_MARVELOUSNESSES_15463361151017896116)],
    ],
    range: 4..=12,
};

static VARS_MART_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MART_CHILDREN),
    value: None,
};

pub static VARS_MART_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ialisation"),
        dictgen::InsensitiveStr::Ascii("ialisations"),
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialization"),
        dictgen::InsensitiveStr::Ascii("ializations"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("yrisation"),
        dictgen::InsensitiveStr::Ascii("yrisations"),
        dictgen::InsensitiveStr::Ascii("yrise"),
        dictgen::InsensitiveStr::Ascii("yrised"),
        dictgen::InsensitiveStr::Ascii("yriser"),
        dictgen::InsensitiveStr::Ascii("yrisers"),
        dictgen::InsensitiveStr::Ascii("yrises"),
        dictgen::InsensitiveStr::Ascii("yrising"),
        dictgen::InsensitiveStr::Ascii("yrization"),
        dictgen::InsensitiveStr::Ascii("yrizations"),
        dictgen::InsensitiveStr::Ascii("yrize"),
        dictgen::InsensitiveStr::Ascii("yrized"),
        dictgen::InsensitiveStr::Ascii("yrizer"),
        dictgen::InsensitiveStr::Ascii("yrizers"),
        dictgen::InsensitiveStr::Ascii("yrizes"),
        dictgen::InsensitiveStr::Ascii("yrizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MARTE_115900376362314851)],
        &[(0b00001, &ENTRY_MARTE_115900376362314851)],
        &[(0b10010, &ENTRY_MARTIALIZATION_12970020243892509428)],
        &[(0b10010, &ENTRY_MARTIALIZATIONS_11697709318054313125)],
        &[(0b10010, &ENTRY_MARTIALIZE_16160203135661407439)],
        &[(0b10010, &ENTRY_MARTIALIZES_16237113673507263901)],
        &[(0b01001, &ENTRY_MARTIALIZATION_12970020243892509428)],
        &[(0b01001, &ENTRY_MARTIALIZATIONS_11697709318054313125)],
        &[(0b01001, &ENTRY_MARTIALIZE_16160203135661407439)],
        &[(0b01001, &ENTRY_MARTIALIZES_16237113673507263901)],
        &[(0b10010, &ENTRY_MARTYRIZATION_6155264151450173537)],
        &[(0b10010, &ENTRY_MARTYRIZATIONS_16966157062728825533)],
        &[(0b10010, &ENTRY_MARTYRIZE_18186520872862732817)],
        &[(0b10010, &ENTRY_MARTYRIZED_4832114212229439073)],
        &[(0b10010, &ENTRY_MARTYRIZER_8947475097586440969)],
        &[(0b10010, &ENTRY_MARTYRIZERS_8288377886330052956)],
        &[(0b10010, &ENTRY_MARTYRIZES_16597254749503837013)],
        &[(0b10010, &ENTRY_MARTYRIZING_7504180782954747537)],
        &[(0b01001, &ENTRY_MARTYRIZATION_6155264151450173537)],
        &[(0b01001, &ENTRY_MARTYRIZATIONS_16966157062728825533)],
        &[(0b01001, &ENTRY_MARTYRIZE_18186520872862732817)],
        &[(0b01001, &ENTRY_MARTYRIZED_4832114212229439073)],
        &[(0b01001, &ENTRY_MARTYRIZER_8947475097586440969)],
        &[(0b01001, &ENTRY_MARTYRIZERS_8288377886330052956)],
        &[(0b01001, &ENTRY_MARTYRIZES_16597254749503837013)],
        &[(0b01001, &ENTRY_MARTYRIZING_7504180782954747537)],
    ],
    range: 1..=11,
};

static VARS_MARS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARS_CHILDREN),
    value: None,
};

pub static VARS_MARS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("haled"),
        dictgen::InsensitiveStr::Ascii("haling"),
        dictgen::InsensitiveStr::Ascii("halled"),
        dictgen::InsensitiveStr::Ascii("halling"),
        dictgen::InsensitiveStr::Ascii("upialisation"),
        dictgen::InsensitiveStr::Ascii("upialisations"),
        dictgen::InsensitiveStr::Ascii("upialise"),
        dictgen::InsensitiveStr::Ascii("upialised"),
        dictgen::InsensitiveStr::Ascii("upialises"),
        dictgen::InsensitiveStr::Ascii("upialising"),
        dictgen::InsensitiveStr::Ascii("upialization"),
        dictgen::InsensitiveStr::Ascii("upializations"),
        dictgen::InsensitiveStr::Ascii("upialize"),
        dictgen::InsensitiveStr::Ascii("upialized"),
        dictgen::InsensitiveStr::Ascii("upializes"),
        dictgen::InsensitiveStr::Ascii("upializing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MARSHALED_14436567244270856596)],
        &[(0b00001, &ENTRY_MARSHALING_16452448580048913285)],
        &[(0b11010, &ENTRY_MARSHALED_14436567244270856596)],
        &[(0b11010, &ENTRY_MARSHALING_16452448580048913285)],
        &[(0b10010, &ENTRY_MARSUPIALIZATION_8918810560002724439)],
        &[(0b10010, &ENTRY_MARSUPIALIZATIONS_131817236626667525)],
        &[(0b10010, &ENTRY_MARSUPIALIZE_1726851296480687486)],
        &[(0b10010, &ENTRY_MARSUPIALIZED_7333631687362051594)],
        &[(0b10010, &ENTRY_MARSUPIALIZES_14629605414761888268)],
        &[(0b10010, &ENTRY_MARSUPIALIZING_11802531571659940556)],
        &[(0b01001, &ENTRY_MARSUPIALIZATION_8918810560002724439)],
        &[(0b01001, &ENTRY_MARSUPIALIZATIONS_131817236626667525)],
        &[(0b01001, &ENTRY_MARSUPIALIZE_1726851296480687486)],
        &[(0b01001, &ENTRY_MARSUPIALIZED_7333631687362051594)],
        &[(0b01001, &ENTRY_MARSUPIALIZES_14629605414761888268)],
        &[(0b01001, &ENTRY_MARSUPIALIZING_11802531571659940556)],
    ],
    range: 5..=13,
};

static VARS_MARM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARM_CHILDREN),
    value: None,
};

pub static VARS_MARM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MARMARIZE_13936404510552809323)],
        &[(0b10010, &ENTRY_MARMARIZED_4375398795551807227)],
        &[(0b10010, &ENTRY_MARMARIZES_15375966147001754735)],
        &[(0b10010, &ENTRY_MARMARIZING_3793569524149852443)],
        &[(0b01001, &ENTRY_MARMARIZE_13936404510552809323)],
        &[(0b01001, &ENTRY_MARMARIZED_4375398795551807227)],
        &[(0b01001, &ENTRY_MARMARIZES_15375966147001754735)],
        &[(0b01001, &ENTRY_MARMARIZING_3793569524149852443)],
        &[(0b10010, &ENTRY_MARMELIZE_16707250168612411670)],
        &[(0b10010, &ENTRY_MARMELIZED_12473285779423633628)],
        &[(0b10010, &ENTRY_MARMELIZES_8910323184633820900)],
        &[(0b10010, &ENTRY_MARMELIZING_5395951919003314838)],
        &[(0b01001, &ENTRY_MARMELIZE_16707250168612411670)],
        &[(0b01001, &ENTRY_MARMELIZED_12473285779423633628)],
        &[(0b01001, &ENTRY_MARMELIZES_8910323184633820900)],
        &[(0b01001, &ENTRY_MARMELIZING_5395951919003314838)],
    ],
    range: 5..=7,
};

static VARS_MARG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARG_CHILDREN),
    value: None,
};

pub static VARS_MARG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aritae"),
        dictgen::InsensitiveStr::Ascii("arite"),
        dictgen::InsensitiveStr::Ascii("inalisation"),
        dictgen::InsensitiveStr::Ascii("inalise"),
        dictgen::InsensitiveStr::Ascii("inalised"),
        dictgen::InsensitiveStr::Ascii("inalises"),
        dictgen::InsensitiveStr::Ascii("inalising"),
        dictgen::InsensitiveStr::Ascii("inalization"),
        dictgen::InsensitiveStr::Ascii("inalize"),
        dictgen::InsensitiveStr::Ascii("inalized"),
        dictgen::InsensitiveStr::Ascii("inalizes"),
        dictgen::InsensitiveStr::Ascii("inalizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MARGARITE_1356877265318483793)],
        &[(0b00001, &ENTRY_MARGARITE_1356877265318483793)],
        &[(0b10010, &ENTRY_MARGINALIZATION_1233702880571492640)],
        &[(0b10010, &ENTRY_MARGINALIZE_5790484722094120614)],
        &[(0b10010, &ENTRY_MARGINALIZED_2250429301168529865)],
        &[(0b10010, &ENTRY_MARGINALIZES_18154888411839614068)],
        &[(0b10010, &ENTRY_MARGINALIZING_7021233111114059911)],
        &[(0b01001, &ENTRY_MARGINALIZATION_1233702880571492640)],
        &[(0b01001, &ENTRY_MARGINALIZE_5790484722094120614)],
        &[(0b01001, &ENTRY_MARGINALIZED_2250429301168529865)],
        &[(0b01001, &ENTRY_MARGINALIZES_18154888411839614068)],
        &[(0b01001, &ENTRY_MARGINALIZING_7021233111114059911)],
    ],
    range: 5..=11,
};

static VARS_MARB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MARB_CHILDREN),
    value: None,
};

pub static VARS_MARB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("leise"),
        dictgen::InsensitiveStr::Ascii("leised"),
        dictgen::InsensitiveStr::Ascii("leises"),
        dictgen::InsensitiveStr::Ascii("leising"),
        dictgen::InsensitiveStr::Ascii("leize"),
        dictgen::InsensitiveStr::Ascii("leized"),
        dictgen::InsensitiveStr::Ascii("leizes"),
        dictgen::InsensitiveStr::Ascii("leizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MARBLEIZE_10560158210625088553)],
        &[(0b10010, &ENTRY_MARBLEIZED_4437604505512174882)],
        &[(0b10010, &ENTRY_MARBLEIZES_4834327648631783601)],
        &[(0b10010, &ENTRY_MARBLEIZING_12106644630219217184)],
        &[(0b01001, &ENTRY_MARBLEIZE_10560158210625088553)],
        &[(0b01001, &ENTRY_MARBLEIZED_4437604505512174882)],
        &[(0b01001, &ENTRY_MARBLEIZES_4834327648631783601)],
        &[(0b01001, &ENTRY_MARBLEIZING_12106644630219217184)],
    ],
    range: 5..=7,
};

static VARS_MAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAN_CHILDREN),
    value: None,
};

pub static VARS_MAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daean"),
        dictgen::InsensitiveStr::Ascii("daeans"),
        dictgen::InsensitiveStr::Ascii("darinise"),
        dictgen::InsensitiveStr::Ascii("darinises"),
        dictgen::InsensitiveStr::Ascii("darinize"),
        dictgen::InsensitiveStr::Ascii("darinizes"),
        dictgen::InsensitiveStr::Ascii("dean"),
        dictgen::InsensitiveStr::Ascii("deans"),
        dictgen::InsensitiveStr::Ascii("doer"),
        dictgen::InsensitiveStr::Ascii("dore"),
        dictgen::InsensitiveStr::Ascii("euver"),
        dictgen::InsensitiveStr::Ascii("euverabilities"),
        dictgen::InsensitiveStr::Ascii("euverability"),
        dictgen::InsensitiveStr::Ascii("euverable"),
        dictgen::InsensitiveStr::Ascii("euverabler"),
        dictgen::InsensitiveStr::Ascii("euverablest"),
        dictgen::InsensitiveStr::Ascii("euvered"),
        dictgen::InsensitiveStr::Ascii("euverer"),
        dictgen::InsensitiveStr::Ascii("euverers"),
        dictgen::InsensitiveStr::Ascii("euvering"),
        dictgen::InsensitiveStr::Ascii("euverings"),
        dictgen::InsensitiveStr::Ascii("euvers"),
        dictgen::InsensitiveStr::Ascii("hattanise"),
        dictgen::InsensitiveStr::Ascii("hattanises"),
        dictgen::InsensitiveStr::Ascii("hattanize"),
        dictgen::InsensitiveStr::Ascii("hattanizes"),
        dictgen::InsensitiveStr::Ascii("ichaeanism"),
        dictgen::InsensitiveStr::Ascii("ichaeans"),
        dictgen::InsensitiveStr::Ascii("ichaeism"),
        dictgen::InsensitiveStr::Ascii("ichaeisms"),
        dictgen::InsensitiveStr::Ascii("ichaeus"),
        dictgen::InsensitiveStr::Ascii("icheanism"),
        dictgen::InsensitiveStr::Ascii("icheans"),
        dictgen::InsensitiveStr::Ascii("icheus"),
        dictgen::InsensitiveStr::Ascii("nerise"),
        dictgen::InsensitiveStr::Ascii("nerises"),
        dictgen::InsensitiveStr::Ascii("nerize"),
        dictgen::InsensitiveStr::Ascii("nerizes"),
        dictgen::InsensitiveStr::Ascii("oeuver"),
        dictgen::InsensitiveStr::Ascii("oeuvered"),
        dictgen::InsensitiveStr::Ascii("oeuvering"),
        dictgen::InsensitiveStr::Ascii("oeuverings"),
        dictgen::InsensitiveStr::Ascii("oeuvers"),
        dictgen::InsensitiveStr::Ascii("oeuvrabilities"),
        dictgen::InsensitiveStr::Ascii("oeuvrability"),
        dictgen::InsensitiveStr::Ascii("oeuvrable"),
        dictgen::InsensitiveStr::Ascii("oeuvrabler"),
        dictgen::InsensitiveStr::Ascii("oeuvrablest"),
        dictgen::InsensitiveStr::Ascii("oeuvre"),
        dictgen::InsensitiveStr::Ascii("oeuvred"),
        dictgen::InsensitiveStr::Ascii("oeuvrer"),
        dictgen::InsensitiveStr::Ascii("oeuvrers"),
        dictgen::InsensitiveStr::Ascii("oeuvres"),
        dictgen::InsensitiveStr::Ascii("oeuvring"),
        dictgen::InsensitiveStr::Ascii("oeuvrings"),
        dictgen::InsensitiveStr::Ascii("tes"),
        dictgen::InsensitiveStr::Ascii("toes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MANDEAN_2244043166169147585)],
        &[(0b11010, &ENTRY_MANDEANS_7824922763371535662)],
        &[(0b10010, &ENTRY_MANDARINIZE_5395269118667728168)],
        &[(0b10010, &ENTRY_MANDARINIZES_3405712212187872515)],
        &[(0b01001, &ENTRY_MANDARINIZE_5395269118667728168)],
        &[(0b01001, &ENTRY_MANDARINIZES_3405712212187872515)],
        &[(0b10011, &ENTRY_MANDEAN_2244043166169147585)],
        &[(0b10011, &ENTRY_MANDEANS_7824922763371535662)],
        &[(0b00001, &ENTRY_MANDOER_1848218089972389391)],
        &[(0b11010, &ENTRY_MANDOER_1848218089972389391)],
        &[(0b01001, &ENTRY_MANEUVER_5387054599640837575)],
        &[(0b00001, &ENTRY_MANEUVERABILITIES_4377566838265267604)],
        &[(0b00001, &ENTRY_MANEUVERABILITY_9991738727964618746)],
        &[(0b00001, &ENTRY_MANEUVERABLE_9241543220534916637)],
        &[(0b00001, &ENTRY_MANEUVERABLER_16242571769731852453)],
        &[(0b00001, &ENTRY_MANEUVERABLEST_12615804687818900918)],
        &[(0b01001, &ENTRY_MANEUVERED_12933808223126942130)],
        &[(0b00001, &ENTRY_MANEUVERER_11024318686818982966)],
        &[(0b00001, &ENTRY_MANEUVERERS_15934664270324741768)],
        &[(0b01001, &ENTRY_MANEUVERING_11412530305974280098)],
        &[(0b01001, &ENTRY_MANEUVERINGS_16913311735858326454)],
        &[(0b01001, &ENTRY_MANEUVERS_610807745803336129)],
        &[(0b10010, &ENTRY_MANHATTANIZE_6316984002770135780)],
        &[(0b10010, &ENTRY_MANHATTANIZES_11664594499184406647)],
        &[(0b01001, &ENTRY_MANHATTANIZE_6316984002770135780)],
        &[(0b01001, &ENTRY_MANHATTANIZES_11664594499184406647)],
        &[(0b11010, &ENTRY_MANICHEANISM_5295642406319230193)],
        &[(0b11010, &ENTRY_MANICHEANS_7059235818280734780)],
        &[(0b11010, &ENTRY_MANICHEISM_492395297356386441)],
        &[(0b11010, &ENTRY_MANICHEISMS_6305433274391716123)],
        &[(0b11010, &ENTRY_MANICHEUS_2161632630177466302)],
        &[(0b00001, &ENTRY_MANICHEANISM_5295642406319230193)],
        &[(0b00001, &ENTRY_MANICHEANS_7059235818280734780)],
        &[(0b00001, &ENTRY_MANICHEUS_2161632630177466302)],
        &[(0b10010, &ENTRY_MANNERIZE_17494010187806672576)],
        &[(0b10010, &ENTRY_MANNERIZES_11335051494000116458)],
        &[(0b01001, &ENTRY_MANNERIZE_17494010187806672576)],
        &[(0b01001, &ENTRY_MANNERIZES_11335051494000116458)],
        &[(0b01000, &ENTRY_MANEUVER_5387054599640837575)],
        &[(0b01000, &ENTRY_MANEUVERED_12933808223126942130)],
        &[(0b01000, &ENTRY_MANEUVERING_11412530305974280098)],
        &[(0b01000, &ENTRY_MANEUVERINGS_16913311735858326454)],
        &[(0b01000, &ENTRY_MANEUVERS_610807745803336129)],
        &[(0b11010, &ENTRY_MANEUVERABILITIES_4377566838265267604)],
        &[(0b11010, &ENTRY_MANEUVERABILITY_9991738727964618746)],
        &[(0b11010, &ENTRY_MANEUVERABLE_9241543220534916637)],
        &[(0b11010, &ENTRY_MANEUVERABLER_16242571769731852453)],
        &[(0b11010, &ENTRY_MANEUVERABLEST_12615804687818900918)],
        &[(0b11010, &ENTRY_MANEUVER_5387054599640837575)],
        &[(0b11010, &ENTRY_MANEUVERED_12933808223126942130)],
        &[(0b11010, &ENTRY_MANEUVERER_11024318686818982966)],
        &[(0b11010, &ENTRY_MANEUVERERS_15934664270324741768)],
        &[(0b11010, &ENTRY_MANEUVERS_610807745803336129)],
        &[(0b11010, &ENTRY_MANEUVERING_11412530305974280098)],
        &[(0b11010, &ENTRY_MANEUVERINGS_16913311735858326454)],
        &[(0b00001, &ENTRY_MANTES_9814453001954994214)],
        &[(0b11010, &ENTRY_MANTES_9814453001954994214)],
    ],
    range: 3..=14,
};

static VARS_MAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAL_CHILDREN),
    value: None,
};

pub static VARS_MAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ayise"),
        dictgen::InsensitiveStr::Ascii("ayises"),
        dictgen::InsensitiveStr::Ascii("ayize"),
        dictgen::InsensitiveStr::Ascii("ayizes"),
        dictgen::InsensitiveStr::Ascii("leablise"),
        dictgen::InsensitiveStr::Ascii("leablises"),
        dictgen::InsensitiveStr::Ascii("leablize"),
        dictgen::InsensitiveStr::Ascii("leablizes"),
        dictgen::InsensitiveStr::Ascii("odor"),
        dictgen::InsensitiveStr::Ascii("odorousness"),
        dictgen::InsensitiveStr::Ascii("odors"),
        dictgen::InsensitiveStr::Ascii("odour"),
        dictgen::InsensitiveStr::Ascii("odourousness"),
        dictgen::InsensitiveStr::Ascii("odours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MALAYIZE_9503037103570804575)],
        &[(0b10010, &ENTRY_MALAYIZES_7101219180314967639)],
        &[(0b01001, &ENTRY_MALAYIZE_9503037103570804575)],
        &[(0b01001, &ENTRY_MALAYIZES_7101219180314967639)],
        &[(0b10010, &ENTRY_MALLEABLIZE_13860404453532312118)],
        &[(0b10010, &ENTRY_MALLEABLIZES_2447853325264765807)],
        &[(0b01001, &ENTRY_MALLEABLIZE_13860404453532312118)],
        &[(0b01001, &ENTRY_MALLEABLIZES_2447853325264765807)],
        &[(0b10001, &ENTRY_MALODOR_1230117012999961238)],
        &[(0b00001, &ENTRY_MALODOROUSNESS_6015133417028203806)],
        &[(0b10001, &ENTRY_MALODORS_9161213875879462130)],
        &[(0b11010, &ENTRY_MALODOR_1230117012999961238)],
        &[(0b11010, &ENTRY_MALODOROUSNESS_6015133417028203806)],
        &[(0b11010, &ENTRY_MALODORS_9161213875879462130)],
    ],
    range: 4..=12,
};

static VARS_MAJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAJ_CHILDREN),
    value: None,
};

pub static VARS_MAJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("usculae"),
        dictgen::InsensitiveStr::Ascii("uscule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAJORIZE_18190803152042070767)],
        &[(0b10010, &ENTRY_MAJORIZES_12441874624584501250)],
        &[(0b01001, &ENTRY_MAJORIZE_18190803152042070767)],
        &[(0b01001, &ENTRY_MAJORIZES_12441874624584501250)],
        &[(0b11010, &ENTRY_MAJUSCULE_4389141979884550889)],
        &[(0b00001, &ENTRY_MAJUSCULE_4389141979884550889)],
    ],
    range: 5..=7,
};

static VARS_MAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAI_CHILDREN),
    value: None,
};

pub static VARS_MAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ger"),
        dictgen::InsensitiveStr::Ascii("gre"),
        dictgen::InsensitiveStr::Ascii("nor"),
        dictgen::InsensitiveStr::Ascii("nors"),
        dictgen::InsensitiveStr::Ascii("nour"),
        dictgen::InsensitiveStr::Ascii("nours"),
        dictgen::InsensitiveStr::Ascii("nprise"),
        dictgen::InsensitiveStr::Ascii("nprize"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sters"),
        dictgen::InsensitiveStr::Ascii("stres"),
        dictgen::InsensitiveStr::Ascii("ze"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MAIGER_14271708748030342793)],
        &[(0b11010, &ENTRY_MAIGER_14271708748030342793)],
        &[(0b00001, &ENTRY_MAINOR_15155182871533443001)],
        &[(0b00001, &ENTRY_MAINORS_1096950270219286282)],
        &[(0b11010, &ENTRY_MAINOR_15155182871533443001)],
        &[(0b11010, &ENTRY_MAINORS_1096950270219286282)],
        &[(0b10010, &ENTRY_MAINPRIZE_12476293352842703157)],
        &[(0b01001, &ENTRY_MAINPRIZE_12476293352842703157)],
        &[(0b10010, &ENTRY_MAIZE_1869902360661909236)],
        &[(0b00001, &ENTRY_MAISTERS_169323063843277028)],
        &[(0b11010, &ENTRY_MAISTERS_169323063843277028)],
        &[(0b01001, &ENTRY_MAIZE_1869902360661909236)],
    ],
    range: 2..=6,
};

static VARS_MAH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAH_CHILDREN),
    value: None,
};

pub static VARS_MAH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oganise"),
        dictgen::InsensitiveStr::Ascii("oganised"),
        dictgen::InsensitiveStr::Ascii("oganises"),
        dictgen::InsensitiveStr::Ascii("oganising"),
        dictgen::InsensitiveStr::Ascii("oganize"),
        dictgen::InsensitiveStr::Ascii("oganized"),
        dictgen::InsensitiveStr::Ascii("oganizes"),
        dictgen::InsensitiveStr::Ascii("oganizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAHOGANIZE_6685229242417344012)],
        &[(0b10010, &ENTRY_MAHOGANIZED_2137275005041857408)],
        &[(0b10010, &ENTRY_MAHOGANIZES_2959701861687031680)],
        &[(0b10010, &ENTRY_MAHOGANIZING_16063905374207361931)],
        &[(0b01001, &ENTRY_MAHOGANIZE_6685229242417344012)],
        &[(0b01001, &ENTRY_MAHOGANIZED_2137275005041857408)],
        &[(0b01001, &ENTRY_MAHOGANIZES_2959701861687031680)],
        &[(0b01001, &ENTRY_MAHOGANIZING_16063905374207361931)],
    ],
    range: 7..=9,
};

static VARS_MAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAG_CHILDREN),
    value: None,
};

pub static VARS_MAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
        dictgen::InsensitiveStr::Ascii("netisabilities"),
        dictgen::InsensitiveStr::Ascii("netisability"),
        dictgen::InsensitiveStr::Ascii("netisable"),
        dictgen::InsensitiveStr::Ascii("netisables"),
        dictgen::InsensitiveStr::Ascii("netisation"),
        dictgen::InsensitiveStr::Ascii("netisations"),
        dictgen::InsensitiveStr::Ascii("netise"),
        dictgen::InsensitiveStr::Ascii("netised"),
        dictgen::InsensitiveStr::Ascii("netiser"),
        dictgen::InsensitiveStr::Ascii("netisers"),
        dictgen::InsensitiveStr::Ascii("netises"),
        dictgen::InsensitiveStr::Ascii("netising"),
        dictgen::InsensitiveStr::Ascii("netizabilities"),
        dictgen::InsensitiveStr::Ascii("netizability"),
        dictgen::InsensitiveStr::Ascii("netizable"),
        dictgen::InsensitiveStr::Ascii("netizables"),
        dictgen::InsensitiveStr::Ascii("netization"),
        dictgen::InsensitiveStr::Ascii("netizations"),
        dictgen::InsensitiveStr::Ascii("netize"),
        dictgen::InsensitiveStr::Ascii("netized"),
        dictgen::InsensitiveStr::Ascii("netizer"),
        dictgen::InsensitiveStr::Ascii("netizers"),
        dictgen::InsensitiveStr::Ascii("netizes"),
        dictgen::InsensitiveStr::Ascii("netizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MAGICALIZE_259845292582546245)],
        &[(0b10010, &ENTRY_MAGICALIZES_230667262651274489)],
        &[(0b01001, &ENTRY_MAGICALIZE_259845292582546245)],
        &[(0b01001, &ENTRY_MAGICALIZES_230667262651274489)],
        &[(0b10010, &ENTRY_MAGNETIZABILITIES_11043943833988980388)],
        &[(0b10010, &ENTRY_MAGNETIZABILITY_15941565557987915165)],
        &[(0b10010, &ENTRY_MAGNETIZABLE_12538903182469509996)],
        &[(0b10010, &ENTRY_MAGNETIZABLES_10982571350353432456)],
        &[(0b10010, &ENTRY_MAGNETIZATION_13418480630541927468)],
        &[(0b10010, &ENTRY_MAGNETIZATIONS_15259881805845075102)],
        &[(0b10010, &ENTRY_MAGNETIZE_6964246850033574939)],
        &[(0b10010, &ENTRY_MAGNETIZED_329380509853608515)],
        &[(0b10010, &ENTRY_MAGNETIZER_10398668050557629386)],
        &[(0b10010, &ENTRY_MAGNETIZERS_6402248007368372769)],
        &[(0b10010, &ENTRY_MAGNETIZES_9519335950988318077)],
        &[(0b10010, &ENTRY_MAGNETIZING_10233564042553328529)],
        &[(0b01001, &ENTRY_MAGNETIZABILITIES_11043943833988980388)],
        &[(0b01001, &ENTRY_MAGNETIZABILITY_15941565557987915165)],
        &[(0b01001, &ENTRY_MAGNETIZABLE_12538903182469509996)],
        &[(0b01001, &ENTRY_MAGNETIZABLES_10982571350353432456)],
        &[(0b01001, &ENTRY_MAGNETIZATION_13418480630541927468)],
        &[(0b01001, &ENTRY_MAGNETIZATIONS_15259881805845075102)],
        &[(0b01001, &ENTRY_MAGNETIZE_6964246850033574939)],
        &[(0b01001, &ENTRY_MAGNETIZED_329380509853608515)],
        &[(0b01001, &ENTRY_MAGNETIZER_10398668050557629386)],
        &[(0b01001, &ENTRY_MAGNETIZERS_6402248007368372769)],
        &[(0b01001, &ENTRY_MAGNETIZES_9519335950988318077)],
        &[(0b01001, &ENTRY_MAGNETIZING_10233564042553328529)],
    ],
    range: 6..=14,
};

static VARS_MAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAE_CHILDREN),
    value: None,
};

pub static VARS_MAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("andrine"),
        dictgen::InsensitiveStr::Ascii("andriniform"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("gbote"),
        dictgen::InsensitiveStr::Ascii("ra"),
    ],
    values: &[
        &[(0b11010, &ENTRY_MEANDRINE_15281745123487615934)],
        &[(0b11010, &ENTRY_MEANDRINIFORM_8185091047283393921)],
        &[(0b00001, &ENTRY_MAED_5682712830527035893)],
        &[(0b11010, &ENTRY_MEGBOTE_6305017947026218797)],
        &[(0b11010, &ENTRY_MERA_2238379545822097898)],
    ],
    range: 1..=11,
};

static VARS_MAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAD_CHILDREN),
    value: None,
};

pub static VARS_MAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("era"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("oera"),
    ],
    values: &[
        &[(0b00001, &ENTRY_MADERA_18034612090128136721)],
        &[(0b10010, &ENTRY_MADERIZATION_8101025765502996105)],
        &[(0b10010, &ENTRY_MADERIZATIONS_7073401233591816042)],
        &[(0b10010, &ENTRY_MADERIZE_2394704387037160176)],
        &[(0b10010, &ENTRY_MADERIZED_7886331459527867042)],
        &[(0b10010, &ENTRY_MADERIZES_15055886479846917253)],
        &[(0b10010, &ENTRY_MADERIZING_15157153976270314707)],
        &[(0b01001, &ENTRY_MADERIZATION_8101025765502996105)],
        &[(0b01001, &ENTRY_MADERIZATIONS_7073401233591816042)],
        &[(0b01001, &ENTRY_MADERIZE_2394704387037160176)],
        &[(0b01001, &ENTRY_MADERIZED_7886331459527867042)],
        &[(0b01001, &ENTRY_MADERIZES_15055886479846917253)],
        &[(0b01001, &ENTRY_MADERIZING_15157153976270314707)],
        &[(0b11010, &ENTRY_MADERA_18034612090128136721)],
    ],
    range: 3..=10,
};

static VARS_MAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAC_CHILDREN),
    value: None,
};

pub static VARS_MAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adamisation"),
        dictgen::InsensitiveStr::Ascii("adamisations"),
        dictgen::InsensitiveStr::Ascii("adamise"),
        dictgen::InsensitiveStr::Ascii("adamised"),
        dictgen::InsensitiveStr::Ascii("adamises"),
        dictgen::InsensitiveStr::Ascii("adamising"),
        dictgen::InsensitiveStr::Ascii("adamization"),
        dictgen::InsensitiveStr::Ascii("adamizations"),
        dictgen::InsensitiveStr::Ascii("adamize"),
        dictgen::InsensitiveStr::Ascii("adamized"),
        dictgen::InsensitiveStr::Ascii("adamizes"),
        dictgen::InsensitiveStr::Ascii("adamizing"),
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("cabaean"),
        dictgen::InsensitiveStr::Ascii("cabean"),
        dictgen::InsensitiveStr::Ascii("hinisation"),
        dictgen::InsensitiveStr::Ascii("hinisations"),
        dictgen::InsensitiveStr::Ascii("hinise"),
        dictgen::InsensitiveStr::Ascii("hinises"),
        dictgen::InsensitiveStr::Ascii("hinization"),
        dictgen::InsensitiveStr::Ascii("hinizations"),
        dictgen::InsensitiveStr::Ascii("hinize"),
        dictgen::InsensitiveStr::Ascii("hinizes"),
        dictgen::InsensitiveStr::Ascii("rander"),
        dictgen::InsensitiveStr::Ascii("randre"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_MACADAMIZATION_10150094710685608161)],
        &[(0b10010, &ENTRY_MACADAMIZATIONS_13499950338218392948)],
        &[(0b10010, &ENTRY_MACADAMIZE_12591043180762607828)],
        &[(0b10010, &ENTRY_MACADAMIZED_7938719006509938754)],
        &[(0b10010, &ENTRY_MACADAMIZES_17270116944727731447)],
        &[(0b10010, &ENTRY_MACADAMIZING_13448491539296168208)],
        &[(0b01001, &ENTRY_MACADAMIZATION_10150094710685608161)],
        &[(0b01001, &ENTRY_MACADAMIZATIONS_13499950338218392948)],
        &[(0b01001, &ENTRY_MACADAMIZE_12591043180762607828)],
        &[(0b01001, &ENTRY_MACADAMIZED_7938719006509938754)],
        &[(0b01001, &ENTRY_MACADAMIZES_17270116944727731447)],
        &[(0b01001, &ENTRY_MACADAMIZING_13448491539296168208)],
        &[(0b10010, &ENTRY_MACARIZE_16257918071730252529)],
        &[(0b10010, &ENTRY_MACARIZED_3181598146994569773)],
        &[(0b10010, &ENTRY_MACARIZES_7493607414497918990)],
        &[(0b10010, &ENTRY_MACARIZING_14614397680315741675)],
        &[(0b01001, &ENTRY_MACARIZE_16257918071730252529)],
        &[(0b01001, &ENTRY_MACARIZED_3181598146994569773)],
        &[(0b01001, &ENTRY_MACARIZES_7493607414497918990)],
        &[(0b01001, &ENTRY_MACARIZING_14614397680315741675)],
        &[(0b11010, &ENTRY_MACCABEAN_958654750140968533)],
        &[(0b00001, &ENTRY_MACCABEAN_958654750140968533)],
        &[(0b10010, &ENTRY_MACHINIZATION_4606202379585370055)],
        &[(0b10010, &ENTRY_MACHINIZATIONS_1078950776046576014)],
        &[(0b10010, &ENTRY_MACHINIZE_7203320845244735452)],
        &[(0b10010, &ENTRY_MACHINIZES_17958467964158304583)],
        &[(0b01001, &ENTRY_MACHINIZATION_4606202379585370055)],
        &[(0b01001, &ENTRY_MACHINIZATIONS_1078950776046576014)],
        &[(0b01001, &ENTRY_MACHINIZE_7203320845244735452)],
        &[(0b01001, &ENTRY_MACHINIZES_17958467964158304583)],
        &[(0b00001, &ENTRY_MACRANDER_9929126881067356727)],
        &[(0b11010, &ENTRY_MACRANDER_9929126881067356727)],
        &[(0b11010, &ENTRY_MACULE_3407035185388617437)],
        &[(0b00001, &ENTRY_MACULE_3407035185388617437)],
    ],
    range: 3..=12,
};

static VARS_MAA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_MAA_CHILDREN),
    value: None,
};

pub static VARS_MAA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ed")],
    values: &[&[(0b11010, &ENTRY_MAED_5682712830527035893)]],
    range: 2..=2,
};

static VARS_L_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_L_CHILDREN),
    value: None,
};

static VARS_L_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_LA_NODE),
    None,
    None,
    None,
    Some(&VARS_LE_NODE),
    None,
    None,
    None,
    Some(&VARS_LI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LU_NODE),
    None,
    None,
    None,
    Some(&VARS_LY_NODE),
    None,
];

static VARS_LY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LY_CHILDREN),
    value: None,
};

pub static VARS_LY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphaemia"),
        dictgen::InsensitiveStr::Ascii("mphedema"),
        dictgen::InsensitiveStr::Ascii("mphemia"),
        dictgen::InsensitiveStr::Ascii("mphoedema"),
        dictgen::InsensitiveStr::Ascii("ophilisation"),
        dictgen::InsensitiveStr::Ascii("ophilisations"),
        dictgen::InsensitiveStr::Ascii("ophilise"),
        dictgen::InsensitiveStr::Ascii("ophilised"),
        dictgen::InsensitiveStr::Ascii("ophiliser"),
        dictgen::InsensitiveStr::Ascii("ophilises"),
        dictgen::InsensitiveStr::Ascii("ophilising"),
        dictgen::InsensitiveStr::Ascii("ophilization"),
        dictgen::InsensitiveStr::Ascii("ophilizations"),
        dictgen::InsensitiveStr::Ascii("ophilize"),
        dictgen::InsensitiveStr::Ascii("ophilized"),
        dictgen::InsensitiveStr::Ascii("ophilizer"),
        dictgen::InsensitiveStr::Ascii("ophilizes"),
        dictgen::InsensitiveStr::Ascii("ophilizing"),
        dictgen::InsensitiveStr::Ascii("ricisation"),
        dictgen::InsensitiveStr::Ascii("ricise"),
        dictgen::InsensitiveStr::Ascii("ricised"),
        dictgen::InsensitiveStr::Ascii("ricises"),
        dictgen::InsensitiveStr::Ascii("ricising"),
        dictgen::InsensitiveStr::Ascii("ricization"),
        dictgen::InsensitiveStr::Ascii("ricize"),
        dictgen::InsensitiveStr::Ascii("ricized"),
        dictgen::InsensitiveStr::Ascii("ricizes"),
        dictgen::InsensitiveStr::Ascii("ricizing"),
        dictgen::InsensitiveStr::Ascii("sogenisation"),
        dictgen::InsensitiveStr::Ascii("sogenise"),
        dictgen::InsensitiveStr::Ascii("sogenised"),
        dictgen::InsensitiveStr::Ascii("sogenises"),
        dictgen::InsensitiveStr::Ascii("sogenising"),
        dictgen::InsensitiveStr::Ascii("sogenization"),
        dictgen::InsensitiveStr::Ascii("sogenize"),
        dictgen::InsensitiveStr::Ascii("sogenized"),
        dictgen::InsensitiveStr::Ascii("sogenizes"),
        dictgen::InsensitiveStr::Ascii("sogenizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LYMPHEMIA_5556164096475699134)],
        &[(0b10001, &ENTRY_LYMPHEDEMA_4096912347991238867)],
        &[(0b00001, &ENTRY_LYMPHEMIA_5556164096475699134)],
        &[(0b11010, &ENTRY_LYMPHEDEMA_4096912347991238867)],
        &[(0b10010, &ENTRY_LYOPHILIZATION_12426577891143807361)],
        &[(0b10010, &ENTRY_LYOPHILIZATIONS_15343691347805562266)],
        &[(0b10010, &ENTRY_LYOPHILIZE_4883245748865024235)],
        &[(0b10010, &ENTRY_LYOPHILIZED_541457860358035146)],
        &[(0b10010, &ENTRY_LYOPHILIZER_3240181350199502588)],
        &[(0b10010, &ENTRY_LYOPHILIZES_17423281299656389223)],
        &[(0b10010, &ENTRY_LYOPHILIZING_17325205477536159774)],
        &[(0b01001, &ENTRY_LYOPHILIZATION_12426577891143807361)],
        &[(0b01001, &ENTRY_LYOPHILIZATIONS_15343691347805562266)],
        &[(0b01001, &ENTRY_LYOPHILIZE_4883245748865024235)],
        &[(0b01001, &ENTRY_LYOPHILIZED_541457860358035146)],
        &[(0b01001, &ENTRY_LYOPHILIZER_3240181350199502588)],
        &[(0b01001, &ENTRY_LYOPHILIZES_17423281299656389223)],
        &[(0b01001, &ENTRY_LYOPHILIZING_17325205477536159774)],
        &[(0b10010, &ENTRY_LYRICIZATION_5227207079625028356)],
        &[(0b10010, &ENTRY_LYRICIZE_5679181090729686264)],
        &[(0b10010, &ENTRY_LYRICIZED_1377860939111837355)],
        &[(0b10010, &ENTRY_LYRICIZES_1087674100771642847)],
        &[(0b10010, &ENTRY_LYRICIZING_16841414967163210794)],
        &[(0b01001, &ENTRY_LYRICIZATION_5227207079625028356)],
        &[(0b01001, &ENTRY_LYRICIZE_5679181090729686264)],
        &[(0b01001, &ENTRY_LYRICIZED_1377860939111837355)],
        &[(0b01001, &ENTRY_LYRICIZES_1087674100771642847)],
        &[(0b01001, &ENTRY_LYRICIZING_16841414967163210794)],
        &[(0b10010, &ENTRY_LYSOGENIZATION_11026822618685223605)],
        &[(0b10010, &ENTRY_LYSOGENIZE_4850978684783834586)],
        &[(0b10010, &ENTRY_LYSOGENIZED_198501167500625979)],
        &[(0b10010, &ENTRY_LYSOGENIZES_1808661323485276222)],
        &[(0b10010, &ENTRY_LYSOGENIZING_8619281309327783502)],
        &[(0b01001, &ENTRY_LYSOGENIZATION_11026822618685223605)],
        &[(0b01001, &ENTRY_LYSOGENIZE_4850978684783834586)],
        &[(0b01001, &ENTRY_LYSOGENIZED_198501167500625979)],
        &[(0b01001, &ENTRY_LYSOGENIZES_1808661323485276222)],
        &[(0b01001, &ENTRY_LYSOGENIZING_8619281309327783502)],
    ],
    range: 6..=13,
};

static VARS_LU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LU_CHILDREN),
    value: None,
};

pub static VARS_LU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mbarisation"),
        dictgen::InsensitiveStr::Ascii("mbarisations"),
        dictgen::InsensitiveStr::Ascii("mbarization"),
        dictgen::InsensitiveStr::Ascii("mbarizations"),
        dictgen::InsensitiveStr::Ascii("natise"),
        dictgen::InsensitiveStr::Ascii("natises"),
        dictgen::InsensitiveStr::Ascii("natize"),
        dictgen::InsensitiveStr::Ascii("natizes"),
        dictgen::InsensitiveStr::Ascii("nulae"),
        dictgen::InsensitiveStr::Ascii("nule"),
        dictgen::InsensitiveStr::Ascii("pines"),
        dictgen::InsensitiveStr::Ascii("ster"),
        dictgen::InsensitiveStr::Ascii("stered"),
        dictgen::InsensitiveStr::Ascii("stering"),
        dictgen::InsensitiveStr::Ascii("sterless"),
        dictgen::InsensitiveStr::Ascii("sterlesser"),
        dictgen::InsensitiveStr::Ascii("sterlessest"),
        dictgen::InsensitiveStr::Ascii("sters"),
        dictgen::InsensitiveStr::Ascii("sterware"),
        dictgen::InsensitiveStr::Ascii("sterwares"),
        dictgen::InsensitiveStr::Ascii("streless"),
        dictgen::InsensitiveStr::Ascii("strelesser"),
        dictgen::InsensitiveStr::Ascii("strelessest"),
        dictgen::InsensitiveStr::Ascii("streware"),
        dictgen::InsensitiveStr::Ascii("strewares"),
        dictgen::InsensitiveStr::Ascii("teinisation"),
        dictgen::InsensitiveStr::Ascii("teinisations"),
        dictgen::InsensitiveStr::Ascii("teinise"),
        dictgen::InsensitiveStr::Ascii("teinised"),
        dictgen::InsensitiveStr::Ascii("teinises"),
        dictgen::InsensitiveStr::Ascii("teinising"),
        dictgen::InsensitiveStr::Ascii("teinization"),
        dictgen::InsensitiveStr::Ascii("teinizations"),
        dictgen::InsensitiveStr::Ascii("teinize"),
        dictgen::InsensitiveStr::Ascii("teinized"),
        dictgen::InsensitiveStr::Ascii("teinizes"),
        dictgen::InsensitiveStr::Ascii("teinizing"),
        dictgen::InsensitiveStr::Ascii("theranise"),
        dictgen::InsensitiveStr::Ascii("theraniser"),
        dictgen::InsensitiveStr::Ascii("theranisers"),
        dictgen::InsensitiveStr::Ascii("theranises"),
        dictgen::InsensitiveStr::Ascii("theranize"),
        dictgen::InsensitiveStr::Ascii("theranizer"),
        dictgen::InsensitiveStr::Ascii("theranizers"),
        dictgen::InsensitiveStr::Ascii("theranizes"),
        dictgen::InsensitiveStr::Ascii("trinae"),
        dictgen::InsensitiveStr::Ascii("trine"),
        dictgen::InsensitiveStr::Ascii("v"),
        dictgen::InsensitiveStr::Ascii("vs"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LUMBARIZATION_14602498224971235802)],
        &[(0b10010, &ENTRY_LUMBARIZATIONS_9565306337604753000)],
        &[(0b01001, &ENTRY_LUMBARIZATION_14602498224971235802)],
        &[(0b01001, &ENTRY_LUMBARIZATIONS_9565306337604753000)],
        &[(0b10010, &ENTRY_LUNATIZE_7809892840688807347)],
        &[(0b10010, &ENTRY_LUNATIZES_1113492957066304386)],
        &[(0b01001, &ENTRY_LUNATIZE_7809892840688807347)],
        &[(0b01001, &ENTRY_LUNATIZES_1113492957066304386)],
        &[(0b11010, &ENTRY_LUNULE_13057287095940975866)],
        &[(0b00001, &ENTRY_LUNULE_13057287095940975866)],
        &[(0b01001, &ENTRY_LUPINES_12557265007088872959)],
        &[(0b00001, &ENTRY_LUSTER_11657857751959453572)],
        &[(0b00001, &ENTRY_LUSTERED_18386163894228820867)],
        &[(0b00001, &ENTRY_LUSTERING_15456794957624815028)],
        &[(0b00001, &ENTRY_LUSTERLESS_5389478484187307315)],
        &[(0b00001, &ENTRY_LUSTERLESSER_7250450891961099005)],
        &[(0b00001, &ENTRY_LUSTERLESSEST_15709155643033799906)],
        &[(0b00001, &ENTRY_LUSTERS_15623538067173334389)],
        &[(0b00001, &ENTRY_LUSTERWARE_7714995265583039919)],
        &[(0b00001, &ENTRY_LUSTERWARES_18360797893051456330)],
        &[(0b11010, &ENTRY_LUSTERLESS_5389478484187307315)],
        &[(0b11010, &ENTRY_LUSTERLESSER_7250450891961099005)],
        &[(0b11010, &ENTRY_LUSTERLESSEST_15709155643033799906)],
        &[(0b11010, &ENTRY_LUSTERWARE_7714995265583039919)],
        &[(0b11010, &ENTRY_LUSTERWARES_18360797893051456330)],
        &[(0b10010, &ENTRY_LUTEINIZATION_10917420500003613570)],
        &[(0b10010, &ENTRY_LUTEINIZATIONS_2301336961919403024)],
        &[(0b10010, &ENTRY_LUTEINIZE_11955489358557604884)],
        &[(0b10010, &ENTRY_LUTEINIZED_16548614593509361290)],
        &[(0b10010, &ENTRY_LUTEINIZES_6496313678658191078)],
        &[(0b10010, &ENTRY_LUTEINIZING_12727551757461309338)],
        &[(0b01001, &ENTRY_LUTEINIZATION_10917420500003613570)],
        &[(0b01001, &ENTRY_LUTEINIZATIONS_2301336961919403024)],
        &[(0b01001, &ENTRY_LUTEINIZE_11955489358557604884)],
        &[(0b01001, &ENTRY_LUTEINIZED_16548614593509361290)],
        &[(0b01001, &ENTRY_LUTEINIZES_6496313678658191078)],
        &[(0b01001, &ENTRY_LUTEINIZING_12727551757461309338)],
        &[(0b10010, &ENTRY_LUTHERANIZE_6443947515442607976)],
        &[(0b10010, &ENTRY_LUTHERANIZER_13007772553916013323)],
        &[(0b10010, &ENTRY_LUTHERANIZERS_3104690288699234709)],
        &[(0b10010, &ENTRY_LUTHERANIZES_15371432198725795026)],
        &[(0b01001, &ENTRY_LUTHERANIZE_6443947515442607976)],
        &[(0b01001, &ENTRY_LUTHERANIZER_13007772553916013323)],
        &[(0b01001, &ENTRY_LUTHERANIZERS_3104690288699234709)],
        &[(0b01001, &ENTRY_LUTHERANIZES_15371432198725795026)],
        &[(0b11010, &ENTRY_LUTRINE_1583093555111669623)],
        &[(0b00001, &ENTRY_LUTRINE_1583093555111669623)],
        &[(0b00001, &ENTRY_LOVE_16520323727787961615)],
        &[(0b00001, &ENTRY_LOVES_4486785153621169721)],
    ],
    range: 1..=12,
};

static VARS_LO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LO_CHILDREN),
    value: None,
};

static VARS_LO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_LOB_NODE),
    Some(&VARS_LOC_NODE),
    Some(&VARS_LOD_NODE),
    Some(&VARS_LOE_NODE),
    None,
    Some(&VARS_LOG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LON_NODE),
    Some(&VARS_LOO_NODE),
    None,
    None,
    Some(&VARS_LOR_NODE),
    None,
    None,
    Some(&VARS_LOU_NODE),
    Some(&VARS_LOV_NODE),
    None,
    None,
    Some(&VARS_LOY_NODE),
    None,
];

static VARS_LOY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOY_CHILDREN),
    value: None,
};

pub static VARS_LOY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LOYALIZE_15988054747149521230)],
        &[(0b10010, &ENTRY_LOYALIZES_10039035262119911075)],
        &[(0b01001, &ENTRY_LOYALIZE_15988054747149521230)],
        &[(0b01001, &ENTRY_LOYALIZES_10039035262119911075)],
    ],
    range: 5..=6,
};

static VARS_LOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOV_CHILDREN),
    value: None,
};

pub static VARS_LOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aebility"),
        dictgen::InsensitiveStr::Ascii("eableness"),
        dictgen::InsensitiveStr::Ascii("eably"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LOVABILITY_8730410497494295106)],
        &[(0b00001, &ENTRY_LOVABLENESS_14732271905038073610)],
        &[(0b00001, &ENTRY_LOVABLY_6219831687533495276)],
    ],
    range: 5..=9,
};

static VARS_LOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOU_CHILDREN),
    value: None,
};

pub static VARS_LOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rdy"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("ry"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("ver"),
        dictgen::InsensitiveStr::Ascii("vered"),
        dictgen::InsensitiveStr::Ascii("vers"),
        dictgen::InsensitiveStr::Ascii("vre"),
        dictgen::InsensitiveStr::Ascii("vred"),
        dictgen::InsensitiveStr::Ascii("vres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LORDY_5781678477358659813)],
        &[(0b11010, &ENTRY_LORINGS_15139277523335794013)],
        &[(0b11010, &ENTRY_LORY_5690223887549386793)],
        &[(0b00001, &ENTRY_LOUTER_14462081307219571398)],
        &[(0b11010, &ENTRY_LOUTER_14462081307219571398)],
        &[(0b01001, &ENTRY_LOUVER_4804716624330681765)],
        &[(0b01001, &ENTRY_LOUVERED_645715404753463951)],
        &[(0b01001, &ENTRY_LOUVERS_7007967065948552702)],
        &[(0b11010, &ENTRY_LOUVER_4804716624330681765)],
        &[(0b11010, &ENTRY_LOUVERED_645715404753463951)],
        &[(0b11010, &ENTRY_LOUVERS_7007967065948552702)],
    ],
    range: 2..=5,
};

static VARS_LOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOR_CHILDREN),
    value: None,
};

pub static VARS_LOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dy"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LORDY_5781678477358659813)],
        &[(0b00001, &ENTRY_LORINGS_15139277523335794013)],
        &[(0b00001, &ENTRY_LORY_5690223887549386793)],
    ],
    range: 1..=4,
};

static VARS_LOO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOO_CHILDREN),
    value: None,
};

pub static VARS_LOO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ed")],
    values: &[&[(0b11010, &ENTRY_LOED_2853311868916521037)]],
    range: 2..=2,
};

static VARS_LON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LON_CHILDREN),
    value: None,
};

pub static VARS_LON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("donisation"),
        dictgen::InsensitiveStr::Ascii("donisations"),
        dictgen::InsensitiveStr::Ascii("donise"),
        dictgen::InsensitiveStr::Ascii("donised"),
        dictgen::InsensitiveStr::Ascii("donises"),
        dictgen::InsensitiveStr::Ascii("donising"),
        dictgen::InsensitiveStr::Ascii("donization"),
        dictgen::InsensitiveStr::Ascii("donizations"),
        dictgen::InsensitiveStr::Ascii("donize"),
        dictgen::InsensitiveStr::Ascii("donized"),
        dictgen::InsensitiveStr::Ascii("donizes"),
        dictgen::InsensitiveStr::Ascii("donizing"),
        dictgen::InsensitiveStr::Ascii("gaeval"),
        dictgen::InsensitiveStr::Ascii("gaevous"),
        dictgen::InsensitiveStr::Ascii("geval"),
        dictgen::InsensitiveStr::Ascii("gevous"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LONDONIZATION_200081076455131667)],
        &[(0b10010, &ENTRY_LONDONIZATIONS_1889334259429879036)],
        &[(0b10010, &ENTRY_LONDONIZE_3238748388091982565)],
        &[(0b10010, &ENTRY_LONDONIZED_16299293806476488564)],
        &[(0b10010, &ENTRY_LONDONIZES_3901227594887662007)],
        &[(0b10010, &ENTRY_LONDONIZING_4059093782595442599)],
        &[(0b01001, &ENTRY_LONDONIZATION_200081076455131667)],
        &[(0b01001, &ENTRY_LONDONIZATIONS_1889334259429879036)],
        &[(0b01001, &ENTRY_LONDONIZE_3238748388091982565)],
        &[(0b01001, &ENTRY_LONDONIZED_16299293806476488564)],
        &[(0b01001, &ENTRY_LONDONIZES_3901227594887662007)],
        &[(0b01001, &ENTRY_LONDONIZING_4059093782595442599)],
        &[(0b11010, &ENTRY_LONGEVAL_15368062473073605372)],
        &[(0b11010, &ENTRY_LONGEVOUS_18025689925843224945)],
        &[(0b00001, &ENTRY_LONGEVAL_15368062473073605372)],
        &[(0b00001, &ENTRY_LONGEVOUS_18025689925843224945)],
    ],
    range: 5..=11,
};

static VARS_LOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOG_CHILDREN),
    value: None,
};

pub static VARS_LOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icalisation"),
        dictgen::InsensitiveStr::Ascii("icalisations"),
        dictgen::InsensitiveStr::Ascii("icalise"),
        dictgen::InsensitiveStr::Ascii("icalises"),
        dictgen::InsensitiveStr::Ascii("icalization"),
        dictgen::InsensitiveStr::Ascii("icalizations"),
        dictgen::InsensitiveStr::Ascii("icalize"),
        dictgen::InsensitiveStr::Ascii("icalizes"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("opaedic"),
        dictgen::InsensitiveStr::Ascii("opaedics"),
        dictgen::InsensitiveStr::Ascii("opedic"),
        dictgen::InsensitiveStr::Ascii("opedics"),
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrheas"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhoeas"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LOGICALIZATION_12818715216393851906)],
        &[(0b10010, &ENTRY_LOGICALIZATIONS_11292099513888491109)],
        &[(0b10010, &ENTRY_LOGICALIZE_2176872405258834372)],
        &[(0b10010, &ENTRY_LOGICALIZES_10430140462205373333)],
        &[(0b01001, &ENTRY_LOGICALIZATION_12818715216393851906)],
        &[(0b01001, &ENTRY_LOGICALIZATIONS_11292099513888491109)],
        &[(0b01001, &ENTRY_LOGICALIZE_2176872405258834372)],
        &[(0b01001, &ENTRY_LOGICALIZES_10430140462205373333)],
        &[(0b10010, &ENTRY_LOGICIZE_15843613372926701720)],
        &[(0b10010, &ENTRY_LOGICIZED_2546846215835324757)],
        &[(0b10010, &ENTRY_LOGICIZES_3568589430640497383)],
        &[(0b10010, &ENTRY_LOGICIZING_6614561759161636962)],
        &[(0b01001, &ENTRY_LOGICIZE_15843613372926701720)],
        &[(0b01001, &ENTRY_LOGICIZED_2546846215835324757)],
        &[(0b01001, &ENTRY_LOGICIZES_3568589430640497383)],
        &[(0b01001, &ENTRY_LOGICIZING_6614561759161636962)],
        &[(0b11010, &ENTRY_LOGOPEDIC_2956934522226350209)],
        &[(0b11010, &ENTRY_LOGOPEDICS_5579541352089166615)],
        &[(0b10001, &ENTRY_LOGOPEDIC_2956934522226350209)],
        &[(0b10001, &ENTRY_LOGOPEDICS_5579541352089166615)],
        &[(0b11001, &ENTRY_LOGORRHEA_1908810066516211712)],
        &[(0b11001, &ENTRY_LOGORRHEAS_1216027759521800987)],
        &[(0b10010, &ENTRY_LOGORRHEA_1908810066516211712)],
        &[(0b10010, &ENTRY_LOGORRHEAS_1216027759521800987)],
    ],
    range: 5..=12,
};

static VARS_LOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOE_CHILDREN),
    value: None,
};

pub static VARS_LOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("sses"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LOED_2853311868916521037)],
        &[(0b11010, &ENTRY_LESSES_11253910437625016547)],
    ],
    range: 1..=4,
};

static VARS_LOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOD_CHILDREN),
    value: None,
};

pub static VARS_LOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iculae"),
        dictgen::InsensitiveStr::Ascii("icule"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LODICULE_12304146402971909793)],
        &[(0b00001, &ENTRY_LODICULE_12304146402971909793)],
    ],
    range: 5..=6,
};

static VARS_LOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOC_CHILDREN),
    value: None,
};

pub static VARS_LOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisabler"),
        dictgen::InsensitiveStr::Ascii("alisables"),
        dictgen::InsensitiveStr::Ascii("alisablest"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alizabler"),
        dictgen::InsensitiveStr::Ascii("alizables"),
        dictgen::InsensitiveStr::Ascii("alizablest"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LOCALIZABLE_5621481337891586601)],
        &[(0b10010, &ENTRY_LOCALIZABLER_5186192263224785623)],
        &[(0b10010, &ENTRY_LOCALIZABLES_12552472873910273687)],
        &[(0b10010, &ENTRY_LOCALIZABLEST_871745589087632617)],
        &[(0b10010, &ENTRY_LOCALIZATION_1238475456869979060)],
        &[(0b10010, &ENTRY_LOCALIZATIONS_2073048544247751824)],
        &[(0b10010, &ENTRY_LOCALIZE_16099552228413639227)],
        &[(0b10010, &ENTRY_LOCALIZED_7455385096278523226)],
        &[(0b10010, &ENTRY_LOCALIZER_7157782650234430721)],
        &[(0b10010, &ENTRY_LOCALIZERS_15025775966428286175)],
        &[(0b10010, &ENTRY_LOCALIZES_3870056311066884314)],
        &[(0b10010, &ENTRY_LOCALIZING_13763510577796965626)],
        &[(0b01001, &ENTRY_LOCALIZABLE_5621481337891586601)],
        &[(0b01001, &ENTRY_LOCALIZABLER_5186192263224785623)],
        &[(0b01001, &ENTRY_LOCALIZABLES_12552472873910273687)],
        &[(0b01001, &ENTRY_LOCALIZABLEST_871745589087632617)],
        &[(0b01001, &ENTRY_LOCALIZATION_1238475456869979060)],
        &[(0b01001, &ENTRY_LOCALIZATIONS_2073048544247751824)],
        &[(0b01001, &ENTRY_LOCALIZE_16099552228413639227)],
        &[(0b01001, &ENTRY_LOCALIZED_7455385096278523226)],
        &[(0b01001, &ENTRY_LOCALIZER_7157782650234430721)],
        &[(0b01001, &ENTRY_LOCALIZERS_15025775966428286175)],
        &[(0b01001, &ENTRY_LOCALIZES_3870056311066884314)],
        &[(0b01001, &ENTRY_LOCALIZING_13763510577796965626)],
    ],
    range: 5..=10,
};

static VARS_LOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LOB_CHILDREN),
    value: None,
};

pub static VARS_LOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otomise"),
        dictgen::InsensitiveStr::Ascii("otomised"),
        dictgen::InsensitiveStr::Ascii("otomises"),
        dictgen::InsensitiveStr::Ascii("otomising"),
        dictgen::InsensitiveStr::Ascii("otomize"),
        dictgen::InsensitiveStr::Ascii("otomized"),
        dictgen::InsensitiveStr::Ascii("otomizes"),
        dictgen::InsensitiveStr::Ascii("otomizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LOBOTOMIZE_8157557484359506144)],
        &[(0b10010, &ENTRY_LOBOTOMIZED_15930324383958788489)],
        &[(0b10010, &ENTRY_LOBOTOMIZES_16177974637639176057)],
        &[(0b10010, &ENTRY_LOBOTOMIZING_2915569577636182986)],
        &[(0b01001, &ENTRY_LOBOTOMIZE_8157557484359506144)],
        &[(0b01001, &ENTRY_LOBOTOMIZED_15930324383958788489)],
        &[(0b01001, &ENTRY_LOBOTOMIZES_16177974637639176057)],
        &[(0b01001, &ENTRY_LOBOTOMIZING_2915569577636182986)],
    ],
    range: 7..=9,
};

static VARS_LI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LI_CHILDREN),
    value: None,
};

static VARS_LI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_LIB_NODE),
    Some(&VARS_LIC_NODE),
    None,
    None,
    None,
    Some(&VARS_LIG_NODE),
    None,
    None,
    None,
    Some(&VARS_LIK_NODE),
    Some(&VARS_LIL_NODE),
    None,
    Some(&VARS_LIN_NODE),
    Some(&VARS_LIO_NODE),
    Some(&VARS_LIP_NODE),
    Some(&VARS_LIQ_NODE),
    None,
    Some(&VARS_LIS_NODE),
    Some(&VARS_LIT_NODE),
    None,
    Some(&VARS_LIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_LIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIV_CHILDREN),
    value: None,
};

pub static VARS_LIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("able")],
    values: &[&[(0b11001, &ENTRY_LIVABLE_3901248475092706490)]],
    range: 4..=4,
};

static VARS_LIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIT_CHILDREN),
    value: None,
};

pub static VARS_LIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralised"),
        dictgen::InsensitiveStr::Ascii("eraliser"),
        dictgen::InsensitiveStr::Ascii("eralisers"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralising"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralized"),
        dictgen::InsensitiveStr::Ascii("eralizer"),
        dictgen::InsensitiveStr::Ascii("eralizers"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("eralizing"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("haemia"),
        dictgen::InsensitiveStr::Ascii("haemic"),
        dictgen::InsensitiveStr::Ascii("hed"),
        dictgen::InsensitiveStr::Ascii("hemia"),
        dictgen::InsensitiveStr::Ascii("hemic"),
        dictgen::InsensitiveStr::Ascii("hoed"),
        dictgen::InsensitiveStr::Ascii("hographise"),
        dictgen::InsensitiveStr::Ascii("hographises"),
        dictgen::InsensitiveStr::Ascii("hographize"),
        dictgen::InsensitiveStr::Ascii("hographizes"),
        dictgen::InsensitiveStr::Ascii("hopaedion"),
        dictgen::InsensitiveStr::Ascii("hopaedium"),
        dictgen::InsensitiveStr::Ascii("hopedion"),
        dictgen::InsensitiveStr::Ascii("hopedium"),
        dictgen::InsensitiveStr::Ascii("hophysae"),
        dictgen::InsensitiveStr::Ascii("hophyse"),
        dictgen::InsensitiveStr::Ascii("hotritise"),
        dictgen::InsensitiveStr::Ascii("hotritised"),
        dictgen::InsensitiveStr::Ascii("hotritises"),
        dictgen::InsensitiveStr::Ascii("hotritising"),
        dictgen::InsensitiveStr::Ascii("hotritize"),
        dictgen::InsensitiveStr::Ascii("hotritized"),
        dictgen::InsensitiveStr::Ascii("hotritizes"),
        dictgen::InsensitiveStr::Ascii("hotritizing"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("res"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LITER_12446429543534900630)],
        &[(0b10010, &ENTRY_LITERALIZATION_16579057682189218971)],
        &[(0b10010, &ENTRY_LITERALIZATIONS_11027786126710213305)],
        &[(0b10010, &ENTRY_LITERALIZE_7488923076722768228)],
        &[(0b10010, &ENTRY_LITERALIZED_17139448346953459594)],
        &[(0b10010, &ENTRY_LITERALIZER_18413794030675395560)],
        &[(0b10010, &ENTRY_LITERALIZERS_6657290223588440562)],
        &[(0b10010, &ENTRY_LITERALIZES_14783446531151201125)],
        &[(0b10010, &ENTRY_LITERALIZING_17176990014657786316)],
        &[(0b01001, &ENTRY_LITERALIZATION_16579057682189218971)],
        &[(0b01001, &ENTRY_LITERALIZATIONS_11027786126710213305)],
        &[(0b01001, &ENTRY_LITERALIZE_7488923076722768228)],
        &[(0b01001, &ENTRY_LITERALIZED_17139448346953459594)],
        &[(0b01001, &ENTRY_LITERALIZER_18413794030675395560)],
        &[(0b01001, &ENTRY_LITERALIZERS_6657290223588440562)],
        &[(0b01001, &ENTRY_LITERALIZES_14783446531151201125)],
        &[(0b01001, &ENTRY_LITERALIZING_17176990014657786316)],
        &[(0b00001, &ENTRY_LITERS_12776695440733823940)],
        &[(0b11010, &ENTRY_LITHEMIA_6379925803216421556)],
        &[(0b11010, &ENTRY_LITHEMIC_7018748774788775749)],
        &[(0b00001, &ENTRY_LITHED_4192395907200130721)],
        &[(0b10001, &ENTRY_LITHEMIA_6379925803216421556)],
        &[(0b10001, &ENTRY_LITHEMIC_7018748774788775749)],
        &[(0b11010, &ENTRY_LITHED_4192395907200130721)],
        &[(0b10010, &ENTRY_LITHOGRAPHIZE_16656619554654866733)],
        &[(0b10010, &ENTRY_LITHOGRAPHIZES_3639204701426090508)],
        &[(0b01001, &ENTRY_LITHOGRAPHIZE_16656619554654866733)],
        &[(0b01001, &ENTRY_LITHOGRAPHIZES_3639204701426090508)],
        &[(0b11010, &ENTRY_LITHOPEDION_18112524864351619969)],
        &[(0b11010, &ENTRY_LITHOPEDIUM_8268761739996957556)],
        &[(0b10001, &ENTRY_LITHOPEDION_18112524864351619969)],
        &[(0b10001, &ENTRY_LITHOPEDIUM_8268761739996957556)],
        &[(0b11010, &ENTRY_LITHOPHYSE_2447474686750604797)],
        &[(0b00001, &ENTRY_LITHOPHYSE_2447474686750604797)],
        &[(0b10010, &ENTRY_LITHOTRITIZE_5875367824474338869)],
        &[(0b10010, &ENTRY_LITHOTRITIZED_16101279289408156476)],
        &[(0b10010, &ENTRY_LITHOTRITIZES_17793208890442211508)],
        &[(0b10010, &ENTRY_LITHOTRITIZING_3557016990622667149)],
        &[(0b01001, &ENTRY_LITHOTRITIZE_5875367824474338869)],
        &[(0b01001, &ENTRY_LITHOTRITIZED_16101279289408156476)],
        &[(0b01001, &ENTRY_LITHOTRITIZES_17793208890442211508)],
        &[(0b01001, &ENTRY_LITHOTRITIZING_3557016990622667149)],
        &[(0b11010, &ENTRY_LITER_12446429543534900630)],
        &[(0b11010, &ENTRY_LITERS_12776695440733823940)],
    ],
    range: 2..=12,
};

static VARS_LIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIS_CHILDREN),
    value: None,
};

pub static VARS_LIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("someness"),
        dictgen::InsensitiveStr::Ascii("somenesses"),
        dictgen::InsensitiveStr::Ascii("somness"),
        dictgen::InsensitiveStr::Ascii("somnesses"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terised"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terising"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terized"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("terizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_LISSOMENESS_10505356153447417142)],
        &[(0b01001, &ENTRY_LISSOMENESSES_17321997662338443285)],
        &[(0b10011, &ENTRY_LISSOMENESS_10505356153447417142)],
        &[(0b10011, &ENTRY_LISSOMENESSES_17321997662338443285)],
        &[(0b10010, &ENTRY_LISTERIZE_1789669691755689663)],
        &[(0b10010, &ENTRY_LISTERIZED_2694194050509300683)],
        &[(0b10010, &ENTRY_LISTERIZES_6903942868385427615)],
        &[(0b10010, &ENTRY_LISTERIZING_15961483896286509040)],
        &[(0b01001, &ENTRY_LISTERIZE_1789669691755689663)],
        &[(0b01001, &ENTRY_LISTERIZED_2694194050509300683)],
        &[(0b01001, &ENTRY_LISTERIZES_6903942868385427615)],
        &[(0b01001, &ENTRY_LISTERIZING_15961483896286509040)],
    ],
    range: 6..=10,
};

static VARS_LIQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIQ_CHILDREN),
    value: None,
};

pub static VARS_LIQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uidisation"),
        dictgen::InsensitiveStr::Ascii("uidise"),
        dictgen::InsensitiveStr::Ascii("uidised"),
        dictgen::InsensitiveStr::Ascii("uidiser"),
        dictgen::InsensitiveStr::Ascii("uidisers"),
        dictgen::InsensitiveStr::Ascii("uidises"),
        dictgen::InsensitiveStr::Ascii("uidising"),
        dictgen::InsensitiveStr::Ascii("uidization"),
        dictgen::InsensitiveStr::Ascii("uidize"),
        dictgen::InsensitiveStr::Ascii("uidized"),
        dictgen::InsensitiveStr::Ascii("uidizer"),
        dictgen::InsensitiveStr::Ascii("uidizers"),
        dictgen::InsensitiveStr::Ascii("uidizes"),
        dictgen::InsensitiveStr::Ascii("uidizing"),
        dictgen::InsensitiveStr::Ascii("uifier"),
        dictgen::InsensitiveStr::Ascii("uifiers"),
        dictgen::InsensitiveStr::Ascii("uorice"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LIQUIDIZATION_13675074303920022173)],
        &[(0b11010, &ENTRY_LIQUIDIZE_7779765250864902667)],
        &[(0b11010, &ENTRY_LIQUIDIZED_5980678006594236599)],
        &[(0b10010, &ENTRY_LIQUIDIZER_14433199094156660496)],
        &[(0b10010, &ENTRY_LIQUIDIZERS_15740552531926766862)],
        &[(0b11010, &ENTRY_LIQUIDIZES_5754653035068200343)],
        &[(0b11010, &ENTRY_LIQUIDIZING_11026646695248605621)],
        &[(0b01001, &ENTRY_LIQUIDIZATION_13675074303920022173)],
        &[(0b01001, &ENTRY_LIQUIDIZE_7779765250864902667)],
        &[(0b01001, &ENTRY_LIQUIDIZED_5980678006594236599)],
        &[(0b01001, &ENTRY_LIQUIDIZER_14433199094156660496)],
        &[(0b01001, &ENTRY_LIQUIDIZERS_15740552531926766862)],
        &[(0b01001, &ENTRY_LIQUIDIZES_5754653035068200343)],
        &[(0b01001, &ENTRY_LIQUIDIZING_11026646695248605621)],
        &[(0b00001, &ENTRY_LIQUEFIER_14101716175872998571)],
        &[(0b00001, &ENTRY_LIQUEFIERS_9846252651053630322)],
        &[(0b10010, &ENTRY_LICORICE_6514036211352134052)],
    ],
    range: 6..=10,
};

static VARS_LIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIP_CHILDREN),
    value: None,
};

pub static VARS_LIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("oidaemia"),
        dictgen::InsensitiveStr::Ascii("oidemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LIPEMIA_15225486669219540679)],
        &[(0b11010, &ENTRY_LIPEMIC_10806335327474718728)],
        &[(0b10001, &ENTRY_LIPEMIA_15225486669219540679)],
        &[(0b10001, &ENTRY_LIPEMIC_10806335327474718728)],
        &[(0b11010, &ENTRY_LIPOIDEMIA_13270643093276922971)],
        &[(0b10001, &ENTRY_LIPOIDEMIA_13270643093276922971)],
    ],
    range: 4..=8,
};

static VARS_LIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIO_CHILDREN),
    value: None,
};

pub static VARS_LIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisable"),
        dictgen::InsensitiveStr::Ascii("nisables"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nizable"),
        dictgen::InsensitiveStr::Ascii("nizables"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LIONIZABLE_8467501967425405420)],
        &[(0b10010, &ENTRY_LIONIZABLES_3283556562579171860)],
        &[(0b10010, &ENTRY_LIONIZATION_1681225231313208851)],
        &[(0b10010, &ENTRY_LIONIZATIONS_6471589896326506860)],
        &[(0b10010, &ENTRY_LIONIZE_6821818092678063880)],
        &[(0b10010, &ENTRY_LIONIZED_1114575847150322021)],
        &[(0b10010, &ENTRY_LIONIZER_10735887263063669185)],
        &[(0b10010, &ENTRY_LIONIZERS_8516239737072899840)],
        &[(0b10010, &ENTRY_LIONIZES_859661935731471597)],
        &[(0b10010, &ENTRY_LIONIZING_10205945039497753785)],
        &[(0b01001, &ENTRY_LIONIZABLE_8467501967425405420)],
        &[(0b01001, &ENTRY_LIONIZABLES_3283556562579171860)],
        &[(0b01001, &ENTRY_LIONIZATION_1681225231313208851)],
        &[(0b01001, &ENTRY_LIONIZATIONS_6471589896326506860)],
        &[(0b01001, &ENTRY_LIONIZE_6821818092678063880)],
        &[(0b01001, &ENTRY_LIONIZED_1114575847150322021)],
        &[(0b01001, &ENTRY_LIONIZER_10735887263063669185)],
        &[(0b01001, &ENTRY_LIONIZERS_8516239737072899840)],
        &[(0b01001, &ENTRY_LIONIZES_859661935731471597)],
        &[(0b01001, &ENTRY_LIONIZING_10205945039497753785)],
    ],
    range: 4..=9,
};

static VARS_LIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIN_CHILDREN),
    value: None,
};

pub static VARS_LIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("earisable"),
        dictgen::InsensitiveStr::Ascii("earisation"),
        dictgen::InsensitiveStr::Ascii("earisations"),
        dictgen::InsensitiveStr::Ascii("earise"),
        dictgen::InsensitiveStr::Ascii("earised"),
        dictgen::InsensitiveStr::Ascii("earises"),
        dictgen::InsensitiveStr::Ascii("earising"),
        dictgen::InsensitiveStr::Ascii("earision"),
        dictgen::InsensitiveStr::Ascii("earizable"),
        dictgen::InsensitiveStr::Ascii("earization"),
        dictgen::InsensitiveStr::Ascii("earizations"),
        dictgen::InsensitiveStr::Ascii("earize"),
        dictgen::InsensitiveStr::Ascii("earized"),
        dictgen::InsensitiveStr::Ascii("earizes"),
        dictgen::InsensitiveStr::Ascii("earizing"),
        dictgen::InsensitiveStr::Ascii("earizion"),
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("eniser"),
        dictgen::InsensitiveStr::Ascii("enisers"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enizer"),
        dictgen::InsensitiveStr::Ascii("enizers"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("ge"),
        dictgen::InsensitiveStr::Ascii("goe"),
        dictgen::InsensitiveStr::Ascii("gualise"),
        dictgen::InsensitiveStr::Ascii("gualises"),
        dictgen::InsensitiveStr::Ascii("gualize"),
        dictgen::InsensitiveStr::Ascii("gualizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LINEARIZABLE_18400360953531743213)],
        &[(0b10010, &ENTRY_LINEARIZATION_9279263650346150967)],
        &[(0b10010, &ENTRY_LINEARIZATIONS_17748612167806095377)],
        &[(0b10010, &ENTRY_LINEARIZE_7336841783934324744)],
        &[(0b10010, &ENTRY_LINEARIZED_2234489635191578422)],
        &[(0b10010, &ENTRY_LINEARIZES_9364491053382084700)],
        &[(0b10010, &ENTRY_LINEARIZING_10738882490325913802)],
        &[(0b10010, &ENTRY_LINEARIZION_15811782744897496386)],
        &[(0b01001, &ENTRY_LINEARIZABLE_18400360953531743213)],
        &[(0b01001, &ENTRY_LINEARIZATION_9279263650346150967)],
        &[(0b01001, &ENTRY_LINEARIZATIONS_17748612167806095377)],
        &[(0b01001, &ENTRY_LINEARIZE_7336841783934324744)],
        &[(0b01001, &ENTRY_LINEARIZED_2234489635191578422)],
        &[(0b01001, &ENTRY_LINEARIZES_9364491053382084700)],
        &[(0b01001, &ENTRY_LINEARIZING_10738882490325913802)],
        &[(0b01001, &ENTRY_LINEARIZION_15811782744897496386)],
        &[(0b10010, &ENTRY_LINENIZE_4255117013207072568)],
        &[(0b10010, &ENTRY_LINENIZER_11892341743174422110)],
        &[(0b10010, &ENTRY_LINENIZERS_17723432590290079521)],
        &[(0b10010, &ENTRY_LINENIZES_13144713631494316074)],
        &[(0b01001, &ENTRY_LINENIZE_4255117013207072568)],
        &[(0b01001, &ENTRY_LINENIZER_11892341743174422110)],
        &[(0b01001, &ENTRY_LINENIZERS_17723432590290079521)],
        &[(0b01001, &ENTRY_LINENIZES_13144713631494316074)],
        &[(0b00001, &ENTRY_LINGE_7553285674660467670)],
        &[(0b11010, &ENTRY_LINGE_7553285674660467670)],
        &[(0b10010, &ENTRY_LINGUALIZE_1511015541496198186)],
        &[(0b10010, &ENTRY_LINGUALIZES_11625557214170052581)],
        &[(0b01001, &ENTRY_LINGUALIZE_1511015541496198186)],
        &[(0b01001, &ENTRY_LINGUALIZES_11625557214170052581)],
    ],
    range: 2..=11,
};

static VARS_LIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIL_CHILDREN),
    value: None,
};

pub static VARS_LIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("liputianise"),
        dictgen::InsensitiveStr::Ascii("liputianises"),
        dictgen::InsensitiveStr::Ascii("liputianize"),
        dictgen::InsensitiveStr::Ascii("liputianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LILLIPUTIANIZE_11727867587474310781)],
        &[(0b10010, &ENTRY_LILLIPUTIANIZES_16811775630936201889)],
        &[(0b01001, &ENTRY_LILLIPUTIANIZE_11727867587474310781)],
        &[(0b01001, &ENTRY_LILLIPUTIANIZES_16811775630936201889)],
    ],
    range: 11..=12,
};

static VARS_LIK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIK_CHILDREN),
    value: None,
};

pub static VARS_LIK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilities"),
        dictgen::InsensitiveStr::Ascii("ability"),
        dictgen::InsensitiveStr::Ascii("ableness"),
        dictgen::InsensitiveStr::Ascii("ablenesses"),
    ],
    values: &[
        &[(0b10001, &ENTRY_LIKABILITIES_1914395607629735656)],
        &[(0b10001, &ENTRY_LIKABILITY_17749543815120781481)],
        &[(0b10001, &ENTRY_LIKABLENESS_13673349450699272280)],
        &[(0b10001, &ENTRY_LIKABLENESSES_6855441341065426255)],
    ],
    range: 7..=10,
};

static VARS_LIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIG_CHILDREN),
    value: None,
};

pub static VARS_LIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nitise"),
        dictgen::InsensitiveStr::Ascii("nitises"),
        dictgen::InsensitiveStr::Ascii("nitize"),
        dictgen::InsensitiveStr::Ascii("nitizes"),
        dictgen::InsensitiveStr::Ascii("nosae"),
        dictgen::InsensitiveStr::Ascii("nose"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LIGNITIZE_1767530194184708816)],
        &[(0b10010, &ENTRY_LIGNITIZES_7337259783024163734)],
        &[(0b01001, &ENTRY_LIGNITIZE_1767530194184708816)],
        &[(0b01001, &ENTRY_LIGNITIZES_7337259783024163734)],
        &[(0b11010, &ENTRY_LIGNOSE_12807960118794739477)],
        &[(0b00001, &ENTRY_LIGNOSE_12807960118794739477)],
        &[(0b11010, &ENTRY_LIGULE_14255542831609864406)],
        &[(0b00001, &ENTRY_LIGULE_14255542831609864406)],
    ],
    range: 3..=7,
};

static VARS_LIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIC_CHILDREN),
    value: None,
};

pub static VARS_LIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ence"),
        dictgen::InsensitiveStr::Ascii("enced"),
        dictgen::InsensitiveStr::Ascii("enceless"),
        dictgen::InsensitiveStr::Ascii("encelesses"),
        dictgen::InsensitiveStr::Ascii("ences"),
        dictgen::InsensitiveStr::Ascii("encing"),
        dictgen::InsensitiveStr::Ascii("enseless"),
        dictgen::InsensitiveStr::Ascii("enselesses"),
        dictgen::InsensitiveStr::Ascii("henisation"),
        dictgen::InsensitiveStr::Ascii("henisations"),
        dictgen::InsensitiveStr::Ascii("henise"),
        dictgen::InsensitiveStr::Ascii("henised"),
        dictgen::InsensitiveStr::Ascii("henises"),
        dictgen::InsensitiveStr::Ascii("henising"),
        dictgen::InsensitiveStr::Ascii("henization"),
        dictgen::InsensitiveStr::Ascii("henizations"),
        dictgen::InsensitiveStr::Ascii("henize"),
        dictgen::InsensitiveStr::Ascii("henized"),
        dictgen::InsensitiveStr::Ascii("henizes"),
        dictgen::InsensitiveStr::Ascii("henizing"),
        dictgen::InsensitiveStr::Ascii("orice"),
    ],
    values: &[
        &[
            (0b00010, &ENTRY_LICENSE_13648883593492983919),
            (0b11010, &ENTRY_LICENSE_7596905334721482195),
        ],
        &[(0b00010, &ENTRY_LICENSED_14395065230293106933)],
        &[(0b11010, &ENTRY_LICENSELESS_8185181790778718082)],
        &[(0b11010, &ENTRY_LICENSELESSES_13483570119205630906)],
        &[
            (0b00010, &ENTRY_LICENSES_11713770293156064365),
            (0b11010, &ENTRY_LICENSES_9473213132468022469),
        ],
        &[(0b00010, &ENTRY_LICENSING_15278454752495763579)],
        &[(0b00001, &ENTRY_LICENSELESS_8185181790778718082)],
        &[(0b00001, &ENTRY_LICENSELESSES_13483570119205630906)],
        &[(0b10010, &ENTRY_LICHENIZATION_15535665386017437615)],
        &[(0b10010, &ENTRY_LICHENIZATIONS_229879429336509734)],
        &[(0b10010, &ENTRY_LICHENIZE_1218523330923020826)],
        &[(0b10010, &ENTRY_LICHENIZED_9848778117506730557)],
        &[(0b10010, &ENTRY_LICHENIZES_10045103594318910049)],
        &[(0b10010, &ENTRY_LICHENIZING_4675116376139174902)],
        &[(0b01001, &ENTRY_LICHENIZATION_15535665386017437615)],
        &[(0b01001, &ENTRY_LICHENIZATIONS_229879429336509734)],
        &[(0b01001, &ENTRY_LICHENIZE_1218523330923020826)],
        &[(0b01001, &ENTRY_LICHENIZED_9848778117506730557)],
        &[(0b01001, &ENTRY_LICHENIZES_10045103594318910049)],
        &[(0b01001, &ENTRY_LICHENIZING_4675116376139174902)],
        &[(0b11001, &ENTRY_LICORICE_6514036211352134052)],
    ],
    range: 4..=11,
};

static VARS_LIB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LIB_CHILDREN),
    value: None,
};

pub static VARS_LIB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elant"),
        dictgen::InsensitiveStr::Ascii("elants"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("elee"),
        dictgen::InsensitiveStr::Ascii("elees"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("ellant"),
        dictgen::InsensitiveStr::Ascii("ellants"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("ellee"),
        dictgen::InsensitiveStr::Ascii("ellees"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellous"),
        dictgen::InsensitiveStr::Ascii("ellouser"),
        dictgen::InsensitiveStr::Ascii("ellousest"),
        dictgen::InsensitiveStr::Ascii("ellouslier"),
        dictgen::InsensitiveStr::Ascii("ellousliest"),
        dictgen::InsensitiveStr::Ascii("ellously"),
        dictgen::InsensitiveStr::Ascii("elous"),
        dictgen::InsensitiveStr::Ascii("elouser"),
        dictgen::InsensitiveStr::Ascii("elousest"),
        dictgen::InsensitiveStr::Ascii("elouslier"),
        dictgen::InsensitiveStr::Ascii("elousliest"),
        dictgen::InsensitiveStr::Ascii("elously"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralised"),
        dictgen::InsensitiveStr::Ascii("eraliser"),
        dictgen::InsensitiveStr::Ascii("eralisers"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralising"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralized"),
        dictgen::InsensitiveStr::Ascii("eralizer"),
        dictgen::InsensitiveStr::Ascii("eralizers"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("eralizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LIBELANT_18318555049160704401)],
        &[(0b00001, &ENTRY_LIBELANTS_18272012151164220579)],
        &[(0b00001, &ENTRY_LIBELED_4865225818350414783)],
        &[(0b00001, &ENTRY_LIBELEE_6476421574039775301)],
        &[(0b00001, &ENTRY_LIBELEES_18236853938926152502)],
        &[(0b00001, &ENTRY_LIBELER_17085228261817297321)],
        &[(0b00001, &ENTRY_LIBELERS_7579436350106243412)],
        &[(0b00001, &ENTRY_LIBELING_8308337792295462824)],
        &[(0b11010, &ENTRY_LIBELANT_18318555049160704401)],
        &[(0b11010, &ENTRY_LIBELANTS_18272012151164220579)],
        &[(0b11010, &ENTRY_LIBELED_4865225818350414783)],
        &[(0b11010, &ENTRY_LIBELEE_6476421574039775301)],
        &[(0b11010, &ENTRY_LIBELEES_18236853938926152502)],
        &[(0b11010, &ENTRY_LIBELER_17085228261817297321)],
        &[(0b11010, &ENTRY_LIBELERS_7579436350106243412)],
        &[(0b11010, &ENTRY_LIBELING_8308337792295462824)],
        &[(0b11010, &ENTRY_LIBELOUS_13707976000878000987)],
        &[(0b11010, &ENTRY_LIBELOUSER_15753313718045269506)],
        &[(0b11010, &ENTRY_LIBELOUSEST_12981542005689062528)],
        &[(0b11010, &ENTRY_LIBELOUSLIER_9957797103251569597)],
        &[(0b11010, &ENTRY_LIBELOUSLIEST_16123024350035836990)],
        &[(0b11010, &ENTRY_LIBELOUSLY_5989552200231943704)],
        &[(0b01001, &ENTRY_LIBELOUS_13707976000878000987)],
        &[(0b01001, &ENTRY_LIBELOUSER_15753313718045269506)],
        &[(0b01001, &ENTRY_LIBELOUSEST_12981542005689062528)],
        &[(0b00001, &ENTRY_LIBELOUSLIER_9957797103251569597)],
        &[(0b00001, &ENTRY_LIBELOUSLIEST_16123024350035836990)],
        &[(0b00001, &ENTRY_LIBELOUSLY_5989552200231943704)],
        &[(0b10010, &ENTRY_LIBERALIZATION_17550369075193850663)],
        &[(0b10010, &ENTRY_LIBERALIZATIONS_13791189277975585532)],
        &[(0b10010, &ENTRY_LIBERALIZE_18317297344527312130)],
        &[(0b10010, &ENTRY_LIBERALIZED_14395627173650056412)],
        &[(0b10010, &ENTRY_LIBERALIZER_12070318024950362610)],
        &[(0b10010, &ENTRY_LIBERALIZERS_2604457956948553415)],
        &[(0b10010, &ENTRY_LIBERALIZES_4445826847051855517)],
        &[(0b10010, &ENTRY_LIBERALIZING_12962394088879054166)],
        &[(0b01001, &ENTRY_LIBERALIZATION_17550369075193850663)],
        &[(0b01001, &ENTRY_LIBERALIZATIONS_13791189277975585532)],
        &[(0b01001, &ENTRY_LIBERALIZE_18317297344527312130)],
        &[(0b01001, &ENTRY_LIBERALIZED_14395627173650056412)],
        &[(0b01001, &ENTRY_LIBERALIZER_12070318024950362610)],
        &[(0b01001, &ENTRY_LIBERALIZERS_2604457956948553415)],
        &[(0b01001, &ENTRY_LIBERALIZES_4445826847051855517)],
        &[(0b01001, &ENTRY_LIBERALIZING_12962394088879054166)],
    ],
    range: 4..=12,
};

static VARS_LE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LE_CHILDREN),
    value: None,
};

static VARS_LE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_LEA_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LEG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LEM_NODE),
    None,
    None,
    Some(&VARS_LEP_NODE),
    None,
    Some(&VARS_LER_NODE),
    Some(&VARS_LES_NODE),
    Some(&VARS_LET_NODE),
    Some(&VARS_LEU_NODE),
    Some(&VARS_LEV_NODE),
    None,
    Some(&VARS_LEX_NODE),
    None,
    None,
];

static VARS_LEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEX_CHILDREN),
    value: None,
};

pub static VARS_LEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icalisation"),
        dictgen::InsensitiveStr::Ascii("icalisations"),
        dictgen::InsensitiveStr::Ascii("icalization"),
        dictgen::InsensitiveStr::Ascii("icalizations"),
        dictgen::InsensitiveStr::Ascii("iconise"),
        dictgen::InsensitiveStr::Ascii("iconises"),
        dictgen::InsensitiveStr::Ascii("iconize"),
        dictgen::InsensitiveStr::Ascii("iconizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LEXICALIZATION_17354516794688165566)],
        &[(0b10010, &ENTRY_LEXICALIZATIONS_4279807953147321913)],
        &[(0b01001, &ENTRY_LEXICALIZATION_17354516794688165566)],
        &[(0b01001, &ENTRY_LEXICALIZATIONS_4279807953147321913)],
        &[(0b10010, &ENTRY_LEXICONIZE_11609885077010802762)],
        &[(0b10010, &ENTRY_LEXICONIZES_9557853906422825830)],
        &[(0b01001, &ENTRY_LEXICONIZE_11609885077010802762)],
        &[(0b01001, &ENTRY_LEXICONIZES_9557853906422825830)],
    ],
    range: 7..=12,
};

static VARS_LEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEV_CHILDREN),
    value: None,
};

pub static VARS_LEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("elest"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("ellest"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("igate"),
        dictgen::InsensitiveStr::Ascii("igated"),
        dictgen::InsensitiveStr::Ascii("igates"),
        dictgen::InsensitiveStr::Ascii("igating"),
        dictgen::InsensitiveStr::Ascii("o"),
        dictgen::InsensitiveStr::Ascii("oduction"),
        dictgen::InsensitiveStr::Ascii("ogyrate"),
        dictgen::InsensitiveStr::Ascii("ogyre"),
        dictgen::InsensitiveStr::Ascii("ogyrous"),
        dictgen::InsensitiveStr::Ascii("olactic"),
        dictgen::InsensitiveStr::Ascii("orotation"),
        dictgen::InsensitiveStr::Ascii("orotations"),
        dictgen::InsensitiveStr::Ascii("orotatory"),
        dictgen::InsensitiveStr::Ascii("otartaric"),
        dictgen::InsensitiveStr::Ascii("oversion"),
        dictgen::InsensitiveStr::Ascii("ulin"),
        dictgen::InsensitiveStr::Ascii("ulose"),
        dictgen::InsensitiveStr::Ascii("uloses"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LEVELED_9665469910971131982)],
        &[(0b00001, &ENTRY_LEVELER_2582561187239213328)],
        &[(0b00001, &ENTRY_LEVELERS_15007791514111643804)],
        &[(0b00001, &ENTRY_LEVELEST_7275123473754767283)],
        &[(0b00001, &ENTRY_LEVELING_2449494232626797630)],
        &[(0b11010, &ENTRY_LEVELED_9665469910971131982)],
        &[(0b11010, &ENTRY_LEVELER_2582561187239213328)],
        &[(0b11010, &ENTRY_LEVELERS_15007791514111643804)],
        &[(0b11010, &ENTRY_LEVELEST_7275123473754767283)],
        &[(0b11010, &ENTRY_LEVELING_2449494232626797630)],
        &[(0b00001, &ENTRY_LEVIGATE_15789706620200322738)],
        &[(0b00001, &ENTRY_LEVIGATED_14877617934398376831)],
        &[(0b00001, &ENTRY_LEVIGATES_16135071688652531978)],
        &[(0b00001, &ENTRY_LEVIGATING_1174558288799674979)],
        &[(0b00001, &ENTRY_LEVO_14542258720001517914)],
        &[(0b00001, &ENTRY_LEVODUCTION_2148814985181413340)],
        &[(0b00001, &ENTRY_LEVOGYRATE_6763119482929043236)],
        &[(0b00001, &ENTRY_LEVOGYRE_5734860870890360841)],
        &[(0b00001, &ENTRY_LEVOGYROUS_6451272270897908077)],
        &[(0b00001, &ENTRY_LEVOLACTIC_9857925753879522136)],
        &[(0b00001, &ENTRY_LEVOROTATION_10477206558920364209)],
        &[(0b00001, &ENTRY_LEVOROTATIONS_13418481525546457918)],
        &[(0b00001, &ENTRY_LEVOROTATORY_10540472502808384816)],
        &[(0b00001, &ENTRY_LEVOTARTARIC_11386421058271291462)],
        &[(0b00001, &ENTRY_LEVOVERSION_15070501857515106835)],
        &[(0b00001, &ENTRY_LEVULIN_17574134793411636672)],
        &[(0b00001, &ENTRY_LEVULOSE_15099852399033494000)],
        &[(0b00001, &ENTRY_LEVULOSES_14491948310541911092)],
    ],
    range: 1..=10,
};

static VARS_LEU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEU_CHILDREN),
    value: None,
};

pub static VARS_LEU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caemia"),
        dictgen::InsensitiveStr::Ascii("caemias"),
        dictgen::InsensitiveStr::Ascii("caemic"),
        dictgen::InsensitiveStr::Ascii("cemia"),
        dictgen::InsensitiveStr::Ascii("cemias"),
        dictgen::InsensitiveStr::Ascii("cemic"),
        dictgen::InsensitiveStr::Ascii("chaemia"),
        dictgen::InsensitiveStr::Ascii("chemia"),
        dictgen::InsensitiveStr::Ascii("cocythaemia"),
        dictgen::InsensitiveStr::Ascii("cocythaemic"),
        dictgen::InsensitiveStr::Ascii("cocythemia"),
        dictgen::InsensitiveStr::Ascii("cocythemic"),
        dictgen::InsensitiveStr::Ascii("corrhea"),
        dictgen::InsensitiveStr::Ascii("corrheal"),
        dictgen::InsensitiveStr::Ascii("corrheas"),
        dictgen::InsensitiveStr::Ascii("corrhoea"),
        dictgen::InsensitiveStr::Ascii("corrhoeal"),
        dictgen::InsensitiveStr::Ascii("corrhoeas"),
        dictgen::InsensitiveStr::Ascii("cothoae"),
        dictgen::InsensitiveStr::Ascii("cothoe"),
        dictgen::InsensitiveStr::Ascii("kaemia"),
        dictgen::InsensitiveStr::Ascii("kaemias"),
        dictgen::InsensitiveStr::Ascii("kaemogeneses"),
        dictgen::InsensitiveStr::Ascii("kaemogenesis"),
        dictgen::InsensitiveStr::Ascii("kemia"),
        dictgen::InsensitiveStr::Ascii("kemias"),
        dictgen::InsensitiveStr::Ascii("kemogeneses"),
        dictgen::InsensitiveStr::Ascii("kemogenesis"),
        dictgen::InsensitiveStr::Ascii("korrhea"),
        dictgen::InsensitiveStr::Ascii("korrheal"),
        dictgen::InsensitiveStr::Ascii("korrhoea"),
        dictgen::InsensitiveStr::Ascii("korrhoeal"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LEUCEMIA_3591351451144568006)],
        &[(0b11010, &ENTRY_LEUCEMIAS_11620167304888335008)],
        &[(0b11010, &ENTRY_LEUCEMIC_4805425255684968634)],
        &[(0b00001, &ENTRY_LEUCEMIA_3591351451144568006)],
        &[(0b00001, &ENTRY_LEUCEMIAS_11620167304888335008)],
        &[(0b00001, &ENTRY_LEUCEMIC_4805425255684968634)],
        &[(0b11010, &ENTRY_LEUCHEMIA_17930526525127388484)],
        &[(0b00001, &ENTRY_LEUCHEMIA_17930526525127388484)],
        &[(0b11010, &ENTRY_LEUCOCYTHEMIA_6949077817963406299)],
        &[(0b11010, &ENTRY_LEUCOCYTHEMIC_10797182314528433809)],
        &[(0b00001, &ENTRY_LEUCOCYTHEMIA_6949077817963406299)],
        &[(0b00001, &ENTRY_LEUCOCYTHEMIC_10797182314528433809)],
        &[(0b00001, &ENTRY_LEUCORRHEA_12491143111744908996)],
        &[(0b00001, &ENTRY_LEUCORRHEAL_2096260838462933156)],
        &[(0b00001, &ENTRY_LEUCORRHEAS_12147874623824130705)],
        &[(0b11010, &ENTRY_LEUCORRHEA_12491143111744908996)],
        &[(0b11010, &ENTRY_LEUCORRHEAL_2096260838462933156)],
        &[(0b11010, &ENTRY_LEUCORRHEAS_12147874623824130705)],
        &[(0b11010, &ENTRY_LEUCOTHOE_11629376781492715609)],
        &[(0b00001, &ENTRY_LEUCOTHOE_11629376781492715609)],
        &[(0b10010, &ENTRY_LEUKEMIA_6916516802276369860)],
        &[(0b10010, &ENTRY_LEUKEMIAS_18410750728698403884)],
        &[(0b11010, &ENTRY_LEUKEMOGENESES_2038159065666272579)],
        &[(0b11010, &ENTRY_LEUKEMOGENESIS_10527747651487262766)],
        &[(0b11001, &ENTRY_LEUKEMIA_6916516802276369860)],
        &[(0b11001, &ENTRY_LEUKEMIAS_18410750728698403884)],
        &[(0b10001, &ENTRY_LEUKEMOGENESES_2038159065666272579)],
        &[(0b10001, &ENTRY_LEUKEMOGENESIS_10527747651487262766)],
        &[(0b10001, &ENTRY_LEUKORRHEA_13781381900549484928)],
        &[(0b10001, &ENTRY_LEUKORRHEAL_14955176177356699707)],
        &[(0b11010, &ENTRY_LEUKORRHEA_13781381900549484928)],
        &[(0b11010, &ENTRY_LEUKORRHEAL_14955176177356699707)],
    ],
    range: 5..=12,
};

static VARS_LET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LET_CHILDREN),
    value: None,
};

pub static VARS_LET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("halise"),
        dictgen::InsensitiveStr::Ascii("halises"),
        dictgen::InsensitiveStr::Ascii("halize"),
        dictgen::InsensitiveStr::Ascii("halizes"),
        dictgen::InsensitiveStr::Ascii("hargise"),
        dictgen::InsensitiveStr::Ascii("hargised"),
        dictgen::InsensitiveStr::Ascii("hargises"),
        dictgen::InsensitiveStr::Ascii("hargising"),
        dictgen::InsensitiveStr::Ascii("hargize"),
        dictgen::InsensitiveStr::Ascii("hargized"),
        dictgen::InsensitiveStr::Ascii("hargizes"),
        dictgen::InsensitiveStr::Ascii("hargizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LETHALIZE_10150294278227484131)],
        &[(0b10010, &ENTRY_LETHALIZES_134641715057728302)],
        &[(0b01001, &ENTRY_LETHALIZE_10150294278227484131)],
        &[(0b01001, &ENTRY_LETHALIZES_134641715057728302)],
        &[(0b10010, &ENTRY_LETHARGIZE_16053857967216252311)],
        &[(0b10010, &ENTRY_LETHARGIZED_4660767625773446412)],
        &[(0b10010, &ENTRY_LETHARGIZES_9871489060060101043)],
        &[(0b10010, &ENTRY_LETHARGIZING_5842943436072891536)],
        &[(0b01001, &ENTRY_LETHARGIZE_16053857967216252311)],
        &[(0b01001, &ENTRY_LETHARGIZED_4660767625773446412)],
        &[(0b01001, &ENTRY_LETHARGIZES_9871489060060101043)],
        &[(0b01001, &ENTRY_LETHARGIZING_5842943436072891536)],
    ],
    range: 6..=9,
};

static VARS_LES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LES_CHILDREN),
    value: None,
};

pub static VARS_LES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ses")],
    values: &[&[(0b00001, &ENTRY_LESSES_11253910437625016547)]],
    range: 3..=3,
};

static VARS_LER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LER_CHILDREN),
    value: None,
};

pub static VARS_LER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("naean"),
        dictgen::InsensitiveStr::Ascii("nean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LERNEAN_14411886954119894826)],
        &[(0b00001, &ENTRY_LERNEAN_14411886954119894826)],
    ],
    range: 4..=5,
};

static VARS_LEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEP_CHILDREN),
    value: None,
};

pub static VARS_LEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oridae"),
        dictgen::InsensitiveStr::Ascii("oride"),
        dictgen::InsensitiveStr::Ascii("tospirae"),
        dictgen::InsensitiveStr::Ascii("tospire"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LEPORIDE_16261088283625577770)],
        &[(0b00001, &ENTRY_LEPORIDE_16261088283625577770)],
        &[(0b11010, &ENTRY_LEPTOSPIRE_8197818469635415334)],
        &[(0b00001, &ENTRY_LEPTOSPIRE_8197818469635415334)],
    ],
    range: 5..=8,
};

static VARS_LEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEM_CHILDREN),
    value: None,
};

pub static VARS_LEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LEMMATIZE_11040947247935760208)],
        &[(0b10010, &ENTRY_LEMMATIZED_18039523576098850991)],
        &[(0b10010, &ENTRY_LEMMATIZES_9200074086732700201)],
        &[(0b10010, &ENTRY_LEMMATIZING_9177369908160152532)],
        &[(0b01001, &ENTRY_LEMMATIZE_11040947247935760208)],
        &[(0b01001, &ENTRY_LEMMATIZED_18039523576098850991)],
        &[(0b01001, &ENTRY_LEMMATIZES_9200074086732700201)],
        &[(0b01001, &ENTRY_LEMMATIZING_9177369908160152532)],
    ],
    range: 6..=8,
};

static VARS_LEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEG_CHILDREN),
    value: None,
};

pub static VARS_LEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("gin"),
        dictgen::InsensitiveStr::Ascii("gins"),
        dictgen::InsensitiveStr::Ascii("itimatise"),
        dictgen::InsensitiveStr::Ascii("itimatised"),
        dictgen::InsensitiveStr::Ascii("itimatises"),
        dictgen::InsensitiveStr::Ascii("itimatising"),
        dictgen::InsensitiveStr::Ascii("itimatize"),
        dictgen::InsensitiveStr::Ascii("itimatized"),
        dictgen::InsensitiveStr::Ascii("itimatizes"),
        dictgen::InsensitiveStr::Ascii("itimatizing"),
        dictgen::InsensitiveStr::Ascii("itimisation"),
        dictgen::InsensitiveStr::Ascii("itimisations"),
        dictgen::InsensitiveStr::Ascii("itimise"),
        dictgen::InsensitiveStr::Ascii("itimised"),
        dictgen::InsensitiveStr::Ascii("itimiser"),
        dictgen::InsensitiveStr::Ascii("itimises"),
        dictgen::InsensitiveStr::Ascii("itimising"),
        dictgen::InsensitiveStr::Ascii("itimization"),
        dictgen::InsensitiveStr::Ascii("itimizations"),
        dictgen::InsensitiveStr::Ascii("itimize"),
        dictgen::InsensitiveStr::Ascii("itimized"),
        dictgen::InsensitiveStr::Ascii("itimizer"),
        dictgen::InsensitiveStr::Ascii("itimizes"),
        dictgen::InsensitiveStr::Ascii("itimizing"),
        dictgen::InsensitiveStr::Ascii("uminosae"),
        dictgen::InsensitiveStr::Ascii("uminose"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LEGALIZATION_1429633233340705019)],
        &[(0b10010, &ENTRY_LEGALIZATIONS_5135517055405810830)],
        &[(0b10010, &ENTRY_LEGALIZE_6922384620678227608)],
        &[(0b10010, &ENTRY_LEGALIZED_12578108449353920177)],
        &[(0b10010, &ENTRY_LEGALIZES_8869300296267545710)],
        &[(0b10010, &ENTRY_LEGALIZING_12535342459582465870)],
        &[(0b01001, &ENTRY_LEGALIZATION_1429633233340705019)],
        &[(0b01001, &ENTRY_LEGALIZATIONS_5135517055405810830)],
        &[(0b01001, &ENTRY_LEGALIZE_6922384620678227608)],
        &[(0b01001, &ENTRY_LEGALIZED_12578108449353920177)],
        &[(0b01001, &ENTRY_LEGALIZES_8869300296267545710)],
        &[(0b01001, &ENTRY_LEGALIZING_12535342459582465870)],
        &[(0b00001, &ENTRY_LEGGING_2988486252228985931)],
        &[(0b00001, &ENTRY_LEGGINGS_9393944049752516352)],
        &[(0b10010, &ENTRY_LEGITIMATIZE_14030890652940162105)],
        &[(0b10010, &ENTRY_LEGITIMATIZED_9454437080445749766)],
        &[(0b10010, &ENTRY_LEGITIMATIZES_4219244495979276250)],
        &[(0b10010, &ENTRY_LEGITIMATIZING_18056063115160381137)],
        &[(0b01001, &ENTRY_LEGITIMATIZE_14030890652940162105)],
        &[(0b01001, &ENTRY_LEGITIMATIZED_9454437080445749766)],
        &[(0b01001, &ENTRY_LEGITIMATIZES_4219244495979276250)],
        &[(0b01001, &ENTRY_LEGITIMATIZING_18056063115160381137)],
        &[(0b10010, &ENTRY_LEGITIMIZATION_14065712783120219782)],
        &[(0b10010, &ENTRY_LEGITIMIZATIONS_3098730780220248274)],
        &[(0b10010, &ENTRY_LEGITIMIZE_6363531271843865015)],
        &[(0b10010, &ENTRY_LEGITIMIZED_2017894209000906860)],
        &[(0b10010, &ENTRY_LEGITIMIZER_17472185937284492353)],
        &[(0b10010, &ENTRY_LEGITIMIZES_8915844240859951340)],
        &[(0b10010, &ENTRY_LEGITIMIZING_1120958333215572753)],
        &[(0b01001, &ENTRY_LEGITIMIZATION_14065712783120219782)],
        &[(0b01001, &ENTRY_LEGITIMIZATIONS_3098730780220248274)],
        &[(0b01001, &ENTRY_LEGITIMIZE_6363531271843865015)],
        &[(0b01001, &ENTRY_LEGITIMIZED_2017894209000906860)],
        &[(0b01001, &ENTRY_LEGITIMIZER_17472185937284492353)],
        &[(0b01001, &ENTRY_LEGITIMIZES_8915844240859951340)],
        &[(0b01001, &ENTRY_LEGITIMIZING_1120958333215572753)],
        &[(0b11010, &ENTRY_LEGUMINOSE_13351579956836938693)],
        &[(0b00001, &ENTRY_LEGUMINOSE_13351579956836938693)],
    ],
    range: 3..=12,
};

static VARS_LEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LEA_CHILDREN),
    value: None,
};

pub static VARS_LEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rnt"),
        dictgen::InsensitiveStr::Ascii("therise"),
        dictgen::InsensitiveStr::Ascii("therises"),
        dictgen::InsensitiveStr::Ascii("therize"),
        dictgen::InsensitiveStr::Ascii("therizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LEARNED_3077939307038472575)],
        &[(0b10010, &ENTRY_LEATHERIZE_17693739748797908774)],
        &[(0b10010, &ENTRY_LEATHERIZES_10078929234890753420)],
        &[(0b01001, &ENTRY_LEATHERIZE_17693739748797908774)],
        &[(0b01001, &ENTRY_LEATHERIZES_10078929234890753420)],
    ],
    range: 3..=8,
};

static VARS_LA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LA_CHILDREN),
    value: None,
};

static VARS_LA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_LAB_NODE),
    Some(&VARS_LAC_NODE),
    None,
    Some(&VARS_LAE_NODE),
    None,
    None,
    None,
    Some(&VARS_LAI_NODE),
    None,
    None,
    None,
    Some(&VARS_LAM_NODE),
    Some(&VARS_LAN_NODE),
    Some(&VARS_LAO_NODE),
    Some(&VARS_LAP_NODE),
    None,
    None,
    Some(&VARS_LAS_NODE),
    Some(&VARS_LAT_NODE),
    Some(&VARS_LAU_NODE),
    Some(&VARS_LAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_LAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAV_CHILDREN),
    value: None,
};

pub static VARS_LAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oltaed"),
        dictgen::InsensitiveStr::Ascii("olted"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LAVOLTED_5688164088762295019)],
        &[(0b00001, &ENTRY_LAVOLTED_5688164088762295019)],
    ],
    range: 5..=6,
};

static VARS_LAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAU_CHILDREN),
    value: None,
};

pub static VARS_LAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rae"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("reled"),
        dictgen::InsensitiveStr::Ascii("reling"),
        dictgen::InsensitiveStr::Ascii("relled"),
        dictgen::InsensitiveStr::Ascii("relling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LAURE_841157505029689756)],
        &[(0b00001, &ENTRY_LAURE_841157505029689756)],
        &[(0b00001, &ENTRY_LAURELED_11054307884791506795)],
        &[(0b00001, &ENTRY_LAURELING_6770137311186276589)],
        &[(0b11010, &ENTRY_LAURELED_11054307884791506795)],
        &[(0b11010, &ENTRY_LAURELING_6770137311186276589)],
    ],
    range: 2..=7,
};

static VARS_LAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAT_CHILDREN),
    value: None,
};

pub static VARS_LAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entise"),
        dictgen::InsensitiveStr::Ascii("entises"),
        dictgen::InsensitiveStr::Ascii("entize"),
        dictgen::InsensitiveStr::Ascii("entizes"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("iniser"),
        dictgen::InsensitiveStr::Ascii("inisers"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizer"),
        dictgen::InsensitiveStr::Ascii("inizers"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LATENTIZE_5719415759703874116)],
        &[(0b10010, &ENTRY_LATENTIZES_7861370147610510510)],
        &[(0b01001, &ENTRY_LATENTIZE_5719415759703874116)],
        &[(0b01001, &ENTRY_LATENTIZES_7861370147610510510)],
        &[(0b10010, &ENTRY_LATERALIZATION_8041407149896392073)],
        &[(0b10010, &ENTRY_LATERALIZATIONS_6289621742941669396)],
        &[(0b10010, &ENTRY_LATERALIZE_2072178859776576442)],
        &[(0b10010, &ENTRY_LATERALIZES_7420128468824420970)],
        &[(0b01001, &ENTRY_LATERALIZATION_8041407149896392073)],
        &[(0b01001, &ENTRY_LATERALIZATIONS_6289621742941669396)],
        &[(0b01001, &ENTRY_LATERALIZE_2072178859776576442)],
        &[(0b01001, &ENTRY_LATERALIZES_7420128468824420970)],
        &[(0b10010, &ENTRY_LATERIZATION_5173633169061109866)],
        &[(0b10010, &ENTRY_LATERIZATIONS_7796215490525515758)],
        &[(0b01001, &ENTRY_LATERIZATION_5173633169061109866)],
        &[(0b01001, &ENTRY_LATERIZATIONS_7796215490525515758)],
        &[(0b10010, &ENTRY_LATINIZATION_13723120966984203012)],
        &[(0b10010, &ENTRY_LATINIZATIONS_3054889801589359637)],
        &[(0b10010, &ENTRY_LATINIZE_3439115749934719092)],
        &[(0b10010, &ENTRY_LATINIZED_7003535688978595675)],
        &[(0b10010, &ENTRY_LATINIZER_2058053073644883801)],
        &[(0b10010, &ENTRY_LATINIZERS_5843855516266216328)],
        &[(0b10010, &ENTRY_LATINIZES_12697197510060274526)],
        &[(0b10010, &ENTRY_LATINIZING_2597326847289767095)],
        &[(0b01001, &ENTRY_LATINIZATION_13723120966984203012)],
        &[(0b01001, &ENTRY_LATINIZATIONS_3054889801589359637)],
        &[(0b01001, &ENTRY_LATINIZE_3439115749934719092)],
        &[(0b01001, &ENTRY_LATINIZED_7003535688978595675)],
        &[(0b01001, &ENTRY_LATINIZER_2058053073644883801)],
        &[(0b01001, &ENTRY_LATINIZERS_5843855516266216328)],
        &[(0b01001, &ENTRY_LATINIZES_12697197510060274526)],
        &[(0b01001, &ENTRY_LATINIZING_2597326847289767095)],
    ],
    range: 5..=12,
};

static VARS_LAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAS_CHILDREN),
    value: None,
};

pub static VARS_LAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agne"),
        dictgen::InsensitiveStr::Ascii("agnes"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LASAGNA_12331136899588325414)],
        &[(0b11010, &ENTRY_LASAGNAS_17494101204628860125)],
        &[(0b00001, &ENTRY_LASTER_5242258785041708124)],
        &[(0b11010, &ENTRY_LASTER_5242258785041708124)],
    ],
    range: 3..=5,
};

static VARS_LAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAP_CHILDREN),
    value: None,
};

pub static VARS_LAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("elled"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LAPELED_3965699421712198651)],
        &[(0b11010, &ENTRY_LAPELED_3965699421712198651)],
    ],
    range: 4..=5,
};

static VARS_LAO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAO_CHILDREN),
    value: None,
};

pub static VARS_LAO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thoae"),
        dictgen::InsensitiveStr::Ascii("thoe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LAOTHOE_7381095044467675447)],
        &[(0b00001, &ENTRY_LAOTHOE_7381095044467675447)],
    ],
    range: 4..=5,
};

static VARS_LAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAN_CHILDREN),
    value: None,
};

pub static VARS_LAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("der"),
        dictgen::InsensitiveStr::Ascii("dre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LANDER_14344486190119467949)],
        &[(0b11010, &ENTRY_LANDER_14344486190119467949)],
    ],
    range: 3..=3,
};

static VARS_LAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAM_CHILDREN),
    value: None,
};

pub static VARS_LAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("inarise"),
        dictgen::InsensitiveStr::Ascii("inarised"),
        dictgen::InsensitiveStr::Ascii("inarises"),
        dictgen::InsensitiveStr::Ascii("inarising"),
        dictgen::InsensitiveStr::Ascii("inarize"),
        dictgen::InsensitiveStr::Ascii("inarized"),
        dictgen::InsensitiveStr::Ascii("inarizes"),
        dictgen::InsensitiveStr::Ascii("inarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LAMINARIZE_1889106193228655985)],
        &[(0b10010, &ENTRY_LAMINARIZED_1016333654497584825)],
        &[(0b10010, &ENTRY_LAMINARIZES_14511387789417490165)],
        &[(0b10010, &ENTRY_LAMINARIZING_13590610923176310804)],
        &[(0b01001, &ENTRY_LAMINARIZE_1889106193228655985)],
        &[(0b01001, &ENTRY_LAMINARIZED_1016333654497584825)],
        &[(0b01001, &ENTRY_LAMINARIZES_14511387789417490165)],
        &[(0b01001, &ENTRY_LAMINARIZING_13590610923176310804)],
    ],
    range: 7..=9,
};

static VARS_LAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAI_CHILDREN),
    value: None,
};

pub static VARS_LAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cisation"),
        dictgen::InsensitiveStr::Ascii("cisations"),
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cised"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cising"),
        dictgen::InsensitiveStr::Ascii("cization"),
        dictgen::InsensitiveStr::Ascii("cizations"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cized"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("cizing"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LAICIZATION_6195007678259612522)],
        &[(0b10010, &ENTRY_LAICIZATIONS_6800567689500405023)],
        &[(0b10010, &ENTRY_LAICIZE_11308741029398318200)],
        &[(0b10010, &ENTRY_LAICIZED_2509011185101191888)],
        &[(0b10010, &ENTRY_LAICIZES_3370790220822496415)],
        &[(0b10010, &ENTRY_LAICIZING_4716979153325135165)],
        &[(0b01001, &ENTRY_LAICIZATION_6195007678259612522)],
        &[(0b01001, &ENTRY_LAICIZATIONS_6800567689500405023)],
        &[(0b01001, &ENTRY_LAICIZE_11308741029398318200)],
        &[(0b01001, &ENTRY_LAICIZED_2509011185101191888)],
        &[(0b01001, &ENTRY_LAICIZES_3370790220822496415)],
        &[(0b01001, &ENTRY_LAICIZING_4716979153325135165)],
        &[(0b10010, &ENTRY_LAIRIZE_17048626001120383827)],
        &[(0b10010, &ENTRY_LAIRIZED_6580351855883704967)],
        &[(0b10010, &ENTRY_LAIRIZES_16624623563786533004)],
        &[(0b10010, &ENTRY_LAIRIZING_4521292118527414337)],
        &[(0b01001, &ENTRY_LAIRIZE_17048626001120383827)],
        &[(0b01001, &ENTRY_LAIRIZED_6580351855883704967)],
        &[(0b01001, &ENTRY_LAIRIZES_16624623563786533004)],
        &[(0b01001, &ENTRY_LAIRIZING_4521292118527414337)],
    ],
    range: 4..=9,
};

static VARS_LAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAE_CHILDREN),
    value: None,
};

pub static VARS_LAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("vigate"),
        dictgen::InsensitiveStr::Ascii("vigated"),
        dictgen::InsensitiveStr::Ascii("vigates"),
        dictgen::InsensitiveStr::Ascii("vigating"),
        dictgen::InsensitiveStr::Ascii("vo"),
        dictgen::InsensitiveStr::Ascii("voduction"),
        dictgen::InsensitiveStr::Ascii("vogyrate"),
        dictgen::InsensitiveStr::Ascii("vogyre"),
        dictgen::InsensitiveStr::Ascii("vogyrous"),
        dictgen::InsensitiveStr::Ascii("volactic"),
        dictgen::InsensitiveStr::Ascii("vorotation"),
        dictgen::InsensitiveStr::Ascii("vorotations"),
        dictgen::InsensitiveStr::Ascii("vorotatory"),
        dictgen::InsensitiveStr::Ascii("votartaric"),
        dictgen::InsensitiveStr::Ascii("voversion"),
        dictgen::InsensitiveStr::Ascii("vulin"),
        dictgen::InsensitiveStr::Ascii("vulose"),
        dictgen::InsensitiveStr::Ascii("vuloses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LEVIGATE_15789706620200322738)],
        &[(0b11010, &ENTRY_LEVIGATED_14877617934398376831)],
        &[(0b11010, &ENTRY_LEVIGATES_16135071688652531978)],
        &[(0b11010, &ENTRY_LEVIGATING_1174558288799674979)],
        &[(0b11010, &ENTRY_LEVO_14542258720001517914)],
        &[(0b11010, &ENTRY_LEVODUCTION_2148814985181413340)],
        &[(0b11010, &ENTRY_LEVOGYRATE_6763119482929043236)],
        &[(0b11010, &ENTRY_LEVOGYRE_5734860870890360841)],
        &[(0b11010, &ENTRY_LEVOGYROUS_6451272270897908077)],
        &[(0b11010, &ENTRY_LEVOLACTIC_9857925753879522136)],
        &[(0b11010, &ENTRY_LEVOROTATION_10477206558920364209)],
        &[(0b11010, &ENTRY_LEVOROTATIONS_13418481525546457918)],
        &[(0b11010, &ENTRY_LEVOROTATORY_10540472502808384816)],
        &[(0b11010, &ENTRY_LEVOTARTARIC_11386421058271291462)],
        &[(0b11010, &ENTRY_LEVOVERSION_15070501857515106835)],
        &[(0b11010, &ENTRY_LEVULIN_17574134793411636672)],
        &[(0b11010, &ENTRY_LEVULOSE_15099852399033494000)],
        &[(0b11010, &ENTRY_LEVULOSES_14491948310541911092)],
    ],
    range: 2..=11,
};

static VARS_LAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LAC_CHILDREN),
    value: None,
};

pub static VARS_LAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("kluster"),
        dictgen::InsensitiveStr::Ascii("klusterrer"),
        dictgen::InsensitiveStr::Ascii("klusterrest"),
        dictgen::InsensitiveStr::Ascii("klusters"),
        dictgen::InsensitiveStr::Ascii("klustre"),
        dictgen::InsensitiveStr::Ascii("klustrer"),
        dictgen::InsensitiveStr::Ascii("klustres"),
        dictgen::InsensitiveStr::Ascii("klustrest"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("tonised"),
        dictgen::InsensitiveStr::Ascii("tonized"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LACKLUSTER_2494503323799670808)],
        &[(0b00001, &ENTRY_LACKLUSTERRER_10237849134270314093)],
        &[(0b00001, &ENTRY_LACKLUSTERREST_17124785842338778470)],
        &[(0b00001, &ENTRY_LACKLUSTERS_3942521351652409819)],
        &[(0b11010, &ENTRY_LACKLUSTER_2494503323799670808)],
        &[(0b11010, &ENTRY_LACKLUSTERRER_10237849134270314093)],
        &[(0b11010, &ENTRY_LACKLUSTERS_3942521351652409819)],
        &[(0b11010, &ENTRY_LACKLUSTERREST_17124785842338778470)],
        &[(0b10010, &ENTRY_LACONIZE_9693633598752813366)],
        &[(0b10010, &ENTRY_LACONIZED_11779313827476836680)],
        &[(0b10010, &ENTRY_LACONIZES_9093953536899310585)],
        &[(0b10010, &ENTRY_LACONIZING_15917635164362459543)],
        &[(0b01001, &ENTRY_LACONIZE_9693633598752813366)],
        &[(0b01001, &ENTRY_LACONIZED_11779313827476836680)],
        &[(0b01001, &ENTRY_LACONIZES_9093953536899310585)],
        &[(0b01001, &ENTRY_LACONIZING_15917635164362459543)],
        &[(0b10010, &ENTRY_LACTONIZED_13709635916917704116)],
        &[(0b01001, &ENTRY_LACTONIZED_13709635916917704116)],
    ],
    range: 5..=11,
};

static VARS_LAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LAB_CHILDREN),
    value: None,
};

static VARS_LAB_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_LABE_NODE),
    None,
    None,
    None,
    Some(&VARS_LABI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LABO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_LABO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_LABO_CHILDREN),
    value: None,
};

static VARS_LABO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_LABOR_NODE),
    None,
    None,
    Some(&VARS_LABOU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_LABOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LABOU_CHILDREN),
    value: None,
};

pub static VARS_LABOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rabilities"),
        dictgen::InsensitiveStr::Ascii("rability"),
        dictgen::InsensitiveStr::Ascii("rable"),
        dictgen::InsensitiveStr::Ascii("rables"),
        dictgen::InsensitiveStr::Ascii("rage"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("redlier"),
        dictgen::InsensitiveStr::Ascii("redliest"),
        dictgen::InsensitiveStr::Ascii("redly"),
        dictgen::InsensitiveStr::Ascii("redness"),
        dictgen::InsensitiveStr::Ascii("rednesses"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("ress"),
        dictgen::InsensitiveStr::Ascii("rhood"),
        dictgen::InsensitiveStr::Ascii("rhoods"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("ringlier"),
        dictgen::InsensitiveStr::Ascii("ringliest"),
        dictgen::InsensitiveStr::Ascii("ringly"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("rism"),
        dictgen::InsensitiveStr::Ascii("risms"),
        dictgen::InsensitiveStr::Ascii("rist"),
        dictgen::InsensitiveStr::Ascii("rists"),
        dictgen::InsensitiveStr::Ascii("rite"),
        dictgen::InsensitiveStr::Ascii("rites"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesser"),
        dictgen::InsensitiveStr::Ascii("rlesses"),
        dictgen::InsensitiveStr::Ascii("rlessest"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("rsaving"),
        dictgen::InsensitiveStr::Ascii("rsome"),
        dictgen::InsensitiveStr::Ascii("rsomely"),
    ],
    values: &[
        &[(0b11010, &ENTRY_LABOR_6900748202033934783)],
        &[(0b11010, &ENTRY_LABORABILITIES_7797372392120967556)],
        &[(0b11010, &ENTRY_LABORABILITY_15883644828666969797)],
        &[(0b11010, &ENTRY_LABORABLE_4111449141966442266)],
        &[(0b11010, &ENTRY_LABORABLES_7918310557704162524)],
        &[(0b11010, &ENTRY_LABORAGE_12473306859130967265)],
        &[(0b11010, &ENTRY_LABORED_17978981141111186545)],
        &[(0b11010, &ENTRY_LABOREDLIER_233247574717297785)],
        &[(0b11010, &ENTRY_LABOREDLIEST_6121536727069717534)],
        &[(0b11010, &ENTRY_LABOREDLY_16392146890289378130)],
        &[(0b11010, &ENTRY_LABOREDNESS_7253397270172707072)],
        &[(0b11010, &ENTRY_LABOREDNESSES_11687900312804126120)],
        &[(0b11010, &ENTRY_LABORER_15546004262725309585)],
        &[(0b11010, &ENTRY_LABORERS_1891473305180927612)],
        &[(0b11010, &ENTRY_LABORESS_5168896427468795263)],
        &[(0b11010, &ENTRY_LABORHOOD_2858476689555142869)],
        &[(0b11010, &ENTRY_LABORHOODS_4554219923160158770)],
        &[(0b11010, &ENTRY_LABORING_9545557393231100138)],
        &[(0b11010, &ENTRY_LABORINGLIER_13113382106188708192)],
        &[(0b11010, &ENTRY_LABORINGLIEST_6064343407107044289)],
        &[(0b11010, &ENTRY_LABORINGLY_7190288000401128860)],
        &[(0b11010, &ENTRY_LABORINGS_10460452481863076398)],
        &[(0b11010, &ENTRY_LABORISM_707643266519411033)],
        &[(0b11010, &ENTRY_LABORISMS_14951457899010464782)],
        &[(0b11010, &ENTRY_LABORIST_4404212966525177578)],
        &[(0b11010, &ENTRY_LABORISTS_9984046093945823347)],
        &[(0b11010, &ENTRY_LABORITE_5420289708015536043)],
        &[(0b11010, &ENTRY_LABORITES_13847041128487303192)],
        &[(0b11010, &ENTRY_LABORLESS_5333428303377019136)],
        &[(0b11010, &ENTRY_LABORLESSER_6950542026780244863)],
        &[(0b11010, &ENTRY_LABORLESSES_3618662866437106672)],
        &[(0b11010, &ENTRY_LABORLESSEST_4725263119506742775)],
        &[(0b11010, &ENTRY_LABORS_12585701017364719611)],
        &[(0b11010, &ENTRY_LABORSAVING_1003966555581027356)],
        &[(0b11010, &ENTRY_LABORSOME_16467437286971490948)],
        &[(0b11010, &ENTRY_LABORSOMELY_14865352057256202178)],
    ],
    range: 1..=10,
};

static VARS_LABOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LABOR_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_LABOR_6900748202033934783)]),
};

pub static VARS_LABOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilities"),
        dictgen::InsensitiveStr::Ascii("ability"),
        dictgen::InsensitiveStr::Ascii("able"),
        dictgen::InsensitiveStr::Ascii("ables"),
        dictgen::InsensitiveStr::Ascii("age"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("edlier"),
        dictgen::InsensitiveStr::Ascii("edliest"),
        dictgen::InsensitiveStr::Ascii("edly"),
        dictgen::InsensitiveStr::Ascii("edness"),
        dictgen::InsensitiveStr::Ascii("ednesses"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ess"),
        dictgen::InsensitiveStr::Ascii("hood"),
        dictgen::InsensitiveStr::Ascii("hoods"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("inglier"),
        dictgen::InsensitiveStr::Ascii("ingliest"),
        dictgen::InsensitiveStr::Ascii("ingly"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("ism"),
        dictgen::InsensitiveStr::Ascii("isms"),
        dictgen::InsensitiveStr::Ascii("ist"),
        dictgen::InsensitiveStr::Ascii("ists"),
        dictgen::InsensitiveStr::Ascii("ite"),
        dictgen::InsensitiveStr::Ascii("ites"),
        dictgen::InsensitiveStr::Ascii("less"),
        dictgen::InsensitiveStr::Ascii("lesser"),
        dictgen::InsensitiveStr::Ascii("lesses"),
        dictgen::InsensitiveStr::Ascii("lessest"),
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("saving"),
        dictgen::InsensitiveStr::Ascii("some"),
        dictgen::InsensitiveStr::Ascii("somely"),
    ],
    values: &[
        &[(0b11001, &ENTRY_LABORABILITIES_7797372392120967556)],
        &[(0b11001, &ENTRY_LABORABILITY_15883644828666969797)],
        &[(0b11001, &ENTRY_LABORABLE_4111449141966442266)],
        &[(0b11001, &ENTRY_LABORABLES_7918310557704162524)],
        &[(0b11001, &ENTRY_LABORAGE_12473306859130967265)],
        &[(0b11001, &ENTRY_LABORED_17978981141111186545)],
        &[(0b11001, &ENTRY_LABOREDLIER_233247574717297785)],
        &[(0b11001, &ENTRY_LABOREDLIEST_6121536727069717534)],
        &[(0b11001, &ENTRY_LABOREDLY_16392146890289378130)],
        &[(0b11001, &ENTRY_LABOREDNESS_7253397270172707072)],
        &[(0b11001, &ENTRY_LABOREDNESSES_11687900312804126120)],
        &[(0b11001, &ENTRY_LABORER_15546004262725309585)],
        &[(0b11001, &ENTRY_LABORERS_1891473305180927612)],
        &[(0b11001, &ENTRY_LABORESS_5168896427468795263)],
        &[(0b11001, &ENTRY_LABORHOOD_2858476689555142869)],
        &[(0b11001, &ENTRY_LABORHOODS_4554219923160158770)],
        &[(0b11001, &ENTRY_LABORING_9545557393231100138)],
        &[(0b11001, &ENTRY_LABORINGLIER_13113382106188708192)],
        &[(0b11001, &ENTRY_LABORINGLIEST_6064343407107044289)],
        &[(0b11001, &ENTRY_LABORINGLY_7190288000401128860)],
        &[(0b11001, &ENTRY_LABORINGS_10460452481863076398)],
        &[(0b11001, &ENTRY_LABORISM_707643266519411033)],
        &[(0b11001, &ENTRY_LABORISMS_14951457899010464782)],
        &[(0b00001, &ENTRY_LABORIST_4404212966525177578)],
        &[(0b00001, &ENTRY_LABORISTS_9984046093945823347)],
        &[(0b00001, &ENTRY_LABORITE_5420289708015536043)],
        &[(0b00001, &ENTRY_LABORITES_13847041128487303192)],
        &[(0b11001, &ENTRY_LABORLESS_5333428303377019136)],
        &[(0b11001, &ENTRY_LABORLESSER_6950542026780244863)],
        &[(0b11001, &ENTRY_LABORLESSES_3618662866437106672)],
        &[(0b11001, &ENTRY_LABORLESSEST_4725263119506742775)],
        &[(0b11001, &ENTRY_LABORS_12585701017364719611)],
        &[(0b11001, &ENTRY_LABORSAVING_1003966555581027356)],
        &[(0b11001, &ENTRY_LABORSOME_16467437286971490948)],
        &[(0b11001, &ENTRY_LABORSOMELY_14865352057256202178)],
    ],
    range: 1..=9,
};

static VARS_LABI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LABI_CHILDREN),
    value: None,
};

pub static VARS_LABI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("atae"),
        dictgen::InsensitiveStr::Ascii("ate"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("ovelarisation"),
        dictgen::InsensitiveStr::Ascii("ovelarise"),
        dictgen::InsensitiveStr::Ascii("ovelarised"),
        dictgen::InsensitiveStr::Ascii("ovelarising"),
        dictgen::InsensitiveStr::Ascii("ovelarization"),
        dictgen::InsensitiveStr::Ascii("ovelarize"),
        dictgen::InsensitiveStr::Ascii("ovelarized"),
        dictgen::InsensitiveStr::Ascii("ovelarizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_LABIALIZATION_15293853718014014842)],
        &[(0b10010, &ENTRY_LABIALIZATIONS_11100103088554056674)],
        &[(0b10010, &ENTRY_LABIALIZE_3849153743438926001)],
        &[(0b10010, &ENTRY_LABIALIZED_13581750401408636148)],
        &[(0b10010, &ENTRY_LABIALIZES_11166772539032438737)],
        &[(0b10010, &ENTRY_LABIALIZING_2747370128883717480)],
        &[(0b01001, &ENTRY_LABIALIZATION_15293853718014014842)],
        &[(0b01001, &ENTRY_LABIALIZATIONS_11100103088554056674)],
        &[(0b01001, &ENTRY_LABIALIZE_3849153743438926001)],
        &[(0b01001, &ENTRY_LABIALIZED_13581750401408636148)],
        &[(0b01001, &ENTRY_LABIALIZES_11166772539032438737)],
        &[(0b01001, &ENTRY_LABIALIZING_2747370128883717480)],
        &[(0b11010, &ENTRY_LABIATE_2435922924163128327)],
        &[(0b00001, &ENTRY_LABIATE_2435922924163128327)],
        &[(0b10010, &ENTRY_LABILIZATION_13451483296111886301)],
        &[(0b10010, &ENTRY_LABILIZATIONS_17617289251407409872)],
        &[(0b10010, &ENTRY_LABILIZE_3216640543484180889)],
        &[(0b10010, &ENTRY_LABILIZES_18075918350625611168)],
        &[(0b01001, &ENTRY_LABILIZATION_13451483296111886301)],
        &[(0b01001, &ENTRY_LABILIZATIONS_17617289251407409872)],
        &[(0b01001, &ENTRY_LABILIZE_3216640543484180889)],
        &[(0b01001, &ENTRY_LABILIZES_18075918350625611168)],
        &[(0b10010, &ENTRY_LABIOVELARIZATION_7949527129202863262)],
        &[(0b10010, &ENTRY_LABIOVELARIZE_5745583009360057266)],
        &[(0b10010, &ENTRY_LABIOVELARIZED_4381746274512287428)],
        &[(0b10010, &ENTRY_LABIOVELARIZING_8054689548550433373)],
        &[(0b01001, &ENTRY_LABIOVELARIZATION_7949527129202863262)],
        &[(0b01001, &ENTRY_LABIOVELARIZE_5745583009360057266)],
        &[(0b01001, &ENTRY_LABIOVELARIZED_4381746274512287428)],
        &[(0b01001, &ENTRY_LABIOVELARIZING_8054689548550433373)],
    ],
    range: 3..=13,
};

static VARS_LABE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_LABE_CHILDREN),
    value: None,
};

pub static VARS_LABE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lable"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("llable"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_LABELABLE_7231451482507254318)],
        &[(0b00001, &ENTRY_LABELED_9725906430384443808)],
        &[(0b00001, &ENTRY_LABELER_4326972748751944713)],
        &[(0b00001, &ENTRY_LABELERS_13647403983724841259)],
        &[(0b00001, &ENTRY_LABELING_17477269265787703550)],
        &[(0b11010, &ENTRY_LABELABLE_7231451482507254318)],
        &[(0b11010, &ENTRY_LABELED_9725906430384443808)],
        &[(0b11010, &ENTRY_LABELER_4326972748751944713)],
        &[(0b11010, &ENTRY_LABELERS_13647403983724841259)],
        &[(0b11010, &ENTRY_LABELING_17477269265787703550)],
    ],
    range: 3..=6,
};

static VARS_K_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_K_CHILDREN),
    value: None,
};

static VARS_K_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_KA_NODE),
    None,
    None,
    None,
    Some(&VARS_KE_NODE),
    None,
    None,
    None,
    Some(&VARS_KI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_KO_NODE),
    None,
    None,
    Some(&VARS_KR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_KY_NODE),
    None,
];

static VARS_KY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KY_CHILDREN),
    value: None,
};

pub static VARS_KY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("loes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_KYANIZE_9586519844157364012)],
        &[(0b10010, &ENTRY_KYANIZED_9952343296250866459)],
        &[(0b10010, &ENTRY_KYANIZES_3069029591103298866)],
        &[(0b10010, &ENTRY_KYANIZING_652034703010533729)],
        &[(0b01001, &ENTRY_KYANIZE_9586519844157364012)],
        &[(0b01001, &ENTRY_KYANIZED_9952343296250866459)],
        &[(0b01001, &ENTRY_KYANIZES_3069029591103298866)],
        &[(0b01001, &ENTRY_KYANIZING_652034703010533729)],
        &[(0b11010, &ENTRY_KYLES_14720795410762956774)],
    ],
    range: 4..=7,
};

static VARS_KR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KR_CHILDREN),
    value: None,
};

pub static VARS_KR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ein")],
    values: &[&[(0b11010, &ENTRY_KERIN_12119680575777787053)]],
    range: 3..=3,
};

static VARS_KO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KO_CHILDREN),
    value: None,
};

pub static VARS_KO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ellia"),
        dictgen::InsensitiveStr::Ascii("eppel"),
        dictgen::InsensitiveStr::Ascii("ssaean"),
        dictgen::InsensitiveStr::Ascii("ssean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_KELLIA_2765963159143846358)],
        &[(0b11010, &ENTRY_KEPPEL_3068696649582784651)],
        &[(0b11010, &ENTRY_KOSSEAN_2643003562717992923)],
        &[(0b00001, &ENTRY_KOSSEAN_2643003562717992923)],
    ],
    range: 5..=6,
};

static VARS_KI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KI_CHILDREN),
    value: None,
};

pub static VARS_KI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dnaped"),
        dictgen::InsensitiveStr::Ascii("dnaper"),
        dictgen::InsensitiveStr::Ascii("dnapers"),
        dictgen::InsensitiveStr::Ascii("dnaping"),
        dictgen::InsensitiveStr::Ascii("logramme"),
        dictgen::InsensitiveStr::Ascii("logrammes"),
        dictgen::InsensitiveStr::Ascii("loliter"),
        dictgen::InsensitiveStr::Ascii("loliters"),
        dictgen::InsensitiveStr::Ascii("lolitre"),
        dictgen::InsensitiveStr::Ascii("lolitres"),
        dictgen::InsensitiveStr::Ascii("lometer"),
        dictgen::InsensitiveStr::Ascii("lometers"),
        dictgen::InsensitiveStr::Ascii("lometre"),
        dictgen::InsensitiveStr::Ascii("lometres"),
        dictgen::InsensitiveStr::Ascii("naestheses"),
        dictgen::InsensitiveStr::Ascii("naesthesia"),
        dictgen::InsensitiveStr::Ascii("naesthesias"),
        dictgen::InsensitiveStr::Ascii("naesthesis"),
        dictgen::InsensitiveStr::Ascii("naesthetic"),
        dictgen::InsensitiveStr::Ascii("naestheticallier"),
        dictgen::InsensitiveStr::Ascii("naestheticalliest"),
        dictgen::InsensitiveStr::Ascii("naesthetically"),
        dictgen::InsensitiveStr::Ascii("naestheticer"),
        dictgen::InsensitiveStr::Ascii("naestheticest"),
        dictgen::InsensitiveStr::Ascii("naesthetics"),
        dictgen::InsensitiveStr::Ascii("ndergartener"),
        dictgen::InsensitiveStr::Ascii("ndergarteners"),
        dictgen::InsensitiveStr::Ascii("ndergartner"),
        dictgen::InsensitiveStr::Ascii("ndergartners"),
        dictgen::InsensitiveStr::Ascii("nestheses"),
        dictgen::InsensitiveStr::Ascii("nesthesia"),
        dictgen::InsensitiveStr::Ascii("nesthesias"),
        dictgen::InsensitiveStr::Ascii("nesthesis"),
        dictgen::InsensitiveStr::Ascii("nesthetic"),
        dictgen::InsensitiveStr::Ascii("nestheticallier"),
        dictgen::InsensitiveStr::Ascii("nestheticalliest"),
        dictgen::InsensitiveStr::Ascii("nesthetically"),
        dictgen::InsensitiveStr::Ascii("nestheticer"),
        dictgen::InsensitiveStr::Ascii("nestheticest"),
        dictgen::InsensitiveStr::Ascii("nesthetics"),
    ],
    values: &[
        &[(0b00001, &ENTRY_KIDNAPPED_8258006507287902376)],
        &[(0b00001, &ENTRY_KIDNAPPER_1975152379883548277)],
        &[(0b00001, &ENTRY_KIDNAPPERS_7511485392866911549)],
        &[(0b00001, &ENTRY_KIDNAPPING_8190098845650201253)],
        &[(0b10010, &ENTRY_KILOGRAM_5464515871465238139)],
        &[(0b10010, &ENTRY_KILOGRAMS_9413140926934099988)],
        &[(0b01001, &ENTRY_KILOLITER_11151444382911560681)],
        &[(0b01001, &ENTRY_KILOLITERS_9786627551420863989)],
        &[(0b11010, &ENTRY_KILOLITER_11151444382911560681)],
        &[(0b11010, &ENTRY_KILOLITERS_9786627551420863989)],
        &[(0b01001, &ENTRY_KILOMETER_6603317962568686055)],
        &[(0b01001, &ENTRY_KILOMETERS_13128037988818073327)],
        &[(0b11010, &ENTRY_KILOMETER_6603317962568686055)],
        &[(0b11010, &ENTRY_KILOMETERS_13128037988818073327)],
        &[(0b11010, &ENTRY_KINESTHESES_5537328044553929564)],
        &[(0b11010, &ENTRY_KINESTHESIA_4147711150901246528)],
        &[(0b11010, &ENTRY_KINESTHESIAS_16830722998283755883)],
        &[(0b11010, &ENTRY_KINESTHESIS_11584641061195125769)],
        &[(0b11010, &ENTRY_KINESTHETIC_9525542020001536167)],
        &[(0b11010, &ENTRY_KINESTHETICALLIER_15258389196130357542)],
        &[(0b11010, &ENTRY_KINESTHETICALLIEST_4433069150068533408)],
        &[(0b11010, &ENTRY_KINESTHETICALLY_3795807158430242904)],
        &[(0b11010, &ENTRY_KINESTHETICER_1776286349748412373)],
        &[(0b11010, &ENTRY_KINESTHETICEST_17696742886422574314)],
        &[(0b11010, &ENTRY_KINESTHETICS_246684268615617993)],
        &[(0b10011, &ENTRY_KINDERGARTNER_819228164485485087)],
        &[(0b10011, &ENTRY_KINDERGARTNERS_12743938718721034302)],
        &[(0b01001, &ENTRY_KINDERGARTNER_819228164485485087)],
        &[(0b01001, &ENTRY_KINDERGARTNERS_12743938718721034302)],
        &[(0b10001, &ENTRY_KINESTHESES_5537328044553929564)],
        &[(0b11001, &ENTRY_KINESTHESIA_4147711150901246528)],
        &[(0b11001, &ENTRY_KINESTHESIAS_16830722998283755883)],
        &[(0b10001, &ENTRY_KINESTHESIS_11584641061195125769)],
        &[(0b11001, &ENTRY_KINESTHETIC_9525542020001536167)],
        &[(0b10001, &ENTRY_KINESTHETICALLIER_15258389196130357542)],
        &[(0b10001, &ENTRY_KINESTHETICALLIEST_4433069150068533408)],
        &[(0b10001, &ENTRY_KINESTHETICALLY_3795807158430242904)],
        &[(0b11001, &ENTRY_KINESTHETICER_1776286349748412373)],
        &[(0b11001, &ENTRY_KINESTHETICEST_17696742886422574314)],
        &[(0b11001, &ENTRY_KINESTHETICS_246684268615617993)],
    ],
    range: 6..=17,
};

static VARS_KE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KE_CHILDREN),
    value: None,
};

pub static VARS_KE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("llia"),
        dictgen::InsensitiveStr::Ascii("mbed"),
        dictgen::InsensitiveStr::Ascii("mboed"),
        dictgen::InsensitiveStr::Ascii("nneled"),
        dictgen::InsensitiveStr::Ascii("nneling"),
        dictgen::InsensitiveStr::Ascii("nnelled"),
        dictgen::InsensitiveStr::Ascii("nnelling"),
        dictgen::InsensitiveStr::Ascii("ppel"),
        dictgen::InsensitiveStr::Ascii("ratinisation"),
        dictgen::InsensitiveStr::Ascii("ratinisations"),
        dictgen::InsensitiveStr::Ascii("ratinise"),
        dictgen::InsensitiveStr::Ascii("ratinised"),
        dictgen::InsensitiveStr::Ascii("ratinises"),
        dictgen::InsensitiveStr::Ascii("ratinising"),
        dictgen::InsensitiveStr::Ascii("ratinization"),
        dictgen::InsensitiveStr::Ascii("ratinizations"),
        dictgen::InsensitiveStr::Ascii("ratinize"),
        dictgen::InsensitiveStr::Ascii("ratinized"),
        dictgen::InsensitiveStr::Ascii("ratinizes"),
        dictgen::InsensitiveStr::Ascii("ratinizing"),
        dictgen::InsensitiveStr::Ascii("rb"),
        dictgen::InsensitiveStr::Ascii("rbed"),
        dictgen::InsensitiveStr::Ascii("rbing"),
        dictgen::InsensitiveStr::Ascii("rbs"),
        dictgen::InsensitiveStr::Ascii("rin"),
        dictgen::InsensitiveStr::Ascii("rneled"),
        dictgen::InsensitiveStr::Ascii("rneling"),
        dictgen::InsensitiveStr::Ascii("rnelled"),
        dictgen::InsensitiveStr::Ascii("rnelling"),
        dictgen::InsensitiveStr::Ascii("rosine"),
        dictgen::InsensitiveStr::Ascii("rosines"),
        dictgen::InsensitiveStr::Ascii("tonaemia"),
        dictgen::InsensitiveStr::Ascii("tonemia"),
        dictgen::InsensitiveStr::Ascii("tonisation"),
        dictgen::InsensitiveStr::Ascii("tonisations"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonization"),
        dictgen::InsensitiveStr::Ascii("tonizations"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_KED_16330510442503716352)],
        &[(0b10010, &ENTRY_KEIZER_3905342153729010348)],
        &[(0b01001, &ENTRY_KEIZER_3905342153729010348)],
        &[(0b00001, &ENTRY_KELLIA_2765963159143846358)],
        &[(0b00001, &ENTRY_KEMBED_13707135129230712936)],
        &[(0b11010, &ENTRY_KEMBED_13707135129230712936)],
        &[(0b00001, &ENTRY_KENNELED_15298221936257378060)],
        &[(0b00001, &ENTRY_KENNELING_8348856211807242608)],
        &[(0b11010, &ENTRY_KENNELED_15298221936257378060)],
        &[(0b11010, &ENTRY_KENNELING_8348856211807242608)],
        &[(0b00001, &ENTRY_KEPPEL_3068696649582784651)],
        &[(0b10010, &ENTRY_KERATINIZATION_2704569985907628734)],
        &[(0b10010, &ENTRY_KERATINIZATIONS_4745190074411978728)],
        &[(0b10010, &ENTRY_KERATINIZE_10404763732923491961)],
        &[(0b10010, &ENTRY_KERATINIZED_584101825994418545)],
        &[(0b10010, &ENTRY_KERATINIZES_14523171164749310546)],
        &[(0b10010, &ENTRY_KERATINIZING_15375186798258678468)],
        &[(0b01001, &ENTRY_KERATINIZATION_2704569985907628734)],
        &[(0b01001, &ENTRY_KERATINIZATIONS_4745190074411978728)],
        &[(0b01001, &ENTRY_KERATINIZE_10404763732923491961)],
        &[(0b01001, &ENTRY_KERATINIZED_584101825994418545)],
        &[(0b01001, &ENTRY_KERATINIZES_14523171164749310546)],
        &[(0b01001, &ENTRY_KERATINIZING_15375186798258678468)],
        &[(0b10010, &ENTRY_CURB_10662074484175094483)],
        &[(0b10010, &ENTRY_CURBED_15767276793691280481)],
        &[(0b10010, &ENTRY_CURBING_3527396542143388091)],
        &[(0b10010, &ENTRY_CURBS_13740246248166179524)],
        &[(0b00001, &ENTRY_KERIN_12119680575777787053)],
        &[(0b00001, &ENTRY_KERNELED_8033424373821514977)],
        &[(0b00001, &ENTRY_KERNELING_1639558248042323198)],
        &[(0b11010, &ENTRY_KERNELED_8033424373821514977)],
        &[(0b11010, &ENTRY_KERNELING_1639558248042323198)],
        &[(0b10011, &ENTRY_KEROSENE_11079706743383213665)],
        &[(0b10011, &ENTRY_KEROSENES_5578493978698306195)],
        &[(0b11010, &ENTRY_KETONEMIA_7553374988631718604)],
        &[(0b10001, &ENTRY_KETONEMIA_7553374988631718604)],
        &[(0b10010, &ENTRY_KETONIZATION_10404300835427344597)],
        &[(0b10010, &ENTRY_KETONIZATIONS_14629309903383300671)],
        &[(0b10010, &ENTRY_KETONIZE_17435606326783529410)],
        &[(0b10010, &ENTRY_KETONIZES_9616017976128138242)],
        &[(0b01001, &ENTRY_KETONIZATION_10404300835427344597)],
        &[(0b01001, &ENTRY_KETONIZATIONS_14629309903383300671)],
        &[(0b01001, &ENTRY_KETONIZE_17435606326783529410)],
        &[(0b01001, &ENTRY_KETONIZES_9616017976128138242)],
    ],
    range: 1..=13,
};

static VARS_KA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_KA_CHILDREN),
    value: None,
};

pub static VARS_KA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("nae"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("olinisation"),
        dictgen::InsensitiveStr::Ascii("olinisations"),
        dictgen::InsensitiveStr::Ascii("olinise"),
        dictgen::InsensitiveStr::Ascii("olinised"),
        dictgen::InsensitiveStr::Ascii("olinises"),
        dictgen::InsensitiveStr::Ascii("olinising"),
        dictgen::InsensitiveStr::Ascii("olinization"),
        dictgen::InsensitiveStr::Ascii("olinizations"),
        dictgen::InsensitiveStr::Ascii("olinize"),
        dictgen::InsensitiveStr::Ascii("olinized"),
        dictgen::InsensitiveStr::Ascii("olinizes"),
        dictgen::InsensitiveStr::Ascii("olinizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_KED_16330510442503716352)],
        &[(0b11010, &ENTRY_KANE_4237037254996437783)],
        &[(0b00001, &ENTRY_KANE_4237037254996437783)],
        &[(0b10010, &ENTRY_KAOLINIZATION_7991448154248062501)],
        &[(0b10010, &ENTRY_KAOLINIZATIONS_1147736204566705803)],
        &[(0b10010, &ENTRY_KAOLINIZE_10919510675768301839)],
        &[(0b10010, &ENTRY_KAOLINIZED_9549498899357684926)],
        &[(0b10010, &ENTRY_KAOLINIZES_6007210570575095960)],
        &[(0b10010, &ENTRY_KAOLINIZING_10817594314873964583)],
        &[(0b01001, &ENTRY_KAOLINIZATION_7991448154248062501)],
        &[(0b01001, &ENTRY_KAOLINIZATIONS_1147736204566705803)],
        &[(0b01001, &ENTRY_KAOLINIZE_10919510675768301839)],
        &[(0b01001, &ENTRY_KAOLINIZED_9549498899357684926)],
        &[(0b01001, &ENTRY_KAOLINIZES_6007210570575095960)],
        &[(0b01001, &ENTRY_KAOLINIZING_10817594314873964583)],
    ],
    range: 2..=12,
};

static VARS_J_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_J_CHILDREN),
    value: None,
};

static VARS_J_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_JA_NODE),
    None,
    None,
    None,
    Some(&VARS_JE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_JO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_JU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_JU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_JU_CHILDREN),
    value: None,
};

pub static VARS_JU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daean"),
        dictgen::InsensitiveStr::Ascii("daeans"),
        dictgen::InsensitiveStr::Ascii("daeophobia"),
        dictgen::InsensitiveStr::Ascii("daisation"),
        dictgen::InsensitiveStr::Ascii("daise"),
        dictgen::InsensitiveStr::Ascii("daised"),
        dictgen::InsensitiveStr::Ascii("daiser"),
        dictgen::InsensitiveStr::Ascii("daising"),
        dictgen::InsensitiveStr::Ascii("daization"),
        dictgen::InsensitiveStr::Ascii("daize"),
        dictgen::InsensitiveStr::Ascii("daized"),
        dictgen::InsensitiveStr::Ascii("daizer"),
        dictgen::InsensitiveStr::Ascii("daizing"),
        dictgen::InsensitiveStr::Ascii("dean"),
        dictgen::InsensitiveStr::Ascii("deans"),
        dictgen::InsensitiveStr::Ascii("deophobia"),
        dictgen::InsensitiveStr::Ascii("dgement"),
        dictgen::InsensitiveStr::Ascii("dgements"),
        dictgen::InsensitiveStr::Ascii("dicialise"),
        dictgen::InsensitiveStr::Ascii("dicialises"),
        dictgen::InsensitiveStr::Ascii("dicialize"),
        dictgen::InsensitiveStr::Ascii("dicializes"),
        dictgen::InsensitiveStr::Ascii("lidae"),
        dictgen::InsensitiveStr::Ascii("lide"),
        dictgen::InsensitiveStr::Ascii("mboise"),
        dictgen::InsensitiveStr::Ascii("mboised"),
        dictgen::InsensitiveStr::Ascii("mboises"),
        dictgen::InsensitiveStr::Ascii("mboising"),
        dictgen::InsensitiveStr::Ascii("mboize"),
        dictgen::InsensitiveStr::Ascii("mboized"),
        dictgen::InsensitiveStr::Ascii("mboizes"),
        dictgen::InsensitiveStr::Ascii("mboizing"),
        dictgen::InsensitiveStr::Ascii("venilise"),
        dictgen::InsensitiveStr::Ascii("venilises"),
        dictgen::InsensitiveStr::Ascii("venilize"),
        dictgen::InsensitiveStr::Ascii("venilizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_JUDEAN_9802407929966548944)],
        &[(0b11010, &ENTRY_JUDEANS_10368783411253037037)],
        &[(0b11010, &ENTRY_JUDEOPHOBIA_9347089286565730960)],
        &[(0b10010, &ENTRY_JUDAIZATION_2583288495658842253)],
        &[(0b10010, &ENTRY_JUDAIZE_1070374568908494373)],
        &[(0b10010, &ENTRY_JUDAIZED_5299369943429817200)],
        &[(0b10010, &ENTRY_JUDAIZER_9583480883509645105)],
        &[(0b10010, &ENTRY_JUDAIZING_1306927867645370383)],
        &[(0b01001, &ENTRY_JUDAIZATION_2583288495658842253)],
        &[(0b01001, &ENTRY_JUDAIZE_1070374568908494373)],
        &[(0b01001, &ENTRY_JUDAIZED_5299369943429817200)],
        &[(0b01001, &ENTRY_JUDAIZER_9583480883509645105)],
        &[(0b01001, &ENTRY_JUDAIZING_1306927867645370383)],
        &[(0b00001, &ENTRY_JUDEAN_9802407929966548944)],
        &[(0b00001, &ENTRY_JUDEANS_10368783411253037037)],
        &[(0b00001, &ENTRY_JUDEOPHOBIA_9347089286565730960)],
        &[(0b11010, &ENTRY_JUDGMENT_1564861960905688138)],
        &[(0b11010, &ENTRY_JUDGMENTS_6714988350174691861)],
        &[(0b10010, &ENTRY_JUDICIALIZE_7481303822478621055)],
        &[(0b10010, &ENTRY_JUDICIALIZES_7935109342064479052)],
        &[(0b01001, &ENTRY_JUDICIALIZE_7481303822478621055)],
        &[(0b01001, &ENTRY_JUDICIALIZES_7935109342064479052)],
        &[(0b11010, &ENTRY_JULIDE_12150077695995964173)],
        &[(0b00001, &ENTRY_JULIDE_12150077695995964173)],
        &[(0b10010, &ENTRY_JUMBOIZE_15138655937615465445)],
        &[(0b10010, &ENTRY_JUMBOIZED_9650613673854154599)],
        &[(0b10010, &ENTRY_JUMBOIZES_14996632444752145143)],
        &[(0b10010, &ENTRY_JUMBOIZING_15027108879327530925)],
        &[(0b01001, &ENTRY_JUMBOIZE_15138655937615465445)],
        &[(0b01001, &ENTRY_JUMBOIZED_9650613673854154599)],
        &[(0b01001, &ENTRY_JUMBOIZES_14996632444752145143)],
        &[(0b01001, &ENTRY_JUMBOIZING_15027108879327530925)],
        &[(0b10010, &ENTRY_JUVENILIZE_2665032966818537333)],
        &[(0b10010, &ENTRY_JUVENILIZES_429993400308407468)],
        &[(0b01001, &ENTRY_JUVENILIZE_2665032966818537333)],
        &[(0b01001, &ENTRY_JUVENILIZES_429993400308407468)],
    ],
    range: 4..=10,
};

static VARS_JO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_JO_CHILDREN),
    value: None,
};

pub static VARS_JO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("ky"),
        dictgen::InsensitiveStr::Ascii("nathanisation"),
        dictgen::InsensitiveStr::Ascii("nathanisations"),
        dictgen::InsensitiveStr::Ascii("nathanization"),
        dictgen::InsensitiveStr::Ascii("nathanizations"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("ur"),
        dictgen::InsensitiveStr::Ascii("urnalisation"),
        dictgen::InsensitiveStr::Ascii("urnalisations"),
        dictgen::InsensitiveStr::Ascii("urnalise"),
        dictgen::InsensitiveStr::Ascii("urnalised"),
        dictgen::InsensitiveStr::Ascii("urnaliser"),
        dictgen::InsensitiveStr::Ascii("urnalisers"),
        dictgen::InsensitiveStr::Ascii("urnalises"),
        dictgen::InsensitiveStr::Ascii("urnalising"),
        dictgen::InsensitiveStr::Ascii("urnalization"),
        dictgen::InsensitiveStr::Ascii("urnalizations"),
        dictgen::InsensitiveStr::Ascii("urnalize"),
        dictgen::InsensitiveStr::Ascii("urnalized"),
        dictgen::InsensitiveStr::Ascii("urnalizer"),
        dictgen::InsensitiveStr::Ascii("urnalizers"),
        dictgen::InsensitiveStr::Ascii("urnalizes"),
        dictgen::InsensitiveStr::Ascii("urnalizing"),
        dictgen::InsensitiveStr::Ascii("urs"),
        dictgen::InsensitiveStr::Ascii("vialise"),
        dictgen::InsensitiveStr::Ascii("vialises"),
        dictgen::InsensitiveStr::Ascii("vialize"),
        dictgen::InsensitiveStr::Ascii("vializes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_JES_3895759907664524295)],
        &[(0b10011, &ENTRY_JOKEY_16351543528249851559)],
        &[(0b10010, &ENTRY_JONATHANIZATION_2830579624043742887)],
        &[(0b10010, &ENTRY_JONATHANIZATIONS_7547805422547054800)],
        &[(0b01001, &ENTRY_JONATHANIZATION_2830579624043742887)],
        &[(0b01001, &ENTRY_JONATHANIZATIONS_7547805422547054800)],
        &[(0b00001, &ENTRY_JOR_12696506718808280959)],
        &[(0b00001, &ENTRY_JORS_11914557043762091913)],
        &[(0b11010, &ENTRY_JOR_12696506718808280959)],
        &[(0b10010, &ENTRY_JOURNALIZATION_359433808018629079)],
        &[(0b10010, &ENTRY_JOURNALIZATIONS_15308350646861956682)],
        &[(0b10010, &ENTRY_JOURNALIZE_6257923934967466362)],
        &[(0b10010, &ENTRY_JOURNALIZED_9351999491366530812)],
        &[(0b10010, &ENTRY_JOURNALIZER_17240098793213073148)],
        &[(0b10010, &ENTRY_JOURNALIZERS_4450356968219419478)],
        &[(0b10010, &ENTRY_JOURNALIZES_413265712215135289)],
        &[(0b10010, &ENTRY_JOURNALIZING_8770885116969361944)],
        &[(0b01001, &ENTRY_JOURNALIZATION_359433808018629079)],
        &[(0b01001, &ENTRY_JOURNALIZATIONS_15308350646861956682)],
        &[(0b01001, &ENTRY_JOURNALIZE_6257923934967466362)],
        &[(0b01001, &ENTRY_JOURNALIZED_9351999491366530812)],
        &[(0b01001, &ENTRY_JOURNALIZER_17240098793213073148)],
        &[(0b01001, &ENTRY_JOURNALIZERS_4450356968219419478)],
        &[(0b01001, &ENTRY_JOURNALIZES_413265712215135289)],
        &[(0b01001, &ENTRY_JOURNALIZING_8770885116969361944)],
        &[(0b11010, &ENTRY_JORS_11914557043762091913)],
        &[(0b10010, &ENTRY_JOVIALIZE_14909643151930429709)],
        &[(0b10010, &ENTRY_JOVIALIZES_15779794696747576301)],
        &[(0b01001, &ENTRY_JOVIALIZE_14909643151930429709)],
        &[(0b01001, &ENTRY_JOVIALIZES_15779794696747576301)],
    ],
    range: 1..=14,
};

static VARS_JE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_JE_CHILDREN),
    value: None,
};

pub static VARS_JE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("opardisation"),
        dictgen::InsensitiveStr::Ascii("opardise"),
        dictgen::InsensitiveStr::Ascii("opardised"),
        dictgen::InsensitiveStr::Ascii("opardises"),
        dictgen::InsensitiveStr::Ascii("opardising"),
        dictgen::InsensitiveStr::Ascii("opardization"),
        dictgen::InsensitiveStr::Ascii("opardize"),
        dictgen::InsensitiveStr::Ascii("opardized"),
        dictgen::InsensitiveStr::Ascii("opardizes"),
        dictgen::InsensitiveStr::Ascii("opardizing"),
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("suitisation"),
        dictgen::InsensitiveStr::Ascii("suitise"),
        dictgen::InsensitiveStr::Ascii("suitised"),
        dictgen::InsensitiveStr::Ascii("suitises"),
        dictgen::InsensitiveStr::Ascii("suitising"),
        dictgen::InsensitiveStr::Ascii("suitization"),
        dictgen::InsensitiveStr::Ascii("suitize"),
        dictgen::InsensitiveStr::Ascii("suitized"),
        dictgen::InsensitiveStr::Ascii("suitizes"),
        dictgen::InsensitiveStr::Ascii("suitizing"),
        dictgen::InsensitiveStr::Ascii("weled"),
        dictgen::InsensitiveStr::Ascii("weler"),
        dictgen::InsensitiveStr::Ascii("welers"),
        dictgen::InsensitiveStr::Ascii("weling"),
        dictgen::InsensitiveStr::Ascii("welled"),
        dictgen::InsensitiveStr::Ascii("weller"),
        dictgen::InsensitiveStr::Ascii("wellers"),
        dictgen::InsensitiveStr::Ascii("wellery"),
        dictgen::InsensitiveStr::Ascii("welling"),
        dictgen::InsensitiveStr::Ascii("welry"),
    ],
    values: &[
        &[(0b10010, &ENTRY_JEOPARDIZATION_2937859644534909830)],
        &[(0b10010, &ENTRY_JEOPARDIZE_17497435966470167065)],
        &[(0b10010, &ENTRY_JEOPARDIZED_14672030278188616555)],
        &[(0b10010, &ENTRY_JEOPARDIZES_14509182339781413876)],
        &[(0b10010, &ENTRY_JEOPARDIZING_17208030805715513372)],
        &[(0b01001, &ENTRY_JEOPARDIZATION_2937859644534909830)],
        &[(0b01001, &ENTRY_JEOPARDIZE_17497435966470167065)],
        &[(0b01001, &ENTRY_JEOPARDIZED_14672030278188616555)],
        &[(0b01001, &ENTRY_JEOPARDIZES_14509182339781413876)],
        &[(0b01001, &ENTRY_JEOPARDIZING_17208030805715513372)],
        &[(0b00001, &ENTRY_JES_3895759907664524295)],
        &[(0b10010, &ENTRY_JESUITIZATION_11570440961702593723)],
        &[(0b10010, &ENTRY_JESUITIZE_6000644968200136366)],
        &[(0b10010, &ENTRY_JESUITIZED_10458308548218113460)],
        &[(0b10010, &ENTRY_JESUITIZES_11157364826076346568)],
        &[(0b10010, &ENTRY_JESUITIZING_3038475298331527607)],
        &[(0b01001, &ENTRY_JESUITIZATION_11570440961702593723)],
        &[(0b01001, &ENTRY_JESUITIZE_6000644968200136366)],
        &[(0b01001, &ENTRY_JESUITIZED_10458308548218113460)],
        &[(0b01001, &ENTRY_JESUITIZES_11157364826076346568)],
        &[(0b01001, &ENTRY_JESUITIZING_3038475298331527607)],
        &[(0b00001, &ENTRY_JEWELED_4326992812391453731)],
        &[(0b00001, &ENTRY_JEWELER_5950808914837775836)],
        &[(0b00001, &ENTRY_JEWELERS_978463834027856886)],
        &[(0b00001, &ENTRY_JEWELING_14303762198587690677)],
        &[(0b11010, &ENTRY_JEWELED_4326992812391453731)],
        &[(0b11010, &ENTRY_JEWELER_5950808914837775836)],
        &[(0b11010, &ENTRY_JEWELERS_978463834027856886)],
        &[(0b11010, &ENTRY_JEWELRY_4147223673886011898)],
        &[(0b11010, &ENTRY_JEWELING_14303762198587690677)],
        &[(0b01001, &ENTRY_JEWELRY_4147223673886011898)],
    ],
    range: 1..=12,
};

static VARS_JA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_JA_CHILDREN),
    value: None,
};

pub static VARS_JA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cobaean"),
        dictgen::InsensitiveStr::Ascii("cobean"),
        dictgen::InsensitiveStr::Ascii("cobinisation"),
        dictgen::InsensitiveStr::Ascii("cobinise"),
        dictgen::InsensitiveStr::Ascii("cobinised"),
        dictgen::InsensitiveStr::Ascii("cobinises"),
        dictgen::InsensitiveStr::Ascii("cobinising"),
        dictgen::InsensitiveStr::Ascii("cobinization"),
        dictgen::InsensitiveStr::Ascii("cobinize"),
        dictgen::InsensitiveStr::Ascii("cobinized"),
        dictgen::InsensitiveStr::Ascii("cobinizes"),
        dictgen::InsensitiveStr::Ascii("cobinizing"),
        dictgen::InsensitiveStr::Ascii("ilor"),
        dictgen::InsensitiveStr::Ascii("ilors"),
        dictgen::InsensitiveStr::Ascii("nisaries"),
        dictgen::InsensitiveStr::Ascii("nisary"),
        dictgen::InsensitiveStr::Ascii("nizaries"),
        dictgen::InsensitiveStr::Ascii("nizary"),
        dictgen::InsensitiveStr::Ascii("panisation"),
        dictgen::InsensitiveStr::Ascii("panisations"),
        dictgen::InsensitiveStr::Ascii("panise"),
        dictgen::InsensitiveStr::Ascii("panised"),
        dictgen::InsensitiveStr::Ascii("panises"),
        dictgen::InsensitiveStr::Ascii("panising"),
        dictgen::InsensitiveStr::Ascii("panization"),
        dictgen::InsensitiveStr::Ascii("panizations"),
        dictgen::InsensitiveStr::Ascii("panize"),
        dictgen::InsensitiveStr::Ascii("panized"),
        dictgen::InsensitiveStr::Ascii("panizes"),
        dictgen::InsensitiveStr::Ascii("panizing"),
        dictgen::InsensitiveStr::Ascii("rgonisation"),
        dictgen::InsensitiveStr::Ascii("rgonisations"),
        dictgen::InsensitiveStr::Ascii("rgonise"),
        dictgen::InsensitiveStr::Ascii("rgonised"),
        dictgen::InsensitiveStr::Ascii("rgonises"),
        dictgen::InsensitiveStr::Ascii("rgonising"),
        dictgen::InsensitiveStr::Ascii("rgonization"),
        dictgen::InsensitiveStr::Ascii("rgonizations"),
        dictgen::InsensitiveStr::Ascii("rgonize"),
        dictgen::InsensitiveStr::Ascii("rgonized"),
        dictgen::InsensitiveStr::Ascii("rgonizes"),
        dictgen::InsensitiveStr::Ascii("rgonizing"),
        dictgen::InsensitiveStr::Ascii("sperise"),
        dictgen::InsensitiveStr::Ascii("sperised"),
        dictgen::InsensitiveStr::Ascii("sperises"),
        dictgen::InsensitiveStr::Ascii("sperising"),
        dictgen::InsensitiveStr::Ascii("sperize"),
        dictgen::InsensitiveStr::Ascii("sperized"),
        dictgen::InsensitiveStr::Ascii("sperizes"),
        dictgen::InsensitiveStr::Ascii("sperizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_JACOBEAN_2306285500279605747)],
        &[(0b00001, &ENTRY_JACOBEAN_2306285500279605747)],
        &[(0b10010, &ENTRY_JACOBINIZATION_13248835767295513863)],
        &[(0b10010, &ENTRY_JACOBINIZE_17126698061231713267)],
        &[(0b10010, &ENTRY_JACOBINIZED_2692791121160783021)],
        &[(0b10010, &ENTRY_JACOBINIZES_13185057525743157466)],
        &[(0b10010, &ENTRY_JACOBINIZING_17823010425672134088)],
        &[(0b01001, &ENTRY_JACOBINIZATION_13248835767295513863)],
        &[(0b01001, &ENTRY_JACOBINIZE_17126698061231713267)],
        &[(0b01001, &ENTRY_JACOBINIZED_2692791121160783021)],
        &[(0b01001, &ENTRY_JACOBINIZES_13185057525743157466)],
        &[(0b01001, &ENTRY_JACOBINIZING_17823010425672134088)],
        &[(0b01001, &ENTRY_JAILER_1369890010036246012)],
        &[(0b01001, &ENTRY_JAILERS_2346423461770093206)],
        &[(0b10010, &ENTRY_JANIZARIES_16592241273420137044)],
        &[(0b10010, &ENTRY_JANIZARY_5645655583936688977)],
        &[(0b01001, &ENTRY_JANIZARIES_16592241273420137044)],
        &[(0b01001, &ENTRY_JANIZARY_5645655583936688977)],
        &[(0b10010, &ENTRY_JAPANIZATION_3492735518315430155)],
        &[(0b10010, &ENTRY_JAPANIZATIONS_15480877777955755597)],
        &[(0b10010, &ENTRY_JAPANIZE_16756105117360579347)],
        &[(0b10010, &ENTRY_JAPANIZED_16661943840791390096)],
        &[(0b10010, &ENTRY_JAPANIZES_17681743681143797110)],
        &[(0b10010, &ENTRY_JAPANIZING_1684002847958973103)],
        &[(0b01001, &ENTRY_JAPANIZATION_3492735518315430155)],
        &[(0b01001, &ENTRY_JAPANIZATIONS_15480877777955755597)],
        &[(0b01001, &ENTRY_JAPANIZE_16756105117360579347)],
        &[(0b01001, &ENTRY_JAPANIZED_16661943840791390096)],
        &[(0b01001, &ENTRY_JAPANIZES_17681743681143797110)],
        &[(0b01001, &ENTRY_JAPANIZING_1684002847958973103)],
        &[(0b10010, &ENTRY_JARGONIZATION_11704848459485664417)],
        &[(0b10010, &ENTRY_JARGONIZATIONS_3515989118992786878)],
        &[(0b10010, &ENTRY_JARGONIZE_13312556972392736698)],
        &[(0b10010, &ENTRY_JARGONIZED_6560506332692694911)],
        &[(0b10010, &ENTRY_JARGONIZES_3262599751720795311)],
        &[(0b10010, &ENTRY_JARGONIZING_9271512143905465697)],
        &[(0b01001, &ENTRY_JARGONIZATION_11704848459485664417)],
        &[(0b01001, &ENTRY_JARGONIZATIONS_3515989118992786878)],
        &[(0b01001, &ENTRY_JARGONIZE_13312556972392736698)],
        &[(0b01001, &ENTRY_JARGONIZED_6560506332692694911)],
        &[(0b01001, &ENTRY_JARGONIZES_3262599751720795311)],
        &[(0b01001, &ENTRY_JARGONIZING_9271512143905465697)],
        &[(0b10010, &ENTRY_JASPERIZE_1843763799496517999)],
        &[(0b10010, &ENTRY_JASPERIZED_13935967158321795558)],
        &[(0b10010, &ENTRY_JASPERIZES_13853455828472448050)],
        &[(0b10010, &ENTRY_JASPERIZING_4150717268435548309)],
        &[(0b01001, &ENTRY_JASPERIZE_1843763799496517999)],
        &[(0b01001, &ENTRY_JASPERIZED_13935967158321795558)],
        &[(0b01001, &ENTRY_JASPERIZES_13853455828472448050)],
        &[(0b01001, &ENTRY_JASPERIZING_4150717268435548309)],
    ],
    range: 4..=12,
};

static VARS_I_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_I_CHILDREN),
    value: None,
};

static VARS_I_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_IC_NODE),
    Some(&VARS_ID_NODE),
    Some(&VARS_IE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IL_NODE),
    Some(&VARS_IM_NODE),
    Some(&VARS_IN_NODE),
    Some(&VARS_IO_NODE),
    Some(&VARS_IP_NODE),
    None,
    Some(&VARS_IR_NODE),
    Some(&VARS_IS_NODE),
    Some(&VARS_IT_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IZ_NODE),
];

static VARS_IZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IZ_CHILDREN),
    value: None,
};

pub static VARS_IZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ing")],
    values: &[&[(0b01001, &ENTRY_IZING_87221185939223267)]],
    range: 3..=3,
};

static VARS_IT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IT_CHILDREN),
    value: None,
};

pub static VARS_IT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alianisation"),
        dictgen::InsensitiveStr::Ascii("alianisations"),
        dictgen::InsensitiveStr::Ascii("alianise"),
        dictgen::InsensitiveStr::Ascii("alianised"),
        dictgen::InsensitiveStr::Ascii("alianiser"),
        dictgen::InsensitiveStr::Ascii("alianisers"),
        dictgen::InsensitiveStr::Ascii("alianises"),
        dictgen::InsensitiveStr::Ascii("alianising"),
        dictgen::InsensitiveStr::Ascii("alianization"),
        dictgen::InsensitiveStr::Ascii("alianizations"),
        dictgen::InsensitiveStr::Ascii("alianize"),
        dictgen::InsensitiveStr::Ascii("alianized"),
        dictgen::InsensitiveStr::Ascii("alianizer"),
        dictgen::InsensitiveStr::Ascii("alianizers"),
        dictgen::InsensitiveStr::Ascii("alianizes"),
        dictgen::InsensitiveStr::Ascii("alianizing"),
        dictgen::InsensitiveStr::Ascii("alicisation"),
        dictgen::InsensitiveStr::Ascii("alicisations"),
        dictgen::InsensitiveStr::Ascii("alicise"),
        dictgen::InsensitiveStr::Ascii("alicised"),
        dictgen::InsensitiveStr::Ascii("alicises"),
        dictgen::InsensitiveStr::Ascii("alicising"),
        dictgen::InsensitiveStr::Ascii("alicization"),
        dictgen::InsensitiveStr::Ascii("alicizations"),
        dictgen::InsensitiveStr::Ascii("alicize"),
        dictgen::InsensitiveStr::Ascii("alicized"),
        dictgen::InsensitiveStr::Ascii("alicizes"),
        dictgen::InsensitiveStr::Ascii("alicizing"),
        dictgen::InsensitiveStr::Ascii("emisation"),
        dictgen::InsensitiveStr::Ascii("emisations"),
        dictgen::InsensitiveStr::Ascii("emise"),
        dictgen::InsensitiveStr::Ascii("emised"),
        dictgen::InsensitiveStr::Ascii("emiser"),
        dictgen::InsensitiveStr::Ascii("emisers"),
        dictgen::InsensitiveStr::Ascii("emises"),
        dictgen::InsensitiveStr::Ascii("emising"),
        dictgen::InsensitiveStr::Ascii("emization"),
        dictgen::InsensitiveStr::Ascii("emizations"),
        dictgen::InsensitiveStr::Ascii("emize"),
        dictgen::InsensitiveStr::Ascii("emized"),
        dictgen::InsensitiveStr::Ascii("emizer"),
        dictgen::InsensitiveStr::Ascii("emizers"),
        dictgen::InsensitiveStr::Ascii("emizes"),
        dictgen::InsensitiveStr::Ascii("emizing"),
        dictgen::InsensitiveStr::Ascii("uraean"),
        dictgen::InsensitiveStr::Ascii("uraeans"),
        dictgen::InsensitiveStr::Ascii("urean"),
        dictgen::InsensitiveStr::Ascii("ureans"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ITALIANIZATION_15289371753530527664)],
        &[(0b10010, &ENTRY_ITALIANIZATIONS_15182079831759741298)],
        &[(0b10010, &ENTRY_ITALIANIZE_3435276594938806940)],
        &[(0b10010, &ENTRY_ITALIANIZED_9265937607616517099)],
        &[(0b10010, &ENTRY_ITALIANIZER_12425000559882305319)],
        &[(0b10010, &ENTRY_ITALIANIZERS_7438679689208329079)],
        &[(0b10010, &ENTRY_ITALIANIZES_8935485272412950845)],
        &[(0b10010, &ENTRY_ITALIANIZING_6882200890707680467)],
        &[(0b01001, &ENTRY_ITALIANIZATION_15289371753530527664)],
        &[(0b01001, &ENTRY_ITALIANIZATIONS_15182079831759741298)],
        &[(0b01001, &ENTRY_ITALIANIZE_3435276594938806940)],
        &[(0b01001, &ENTRY_ITALIANIZED_9265937607616517099)],
        &[(0b01001, &ENTRY_ITALIANIZER_12425000559882305319)],
        &[(0b01001, &ENTRY_ITALIANIZERS_7438679689208329079)],
        &[(0b01001, &ENTRY_ITALIANIZES_8935485272412950845)],
        &[(0b01001, &ENTRY_ITALIANIZING_6882200890707680467)],
        &[(0b10010, &ENTRY_ITALICIZATION_11392681570163865096)],
        &[(0b10010, &ENTRY_ITALICIZATIONS_5819324693969518707)],
        &[(0b10010, &ENTRY_ITALICIZE_9105109899179023320)],
        &[(0b10010, &ENTRY_ITALICIZED_17732755536256154944)],
        &[(0b10010, &ENTRY_ITALICIZES_15932887042285237466)],
        &[(0b10010, &ENTRY_ITALICIZING_14470630360119711166)],
        &[(0b01001, &ENTRY_ITALICIZATION_11392681570163865096)],
        &[(0b01001, &ENTRY_ITALICIZATIONS_5819324693969518707)],
        &[(0b01001, &ENTRY_ITALICIZE_9105109899179023320)],
        &[(0b01001, &ENTRY_ITALICIZED_17732755536256154944)],
        &[(0b01001, &ENTRY_ITALICIZES_15932887042285237466)],
        &[(0b01001, &ENTRY_ITALICIZING_14470630360119711166)],
        &[(0b10010, &ENTRY_ITEMIZATION_1151183169051499453)],
        &[(0b10010, &ENTRY_ITEMIZATIONS_4501467912155184777)],
        &[(0b10010, &ENTRY_ITEMIZE_8581418811802894000)],
        &[(0b10010, &ENTRY_ITEMIZED_14832736118651335171)],
        &[(0b10010, &ENTRY_ITEMIZER_16293437282164566897)],
        &[(0b10010, &ENTRY_ITEMIZERS_11782059433108693632)],
        &[(0b10010, &ENTRY_ITEMIZES_10919132215830907409)],
        &[(0b10010, &ENTRY_ITEMIZING_1853557894573485171)],
        &[(0b01001, &ENTRY_ITEMIZATION_1151183169051499453)],
        &[(0b01001, &ENTRY_ITEMIZATIONS_4501467912155184777)],
        &[(0b01001, &ENTRY_ITEMIZE_8581418811802894000)],
        &[(0b01001, &ENTRY_ITEMIZED_14832736118651335171)],
        &[(0b01001, &ENTRY_ITEMIZER_16293437282164566897)],
        &[(0b01001, &ENTRY_ITEMIZERS_11782059433108693632)],
        &[(0b01001, &ENTRY_ITEMIZES_10919132215830907409)],
        &[(0b01001, &ENTRY_ITEMIZING_1853557894573485171)],
        &[(0b11010, &ENTRY_ITUREAN_1579753874067258559)],
        &[(0b11010, &ENTRY_ITUREANS_17311638727147711544)],
        &[(0b00001, &ENTRY_ITUREAN_1579753874067258559)],
        &[(0b00001, &ENTRY_ITUREANS_17311638727147711544)],
    ],
    range: 5..=13,
};

static VARS_IS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IS_CHILDREN),
    value: None,
};

pub static VARS_IS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chaemia"),
        dictgen::InsensitiveStr::Ascii("chaemias"),
        dictgen::InsensitiveStr::Ascii("chaemic"),
        dictgen::InsensitiveStr::Ascii("chemia"),
        dictgen::InsensitiveStr::Ascii("chemias"),
        dictgen::InsensitiveStr::Ascii("chemic"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("lamicise"),
        dictgen::InsensitiveStr::Ascii("lamicised"),
        dictgen::InsensitiveStr::Ascii("lamicises"),
        dictgen::InsensitiveStr::Ascii("lamicising"),
        dictgen::InsensitiveStr::Ascii("lamicize"),
        dictgen::InsensitiveStr::Ascii("lamicized"),
        dictgen::InsensitiveStr::Ascii("lamicizes"),
        dictgen::InsensitiveStr::Ascii("lamicizing"),
        dictgen::InsensitiveStr::Ascii("lamisation"),
        dictgen::InsensitiveStr::Ascii("lamisations"),
        dictgen::InsensitiveStr::Ascii("lamise"),
        dictgen::InsensitiveStr::Ascii("lamised"),
        dictgen::InsensitiveStr::Ascii("lamises"),
        dictgen::InsensitiveStr::Ascii("lamising"),
        dictgen::InsensitiveStr::Ascii("lamization"),
        dictgen::InsensitiveStr::Ascii("lamizations"),
        dictgen::InsensitiveStr::Ascii("lamize"),
        dictgen::InsensitiveStr::Ascii("lamized"),
        dictgen::InsensitiveStr::Ascii("lamizes"),
        dictgen::InsensitiveStr::Ascii("lamizing"),
        dictgen::InsensitiveStr::Ascii("ochronisation"),
        dictgen::InsensitiveStr::Ascii("ochronise"),
        dictgen::InsensitiveStr::Ascii("ochronised"),
        dictgen::InsensitiveStr::Ascii("ochronises"),
        dictgen::InsensitiveStr::Ascii("ochronising"),
        dictgen::InsensitiveStr::Ascii("ochronization"),
        dictgen::InsensitiveStr::Ascii("ochronize"),
        dictgen::InsensitiveStr::Ascii("ochronized"),
        dictgen::InsensitiveStr::Ascii("ochronizes"),
        dictgen::InsensitiveStr::Ascii("ochronizing"),
        dictgen::InsensitiveStr::Ascii("oimmunisation"),
        dictgen::InsensitiveStr::Ascii("oimmunisations"),
        dictgen::InsensitiveStr::Ascii("oimmunise"),
        dictgen::InsensitiveStr::Ascii("oimmunises"),
        dictgen::InsensitiveStr::Ascii("oimmunization"),
        dictgen::InsensitiveStr::Ascii("oimmunizations"),
        dictgen::InsensitiveStr::Ascii("oimmunize"),
        dictgen::InsensitiveStr::Ascii("oimmunizes"),
        dictgen::InsensitiveStr::Ascii("omerisation"),
        dictgen::InsensitiveStr::Ascii("omerisations"),
        dictgen::InsensitiveStr::Ascii("omerise"),
        dictgen::InsensitiveStr::Ascii("omerised"),
        dictgen::InsensitiveStr::Ascii("omerises"),
        dictgen::InsensitiveStr::Ascii("omerising"),
        dictgen::InsensitiveStr::Ascii("omerization"),
        dictgen::InsensitiveStr::Ascii("omerizations"),
        dictgen::InsensitiveStr::Ascii("omerize"),
        dictgen::InsensitiveStr::Ascii("omerized"),
        dictgen::InsensitiveStr::Ascii("omerizes"),
        dictgen::InsensitiveStr::Ascii("omerizing"),
        dictgen::InsensitiveStr::Ascii("raelitise"),
        dictgen::InsensitiveStr::Ascii("raelitises"),
        dictgen::InsensitiveStr::Ascii("raelitize"),
        dictgen::InsensitiveStr::Ascii("raelitizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ISCHEMIA_4729777747896369761)],
        &[(0b10010, &ENTRY_ISCHEMIAS_5196750807964195068)],
        &[(0b10010, &ENTRY_ISCHEMIC_14757992729373341279)],
        &[(0b11001, &ENTRY_ISCHEMIA_4729777747896369761)],
        &[(0b11001, &ENTRY_ISCHEMIAS_5196750807964195068)],
        &[(0b11001, &ENTRY_ISCHEMIC_14757992729373341279)],
        &[(0b10010, &ENTRY_IZING_87221185939223267)],
        &[(0b10010, &ENTRY_ISLAMICIZE_2949509590284400025)],
        &[(0b10010, &ENTRY_ISLAMICIZED_16429587923977697429)],
        &[(0b10010, &ENTRY_ISLAMICIZES_6389752952421773018)],
        &[(0b10010, &ENTRY_ISLAMICIZING_23850168929317726)],
        &[(0b01001, &ENTRY_ISLAMICIZE_2949509590284400025)],
        &[(0b01001, &ENTRY_ISLAMICIZED_16429587923977697429)],
        &[(0b01001, &ENTRY_ISLAMICIZES_6389752952421773018)],
        &[(0b01001, &ENTRY_ISLAMICIZING_23850168929317726)],
        &[(0b10010, &ENTRY_ISLAMIZATION_4608858883195228793)],
        &[(0b10010, &ENTRY_ISLAMIZATIONS_7348486256618393812)],
        &[(0b10010, &ENTRY_ISLAMIZE_3716181323919679147)],
        &[(0b10010, &ENTRY_ISLAMIZED_5471740521815167478)],
        &[(0b10010, &ENTRY_ISLAMIZES_6267509887106064680)],
        &[(0b10010, &ENTRY_ISLAMIZING_17686590495892593881)],
        &[(0b01001, &ENTRY_ISLAMIZATION_4608858883195228793)],
        &[(0b01001, &ENTRY_ISLAMIZATIONS_7348486256618393812)],
        &[(0b01001, &ENTRY_ISLAMIZE_3716181323919679147)],
        &[(0b01001, &ENTRY_ISLAMIZED_5471740521815167478)],
        &[(0b01001, &ENTRY_ISLAMIZES_6267509887106064680)],
        &[(0b01001, &ENTRY_ISLAMIZING_17686590495892593881)],
        &[(0b10010, &ENTRY_ISOCHRONIZATION_5455751798581610372)],
        &[(0b10010, &ENTRY_ISOCHRONIZE_2891882600957804109)],
        &[(0b10010, &ENTRY_ISOCHRONIZED_6953711592892129564)],
        &[(0b10010, &ENTRY_ISOCHRONIZES_3749787773992422117)],
        &[(0b10010, &ENTRY_ISOCHRONIZING_10087011436033155174)],
        &[(0b01001, &ENTRY_ISOCHRONIZATION_5455751798581610372)],
        &[(0b01001, &ENTRY_ISOCHRONIZE_2891882600957804109)],
        &[(0b01001, &ENTRY_ISOCHRONIZED_6953711592892129564)],
        &[(0b01001, &ENTRY_ISOCHRONIZES_3749787773992422117)],
        &[(0b01001, &ENTRY_ISOCHRONIZING_10087011436033155174)],
        &[(0b10010, &ENTRY_ISOIMMUNIZATION_16129604172463725287)],
        &[(0b10010, &ENTRY_ISOIMMUNIZATIONS_5261136359759079737)],
        &[(0b10010, &ENTRY_ISOIMMUNIZE_1925023617514416731)],
        &[(0b10010, &ENTRY_ISOIMMUNIZES_5630738645861994081)],
        &[(0b01001, &ENTRY_ISOIMMUNIZATION_16129604172463725287)],
        &[(0b01001, &ENTRY_ISOIMMUNIZATIONS_5261136359759079737)],
        &[(0b01001, &ENTRY_ISOIMMUNIZE_1925023617514416731)],
        &[(0b01001, &ENTRY_ISOIMMUNIZES_5630738645861994081)],
        &[(0b10010, &ENTRY_ISOMERIZATION_5858048477967388064)],
        &[(0b10010, &ENTRY_ISOMERIZATIONS_97375950389314089)],
        &[(0b10010, &ENTRY_ISOMERIZE_1321699050546721247)],
        &[(0b10010, &ENTRY_ISOMERIZED_14764124884003792517)],
        &[(0b10010, &ENTRY_ISOMERIZES_10200929254514131243)],
        &[(0b10010, &ENTRY_ISOMERIZING_13216788009796842004)],
        &[(0b01001, &ENTRY_ISOMERIZATION_5858048477967388064)],
        &[(0b01001, &ENTRY_ISOMERIZATIONS_97375950389314089)],
        &[(0b01001, &ENTRY_ISOMERIZE_1321699050546721247)],
        &[(0b01001, &ENTRY_ISOMERIZED_14764124884003792517)],
        &[(0b01001, &ENTRY_ISOMERIZES_10200929254514131243)],
        &[(0b01001, &ENTRY_ISOMERIZING_13216788009796842004)],
        &[(0b10010, &ENTRY_ISRAELITIZE_2547909155867308223)],
        &[(0b10010, &ENTRY_ISRAELITIZES_405850961922469630)],
        &[(0b01001, &ENTRY_ISRAELITIZE_2547909155867308223)],
        &[(0b01001, &ENTRY_ISRAELITIZES_405850961922469630)],
    ],
    range: 3..=14,
};

static VARS_IR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IR_CHILDREN),
    value: None,
};

pub static VARS_IR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("idectomise"),
        dictgen::InsensitiveStr::Ascii("idectomised"),
        dictgen::InsensitiveStr::Ascii("idectomising"),
        dictgen::InsensitiveStr::Ascii("idectomize"),
        dictgen::InsensitiveStr::Ascii("idectomized"),
        dictgen::InsensitiveStr::Ascii("idectomizing"),
        dictgen::InsensitiveStr::Ascii("idisation"),
        dictgen::InsensitiveStr::Ascii("idisations"),
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idised"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idising"),
        dictgen::InsensitiveStr::Ascii("idization"),
        dictgen::InsensitiveStr::Ascii("idizations"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idized"),
        dictgen::InsensitiveStr::Ascii("idizes"),
        dictgen::InsensitiveStr::Ascii("idizing"),
        dictgen::InsensitiveStr::Ascii("ishise"),
        dictgen::InsensitiveStr::Ascii("ishised"),
        dictgen::InsensitiveStr::Ascii("ishises"),
        dictgen::InsensitiveStr::Ascii("ishising"),
        dictgen::InsensitiveStr::Ascii("ishize"),
        dictgen::InsensitiveStr::Ascii("ishized"),
        dictgen::InsensitiveStr::Ascii("ishizes"),
        dictgen::InsensitiveStr::Ascii("ishizing"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("rationalise"),
        dictgen::InsensitiveStr::Ascii("rationalised"),
        dictgen::InsensitiveStr::Ascii("rationalises"),
        dictgen::InsensitiveStr::Ascii("rationalising"),
        dictgen::InsensitiveStr::Ascii("rationalize"),
        dictgen::InsensitiveStr::Ascii("rationalized"),
        dictgen::InsensitiveStr::Ascii("rationalizes"),
        dictgen::InsensitiveStr::Ascii("rationalizing"),
        dictgen::InsensitiveStr::Ascii("realisable"),
        dictgen::InsensitiveStr::Ascii("realizable"),
        dictgen::InsensitiveStr::Ascii("recognisable"),
        dictgen::InsensitiveStr::Ascii("recognizable"),
        dictgen::InsensitiveStr::Ascii("regularise"),
        dictgen::InsensitiveStr::Ascii("regularises"),
        dictgen::InsensitiveStr::Ascii("regularize"),
        dictgen::InsensitiveStr::Ascii("regularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IRANIZE_14984518848921394539)],
        &[(0b10010, &ENTRY_IRANIZES_14320284390344997490)],
        &[(0b01001, &ENTRY_IRANIZE_14984518848921394539)],
        &[(0b01001, &ENTRY_IRANIZES_14320284390344997490)],
        &[(0b11010, &ENTRY_IER_8590173399354916659)],
        &[(0b10010, &ENTRY_IRICIZE_5507636142851661219)],
        &[(0b10010, &ENTRY_IRICIZED_11289808119115340522)],
        &[(0b10010, &ENTRY_IRICIZING_6368473720803336644)],
        &[(0b01001, &ENTRY_IRICIZE_5507636142851661219)],
        &[(0b01001, &ENTRY_IRICIZED_11289808119115340522)],
        &[(0b01001, &ENTRY_IRICIZING_6368473720803336644)],
        &[(0b10010, &ENTRY_IRIDECTOMIZE_86328183387103922)],
        &[(0b10010, &ENTRY_IRIDECTOMIZED_3810752923190433476)],
        &[(0b10010, &ENTRY_IRIDECTOMIZING_3730176016492424041)],
        &[(0b01001, &ENTRY_IRIDECTOMIZE_86328183387103922)],
        &[(0b01001, &ENTRY_IRIDECTOMIZED_3810752923190433476)],
        &[(0b01001, &ENTRY_IRIDECTOMIZING_3730176016492424041)],
        &[(0b10010, &ENTRY_IRIDIZATION_10092871928556164080)],
        &[(0b10010, &ENTRY_IRIDIZATIONS_17562951663224796668)],
        &[(0b10010, &ENTRY_IRIDIZE_2104202158839307435)],
        &[(0b10010, &ENTRY_IRIDIZED_7355489127205562934)],
        &[(0b10010, &ENTRY_IRIDIZES_17186722611356826762)],
        &[(0b10010, &ENTRY_IRIDIZING_18250467508898199333)],
        &[(0b01001, &ENTRY_IRIDIZATION_10092871928556164080)],
        &[(0b01001, &ENTRY_IRIDIZATIONS_17562951663224796668)],
        &[(0b01001, &ENTRY_IRIDIZE_2104202158839307435)],
        &[(0b01001, &ENTRY_IRIDIZED_7355489127205562934)],
        &[(0b01001, &ENTRY_IRIDIZES_17186722611356826762)],
        &[(0b01001, &ENTRY_IRIDIZING_18250467508898199333)],
        &[(0b10010, &ENTRY_IRISHIZE_16946666616811306545)],
        &[(0b10010, &ENTRY_IRISHIZED_7371087371918107959)],
        &[(0b10010, &ENTRY_IRISHIZES_13402990074273477360)],
        &[(0b10010, &ENTRY_IRISHIZING_7496331717389209111)],
        &[(0b01001, &ENTRY_IRISHIZE_16946666616811306545)],
        &[(0b01001, &ENTRY_IRISHIZED_7371087371918107959)],
        &[(0b01001, &ENTRY_IRISHIZES_13402990074273477360)],
        &[(0b01001, &ENTRY_IRISHIZING_7496331717389209111)],
        &[(0b10010, &ENTRY_IRONIZE_18110787504657881641)],
        &[(0b10010, &ENTRY_IRONIZED_17698114892762359021)],
        &[(0b10010, &ENTRY_IRONIZES_17019087894237992930)],
        &[(0b10010, &ENTRY_IRONIZING_11068082412043423659)],
        &[(0b01001, &ENTRY_IRONIZE_18110787504657881641)],
        &[(0b01001, &ENTRY_IRONIZED_17698114892762359021)],
        &[(0b01001, &ENTRY_IRONIZES_17019087894237992930)],
        &[(0b01001, &ENTRY_IRONIZING_11068082412043423659)],
        &[(0b10010, &ENTRY_IRRATIONALIZE_8845257735070876188)],
        &[(0b10010, &ENTRY_IRRATIONALIZED_13246734682538802047)],
        &[(0b10010, &ENTRY_IRRATIONALIZES_8065254995992628819)],
        &[(0b10010, &ENTRY_IRRATIONALIZING_11978922020771473408)],
        &[(0b01001, &ENTRY_IRRATIONALIZE_8845257735070876188)],
        &[(0b01001, &ENTRY_IRRATIONALIZED_13246734682538802047)],
        &[(0b01001, &ENTRY_IRRATIONALIZES_8065254995992628819)],
        &[(0b01001, &ENTRY_IRRATIONALIZING_11978922020771473408)],
        &[(0b10010, &ENTRY_IRREALIZABLE_6638234207162807349)],
        &[(0b01001, &ENTRY_IRREALIZABLE_6638234207162807349)],
        &[(0b10010, &ENTRY_IRRECOGNIZABLE_17719796395122033372)],
        &[(0b01001, &ENTRY_IRRECOGNIZABLE_17719796395122033372)],
        &[(0b10010, &ENTRY_IRREGULARIZE_10956494208423895030)],
        &[(0b10010, &ENTRY_IRREGULARIZES_6852005375793762938)],
        &[(0b01001, &ENTRY_IRREGULARIZE_10956494208423895030)],
        &[(0b01001, &ENTRY_IRREGULARIZES_6852005375793762938)],
    ],
    range: 1..=13,
};

static VARS_IP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IP_CHILDREN),
    value: None,
};

pub static VARS_IP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hinoae"),
        dictgen::InsensitiveStr::Ascii("hinoe"),
        dictgen::InsensitiveStr::Ascii("omea"),
        dictgen::InsensitiveStr::Ascii("omoea"),
    ],
    values: &[
        &[(0b11010, &ENTRY_IPHINOE_2249018876749228073)],
        &[(0b00001, &ENTRY_IPHINOE_2249018876749228073)],
        &[(0b10001, &ENTRY_IPOMEA_17942946379691060366)],
        &[(0b11010, &ENTRY_IPOMEA_17942946379691060366)],
    ],
    range: 4..=6,
};

static VARS_IO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IO_CHILDREN),
    value: None,
};

pub static VARS_IO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("disation"),
        dictgen::InsensitiveStr::Ascii("dise"),
        dictgen::InsensitiveStr::Ascii("dised"),
        dictgen::InsensitiveStr::Ascii("diser"),
        dictgen::InsensitiveStr::Ascii("disers"),
        dictgen::InsensitiveStr::Ascii("dises"),
        dictgen::InsensitiveStr::Ascii("dising"),
        dictgen::InsensitiveStr::Ascii("dization"),
        dictgen::InsensitiveStr::Ascii("dize"),
        dictgen::InsensitiveStr::Ascii("dized"),
        dictgen::InsensitiveStr::Ascii("dizer"),
        dictgen::InsensitiveStr::Ascii("dizers"),
        dictgen::InsensitiveStr::Ascii("dizes"),
        dictgen::InsensitiveStr::Ascii("dizing"),
        dictgen::InsensitiveStr::Ascii("nicisation"),
        dictgen::InsensitiveStr::Ascii("nicisations"),
        dictgen::InsensitiveStr::Ascii("nicise"),
        dictgen::InsensitiveStr::Ascii("nicised"),
        dictgen::InsensitiveStr::Ascii("nicises"),
        dictgen::InsensitiveStr::Ascii("nicising"),
        dictgen::InsensitiveStr::Ascii("nicization"),
        dictgen::InsensitiveStr::Ascii("nicizations"),
        dictgen::InsensitiveStr::Ascii("nicize"),
        dictgen::InsensitiveStr::Ascii("nicized"),
        dictgen::InsensitiveStr::Ascii("nicizes"),
        dictgen::InsensitiveStr::Ascii("nicizing"),
        dictgen::InsensitiveStr::Ascii("nisable"),
        dictgen::InsensitiveStr::Ascii("nisabler"),
        dictgen::InsensitiveStr::Ascii("nisables"),
        dictgen::InsensitiveStr::Ascii("nisablest"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nisings"),
        dictgen::InsensitiveStr::Ascii("nision"),
        dictgen::InsensitiveStr::Ascii("nisions"),
        dictgen::InsensitiveStr::Ascii("nizable"),
        dictgen::InsensitiveStr::Ascii("nizabler"),
        dictgen::InsensitiveStr::Ascii("nizables"),
        dictgen::InsensitiveStr::Ascii("nizablest"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
        dictgen::InsensitiveStr::Ascii("nizings"),
        dictgen::InsensitiveStr::Ascii("nizion"),
        dictgen::InsensitiveStr::Ascii("nizions"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IODIZATION_5586899596747043878)],
        &[(0b10010, &ENTRY_IODIZE_6551505461584920010)],
        &[(0b10010, &ENTRY_IODIZED_14153462304228484989)],
        &[(0b10010, &ENTRY_IODIZER_5079398846400506402)],
        &[(0b10010, &ENTRY_IODIZERS_1602693425808401778)],
        &[(0b10010, &ENTRY_IODIZES_4704571112577733661)],
        &[(0b10010, &ENTRY_IODIZING_6412372743785816878)],
        &[(0b01001, &ENTRY_IODIZATION_5586899596747043878)],
        &[(0b01001, &ENTRY_IODIZE_6551505461584920010)],
        &[(0b01001, &ENTRY_IODIZED_14153462304228484989)],
        &[(0b01001, &ENTRY_IODIZER_5079398846400506402)],
        &[(0b01001, &ENTRY_IODIZERS_1602693425808401778)],
        &[(0b01001, &ENTRY_IODIZES_4704571112577733661)],
        &[(0b01001, &ENTRY_IODIZING_6412372743785816878)],
        &[(0b10010, &ENTRY_IONICIZATION_14275328423202505280)],
        &[(0b10010, &ENTRY_IONICIZATIONS_15904942843642930835)],
        &[(0b10010, &ENTRY_IONICIZE_252607515789455611)],
        &[(0b10010, &ENTRY_IONICIZED_10169630711506345495)],
        &[(0b10010, &ENTRY_IONICIZES_5099927358201731442)],
        &[(0b10010, &ENTRY_IONICIZING_16480798181970686021)],
        &[(0b01001, &ENTRY_IONICIZATION_14275328423202505280)],
        &[(0b01001, &ENTRY_IONICIZATIONS_15904942843642930835)],
        &[(0b01001, &ENTRY_IONICIZE_252607515789455611)],
        &[(0b01001, &ENTRY_IONICIZED_10169630711506345495)],
        &[(0b01001, &ENTRY_IONICIZES_5099927358201731442)],
        &[(0b01001, &ENTRY_IONICIZING_16480798181970686021)],
        &[(0b10010, &ENTRY_IONIZABLE_16754526582239461220)],
        &[(0b10010, &ENTRY_IONIZABLER_13678850402565349390)],
        &[(0b10010, &ENTRY_IONIZABLES_11104144020213787190)],
        &[(0b10010, &ENTRY_IONIZABLEST_11616981145574633025)],
        &[(0b10010, &ENTRY_IONIZATION_8977413361399661805)],
        &[(0b10010, &ENTRY_IONIZATIONS_2745402667451593899)],
        &[(0b10010, &ENTRY_IONIZE_16475901568737754789)],
        &[(0b10010, &ENTRY_IONIZED_81144343905744698)],
        &[(0b10010, &ENTRY_IONIZER_16564271588203588673)],
        &[(0b10010, &ENTRY_IONIZERS_14153461400591590929)],
        &[(0b10010, &ENTRY_IONIZES_18175490219979114523)],
        &[(0b10010, &ENTRY_IONIZING_1336169812778253456)],
        &[(0b10010, &ENTRY_IONIZINGS_1080850027408256472)],
        &[(0b10010, &ENTRY_IONIZION_15367966732951664052)],
        &[(0b10010, &ENTRY_IONIZIONS_5183748198612010486)],
        &[(0b01001, &ENTRY_IONIZABLE_16754526582239461220)],
        &[(0b01001, &ENTRY_IONIZABLER_13678850402565349390)],
        &[(0b01001, &ENTRY_IONIZABLES_11104144020213787190)],
        &[(0b01001, &ENTRY_IONIZABLEST_11616981145574633025)],
        &[(0b01001, &ENTRY_IONIZATION_8977413361399661805)],
        &[(0b01001, &ENTRY_IONIZATIONS_2745402667451593899)],
        &[(0b01001, &ENTRY_IONIZE_16475901568737754789)],
        &[(0b01001, &ENTRY_IONIZED_81144343905744698)],
        &[(0b01001, &ENTRY_IONIZES_18175490219979114523)],
        &[(0b01001, &ENTRY_IONIZING_1336169812778253456)],
        &[(0b01001, &ENTRY_IONIZINGS_1080850027408256472)],
        &[(0b01001, &ENTRY_IONIZION_15367966732951664052)],
        &[(0b01001, &ENTRY_IONIZIONS_5183748198612010486)],
    ],
    range: 4..=11,
};

static VARS_IN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_IN_CHILDREN),
    value: None,
};

static VARS_IN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_INA_NODE),
    None,
    Some(&VARS_INC_NODE),
    Some(&VARS_IND_NODE),
    Some(&VARS_INE_NODE),
    Some(&VARS_INF_NODE),
    Some(&VARS_ING_NODE),
    Some(&VARS_INH_NODE),
    Some(&VARS_INI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_INO_NODE),
    None,
    None,
    None,
    Some(&VARS_INS_NODE),
    Some(&VARS_INT_NODE),
    None,
    Some(&VARS_INV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_INV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INV_CHILDREN),
    value: None,
};

pub static VARS_INV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("igor"),
        dictgen::InsensitiveStr::Ascii("igour"),
    ],
    values: &[
        &[(0b10001, &ENTRY_INVIGOR_14173497971570465880)],
        &[(0b11010, &ENTRY_INVIGOR_14173497971570465880)],
    ],
    range: 4..=5,
};

static VARS_INT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_INT_CHILDREN),
    value: None,
};

static VARS_INT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_INTE_NODE),
    None,
    None,
    Some(&VARS_INTH_NODE),
    Some(&VARS_INTI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_INTR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_INTR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTR_CHILDREN),
    value: None,
};

pub static VARS_INTR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aorganisation"),
        dictgen::InsensitiveStr::Ascii("aorganisations"),
        dictgen::InsensitiveStr::Ascii("aorganization"),
        dictgen::InsensitiveStr::Ascii("aorganizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTRAORGANIZATION_8702660329036380979)],
        &[(0b10010, &ENTRY_INTRAORGANIZATIONS_1216554799512649042)],
        &[(0b01001, &ENTRY_INTRAORGANIZATION_8702660329036380979)],
        &[(0b01001, &ENTRY_INTRAORGANIZATIONS_1216554799512649042)],
    ],
    range: 13..=14,
};

static VARS_INTI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTI_CHILDREN),
    value: None,
};

pub static VARS_INTI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mae"),
        dictgen::InsensitiveStr::Ascii("me"),
    ],
    values: &[
        &[(0b11010, &ENTRY_INTIME_16056492823113439440)],
        &[(0b00001, &ENTRY_INTIME_16056492823113439440)],
    ],
    range: 2..=3,
};

static VARS_INTH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTH_CHILDREN),
    value: None,
};

pub static VARS_INTH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rall"),
        dictgen::InsensitiveStr::Ascii("ralled"),
        dictgen::InsensitiveStr::Ascii("ralling"),
        dictgen::InsensitiveStr::Ascii("ralls"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ENTHRALL_16443508848218743746)],
        &[(0b11010, &ENTRY_ENTHRALLED_15327783804003895042)],
        &[(0b11010, &ENTRY_ENTHRALLING_13370984936544117104)],
        &[(0b10010, &ENTRY_ENTHRALLS_4618745032526572838)],
    ],
    range: 4..=7,
};

static VARS_INTE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_INTE_CHILDREN),
    value: None,
};

static VARS_INTE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_INTEG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_INTEL_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_INTER_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_INTER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_INTER_CHILDREN),
    value: None,
};

static VARS_INTER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_INTERC_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_INTERH_NODE),
    Some(&VARS_INTERI_NODE),
    Some(&VARS_INTERJ_NODE),
    None,
    None,
    None,
    Some(&VARS_INTERN_NODE),
    Some(&VARS_INTERO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_INTERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERO_CHILDREN),
    value: None,
};

pub static VARS_INTERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisational"),
        dictgen::InsensitiveStr::Ascii("rganizational"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERORGANIZATIONAL_3810231326080050928)],
        &[(0b01001, &ENTRY_INTERORGANIZATIONAL_3810231326080050928)],
    ],
    range: 13..=13,
};

static VARS_INTERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERN_CHILDREN),
    value: None,
};

pub static VARS_INTERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalised"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalising"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalized"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
        dictgen::InsensitiveStr::Ascii("ationalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERNALIZATION_159848461615772073)],
        &[(0b10010, &ENTRY_INTERNALIZATIONS_3319603770245748552)],
        &[(0b10010, &ENTRY_INTERNALIZE_9052410837903434140)],
        &[(0b10010, &ENTRY_INTERNALIZED_17544531137085832812)],
        &[(0b10010, &ENTRY_INTERNALIZES_3719150015182585151)],
        &[(0b10010, &ENTRY_INTERNALIZING_4943964155563804031)],
        &[(0b01001, &ENTRY_INTERNALIZATION_159848461615772073)],
        &[(0b01001, &ENTRY_INTERNALIZATIONS_3319603770245748552)],
        &[(0b01001, &ENTRY_INTERNALIZE_9052410837903434140)],
        &[(0b01001, &ENTRY_INTERNALIZED_17544531137085832812)],
        &[(0b01001, &ENTRY_INTERNALIZES_3719150015182585151)],
        &[(0b01001, &ENTRY_INTERNALIZING_4943964155563804031)],
        &[(0b10010, &ENTRY_INTERNATIONALIZATION_8109207030063572661)],
        &[(0b10010, &ENTRY_INTERNATIONALIZATIONS_11949350599612691638)],
        &[(0b10010, &ENTRY_INTERNATIONALIZE_9450963003714748234)],
        &[(0b10010, &ENTRY_INTERNATIONALIZED_7366505194713879567)],
        &[(0b10010, &ENTRY_INTERNATIONALIZES_6120281846937694012)],
        &[(0b10010, &ENTRY_INTERNATIONALIZING_12026461136750240322)],
        &[(0b01001, &ENTRY_INTERNATIONALIZATION_8109207030063572661)],
        &[(0b01001, &ENTRY_INTERNATIONALIZATIONS_11949350599612691638)],
        &[(0b01001, &ENTRY_INTERNATIONALIZE_9450963003714748234)],
        &[(0b01001, &ENTRY_INTERNATIONALIZED_7366505194713879567)],
        &[(0b01001, &ENTRY_INTERNATIONALIZES_6120281846937694012)],
        &[(0b01001, &ENTRY_INTERNATIONALIZING_12026461136750240322)],
    ],
    range: 5..=15,
};

static VARS_INTERJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERJ_CHILDREN),
    value: None,
};

pub static VARS_INTERJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectionalise"),
        dictgen::InsensitiveStr::Ascii("ectionalised"),
        dictgen::InsensitiveStr::Ascii("ectionalises"),
        dictgen::InsensitiveStr::Ascii("ectionalising"),
        dictgen::InsensitiveStr::Ascii("ectionalize"),
        dictgen::InsensitiveStr::Ascii("ectionalized"),
        dictgen::InsensitiveStr::Ascii("ectionalizes"),
        dictgen::InsensitiveStr::Ascii("ectionalizing"),
        dictgen::InsensitiveStr::Ascii("ectionise"),
        dictgen::InsensitiveStr::Ascii("ectionises"),
        dictgen::InsensitiveStr::Ascii("ectionize"),
        dictgen::InsensitiveStr::Ascii("ectionizes"),
        dictgen::InsensitiveStr::Ascii("udgement"),
        dictgen::InsensitiveStr::Ascii("udgements"),
        dictgen::InsensitiveStr::Ascii("udgment"),
        dictgen::InsensitiveStr::Ascii("udgments"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERJECTIONALIZE_591313385604347967)],
        &[(0b10010, &ENTRY_INTERJECTIONALIZED_5045489232723081851)],
        &[(0b10010, &ENTRY_INTERJECTIONALIZES_13914305345512718530)],
        &[(0b10010, &ENTRY_INTERJECTIONALIZING_10094859053830302207)],
        &[(0b01001, &ENTRY_INTERJECTIONALIZE_591313385604347967)],
        &[(0b01001, &ENTRY_INTERJECTIONALIZED_5045489232723081851)],
        &[(0b01001, &ENTRY_INTERJECTIONALIZES_13914305345512718530)],
        &[(0b01001, &ENTRY_INTERJECTIONALIZING_10094859053830302207)],
        &[(0b10010, &ENTRY_INTERJECTIONIZE_4980810915948512817)],
        &[(0b10010, &ENTRY_INTERJECTIONIZES_14093916347873886338)],
        &[(0b01001, &ENTRY_INTERJECTIONIZE_4980810915948512817)],
        &[(0b01001, &ENTRY_INTERJECTIONIZES_14093916347873886338)],
        &[(0b11010, &ENTRY_INTERJUDGMENT_8612456108918427681)],
        &[(0b11010, &ENTRY_INTERJUDGMENTS_14759052647054024995)],
        &[(0b00001, &ENTRY_INTERJUDGMENT_8612456108918427681)],
        &[(0b00001, &ENTRY_INTERJUDGMENTS_14759052647054024995)],
    ],
    range: 7..=13,
};

static VARS_INTERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERI_CHILDREN),
    value: None,
};

pub static VARS_INTERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERIORIZATION_13293072248187546000)],
        &[(0b10010, &ENTRY_INTERIORIZE_3609227527138000868)],
        &[(0b10010, &ENTRY_INTERIORIZED_16350287523422070128)],
        &[(0b10010, &ENTRY_INTERIORIZES_17359761587243653961)],
        &[(0b10010, &ENTRY_INTERIORIZING_4323238478406514613)],
        &[(0b01001, &ENTRY_INTERIORIZATION_13293072248187546000)],
        &[(0b01001, &ENTRY_INTERIORIZE_3609227527138000868)],
        &[(0b01001, &ENTRY_INTERIORIZED_16350287523422070128)],
        &[(0b01001, &ENTRY_INTERIORIZES_17359761587243653961)],
        &[(0b01001, &ENTRY_INTERIORIZING_4323238478406514613)],
    ],
    range: 5..=9,
};

static VARS_INTERH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERH_CHILDREN),
    value: None,
};

pub static VARS_INTERH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemal"),
        dictgen::InsensitiveStr::Ascii("emal"),
        dictgen::InsensitiveStr::Ascii("ybridise"),
        dictgen::InsensitiveStr::Ascii("ybridises"),
        dictgen::InsensitiveStr::Ascii("ybridize"),
        dictgen::InsensitiveStr::Ascii("ybridizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_INTERHEMAL_8069091550193247477)],
        &[(0b10001, &ENTRY_INTERHEMAL_8069091550193247477)],
        &[(0b10010, &ENTRY_INTERHYBRIDIZE_11428419392867696597)],
        &[(0b10010, &ENTRY_INTERHYBRIDIZES_15088740729497120786)],
        &[(0b01001, &ENTRY_INTERHYBRIDIZE_11428419392867696597)],
        &[(0b01001, &ENTRY_INTERHYBRIDIZES_15088740729497120786)],
    ],
    range: 4..=9,
};

static VARS_INTERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTERC_CHILDREN),
    value: None,
};

pub static VARS_INTERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("olonisation"),
        dictgen::InsensitiveStr::Ascii("olonisations"),
        dictgen::InsensitiveStr::Ascii("olonization"),
        dictgen::InsensitiveStr::Ascii("olonizations"),
        dictgen::InsensitiveStr::Ascii("rystallisation"),
        dictgen::InsensitiveStr::Ascii("rystallisations"),
        dictgen::InsensitiveStr::Ascii("rystallise"),
        dictgen::InsensitiveStr::Ascii("rystallises"),
        dictgen::InsensitiveStr::Ascii("rystallization"),
        dictgen::InsensitiveStr::Ascii("rystallizations"),
        dictgen::InsensitiveStr::Ascii("rystallize"),
        dictgen::InsensitiveStr::Ascii("rystallizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTERCIVILIZATION_10438802679590964516)],
        &[(0b10010, &ENTRY_INTERCIVILIZATIONS_16686447883834461544)],
        &[(0b01001, &ENTRY_INTERCIVILIZATION_10438802679590964516)],
        &[(0b01001, &ENTRY_INTERCIVILIZATIONS_16686447883834461544)],
        &[(0b10010, &ENTRY_INTERCOLONIZATION_9529792773429446590)],
        &[(0b10010, &ENTRY_INTERCOLONIZATIONS_1193684945774928129)],
        &[(0b01001, &ENTRY_INTERCOLONIZATION_9529792773429446590)],
        &[(0b01001, &ENTRY_INTERCOLONIZATIONS_1193684945774928129)],
        &[(0b10010, &ENTRY_INTERCRYSTALLIZATION_535306253275539668)],
        &[(0b10010, &ENTRY_INTERCRYSTALLIZATIONS_15715918494142587543)],
        &[(0b10010, &ENTRY_INTERCRYSTALLIZE_7702248759277822441)],
        &[(0b10010, &ENTRY_INTERCRYSTALLIZES_13807609427203436454)],
        &[(0b01001, &ENTRY_INTERCRYSTALLIZATION_535306253275539668)],
        &[(0b01001, &ENTRY_INTERCRYSTALLIZATIONS_15715918494142587543)],
        &[(0b01001, &ENTRY_INTERCRYSTALLIZE_7702248759277822441)],
        &[(0b01001, &ENTRY_INTERCRYSTALLIZES_13807609427203436454)],
    ],
    range: 10..=15,
};

static VARS_INTEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTEL_CHILDREN),
    value: None,
};

pub static VARS_INTEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lectualisation"),
        dictgen::InsensitiveStr::Ascii("lectualisations"),
        dictgen::InsensitiveStr::Ascii("lectualise"),
        dictgen::InsensitiveStr::Ascii("lectualised"),
        dictgen::InsensitiveStr::Ascii("lectualiser"),
        dictgen::InsensitiveStr::Ascii("lectualisers"),
        dictgen::InsensitiveStr::Ascii("lectualises"),
        dictgen::InsensitiveStr::Ascii("lectualising"),
        dictgen::InsensitiveStr::Ascii("lectualization"),
        dictgen::InsensitiveStr::Ascii("lectualizations"),
        dictgen::InsensitiveStr::Ascii("lectualize"),
        dictgen::InsensitiveStr::Ascii("lectualized"),
        dictgen::InsensitiveStr::Ascii("lectualizer"),
        dictgen::InsensitiveStr::Ascii("lectualizers"),
        dictgen::InsensitiveStr::Ascii("lectualizes"),
        dictgen::InsensitiveStr::Ascii("lectualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTELLECTUALIZATION_5006098909718239143)],
        &[(0b10010, &ENTRY_INTELLECTUALIZATIONS_3199889427953063623)],
        &[(0b10010, &ENTRY_INTELLECTUALIZE_6007564803782987842)],
        &[(0b10010, &ENTRY_INTELLECTUALIZED_8385887282030505172)],
        &[(0b10010, &ENTRY_INTELLECTUALIZER_17482373382110935014)],
        &[(0b10010, &ENTRY_INTELLECTUALIZERS_11392986022853877080)],
        &[(0b10010, &ENTRY_INTELLECTUALIZES_10524380563631063928)],
        &[(0b10010, &ENTRY_INTELLECTUALIZING_11856597360745053121)],
        &[(0b01001, &ENTRY_INTELLECTUALIZATION_5006098909718239143)],
        &[(0b01001, &ENTRY_INTELLECTUALIZATIONS_3199889427953063623)],
        &[(0b01001, &ENTRY_INTELLECTUALIZE_6007564803782987842)],
        &[(0b01001, &ENTRY_INTELLECTUALIZED_8385887282030505172)],
        &[(0b01001, &ENTRY_INTELLECTUALIZER_17482373382110935014)],
        &[(0b01001, &ENTRY_INTELLECTUALIZERS_11392986022853877080)],
        &[(0b01001, &ENTRY_INTELLECTUALIZES_10524380563631063928)],
        &[(0b01001, &ENTRY_INTELLECTUALIZING_11856597360745053121)],
    ],
    range: 10..=15,
};

static VARS_INTEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INTEG_CHILDREN),
    value: None,
};

pub static VARS_INTEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INTEGRALIZATION_14909799739781830655)],
        &[(0b10010, &ENTRY_INTEGRALIZATIONS_14841454090292389979)],
        &[(0b10010, &ENTRY_INTEGRALIZE_4227561325105793311)],
        &[(0b10010, &ENTRY_INTEGRALIZES_16303894927038567041)],
        &[(0b01001, &ENTRY_INTEGRALIZATION_14909799739781830655)],
        &[(0b01001, &ENTRY_INTEGRALIZATIONS_14841454090292389979)],
        &[(0b01001, &ENTRY_INTEGRALIZE_4227561325105793311)],
        &[(0b01001, &ENTRY_INTEGRALIZES_16303894927038567041)],
    ],
    range: 6..=11,
};

static VARS_INS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INS_CHILDREN),
    value: None,
};

pub static VARS_INS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olubilisation"),
        dictgen::InsensitiveStr::Ascii("olubilise"),
        dictgen::InsensitiveStr::Ascii("olubilised"),
        dictgen::InsensitiveStr::Ascii("olubilises"),
        dictgen::InsensitiveStr::Ascii("olubilising"),
        dictgen::InsensitiveStr::Ascii("olubilization"),
        dictgen::InsensitiveStr::Ascii("olubilize"),
        dictgen::InsensitiveStr::Ascii("olubilized"),
        dictgen::InsensitiveStr::Ascii("olubilizes"),
        dictgen::InsensitiveStr::Ascii("olubilizing"),
        dictgen::InsensitiveStr::Ascii("tal"),
        dictgen::InsensitiveStr::Ascii("tallment"),
        dictgen::InsensitiveStr::Ascii("tallments"),
        dictgen::InsensitiveStr::Ascii("talment"),
        dictgen::InsensitiveStr::Ascii("talments"),
        dictgen::InsensitiveStr::Ascii("tals"),
        dictgen::InsensitiveStr::Ascii("til"),
        dictgen::InsensitiveStr::Ascii("tils"),
        dictgen::InsensitiveStr::Ascii("titutionalisation"),
        dictgen::InsensitiveStr::Ascii("titutionalisations"),
        dictgen::InsensitiveStr::Ascii("titutionalise"),
        dictgen::InsensitiveStr::Ascii("titutionalised"),
        dictgen::InsensitiveStr::Ascii("titutionalises"),
        dictgen::InsensitiveStr::Ascii("titutionalising"),
        dictgen::InsensitiveStr::Ascii("titutionalization"),
        dictgen::InsensitiveStr::Ascii("titutionalizations"),
        dictgen::InsensitiveStr::Ascii("titutionalize"),
        dictgen::InsensitiveStr::Ascii("titutionalized"),
        dictgen::InsensitiveStr::Ascii("titutionalizes"),
        dictgen::InsensitiveStr::Ascii("titutionalizing"),
        dictgen::InsensitiveStr::Ascii("titutionise"),
        dictgen::InsensitiveStr::Ascii("titutionises"),
        dictgen::InsensitiveStr::Ascii("titutionize"),
        dictgen::InsensitiveStr::Ascii("titutionizes"),
        dictgen::InsensitiveStr::Ascii("trumentalise"),
        dictgen::InsensitiveStr::Ascii("trumentalises"),
        dictgen::InsensitiveStr::Ascii("trumentalize"),
        dictgen::InsensitiveStr::Ascii("trumentalizes"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("urrectionise"),
        dictgen::InsensitiveStr::Ascii("urrectionised"),
        dictgen::InsensitiveStr::Ascii("urrectionises"),
        dictgen::InsensitiveStr::Ascii("urrectionising"),
        dictgen::InsensitiveStr::Ascii("urrectionize"),
        dictgen::InsensitiveStr::Ascii("urrectionized"),
        dictgen::InsensitiveStr::Ascii("urrectionizes"),
        dictgen::InsensitiveStr::Ascii("urrectionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INSOLUBILIZATION_2624933827226592167)],
        &[(0b10010, &ENTRY_INSOLUBILIZE_16190378805001128650)],
        &[(0b10010, &ENTRY_INSOLUBILIZED_11559003470253032575)],
        &[(0b10010, &ENTRY_INSOLUBILIZES_2928855643803441236)],
        &[(0b10010, &ENTRY_INSOLUBILIZING_17373219238380218554)],
        &[(0b01001, &ENTRY_INSOLUBILIZATION_2624933827226592167)],
        &[(0b01001, &ENTRY_INSOLUBILIZE_16190378805001128650)],
        &[(0b01001, &ENTRY_INSOLUBILIZED_11559003470253032575)],
        &[(0b01001, &ENTRY_INSOLUBILIZES_2928855643803441236)],
        &[(0b01001, &ENTRY_INSOLUBILIZING_17373219238380218554)],
        &[(0b11010, &ENTRY_INSTALL_1232036630970101636)],
        &[(0b01001, &ENTRY_INSTALLMENT_15955257315912152068)],
        &[(0b01001, &ENTRY_INSTALLMENTS_6628253336902494309)],
        &[(0b11010, &ENTRY_INSTALLMENT_15955257315912152068)],
        &[(0b11010, &ENTRY_INSTALLMENTS_6628253336902494309)],
        &[(0b11010, &ENTRY_INSTALLS_10741039873860965951)],
        &[(0b11010, &ENTRY_INSTILL_12975407349726514336)],
        &[(0b11010, &ENTRY_INSTILLS_8131073218211206010)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZATION_3187856750627910628)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZATIONS_12755904320513262139)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZE_2368732057929198536)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZED_662778395420998219)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZES_12707267082253355926)],
        &[(0b10010, &ENTRY_INSTITUTIONALIZING_5314493516630022554)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZATION_3187856750627910628)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZATIONS_12755904320513262139)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZE_2368732057929198536)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZED_662778395420998219)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZES_12707267082253355926)],
        &[(0b01001, &ENTRY_INSTITUTIONALIZING_5314493516630022554)],
        &[(0b10010, &ENTRY_INSTITUTIONIZE_10372940805349027641)],
        &[(0b10010, &ENTRY_INSTITUTIONIZES_10150724383117783571)],
        &[(0b01001, &ENTRY_INSTITUTIONIZE_10372940805349027641)],
        &[(0b01001, &ENTRY_INSTITUTIONIZES_10150724383117783571)],
        &[(0b10010, &ENTRY_INSTRUMENTALIZE_14933680729070542221)],
        &[(0b10010, &ENTRY_INSTRUMENTALIZES_16506735465128047968)],
        &[(0b01001, &ENTRY_INSTRUMENTALIZE_14933680729070542221)],
        &[(0b01001, &ENTRY_INSTRUMENTALIZES_16506735465128047968)],
        &[(0b10010, &ENTRY_INSULARIZE_9177745690473314239)],
        &[(0b10010, &ENTRY_INSULARIZES_6595980328038128413)],
        &[(0b01001, &ENTRY_INSULARIZE_9177745690473314239)],
        &[(0b01001, &ENTRY_INSULARIZES_6595980328038128413)],
        &[(0b10010, &ENTRY_INSURRECTIONIZE_13973633585951003277)],
        &[(0b10010, &ENTRY_INSURRECTIONIZED_9902157018267694954)],
        &[(0b10010, &ENTRY_INSURRECTIONIZES_15593571003663123617)],
        &[(0b10010, &ENTRY_INSURRECTIONIZING_9230576022597150453)],
        &[(0b01001, &ENTRY_INSURRECTIONIZE_13973633585951003277)],
        &[(0b01001, &ENTRY_INSURRECTIONIZED_9902157018267694954)],
        &[(0b01001, &ENTRY_INSURRECTIONIZES_15593571003663123617)],
        &[(0b01001, &ENTRY_INSURRECTIONIZING_9230576022597150453)],
    ],
    range: 3..=18,
};

static VARS_INO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INO_CHILDREN),
    value: None,
};

pub static VARS_INO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INORGANIZATION_11855467122026486374)],
        &[(0b10010, &ENTRY_INORGANIZATIONS_3786296158259671895)],
        &[(0b10010, &ENTRY_INORGANIZED_11175057158204772809)],
        &[(0b01001, &ENTRY_INORGANIZATION_11855467122026486374)],
        &[(0b01001, &ENTRY_INORGANIZATIONS_3786296158259671895)],
        &[(0b01001, &ENTRY_INORGANIZED_11175057158204772809)],
    ],
    range: 8..=12,
};

static VARS_INI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INI_CHILDREN),
    value: None,
};

pub static VARS_INI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tialed"),
        dictgen::InsensitiveStr::Ascii("tialer"),
        dictgen::InsensitiveStr::Ascii("tialers"),
        dictgen::InsensitiveStr::Ascii("tialing"),
        dictgen::InsensitiveStr::Ascii("tialisable"),
        dictgen::InsensitiveStr::Ascii("tialisation"),
        dictgen::InsensitiveStr::Ascii("tialisations"),
        dictgen::InsensitiveStr::Ascii("tialise"),
        dictgen::InsensitiveStr::Ascii("tialised"),
        dictgen::InsensitiveStr::Ascii("tialiser"),
        dictgen::InsensitiveStr::Ascii("tialisers"),
        dictgen::InsensitiveStr::Ascii("tialises"),
        dictgen::InsensitiveStr::Ascii("tialising"),
        dictgen::InsensitiveStr::Ascii("tializable"),
        dictgen::InsensitiveStr::Ascii("tialization"),
        dictgen::InsensitiveStr::Ascii("tializations"),
        dictgen::InsensitiveStr::Ascii("tialize"),
        dictgen::InsensitiveStr::Ascii("tialized"),
        dictgen::InsensitiveStr::Ascii("tializer"),
        dictgen::InsensitiveStr::Ascii("tializers"),
        dictgen::InsensitiveStr::Ascii("tializes"),
        dictgen::InsensitiveStr::Ascii("tializing"),
        dictgen::InsensitiveStr::Ascii("tialled"),
        dictgen::InsensitiveStr::Ascii("tialler"),
        dictgen::InsensitiveStr::Ascii("tiallers"),
        dictgen::InsensitiveStr::Ascii("tialling"),
    ],
    values: &[
        &[(0b01001, &ENTRY_INITIALED_1122623591354647527)],
        &[(0b00001, &ENTRY_INITIALER_6151200791899571202)],
        &[(0b00001, &ENTRY_INITIALERS_3062657226262961390)],
        &[(0b01001, &ENTRY_INITIALING_14617210175952400635)],
        &[(0b10010, &ENTRY_INITIALIZABLE_7321355618285398649)],
        &[(0b10010, &ENTRY_INITIALIZATION_13629327501468098349)],
        &[(0b10010, &ENTRY_INITIALIZATIONS_9980554775185315575)],
        &[(0b10010, &ENTRY_INITIALIZE_14137997308893047575)],
        &[(0b10010, &ENTRY_INITIALIZED_7587168812809071543)],
        &[(0b10010, &ENTRY_INITIALIZER_4018135888541909006)],
        &[(0b10010, &ENTRY_INITIALIZERS_12398839316559453843)],
        &[(0b10010, &ENTRY_INITIALIZES_6563132601688087865)],
        &[(0b10010, &ENTRY_INITIALIZING_7489678212739024329)],
        &[(0b01001, &ENTRY_INITIALIZABLE_7321355618285398649)],
        &[(0b01001, &ENTRY_INITIALIZATION_13629327501468098349)],
        &[(0b01001, &ENTRY_INITIALIZATIONS_9980554775185315575)],
        &[(0b01001, &ENTRY_INITIALIZE_14137997308893047575)],
        &[(0b01001, &ENTRY_INITIALIZED_7587168812809071543)],
        &[(0b01001, &ENTRY_INITIALIZER_4018135888541909006)],
        &[(0b01001, &ENTRY_INITIALIZERS_12398839316559453843)],
        &[(0b01001, &ENTRY_INITIALIZES_6563132601688087865)],
        &[(0b01001, &ENTRY_INITIALIZING_7489678212739024329)],
        &[(0b11010, &ENTRY_INITIALED_1122623591354647527)],
        &[(0b11010, &ENTRY_INITIALER_6151200791899571202)],
        &[(0b11010, &ENTRY_INITIALERS_3062657226262961390)],
        &[(0b11010, &ENTRY_INITIALING_14617210175952400635)],
    ],
    range: 6..=12,
};

static VARS_INH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INH_CHILDREN),
    value: None,
};

pub static VARS_INH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INHUMANIZE_1125531716586320140)],
        &[(0b10010, &ENTRY_INHUMANIZES_5657328343169490122)],
        &[(0b01001, &ENTRY_INHUMANIZE_1125531716586320140)],
        &[(0b01001, &ENTRY_INHUMANIZES_5657328343169490122)],
    ],
    range: 7..=8,
};

static VARS_ING_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ING_CHILDREN),
    value: None,
};

pub static VARS_ING_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("vaeonic"),
        dictgen::InsensitiveStr::Ascii("veonic"),
        dictgen::InsensitiveStr::Ascii("waeonic"),
        dictgen::InsensitiveStr::Ascii("weonic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_INGVEONIC_455635617998549394)],
        &[(0b00001, &ENTRY_INGVEONIC_455635617998549394)],
        &[(0b11010, &ENTRY_INGWEONIC_3016657805432955135)],
        &[(0b00001, &ENTRY_INGWEONIC_3016657805432955135)],
    ],
    range: 6..=7,
};

static VARS_INF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INF_CHILDREN),
    value: None,
};

pub static VARS_INF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amise"),
        dictgen::InsensitiveStr::Ascii("amised"),
        dictgen::InsensitiveStr::Ascii("amises"),
        dictgen::InsensitiveStr::Ascii("amising"),
        dictgen::InsensitiveStr::Ascii("amize"),
        dictgen::InsensitiveStr::Ascii("amized"),
        dictgen::InsensitiveStr::Ascii("amizes"),
        dictgen::InsensitiveStr::Ascii("amizing"),
        dictgen::InsensitiveStr::Ascii("amonise"),
        dictgen::InsensitiveStr::Ascii("amonised"),
        dictgen::InsensitiveStr::Ascii("amonises"),
        dictgen::InsensitiveStr::Ascii("amonising"),
        dictgen::InsensitiveStr::Ascii("amonize"),
        dictgen::InsensitiveStr::Ascii("amonized"),
        dictgen::InsensitiveStr::Ascii("amonizes"),
        dictgen::InsensitiveStr::Ascii("amonizing"),
        dictgen::InsensitiveStr::Ascii("ere"),
        dictgen::InsensitiveStr::Ascii("eriorise"),
        dictgen::InsensitiveStr::Ascii("eriorises"),
        dictgen::InsensitiveStr::Ascii("eriorize"),
        dictgen::InsensitiveStr::Ascii("eriorizes"),
        dictgen::InsensitiveStr::Ascii("ernalise"),
        dictgen::InsensitiveStr::Ascii("ernalises"),
        dictgen::InsensitiveStr::Ascii("ernalize"),
        dictgen::InsensitiveStr::Ascii("ernalizes"),
        dictgen::InsensitiveStr::Ascii("idelise"),
        dictgen::InsensitiveStr::Ascii("idelises"),
        dictgen::InsensitiveStr::Ascii("idelize"),
        dictgen::InsensitiveStr::Ascii("idelizes"),
        dictgen::InsensitiveStr::Ascii("initise"),
        dictgen::InsensitiveStr::Ascii("initises"),
        dictgen::InsensitiveStr::Ascii("initize"),
        dictgen::InsensitiveStr::Ascii("initizes"),
        dictgen::InsensitiveStr::Ascii("lexion"),
        dictgen::InsensitiveStr::Ascii("lexions"),
        dictgen::InsensitiveStr::Ascii("ormalise"),
        dictgen::InsensitiveStr::Ascii("ormalises"),
        dictgen::InsensitiveStr::Ascii("ormalize"),
        dictgen::InsensitiveStr::Ascii("ormalizes"),
        dictgen::InsensitiveStr::Ascii("ree"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INFAMIZE_9505936708834210302)],
        &[(0b10010, &ENTRY_INFAMIZED_8107492535730330362)],
        &[(0b10010, &ENTRY_INFAMIZES_13859908196515724665)],
        &[(0b10010, &ENTRY_INFAMIZING_2418856263638143206)],
        &[(0b01001, &ENTRY_INFAMIZE_9505936708834210302)],
        &[(0b01001, &ENTRY_INFAMIZED_8107492535730330362)],
        &[(0b01001, &ENTRY_INFAMIZES_13859908196515724665)],
        &[(0b01001, &ENTRY_INFAMIZING_2418856263638143206)],
        &[(0b10010, &ENTRY_INFAMONIZE_1912633598113446535)],
        &[(0b10010, &ENTRY_INFAMONIZED_12631432978176771320)],
        &[(0b10010, &ENTRY_INFAMONIZES_828661709748784693)],
        &[(0b10010, &ENTRY_INFAMONIZING_3560185438718299549)],
        &[(0b01001, &ENTRY_INFAMONIZE_1912633598113446535)],
        &[(0b01001, &ENTRY_INFAMONIZED_12631432978176771320)],
        &[(0b01001, &ENTRY_INFAMONIZES_828661709748784693)],
        &[(0b01001, &ENTRY_INFAMONIZING_3560185438718299549)],
        &[(0b00001, &ENTRY_INFERE_12081519587041032918)],
        &[(0b10010, &ENTRY_INFERIORIZE_18055626716137479185)],
        &[(0b10010, &ENTRY_INFERIORIZES_13851169502462205708)],
        &[(0b01001, &ENTRY_INFERIORIZE_18055626716137479185)],
        &[(0b01001, &ENTRY_INFERIORIZES_13851169502462205708)],
        &[(0b10010, &ENTRY_INFERNALIZE_271646759477051771)],
        &[(0b10010, &ENTRY_INFERNALIZES_12015516847502853908)],
        &[(0b01001, &ENTRY_INFERNALIZE_271646759477051771)],
        &[(0b01001, &ENTRY_INFERNALIZES_12015516847502853908)],
        &[(0b10010, &ENTRY_INFIDELIZE_12024929451033396652)],
        &[(0b10010, &ENTRY_INFIDELIZES_9998852219255855475)],
        &[(0b01001, &ENTRY_INFIDELIZE_12024929451033396652)],
        &[(0b01001, &ENTRY_INFIDELIZES_9998852219255855475)],
        &[(0b10010, &ENTRY_INFINITIZE_12913263953737511613)],
        &[(0b10010, &ENTRY_INFINITIZES_16900614083188680149)],
        &[(0b01001, &ENTRY_INFINITIZE_12913263953737511613)],
        &[(0b01001, &ENTRY_INFINITIZES_16900614083188680149)],
        &[(0b10010, &ENTRY_INFLECTION_13441227020426228543)],
        &[(0b10010, &ENTRY_INFLECTIONS_3311441335165237996)],
        &[(0b10010, &ENTRY_INFORMALIZE_17826170607752662140)],
        &[(0b10010, &ENTRY_INFORMALIZES_10886097819718009126)],
        &[(0b01001, &ENTRY_INFORMALIZE_17826170607752662140)],
        &[(0b01001, &ENTRY_INFORMALIZES_10886097819718009126)],
        &[(0b11010, &ENTRY_INFERE_12081519587041032918)],
    ],
    range: 3..=9,
};

static VARS_INE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INE_CHILDREN),
    value: None,
};

pub static VARS_INE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("sthetic")],
    values: &[&[(0b00001, &ENTRY_INESTHETIC_8618358610512556728)]],
    range: 7..=7,
};

static VARS_IND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IND_CHILDREN),
    value: None,
};

pub static VARS_IND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ianisation"),
        dictgen::InsensitiveStr::Ascii("ianise"),
        dictgen::InsensitiveStr::Ascii("ianised"),
        dictgen::InsensitiveStr::Ascii("ianises"),
        dictgen::InsensitiveStr::Ascii("ianising"),
        dictgen::InsensitiveStr::Ascii("ianization"),
        dictgen::InsensitiveStr::Ascii("ianize"),
        dictgen::InsensitiveStr::Ascii("ianized"),
        dictgen::InsensitiveStr::Ascii("ianizes"),
        dictgen::InsensitiveStr::Ascii("ianizing"),
        dictgen::InsensitiveStr::Ascii("igenae"),
        dictgen::InsensitiveStr::Ascii("igene"),
        dictgen::InsensitiveStr::Ascii("igenisation"),
        dictgen::InsensitiveStr::Ascii("igenisations"),
        dictgen::InsensitiveStr::Ascii("igenise"),
        dictgen::InsensitiveStr::Ascii("igenised"),
        dictgen::InsensitiveStr::Ascii("igenises"),
        dictgen::InsensitiveStr::Ascii("igenising"),
        dictgen::InsensitiveStr::Ascii("igenization"),
        dictgen::InsensitiveStr::Ascii("igenizations"),
        dictgen::InsensitiveStr::Ascii("igenize"),
        dictgen::InsensitiveStr::Ascii("igenized"),
        dictgen::InsensitiveStr::Ascii("igenizes"),
        dictgen::InsensitiveStr::Ascii("igenizing"),
        dictgen::InsensitiveStr::Ascii("ividualisation"),
        dictgen::InsensitiveStr::Ascii("ividualisations"),
        dictgen::InsensitiveStr::Ascii("ividualise"),
        dictgen::InsensitiveStr::Ascii("ividualised"),
        dictgen::InsensitiveStr::Ascii("ividualiser"),
        dictgen::InsensitiveStr::Ascii("ividualisers"),
        dictgen::InsensitiveStr::Ascii("ividualises"),
        dictgen::InsensitiveStr::Ascii("ividualising"),
        dictgen::InsensitiveStr::Ascii("ividualisingly"),
        dictgen::InsensitiveStr::Ascii("ividualization"),
        dictgen::InsensitiveStr::Ascii("ividualizations"),
        dictgen::InsensitiveStr::Ascii("ividualize"),
        dictgen::InsensitiveStr::Ascii("ividualized"),
        dictgen::InsensitiveStr::Ascii("ividualizer"),
        dictgen::InsensitiveStr::Ascii("ividualizers"),
        dictgen::InsensitiveStr::Ascii("ividualizes"),
        dictgen::InsensitiveStr::Ascii("ividualizing"),
        dictgen::InsensitiveStr::Ascii("ividualizingly"),
        dictgen::InsensitiveStr::Ascii("raft"),
        dictgen::InsensitiveStr::Ascii("rafts"),
        dictgen::InsensitiveStr::Ascii("raught"),
        dictgen::InsensitiveStr::Ascii("raughts"),
        dictgen::InsensitiveStr::Ascii("ustrialisation"),
        dictgen::InsensitiveStr::Ascii("ustrialisations"),
        dictgen::InsensitiveStr::Ascii("ustrialise"),
        dictgen::InsensitiveStr::Ascii("ustrialised"),
        dictgen::InsensitiveStr::Ascii("ustrialises"),
        dictgen::InsensitiveStr::Ascii("ustrialising"),
        dictgen::InsensitiveStr::Ascii("ustrialization"),
        dictgen::InsensitiveStr::Ascii("ustrializations"),
        dictgen::InsensitiveStr::Ascii("ustrialize"),
        dictgen::InsensitiveStr::Ascii("ustrialized"),
        dictgen::InsensitiveStr::Ascii("ustrializes"),
        dictgen::InsensitiveStr::Ascii("ustrializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INDIANIZATION_16145413298304712165)],
        &[(0b10010, &ENTRY_INDIANIZE_11979657832545271268)],
        &[(0b10010, &ENTRY_INDIANIZED_6203878007785616549)],
        &[(0b10010, &ENTRY_INDIANIZES_5103097757150832367)],
        &[(0b10010, &ENTRY_INDIANIZING_10380881278589214058)],
        &[(0b01001, &ENTRY_INDIANIZATION_16145413298304712165)],
        &[(0b01001, &ENTRY_INDIANIZE_11979657832545271268)],
        &[(0b01001, &ENTRY_INDIANIZED_6203878007785616549)],
        &[(0b01001, &ENTRY_INDIANIZES_5103097757150832367)],
        &[(0b01001, &ENTRY_INDIANIZING_10380881278589214058)],
        &[(0b11010, &ENTRY_INDIGENE_15049604537921582666)],
        &[(0b00001, &ENTRY_INDIGENE_15049604537921582666)],
        &[(0b10010, &ENTRY_INDIGENIZATION_7957795492779097437)],
        &[(0b10010, &ENTRY_INDIGENIZATIONS_13318481869437423349)],
        &[(0b10010, &ENTRY_INDIGENIZE_17958730421669576658)],
        &[(0b10010, &ENTRY_INDIGENIZED_17113860080855467952)],
        &[(0b10010, &ENTRY_INDIGENIZES_8212488857174469274)],
        &[(0b10010, &ENTRY_INDIGENIZING_5786616818049833426)],
        &[(0b01001, &ENTRY_INDIGENIZATION_7957795492779097437)],
        &[(0b01001, &ENTRY_INDIGENIZATIONS_13318481869437423349)],
        &[(0b01001, &ENTRY_INDIGENIZE_17958730421669576658)],
        &[(0b01001, &ENTRY_INDIGENIZED_17113860080855467952)],
        &[(0b01001, &ENTRY_INDIGENIZES_8212488857174469274)],
        &[(0b01001, &ENTRY_INDIGENIZING_5786616818049833426)],
        &[(0b10010, &ENTRY_INDIVIDUALIZATION_649176936740988346)],
        &[(0b10010, &ENTRY_INDIVIDUALIZATIONS_11118632820394117785)],
        &[(0b10010, &ENTRY_INDIVIDUALIZE_13939176487047243121)],
        &[(0b10010, &ENTRY_INDIVIDUALIZED_16128034337210456768)],
        &[(0b10010, &ENTRY_INDIVIDUALIZER_4182762615893522554)],
        &[(0b10010, &ENTRY_INDIVIDUALIZERS_15913845742563764251)],
        &[(0b10010, &ENTRY_INDIVIDUALIZES_10472470571311764620)],
        &[(0b10010, &ENTRY_INDIVIDUALIZING_8929349970924125846)],
        &[(0b10010, &ENTRY_INDIVIDUALIZINGLY_10770535701165712688)],
        &[(0b01001, &ENTRY_INDIVIDUALIZATION_649176936740988346)],
        &[(0b01001, &ENTRY_INDIVIDUALIZATIONS_11118632820394117785)],
        &[(0b01001, &ENTRY_INDIVIDUALIZE_13939176487047243121)],
        &[(0b01001, &ENTRY_INDIVIDUALIZED_16128034337210456768)],
        &[(0b01001, &ENTRY_INDIVIDUALIZER_4182762615893522554)],
        &[(0b01001, &ENTRY_INDIVIDUALIZERS_15913845742563764251)],
        &[(0b01001, &ENTRY_INDIVIDUALIZES_10472470571311764620)],
        &[(0b01001, &ENTRY_INDIVIDUALIZING_8929349970924125846)],
        &[(0b01001, &ENTRY_INDIVIDUALIZINGLY_10770535701165712688)],
        &[(0b01001, &ENTRY_INDRAFT_906884386745118313)],
        &[(0b01001, &ENTRY_INDRAFTS_5585473109884484359)],
        &[(0b10010, &ENTRY_INDRAFT_906884386745118313)],
        &[(0b10010, &ENTRY_INDRAFTS_5585473109884484359)],
        &[(0b10010, &ENTRY_INDUSTRIALIZATION_3782509534748207782)],
        &[(0b10010, &ENTRY_INDUSTRIALIZATIONS_5781661892562457350)],
        &[(0b10010, &ENTRY_INDUSTRIALIZE_11802203695636303310)],
        &[(0b10010, &ENTRY_INDUSTRIALIZED_2970036951077578679)],
        &[(0b10010, &ENTRY_INDUSTRIALIZES_108463817008379635)],
        &[(0b10010, &ENTRY_INDUSTRIALIZING_4108758435956044036)],
        &[(0b01001, &ENTRY_INDUSTRIALIZATION_3782509534748207782)],
        &[(0b01001, &ENTRY_INDUSTRIALIZATIONS_5781661892562457350)],
        &[(0b01001, &ENTRY_INDUSTRIALIZE_11802203695636303310)],
        &[(0b01001, &ENTRY_INDUSTRIALIZED_2970036951077578679)],
        &[(0b01001, &ENTRY_INDUSTRIALIZES_108463817008379635)],
        &[(0b01001, &ENTRY_INDUSTRIALIZING_4108758435956044036)],
    ],
    range: 4..=15,
};

static VARS_INC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INC_CHILDREN),
    value: None,
};

pub static VARS_INC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arnalise"),
        dictgen::InsensitiveStr::Ascii("arnalised"),
        dictgen::InsensitiveStr::Ascii("arnalising"),
        dictgen::InsensitiveStr::Ascii("arnalize"),
        dictgen::InsensitiveStr::Ascii("arnalized"),
        dictgen::InsensitiveStr::Ascii("arnalizing"),
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entivisation"),
        dictgen::InsensitiveStr::Ascii("entivisations"),
        dictgen::InsensitiveStr::Ascii("entivise"),
        dictgen::InsensitiveStr::Ascii("entivised"),
        dictgen::InsensitiveStr::Ascii("entivises"),
        dictgen::InsensitiveStr::Ascii("entivising"),
        dictgen::InsensitiveStr::Ascii("entivization"),
        dictgen::InsensitiveStr::Ascii("entivizations"),
        dictgen::InsensitiveStr::Ascii("entivize"),
        dictgen::InsensitiveStr::Ascii("entivized"),
        dictgen::InsensitiveStr::Ascii("entivizes"),
        dictgen::InsensitiveStr::Ascii("entivizing"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entres"),
        dictgen::InsensitiveStr::Ascii("erate"),
        dictgen::InsensitiveStr::Ascii("lose"),
        dictgen::InsensitiveStr::Ascii("losed"),
        dictgen::InsensitiveStr::Ascii("loses"),
        dictgen::InsensitiveStr::Ascii("losing"),
        dictgen::InsensitiveStr::Ascii("ognisable"),
        dictgen::InsensitiveStr::Ascii("ognisance"),
        dictgen::InsensitiveStr::Ascii("ognisances"),
        dictgen::InsensitiveStr::Ascii("ognisant"),
        dictgen::InsensitiveStr::Ascii("ognizable"),
        dictgen::InsensitiveStr::Ascii("ognizance"),
        dictgen::InsensitiveStr::Ascii("ognizances"),
        dictgen::InsensitiveStr::Ascii("ognizant"),
        dictgen::InsensitiveStr::Ascii("reate"),
    ],
    values: &[
        &[(0b10010, &ENTRY_INCARNALIZE_7861142043845714587)],
        &[(0b10010, &ENTRY_INCARNALIZED_6333109739765414243)],
        &[(0b10010, &ENTRY_INCARNALIZING_14863074476515763083)],
        &[(0b01001, &ENTRY_INCARNALIZE_7861142043845714587)],
        &[(0b01001, &ENTRY_INCARNALIZED_6333109739765414243)],
        &[(0b01001, &ENTRY_INCARNALIZING_14863074476515763083)],
        &[(0b00001, &ENTRY_INCENTER_9458973874644957428)],
        &[(0b00001, &ENTRY_INCENTERS_16040338651220938626)],
        &[(0b10010, &ENTRY_INCENTIVIZATION_6332222872955507843)],
        &[(0b10010, &ENTRY_INCENTIVIZATIONS_14102392630691423740)],
        &[(0b10010, &ENTRY_INCENTIVIZE_552070002375523113)],
        &[(0b10010, &ENTRY_INCENTIVIZED_2383735849153336951)],
        &[(0b10010, &ENTRY_INCENTIVIZES_16584149161391523509)],
        &[(0b10010, &ENTRY_INCENTIVIZING_15493171350741422018)],
        &[(0b01001, &ENTRY_INCENTIVIZATION_6332222872955507843)],
        &[(0b01001, &ENTRY_INCENTIVIZATIONS_14102392630691423740)],
        &[(0b01001, &ENTRY_INCENTIVIZE_552070002375523113)],
        &[(0b01001, &ENTRY_INCENTIVIZED_2383735849153336951)],
        &[(0b01001, &ENTRY_INCENTIVIZES_16584149161391523509)],
        &[(0b01001, &ENTRY_INCENTIVIZING_15493171350741422018)],
        &[(0b11010, &ENTRY_INCENTER_9458973874644957428)],
        &[(0b11010, &ENTRY_INCENTERS_16040338651220938626)],
        &[(0b00001, &ENTRY_INCERATE_15157256917180496396)],
        &[(0b00001, &ENTRY_ENCLOSE_16455068235111751734)],
        &[(0b00001, &ENTRY_ENCLOSED_13340347130367472311)],
        &[(0b00001, &ENTRY_ENCLOSES_936921542023137950)],
        &[(0b00001, &ENTRY_ENCLOSING_8054071438169915028)],
        &[(0b10010, &ENTRY_INCOGNIZABLE_10607185097022859286)],
        &[(0b10010, &ENTRY_INCOGNIZANCE_6248858370628163819)],
        &[(0b10010, &ENTRY_INCOGNIZANCES_17577781369104818851)],
        &[(0b10010, &ENTRY_INCOGNIZANT_10246562813251688993)],
        &[(0b01001, &ENTRY_INCOGNIZABLE_10607185097022859286)],
        &[(0b01001, &ENTRY_INCOGNIZANCE_6248858370628163819)],
        &[(0b01001, &ENTRY_INCOGNIZANCES_17577781369104818851)],
        &[(0b01001, &ENTRY_INCOGNIZANT_10246562813251688993)],
        &[(0b11010, &ENTRY_INCERATE_15157256917180496396)],
    ],
    range: 4..=13,
};

static VARS_INA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_INA_CHILDREN),
    value: None,
};

pub static VARS_INA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("esthetic")],
    values: &[&[(0b11010, &ENTRY_INESTHETIC_8618358610512556728)]],
    range: 8..=8,
};

static VARS_IM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_IM_CHILDREN),
    value: None,
};

static VARS_IM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_IMB_NODE),
    None,
    None,
    Some(&VARS_IME_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IMM_NODE),
    None,
    None,
    Some(&VARS_IMP_NODE),
    None,
    Some(&VARS_IMR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_IMR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMR_CHILDREN),
    value: None,
};

pub static VARS_IMR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b11010, &ENTRY_IMER_14870920039806180201)]],
    range: 1..=1,
};

static VARS_IMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMP_CHILDREN),
    value: None,
};

pub static VARS_IMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("actionise"),
        dictgen::InsensitiveStr::Ascii("actionises"),
        dictgen::InsensitiveStr::Ascii("actionize"),
        dictgen::InsensitiveStr::Ascii("actionizes"),
        dictgen::InsensitiveStr::Ascii("aneled"),
        dictgen::InsensitiveStr::Ascii("aneling"),
        dictgen::InsensitiveStr::Ascii("anelled"),
        dictgen::InsensitiveStr::Ascii("anelling"),
        dictgen::InsensitiveStr::Ascii("asted"),
        dictgen::InsensitiveStr::Ascii("astoed"),
        dictgen::InsensitiveStr::Ascii("erialisation"),
        dictgen::InsensitiveStr::Ascii("erialisations"),
        dictgen::InsensitiveStr::Ascii("erialise"),
        dictgen::InsensitiveStr::Ascii("erialised"),
        dictgen::InsensitiveStr::Ascii("erialises"),
        dictgen::InsensitiveStr::Ascii("erialising"),
        dictgen::InsensitiveStr::Ascii("erialization"),
        dictgen::InsensitiveStr::Ascii("erializations"),
        dictgen::InsensitiveStr::Ascii("erialize"),
        dictgen::InsensitiveStr::Ascii("erialized"),
        dictgen::InsensitiveStr::Ascii("erializes"),
        dictgen::InsensitiveStr::Ascii("erializing"),
        dictgen::InsensitiveStr::Ascii("eriled"),
        dictgen::InsensitiveStr::Ascii("eriling"),
        dictgen::InsensitiveStr::Ascii("erilled"),
        dictgen::InsensitiveStr::Ascii("erilling"),
        dictgen::InsensitiveStr::Ascii("erscriptible"),
        dictgen::InsensitiveStr::Ascii("ersonalisation"),
        dictgen::InsensitiveStr::Ascii("ersonalisations"),
        dictgen::InsensitiveStr::Ascii("ersonalise"),
        dictgen::InsensitiveStr::Ascii("ersonalised"),
        dictgen::InsensitiveStr::Ascii("ersonalises"),
        dictgen::InsensitiveStr::Ascii("ersonalising"),
        dictgen::InsensitiveStr::Ascii("ersonalization"),
        dictgen::InsensitiveStr::Ascii("ersonalizations"),
        dictgen::InsensitiveStr::Ascii("ersonalize"),
        dictgen::InsensitiveStr::Ascii("ersonalized"),
        dictgen::InsensitiveStr::Ascii("ersonalizes"),
        dictgen::InsensitiveStr::Ascii("ersonalizing"),
        dictgen::InsensitiveStr::Ascii("rescriptible"),
        dictgen::InsensitiveStr::Ascii("rovisatorise"),
        dictgen::InsensitiveStr::Ascii("rovisatorises"),
        dictgen::InsensitiveStr::Ascii("rovisatorize"),
        dictgen::InsensitiveStr::Ascii("rovisatorizes"),
        dictgen::InsensitiveStr::Ascii("rovizatorize"),
        dictgen::InsensitiveStr::Ascii("rovizatorizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMPACTIONIZE_2104051076866943054)],
        &[(0b10010, &ENTRY_IMPACTIONIZES_426122654023138033)],
        &[(0b01001, &ENTRY_IMPACTIONIZE_2104051076866943054)],
        &[(0b01001, &ENTRY_IMPACTIONIZES_426122654023138033)],
        &[(0b00001, &ENTRY_IMPANELED_1167928814655817587)],
        &[(0b00001, &ENTRY_IMPANELING_8436697861195228668)],
        &[(0b11010, &ENTRY_IMPANELED_1167928814655817587)],
        &[(0b11010, &ENTRY_IMPANELING_8436697861195228668)],
        &[(0b00001, &ENTRY_IMPASTED_8815350397702761813)],
        &[(0b11010, &ENTRY_IMPASTED_8815350397702761813)],
        &[(0b10010, &ENTRY_IMPERIALIZATION_809389970245717092)],
        &[(0b10010, &ENTRY_IMPERIALIZATIONS_14083397381534560194)],
        &[(0b10010, &ENTRY_IMPERIALIZE_4481105644087115733)],
        &[(0b10010, &ENTRY_IMPERIALIZED_15090938406523631069)],
        &[(0b10010, &ENTRY_IMPERIALIZES_18231768259408025685)],
        &[(0b10010, &ENTRY_IMPERIALIZING_15786015724673840691)],
        &[(0b01001, &ENTRY_IMPERIALIZATION_809389970245717092)],
        &[(0b01001, &ENTRY_IMPERIALIZATIONS_14083397381534560194)],
        &[(0b01001, &ENTRY_IMPERIALIZE_4481105644087115733)],
        &[(0b01001, &ENTRY_IMPERIALIZED_15090938406523631069)],
        &[(0b01001, &ENTRY_IMPERIALIZES_18231768259408025685)],
        &[(0b01001, &ENTRY_IMPERIALIZING_15786015724673840691)],
        &[(0b00001, &ENTRY_IMPERILED_1817411383008732803)],
        &[(0b00001, &ENTRY_IMPERILING_15623355054691084103)],
        &[(0b11010, &ENTRY_IMPERILED_1817411383008732803)],
        &[(0b11010, &ENTRY_IMPERILING_15623355054691084103)],
        &[(0b00001, &ENTRY_IMPERSCRIPTIBLE_2676593766088045954)],
        &[(0b10010, &ENTRY_IMPERSONALIZATION_11876381482371779340)],
        &[(0b10010, &ENTRY_IMPERSONALIZATIONS_6126721940741583599)],
        &[(0b10010, &ENTRY_IMPERSONALIZE_3918416555072155183)],
        &[(0b10010, &ENTRY_IMPERSONALIZED_14013696750625247313)],
        &[(0b10010, &ENTRY_IMPERSONALIZES_10756220249571201643)],
        &[(0b10010, &ENTRY_IMPERSONALIZING_8456593987165047413)],
        &[(0b01001, &ENTRY_IMPERSONALIZATION_11876381482371779340)],
        &[(0b01001, &ENTRY_IMPERSONALIZATIONS_6126721940741583599)],
        &[(0b01001, &ENTRY_IMPERSONALIZE_3918416555072155183)],
        &[(0b01001, &ENTRY_IMPERSONALIZED_14013696750625247313)],
        &[(0b01001, &ENTRY_IMPERSONALIZES_10756220249571201643)],
        &[(0b01001, &ENTRY_IMPERSONALIZING_8456593987165047413)],
        &[(0b11010, &ENTRY_IMPERSCRIPTIBLE_2676593766088045954)],
        &[(0b10010, &ENTRY_IMPROVIZATORIZE_10750757082424118716)],
        &[(0b10010, &ENTRY_IMPROVIZATORIZES_6258011353493362699)],
        &[(0b01000, &ENTRY_IMPROVIZATORIZE_10750757082424118716)],
        &[(0b01000, &ENTRY_IMPROVIZATORIZES_6258011353493362699)],
        &[(0b00001, &ENTRY_IMPROVIZATORIZE_10750757082424118716)],
        &[(0b00001, &ENTRY_IMPROVIZATORIZES_6258011353493362699)],
    ],
    range: 5..=15,
};

static VARS_IMM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_IMM_CHILDREN),
    value: None,
};

static VARS_IMM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_IMMA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IMMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IMMO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IMMU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_IMMU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMMU_CHILDREN),
    value: None,
};

pub static VARS_IMMU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMMUNIZATION_5538869136254922551)],
        &[(0b10010, &ENTRY_IMMUNIZATIONS_2659481680598819621)],
        &[(0b10010, &ENTRY_IMMUNIZE_2664627276125231648)],
        &[(0b10010, &ENTRY_IMMUNIZED_12890937714947487224)],
        &[(0b10010, &ENTRY_IMMUNIZER_15479014044677441669)],
        &[(0b10010, &ENTRY_IMMUNIZES_5928407860363224635)],
        &[(0b10010, &ENTRY_IMMUNIZING_1565078017048661043)],
        &[(0b01001, &ENTRY_IMMUNIZATION_5538869136254922551)],
        &[(0b01001, &ENTRY_IMMUNIZATIONS_2659481680598819621)],
        &[(0b01001, &ENTRY_IMMUNIZE_2664627276125231648)],
        &[(0b01001, &ENTRY_IMMUNIZED_12890937714947487224)],
        &[(0b01001, &ENTRY_IMMUNIZER_15479014044677441669)],
        &[(0b01001, &ENTRY_IMMUNIZES_5928407860363224635)],
        &[(0b01001, &ENTRY_IMMUNIZING_1565078017048661043)],
    ],
    range: 4..=9,
};

static VARS_IMMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMMO_CHILDREN),
    value: None,
};

pub static VARS_IMMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilisation"),
        dictgen::InsensitiveStr::Ascii("bilisations"),
        dictgen::InsensitiveStr::Ascii("bilise"),
        dictgen::InsensitiveStr::Ascii("bilised"),
        dictgen::InsensitiveStr::Ascii("biliser"),
        dictgen::InsensitiveStr::Ascii("bilisers"),
        dictgen::InsensitiveStr::Ascii("bilises"),
        dictgen::InsensitiveStr::Ascii("bilising"),
        dictgen::InsensitiveStr::Ascii("bilization"),
        dictgen::InsensitiveStr::Ascii("bilizations"),
        dictgen::InsensitiveStr::Ascii("bilize"),
        dictgen::InsensitiveStr::Ascii("bilized"),
        dictgen::InsensitiveStr::Ascii("bilizer"),
        dictgen::InsensitiveStr::Ascii("bilizers"),
        dictgen::InsensitiveStr::Ascii("bilizes"),
        dictgen::InsensitiveStr::Ascii("bilizing"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
        dictgen::InsensitiveStr::Ascii("rtalisable"),
        dictgen::InsensitiveStr::Ascii("rtalisabler"),
        dictgen::InsensitiveStr::Ascii("rtalisables"),
        dictgen::InsensitiveStr::Ascii("rtalisablest"),
        dictgen::InsensitiveStr::Ascii("rtalisation"),
        dictgen::InsensitiveStr::Ascii("rtalisations"),
        dictgen::InsensitiveStr::Ascii("rtalise"),
        dictgen::InsensitiveStr::Ascii("rtalised"),
        dictgen::InsensitiveStr::Ascii("rtaliser"),
        dictgen::InsensitiveStr::Ascii("rtalisers"),
        dictgen::InsensitiveStr::Ascii("rtalises"),
        dictgen::InsensitiveStr::Ascii("rtalising"),
        dictgen::InsensitiveStr::Ascii("rtalizable"),
        dictgen::InsensitiveStr::Ascii("rtalizabler"),
        dictgen::InsensitiveStr::Ascii("rtalizables"),
        dictgen::InsensitiveStr::Ascii("rtalizablest"),
        dictgen::InsensitiveStr::Ascii("rtalization"),
        dictgen::InsensitiveStr::Ascii("rtalizations"),
        dictgen::InsensitiveStr::Ascii("rtalize"),
        dictgen::InsensitiveStr::Ascii("rtalized"),
        dictgen::InsensitiveStr::Ascii("rtalizer"),
        dictgen::InsensitiveStr::Ascii("rtalizers"),
        dictgen::InsensitiveStr::Ascii("rtalizes"),
        dictgen::InsensitiveStr::Ascii("rtalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMMOBILIZATION_14269365516868106061)],
        &[(0b10010, &ENTRY_IMMOBILIZATIONS_6872011870912376673)],
        &[(0b10010, &ENTRY_IMMOBILIZE_1538489296094287236)],
        &[(0b10010, &ENTRY_IMMOBILIZED_6366288157273401051)],
        &[(0b10010, &ENTRY_IMMOBILIZER_10527563302868891526)],
        &[(0b10010, &ENTRY_IMMOBILIZERS_8902105516181595834)],
        &[(0b10010, &ENTRY_IMMOBILIZES_6192137487727370549)],
        &[(0b10010, &ENTRY_IMMOBILIZING_5171896597862510473)],
        &[(0b01001, &ENTRY_IMMOBILIZATION_14269365516868106061)],
        &[(0b01001, &ENTRY_IMMOBILIZATIONS_6872011870912376673)],
        &[(0b01001, &ENTRY_IMMOBILIZE_1538489296094287236)],
        &[(0b01001, &ENTRY_IMMOBILIZED_6366288157273401051)],
        &[(0b01001, &ENTRY_IMMOBILIZER_10527563302868891526)],
        &[(0b01001, &ENTRY_IMMOBILIZERS_8902105516181595834)],
        &[(0b01001, &ENTRY_IMMOBILIZES_6192137487727370549)],
        &[(0b01001, &ENTRY_IMMOBILIZING_5171896597862510473)],
        &[(0b10010, &ENTRY_IMMORALIZE_12133461291897920761)],
        &[(0b10010, &ENTRY_IMMORALIZED_8743847232919532242)],
        &[(0b10010, &ENTRY_IMMORALIZES_2840645599967765235)],
        &[(0b10010, &ENTRY_IMMORALIZING_225651617588777573)],
        &[(0b01001, &ENTRY_IMMORALIZE_12133461291897920761)],
        &[(0b01001, &ENTRY_IMMORALIZED_8743847232919532242)],
        &[(0b01001, &ENTRY_IMMORALIZES_2840645599967765235)],
        &[(0b01001, &ENTRY_IMMORALIZING_225651617588777573)],
        &[(0b10010, &ENTRY_IMMORTALIZABLE_15265716038811129100)],
        &[(0b10010, &ENTRY_IMMORTALIZABLER_564668294341461583)],
        &[(0b10010, &ENTRY_IMMORTALIZABLES_4125528812325170114)],
        &[(0b10010, &ENTRY_IMMORTALIZABLEST_7714158371330611954)],
        &[(0b10010, &ENTRY_IMMORTALIZATION_4641698519464381352)],
        &[(0b10010, &ENTRY_IMMORTALIZATIONS_15664742949388054394)],
        &[(0b10010, &ENTRY_IMMORTALIZE_7365899919779412057)],
        &[(0b10010, &ENTRY_IMMORTALIZED_12615514167775867804)],
        &[(0b10010, &ENTRY_IMMORTALIZER_16932530946305699963)],
        &[(0b10010, &ENTRY_IMMORTALIZERS_6443963380598843946)],
        &[(0b10010, &ENTRY_IMMORTALIZES_15825297845454086009)],
        &[(0b10010, &ENTRY_IMMORTALIZING_11881433655552032564)],
        &[(0b01001, &ENTRY_IMMORTALIZABLE_15265716038811129100)],
        &[(0b01001, &ENTRY_IMMORTALIZABLER_564668294341461583)],
        &[(0b01001, &ENTRY_IMMORTALIZABLES_4125528812325170114)],
        &[(0b01001, &ENTRY_IMMORTALIZABLEST_7714158371330611954)],
        &[(0b01001, &ENTRY_IMMORTALIZATION_4641698519464381352)],
        &[(0b01001, &ENTRY_IMMORTALIZATIONS_15664742949388054394)],
        &[(0b01001, &ENTRY_IMMORTALIZE_7365899919779412057)],
        &[(0b01001, &ENTRY_IMMORTALIZED_12615514167775867804)],
        &[(0b01001, &ENTRY_IMMORTALIZER_16932530946305699963)],
        &[(0b01001, &ENTRY_IMMORTALIZERS_6443963380598843946)],
        &[(0b01001, &ENTRY_IMMORTALIZES_15825297845454086009)],
        &[(0b01001, &ENTRY_IMMORTALIZING_11881433655552032564)],
    ],
    range: 6..=12,
};

static VARS_IMMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMMI_CHILDREN),
    value: None,
};

pub static VARS_IMMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("serisation"),
        dictgen::InsensitiveStr::Ascii("serisations"),
        dictgen::InsensitiveStr::Ascii("serise"),
        dictgen::InsensitiveStr::Ascii("serised"),
        dictgen::InsensitiveStr::Ascii("serises"),
        dictgen::InsensitiveStr::Ascii("serising"),
        dictgen::InsensitiveStr::Ascii("serization"),
        dictgen::InsensitiveStr::Ascii("serizations"),
        dictgen::InsensitiveStr::Ascii("serize"),
        dictgen::InsensitiveStr::Ascii("serized"),
        dictgen::InsensitiveStr::Ascii("serizes"),
        dictgen::InsensitiveStr::Ascii("serizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMMISERIZATION_14804280031319124390)],
        &[(0b10010, &ENTRY_IMMISERIZATIONS_4435664819116002162)],
        &[(0b10010, &ENTRY_IMMISERIZE_14280117300182154146)],
        &[(0b10010, &ENTRY_IMMISERIZED_15690784954007838498)],
        &[(0b10010, &ENTRY_IMMISERIZES_3930721082718257837)],
        &[(0b10010, &ENTRY_IMMISERIZING_7076021387262132556)],
        &[(0b01001, &ENTRY_IMMISERIZATION_14804280031319124390)],
        &[(0b01001, &ENTRY_IMMISERIZATIONS_4435664819116002162)],
        &[(0b01001, &ENTRY_IMMISERIZE_14280117300182154146)],
        &[(0b01001, &ENTRY_IMMISERIZED_15690784954007838498)],
        &[(0b01001, &ENTRY_IMMISERIZES_3930721082718257837)],
        &[(0b01001, &ENTRY_IMMISERIZING_7076021387262132556)],
    ],
    range: 6..=11,
};

static VARS_IMMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMMA_CHILDREN),
    value: None,
};

pub static VARS_IMMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("terialisation"),
        dictgen::InsensitiveStr::Ascii("terialise"),
        dictgen::InsensitiveStr::Ascii("terialised"),
        dictgen::InsensitiveStr::Ascii("terialises"),
        dictgen::InsensitiveStr::Ascii("terialising"),
        dictgen::InsensitiveStr::Ascii("terialization"),
        dictgen::InsensitiveStr::Ascii("terialize"),
        dictgen::InsensitiveStr::Ascii("terialized"),
        dictgen::InsensitiveStr::Ascii("terializes"),
        dictgen::InsensitiveStr::Ascii("terializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IMMATERIALIZATION_6031031436477619826)],
        &[(0b10010, &ENTRY_IMMATERIALIZE_2608487643159689091)],
        &[(0b10010, &ENTRY_IMMATERIALIZED_7515469749951851138)],
        &[(0b10010, &ENTRY_IMMATERIALIZES_14051931910265590173)],
        &[(0b10010, &ENTRY_IMMATERIALIZING_10859489260752984597)],
        &[(0b01001, &ENTRY_IMMATERIALIZATION_6031031436477619826)],
        &[(0b01001, &ENTRY_IMMATERIALIZE_2608487643159689091)],
        &[(0b01001, &ENTRY_IMMATERIALIZED_7515469749951851138)],
        &[(0b01001, &ENTRY_IMMATERIALIZES_14051931910265590173)],
        &[(0b01001, &ENTRY_IMMATERIALIZING_10859489260752984597)],
    ],
    range: 9..=13,
};

static VARS_IME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IME_CHILDREN),
    value: None,
};

pub static VARS_IME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("r")],
    values: &[&[(0b00001, &ENTRY_IMER_14870920039806180201)]],
    range: 1..=1,
};

static VARS_IMB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IMB_CHILDREN),
    value: None,
};

pub static VARS_IMB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edment"),
        dictgen::InsensitiveStr::Ascii("edments"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EMBEDMENT_2516420638791723000)],
        &[(0b00001, &ENTRY_EMBEDMENTS_9605808427028077825)],
    ],
    range: 6..=7,
};

static VARS_IL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IL_CHILDREN),
    value: None,
};

pub static VARS_IL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eocaecal"),
        dictgen::InsensitiveStr::Ascii("eocecal"),
        dictgen::InsensitiveStr::Ascii("iadise"),
        dictgen::InsensitiveStr::Ascii("iadises"),
        dictgen::InsensitiveStr::Ascii("iadize"),
        dictgen::InsensitiveStr::Ascii("iadizes"),
        dictgen::InsensitiveStr::Ascii("legalisation"),
        dictgen::InsensitiveStr::Ascii("legalisations"),
        dictgen::InsensitiveStr::Ascii("legalise"),
        dictgen::InsensitiveStr::Ascii("legalised"),
        dictgen::InsensitiveStr::Ascii("legalises"),
        dictgen::InsensitiveStr::Ascii("legalising"),
        dictgen::InsensitiveStr::Ascii("legalization"),
        dictgen::InsensitiveStr::Ascii("legalizations"),
        dictgen::InsensitiveStr::Ascii("legalize"),
        dictgen::InsensitiveStr::Ascii("legalized"),
        dictgen::InsensitiveStr::Ascii("legalizes"),
        dictgen::InsensitiveStr::Ascii("legalizing"),
        dictgen::InsensitiveStr::Ascii("legitimatise"),
        dictgen::InsensitiveStr::Ascii("legitimatised"),
        dictgen::InsensitiveStr::Ascii("legitimatises"),
        dictgen::InsensitiveStr::Ascii("legitimatising"),
        dictgen::InsensitiveStr::Ascii("legitimatize"),
        dictgen::InsensitiveStr::Ascii("legitimatized"),
        dictgen::InsensitiveStr::Ascii("legitimatizes"),
        dictgen::InsensitiveStr::Ascii("legitimatizing"),
        dictgen::InsensitiveStr::Ascii("liberalise"),
        dictgen::InsensitiveStr::Ascii("liberalised"),
        dictgen::InsensitiveStr::Ascii("liberalises"),
        dictgen::InsensitiveStr::Ascii("liberalising"),
        dictgen::InsensitiveStr::Ascii("liberalize"),
        dictgen::InsensitiveStr::Ascii("liberalized"),
        dictgen::InsensitiveStr::Ascii("liberalizes"),
        dictgen::InsensitiveStr::Ascii("liberalizing"),
        dictgen::InsensitiveStr::Ascii("luminise"),
        dictgen::InsensitiveStr::Ascii("luminises"),
        dictgen::InsensitiveStr::Ascii("luminize"),
        dictgen::InsensitiveStr::Ascii("luminizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ILEOCECAL_16783306468594549177)],
        &[(0b00001, &ENTRY_ILEOCECAL_16783306468594549177)],
        &[(0b10010, &ENTRY_ILIADIZE_15127972838873373823)],
        &[(0b10010, &ENTRY_ILIADIZES_9101371657731138727)],
        &[(0b01001, &ENTRY_ILIADIZE_15127972838873373823)],
        &[(0b01001, &ENTRY_ILIADIZES_9101371657731138727)],
        &[(0b10010, &ENTRY_ILLEGALIZATION_4625157464834082989)],
        &[(0b10010, &ENTRY_ILLEGALIZATIONS_1156484598694873817)],
        &[(0b10010, &ENTRY_ILLEGALIZE_16625635604289115309)],
        &[(0b10010, &ENTRY_ILLEGALIZED_484742681447604998)],
        &[(0b10010, &ENTRY_ILLEGALIZES_1428654024712106207)],
        &[(0b10010, &ENTRY_ILLEGALIZING_14859202189889876673)],
        &[(0b01001, &ENTRY_ILLEGALIZATION_4625157464834082989)],
        &[(0b01001, &ENTRY_ILLEGALIZATIONS_1156484598694873817)],
        &[(0b01001, &ENTRY_ILLEGALIZE_16625635604289115309)],
        &[(0b01001, &ENTRY_ILLEGALIZED_484742681447604998)],
        &[(0b01001, &ENTRY_ILLEGALIZES_1428654024712106207)],
        &[(0b01001, &ENTRY_ILLEGALIZING_14859202189889876673)],
        &[(0b10010, &ENTRY_ILLEGITIMATIZE_14953959094151382508)],
        &[(0b10010, &ENTRY_ILLEGITIMATIZED_9298797108128630594)],
        &[(0b10010, &ENTRY_ILLEGITIMATIZES_10871580308994962653)],
        &[(0b10010, &ENTRY_ILLEGITIMATIZING_3130773918673655897)],
        &[(0b01001, &ENTRY_ILLEGITIMATIZE_14953959094151382508)],
        &[(0b01001, &ENTRY_ILLEGITIMATIZED_9298797108128630594)],
        &[(0b01001, &ENTRY_ILLEGITIMATIZES_10871580308994962653)],
        &[(0b01001, &ENTRY_ILLEGITIMATIZING_3130773918673655897)],
        &[(0b10010, &ENTRY_ILLIBERALIZE_16887752615283473950)],
        &[(0b10010, &ENTRY_ILLIBERALIZED_2905951389427902439)],
        &[(0b10010, &ENTRY_ILLIBERALIZES_2675206746403840559)],
        &[(0b10010, &ENTRY_ILLIBERALIZING_1093587366997831440)],
        &[(0b01001, &ENTRY_ILLIBERALIZE_16887752615283473950)],
        &[(0b01001, &ENTRY_ILLIBERALIZED_2905951389427902439)],
        &[(0b01001, &ENTRY_ILLIBERALIZES_2675206746403840559)],
        &[(0b01001, &ENTRY_ILLIBERALIZING_1093587366997831440)],
        &[(0b10010, &ENTRY_ILLUMINIZE_12083084487959333250)],
        &[(0b10010, &ENTRY_ILLUMINIZES_2269056124855197647)],
        &[(0b01001, &ENTRY_ILLUMINIZE_12083084487959333250)],
        &[(0b01001, &ENTRY_ILLUMINIZES_2269056124855197647)],
    ],
    range: 6..=14,
};

static VARS_IE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IE_CHILDREN),
    value: None,
};

pub static VARS_IE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("r")],
    values: &[&[(0b00001, &ENTRY_IER_8590173399354916659)]],
    range: 1..=1,
};

static VARS_ID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ID_CHILDREN),
    value: None,
};

static VARS_ID_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_IDA_NODE),
    None,
    None,
    None,
    Some(&VARS_IDE_NODE),
    None,
    None,
    None,
    Some(&VARS_IDI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IDO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_IDU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_IDU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDU_CHILDREN),
    value: None,
};

pub static VARS_IDU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maea"),
        dictgen::InsensitiveStr::Ascii("maean"),
        dictgen::InsensitiveStr::Ascii("maeans"),
        dictgen::InsensitiveStr::Ascii("mea"),
        dictgen::InsensitiveStr::Ascii("mean"),
        dictgen::InsensitiveStr::Ascii("means"),
    ],
    values: &[
        &[(0b11010, &ENTRY_IDUMEA_13980136124670779407)],
        &[(0b11010, &ENTRY_IDUMEAN_10223482079508735346)],
        &[(0b11010, &ENTRY_IDUMEANS_2701997562386323077)],
        &[(0b00001, &ENTRY_IDUMEA_13980136124670779407)],
        &[(0b00001, &ENTRY_IDUMEAN_10223482079508735346)],
        &[(0b00001, &ENTRY_IDUMEANS_2701997562386323077)],
    ],
    range: 3..=6,
};

static VARS_IDO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDO_CHILDREN),
    value: None,
};

pub static VARS_IDO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("laster"),
        dictgen::InsensitiveStr::Ascii("lastre"),
        dictgen::InsensitiveStr::Ascii("latrise"),
        dictgen::InsensitiveStr::Ascii("latrised"),
        dictgen::InsensitiveStr::Ascii("latriser"),
        dictgen::InsensitiveStr::Ascii("latrises"),
        dictgen::InsensitiveStr::Ascii("latrising"),
        dictgen::InsensitiveStr::Ascii("latrize"),
        dictgen::InsensitiveStr::Ascii("latrized"),
        dictgen::InsensitiveStr::Ascii("latrizer"),
        dictgen::InsensitiveStr::Ascii("latrizes"),
        dictgen::InsensitiveStr::Ascii("latrizing"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_IDOLASTER_7266072593117643606)],
        &[(0b11010, &ENTRY_IDOLASTER_7266072593117643606)],
        &[(0b10010, &ENTRY_IDOLATRIZE_4656997284033474549)],
        &[(0b10010, &ENTRY_IDOLATRIZED_13594082497249773073)],
        &[(0b10010, &ENTRY_IDOLATRIZER_13466408337970930578)],
        &[(0b10010, &ENTRY_IDOLATRIZES_6460555645543616854)],
        &[(0b10010, &ENTRY_IDOLATRIZING_2845662815694741055)],
        &[(0b01001, &ENTRY_IDOLATRIZE_4656997284033474549)],
        &[(0b01001, &ENTRY_IDOLATRIZED_13594082497249773073)],
        &[(0b01001, &ENTRY_IDOLATRIZER_13466408337970930578)],
        &[(0b01001, &ENTRY_IDOLATRIZES_6460555645543616854)],
        &[(0b01001, &ENTRY_IDOLATRIZING_2845662815694741055)],
        &[(0b10010, &ENTRY_IDOLIZATION_8632443878294442006)],
        &[(0b10010, &ENTRY_IDOLIZATIONS_9712598788540549768)],
        &[(0b10010, &ENTRY_IDOLIZE_2701460930995107542)],
        &[(0b10010, &ENTRY_IDOLIZED_816557049996724188)],
        &[(0b10010, &ENTRY_IDOLIZER_9248020857005213110)],
        &[(0b10010, &ENTRY_IDOLIZERS_1279817137520626890)],
        &[(0b10010, &ENTRY_IDOLIZES_15045222501412845991)],
        &[(0b10010, &ENTRY_IDOLIZING_1591764180221977340)],
        &[(0b01001, &ENTRY_IDOLIZATION_8632443878294442006)],
        &[(0b01001, &ENTRY_IDOLIZATIONS_9712598788540549768)],
        &[(0b01001, &ENTRY_IDOLIZE_2701460930995107542)],
        &[(0b01001, &ENTRY_IDOLIZED_816557049996724188)],
        &[(0b01001, &ENTRY_IDOLIZER_9248020857005213110)],
        &[(0b01001, &ENTRY_IDOLIZERS_1279817137520626890)],
        &[(0b01001, &ENTRY_IDOLIZES_15045222501412845991)],
        &[(0b01001, &ENTRY_IDOLIZING_1591764180221977340)],
    ],
    range: 4..=9,
};

static VARS_IDI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDI_CHILDREN),
    value: None,
};

pub static VARS_IDI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_IDIOTIZE_1684624828093976331)],
        &[(0b10010, &ENTRY_IDIOTIZED_2823205485453867122)],
        &[(0b10010, &ENTRY_IDIOTIZES_7580197157055076168)],
        &[(0b10010, &ENTRY_IDIOTIZING_7163780928321635270)],
        &[(0b01001, &ENTRY_IDIOTIZE_1684624828093976331)],
        &[(0b01001, &ENTRY_IDIOTIZED_2823205485453867122)],
        &[(0b01001, &ENTRY_IDIOTIZES_7580197157055076168)],
        &[(0b01001, &ENTRY_IDIOTIZING_7163780928321635270)],
    ],
    range: 5..=7,
};

static VARS_IDE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDE_CHILDREN),
    value: None,
};

pub static VARS_IDE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("an"),
        dictgen::InsensitiveStr::Ascii("ologise"),
        dictgen::InsensitiveStr::Ascii("ologised"),
        dictgen::InsensitiveStr::Ascii("ologising"),
        dictgen::InsensitiveStr::Ascii("ologize"),
        dictgen::InsensitiveStr::Ascii("ologized"),
        dictgen::InsensitiveStr::Ascii("ologizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_IDEA_10731610012075090621)],
        &[(0b10010, &ENTRY_IDEALIZATION_8942077149848649531)],
        &[(0b10010, &ENTRY_IDEALIZATIONS_17706069873226328743)],
        &[(0b10010, &ENTRY_IDEALIZE_14123580326934520124)],
        &[(0b10010, &ENTRY_IDEALIZED_14008500069022545339)],
        &[(0b10010, &ENTRY_IDEALIZER_10372227838521078835)],
        &[(0b10010, &ENTRY_IDEALIZERS_9984755113941497632)],
        &[(0b10010, &ENTRY_IDEALIZES_11364769940078887168)],
        &[(0b10010, &ENTRY_IDEALIZING_11261011833401157832)],
        &[(0b01001, &ENTRY_IDEALIZATION_8942077149848649531)],
        &[(0b01001, &ENTRY_IDEALIZATIONS_17706069873226328743)],
        &[(0b01001, &ENTRY_IDEALIZE_14123580326934520124)],
        &[(0b01001, &ENTRY_IDEALIZED_14008500069022545339)],
        &[(0b01001, &ENTRY_IDEALIZER_10372227838521078835)],
        &[(0b01001, &ENTRY_IDEALIZERS_9984755113941497632)],
        &[(0b01001, &ENTRY_IDEALIZES_11364769940078887168)],
        &[(0b01001, &ENTRY_IDEALIZING_11261011833401157832)],
        &[(0b00001, &ENTRY_IDEAN_9346667922217550026)],
        &[(0b10010, &ENTRY_IDEOLOGIZE_6184243847595357924)],
        &[(0b10010, &ENTRY_IDEOLOGIZED_14839820276752351313)],
        &[(0b10010, &ENTRY_IDEOLOGIZING_5810490570451528116)],
        &[(0b01001, &ENTRY_IDEOLOGIZE_6184243847595357924)],
        &[(0b01001, &ENTRY_IDEOLOGIZED_14839820276752351313)],
        &[(0b01001, &ENTRY_IDEOLOGIZING_5810490570451528116)],
    ],
    range: 1..=10,
};

static VARS_IDA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IDA_CHILDREN),
    value: None,
};

pub static VARS_IDA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("ean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_IDEA_10731610012075090621)],
        &[(0b11010, &ENTRY_IDEAN_9346667922217550026)],
    ],
    range: 2..=3,
};

static VARS_IC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_IC_CHILDREN),
    value: None,
};

pub static VARS_IC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hneumonised"),
        dictgen::InsensitiveStr::Ascii("hneumoniseds"),
        dictgen::InsensitiveStr::Ascii("hneumonized"),
        dictgen::InsensitiveStr::Ascii("hneumonizeds"),
        dictgen::InsensitiveStr::Ascii("horrhaemia"),
        dictgen::InsensitiveStr::Ascii("horrhea"),
        dictgen::InsensitiveStr::Ascii("horrhemia"),
        dictgen::InsensitiveStr::Ascii("horrhoea"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ICHNEUMONIZED_6378362117508680448)],
        &[(0b10010, &ENTRY_ICHNEUMONIZEDS_16408019083414202849)],
        &[(0b01001, &ENTRY_ICHNEUMONIZED_6378362117508680448)],
        &[(0b01001, &ENTRY_ICHNEUMONIZEDS_16408019083414202849)],
        &[(0b11010, &ENTRY_ICHORRHEMIA_13725064108367155360)],
        &[(0b10001, &ENTRY_ICHORRHEA_14916867309701249088)],
        &[(0b10001, &ENTRY_ICHORRHEMIA_13725064108367155360)],
        &[(0b11010, &ENTRY_ICHORRHEA_14916867309701249088)],
        &[(0b10010, &ENTRY_ICONIZE_1250698237284228147)],
        &[(0b10010, &ENTRY_ICONIZED_9166522339758963505)],
        &[(0b10010, &ENTRY_ICONIZES_7146786515616481266)],
        &[(0b10010, &ENTRY_ICONIZING_4559448370943859169)],
        &[(0b01001, &ENTRY_ICONIZE_1250698237284228147)],
        &[(0b01001, &ENTRY_ICONIZED_9166522339758963505)],
        &[(0b01001, &ENTRY_ICONIZES_7146786515616481266)],
        &[(0b01001, &ENTRY_ICONIZING_4559448370943859169)],
    ],
    range: 5..=12,
};

static VARS_H_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_H_CHILDREN),
    value: None,
};

static VARS_H_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HA_NODE),
    None,
    None,
    None,
    Some(&VARS_HE_NODE),
    None,
    None,
    None,
    Some(&VARS_HI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HU_NODE),
    None,
    None,
    None,
    Some(&VARS_HY_NODE),
    None,
];

static VARS_HY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HY_CHILDREN),
    value: None,
};

static VARS_HY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HYA_NODE),
    Some(&VARS_HYB_NODE),
    None,
    Some(&VARS_HYD_NODE),
    Some(&VARS_HYE_NODE),
    None,
    Some(&VARS_HYG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HYM_NODE),
    None,
    None,
    Some(&VARS_HYP_NODE),
    None,
    None,
    Some(&VARS_HYS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HYS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYS_CHILDREN),
    value: None,
};

pub static VARS_HYS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("terectomise"),
        dictgen::InsensitiveStr::Ascii("terectomised"),
        dictgen::InsensitiveStr::Ascii("terectomises"),
        dictgen::InsensitiveStr::Ascii("terectomising"),
        dictgen::InsensitiveStr::Ascii("terectomize"),
        dictgen::InsensitiveStr::Ascii("terectomized"),
        dictgen::InsensitiveStr::Ascii("terectomizes"),
        dictgen::InsensitiveStr::Ascii("terectomizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYSTERECTOMIZE_339019716389420307)],
        &[(0b10010, &ENTRY_HYSTERECTOMIZED_13349404234142869054)],
        &[(0b10010, &ENTRY_HYSTERECTOMIZES_7837017087019854209)],
        &[(0b10010, &ENTRY_HYSTERECTOMIZING_1803341574005543960)],
        &[(0b01001, &ENTRY_HYSTERECTOMIZE_339019716389420307)],
        &[(0b01001, &ENTRY_HYSTERECTOMIZED_13349404234142869054)],
        &[(0b01001, &ENTRY_HYSTERECTOMIZES_7837017087019854209)],
        &[(0b01001, &ENTRY_HYSTERECTOMIZING_1803341574005543960)],
    ],
    range: 11..=13,
};

static VARS_HYP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HYP_CHILDREN),
    value: None,
};

static VARS_HYP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HYPA_NODE),
    None,
    None,
    None,
    Some(&VARS_HYPE_NODE),
    None,
    None,
    Some(&VARS_HYPH_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HYPN_NODE),
    Some(&VARS_HYPO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HYPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HYPO_CHILDREN),
    value: None,
};

static VARS_HYPO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_HYPOC_NODE),
    None,
    None,
    None,
    Some(&VARS_HYPOG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HYPOM_NODE),
    None,
    None,
    Some(&VARS_HYPOP_NODE),
    None,
    None,
    Some(&VARS_HYPOS_NODE),
    Some(&VARS_HYPOT_NODE),
    None,
    None,
    None,
    Some(&VARS_HYPOX_NODE),
    None,
    None,
];

static VARS_HYPOX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOX_CHILDREN),
    value: None,
};

pub static VARS_HYPOX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemia"),
        dictgen::InsensitiveStr::Ascii("aemias"),
        dictgen::InsensitiveStr::Ascii("aemic"),
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPOXEMIA_18278832485926696070)],
        &[(0b11010, &ENTRY_HYPOXEMIAS_16532743875103109491)],
        &[(0b11010, &ENTRY_HYPOXEMIC_548533936920854543)],
        &[(0b10001, &ENTRY_HYPOXEMIA_18278832485926696070)],
        &[(0b10001, &ENTRY_HYPOXEMIAS_16532743875103109491)],
        &[(0b10001, &ENTRY_HYPOXEMIC_548533936920854543)],
    ],
    range: 4..=6,
};

static VARS_HYPOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOT_CHILDREN),
    value: None,
};

pub static VARS_HYPOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hesise"),
        dictgen::InsensitiveStr::Ascii("hesised"),
        dictgen::InsensitiveStr::Ascii("hesiser"),
        dictgen::InsensitiveStr::Ascii("hesisers"),
        dictgen::InsensitiveStr::Ascii("hesises"),
        dictgen::InsensitiveStr::Ascii("hesising"),
        dictgen::InsensitiveStr::Ascii("hesize"),
        dictgen::InsensitiveStr::Ascii("hesized"),
        dictgen::InsensitiveStr::Ascii("hesizer"),
        dictgen::InsensitiveStr::Ascii("hesizers"),
        dictgen::InsensitiveStr::Ascii("hesizes"),
        dictgen::InsensitiveStr::Ascii("hesizing"),
        dictgen::InsensitiveStr::Ascii("hetise"),
        dictgen::InsensitiveStr::Ascii("hetised"),
        dictgen::InsensitiveStr::Ascii("hetises"),
        dictgen::InsensitiveStr::Ascii("hetising"),
        dictgen::InsensitiveStr::Ascii("hetize"),
        dictgen::InsensitiveStr::Ascii("hetized"),
        dictgen::InsensitiveStr::Ascii("hetizes"),
        dictgen::InsensitiveStr::Ascii("hetizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPOTHESIZE_9991606314621761423)],
        &[(0b10010, &ENTRY_HYPOTHESIZED_7654092048334444056)],
        &[(0b10010, &ENTRY_HYPOTHESIZER_12418298699515974202)],
        &[(0b10010, &ENTRY_HYPOTHESIZERS_603918477512076863)],
        &[(0b10010, &ENTRY_HYPOTHESIZES_15615154634968472421)],
        &[(0b10010, &ENTRY_HYPOTHESIZING_17752502848335912546)],
        &[(0b01001, &ENTRY_HYPOTHESIZE_9991606314621761423)],
        &[(0b01001, &ENTRY_HYPOTHESIZED_7654092048334444056)],
        &[(0b01001, &ENTRY_HYPOTHESIZER_12418298699515974202)],
        &[(0b01001, &ENTRY_HYPOTHESIZERS_603918477512076863)],
        &[(0b01001, &ENTRY_HYPOTHESIZES_15615154634968472421)],
        &[(0b01001, &ENTRY_HYPOTHESIZING_17752502848335912546)],
        &[(0b10010, &ENTRY_HYPOTHETIZE_9755880027223809632)],
        &[(0b10010, &ENTRY_HYPOTHETIZED_5891619059003247329)],
        &[(0b10010, &ENTRY_HYPOTHETIZES_1892978940988731731)],
        &[(0b10010, &ENTRY_HYPOTHETIZING_17356916950623118977)],
        &[(0b01001, &ENTRY_HYPOTHETIZE_9755880027223809632)],
        &[(0b01001, &ENTRY_HYPOTHETIZED_5891619059003247329)],
        &[(0b01001, &ENTRY_HYPOTHETIZES_1892978940988731731)],
        &[(0b01001, &ENTRY_HYPOTHETIZING_17356916950623118977)],
    ],
    range: 6..=8,
};

static VARS_HYPOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOS_CHILDREN),
    value: None,
};

pub static VARS_HYPOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensitisation"),
        dictgen::InsensitiveStr::Ascii("ensitise"),
        dictgen::InsensitiveStr::Ascii("ensitization"),
        dictgen::InsensitiveStr::Ascii("ensitize"),
        dictgen::InsensitiveStr::Ascii("tasise"),
        dictgen::InsensitiveStr::Ascii("tasised"),
        dictgen::InsensitiveStr::Ascii("tasises"),
        dictgen::InsensitiveStr::Ascii("tasising"),
        dictgen::InsensitiveStr::Ascii("tasize"),
        dictgen::InsensitiveStr::Ascii("tasized"),
        dictgen::InsensitiveStr::Ascii("tasizes"),
        dictgen::InsensitiveStr::Ascii("tasizing"),
        dictgen::InsensitiveStr::Ascii("tatisation"),
        dictgen::InsensitiveStr::Ascii("tatisations"),
        dictgen::InsensitiveStr::Ascii("tatise"),
        dictgen::InsensitiveStr::Ascii("tatised"),
        dictgen::InsensitiveStr::Ascii("tatises"),
        dictgen::InsensitiveStr::Ascii("tatising"),
        dictgen::InsensitiveStr::Ascii("tatization"),
        dictgen::InsensitiveStr::Ascii("tatizations"),
        dictgen::InsensitiveStr::Ascii("tatize"),
        dictgen::InsensitiveStr::Ascii("tatized"),
        dictgen::InsensitiveStr::Ascii("tatizes"),
        dictgen::InsensitiveStr::Ascii("tatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPOSENSITIZATION_13169981854919292277)],
        &[(0b10010, &ENTRY_HYPOSENSITIZE_2895248881259272507)],
        &[(0b01001, &ENTRY_HYPOSENSITIZATION_13169981854919292277)],
        &[(0b01001, &ENTRY_HYPOSENSITIZE_2895248881259272507)],
        &[(0b10010, &ENTRY_HYPOSTASIZE_11096004503705632835)],
        &[(0b10010, &ENTRY_HYPOSTASIZED_14675743548250216380)],
        &[(0b10010, &ENTRY_HYPOSTASIZES_15212084710875560260)],
        &[(0b10010, &ENTRY_HYPOSTASIZING_4036380769759199422)],
        &[(0b01001, &ENTRY_HYPOSTASIZE_11096004503705632835)],
        &[(0b01001, &ENTRY_HYPOSTASIZED_14675743548250216380)],
        &[(0b01001, &ENTRY_HYPOSTASIZES_15212084710875560260)],
        &[(0b01001, &ENTRY_HYPOSTASIZING_4036380769759199422)],
        &[(0b10010, &ENTRY_HYPOSTATIZATION_3087117275369319820)],
        &[(0b10010, &ENTRY_HYPOSTATIZATIONS_4580078961622780169)],
        &[(0b10010, &ENTRY_HYPOSTATIZE_1068205308830584989)],
        &[(0b10010, &ENTRY_HYPOSTATIZED_12087439657646325061)],
        &[(0b10010, &ENTRY_HYPOSTATIZES_8600110126821695484)],
        &[(0b10010, &ENTRY_HYPOSTATIZING_17172618075417547515)],
        &[(0b01001, &ENTRY_HYPOSTATIZATION_3087117275369319820)],
        &[(0b01001, &ENTRY_HYPOSTATIZATIONS_4580078961622780169)],
        &[(0b01001, &ENTRY_HYPOSTATIZE_1068205308830584989)],
        &[(0b01001, &ENTRY_HYPOSTATIZED_12087439657646325061)],
        &[(0b01001, &ENTRY_HYPOSTATIZES_8600110126821695484)],
        &[(0b01001, &ENTRY_HYPOSTATIZING_17172618075417547515)],
    ],
    range: 6..=12,
};

static VARS_HYPOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOP_CHILDREN),
    value: None,
};

pub static VARS_HYPOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hysectomise"),
        dictgen::InsensitiveStr::Ascii("hysectomised"),
        dictgen::InsensitiveStr::Ascii("hysectomize"),
        dictgen::InsensitiveStr::Ascii("hysectomized"),
        dictgen::InsensitiveStr::Ascii("nea"),
        dictgen::InsensitiveStr::Ascii("noea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPOPHYSECTOMIZE_7491760103755206752)],
        &[(0b10010, &ENTRY_HYPOPHYSECTOMIZED_16316479332714641237)],
        &[(0b01001, &ENTRY_HYPOPHYSECTOMIZE_7491760103755206752)],
        &[(0b01001, &ENTRY_HYPOPHYSECTOMIZED_16316479332714641237)],
        &[(0b10001, &ENTRY_HYPOPNEA_8190235472388790329)],
        &[(0b11010, &ENTRY_HYPOPNEA_8190235472388790329)],
    ],
    range: 3..=12,
};

static VARS_HYPOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOM_CHILDREN),
    value: None,
};

pub static VARS_HYPOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agnesaemia"),
        dictgen::InsensitiveStr::Ascii("agnesaemias"),
        dictgen::InsensitiveStr::Ascii("agnesemia"),
        dictgen::InsensitiveStr::Ascii("agnesemias"),
        dictgen::InsensitiveStr::Ascii("enorrhea"),
        dictgen::InsensitiveStr::Ascii("enorrheas"),
        dictgen::InsensitiveStr::Ascii("enorrhoea"),
        dictgen::InsensitiveStr::Ascii("enorrhoeas"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPOMAGNESEMIA_11350011491335743618)],
        &[(0b11010, &ENTRY_HYPOMAGNESEMIAS_14272891159396393964)],
        &[(0b10001, &ENTRY_HYPOMAGNESEMIA_11350011491335743618)],
        &[(0b10001, &ENTRY_HYPOMAGNESEMIAS_14272891159396393964)],
        &[(0b10001, &ENTRY_HYPOMENORRHEA_15862079214702615306)],
        &[(0b10001, &ENTRY_HYPOMENORRHEAS_10501238150845360653)],
        &[(0b11010, &ENTRY_HYPOMENORRHEA_15862079214702615306)],
        &[(0b11010, &ENTRY_HYPOMENORRHEAS_10501238150845360653)],
    ],
    range: 8..=11,
};

static VARS_HYPOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOG_CHILDREN),
    value: None,
};

pub static VARS_HYPOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aea"),
        dictgen::InsensitiveStr::Ascii("aeal"),
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("aeic"),
        dictgen::InsensitiveStr::Ascii("aeous"),
        dictgen::InsensitiveStr::Ascii("aeum"),
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("eal"),
        dictgen::InsensitiveStr::Ascii("ean"),
        dictgen::InsensitiveStr::Ascii("eic"),
        dictgen::InsensitiveStr::Ascii("eous"),
        dictgen::InsensitiveStr::Ascii("eum"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPOGEA_5577040873155624794)],
        &[(0b11010, &ENTRY_HYPOGEAL_4214900613383499478)],
        &[(0b11010, &ENTRY_HYPOGEAN_12254254837392880307)],
        &[(0b11010, &ENTRY_HYPOGEIC_8668126381759058087)],
        &[(0b11010, &ENTRY_HYPOGEOUS_12131139259918270129)],
        &[(0b11010, &ENTRY_HYPOGEUM_4724680330192032314)],
        &[(0b10001, &ENTRY_HYPOGEA_5577040873155624794)],
        &[(0b10001, &ENTRY_HYPOGEAL_4214900613383499478)],
        &[(0b10001, &ENTRY_HYPOGEAN_12254254837392880307)],
        &[(0b10001, &ENTRY_HYPOGEIC_8668126381759058087)],
        &[(0b10001, &ENTRY_HYPOGEOUS_12131139259918270129)],
        &[(0b10001, &ENTRY_HYPOGEUM_4724680330192032314)],
    ],
    range: 2..=5,
};

static VARS_HYPOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPOC_CHILDREN),
    value: None,
};

pub static VARS_HYPOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HYPOCENTER_10924617547082167348)],
        &[(0b00001, &ENTRY_HYPOCENTERS_8535258706052045382)],
        &[(0b11010, &ENTRY_HYPOCENTER_10924617547082167348)],
        &[(0b11010, &ENTRY_HYPOCENTERS_8535258706052045382)],
    ],
    range: 5..=6,
};

static VARS_HYPN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPN_CHILDREN),
    value: None,
};

pub static VARS_HYPN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oidise"),
        dictgen::InsensitiveStr::Ascii("oidised"),
        dictgen::InsensitiveStr::Ascii("oidises"),
        dictgen::InsensitiveStr::Ascii("oidising"),
        dictgen::InsensitiveStr::Ascii("oidize"),
        dictgen::InsensitiveStr::Ascii("oidized"),
        dictgen::InsensitiveStr::Ascii("oidizes"),
        dictgen::InsensitiveStr::Ascii("oidizing"),
        dictgen::InsensitiveStr::Ascii("opaedia"),
        dictgen::InsensitiveStr::Ascii("opaedias"),
        dictgen::InsensitiveStr::Ascii("opedia"),
        dictgen::InsensitiveStr::Ascii("opedias"),
        dictgen::InsensitiveStr::Ascii("otisabilities"),
        dictgen::InsensitiveStr::Ascii("otisability"),
        dictgen::InsensitiveStr::Ascii("otisable"),
        dictgen::InsensitiveStr::Ascii("otisabler"),
        dictgen::InsensitiveStr::Ascii("otisables"),
        dictgen::InsensitiveStr::Ascii("otisablest"),
        dictgen::InsensitiveStr::Ascii("otisation"),
        dictgen::InsensitiveStr::Ascii("otisations"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otiser"),
        dictgen::InsensitiveStr::Ascii("otisers"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otizabilities"),
        dictgen::InsensitiveStr::Ascii("otizability"),
        dictgen::InsensitiveStr::Ascii("otizable"),
        dictgen::InsensitiveStr::Ascii("otizabler"),
        dictgen::InsensitiveStr::Ascii("otizables"),
        dictgen::InsensitiveStr::Ascii("otizablest"),
        dictgen::InsensitiveStr::Ascii("otization"),
        dictgen::InsensitiveStr::Ascii("otizations"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizer"),
        dictgen::InsensitiveStr::Ascii("otizers"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPNOIDIZE_2850779439524391424)],
        &[(0b10010, &ENTRY_HYPNOIDIZED_9319780668114784761)],
        &[(0b10010, &ENTRY_HYPNOIDIZES_17015057874529046063)],
        &[(0b10010, &ENTRY_HYPNOIDIZING_13556905370183450835)],
        &[(0b01001, &ENTRY_HYPNOIDIZE_2850779439524391424)],
        &[(0b01001, &ENTRY_HYPNOIDIZED_9319780668114784761)],
        &[(0b01001, &ENTRY_HYPNOIDIZES_17015057874529046063)],
        &[(0b01001, &ENTRY_HYPNOIDIZING_13556905370183450835)],
        &[(0b11010, &ENTRY_HYPNOPEDIA_16182744577342481603)],
        &[(0b11010, &ENTRY_HYPNOPEDIAS_2021280433174594462)],
        &[(0b10001, &ENTRY_HYPNOPEDIA_16182744577342481603)],
        &[(0b10001, &ENTRY_HYPNOPEDIAS_2021280433174594462)],
        &[(0b10010, &ENTRY_HYPNOTIZABILITIES_11128345419464903204)],
        &[(0b10010, &ENTRY_HYPNOTIZABILITY_4276821883858401715)],
        &[(0b10010, &ENTRY_HYPNOTIZABLE_16992601341623152607)],
        &[(0b10010, &ENTRY_HYPNOTIZABLER_17707987328116457331)],
        &[(0b10010, &ENTRY_HYPNOTIZABLES_7101472140016331305)],
        &[(0b10010, &ENTRY_HYPNOTIZABLEST_6467410254949884057)],
        &[(0b10010, &ENTRY_HYPNOTIZATION_15666177504048422050)],
        &[(0b10010, &ENTRY_HYPNOTIZATIONS_12338000884893753831)],
        &[(0b10010, &ENTRY_HYPNOTIZE_31495543619220727)],
        &[(0b10010, &ENTRY_HYPNOTIZED_1649105222019656795)],
        &[(0b10010, &ENTRY_HYPNOTIZER_13806710050342747653)],
        &[(0b10010, &ENTRY_HYPNOTIZERS_13980343117375469027)],
        &[(0b10010, &ENTRY_HYPNOTIZES_18356635304308769334)],
        &[(0b10010, &ENTRY_HYPNOTIZING_1791072609905298231)],
        &[(0b01001, &ENTRY_HYPNOTIZABILITIES_11128345419464903204)],
        &[(0b01001, &ENTRY_HYPNOTIZABILITY_4276821883858401715)],
        &[(0b01001, &ENTRY_HYPNOTIZABLE_16992601341623152607)],
        &[(0b01001, &ENTRY_HYPNOTIZABLER_17707987328116457331)],
        &[(0b01001, &ENTRY_HYPNOTIZABLES_7101472140016331305)],
        &[(0b01001, &ENTRY_HYPNOTIZABLEST_6467410254949884057)],
        &[(0b01001, &ENTRY_HYPNOTIZATION_15666177504048422050)],
        &[(0b01001, &ENTRY_HYPNOTIZATIONS_12338000884893753831)],
        &[(0b01001, &ENTRY_HYPNOTIZE_31495543619220727)],
        &[(0b01001, &ENTRY_HYPNOTIZED_1649105222019656795)],
        &[(0b01001, &ENTRY_HYPNOTIZER_13806710050342747653)],
        &[(0b01001, &ENTRY_HYPNOTIZERS_13980343117375469027)],
        &[(0b01001, &ENTRY_HYPNOTIZES_18356635304308769334)],
        &[(0b01001, &ENTRY_HYPNOTIZING_1791072609905298231)],
    ],
    range: 5..=13,
};

static VARS_HYPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPH_CHILDREN),
    value: None,
};

pub static VARS_HYPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enisation"),
        dictgen::InsensitiveStr::Ascii("enisations"),
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enised"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enising"),
        dictgen::InsensitiveStr::Ascii("enization"),
        dictgen::InsensitiveStr::Ascii("enizations"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enized"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("enizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPHENIZATION_518047111423409166)],
        &[(0b10010, &ENTRY_HYPHENIZATIONS_2352732446948213541)],
        &[(0b10010, &ENTRY_HYPHENIZE_1355066745467653190)],
        &[(0b10010, &ENTRY_HYPHENIZED_11632374625403992542)],
        &[(0b10010, &ENTRY_HYPHENIZES_15581224527134621804)],
        &[(0b10010, &ENTRY_HYPHENIZING_17487608124210140279)],
        &[(0b01001, &ENTRY_HYPHENIZATION_518047111423409166)],
        &[(0b01001, &ENTRY_HYPHENIZATIONS_2352732446948213541)],
        &[(0b01001, &ENTRY_HYPHENIZE_1355066745467653190)],
        &[(0b01001, &ENTRY_HYPHENIZED_11632374625403992542)],
        &[(0b01001, &ENTRY_HYPHENIZES_15581224527134621804)],
        &[(0b01001, &ENTRY_HYPHENIZING_17487608124210140279)],
    ],
    range: 5..=10,
};

static VARS_HYPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HYPE_CHILDREN),
    value: None,
};

static VARS_HYPE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HYPER_NODE),
    Some(&VARS_HYPES_NODE),
    Some(&VARS_HYPET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HYPET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPET_CHILDREN),
    value: None,
};

pub static VARS_HYPET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("hral")],
    values: &[&[(0b10001, &ENTRY_HYPETHRAL_16444817472811439978)]],
    range: 4..=4,
};

static VARS_HYPES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPES_CHILDREN),
    value: None,
};

pub static VARS_HYPES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thesia"),
        dictgen::InsensitiveStr::Ascii("thesias"),
        dictgen::InsensitiveStr::Ascii("thesic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HYPESTHESIA_14564732207680543956)],
        &[(0b10001, &ENTRY_HYPESTHESIAS_4432727321640703024)],
        &[(0b10001, &ENTRY_HYPESTHESIC_1142742684373539307)],
    ],
    range: 6..=7,
};

static VARS_HYPER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HYPER_CHILDREN),
    value: None,
};

static VARS_HYPER_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HYPERA_NODE),
    Some(&VARS_HYPERB_NODE),
    Some(&VARS_HYPERC_NODE),
    None,
    Some(&VARS_HYPERE_NODE),
    None,
    Some(&VARS_HYPERG_NODE),
    None,
    Some(&VARS_HYPERI_NODE),
    None,
    None,
    Some(&VARS_HYPERL_NODE),
    None,
    Some(&VARS_HYPERN_NODE),
    Some(&VARS_HYPERO_NODE),
    Some(&VARS_HYPERP_NODE),
    None,
    Some(&VARS_HYPERR_NODE),
    Some(&VARS_HYPERS_NODE),
    Some(&VARS_HYPERT_NODE),
    None,
    Some(&VARS_HYPERV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_HYPERV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERV_CHILDREN),
    value: None,
};

pub static VARS_HYPERV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italisations"),
        dictgen::InsensitiveStr::Ascii("italise"),
        dictgen::InsensitiveStr::Ascii("italises"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italizations"),
        dictgen::InsensitiveStr::Ascii("italize"),
        dictgen::InsensitiveStr::Ascii("italizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERVITALIZATION_372457073358759943)],
        &[(0b10010, &ENTRY_HYPERVITALIZATIONS_16611523953783366472)],
        &[(0b10010, &ENTRY_HYPERVITALIZE_9679249450621626506)],
        &[(0b10010, &ENTRY_HYPERVITALIZES_11384012178375345224)],
        &[(0b01001, &ENTRY_HYPERVITALIZATION_372457073358759943)],
        &[(0b01001, &ENTRY_HYPERVITALIZATIONS_16611523953783366472)],
        &[(0b01001, &ENTRY_HYPERVITALIZE_9679249450621626506)],
        &[(0b01001, &ENTRY_HYPERVITALIZES_11384012178375345224)],
    ],
    range: 7..=12,
};

static VARS_HYPERT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERT_CHILDREN),
    value: None,
};

pub static VARS_HYPERT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hyroidisation"),
        dictgen::InsensitiveStr::Ascii("hyroidisations"),
        dictgen::InsensitiveStr::Ascii("hyroidise"),
        dictgen::InsensitiveStr::Ascii("hyroidises"),
        dictgen::InsensitiveStr::Ascii("hyroidization"),
        dictgen::InsensitiveStr::Ascii("hyroidizations"),
        dictgen::InsensitiveStr::Ascii("hyroidize"),
        dictgen::InsensitiveStr::Ascii("hyroidizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERTHYROIDIZATION_1460066134283167463)],
        &[(0b10010, &ENTRY_HYPERTHYROIDIZATIONS_644639064305189453)],
        &[(0b10010, &ENTRY_HYPERTHYROIDIZE_220125976519158472)],
        &[(0b10010, &ENTRY_HYPERTHYROIDIZES_16533830875218158099)],
        &[(0b01001, &ENTRY_HYPERTHYROIDIZATION_1460066134283167463)],
        &[(0b01001, &ENTRY_HYPERTHYROIDIZATIONS_644639064305189453)],
        &[(0b01001, &ENTRY_HYPERTHYROIDIZE_220125976519158472)],
        &[(0b01001, &ENTRY_HYPERTHYROIDIZES_16533830875218158099)],
    ],
    range: 9..=14,
};

static VARS_HYPERS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERS_CHILDREN),
    value: None,
};

pub static VARS_HYPERS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensitisation"),
        dictgen::InsensitiveStr::Ascii("ensitisations"),
        dictgen::InsensitiveStr::Ascii("ensitise"),
        dictgen::InsensitiveStr::Ascii("ensitised"),
        dictgen::InsensitiveStr::Ascii("ensitises"),
        dictgen::InsensitiveStr::Ascii("ensitising"),
        dictgen::InsensitiveStr::Ascii("ensitization"),
        dictgen::InsensitiveStr::Ascii("ensitizations"),
        dictgen::InsensitiveStr::Ascii("ensitize"),
        dictgen::InsensitiveStr::Ascii("ensitized"),
        dictgen::InsensitiveStr::Ascii("ensitizes"),
        dictgen::InsensitiveStr::Ascii("ensitizing"),
        dictgen::InsensitiveStr::Ascii("piritualising"),
        dictgen::InsensitiveStr::Ascii("piritualisings"),
        dictgen::InsensitiveStr::Ascii("piritualizing"),
        dictgen::InsensitiveStr::Ascii("piritualizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERSENSITIZATION_11377085362616181909)],
        &[(0b10010, &ENTRY_HYPERSENSITIZATIONS_7563579891463645188)],
        &[(0b10010, &ENTRY_HYPERSENSITIZE_11154923794098091939)],
        &[(0b10010, &ENTRY_HYPERSENSITIZED_3330978906246494687)],
        &[(0b10010, &ENTRY_HYPERSENSITIZES_11368790626933593739)],
        &[(0b10010, &ENTRY_HYPERSENSITIZING_6146233767758672273)],
        &[(0b01001, &ENTRY_HYPERSENSITIZATION_11377085362616181909)],
        &[(0b01001, &ENTRY_HYPERSENSITIZATIONS_7563579891463645188)],
        &[(0b01001, &ENTRY_HYPERSENSITIZE_11154923794098091939)],
        &[(0b01001, &ENTRY_HYPERSENSITIZED_3330978906246494687)],
        &[(0b01001, &ENTRY_HYPERSENSITIZES_11368790626933593739)],
        &[(0b01001, &ENTRY_HYPERSENSITIZING_6146233767758672273)],
        &[(0b10010, &ENTRY_HYPERSPIRITUALIZING_5448619034968576987)],
        &[(0b10010, &ENTRY_HYPERSPIRITUALIZINGS_11634664580831934117)],
        &[(0b01001, &ENTRY_HYPERSPIRITUALIZING_5448619034968576987)],
        &[(0b01001, &ENTRY_HYPERSPIRITUALIZINGS_11634664580831934117)],
    ],
    range: 8..=14,
};

static VARS_HYPERR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERR_CHILDREN),
    value: None,
};

pub static VARS_HYPERR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERREALIZE_18209108411522187070)],
        &[(0b10010, &ENTRY_HYPERREALIZES_6087084825849447883)],
        &[(0b01001, &ENTRY_HYPERREALIZE_18209108411522187070)],
        &[(0b01001, &ENTRY_HYPERREALIZES_6087084825849447883)],
    ],
    range: 6..=7,
};

static VARS_HYPERP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERP_CHILDREN),
    value: None,
};

pub static VARS_HYPERP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arasitise"),
        dictgen::InsensitiveStr::Ascii("arasitises"),
        dictgen::InsensitiveStr::Ascii("arasitize"),
        dictgen::InsensitiveStr::Ascii("arasitizes"),
        dictgen::InsensitiveStr::Ascii("nea"),
        dictgen::InsensitiveStr::Ascii("noea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERPARASITIZE_7853126625657581368)],
        &[(0b10010, &ENTRY_HYPERPARASITIZES_18286520501846479011)],
        &[(0b01001, &ENTRY_HYPERPARASITIZE_7853126625657581368)],
        &[(0b01001, &ENTRY_HYPERPARASITIZES_18286520501846479011)],
        &[(0b10001, &ENTRY_HYPERPNEA_12342432255421507220)],
        &[(0b11010, &ENTRY_HYPERPNEA_12342432255421507220)],
    ],
    range: 3..=10,
};

static VARS_HYPERO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERO_CHILDREN),
    value: None,
};

pub static VARS_HYPERO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("xygenise"),
        dictgen::InsensitiveStr::Ascii("xygenises"),
        dictgen::InsensitiveStr::Ascii("xygenize"),
        dictgen::InsensitiveStr::Ascii("xygenizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPEROXYGENIZE_14719478602723604195)],
        &[(0b10010, &ENTRY_HYPEROXYGENIZES_5991942787572964850)],
        &[(0b01001, &ENTRY_HYPEROXYGENIZE_14719478602723604195)],
        &[(0b01001, &ENTRY_HYPEROXYGENIZES_5991942787572964850)],
    ],
    range: 8..=9,
};

static VARS_HYPERN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERN_CHILDREN),
    value: None,
};

pub static VARS_HYPERN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atraemia"),
        dictgen::InsensitiveStr::Ascii("atremia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPERNATREMIA_9942512727988845580)],
        &[(0b10001, &ENTRY_HYPERNATREMIA_9942512727988845580)],
    ],
    range: 7..=8,
};

static VARS_HYPERL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERL_CHILDREN),
    value: None,
};

pub static VARS_HYPERL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ipaemia"),
        dictgen::InsensitiveStr::Ascii("ipaemic"),
        dictgen::InsensitiveStr::Ascii("ipemia"),
        dictgen::InsensitiveStr::Ascii("ipemic"),
        dictgen::InsensitiveStr::Ascii("ipidaemia"),
        dictgen::InsensitiveStr::Ascii("ipidemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPERLIPEMIA_17019921749433845994)],
        &[(0b11010, &ENTRY_HYPERLIPEMIC_14507717637329252900)],
        &[(0b10001, &ENTRY_HYPERLIPEMIA_17019921749433845994)],
        &[(0b10001, &ENTRY_HYPERLIPEMIC_14507717637329252900)],
        &[(0b11010, &ENTRY_HYPERLIPIDEMIA_2777804776193284974)],
        &[(0b10001, &ENTRY_HYPERLIPIDEMIA_2777804776193284974)],
    ],
    range: 6..=9,
};

static VARS_HYPERI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERI_CHILDREN),
    value: None,
};

pub static VARS_HYPERI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mmunisation"),
        dictgen::InsensitiveStr::Ascii("mmunisations"),
        dictgen::InsensitiveStr::Ascii("mmunise"),
        dictgen::InsensitiveStr::Ascii("mmunises"),
        dictgen::InsensitiveStr::Ascii("mmunization"),
        dictgen::InsensitiveStr::Ascii("mmunizations"),
        dictgen::InsensitiveStr::Ascii("mmunize"),
        dictgen::InsensitiveStr::Ascii("mmunizes"),
        dictgen::InsensitiveStr::Ascii("nsulinisation"),
        dictgen::InsensitiveStr::Ascii("nsulinisations"),
        dictgen::InsensitiveStr::Ascii("nsulinise"),
        dictgen::InsensitiveStr::Ascii("nsulinises"),
        dictgen::InsensitiveStr::Ascii("nsulinization"),
        dictgen::InsensitiveStr::Ascii("nsulinizations"),
        dictgen::InsensitiveStr::Ascii("nsulinize"),
        dictgen::InsensitiveStr::Ascii("nsulinizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERIMMUNIZATION_15847003636676248532)],
        &[(0b10010, &ENTRY_HYPERIMMUNIZATIONS_11646409859052189468)],
        &[(0b10010, &ENTRY_HYPERIMMUNIZE_17424124507015070277)],
        &[(0b10010, &ENTRY_HYPERIMMUNIZES_18311239313571916578)],
        &[(0b01001, &ENTRY_HYPERIMMUNIZATION_15847003636676248532)],
        &[(0b01001, &ENTRY_HYPERIMMUNIZATIONS_11646409859052189468)],
        &[(0b01001, &ENTRY_HYPERIMMUNIZE_17424124507015070277)],
        &[(0b01001, &ENTRY_HYPERIMMUNIZES_18311239313571916578)],
        &[(0b10010, &ENTRY_HYPERINSULINIZATION_8367048383423792181)],
        &[(0b10010, &ENTRY_HYPERINSULINIZATIONS_10721167808286232537)],
        &[(0b10010, &ENTRY_HYPERINSULINIZE_1640801475569483960)],
        &[(0b10010, &ENTRY_HYPERINSULINIZES_16582773226683393561)],
        &[(0b01001, &ENTRY_HYPERINSULINIZATION_8367048383423792181)],
        &[(0b01001, &ENTRY_HYPERINSULINIZATIONS_10721167808286232537)],
        &[(0b01001, &ENTRY_HYPERINSULINIZE_1640801475569483960)],
        &[(0b01001, &ENTRY_HYPERINSULINIZES_16582773226683393561)],
    ],
    range: 7..=14,
};

static VARS_HYPERG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERG_CHILDREN),
    value: None,
};

pub static VARS_HYPERG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lycaemic"),
        dictgen::InsensitiveStr::Ascii("lycemic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPERGLYCEMIC_2706228210156780391)],
        &[(0b10001, &ENTRY_HYPERGLYCEMIC_2706228210156780391)],
    ],
    range: 7..=8,
};

static VARS_HYPERE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERE_CHILDREN),
    value: None,
};

pub static VARS_HYPERE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mia"),
        dictgen::InsensitiveStr::Ascii("mias"),
        dictgen::InsensitiveStr::Ascii("mic"),
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthete"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("stheticer"),
        dictgen::InsensitiveStr::Ascii("stheticest"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HYPEREMIA_11403022388573074712)],
        &[(0b10001, &ENTRY_HYPEREMIAS_14973262707798439239)],
        &[(0b10001, &ENTRY_HYPEREMIC_14808381080797019440)],
        &[(0b10010, &ENTRY_HYPEREMPHASIZE_7223152754553927293)],
        &[(0b10010, &ENTRY_HYPEREMPHASIZES_2256689383008575579)],
        &[(0b01001, &ENTRY_HYPEREMPHASIZE_7223152754553927293)],
        &[(0b01001, &ENTRY_HYPEREMPHASIZES_2256689383008575579)],
        &[(0b10001, &ENTRY_HYPERESTHESIA_3173626697674674219)],
        &[(0b10001, &ENTRY_HYPERESTHESIAS_4970829968815661247)],
        &[(0b10001, &ENTRY_HYPERESTHETE_17327616943843185138)],
        &[(0b10001, &ENTRY_HYPERESTHETIC_13222558890179022448)],
        &[(0b10001, &ENTRY_HYPERESTHETICER_15328293772641718368)],
        &[(0b10001, &ENTRY_HYPERESTHETICEST_10480488079230686661)],
    ],
    range: 3..=10,
};

static VARS_HYPERC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERC_CHILDREN),
    value: None,
};

pub static VARS_HYPERC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alcaemia"),
        dictgen::InsensitiveStr::Ascii("alcaemias"),
        dictgen::InsensitiveStr::Ascii("alcemia"),
        dictgen::InsensitiveStr::Ascii("alcemias"),
        dictgen::InsensitiveStr::Ascii("alcinaemia"),
        dictgen::InsensitiveStr::Ascii("alcinemia"),
        dictgen::InsensitiveStr::Ascii("atharses"),
        dictgen::InsensitiveStr::Ascii("atharsises"),
        dictgen::InsensitiveStr::Ascii("hloraemia"),
        dictgen::InsensitiveStr::Ascii("hloremia"),
        dictgen::InsensitiveStr::Ascii("holesterolaemia"),
        dictgen::InsensitiveStr::Ascii("holesterolaemias"),
        dictgen::InsensitiveStr::Ascii("holesterolemia"),
        dictgen::InsensitiveStr::Ascii("holesterolemias"),
        dictgen::InsensitiveStr::Ascii("ivilisation"),
        dictgen::InsensitiveStr::Ascii("ivilisations"),
        dictgen::InsensitiveStr::Ascii("ivilised"),
        dictgen::InsensitiveStr::Ascii("iviliseds"),
        dictgen::InsensitiveStr::Ascii("ivilization"),
        dictgen::InsensitiveStr::Ascii("ivilizations"),
        dictgen::InsensitiveStr::Ascii("ivilized"),
        dictgen::InsensitiveStr::Ascii("ivilizeds"),
        dictgen::InsensitiveStr::Ascii("riticise"),
        dictgen::InsensitiveStr::Ascii("riticised"),
        dictgen::InsensitiveStr::Ascii("riticises"),
        dictgen::InsensitiveStr::Ascii("riticising"),
        dictgen::InsensitiveStr::Ascii("riticize"),
        dictgen::InsensitiveStr::Ascii("riticized"),
        dictgen::InsensitiveStr::Ascii("riticizes"),
        dictgen::InsensitiveStr::Ascii("riticizing"),
        dictgen::InsensitiveStr::Ascii("ryaesthesia"),
        dictgen::InsensitiveStr::Ascii("ryesthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPERCALCEMIA_11420824230101269161)],
        &[(0b11010, &ENTRY_HYPERCALCEMIAS_11134033661726779455)],
        &[(0b10001, &ENTRY_HYPERCALCEMIA_11420824230101269161)],
        &[(0b10001, &ENTRY_HYPERCALCEMIAS_11134033661726779455)],
        &[(0b11010, &ENTRY_HYPERCALCINEMIA_8023103474709621904)],
        &[(0b10001, &ENTRY_HYPERCALCINEMIA_8023103474709621904)],
        &[(0b11010, &ENTRY_HYPERCATHARSISES_2379400235584935479)],
        &[(0b00001, &ENTRY_HYPERCATHARSISES_2379400235584935479)],
        &[(0b11010, &ENTRY_HYPERCHLOREMIA_7441395776225879415)],
        &[(0b10001, &ENTRY_HYPERCHLOREMIA_7441395776225879415)],
        &[(0b11010, &ENTRY_HYPERCHOLESTEROLEMIA_3478964180569604143)],
        &[(0b11010, &ENTRY_HYPERCHOLESTEROLEMIAS_10902398019851674783)],
        &[(0b10001, &ENTRY_HYPERCHOLESTEROLEMIA_3478964180569604143)],
        &[(0b10001, &ENTRY_HYPERCHOLESTEROLEMIAS_10902398019851674783)],
        &[(0b10010, &ENTRY_HYPERCIVILIZATION_13803153736151445143)],
        &[(0b10010, &ENTRY_HYPERCIVILIZATIONS_15211543891339482443)],
        &[(0b10010, &ENTRY_HYPERCIVILIZED_4129945024296325999)],
        &[(0b10010, &ENTRY_HYPERCIVILIZEDS_8179865442803788169)],
        &[(0b01001, &ENTRY_HYPERCIVILIZATION_13803153736151445143)],
        &[(0b01001, &ENTRY_HYPERCIVILIZATIONS_15211543891339482443)],
        &[(0b01001, &ENTRY_HYPERCIVILIZED_4129945024296325999)],
        &[(0b01001, &ENTRY_HYPERCIVILIZEDS_8179865442803788169)],
        &[(0b10010, &ENTRY_HYPERCRITICIZE_7531870804381594430)],
        &[(0b10010, &ENTRY_HYPERCRITICIZED_16299270072259171288)],
        &[(0b10010, &ENTRY_HYPERCRITICIZES_17766772107445549296)],
        &[(0b10010, &ENTRY_HYPERCRITICIZING_11441741306039788542)],
        &[(0b01001, &ENTRY_HYPERCRITICIZE_7531870804381594430)],
        &[(0b01001, &ENTRY_HYPERCRITICIZED_16299270072259171288)],
        &[(0b01001, &ENTRY_HYPERCRITICIZES_17766772107445549296)],
        &[(0b01001, &ENTRY_HYPERCRITICIZING_11441741306039788542)],
        &[(0b11010, &ENTRY_HYPERCRYESTHESIA_16159941951842497999)],
        &[(0b00001, &ENTRY_HYPERCRYESTHESIA_16159941951842497999)],
    ],
    range: 7..=16,
};

static VARS_HYPERB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERB_CHILDREN),
    value: None,
};

pub static VARS_HYPERB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYPERBOLIZE_17992431734514947864)],
        &[(0b10010, &ENTRY_HYPERBOLIZED_411978819565944419)],
        &[(0b10010, &ENTRY_HYPERBOLIZES_10753409068722265798)],
        &[(0b10010, &ENTRY_HYPERBOLIZING_9551617205341066643)],
        &[(0b01001, &ENTRY_HYPERBOLIZE_17992431734514947864)],
        &[(0b01001, &ENTRY_HYPERBOLIZED_411978819565944419)],
        &[(0b01001, &ENTRY_HYPERBOLIZES_10753409068722265798)],
        &[(0b01001, &ENTRY_HYPERBOLIZING_9551617205341066643)],
    ],
    range: 5..=7,
};

static VARS_HYPERA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPERA_CHILDREN),
    value: None,
};

pub static VARS_HYPERA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emia"),
        dictgen::InsensitiveStr::Ascii("emias"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthete"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
        dictgen::InsensitiveStr::Ascii("estheticer"),
        dictgen::InsensitiveStr::Ascii("estheticest"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPEREMIA_11403022388573074712)],
        &[(0b11010, &ENTRY_HYPEREMIAS_14973262707798439239)],
        &[(0b11010, &ENTRY_HYPEREMIC_14808381080797019440)],
        &[(0b11010, &ENTRY_HYPERESTHESIA_3173626697674674219)],
        &[(0b11010, &ENTRY_HYPERESTHESIAS_4970829968815661247)],
        &[(0b11010, &ENTRY_HYPERESTHETE_17327616943843185138)],
        &[(0b11010, &ENTRY_HYPERESTHETIC_13222558890179022448)],
        &[(0b11010, &ENTRY_HYPERESTHETICER_15328293772641718368)],
        &[(0b11010, &ENTRY_HYPERESTHETICEST_10480488079230686661)],
    ],
    range: 4..=11,
};

static VARS_HYPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYPA_CHILDREN),
    value: None,
};

pub static VARS_HYPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthesias"),
        dictgen::InsensitiveStr::Ascii("esthesic"),
        dictgen::InsensitiveStr::Ascii("ethral"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYPESTHESIA_14564732207680543956)],
        &[(0b11010, &ENTRY_HYPESTHESIAS_4432727321640703024)],
        &[(0b11010, &ENTRY_HYPESTHESIC_1142742684373539307)],
        &[(0b11010, &ENTRY_HYPETHRAL_16444817472811439978)],
    ],
    range: 6..=9,
};

static VARS_HYM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYM_CHILDREN),
    value: None,
};

pub static VARS_HYM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enaean"),
        dictgen::InsensitiveStr::Ascii("enean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYMENEAN_13932552305346136403)],
        &[(0b10001, &ENTRY_HYMENEAN_13932552305346136403)],
    ],
    range: 5..=6,
};

static VARS_HYG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYG_CHILDREN),
    value: None,
};

pub static VARS_HYG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ienisation"),
        dictgen::InsensitiveStr::Ascii("ienisations"),
        dictgen::InsensitiveStr::Ascii("ienise"),
        dictgen::InsensitiveStr::Ascii("ienises"),
        dictgen::InsensitiveStr::Ascii("ienization"),
        dictgen::InsensitiveStr::Ascii("ienizations"),
        dictgen::InsensitiveStr::Ascii("ienize"),
        dictgen::InsensitiveStr::Ascii("ienizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYGIENIZATION_625023551255960285)],
        &[(0b10010, &ENTRY_HYGIENIZATIONS_6338160659202170314)],
        &[(0b10010, &ENTRY_HYGIENIZE_12397245127353122790)],
        &[(0b10010, &ENTRY_HYGIENIZES_17832600989781813895)],
        &[(0b01001, &ENTRY_HYGIENIZATION_625023551255960285)],
        &[(0b01001, &ENTRY_HYGIENIZATIONS_6338160659202170314)],
        &[(0b01001, &ENTRY_HYGIENIZE_12397245127353122790)],
        &[(0b01001, &ENTRY_HYGIENIZES_17832600989781813895)],
    ],
    range: 6..=11,
};

static VARS_HYE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYE_CHILDREN),
    value: None,
};

pub static VARS_HYE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("nic")],
    values: &[&[(0b00001, &ENTRY_HYENIC_15051336625087668416)]],
    range: 3..=3,
};

static VARS_HYD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYD_CHILDREN),
    value: None,
};

pub static VARS_HYD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("raemia"),
        dictgen::InsensitiveStr::Ascii("raemias"),
        dictgen::InsensitiveStr::Ascii("raemic"),
        dictgen::InsensitiveStr::Ascii("remia"),
        dictgen::InsensitiveStr::Ascii("remias"),
        dictgen::InsensitiveStr::Ascii("remic"),
        dictgen::InsensitiveStr::Ascii("rocele"),
        dictgen::InsensitiveStr::Ascii("rocoele"),
        dictgen::InsensitiveStr::Ascii("rogenisation"),
        dictgen::InsensitiveStr::Ascii("rogenisations"),
        dictgen::InsensitiveStr::Ascii("rogenise"),
        dictgen::InsensitiveStr::Ascii("rogenised"),
        dictgen::InsensitiveStr::Ascii("rogenises"),
        dictgen::InsensitiveStr::Ascii("rogenising"),
        dictgen::InsensitiveStr::Ascii("rogenization"),
        dictgen::InsensitiveStr::Ascii("rogenizations"),
        dictgen::InsensitiveStr::Ascii("rogenize"),
        dictgen::InsensitiveStr::Ascii("rogenized"),
        dictgen::InsensitiveStr::Ascii("rogenizes"),
        dictgen::InsensitiveStr::Ascii("rogenizing"),
        dictgen::InsensitiveStr::Ascii("rolise"),
        dictgen::InsensitiveStr::Ascii("rolize"),
        dictgen::InsensitiveStr::Ascii("rolysable"),
        dictgen::InsensitiveStr::Ascii("rolysabler"),
        dictgen::InsensitiveStr::Ascii("rolysables"),
        dictgen::InsensitiveStr::Ascii("rolysablest"),
        dictgen::InsensitiveStr::Ascii("rolysate"),
        dictgen::InsensitiveStr::Ascii("rolysates"),
        dictgen::InsensitiveStr::Ascii("rolysation"),
        dictgen::InsensitiveStr::Ascii("rolyse"),
        dictgen::InsensitiveStr::Ascii("rolysed"),
        dictgen::InsensitiveStr::Ascii("rolyser"),
        dictgen::InsensitiveStr::Ascii("rolysing"),
        dictgen::InsensitiveStr::Ascii("rolyzable"),
        dictgen::InsensitiveStr::Ascii("rolyzabler"),
        dictgen::InsensitiveStr::Ascii("rolyzables"),
        dictgen::InsensitiveStr::Ascii("rolyzablest"),
        dictgen::InsensitiveStr::Ascii("rolyzate"),
        dictgen::InsensitiveStr::Ascii("rolyzates"),
        dictgen::InsensitiveStr::Ascii("rolyzation"),
        dictgen::InsensitiveStr::Ascii("rolyze"),
        dictgen::InsensitiveStr::Ascii("rolyzed"),
        dictgen::InsensitiveStr::Ascii("rolyzer"),
        dictgen::InsensitiveStr::Ascii("rolyzes"),
        dictgen::InsensitiveStr::Ascii("rolyzing"),
        dictgen::InsensitiveStr::Ascii("rorrhea"),
        dictgen::InsensitiveStr::Ascii("rorrhoea"),
        dictgen::InsensitiveStr::Ascii("roxylisation"),
        dictgen::InsensitiveStr::Ascii("roxylisations"),
        dictgen::InsensitiveStr::Ascii("roxylise"),
        dictgen::InsensitiveStr::Ascii("roxylises"),
        dictgen::InsensitiveStr::Ascii("roxylization"),
        dictgen::InsensitiveStr::Ascii("roxylizations"),
        dictgen::InsensitiveStr::Ascii("roxylize"),
        dictgen::InsensitiveStr::Ascii("roxylizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYDREMIA_15737604061809105573)],
        &[(0b11010, &ENTRY_HYDREMIAS_5705396115596322771)],
        &[(0b11010, &ENTRY_HYDREMIC_7677276768554498277)],
        &[(0b10001, &ENTRY_HYDREMIA_15737604061809105573)],
        &[(0b10001, &ENTRY_HYDREMIAS_5705396115596322771)],
        &[(0b10001, &ENTRY_HYDREMIC_7677276768554498277)],
        &[(0b10001, &ENTRY_HYDROCELE_10742030391066081682)],
        &[(0b11010, &ENTRY_HYDROCELE_10742030391066081682)],
        &[(0b10010, &ENTRY_HYDROGENIZATION_1304003273128011350)],
        &[(0b10010, &ENTRY_HYDROGENIZATIONS_13526938534356803421)],
        &[(0b10010, &ENTRY_HYDROGENIZE_3962922331531856094)],
        &[(0b10010, &ENTRY_HYDROGENIZED_10274497346817495654)],
        &[(0b10010, &ENTRY_HYDROGENIZES_15414612709209000503)],
        &[(0b10010, &ENTRY_HYDROGENIZING_14049891921794212990)],
        &[(0b01001, &ENTRY_HYDROGENIZATION_1304003273128011350)],
        &[(0b01001, &ENTRY_HYDROGENIZATIONS_13526938534356803421)],
        &[(0b01001, &ENTRY_HYDROGENIZE_3962922331531856094)],
        &[(0b01001, &ENTRY_HYDROGENIZED_10274497346817495654)],
        &[(0b01001, &ENTRY_HYDROGENIZES_15414612709209000503)],
        &[(0b01001, &ENTRY_HYDROGENIZING_14049891921794212990)],
        &[(0b10010, &ENTRY_HYDROLIZE_5796989920616720182)],
        &[(0b01001, &ENTRY_HYDROLIZE_5796989920616720182)],
        &[(0b10010, &ENTRY_HYDROLYZABLE_8991197244785935669)],
        &[(0b10010, &ENTRY_HYDROLYZABLER_12427972367765097514)],
        &[(0b10010, &ENTRY_HYDROLYZABLES_15919432710942584334)],
        &[(0b10010, &ENTRY_HYDROLYZABLEST_9835789422025315722)],
        &[(0b10010, &ENTRY_HYDROLYZATE_7572075944447421858)],
        &[(0b10010, &ENTRY_HYDROLYZATES_1902626880371868391)],
        &[(0b10010, &ENTRY_HYDROLYZATION_5046652609416235138)],
        &[(0b11010, &ENTRY_HYDROLYZE_14713911854595051121)],
        &[(0b11010, &ENTRY_HYDROLYZED_3791193711312452932)],
        &[(0b10010, &ENTRY_HYDROLYZER_7963252770617082917)],
        &[(0b11010, &ENTRY_HYDROLYZING_12759236550275710849)],
        &[(0b01001, &ENTRY_HYDROLYZABLE_8991197244785935669)],
        &[(0b01001, &ENTRY_HYDROLYZABLER_12427972367765097514)],
        &[(0b01001, &ENTRY_HYDROLYZABLES_15919432710942584334)],
        &[(0b01001, &ENTRY_HYDROLYZABLEST_9835789422025315722)],
        &[(0b01001, &ENTRY_HYDROLYZATE_7572075944447421858)],
        &[(0b01001, &ENTRY_HYDROLYZATES_1902626880371868391)],
        &[(0b01001, &ENTRY_HYDROLYZATION_5046652609416235138)],
        &[(0b01001, &ENTRY_HYDROLYZE_14713911854595051121)],
        &[(0b01001, &ENTRY_HYDROLYZED_3791193711312452932)],
        &[(0b01001, &ENTRY_HYDROLYZER_7963252770617082917)],
        &[(0b01001, &ENTRY_HYDROLYZES_10792622190037744120)],
        &[(0b01001, &ENTRY_HYDROLYZING_12759236550275710849)],
        &[(0b10001, &ENTRY_HYDRORRHEA_14755418364154758097)],
        &[(0b11010, &ENTRY_HYDRORRHEA_14755418364154758097)],
        &[(0b10010, &ENTRY_HYDROXYLIZATION_11144096051800167199)],
        &[(0b10010, &ENTRY_HYDROXYLIZATIONS_9323455027499464587)],
        &[(0b10010, &ENTRY_HYDROXYLIZE_6225544713210248934)],
        &[(0b10010, &ENTRY_HYDROXYLIZES_11433886242354117839)],
        &[(0b01001, &ENTRY_HYDROXYLIZATION_11144096051800167199)],
        &[(0b01001, &ENTRY_HYDROXYLIZATIONS_9323455027499464587)],
        &[(0b01001, &ENTRY_HYDROXYLIZE_6225544713210248934)],
        &[(0b01001, &ENTRY_HYDROXYLIZES_11433886242354117839)],
    ],
    range: 5..=13,
};

static VARS_HYB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYB_CHILDREN),
    value: None,
};

pub static VARS_HYB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ridisable"),
        dictgen::InsensitiveStr::Ascii("ridisabler"),
        dictgen::InsensitiveStr::Ascii("ridisables"),
        dictgen::InsensitiveStr::Ascii("ridisablest"),
        dictgen::InsensitiveStr::Ascii("ridisation"),
        dictgen::InsensitiveStr::Ascii("ridisations"),
        dictgen::InsensitiveStr::Ascii("ridise"),
        dictgen::InsensitiveStr::Ascii("ridised"),
        dictgen::InsensitiveStr::Ascii("ridiser"),
        dictgen::InsensitiveStr::Ascii("ridisers"),
        dictgen::InsensitiveStr::Ascii("ridises"),
        dictgen::InsensitiveStr::Ascii("ridising"),
        dictgen::InsensitiveStr::Ascii("ridizable"),
        dictgen::InsensitiveStr::Ascii("ridizabler"),
        dictgen::InsensitiveStr::Ascii("ridizables"),
        dictgen::InsensitiveStr::Ascii("ridizablest"),
        dictgen::InsensitiveStr::Ascii("ridization"),
        dictgen::InsensitiveStr::Ascii("ridizations"),
        dictgen::InsensitiveStr::Ascii("ridize"),
        dictgen::InsensitiveStr::Ascii("ridized"),
        dictgen::InsensitiveStr::Ascii("ridizer"),
        dictgen::InsensitiveStr::Ascii("ridizers"),
        dictgen::InsensitiveStr::Ascii("ridizes"),
        dictgen::InsensitiveStr::Ascii("ridizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HYBRIDIZABLE_10574109574999308410)],
        &[(0b10010, &ENTRY_HYBRIDIZABLER_4007040412317588432)],
        &[(0b10010, &ENTRY_HYBRIDIZABLES_5241796645102016487)],
        &[(0b10010, &ENTRY_HYBRIDIZABLEST_373072217288267910)],
        &[(0b10010, &ENTRY_HYBRIDIZATION_161986988115386392)],
        &[(0b10010, &ENTRY_HYBRIDIZATIONS_15165179760111354303)],
        &[(0b10010, &ENTRY_HYBRIDIZE_12739035965572292237)],
        &[(0b10010, &ENTRY_HYBRIDIZED_2291718058649708615)],
        &[(0b10010, &ENTRY_HYBRIDIZER_413649520934854910)],
        &[(0b10010, &ENTRY_HYBRIDIZERS_13820118558244742035)],
        &[(0b10010, &ENTRY_HYBRIDIZES_47886802934099991)],
        &[(0b10010, &ENTRY_HYBRIDIZING_17601175295259958488)],
        &[(0b01001, &ENTRY_HYBRIDIZABLE_10574109574999308410)],
        &[(0b01001, &ENTRY_HYBRIDIZABLER_4007040412317588432)],
        &[(0b01001, &ENTRY_HYBRIDIZABLES_5241796645102016487)],
        &[(0b01001, &ENTRY_HYBRIDIZABLEST_373072217288267910)],
        &[(0b01001, &ENTRY_HYBRIDIZATION_161986988115386392)],
        &[(0b01001, &ENTRY_HYBRIDIZATIONS_15165179760111354303)],
        &[(0b01001, &ENTRY_HYBRIDIZE_12739035965572292237)],
        &[(0b01001, &ENTRY_HYBRIDIZED_2291718058649708615)],
        &[(0b01001, &ENTRY_HYBRIDIZER_413649520934854910)],
        &[(0b01001, &ENTRY_HYBRIDIZERS_13820118558244742035)],
        &[(0b01001, &ENTRY_HYBRIDIZES_47886802934099991)],
        &[(0b01001, &ENTRY_HYBRIDIZING_17601175295259958488)],
    ],
    range: 6..=11,
};

static VARS_HYA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HYA_CHILDREN),
    value: None,
};

pub static VARS_HYA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enic"),
        dictgen::InsensitiveStr::Ascii("linisation"),
        dictgen::InsensitiveStr::Ascii("linisations"),
        dictgen::InsensitiveStr::Ascii("linise"),
        dictgen::InsensitiveStr::Ascii("linised"),
        dictgen::InsensitiveStr::Ascii("linises"),
        dictgen::InsensitiveStr::Ascii("linising"),
        dictgen::InsensitiveStr::Ascii("linization"),
        dictgen::InsensitiveStr::Ascii("linizations"),
        dictgen::InsensitiveStr::Ascii("linize"),
        dictgen::InsensitiveStr::Ascii("linized"),
        dictgen::InsensitiveStr::Ascii("linizes"),
        dictgen::InsensitiveStr::Ascii("linizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HYENIC_15051336625087668416)],
        &[(0b10010, &ENTRY_HYALINIZATION_7110805105087800464)],
        &[(0b10010, &ENTRY_HYALINIZATIONS_5013187970535765431)],
        &[(0b10010, &ENTRY_HYALINIZE_11908495486530243350)],
        &[(0b10010, &ENTRY_HYALINIZED_8648450487385096318)],
        &[(0b10010, &ENTRY_HYALINIZES_6068368648603328649)],
        &[(0b10010, &ENTRY_HYALINIZING_1451919180488822376)],
        &[(0b01001, &ENTRY_HYALINIZATION_7110805105087800464)],
        &[(0b01001, &ENTRY_HYALINIZATIONS_5013187970535765431)],
        &[(0b01001, &ENTRY_HYALINIZE_11908495486530243350)],
        &[(0b01001, &ENTRY_HYALINIZED_8648450487385096318)],
        &[(0b01001, &ENTRY_HYALINIZES_6068368648603328649)],
        &[(0b01001, &ENTRY_HYALINIZING_1451919180488822376)],
    ],
    range: 4..=11,
};

static VARS_HU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HU_CHILDREN),
    value: None,
};

static VARS_HU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_HUC_NODE),
    None,
    Some(&VARS_HUE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HUM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HUR_CHILDREN),
    value: None,
};

pub static VARS_HUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("rahes"),
        dictgen::InsensitiveStr::Ascii("ricanise"),
        dictgen::InsensitiveStr::Ascii("ricanises"),
        dictgen::InsensitiveStr::Ascii("ricanize"),
        dictgen::InsensitiveStr::Ascii("ricanizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HUER_14814098217806996597)],
        &[(0b00001, &ENTRY_HURRAHS_17087845443906118467)],
        &[(0b10010, &ENTRY_HURRICANIZE_11443075877213865736)],
        &[(0b10010, &ENTRY_HURRICANIZES_14038183598909771719)],
        &[(0b01001, &ENTRY_HURRICANIZE_11443075877213865736)],
        &[(0b01001, &ENTRY_HURRICANIZES_14038183598909771719)],
    ],
    range: 1..=9,
};

static VARS_HUM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HUM_CHILDREN),
    value: None,
};

pub static VARS_HUM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anisations"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anisers"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anitarianise"),
        dictgen::InsensitiveStr::Ascii("anitarianises"),
        dictgen::InsensitiveStr::Ascii("anitarianize"),
        dictgen::InsensitiveStr::Ascii("anitarianizes"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anizations"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizers"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("orful"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("orlesser"),
        dictgen::InsensitiveStr::Ascii("orlesses"),
        dictgen::InsensitiveStr::Ascii("orlessest"),
        dictgen::InsensitiveStr::Ascii("orlessness"),
        dictgen::InsensitiveStr::Ascii("orlessnesses"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("orsome"),
        dictgen::InsensitiveStr::Ascii("orsomeness"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oural"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ourful"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ourlesser"),
        dictgen::InsensitiveStr::Ascii("ourlesses"),
        dictgen::InsensitiveStr::Ascii("ourlessest"),
        dictgen::InsensitiveStr::Ascii("ourlessness"),
        dictgen::InsensitiveStr::Ascii("ourlessnesses"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("oursome"),
        dictgen::InsensitiveStr::Ascii("oursomeness"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HUMANIZATION_5830695966920821886)],
        &[(0b10010, &ENTRY_HUMANIZATIONS_3865648289532969387)],
        &[(0b10010, &ENTRY_HUMANIZE_4044911342190458943)],
        &[(0b10010, &ENTRY_HUMANIZED_15704417917952177815)],
        &[(0b10010, &ENTRY_HUMANIZER_12017356498460139218)],
        &[(0b10010, &ENTRY_HUMANIZERS_10409227793679563956)],
        &[(0b10010, &ENTRY_HUMANIZES_6273845182070294397)],
        &[(0b10010, &ENTRY_HUMANIZING_15664126028277437903)],
        &[(0b10010, &ENTRY_HUMANITARIANIZE_10414962610230588177)],
        &[(0b10010, &ENTRY_HUMANITARIANIZES_18048535083732291734)],
        &[(0b01001, &ENTRY_HUMANITARIANIZE_10414962610230588177)],
        &[(0b01001, &ENTRY_HUMANITARIANIZES_18048535083732291734)],
        &[(0b01001, &ENTRY_HUMANIZATION_5830695966920821886)],
        &[(0b01001, &ENTRY_HUMANIZATIONS_3865648289532969387)],
        &[(0b01001, &ENTRY_HUMANIZE_4044911342190458943)],
        &[(0b01001, &ENTRY_HUMANIZED_15704417917952177815)],
        &[(0b01001, &ENTRY_HUMANIZER_12017356498460139218)],
        &[(0b01001, &ENTRY_HUMANIZERS_10409227793679563956)],
        &[(0b01001, &ENTRY_HUMANIZES_6273845182070294397)],
        &[(0b01001, &ENTRY_HUMANIZING_15664126028277437903)],
        &[(0b11001, &ENTRY_HUMOR_2121063190473553072)],
        &[(0b11001, &ENTRY_HUMORED_11087443859021308864)],
        &[(0b11001, &ENTRY_HUMORER_14321582164268398325)],
        &[(0b11001, &ENTRY_HUMORERS_11361453604963756719)],
        &[(0b11001, &ENTRY_HUMORFUL_15115567956635786701)],
        &[(0b11001, &ENTRY_HUMORING_14086332731556696553)],
        &[(0b10010, &ENTRY_HUMORIZE_7965858586505042691)],
        &[(0b10010, &ENTRY_HUMORIZES_3167907102560083410)],
        &[(0b01001, &ENTRY_HUMORIZE_7965858586505042691)],
        &[(0b01001, &ENTRY_HUMORIZES_3167907102560083410)],
        &[(0b11001, &ENTRY_HUMORLESS_12186481528337453416)],
        &[(0b11001, &ENTRY_HUMORLESSER_16003980549488709473)],
        &[(0b11001, &ENTRY_HUMORLESSES_370612185245224252)],
        &[(0b11001, &ENTRY_HUMORLESSEST_11446149668669386608)],
        &[(0b11001, &ENTRY_HUMORLESSNESS_18219335685205775655)],
        &[(0b11001, &ENTRY_HUMORLESSNESSES_17811424853582146815)],
        &[(0b11001, &ENTRY_HUMORS_5159689657032296642)],
        &[(0b11001, &ENTRY_HUMORSOME_8048377448291557893)],
        &[(0b11001, &ENTRY_HUMORSOMENESS_10935035806711277523)],
        &[(0b11010, &ENTRY_HUMOR_2121063190473553072)],
        &[(0b11010, &ENTRY_HUMORAL_2853760863304111656)],
        &[(0b11010, &ENTRY_HUMORED_11087443859021308864)],
        &[(0b11010, &ENTRY_HUMORER_14321582164268398325)],
        &[(0b11010, &ENTRY_HUMORERS_11361453604963756719)],
        &[(0b11010, &ENTRY_HUMORFUL_15115567956635786701)],
        &[(0b11010, &ENTRY_HUMORING_14086332731556696553)],
        &[(0b11010, &ENTRY_HUMORLESS_12186481528337453416)],
        &[(0b11010, &ENTRY_HUMORLESSER_16003980549488709473)],
        &[(0b11010, &ENTRY_HUMORLESSES_370612185245224252)],
        &[(0b11010, &ENTRY_HUMORLESSEST_11446149668669386608)],
        &[(0b11010, &ENTRY_HUMORLESSNESS_18219335685205775655)],
        &[(0b11010, &ENTRY_HUMORLESSNESSES_17811424853582146815)],
        &[(0b11010, &ENTRY_HUMORS_5159689657032296642)],
        &[(0b11010, &ENTRY_HUMORSOME_8048377448291557893)],
        &[(0b11010, &ENTRY_HUMORSOMENESS_10935035806711277523)],
    ],
    range: 2..=13,
};

static VARS_HUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HUE_CHILDREN),
    value: None,
};

pub static VARS_HUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("r")],
    values: &[&[(0b00001, &ENTRY_HUER_14814098217806996597)]],
    range: 1..=1,
};

static VARS_HUC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HUC_CHILDREN),
    value: None,
};

pub static VARS_HUC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ksterise"),
        dictgen::InsensitiveStr::Ascii("ksterises"),
        dictgen::InsensitiveStr::Ascii("ksterize"),
        dictgen::InsensitiveStr::Ascii("ksterizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HUCKSTERIZE_13308151300872354760)],
        &[(0b10010, &ENTRY_HUCKSTERIZES_8268659569338877880)],
        &[(0b01001, &ENTRY_HUCKSTERIZE_13308151300872354760)],
        &[(0b01001, &ENTRY_HUCKSTERIZES_8268659569338877880)],
    ],
    range: 8..=9,
};

static VARS_HO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HO_CHILDREN),
    value: None,
};

static VARS_HO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HOL_NODE),
    Some(&VARS_HOM_NODE),
    Some(&VARS_HON_NODE),
    Some(&VARS_HOO_NODE),
    None,
    None,
    Some(&VARS_HOR_NODE),
    Some(&VARS_HOS_NODE),
    Some(&VARS_HOT_NODE),
    Some(&VARS_HOU_NODE),
    Some(&VARS_HOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_HOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOV_CHILDREN),
    value: None,
};

pub static VARS_HOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HOVELED_12568330716779771103)],
        &[(0b00001, &ENTRY_HOVELER_1958268142806831894)],
        &[(0b00001, &ENTRY_HOVELERS_13219825849431143741)],
        &[(0b00001, &ENTRY_HOVELING_7298952268414160735)],
        &[(0b11010, &ENTRY_HOVELED_12568330716779771103)],
        &[(0b11010, &ENTRY_HOVELER_1958268142806831894)],
        &[(0b11010, &ENTRY_HOVELERS_13219825849431143741)],
        &[(0b11010, &ENTRY_HOVELING_7298952268414160735)],
    ],
    range: 4..=6,
};

static VARS_HOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOU_CHILDREN),
    value: None,
};

pub static VARS_HOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seling"),
        dictgen::InsensitiveStr::Ascii("selings"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("selling"),
        dictgen::InsensitiveStr::Ascii("sellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HOUSELED_11961205696401030035)],
        &[(0b00001, &ENTRY_HOUSELING_9033251538610526455)],
        &[(0b00001, &ENTRY_HOUSELINGS_15578665640776341869)],
        &[(0b11010, &ENTRY_HOUSELED_11961205696401030035)],
        &[(0b11010, &ENTRY_HOUSELING_9033251538610526455)],
        &[(0b11010, &ENTRY_HOUSELINGS_15578665640776341869)],
    ],
    range: 5..=8,
};

static VARS_HOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOT_CHILDREN),
    value: None,
};

pub static VARS_HOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOTELIZATION_11630362029882906887)],
        &[(0b10010, &ENTRY_HOTELIZATIONS_6794114000883410377)],
        &[(0b10010, &ENTRY_HOTELIZE_10883646870902168688)],
        &[(0b10010, &ENTRY_HOTELIZES_8836454095068282095)],
        &[(0b01001, &ENTRY_HOTELIZATION_11630362029882906887)],
        &[(0b01001, &ENTRY_HOTELIZATIONS_6794114000883410377)],
        &[(0b01001, &ENTRY_HOTELIZE_10883646870902168688)],
        &[(0b01001, &ENTRY_HOTELIZES_8836454095068282095)],
    ],
    range: 5..=10,
};

static VARS_HOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOS_CHILDREN),
    value: None,
};

pub static VARS_HOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("pitalisation"),
        dictgen::InsensitiveStr::Ascii("pitalisations"),
        dictgen::InsensitiveStr::Ascii("pitalise"),
        dictgen::InsensitiveStr::Ascii("pitalised"),
        dictgen::InsensitiveStr::Ascii("pitalises"),
        dictgen::InsensitiveStr::Ascii("pitalising"),
        dictgen::InsensitiveStr::Ascii("pitalization"),
        dictgen::InsensitiveStr::Ascii("pitalizations"),
        dictgen::InsensitiveStr::Ascii("pitalize"),
        dictgen::InsensitiveStr::Ascii("pitalized"),
        dictgen::InsensitiveStr::Ascii("pitalizes"),
        dictgen::InsensitiveStr::Ascii("pitalizing"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOSPITALIZATION_6876754108770647316)],
        &[(0b10010, &ENTRY_HOSPITALIZATIONS_9565778561496260205)],
        &[(0b10010, &ENTRY_HOSPITALIZE_6250395622105373650)],
        &[(0b10010, &ENTRY_HOSPITALIZED_14669852566244731121)],
        &[(0b10010, &ENTRY_HOSPITALIZES_15004904411392264424)],
        &[(0b10010, &ENTRY_HOSPITALIZING_13736882711613304855)],
        &[(0b01001, &ENTRY_HOSPITALIZATION_6876754108770647316)],
        &[(0b01001, &ENTRY_HOSPITALIZATIONS_9565778561496260205)],
        &[(0b01001, &ENTRY_HOSPITALIZE_6250395622105373650)],
        &[(0b01001, &ENTRY_HOSPITALIZED_14669852566244731121)],
        &[(0b01001, &ENTRY_HOSPITALIZES_15004904411392264424)],
        &[(0b01001, &ENTRY_HOSPITALIZING_13736882711613304855)],
        &[(0b10010, &ENTRY_HOSTILIZE_13783071968481819947)],
        &[(0b10010, &ENTRY_HOSTILIZES_4822749923344907441)],
        &[(0b01001, &ENTRY_HOSTILIZE_13783071968481819947)],
        &[(0b01001, &ENTRY_HOSTILIZES_4822749923344907441)],
    ],
    range: 6..=13,
};

static VARS_HOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOR_CHILDREN),
    value: None,
};

pub static VARS_HOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("izontalisation"),
        dictgen::InsensitiveStr::Ascii("izontalisations"),
        dictgen::InsensitiveStr::Ascii("izontalise"),
        dictgen::InsensitiveStr::Ascii("izontalises"),
        dictgen::InsensitiveStr::Ascii("izontalization"),
        dictgen::InsensitiveStr::Ascii("izontalizations"),
        dictgen::InsensitiveStr::Ascii("izontalize"),
        dictgen::InsensitiveStr::Ascii("izontalizes"),
        dictgen::InsensitiveStr::Ascii("monise"),
        dictgen::InsensitiveStr::Ascii("monises"),
        dictgen::InsensitiveStr::Ascii("monize"),
        dictgen::InsensitiveStr::Ascii("monizes"),
        dictgen::InsensitiveStr::Ascii("rorise"),
        dictgen::InsensitiveStr::Ascii("rorises"),
        dictgen::InsensitiveStr::Ascii("rorize"),
        dictgen::InsensitiveStr::Ascii("rorizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HORE_240384164818754909)],
        &[(0b00001, &ENTRY_HORE_240384164818754909)],
        &[(0b10010, &ENTRY_HORIZONTALIZATION_5399738844710518132)],
        &[(0b10010, &ENTRY_HORIZONTALIZATIONS_12341881527322670940)],
        &[(0b10010, &ENTRY_HORIZONTALIZE_7528617191591553093)],
        &[(0b10010, &ENTRY_HORIZONTALIZES_7733280569310807502)],
        &[(0b01001, &ENTRY_HORIZONTALIZATION_5399738844710518132)],
        &[(0b01001, &ENTRY_HORIZONTALIZATIONS_12341881527322670940)],
        &[(0b01001, &ENTRY_HORIZONTALIZE_7528617191591553093)],
        &[(0b01001, &ENTRY_HORIZONTALIZES_7733280569310807502)],
        &[(0b10010, &ENTRY_HORMONIZE_16402712449126296970)],
        &[(0b10010, &ENTRY_HORMONIZES_5178751617646281462)],
        &[(0b01001, &ENTRY_HORMONIZE_16402712449126296970)],
        &[(0b01001, &ENTRY_HORMONIZES_5178751617646281462)],
        &[(0b10010, &ENTRY_HORRORIZE_1721568873445513652)],
        &[(0b10010, &ENTRY_HORRORIZES_17965582474215827942)],
        &[(0b01001, &ENTRY_HORRORIZE_1721568873445513652)],
        &[(0b01001, &ENTRY_HORRORIZES_17965582474215827942)],
    ],
    range: 1..=15,
};

static VARS_HOO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOO_CHILDREN),
    value: None,
};

pub static VARS_HOO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dlumise"),
        dictgen::InsensitiveStr::Ascii("dlumises"),
        dictgen::InsensitiveStr::Ascii("dlumize"),
        dictgen::InsensitiveStr::Ascii("dlumizes"),
        dictgen::InsensitiveStr::Ascii("liganise"),
        dictgen::InsensitiveStr::Ascii("liganises"),
        dictgen::InsensitiveStr::Ascii("liganize"),
        dictgen::InsensitiveStr::Ascii("liganizes"),
        dictgen::InsensitiveStr::Ascii("rah"),
        dictgen::InsensitiveStr::Ascii("rahs"),
        dictgen::InsensitiveStr::Ascii("sierise"),
        dictgen::InsensitiveStr::Ascii("sierises"),
        dictgen::InsensitiveStr::Ascii("sierize"),
        dictgen::InsensitiveStr::Ascii("sierizes"),
        dictgen::InsensitiveStr::Ascii("verise"),
        dictgen::InsensitiveStr::Ascii("verises"),
        dictgen::InsensitiveStr::Ascii("verize"),
        dictgen::InsensitiveStr::Ascii("verizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOODLUMIZE_1988199326490657618)],
        &[(0b10010, &ENTRY_HOODLUMIZES_2337314049834401492)],
        &[(0b01001, &ENTRY_HOODLUMIZE_1988199326490657618)],
        &[(0b01001, &ENTRY_HOODLUMIZES_2337314049834401492)],
        &[(0b10010, &ENTRY_HOOLIGANIZE_17119619341142584244)],
        &[(0b10010, &ENTRY_HOOLIGANIZES_10378468821053779568)],
        &[(0b01001, &ENTRY_HOOLIGANIZE_17119619341142584244)],
        &[(0b01001, &ENTRY_HOOLIGANIZES_10378468821053779568)],
        &[(0b00001, &ENTRY_HURRAH_2302953427822584414)],
        &[(0b00001, &ENTRY_HURRAHS_17087845443906118467)],
        &[(0b10010, &ENTRY_HOOSIERIZE_1491277666553366678)],
        &[(0b10010, &ENTRY_HOOSIERIZES_3096818361317634282)],
        &[(0b01001, &ENTRY_HOOSIERIZE_1491277666553366678)],
        &[(0b01001, &ENTRY_HOOSIERIZES_3096818361317634282)],
        &[(0b10010, &ENTRY_HOOVERIZE_12514395268479045206)],
        &[(0b10010, &ENTRY_HOOVERIZES_11190309671847930638)],
        &[(0b01001, &ENTRY_HOOVERIZE_12514395268479045206)],
        &[(0b01001, &ENTRY_HOOVERIZES_11190309671847930638)],
    ],
    range: 3..=9,
};

static VARS_HON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HON_CHILDREN),
    value: None,
};

pub static VARS_HON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orabilities"),
        dictgen::InsensitiveStr::Ascii("orability"),
        dictgen::InsensitiveStr::Ascii("orable"),
        dictgen::InsensitiveStr::Ascii("orableness"),
        dictgen::InsensitiveStr::Ascii("orablenesses"),
        dictgen::InsensitiveStr::Ascii("orabler"),
        dictgen::InsensitiveStr::Ascii("orables"),
        dictgen::InsensitiveStr::Ascii("orableship"),
        dictgen::InsensitiveStr::Ascii("orableships"),
        dictgen::InsensitiveStr::Ascii("orablest"),
        dictgen::InsensitiveStr::Ascii("orablier"),
        dictgen::InsensitiveStr::Ascii("orablies"),
        dictgen::InsensitiveStr::Ascii("orabliest"),
        dictgen::InsensitiveStr::Ascii("orably"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("oree"),
        dictgen::InsensitiveStr::Ascii("orees"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("orlesser"),
        dictgen::InsensitiveStr::Ascii("orlesses"),
        dictgen::InsensitiveStr::Ascii("orlessest"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourabilities"),
        dictgen::InsensitiveStr::Ascii("ourability"),
        dictgen::InsensitiveStr::Ascii("ourable"),
        dictgen::InsensitiveStr::Ascii("ourableness"),
        dictgen::InsensitiveStr::Ascii("ourablenesses"),
        dictgen::InsensitiveStr::Ascii("ourabler"),
        dictgen::InsensitiveStr::Ascii("ourables"),
        dictgen::InsensitiveStr::Ascii("ourableship"),
        dictgen::InsensitiveStr::Ascii("ourableships"),
        dictgen::InsensitiveStr::Ascii("ourablest"),
        dictgen::InsensitiveStr::Ascii("ourablier"),
        dictgen::InsensitiveStr::Ascii("ourablies"),
        dictgen::InsensitiveStr::Ascii("ourabliest"),
        dictgen::InsensitiveStr::Ascii("ourably"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ouree"),
        dictgen::InsensitiveStr::Ascii("ourees"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ourlesser"),
        dictgen::InsensitiveStr::Ascii("ourlesses"),
        dictgen::InsensitiveStr::Ascii("ourlessest"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_HONOR_12284245170176182479)],
        &[(0b11001, &ENTRY_HONORABILITIES_17692403882040438215)],
        &[(0b11001, &ENTRY_HONORABILITY_12580589027472191611)],
        &[(0b11001, &ENTRY_HONORABLE_16346079154255994276)],
        &[(0b11001, &ENTRY_HONORABLENESS_11259768724529598124)],
        &[(0b11001, &ENTRY_HONORABLENESSES_5348711556750177695)],
        &[(0b11001, &ENTRY_HONORABLER_1697067400290285301)],
        &[(0b11001, &ENTRY_HONORABLES_2913554671346259853)],
        &[(0b11001, &ENTRY_HONORABLESHIP_16239512951229580872)],
        &[(0b11001, &ENTRY_HONORABLESHIPS_17263052691602698851)],
        &[(0b11001, &ENTRY_HONORABLEST_11244773893570663300)],
        &[(0b11001, &ENTRY_HONORABLIER_6904513272854009789)],
        &[(0b11001, &ENTRY_HONORABLIES_12203013003442305559)],
        &[(0b11001, &ENTRY_HONORABLIEST_11197357664137213595)],
        &[(0b11001, &ENTRY_HONORABLY_17038293500649165869)],
        &[(0b11001, &ENTRY_HONORED_16057015610203465375)],
        &[(0b11001, &ENTRY_HONOREE_16211612529520124524)],
        &[(0b11001, &ENTRY_HONOREES_18235412860085516031)],
        &[(0b11001, &ENTRY_HONORER_1852924574530689208)],
        &[(0b11001, &ENTRY_HONORERS_6333132769292360884)],
        &[(0b11001, &ENTRY_HONORING_6077083205656592738)],
        &[(0b11001, &ENTRY_HONORLESS_5387528221786719947)],
        &[(0b11001, &ENTRY_HONORLESSER_8961804267410442314)],
        &[(0b11001, &ENTRY_HONORLESSES_18009355419310607858)],
        &[(0b11001, &ENTRY_HONORLESSEST_8580952947078616611)],
        &[(0b11001, &ENTRY_HONORS_13638393746809061853)],
        &[(0b11010, &ENTRY_HONOR_12284245170176182479)],
        &[(0b11010, &ENTRY_HONORABILITIES_17692403882040438215)],
        &[(0b11010, &ENTRY_HONORABILITY_12580589027472191611)],
        &[(0b11010, &ENTRY_HONORABLE_16346079154255994276)],
        &[(0b11010, &ENTRY_HONORABLENESS_11259768724529598124)],
        &[(0b11010, &ENTRY_HONORABLENESSES_5348711556750177695)],
        &[(0b11010, &ENTRY_HONORABLER_1697067400290285301)],
        &[(0b11010, &ENTRY_HONORABLES_2913554671346259853)],
        &[(0b11010, &ENTRY_HONORABLESHIP_16239512951229580872)],
        &[(0b11010, &ENTRY_HONORABLESHIPS_17263052691602698851)],
        &[(0b11010, &ENTRY_HONORABLEST_11244773893570663300)],
        &[(0b11010, &ENTRY_HONORABLIER_6904513272854009789)],
        &[(0b11010, &ENTRY_HONORABLIES_12203013003442305559)],
        &[(0b11010, &ENTRY_HONORABLIEST_11197357664137213595)],
        &[(0b11010, &ENTRY_HONORABLY_17038293500649165869)],
        &[(0b11010, &ENTRY_HONORED_16057015610203465375)],
        &[(0b11010, &ENTRY_HONOREE_16211612529520124524)],
        &[(0b11010, &ENTRY_HONOREES_18235412860085516031)],
        &[(0b11010, &ENTRY_HONORER_1852924574530689208)],
        &[(0b11010, &ENTRY_HONORERS_6333132769292360884)],
        &[(0b11010, &ENTRY_HONORING_6077083205656592738)],
        &[(0b11010, &ENTRY_HONORLESS_5387528221786719947)],
        &[(0b11010, &ENTRY_HONORLESSER_8961804267410442314)],
        &[(0b11010, &ENTRY_HONORLESSES_18009355419310607858)],
        &[(0b11010, &ENTRY_HONORLESSEST_8580952947078616611)],
        &[(0b11010, &ENTRY_HONORS_13638393746809061853)],
    ],
    range: 2..=13,
};

static VARS_HOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HOM_CHILDREN),
    value: None,
};

static VARS_HOM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HOMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HOMO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HOMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HOMO_CHILDREN),
    value: None,
};

static VARS_HOMO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_HOMOE_NODE),
    None,
    Some(&VARS_HOMOG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HOMOL_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HOMOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOMOL_CHILDREN),
    value: None,
};

pub static VARS_HOMOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("og"),
        dictgen::InsensitiveStr::Ascii("ogisation"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogiser"),
        dictgen::InsensitiveStr::Ascii("ogisers"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogization"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizer"),
        dictgen::InsensitiveStr::Ascii("ogizers"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ogs"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HOMOLOGUE_12262727764635293494)],
        &[(0b10010, &ENTRY_HOMOLOGIZATION_2821144199023611743)],
        &[(0b10010, &ENTRY_HOMOLOGIZE_16692911359990964362)],
        &[(0b10010, &ENTRY_HOMOLOGIZED_11005543793325536942)],
        &[(0b10010, &ENTRY_HOMOLOGIZER_7601894071386003883)],
        &[(0b10010, &ENTRY_HOMOLOGIZERS_5981615810035626144)],
        &[(0b10010, &ENTRY_HOMOLOGIZES_9606957905590841740)],
        &[(0b10010, &ENTRY_HOMOLOGIZING_5163950846513087370)],
        &[(0b01001, &ENTRY_HOMOLOGIZATION_2821144199023611743)],
        &[(0b01001, &ENTRY_HOMOLOGIZE_16692911359990964362)],
        &[(0b01001, &ENTRY_HOMOLOGIZED_11005543793325536942)],
        &[(0b01001, &ENTRY_HOMOLOGIZER_7601894071386003883)],
        &[(0b01001, &ENTRY_HOMOLOGIZERS_5981615810035626144)],
        &[(0b01001, &ENTRY_HOMOLOGIZES_9606957905590841740)],
        &[(0b01001, &ENTRY_HOMOLOGIZING_5163950846513087370)],
        &[(0b00001, &ENTRY_HOMOLOGUES_13017718427263208887)],
    ],
    range: 2..=9,
};

static VARS_HOMOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOMOG_CHILDREN),
    value: None,
};

pub static VARS_HOMOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enisation"),
        dictgen::InsensitiveStr::Ascii("enisations"),
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enised"),
        dictgen::InsensitiveStr::Ascii("eniser"),
        dictgen::InsensitiveStr::Ascii("enisers"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enising"),
        dictgen::InsensitiveStr::Ascii("enization"),
        dictgen::InsensitiveStr::Ascii("enizations"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enized"),
        dictgen::InsensitiveStr::Ascii("enizer"),
        dictgen::InsensitiveStr::Ascii("enizers"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("enizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOMOGENIZATION_4656356242119525138)],
        &[(0b10010, &ENTRY_HOMOGENIZATIONS_6507363217080422658)],
        &[(0b10010, &ENTRY_HOMOGENIZE_7151746964336550590)],
        &[(0b10010, &ENTRY_HOMOGENIZED_18397765472405266148)],
        &[(0b10010, &ENTRY_HOMOGENIZER_6996925915876051690)],
        &[(0b10010, &ENTRY_HOMOGENIZERS_10980385487255230065)],
        &[(0b10010, &ENTRY_HOMOGENIZES_8369010059050295552)],
        &[(0b10010, &ENTRY_HOMOGENIZING_14283963830585886911)],
        &[(0b01001, &ENTRY_HOMOGENIZATION_4656356242119525138)],
        &[(0b01001, &ENTRY_HOMOGENIZATIONS_6507363217080422658)],
        &[(0b01001, &ENTRY_HOMOGENIZE_7151746964336550590)],
        &[(0b01001, &ENTRY_HOMOGENIZED_18397765472405266148)],
        &[(0b01001, &ENTRY_HOMOGENIZER_6996925915876051690)],
        &[(0b01001, &ENTRY_HOMOGENIZERS_10980385487255230065)],
        &[(0b01001, &ENTRY_HOMOGENIZES_8369010059050295552)],
        &[(0b01001, &ENTRY_HOMOGENIZING_14283963830585886911)],
    ],
    range: 5..=10,
};

static VARS_HOMOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOMOE_CHILDREN),
    value: None,
};

pub static VARS_HOMOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oblastic"),
        dictgen::InsensitiveStr::Ascii("obox"),
        dictgen::InsensitiveStr::Ascii("ochromatic"),
        dictgen::InsensitiveStr::Ascii("ochronous"),
        dictgen::InsensitiveStr::Ascii("ocrystalline"),
        dictgen::InsensitiveStr::Ascii("ogenic"),
        dictgen::InsensitiveStr::Ascii("ogenous"),
        dictgen::InsensitiveStr::Ascii("oid"),
        dictgen::InsensitiveStr::Ascii("okinesis"),
        dictgen::InsensitiveStr::Ascii("omeric"),
        dictgen::InsensitiveStr::Ascii("omeries"),
        dictgen::InsensitiveStr::Ascii("omerous"),
        dictgen::InsensitiveStr::Ascii("omery"),
        dictgen::InsensitiveStr::Ascii("omorph"),
        dictgen::InsensitiveStr::Ascii("omorphic"),
        dictgen::InsensitiveStr::Ascii("omorphies"),
        dictgen::InsensitiveStr::Ascii("omorphous"),
        dictgen::InsensitiveStr::Ascii("omorphs"),
        dictgen::InsensitiveStr::Ascii("omorphy"),
        dictgen::InsensitiveStr::Ascii("opath"),
        dictgen::InsensitiveStr::Ascii("opathic"),
        dictgen::InsensitiveStr::Ascii("opathicallier"),
        dictgen::InsensitiveStr::Ascii("opathicalliest"),
        dictgen::InsensitiveStr::Ascii("opathically"),
        dictgen::InsensitiveStr::Ascii("opathicer"),
        dictgen::InsensitiveStr::Ascii("opathicest"),
        dictgen::InsensitiveStr::Ascii("opathician"),
        dictgen::InsensitiveStr::Ascii("opathicity"),
        dictgen::InsensitiveStr::Ascii("opathies"),
        dictgen::InsensitiveStr::Ascii("opathist"),
        dictgen::InsensitiveStr::Ascii("opathists"),
        dictgen::InsensitiveStr::Ascii("opaths"),
        dictgen::InsensitiveStr::Ascii("opathy"),
        dictgen::InsensitiveStr::Ascii("ophony"),
        dictgen::InsensitiveStr::Ascii("oplasia"),
        dictgen::InsensitiveStr::Ascii("oplastic"),
        dictgen::InsensitiveStr::Ascii("oplasy"),
        dictgen::InsensitiveStr::Ascii("opolar"),
        dictgen::InsensitiveStr::Ascii("oses"),
        dictgen::InsensitiveStr::Ascii("osis"),
        dictgen::InsensitiveStr::Ascii("ostases"),
        dictgen::InsensitiveStr::Ascii("ostasis"),
        dictgen::InsensitiveStr::Ascii("ostatic"),
        dictgen::InsensitiveStr::Ascii("oteleuton"),
        dictgen::InsensitiveStr::Ascii("oteleutons"),
        dictgen::InsensitiveStr::Ascii("othermal"),
        dictgen::InsensitiveStr::Ascii("othermic"),
        dictgen::InsensitiveStr::Ascii("othermous"),
        dictgen::InsensitiveStr::Ascii("otic"),
        dictgen::InsensitiveStr::Ascii("otype"),
        dictgen::InsensitiveStr::Ascii("otypic"),
        dictgen::InsensitiveStr::Ascii("otypical"),
        dictgen::InsensitiveStr::Ascii("ozoic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HOMEOBLASTIC_6746209829258825772)],
        &[(0b11010, &ENTRY_HOMEOBOX_429210278928517870)],
        &[(0b11010, &ENTRY_HOMEOCHROMATIC_11999475947164180492)],
        &[(0b11010, &ENTRY_HOMEOCHRONOUS_8014923555195616828)],
        &[(0b11010, &ENTRY_HOMEOCRYSTALLINE_16924542982654673284)],
        &[(0b11010, &ENTRY_HOMEOGENIC_9645370346333050697)],
        &[(0b11010, &ENTRY_HOMEOGENOUS_14853646215868318087)],
        &[(0b11010, &ENTRY_HOMEOID_1872912226240221334)],
        &[(0b11010, &ENTRY_HOMEOKINESIS_6170969351054020797)],
        &[(0b11010, &ENTRY_HOMEOMERIC_3398859861466283325)],
        &[(0b11010, &ENTRY_HOMEOMERIES_11379170224465058869)],
        &[(0b11010, &ENTRY_HOMEOMEROUS_6218438835083612194)],
        &[(0b11010, &ENTRY_HOMEOMERY_5639570395337974043)],
        &[(0b11010, &ENTRY_HOMEOMORPH_84773973062870875)],
        &[(0b11010, &ENTRY_HOMEOMORPHIC_1948628429205039039)],
        &[(0b11010, &ENTRY_HOMEOMORPHIES_14622240917714789970)],
        &[(0b11010, &ENTRY_HOMEOMORPHOUS_13335878237289387669)],
        &[(0b11010, &ENTRY_HOMEOMORPHS_16100106052531760213)],
        &[(0b11010, &ENTRY_HOMEOMORPHY_8107825719716227576)],
        &[(0b10010, &ENTRY_HOMEOPATH_8050958568587536315)],
        &[(0b10010, &ENTRY_HOMEOPATHIC_2595837653280609646)],
        &[(0b11010, &ENTRY_HOMEOPATHICALLIER_1906322964795778344)],
        &[(0b11010, &ENTRY_HOMEOPATHICALLIEST_17712966541260034812)],
        &[(0b11010, &ENTRY_HOMEOPATHICALLY_14527514477064061578)],
        &[(0b10010, &ENTRY_HOMEOPATHICER_8555062855537875022)],
        &[(0b10010, &ENTRY_HOMEOPATHICEST_7501604706728812827)],
        &[(0b11010, &ENTRY_HOMEOPATHICIAN_20367417011957025)],
        &[(0b11010, &ENTRY_HOMEOPATHICITY_7965137265585164533)],
        &[(0b10010, &ENTRY_HOMEOPATHIES_6130111446071821583)],
        &[(0b11010, &ENTRY_HOMEOPATHIST_13588025674470919172)],
        &[(0b11010, &ENTRY_HOMEOPATHISTS_7529185235165580015)],
        &[(0b10010, &ENTRY_HOMEOPATHS_11980413245885940279)],
        &[(0b10010, &ENTRY_HOMEOPATHY_15227637772904556345)],
        &[(0b11010, &ENTRY_HOMEOPHONY_9154734443919559444)],
        &[(0b11010, &ENTRY_HOMEOPLASIA_3059803871019512419)],
        &[(0b11010, &ENTRY_HOMEOPLASTIC_17893015370456211967)],
        &[(0b11010, &ENTRY_HOMEOPLASY_4819557973925456326)],
        &[(0b11010, &ENTRY_HOMEOPOLAR_3145512571186875572)],
        &[(0b11010, &ENTRY_HOMEOSES_303789675254329178)],
        &[(0b11010, &ENTRY_HOMEOSIS_11588213019930111450)],
        &[(0b11010, &ENTRY_HOMEOSTASES_5173714139377093881)],
        &[(0b11010, &ENTRY_HOMEOSTASIS_4138793109351981017)],
        &[(0b11010, &ENTRY_HOMEOSTATIC_8960257562201062527)],
        &[(0b11010, &ENTRY_HOMEOTELEUTON_16219979521219347957)],
        &[(0b11010, &ENTRY_HOMEOTELEUTONS_4791090930087046081)],
        &[(0b11010, &ENTRY_HOMEOTHERMAL_12106163977771685441)],
        &[(0b11010, &ENTRY_HOMEOTHERMIC_3531598803017384948)],
        &[(0b11010, &ENTRY_HOMEOTHERMOUS_15284024759127648929)],
        &[(0b11010, &ENTRY_HOMEOTIC_7762310538628691725)],
        &[(0b11010, &ENTRY_HOMEOTYPE_14898446616858101857)],
        &[(0b11010, &ENTRY_HOMEOTYPIC_16234822496573387731)],
        &[(0b11010, &ENTRY_HOMEOTYPICAL_2867923706738058619)],
        &[(0b11010, &ENTRY_HOMEOZOIC_10691139051307473852)],
    ],
    range: 3..=14,
};

static VARS_HOMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOMI_CHILDREN),
    value: None,
};

pub static VARS_HOMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOMINIZATION_15453871557875181149)],
        &[(0b10010, &ENTRY_HOMINIZED_1937428321671242913)],
        &[(0b01001, &ENTRY_HOMINIZATION_15453871557875181149)],
        &[(0b01001, &ENTRY_HOMINIZED_1937428321671242913)],
    ],
    range: 5..=8,
};

static VARS_HOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HOL_CHILDREN),
    value: None,
};

pub static VARS_HOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lywoodise"),
        dictgen::InsensitiveStr::Ascii("lywoodised"),
        dictgen::InsensitiveStr::Ascii("lywoodises"),
        dictgen::InsensitiveStr::Ascii("lywoodising"),
        dictgen::InsensitiveStr::Ascii("lywoodize"),
        dictgen::InsensitiveStr::Ascii("lywoodized"),
        dictgen::InsensitiveStr::Ascii("lywoodizes"),
        dictgen::InsensitiveStr::Ascii("lywoodizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HOLLYWOODIZE_4477243734441393330)],
        &[(0b10010, &ENTRY_HOLLYWOODIZED_13360580927430344074)],
        &[(0b10010, &ENTRY_HOLLYWOODIZES_4459914627860315265)],
        &[(0b10010, &ENTRY_HOLLYWOODIZING_7888024247300732070)],
        &[(0b01001, &ENTRY_HOLLYWOODIZE_4477243734441393330)],
        &[(0b01001, &ENTRY_HOLLYWOODIZED_13360580927430344074)],
        &[(0b01001, &ENTRY_HOLLYWOODIZES_4459914627860315265)],
        &[(0b01001, &ENTRY_HOLLYWOODIZING_7888024247300732070)],
    ],
    range: 9..=11,
};

static VARS_HI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HI_CHILDREN),
    value: None,
};

static VARS_HI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_HIB_NODE),
    Some(&VARS_HIC_NODE),
    None,
    Some(&VARS_HIE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HIL_NODE),
    None,
    Some(&VARS_HIN_NODE),
    None,
    None,
    None,
    Some(&VARS_HIR_NODE),
    Some(&VARS_HIS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIS_CHILDREN),
    value: None,
};

pub static VARS_HIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("panicisation"),
        dictgen::InsensitiveStr::Ascii("panicisations"),
        dictgen::InsensitiveStr::Ascii("panicise"),
        dictgen::InsensitiveStr::Ascii("panicised"),
        dictgen::InsensitiveStr::Ascii("panicises"),
        dictgen::InsensitiveStr::Ascii("panicising"),
        dictgen::InsensitiveStr::Ascii("panicization"),
        dictgen::InsensitiveStr::Ascii("panicizations"),
        dictgen::InsensitiveStr::Ascii("panicize"),
        dictgen::InsensitiveStr::Ascii("panicized"),
        dictgen::InsensitiveStr::Ascii("panicizes"),
        dictgen::InsensitiveStr::Ascii("panicizing"),
        dictgen::InsensitiveStr::Ascii("paniolise"),
        dictgen::InsensitiveStr::Ascii("paniolised"),
        dictgen::InsensitiveStr::Ascii("paniolises"),
        dictgen::InsensitiveStr::Ascii("paniolising"),
        dictgen::InsensitiveStr::Ascii("paniolize"),
        dictgen::InsensitiveStr::Ascii("paniolized"),
        dictgen::InsensitiveStr::Ascii("paniolizes"),
        dictgen::InsensitiveStr::Ascii("paniolizing"),
        dictgen::InsensitiveStr::Ascii("toricise"),
        dictgen::InsensitiveStr::Ascii("toricised"),
        dictgen::InsensitiveStr::Ascii("toricises"),
        dictgen::InsensitiveStr::Ascii("toricising"),
        dictgen::InsensitiveStr::Ascii("toricize"),
        dictgen::InsensitiveStr::Ascii("toricized"),
        dictgen::InsensitiveStr::Ascii("toricizes"),
        dictgen::InsensitiveStr::Ascii("toricizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HISPANICIZATION_16683525730667710346)],
        &[(0b10010, &ENTRY_HISPANICIZATIONS_10358570653173988410)],
        &[(0b10010, &ENTRY_HISPANICIZE_1047337502816548436)],
        &[(0b10010, &ENTRY_HISPANICIZED_12357862745153928252)],
        &[(0b10010, &ENTRY_HISPANICIZES_11390009193328514217)],
        &[(0b10010, &ENTRY_HISPANICIZING_10297649593265523682)],
        &[(0b01001, &ENTRY_HISPANICIZATION_16683525730667710346)],
        &[(0b01001, &ENTRY_HISPANICIZATIONS_10358570653173988410)],
        &[(0b01001, &ENTRY_HISPANICIZE_1047337502816548436)],
        &[(0b01001, &ENTRY_HISPANICIZED_12357862745153928252)],
        &[(0b01001, &ENTRY_HISPANICIZES_11390009193328514217)],
        &[(0b01001, &ENTRY_HISPANICIZING_10297649593265523682)],
        &[(0b10010, &ENTRY_HISPANIOLIZE_12040635907161743907)],
        &[(0b10010, &ENTRY_HISPANIOLIZED_17603705847587336285)],
        &[(0b10010, &ENTRY_HISPANIOLIZES_15865799872959107963)],
        &[(0b10010, &ENTRY_HISPANIOLIZING_14719191412394590748)],
        &[(0b01001, &ENTRY_HISPANIOLIZE_12040635907161743907)],
        &[(0b01001, &ENTRY_HISPANIOLIZED_17603705847587336285)],
        &[(0b01001, &ENTRY_HISPANIOLIZES_15865799872959107963)],
        &[(0b01001, &ENTRY_HISPANIOLIZING_14719191412394590748)],
        &[(0b10010, &ENTRY_HISTORICIZE_787070662493754066)],
        &[(0b10010, &ENTRY_HISTORICIZED_15317036403172319970)],
        &[(0b10010, &ENTRY_HISTORICIZES_9252360923584277113)],
        &[(0b10010, &ENTRY_HISTORICIZING_15546207066252957575)],
        &[(0b01001, &ENTRY_HISTORICIZE_787070662493754066)],
        &[(0b01001, &ENTRY_HISTORICIZED_15317036403172319970)],
        &[(0b01001, &ENTRY_HISTORICIZES_9252360923584277113)],
        &[(0b01001, &ENTRY_HISTORICIZING_15546207066252957575)],
    ],
    range: 8..=13,
};

static VARS_HIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIR_CHILDREN),
    value: None,
};

pub static VARS_HIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seling"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("selling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HIRSELED_6428358124306464688)],
        &[(0b00001, &ENTRY_HIRSELING_3208245182152685788)],
        &[(0b11010, &ENTRY_HIRSELED_6428358124306464688)],
        &[(0b11010, &ENTRY_HIRSELING_3208245182152685788)],
    ],
    range: 5..=7,
};

static VARS_HIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIN_CHILDREN),
    value: None,
};

pub static VARS_HIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("duise"),
        dictgen::InsensitiveStr::Ascii("duised"),
        dictgen::InsensitiveStr::Ascii("duises"),
        dictgen::InsensitiveStr::Ascii("duising"),
        dictgen::InsensitiveStr::Ascii("duize"),
        dictgen::InsensitiveStr::Ascii("duized"),
        dictgen::InsensitiveStr::Ascii("duizes"),
        dictgen::InsensitiveStr::Ascii("duizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HINDUIZE_8107305186736185273)],
        &[(0b10010, &ENTRY_HINDUIZED_11895274507413844911)],
        &[(0b10010, &ENTRY_HINDUIZES_175867203024573544)],
        &[(0b10010, &ENTRY_HINDUIZING_11790232298515925904)],
        &[(0b01001, &ENTRY_HINDUIZE_8107305186736185273)],
        &[(0b01001, &ENTRY_HINDUIZED_11895274507413844911)],
        &[(0b01001, &ENTRY_HINDUIZES_175867203024573544)],
        &[(0b01001, &ENTRY_HINDUIZING_11790232298515925904)],
    ],
    range: 5..=7,
};

static VARS_HIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIL_CHILDREN),
    value: None,
};

pub static VARS_HIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("loaed"),
        dictgen::InsensitiveStr::Ascii("loed"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HILLOED_14622198878819481120)],
        &[(0b00001, &ENTRY_HILLOED_14622198878819481120)],
    ],
    range: 4..=5,
};

static VARS_HIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIE_CHILDREN),
    value: None,
};

pub static VARS_HIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rarchise"),
        dictgen::InsensitiveStr::Ascii("rarchised"),
        dictgen::InsensitiveStr::Ascii("rarchising"),
        dictgen::InsensitiveStr::Ascii("rarchize"),
        dictgen::InsensitiveStr::Ascii("rarchized"),
        dictgen::InsensitiveStr::Ascii("rarchizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HIERARCHIZE_13167378612173910356)],
        &[(0b10010, &ENTRY_HIERARCHIZED_2434677209411391895)],
        &[(0b10010, &ENTRY_HIERARCHIZING_4483130984905685192)],
        &[(0b01001, &ENTRY_HIERARCHIZE_13167378612173910356)],
        &[(0b01001, &ENTRY_HIERARCHIZED_2434677209411391895)],
        &[(0b01001, &ENTRY_HIERARCHIZING_4483130984905685192)],
    ],
    range: 8..=10,
};

static VARS_HIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIC_CHILDREN),
    value: None,
};

pub static VARS_HIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cupped"),
        dictgen::InsensitiveStr::Ascii("cupping"),
    ],
    values: &[
        &[(0b01000, &ENTRY_HICCUPED_16748037414823767847)],
        &[(0b01000, &ENTRY_HICCUPING_10532915601093689832)],
    ],
    range: 6..=7,
};

static VARS_HIB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HIB_CHILDREN),
    value: None,
};

pub static VARS_HIB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernicise"),
        dictgen::InsensitiveStr::Ascii("ernicised"),
        dictgen::InsensitiveStr::Ascii("ernicises"),
        dictgen::InsensitiveStr::Ascii("ernicising"),
        dictgen::InsensitiveStr::Ascii("ernicize"),
        dictgen::InsensitiveStr::Ascii("ernicized"),
        dictgen::InsensitiveStr::Ascii("ernicizes"),
        dictgen::InsensitiveStr::Ascii("ernicizing"),
        dictgen::InsensitiveStr::Ascii("ernisation"),
        dictgen::InsensitiveStr::Ascii("ernisations"),
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernised"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernising"),
        dictgen::InsensitiveStr::Ascii("ernization"),
        dictgen::InsensitiveStr::Ascii("ernizations"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernized"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
        dictgen::InsensitiveStr::Ascii("ernizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HIBERNICIZE_17037881377750107736)],
        &[(0b10010, &ENTRY_HIBERNICIZED_17579936602226206872)],
        &[(0b10010, &ENTRY_HIBERNICIZES_4135316136924898775)],
        &[(0b10010, &ENTRY_HIBERNICIZING_14639684283522219260)],
        &[(0b01001, &ENTRY_HIBERNICIZE_17037881377750107736)],
        &[(0b01001, &ENTRY_HIBERNICIZED_17579936602226206872)],
        &[(0b01001, &ENTRY_HIBERNICIZES_4135316136924898775)],
        &[(0b01001, &ENTRY_HIBERNICIZING_14639684283522219260)],
        &[(0b10010, &ENTRY_HIBERNIZATION_13137120377558636657)],
        &[(0b10010, &ENTRY_HIBERNIZATIONS_2483818890865195275)],
        &[(0b10010, &ENTRY_HIBERNIZE_1545133711844580221)],
        &[(0b10010, &ENTRY_HIBERNIZED_16125091806689100794)],
        &[(0b10010, &ENTRY_HIBERNIZES_11866751661595811204)],
        &[(0b10010, &ENTRY_HIBERNIZING_9266995601950673715)],
        &[(0b01001, &ENTRY_HIBERNIZATION_13137120377558636657)],
        &[(0b01001, &ENTRY_HIBERNIZATIONS_2483818890865195275)],
        &[(0b01001, &ENTRY_HIBERNIZE_1545133711844580221)],
        &[(0b01001, &ENTRY_HIBERNIZED_16125091806689100794)],
        &[(0b01001, &ENTRY_HIBERNIZES_11866751661595811204)],
        &[(0b01001, &ENTRY_HIBERNIZING_9266995601950673715)],
    ],
    range: 6..=11,
};

static VARS_HE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HE_CHILDREN),
    value: None,
};

static VARS_HE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HEA_NODE),
    Some(&VARS_HEB_NODE),
    Some(&VARS_HEC_NODE),
    Some(&VARS_HED_NODE),
    None,
    None,
    Some(&VARS_HEG_NODE),
    None,
    None,
    None,
    Some(&VARS_HEK_NODE),
    Some(&VARS_HEL_NODE),
    Some(&VARS_HEM_NODE),
    None,
    None,
    Some(&VARS_HEP_NODE),
    None,
    Some(&VARS_HER_NODE),
    None,
    Some(&VARS_HET_NODE),
    None,
    None,
    None,
    Some(&VARS_HEX_NODE),
    None,
    None,
];

static VARS_HEX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEX_CHILDREN),
    value: None,
};

pub static VARS_HEX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("achlorethane"),
        dictgen::InsensitiveStr::Ascii("achlorethanes"),
        dictgen::InsensitiveStr::Ascii("achloroethane"),
        dictgen::InsensitiveStr::Ascii("achloroethanes"),
        dictgen::InsensitiveStr::Ascii("ametrise"),
        dictgen::InsensitiveStr::Ascii("ametrised"),
        dictgen::InsensitiveStr::Ascii("ametrises"),
        dictgen::InsensitiveStr::Ascii("ametrising"),
        dictgen::InsensitiveStr::Ascii("ametrize"),
        dictgen::InsensitiveStr::Ascii("ametrized"),
        dictgen::InsensitiveStr::Ascii("ametrizes"),
        dictgen::InsensitiveStr::Ascii("ametrizing"),
        dictgen::InsensitiveStr::Ascii("estrol"),
        dictgen::InsensitiveStr::Ascii("oestrol"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HEXACHLORETHANE_11021447419541267943)],
        &[(0b00001, &ENTRY_HEXACHLORETHANES_2079345014326674767)],
        &[(0b11010, &ENTRY_HEXACHLORETHANE_11021447419541267943)],
        &[(0b11010, &ENTRY_HEXACHLORETHANES_2079345014326674767)],
        &[(0b10010, &ENTRY_HEXAMETRIZE_14699250639166930630)],
        &[(0b10010, &ENTRY_HEXAMETRIZED_3185164622729779957)],
        &[(0b10010, &ENTRY_HEXAMETRIZES_12751554074248898767)],
        &[(0b10010, &ENTRY_HEXAMETRIZING_2426175730535979568)],
        &[(0b01001, &ENTRY_HEXAMETRIZE_14699250639166930630)],
        &[(0b01001, &ENTRY_HEXAMETRIZED_3185164622729779957)],
        &[(0b01001, &ENTRY_HEXAMETRIZES_12751554074248898767)],
        &[(0b01001, &ENTRY_HEXAMETRIZING_2426175730535979568)],
        &[(0b00001, &ENTRY_HEXESTROL_3904723358075993454)],
        &[(0b11010, &ENTRY_HEXESTROL_3904723358075993454)],
    ],
    range: 6..=14,
};

static VARS_HET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HET_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_HET_10103159752309740785)]),
};

pub static VARS_HET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aeric"),
        dictgen::InsensitiveStr::Ascii("aerism"),
        dictgen::InsensitiveStr::Ascii("erecious"),
        dictgen::InsensitiveStr::Ascii("eric"),
        dictgen::InsensitiveStr::Ascii("erism"),
        dictgen::InsensitiveStr::Ascii("eroecious"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HETERIC_14927082686103953595)],
        &[(0b11010, &ENTRY_HETERISM_629753888071252179)],
        &[(0b00001, &ENTRY_HETERECIOUS_528818645302753522)],
        &[(0b10001, &ENTRY_HETERIC_14927082686103953595)],
        &[(0b10001, &ENTRY_HETERISM_629753888071252179)],
        &[(0b11010, &ENTRY_HETERECIOUS_528818645302753522)],
        &[(0b00001, &ENTRY_HETS_6749474741457650714)],
    ],
    range: 1..=9,
};

static VARS_HER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HER_CHILDREN),
    value: None,
};

pub static VARS_HER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aldise"),
        dictgen::InsensitiveStr::Ascii("aldises"),
        dictgen::InsensitiveStr::Ascii("aldize"),
        dictgen::InsensitiveStr::Ascii("aldizes"),
        dictgen::InsensitiveStr::Ascii("borisation"),
        dictgen::InsensitiveStr::Ascii("borisations"),
        dictgen::InsensitiveStr::Ascii("borise"),
        dictgen::InsensitiveStr::Ascii("borised"),
        dictgen::InsensitiveStr::Ascii("borises"),
        dictgen::InsensitiveStr::Ascii("borising"),
        dictgen::InsensitiveStr::Ascii("borization"),
        dictgen::InsensitiveStr::Ascii("borizations"),
        dictgen::InsensitiveStr::Ascii("borize"),
        dictgen::InsensitiveStr::Ascii("borized"),
        dictgen::InsensitiveStr::Ascii("borizes"),
        dictgen::InsensitiveStr::Ascii("borizing"),
        dictgen::InsensitiveStr::Ascii("edes"),
        dictgen::InsensitiveStr::Ascii("eticise"),
        dictgen::InsensitiveStr::Ascii("eticises"),
        dictgen::InsensitiveStr::Ascii("eticize"),
        dictgen::InsensitiveStr::Ascii("eticizes"),
        dictgen::InsensitiveStr::Ascii("oinise"),
        dictgen::InsensitiveStr::Ascii("oinises"),
        dictgen::InsensitiveStr::Ascii("oinize"),
        dictgen::InsensitiveStr::Ascii("oinizes"),
        dictgen::InsensitiveStr::Ascii("oisation"),
        dictgen::InsensitiveStr::Ascii("oisations"),
        dictgen::InsensitiveStr::Ascii("oise"),
        dictgen::InsensitiveStr::Ascii("oised"),
        dictgen::InsensitiveStr::Ascii("oises"),
        dictgen::InsensitiveStr::Ascii("oising"),
        dictgen::InsensitiveStr::Ascii("oization"),
        dictgen::InsensitiveStr::Ascii("oizations"),
        dictgen::InsensitiveStr::Ascii("oize"),
        dictgen::InsensitiveStr::Ascii("oized"),
        dictgen::InsensitiveStr::Ascii("oizes"),
        dictgen::InsensitiveStr::Ascii("oizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HERALDIZE_13245151934087390658)],
        &[(0b10010, &ENTRY_HERALDIZES_3427011486777293121)],
        &[(0b01001, &ENTRY_HERALDIZE_13245151934087390658)],
        &[(0b01001, &ENTRY_HERALDIZES_3427011486777293121)],
        &[(0b10010, &ENTRY_HERBORIZATION_2180699383757200505)],
        &[(0b10010, &ENTRY_HERBORIZATIONS_3220427015154511891)],
        &[(0b10010, &ENTRY_HERBORIZE_9236267314777430141)],
        &[(0b10010, &ENTRY_HERBORIZED_1986245296299390128)],
        &[(0b10010, &ENTRY_HERBORIZES_18049858840826246838)],
        &[(0b10010, &ENTRY_HERBORIZING_14418490249039027873)],
        &[(0b01001, &ENTRY_HERBORIZATION_2180699383757200505)],
        &[(0b01001, &ENTRY_HERBORIZATIONS_3220427015154511891)],
        &[(0b01001, &ENTRY_HERBORIZE_9236267314777430141)],
        &[(0b01001, &ENTRY_HERBORIZED_1986245296299390128)],
        &[(0b01001, &ENTRY_HERBORIZES_18049858840826246838)],
        &[(0b01001, &ENTRY_HERBORIZING_14418490249039027873)],
        &[(0b00001, &ENTRY_HEREDES_12466213351118710275)],
        &[(0b10010, &ENTRY_HERETICIZE_9737734736005533859)],
        &[(0b10010, &ENTRY_HERETICIZES_2989278302591587100)],
        &[(0b01001, &ENTRY_HERETICIZE_9737734736005533859)],
        &[(0b01001, &ENTRY_HERETICIZES_2989278302591587100)],
        &[(0b10010, &ENTRY_HEROINIZE_7929779025273191656)],
        &[(0b10010, &ENTRY_HEROINIZES_530036718996538373)],
        &[(0b01001, &ENTRY_HEROINIZE_7929779025273191656)],
        &[(0b01001, &ENTRY_HEROINIZES_530036718996538373)],
        &[(0b10010, &ENTRY_HEROIZATION_13271943150165407572)],
        &[(0b10010, &ENTRY_HEROIZATIONS_17938260117292724826)],
        &[(0b10010, &ENTRY_HEROIZE_209937210303349791)],
        &[(0b10010, &ENTRY_HEROIZED_12288505910391777346)],
        &[(0b10010, &ENTRY_HEROIZES_18377738024677746144)],
        &[(0b10010, &ENTRY_HEROIZING_15459599585497422378)],
        &[(0b01001, &ENTRY_HEROIZATION_13271943150165407572)],
        &[(0b01001, &ENTRY_HEROIZATIONS_17938260117292724826)],
        &[(0b01001, &ENTRY_HEROIZE_209937210303349791)],
        &[(0b01001, &ENTRY_HEROIZED_12288505910391777346)],
        &[(0b01001, &ENTRY_HEROIZES_18377738024677746144)],
        &[(0b01001, &ENTRY_HEROIZING_15459599585497422378)],
    ],
    range: 4..=11,
};

static VARS_HEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEP_CHILDREN),
    value: None,
};

pub static VARS_HEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arinise"),
        dictgen::InsensitiveStr::Ascii("arinize"),
        dictgen::InsensitiveStr::Ascii("atisation"),
        dictgen::InsensitiveStr::Ascii("atisations"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atised"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atising"),
        dictgen::InsensitiveStr::Ascii("atization"),
        dictgen::InsensitiveStr::Ascii("atizations"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atized"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("atizing"),
        dictgen::InsensitiveStr::Ascii("atorrhea"),
        dictgen::InsensitiveStr::Ascii("atorrhoea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HEPARINIZE_825464359295045447)],
        &[(0b01001, &ENTRY_HEPARINIZE_825464359295045447)],
        &[(0b10010, &ENTRY_HEPATIZATION_18188813903715470881)],
        &[(0b10010, &ENTRY_HEPATIZATIONS_9429604348465734291)],
        &[(0b10010, &ENTRY_HEPATIZE_9537992825882517878)],
        &[(0b10010, &ENTRY_HEPATIZED_16132157599205450670)],
        &[(0b10010, &ENTRY_HEPATIZES_13438718625424032453)],
        &[(0b10010, &ENTRY_HEPATIZING_17190565875897655918)],
        &[(0b01001, &ENTRY_HEPATIZATION_18188813903715470881)],
        &[(0b01001, &ENTRY_HEPATIZATIONS_9429604348465734291)],
        &[(0b01001, &ENTRY_HEPATIZE_9537992825882517878)],
        &[(0b01001, &ENTRY_HEPATIZED_16132157599205450670)],
        &[(0b01001, &ENTRY_HEPATIZES_13438718625424032453)],
        &[(0b01001, &ENTRY_HEPATIZING_17190565875897655918)],
        &[(0b10001, &ENTRY_HEPATORRHEA_33783066209687899)],
        &[(0b11010, &ENTRY_HEPATORRHEA_33783066209687899)],
    ],
    range: 5..=10,
};

static VARS_HEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HEM_CHILDREN),
    value: None,
};

static VARS_HEM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HEMA_NODE),
    None,
    None,
    None,
    Some(&VARS_HEME_NODE),
    None,
    None,
    None,
    Some(&VARS_HEMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HEMO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HEMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMO_CHILDREN),
    value: None,
};

pub static VARS_HEMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blast"),
        dictgen::InsensitiveStr::Ascii("chromatoses"),
        dictgen::InsensitiveStr::Ascii("chromatosis"),
        dictgen::InsensitiveStr::Ascii("chrome"),
        dictgen::InsensitiveStr::Ascii("coel"),
        dictgen::InsensitiveStr::Ascii("coels"),
        dictgen::InsensitiveStr::Ascii("concentration"),
        dictgen::InsensitiveStr::Ascii("conia"),
        dictgen::InsensitiveStr::Ascii("cyanin"),
        dictgen::InsensitiveStr::Ascii("cyanins"),
        dictgen::InsensitiveStr::Ascii("cyte"),
        dictgen::InsensitiveStr::Ascii("cytes"),
        dictgen::InsensitiveStr::Ascii("cytoblast"),
        dictgen::InsensitiveStr::Ascii("cytoblastic"),
        dictgen::InsensitiveStr::Ascii("cytometer"),
        dictgen::InsensitiveStr::Ascii("dialyses"),
        dictgen::InsensitiveStr::Ascii("dialysis"),
        dictgen::InsensitiveStr::Ascii("dilution"),
        dictgen::InsensitiveStr::Ascii("dynamic"),
        dictgen::InsensitiveStr::Ascii("dynamics"),
        dictgen::InsensitiveStr::Ascii("erythrin"),
        dictgen::InsensitiveStr::Ascii("flagellate"),
        dictgen::InsensitiveStr::Ascii("globic"),
        dictgen::InsensitiveStr::Ascii("globin"),
        dictgen::InsensitiveStr::Ascii("globinopathies"),
        dictgen::InsensitiveStr::Ascii("globinopathy"),
        dictgen::InsensitiveStr::Ascii("globinous"),
        dictgen::InsensitiveStr::Ascii("globinuria"),
        dictgen::InsensitiveStr::Ascii("gram"),
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("lysin"),
        dictgen::InsensitiveStr::Ascii("lysis"),
        dictgen::InsensitiveStr::Ascii("lytic"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("phile"),
        dictgen::InsensitiveStr::Ascii("philia"),
        dictgen::InsensitiveStr::Ascii("philiac"),
        dictgen::InsensitiveStr::Ascii("philiacs"),
        dictgen::InsensitiveStr::Ascii("philic"),
        dictgen::InsensitiveStr::Ascii("pod"),
        dictgen::InsensitiveStr::Ascii("poiesis"),
        dictgen::InsensitiveStr::Ascii("ptyses"),
        dictgen::InsensitiveStr::Ascii("ptysis"),
        dictgen::InsensitiveStr::Ascii("rrhage"),
        dictgen::InsensitiveStr::Ascii("rrhaged"),
        dictgen::InsensitiveStr::Ascii("rrhages"),
        dictgen::InsensitiveStr::Ascii("rrhaging"),
        dictgen::InsensitiveStr::Ascii("rrhoid"),
        dictgen::InsensitiveStr::Ascii("rrhoidal"),
        dictgen::InsensitiveStr::Ascii("rrhoidectomy"),
        dictgen::InsensitiveStr::Ascii("rrhoids"),
        dictgen::InsensitiveStr::Ascii("sporid"),
        dictgen::InsensitiveStr::Ascii("sporidian"),
        dictgen::InsensitiveStr::Ascii("stases"),
        dictgen::InsensitiveStr::Ascii("stasia"),
        dictgen::InsensitiveStr::Ascii("stasis"),
        dictgen::InsensitiveStr::Ascii("static"),
        dictgen::InsensitiveStr::Ascii("thorax"),
        dictgen::InsensitiveStr::Ascii("toxic"),
        dictgen::InsensitiveStr::Ascii("toxin"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMOBLAST_1212952674211829865)],
        &[(0b10001, &ENTRY_HEMOCHROMATOSES_15366460809089499165)],
        &[(0b10001, &ENTRY_HEMOCHROMATOSIS_2585842551183947470)],
        &[(0b10001, &ENTRY_HEMOCHROME_2175430877481267405)],
        &[(0b10001, &ENTRY_HEMOCOEL_13831278213168049606)],
        &[(0b10001, &ENTRY_HEMOCOELS_18362432535121397233)],
        &[(0b10001, &ENTRY_HEMOCONCENTRATION_16358090763140109058)],
        &[(0b10001, &ENTRY_HEMOCONIA_16171119888057670146)],
        &[(0b10001, &ENTRY_HEMOCYANIN_12147015753804620517)],
        &[(0b10001, &ENTRY_HEMOCYANINS_17279027934588336382)],
        &[(0b10001, &ENTRY_HEMOCYTE_15334672110474097892)],
        &[(0b10001, &ENTRY_HEMOCYTES_11990928088518685379)],
        &[(0b10001, &ENTRY_HEMOCYTOBLAST_8571898144164238141)],
        &[(0b10001, &ENTRY_HEMOCYTOBLASTIC_15757846276939616596)],
        &[(0b10001, &ENTRY_HEMOCYTOMETER_12858869074539466859)],
        &[(0b11001, &ENTRY_HEMODIALYSES_11392463941635998019)],
        &[(0b11001, &ENTRY_HEMODIALYSIS_1163550974992047350)],
        &[(0b10001, &ENTRY_HEMODILUTION_11283430470235069221)],
        &[(0b10001, &ENTRY_HEMODYNAMIC_7240703745835327386)],
        &[(0b10001, &ENTRY_HEMODYNAMICS_15802810674260006804)],
        &[(0b11010, &ENTRY_HEMERYTHRIN_18297143920246755389)],
        &[(0b10001, &ENTRY_HEMOFLAGELLATE_8230159863303274833)],
        &[(0b10001, &ENTRY_HEMOGLOBIC_14765854368021767231)],
        &[(0b11001, &ENTRY_HEMOGLOBIN_6804726008880716957)],
        &[(0b10001, &ENTRY_HEMOGLOBINOPATHIES_17410196980417446786)],
        &[(0b10001, &ENTRY_HEMOGLOBINOPATHY_14568715325380669233)],
        &[(0b10001, &ENTRY_HEMOGLOBINOUS_5070767689092245762)],
        &[(0b10001, &ENTRY_HEMOGLOBINURIA_4853343125806894750)],
        &[(0b10001, &ENTRY_HEMOGRAM_6271130824240485709)],
        &[(0b10001, &ENTRY_HEMOID_8415451507008006846)],
        &[(0b10001, &ENTRY_HEMOLYSIN_1274334236242292741)],
        &[(0b11001, &ENTRY_HEMOLYSIS_12608987784718295390)],
        &[(0b10001, &ENTRY_HEMOLYTIC_16715121281784730995)],
        &[(0b10001, &ENTRY_HEMOMETER_6044885281478125261)],
        &[(0b10001, &ENTRY_HEMON_8613843011077669238)],
        &[(0b10001, &ENTRY_HEMOPHILE_939872597781518278)],
        &[(0b11001, &ENTRY_HEMOPHILIA_438737295534097219)],
        &[(0b11001, &ENTRY_HEMOPHILIAC_6895884973735776837)],
        &[(0b11001, &ENTRY_HEMOPHILIACS_6189076765654799565)],
        &[(0b11001, &ENTRY_HEMOPHILIC_14204241671140169324)],
        &[(0b10001, &ENTRY_HEMOPOD_10686552211410032739)],
        &[(0b10001, &ENTRY_HEMOPOIESIS_2722325828942122456)],
        &[(0b10001, &ENTRY_HEMOPTYSES_5361818757552462001)],
        &[(0b10001, &ENTRY_HEMOPTYSIS_4816059883591909702)],
        &[(0b11001, &ENTRY_HEMORRHAGE_9520986120225337113)],
        &[(0b11001, &ENTRY_HEMORRHAGED_4698265870788181194)],
        &[(0b11001, &ENTRY_HEMORRHAGES_12805262983424280799)],
        &[(0b11001, &ENTRY_HEMORRHAGING_17455703193968736621)],
        &[(0b11001, &ENTRY_HEMORRHOID_12305272210878568670)],
        &[(0b11001, &ENTRY_HEMORRHOIDAL_8918031688638577890)],
        &[(0b10001, &ENTRY_HEMORRHOIDECTOMY_14512378041008423124)],
        &[(0b11001, &ENTRY_HEMORRHOIDS_7074206056862708793)],
        &[(0b10001, &ENTRY_HEMOSPORID_10539794951355089581)],
        &[(0b10001, &ENTRY_HEMOSPORIDIAN_12777425045521991692)],
        &[(0b10001, &ENTRY_HEMOSTASES_12539643331032997430)],
        &[(0b10001, &ENTRY_HEMOSTASIA_2707018494480397353)],
        &[(0b10001, &ENTRY_HEMOSTASIS_13491292460836556551)],
        &[(0b10001, &ENTRY_HEMOSTATIC_16725641889932539790)],
        &[(0b10001, &ENTRY_HEMOTHORAX_9888985812399256510)],
        &[(0b10001, &ENTRY_HEMOTOXIC_15421781554160520339)],
        &[(0b10001, &ENTRY_HEMOTOXIN_15634750057214615777)],
    ],
    range: 1..=14,
};

static VARS_HEMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMI_CHILDREN),
    value: None,
};

pub static VARS_HEMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("c"),
        dictgen::InsensitiveStr::Ascii("hypesthesia"),
        dictgen::InsensitiveStr::Ascii("hypoesthesia"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("ns"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMIC_3956501241017708617)],
        &[(0b00001, &ENTRY_HEMIHYPESTHESIA_15185944125713437083)],
        &[(0b11010, &ENTRY_HEMIHYPESTHESIA_15185944125713437083)],
        &[(0b10001, &ENTRY_HEMIN_2159475285525852130)],
        &[(0b10001, &ENTRY_HEMINS_2205333871048481752)],
    ],
    range: 1..=12,
};

static VARS_HEME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEME_CHILDREN),
    value: Some(&[(0b10001, &ENTRY_HEME_3428853214083440122)]),
};

pub static VARS_HEME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("rythrin")],
    values: &[&[(0b00001, &ENTRY_HEMERYTHRIN_18297143920246755389)]],
    range: 7..=7,
};

static VARS_HEMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HEMA_CHILDREN),
    value: None,
};

static VARS_HEMA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_HEMAC_NODE),
    Some(&VARS_HEMAD_NODE),
    None,
    None,
    Some(&VARS_HEMAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HEMAL_NODE),
    Some(&VARS_HEMAM_NODE),
    Some(&VARS_HEMAN_NODE),
    None,
    Some(&VARS_HEMAP_NODE),
    None,
    None,
    Some(&VARS_HEMAS_NODE),
    Some(&VARS_HEMAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HEMAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAT_CHILDREN),
    value: None,
};

pub static VARS_HEMAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("ein"),
        dictgen::InsensitiveStr::Ascii("emesis"),
        dictgen::InsensitiveStr::Ascii("herm"),
        dictgen::InsensitiveStr::Ascii("hermal"),
        dictgen::InsensitiveStr::Ascii("hermous"),
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("ics"),
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("in"),
        dictgen::InsensitiveStr::Ascii("inic"),
        dictgen::InsensitiveStr::Ascii("inics"),
        dictgen::InsensitiveStr::Ascii("ins"),
        dictgen::InsensitiveStr::Ascii("ite"),
        dictgen::InsensitiveStr::Ascii("ites"),
        dictgen::InsensitiveStr::Ascii("itic"),
        dictgen::InsensitiveStr::Ascii("oblast"),
        dictgen::InsensitiveStr::Ascii("oblasts"),
        dictgen::InsensitiveStr::Ascii("obranchiate"),
        dictgen::InsensitiveStr::Ascii("ocele"),
        dictgen::InsensitiveStr::Ascii("ocrit"),
        dictgen::InsensitiveStr::Ascii("ocrits"),
        dictgen::InsensitiveStr::Ascii("ocryal"),
        dictgen::InsensitiveStr::Ascii("ocyst"),
        dictgen::InsensitiveStr::Ascii("ocystis"),
        dictgen::InsensitiveStr::Ascii("ocyte"),
        dictgen::InsensitiveStr::Ascii("ogeneses"),
        dictgen::InsensitiveStr::Ascii("ogenesis"),
        dictgen::InsensitiveStr::Ascii("ogenous"),
        dictgen::InsensitiveStr::Ascii("oid"),
        dictgen::InsensitiveStr::Ascii("oidin"),
        dictgen::InsensitiveStr::Ascii("ologic"),
        dictgen::InsensitiveStr::Ascii("ological"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ologists"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("olysis"),
        dictgen::InsensitiveStr::Ascii("oma"),
        dictgen::InsensitiveStr::Ascii("omas"),
        dictgen::InsensitiveStr::Ascii("omata"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ophyte"),
        dictgen::InsensitiveStr::Ascii("opoieses"),
        dictgen::InsensitiveStr::Ascii("opoiesis"),
        dictgen::InsensitiveStr::Ascii("opoietic"),
        dictgen::InsensitiveStr::Ascii("orrhachis"),
        dictgen::InsensitiveStr::Ascii("osepsis"),
        dictgen::InsensitiveStr::Ascii("osin"),
        dictgen::InsensitiveStr::Ascii("osis"),
        dictgen::InsensitiveStr::Ascii("othermal"),
        dictgen::InsensitiveStr::Ascii("oxylic"),
        dictgen::InsensitiveStr::Ascii("oxylin"),
        dictgen::InsensitiveStr::Ascii("oxylins"),
        dictgen::InsensitiveStr::Ascii("ozoa"),
        dictgen::InsensitiveStr::Ascii("ozoal"),
        dictgen::InsensitiveStr::Ascii("ozoic"),
        dictgen::InsensitiveStr::Ascii("ozoon"),
        dictgen::InsensitiveStr::Ascii("ozzoa"),
        dictgen::InsensitiveStr::Ascii("uria"),
        dictgen::InsensitiveStr::Ascii("urias"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMATAL_7087036422270254482)],
        &[(0b10001, &ENTRY_HEMATEIN_15736414880744516603)],
        &[(0b10001, &ENTRY_HEMATEMESIS_1150278158641123049)],
        &[(0b10001, &ENTRY_HEMATHERM_5926070727779344344)],
        &[(0b10001, &ENTRY_HEMATHERMAL_1873265424030054420)],
        &[(0b10001, &ENTRY_HEMATHERMOUS_15573027130540325878)],
        &[(0b10001, &ENTRY_HEMATIC_12135656367189032895)],
        &[(0b10001, &ENTRY_HEMATICS_15442957672300497599)],
        &[(0b10001, &ENTRY_HEMATID_5688919815724817461)],
        &[(0b10001, &ENTRY_HEMATIN_7088374062718549777)],
        &[(0b10001, &ENTRY_HEMATINIC_13817867819850632982)],
        &[(0b10001, &ENTRY_HEMATINICS_14584691563755596573)],
        &[(0b10001, &ENTRY_HEMATINS_3508374996795413939)],
        &[(0b11001, &ENTRY_HEMATITE_18189725537336168240)],
        &[(0b11001, &ENTRY_HEMATITES_16664996411162525513)],
        &[(0b10001, &ENTRY_HEMATITIC_6519641012406286441)],
        &[(0b10001, &ENTRY_HEMATOBLAST_6156351493707158509)],
        &[(0b10001, &ENTRY_HEMATOBLASTS_11740583065401144309)],
        &[(0b10001, &ENTRY_HEMATOBRANCHIATE_6724889294153595153)],
        &[(0b11001, &ENTRY_HEMATOCELE_14219451917679449221)],
        &[(0b10001, &ENTRY_HEMATOCRIT_6552226497838822276)],
        &[(0b10001, &ENTRY_HEMATOCRITS_11851859531643542564)],
        &[(0b10001, &ENTRY_HEMATOCRYAL_14432690073423033477)],
        &[(0b10001, &ENTRY_HEMATOCYST_17378437902553802108)],
        &[(0b10001, &ENTRY_HEMATOCYSTIS_2331938888115761990)],
        &[(0b10001, &ENTRY_HEMATOCYTE_14737318323778154918)],
        &[(0b10001, &ENTRY_HEMATOGENESES_13718226437830070782)],
        &[(0b10001, &ENTRY_HEMATOGENESIS_17338628845528835521)],
        &[(0b10001, &ENTRY_HEMATOGENOUS_251917998139736524)],
        &[(0b10001, &ENTRY_HEMATOID_4321558159204018583)],
        &[(0b10001, &ENTRY_HEMATOIDIN_16093151429433672073)],
        &[(0b11001, &ENTRY_HEMATOLOGIC_2423209455187409759)],
        &[(0b11001, &ENTRY_HEMATOLOGICAL_2070290026293273654)],
        &[(0b11001, &ENTRY_HEMATOLOGIES_13320136886151112131)],
        &[(0b11001, &ENTRY_HEMATOLOGIST_3249312009468893819)],
        &[(0b11001, &ENTRY_HEMATOLOGISTS_4000147591809351359)],
        &[(0b11001, &ENTRY_HEMATOLOGY_8202738283142709840)],
        &[(0b10001, &ENTRY_HEMATOLYSIS_17421425993349650821)],
        &[(0b10001, &ENTRY_HEMATOMA_13408617756828997822)],
        &[(0b10001, &ENTRY_HEMATOMAS_16695820346078382946)],
        &[(0b10001, &ENTRY_HEMATOMATA_6404648405816919402)],
        &[(0b10001, &ENTRY_HEMATOMETER_16112233482898382242)],
        &[(0b10001, &ENTRY_HEMATOPHYTE_16898559278123185799)],
        &[(0b10001, &ENTRY_HEMATOPOIESES_6523522757774558460)],
        &[(0b10001, &ENTRY_HEMATOPOIESIS_13051150701975906944)],
        &[(0b10001, &ENTRY_HEMATOPOIETIC_7321368675852188024)],
        &[(0b10001, &ENTRY_HEMATORRHACHIS_14809769741461008390)],
        &[(0b10001, &ENTRY_HEMATOSEPSIS_13675575187899218762)],
        &[(0b10001, &ENTRY_HEMATOSIN_5725284952839086511)],
        &[(0b10001, &ENTRY_HEMATOSIS_10551613893224734170)],
        &[(0b10001, &ENTRY_HEMATOTHERMAL_5757070152932847531)],
        &[(0b10001, &ENTRY_HEMATOXYLIC_8256186193967626317)],
        &[(0b11001, &ENTRY_HEMATOXYLIN_3495797730607733321)],
        &[(0b11001, &ENTRY_HEMATOXYLINS_9008305718553626994)],
        &[(0b10001, &ENTRY_HEMATOZOA_4614122145286367461)],
        &[(0b10001, &ENTRY_HEMATOZOAL_15898976106203214908)],
        &[(0b10001, &ENTRY_HEMATOZOIC_3178088775054807745)],
        &[(0b10001, &ENTRY_HEMATOZOON_5429660456895400780)],
        &[(0b10001, &ENTRY_HEMATOZZOA_10055676600204821827)],
        &[(0b11001, &ENTRY_HEMATURIA_4282384524379690883)],
        &[(0b11001, &ENTRY_HEMATURIAS_210214870880694336)],
    ],
    range: 2..=11,
};

static VARS_HEMAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAS_CHILDREN),
    value: None,
};

pub static VARS_HEMAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("pectroscope")],
    values: &[&[(0b10001, &ENTRY_HEMASPECTROSCOPE_15636245578363276486)]],
    range: 11..=11,
};

static VARS_HEMAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAP_CHILDREN),
    value: None,
};

pub static VARS_HEMAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ophysis")],
    values: &[&[(0b10001, &ENTRY_HEMAPOPHYSIS_14410027549001408776)]],
    range: 7..=7,
};

static VARS_HEMAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAN_CHILDREN),
    value: None,
};

pub static VARS_HEMAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gioma"),
        dictgen::InsensitiveStr::Ascii("giomas"),
        dictgen::InsensitiveStr::Ascii("giomata"),
        dictgen::InsensitiveStr::Ascii("giomatosis"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMANGIOMA_4433290260611802687)],
        &[(0b10001, &ENTRY_HEMANGIOMAS_5403149239971967527)],
        &[(0b10001, &ENTRY_HEMANGIOMATA_17129056589733427049)],
        &[(0b10001, &ENTRY_HEMANGIOMATOSIS_6766889074360311777)],
    ],
    range: 5..=10,
};

static VARS_HEMAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAM_CHILDREN),
    value: None,
};

pub static VARS_HEMAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eba"),
        dictgen::InsensitiveStr::Ascii("oeba"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMAMEBA_3738470481791074652)],
        &[(0b11010, &ENTRY_HEMAMEBA_3738470481791074652)],
    ],
    range: 3..=4,
};

static VARS_HEMAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAL_CHILDREN),
    value: Some(&[(0b10001, &ENTRY_HEMAL_8174621070613039824)]),
};

pub static VARS_HEMAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HEMAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAG_CHILDREN),
    value: None,
};

pub static VARS_HEMAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("glutinate"),
        dictgen::InsensitiveStr::Ascii("glutinated"),
        dictgen::InsensitiveStr::Ascii("glutinating"),
        dictgen::InsensitiveStr::Ascii("glutination"),
        dictgen::InsensitiveStr::Ascii("glutinative"),
        dictgen::InsensitiveStr::Ascii("glutinin"),
        dictgen::InsensitiveStr::Ascii("ogue"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMAGGLUTINATE_16094833305901311560)],
        &[(0b10001, &ENTRY_HEMAGGLUTINATED_847479788420217781)],
        &[(0b10001, &ENTRY_HEMAGGLUTINATING_406171148269136925)],
        &[(0b10001, &ENTRY_HEMAGGLUTINATION_16199920820699607422)],
        &[(0b10001, &ENTRY_HEMAGGLUTINATIVE_12088266750522338367)],
        &[(0b10001, &ENTRY_HEMAGGLUTININ_1512122070828458386)],
        &[(0b10001, &ENTRY_HEMAGOGUE_7911863114412250688)],
    ],
    range: 4..=11,
};

static VARS_HEMAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAD_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_HEMAD_13652123074339994243)]),
};

pub static VARS_HEMAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HEMAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEMAC_CHILDREN),
    value: None,
};

pub static VARS_HEMAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hrome"),
        dictgen::InsensitiveStr::Ascii("ytometer"),
    ],
    values: &[
        &[(0b10001, &ENTRY_HEMACHROME_6418660628406537270)],
        &[(0b10001, &ENTRY_HEMACYTOMETER_10171050284277896358)],
    ],
    range: 5..=8,
};

static VARS_HEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEL_CHILDREN),
    value: None,
};

pub static VARS_HEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("lenisation"),
        dictgen::InsensitiveStr::Ascii("lenisations"),
        dictgen::InsensitiveStr::Ascii("lenise"),
        dictgen::InsensitiveStr::Ascii("lenised"),
        dictgen::InsensitiveStr::Ascii("leniser"),
        dictgen::InsensitiveStr::Ascii("lenises"),
        dictgen::InsensitiveStr::Ascii("lenising"),
        dictgen::InsensitiveStr::Ascii("lenization"),
        dictgen::InsensitiveStr::Ascii("lenizations"),
        dictgen::InsensitiveStr::Ascii("lenize"),
        dictgen::InsensitiveStr::Ascii("lenized"),
        dictgen::InsensitiveStr::Ascii("lenizer"),
        dictgen::InsensitiveStr::Ascii("lenizes"),
        dictgen::InsensitiveStr::Ascii("lenizing"),
        dictgen::InsensitiveStr::Ascii("loed"),
        dictgen::InsensitiveStr::Ascii("oe"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HELE_15877226027490641560)],
        &[(0b00001, &ENTRY_HELLED_17922575627420769814)],
        &[(0b10010, &ENTRY_HELLENIZATION_572299821795419581)],
        &[(0b10010, &ENTRY_HELLENIZATIONS_16400001129419755934)],
        &[(0b10010, &ENTRY_HELLENIZE_423650469605584095)],
        &[(0b10010, &ENTRY_HELLENIZED_1262240579030098003)],
        &[(0b10010, &ENTRY_HELLENIZER_5626782103778669758)],
        &[(0b10010, &ENTRY_HELLENIZES_11902572538272316091)],
        &[(0b10010, &ENTRY_HELLENIZING_6274266325744186778)],
        &[(0b01001, &ENTRY_HELLENIZATION_572299821795419581)],
        &[(0b01001, &ENTRY_HELLENIZATIONS_16400001129419755934)],
        &[(0b01001, &ENTRY_HELLENIZE_423650469605584095)],
        &[(0b01001, &ENTRY_HELLENIZED_1262240579030098003)],
        &[(0b01001, &ENTRY_HELLENIZER_5626782103778669758)],
        &[(0b01001, &ENTRY_HELLENIZES_11902572538272316091)],
        &[(0b01001, &ENTRY_HELLENIZING_6274266325744186778)],
        &[(0b11010, &ENTRY_HELLED_17922575627420769814)],
        &[(0b11010, &ENTRY_HELE_15877226027490641560)],
    ],
    range: 1..=11,
};

static VARS_HEK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEK_CHILDREN),
    value: None,
};

pub static VARS_HEK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ataean"),
        dictgen::InsensitiveStr::Ascii("atean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEKATEAN_17977682053451514832)],
        &[(0b00001, &ENTRY_HEKATEAN_17977682053451514832)],
    ],
    range: 5..=6,
};

static VARS_HEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEG_CHILDREN),
    value: None,
};

pub static VARS_HEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elianise"),
        dictgen::InsensitiveStr::Ascii("elianises"),
        dictgen::InsensitiveStr::Ascii("elianize"),
        dictgen::InsensitiveStr::Ascii("elianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HEGELIANIZE_7050861181716613923)],
        &[(0b10010, &ENTRY_HEGELIANIZES_12105617449412785322)],
        &[(0b01001, &ENTRY_HEGELIANIZE_7050861181716613923)],
        &[(0b01001, &ENTRY_HEGELIANIZES_12105617449412785322)],
    ],
    range: 8..=9,
};

static VARS_HED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HED_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_HED_13866725514010411690)]),
};

pub static VARS_HED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEC_CHILDREN),
    value: None,
};

pub static VARS_HEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ataean"),
        dictgen::InsensitiveStr::Ascii("atean"),
        dictgen::InsensitiveStr::Ascii("togramme"),
        dictgen::InsensitiveStr::Ascii("togrammes"),
        dictgen::InsensitiveStr::Ascii("toliter"),
        dictgen::InsensitiveStr::Ascii("toliters"),
        dictgen::InsensitiveStr::Ascii("tolitre"),
        dictgen::InsensitiveStr::Ascii("tolitres"),
        dictgen::InsensitiveStr::Ascii("tometer"),
        dictgen::InsensitiveStr::Ascii("tometers"),
        dictgen::InsensitiveStr::Ascii("tometre"),
        dictgen::InsensitiveStr::Ascii("tometres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HECATEAN_15663949261116623377)],
        &[(0b00001, &ENTRY_HECATEAN_15663949261116623377)],
        &[(0b10010, &ENTRY_HECTOGRAM_16008811031541342243)],
        &[(0b10010, &ENTRY_HECTOGRAMS_2910260634951244882)],
        &[(0b00001, &ENTRY_HECTOLITER_14135938994986629002)],
        &[(0b00001, &ENTRY_HECTOLITERS_63081804785897288)],
        &[(0b11010, &ENTRY_HECTOLITER_14135938994986629002)],
        &[(0b11010, &ENTRY_HECTOLITERS_63081804785897288)],
        &[(0b00001, &ENTRY_HECTOMETER_5600234923988117994)],
        &[(0b00001, &ENTRY_HECTOMETERS_14599131318366707062)],
        &[(0b11010, &ENTRY_HECTOMETER_5600234923988117994)],
        &[(0b11010, &ENTRY_HECTOMETERS_14599131318366707062)],
    ],
    range: 5..=9,
};

static VARS_HEB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEB_CHILDREN),
    value: None,
};

pub static VARS_HEB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("raicise"),
        dictgen::InsensitiveStr::Ascii("raicises"),
        dictgen::InsensitiveStr::Ascii("raicize"),
        dictgen::InsensitiveStr::Ascii("raicizes"),
        dictgen::InsensitiveStr::Ascii("raisation"),
        dictgen::InsensitiveStr::Ascii("raisations"),
        dictgen::InsensitiveStr::Ascii("raise"),
        dictgen::InsensitiveStr::Ascii("raised"),
        dictgen::InsensitiveStr::Ascii("raiser"),
        dictgen::InsensitiveStr::Ascii("raises"),
        dictgen::InsensitiveStr::Ascii("raising"),
        dictgen::InsensitiveStr::Ascii("raization"),
        dictgen::InsensitiveStr::Ascii("raizations"),
        dictgen::InsensitiveStr::Ascii("raize"),
        dictgen::InsensitiveStr::Ascii("raized"),
        dictgen::InsensitiveStr::Ascii("raizer"),
        dictgen::InsensitiveStr::Ascii("raizes"),
        dictgen::InsensitiveStr::Ascii("raizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HEBRAICIZE_14258396906314719553)],
        &[(0b10010, &ENTRY_HEBRAICIZES_5673642863053082994)],
        &[(0b01001, &ENTRY_HEBRAICIZE_14258396906314719553)],
        &[(0b01001, &ENTRY_HEBRAICIZES_5673642863053082994)],
        &[(0b10010, &ENTRY_HEBRAIZATION_8649165272409155064)],
        &[(0b10010, &ENTRY_HEBRAIZATIONS_17267782356694125258)],
        &[(0b10010, &ENTRY_HEBRAIZE_3305968178586478178)],
        &[(0b10010, &ENTRY_HEBRAIZED_2388987152857304653)],
        &[(0b10010, &ENTRY_HEBRAIZER_18227136059206047351)],
        &[(0b10010, &ENTRY_HEBRAIZES_14496726034063146653)],
        &[(0b10010, &ENTRY_HEBRAIZING_8562209306481252582)],
        &[(0b01001, &ENTRY_HEBRAIZATION_8649165272409155064)],
        &[(0b01001, &ENTRY_HEBRAIZATIONS_17267782356694125258)],
        &[(0b01001, &ENTRY_HEBRAIZE_3305968178586478178)],
        &[(0b01001, &ENTRY_HEBRAIZED_2388987152857304653)],
        &[(0b01001, &ENTRY_HEBRAIZER_18227136059206047351)],
        &[(0b01001, &ENTRY_HEBRAIZES_14496726034063146653)],
        &[(0b01001, &ENTRY_HEBRAIZING_8562209306481252582)],
    ],
    range: 5..=10,
};

static VARS_HEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HEA_CHILDREN),
    value: None,
};

pub static VARS_HEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thenisation"),
        dictgen::InsensitiveStr::Ascii("thenise"),
        dictgen::InsensitiveStr::Ascii("thenised"),
        dictgen::InsensitiveStr::Ascii("thenises"),
        dictgen::InsensitiveStr::Ascii("thenising"),
        dictgen::InsensitiveStr::Ascii("thenization"),
        dictgen::InsensitiveStr::Ascii("thenize"),
        dictgen::InsensitiveStr::Ascii("thenized"),
        dictgen::InsensitiveStr::Ascii("thenizes"),
        dictgen::InsensitiveStr::Ascii("thenizing"),
        dictgen::InsensitiveStr::Ascii("venise"),
        dictgen::InsensitiveStr::Ascii("venises"),
        dictgen::InsensitiveStr::Ascii("venize"),
        dictgen::InsensitiveStr::Ascii("venizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HEATHENIZATION_4307661223767237492)],
        &[(0b10010, &ENTRY_HEATHENIZE_471060992603716901)],
        &[(0b10010, &ENTRY_HEATHENIZED_11565747380883958930)],
        &[(0b10010, &ENTRY_HEATHENIZES_11230758663043117117)],
        &[(0b10010, &ENTRY_HEATHENIZING_18393026372866732801)],
        &[(0b01001, &ENTRY_HEATHENIZATION_4307661223767237492)],
        &[(0b01001, &ENTRY_HEATHENIZE_471060992603716901)],
        &[(0b01001, &ENTRY_HEATHENIZED_11565747380883958930)],
        &[(0b01001, &ENTRY_HEATHENIZES_11230758663043117117)],
        &[(0b01001, &ENTRY_HEATHENIZING_18393026372866732801)],
        &[(0b10010, &ENTRY_HEAVENIZE_13257962880157202779)],
        &[(0b10010, &ENTRY_HEAVENIZES_16090084063510819598)],
        &[(0b01001, &ENTRY_HEAVENIZE_13257962880157202779)],
        &[(0b01001, &ENTRY_HEAVENIZES_16090084063510819598)],
    ],
    range: 6..=11,
};

static VARS_HA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HA_CHILDREN),
    value: None,
};

static VARS_HA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_HAB_NODE),
    None,
    None,
    Some(&VARS_HAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HAM_NODE),
    Some(&VARS_HAN_NODE),
    None,
    None,
    None,
    Some(&VARS_HAR_NODE),
    Some(&VARS_HAS_NODE),
    Some(&VARS_HAT_NODE),
    Some(&VARS_HAU_NODE),
    Some(&VARS_HAV_NODE),
    None,
    None,
    None,
    Some(&VARS_HAZ_NODE),
];

static VARS_HAZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAZ_CHILDREN),
    value: None,
};

pub static VARS_HAZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ardise"),
        dictgen::InsensitiveStr::Ascii("ardises"),
        dictgen::InsensitiveStr::Ascii("ardize"),
        dictgen::InsensitiveStr::Ascii("ardizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HAZARDIZE_16561989176363630666)],
        &[(0b10010, &ENTRY_HAZARDIZES_3621374866194883455)],
        &[(0b01001, &ENTRY_HAZARDIZE_16561989176363630666)],
        &[(0b01001, &ENTRY_HAZARDIZES_3621374866194883455)],
    ],
    range: 6..=7,
};

static VARS_HAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAV_CHILDREN),
    value: None,
};

pub static VARS_HAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ior"),
        dictgen::InsensitiveStr::Ascii("iored"),
        dictgen::InsensitiveStr::Ascii("iors"),
        dictgen::InsensitiveStr::Ascii("iour"),
        dictgen::InsensitiveStr::Ascii("ioured"),
        dictgen::InsensitiveStr::Ascii("iours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_HAVIOR_9194418702489177973)],
        &[(0b11001, &ENTRY_HAVIORED_12864545760294288553)],
        &[(0b11001, &ENTRY_HAVIORS_7709423866676716486)],
        &[(0b11010, &ENTRY_HAVIOR_9194418702489177973)],
        &[(0b11010, &ENTRY_HAVIORED_12864545760294288553)],
        &[(0b11010, &ENTRY_HAVIORS_7709423866676716486)],
    ],
    range: 3..=6,
};

static VARS_HAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAU_CHILDREN),
    value: None,
};

pub static VARS_HAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ssmannisation"),
        dictgen::InsensitiveStr::Ascii("ssmannisations"),
        dictgen::InsensitiveStr::Ascii("ssmannise"),
        dictgen::InsensitiveStr::Ascii("ssmannised"),
        dictgen::InsensitiveStr::Ascii("ssmannises"),
        dictgen::InsensitiveStr::Ascii("ssmannising"),
        dictgen::InsensitiveStr::Ascii("ssmannization"),
        dictgen::InsensitiveStr::Ascii("ssmannizations"),
        dictgen::InsensitiveStr::Ascii("ssmannize"),
        dictgen::InsensitiveStr::Ascii("ssmannized"),
        dictgen::InsensitiveStr::Ascii("ssmannizes"),
        dictgen::InsensitiveStr::Ascii("ssmannizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HAUSSMANNIZATION_11833307813821936803)],
        &[(0b10010, &ENTRY_HAUSSMANNIZATIONS_14174390069218345646)],
        &[(0b10010, &ENTRY_HAUSSMANNIZE_1750956549415927085)],
        &[(0b10010, &ENTRY_HAUSSMANNIZED_16790530478703643375)],
        &[(0b10010, &ENTRY_HAUSSMANNIZES_10290035980633013808)],
        &[(0b10010, &ENTRY_HAUSSMANNIZING_7743598241365094927)],
        &[(0b01001, &ENTRY_HAUSSMANNIZATION_11833307813821936803)],
        &[(0b01001, &ENTRY_HAUSSMANNIZATIONS_14174390069218345646)],
        &[(0b01001, &ENTRY_HAUSSMANNIZE_1750956549415927085)],
        &[(0b01001, &ENTRY_HAUSSMANNIZED_16790530478703643375)],
        &[(0b01001, &ENTRY_HAUSSMANNIZES_10290035980633013808)],
        &[(0b01001, &ENTRY_HAUSSMANNIZING_7743598241365094927)],
    ],
    range: 9..=14,
};

static VARS_HAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAT_CHILDREN),
    value: None,
};

pub static VARS_HAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cheled"),
        dictgen::InsensitiveStr::Ascii("cheling"),
        dictgen::InsensitiveStr::Ascii("chelled"),
        dictgen::InsensitiveStr::Ascii("chelling"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HATCHELED_833142746170795775)],
        &[(0b00001, &ENTRY_HATCHELING_2188593831667763850)],
        &[(0b11010, &ENTRY_HATCHELED_833142746170795775)],
        &[(0b11010, &ENTRY_HATCHELING_2188593831667763850)],
        &[(0b10010, &ENTRY_HATTIZE_12381830723700612027)],
        &[(0b10010, &ENTRY_HATTIZES_2400340849510871993)],
        &[(0b01001, &ENTRY_HATTIZE_12381830723700612027)],
        &[(0b01001, &ENTRY_HATTIZES_2400340849510871993)],
    ],
    range: 4..=8,
};

static VARS_HAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAS_CHILDREN),
    value: None,
};

pub static VARS_HAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idaean"),
        dictgen::InsensitiveStr::Ascii("idean"),
        dictgen::InsensitiveStr::Ascii("monaean"),
        dictgen::InsensitiveStr::Ascii("monaeans"),
        dictgen::InsensitiveStr::Ascii("monean"),
        dictgen::InsensitiveStr::Ascii("moneans"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HASIDEAN_7075843562757009121)],
        &[(0b00001, &ENTRY_HASIDEAN_7075843562757009121)],
        &[(0b11010, &ENTRY_HASMONEAN_8439032050688349426)],
        &[(0b11010, &ENTRY_HASMONEANS_4264606967949907198)],
        &[(0b00001, &ENTRY_HASMONEAN_8439032050688349426)],
        &[(0b00001, &ENTRY_HASMONEANS_4264606967949907198)],
    ],
    range: 5..=8,
};

static VARS_HAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HAR_CHILDREN),
    value: None,
};

static VARS_HAR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_HARB_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HARM_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HARV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_HARV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HARV_CHILDREN),
    value: None,
};

pub static VARS_HARV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ardise"),
        dictgen::InsensitiveStr::Ascii("ardises"),
        dictgen::InsensitiveStr::Ascii("ardize"),
        dictgen::InsensitiveStr::Ascii("ardizes"),
        dictgen::InsensitiveStr::Ascii("eyise"),
        dictgen::InsensitiveStr::Ascii("eyises"),
        dictgen::InsensitiveStr::Ascii("eyize"),
        dictgen::InsensitiveStr::Ascii("eyizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HARVARDIZE_17099717488981918243)],
        &[(0b10010, &ENTRY_HARVARDIZES_15120540188589580097)],
        &[(0b01001, &ENTRY_HARVARDIZE_17099717488981918243)],
        &[(0b01001, &ENTRY_HARVARDIZES_15120540188589580097)],
        &[(0b10010, &ENTRY_HARVEYIZE_8525712996046155627)],
        &[(0b10010, &ENTRY_HARVEYIZES_14473265147115327687)],
        &[(0b01001, &ENTRY_HARVEYIZE_8525712996046155627)],
        &[(0b01001, &ENTRY_HARVEYIZES_14473265147115327687)],
    ],
    range: 5..=7,
};

static VARS_HARM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HARM_CHILDREN),
    value: None,
};

pub static VARS_HARM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onisable"),
        dictgen::InsensitiveStr::Ascii("onisabler"),
        dictgen::InsensitiveStr::Ascii("onisables"),
        dictgen::InsensitiveStr::Ascii("onisablest"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onisers"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onizable"),
        dictgen::InsensitiveStr::Ascii("onizabler"),
        dictgen::InsensitiveStr::Ascii("onizables"),
        dictgen::InsensitiveStr::Ascii("onizablest"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizers"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("othoae"),
        dictgen::InsensitiveStr::Ascii("othoe"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HARMONIZABLE_3524685114296597734)],
        &[(0b10010, &ENTRY_HARMONIZABLER_784086214484258137)],
        &[(0b10010, &ENTRY_HARMONIZABLES_12681674670896899721)],
        &[(0b10010, &ENTRY_HARMONIZABLEST_2737362624785805248)],
        &[(0b10010, &ENTRY_HARMONIZATION_3936035217464563683)],
        &[(0b10010, &ENTRY_HARMONIZATIONS_1390450432634590795)],
        &[(0b10010, &ENTRY_HARMONIZE_16537605792111248548)],
        &[(0b10010, &ENTRY_HARMONIZED_1245910378210887216)],
        &[(0b10010, &ENTRY_HARMONIZER_11079314650397597076)],
        &[(0b10010, &ENTRY_HARMONIZERS_14760666922495363496)],
        &[(0b10010, &ENTRY_HARMONIZES_11148526706436473737)],
        &[(0b10010, &ENTRY_HARMONIZING_3276739627374116575)],
        &[(0b01001, &ENTRY_HARMONIZABLE_3524685114296597734)],
        &[(0b01001, &ENTRY_HARMONIZABLER_784086214484258137)],
        &[(0b01001, &ENTRY_HARMONIZABLES_12681674670896899721)],
        &[(0b01001, &ENTRY_HARMONIZABLEST_2737362624785805248)],
        &[(0b01001, &ENTRY_HARMONIZATION_3936035217464563683)],
        &[(0b01001, &ENTRY_HARMONIZATIONS_1390450432634590795)],
        &[(0b01001, &ENTRY_HARMONIZE_16537605792111248548)],
        &[(0b01001, &ENTRY_HARMONIZED_1245910378210887216)],
        &[(0b01001, &ENTRY_HARMONIZER_11079314650397597076)],
        &[(0b01001, &ENTRY_HARMONIZERS_14760666922495363496)],
        &[(0b01001, &ENTRY_HARMONIZES_11148526706436473737)],
        &[(0b01001, &ENTRY_HARMONIZING_3276739627374116575)],
        &[(0b11010, &ENTRY_HARMOTHOE_15375280065469282042)],
        &[(0b00001, &ENTRY_HARMOTHOE_15375280065469282042)],
    ],
    range: 5..=10,
};

static VARS_HARB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HARB_CHILDREN),
    value: None,
};

pub static VARS_HARB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orage"),
        dictgen::InsensitiveStr::Ascii("orages"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("orful"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("orlesser"),
        dictgen::InsensitiveStr::Ascii("orlesses"),
        dictgen::InsensitiveStr::Ascii("orlessest"),
        dictgen::InsensitiveStr::Ascii("orous"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("orside"),
        dictgen::InsensitiveStr::Ascii("orward"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourage"),
        dictgen::InsensitiveStr::Ascii("ourages"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ourful"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ourlesser"),
        dictgen::InsensitiveStr::Ascii("ourlesses"),
        dictgen::InsensitiveStr::Ascii("ourlessest"),
        dictgen::InsensitiveStr::Ascii("ourous"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("ourside"),
        dictgen::InsensitiveStr::Ascii("ourward"),
    ],
    values: &[
        &[(0b11001, &ENTRY_HARBOR_7684387603909099341)],
        &[(0b11001, &ENTRY_HARBORAGE_3550097433722182667)],
        &[(0b11001, &ENTRY_HARBORAGES_798940995174395851)],
        &[(0b11001, &ENTRY_HARBORED_7559176787853337330)],
        &[(0b11001, &ENTRY_HARBORER_17782355986829956224)],
        &[(0b11001, &ENTRY_HARBORERS_14405132928866064013)],
        &[(0b11001, &ENTRY_HARBORFUL_10848468655854650625)],
        &[(0b11001, &ENTRY_HARBORING_8402517685558870632)],
        &[(0b11001, &ENTRY_HARBORLESS_1184995738439778537)],
        &[(0b11001, &ENTRY_HARBORLESSER_9734324406563797455)],
        &[(0b11001, &ENTRY_HARBORLESSES_12304255545984710354)],
        &[(0b11001, &ENTRY_HARBORLESSEST_630061914736245442)],
        &[(0b00001, &ENTRY_HARBOROUS_5233500953165283102)],
        &[(0b11001, &ENTRY_HARBORS_8699567614856953096)],
        &[(0b11001, &ENTRY_HARBORSIDE_15034063211426224574)],
        &[(0b11001, &ENTRY_HARBORWARD_15630040836906357036)],
        &[(0b11010, &ENTRY_HARBOR_7684387603909099341)],
        &[(0b11010, &ENTRY_HARBORAGE_3550097433722182667)],
        &[(0b11010, &ENTRY_HARBORAGES_798940995174395851)],
        &[(0b11010, &ENTRY_HARBORED_7559176787853337330)],
        &[(0b11010, &ENTRY_HARBORER_17782355986829956224)],
        &[(0b11010, &ENTRY_HARBORERS_14405132928866064013)],
        &[(0b11010, &ENTRY_HARBORFUL_10848468655854650625)],
        &[(0b11010, &ENTRY_HARBORING_8402517685558870632)],
        &[(0b11010, &ENTRY_HARBORLESS_1184995738439778537)],
        &[(0b11010, &ENTRY_HARBORLESSER_9734324406563797455)],
        &[(0b11010, &ENTRY_HARBORLESSES_12304255545984710354)],
        &[(0b11010, &ENTRY_HARBORLESSEST_630061914736245442)],
        &[(0b11010, &ENTRY_HARBOROUS_5233500953165283102)],
        &[(0b11010, &ENTRY_HARBORS_8699567614856953096)],
        &[(0b11010, &ENTRY_HARBORSIDE_15034063211426224574)],
        &[(0b11010, &ENTRY_HARBORWARD_15630040836906357036)],
    ],
    range: 2..=10,
};

static VARS_HAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAN_CHILDREN),
    value: None,
};

pub static VARS_HAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dseled"),
        dictgen::InsensitiveStr::Ascii("dseling"),
        dictgen::InsensitiveStr::Ascii("dselled"),
        dictgen::InsensitiveStr::Ascii("dselling"),
        dictgen::InsensitiveStr::Ascii("overianise"),
        dictgen::InsensitiveStr::Ascii("overianises"),
        dictgen::InsensitiveStr::Ascii("overianize"),
        dictgen::InsensitiveStr::Ascii("overianizes"),
        dictgen::InsensitiveStr::Ascii("overise"),
        dictgen::InsensitiveStr::Ascii("overises"),
        dictgen::InsensitiveStr::Ascii("overize"),
        dictgen::InsensitiveStr::Ascii("overizes"),
        dictgen::InsensitiveStr::Ascii("sardise"),
        dictgen::InsensitiveStr::Ascii("sardised"),
        dictgen::InsensitiveStr::Ascii("sardises"),
        dictgen::InsensitiveStr::Ascii("sardising"),
        dictgen::InsensitiveStr::Ascii("sardize"),
        dictgen::InsensitiveStr::Ascii("sardized"),
        dictgen::InsensitiveStr::Ascii("sardizes"),
        dictgen::InsensitiveStr::Ascii("sardizing"),
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seling"),
        dictgen::InsensitiveStr::Ascii("selled"),
        dictgen::InsensitiveStr::Ascii("selling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_HANDSELED_4558617958729347581)],
        &[(0b00001, &ENTRY_HANDSELING_7816828783515165883)],
        &[(0b11010, &ENTRY_HANDSELED_4558617958729347581)],
        &[(0b11010, &ENTRY_HANDSELING_7816828783515165883)],
        &[(0b10010, &ENTRY_HANOVERIANIZE_5334670887206094723)],
        &[(0b10010, &ENTRY_HANOVERIANIZES_14446304127834146718)],
        &[(0b01001, &ENTRY_HANOVERIANIZE_5334670887206094723)],
        &[(0b01001, &ENTRY_HANOVERIANIZES_14446304127834146718)],
        &[(0b10010, &ENTRY_HANOVERIZE_11360763386599500895)],
        &[(0b10010, &ENTRY_HANOVERIZES_4571999407649732424)],
        &[(0b01001, &ENTRY_HANOVERIZE_11360763386599500895)],
        &[(0b01001, &ENTRY_HANOVERIZES_4571999407649732424)],
        &[(0b10010, &ENTRY_HANSARDIZE_14805346125270133932)],
        &[(0b10010, &ENTRY_HANSARDIZED_14987634660702470913)],
        &[(0b10010, &ENTRY_HANSARDIZES_16469043666980648203)],
        &[(0b10010, &ENTRY_HANSARDIZING_3110991711011733484)],
        &[(0b01001, &ENTRY_HANSARDIZE_14805346125270133932)],
        &[(0b01001, &ENTRY_HANSARDIZED_14987634660702470913)],
        &[(0b01001, &ENTRY_HANSARDIZES_16469043666980648203)],
        &[(0b01001, &ENTRY_HANSARDIZING_3110991711011733484)],
        &[(0b00001, &ENTRY_HANSELED_3944549000155682089)],
        &[(0b00001, &ENTRY_HANSELING_7080754228121990699)],
        &[(0b11010, &ENTRY_HANSELED_3944549000155682089)],
        &[(0b11010, &ENTRY_HANSELING_7080754228121990699)],
    ],
    range: 5..=11,
};

static VARS_HAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAM_CHILDREN),
    value: None,
};

pub static VARS_HAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("letisation"),
        dictgen::InsensitiveStr::Ascii("letisations"),
        dictgen::InsensitiveStr::Ascii("letise"),
        dictgen::InsensitiveStr::Ascii("letises"),
        dictgen::InsensitiveStr::Ascii("letization"),
        dictgen::InsensitiveStr::Ascii("letizations"),
        dictgen::InsensitiveStr::Ascii("letize"),
        dictgen::InsensitiveStr::Ascii("letizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HAMLETIZATION_5996454377141688911)],
        &[(0b10010, &ENTRY_HAMLETIZATIONS_7394464384934624017)],
        &[(0b10010, &ENTRY_HAMLETIZE_576738953922217726)],
        &[(0b10010, &ENTRY_HAMLETIZES_3332330520225481896)],
        &[(0b01001, &ENTRY_HAMLETIZATION_5996454377141688911)],
        &[(0b01001, &ENTRY_HAMLETIZATIONS_7394464384934624017)],
        &[(0b01001, &ENTRY_HAMLETIZE_576738953922217726)],
        &[(0b01001, &ENTRY_HAMLETIZES_3332330520225481896)],
    ],
    range: 6..=11,
};

static VARS_HAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HAE_CHILDREN),
    value: None,
};

static VARS_HAE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    Some(&VARS_HAED_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HAEM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HAER_NODE),
    None,
    Some(&VARS_HAET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HAET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAET_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HET_10103159752309740785)]),
};

pub static VARS_HAET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b11010, &ENTRY_HETS_6749474741457650714)]],
    range: 1..=1,
};

static VARS_HAER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAER_CHILDREN),
    value: None,
};

pub static VARS_HAER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("edes")],
    values: &[&[(0b11010, &ENTRY_HEREDES_12466213351118710275)]],
    range: 4..=4,
};

static VARS_HAEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HAEM_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HEME_3428853214083440122)]),
};

static VARS_HAEM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_HAEMA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HAEMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_HAEMO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HAEMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMO_CHILDREN),
    value: None,
};

pub static VARS_HAEMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blast"),
        dictgen::InsensitiveStr::Ascii("chromatoses"),
        dictgen::InsensitiveStr::Ascii("chromatosis"),
        dictgen::InsensitiveStr::Ascii("chrome"),
        dictgen::InsensitiveStr::Ascii("coel"),
        dictgen::InsensitiveStr::Ascii("coels"),
        dictgen::InsensitiveStr::Ascii("concentration"),
        dictgen::InsensitiveStr::Ascii("conia"),
        dictgen::InsensitiveStr::Ascii("cyanin"),
        dictgen::InsensitiveStr::Ascii("cyanins"),
        dictgen::InsensitiveStr::Ascii("cyte"),
        dictgen::InsensitiveStr::Ascii("cytes"),
        dictgen::InsensitiveStr::Ascii("cytoblast"),
        dictgen::InsensitiveStr::Ascii("cytoblastic"),
        dictgen::InsensitiveStr::Ascii("cytometer"),
        dictgen::InsensitiveStr::Ascii("dialyses"),
        dictgen::InsensitiveStr::Ascii("dialysis"),
        dictgen::InsensitiveStr::Ascii("dilution"),
        dictgen::InsensitiveStr::Ascii("dynamic"),
        dictgen::InsensitiveStr::Ascii("dynamics"),
        dictgen::InsensitiveStr::Ascii("flagellate"),
        dictgen::InsensitiveStr::Ascii("globic"),
        dictgen::InsensitiveStr::Ascii("globin"),
        dictgen::InsensitiveStr::Ascii("globinopathies"),
        dictgen::InsensitiveStr::Ascii("globinopathy"),
        dictgen::InsensitiveStr::Ascii("globinous"),
        dictgen::InsensitiveStr::Ascii("globinuria"),
        dictgen::InsensitiveStr::Ascii("gram"),
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("lysin"),
        dictgen::InsensitiveStr::Ascii("lysis"),
        dictgen::InsensitiveStr::Ascii("lytic"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("phile"),
        dictgen::InsensitiveStr::Ascii("philia"),
        dictgen::InsensitiveStr::Ascii("philiac"),
        dictgen::InsensitiveStr::Ascii("philiacs"),
        dictgen::InsensitiveStr::Ascii("philic"),
        dictgen::InsensitiveStr::Ascii("pod"),
        dictgen::InsensitiveStr::Ascii("poiesis"),
        dictgen::InsensitiveStr::Ascii("ptyses"),
        dictgen::InsensitiveStr::Ascii("ptysis"),
        dictgen::InsensitiveStr::Ascii("rrhage"),
        dictgen::InsensitiveStr::Ascii("rrhaged"),
        dictgen::InsensitiveStr::Ascii("rrhages"),
        dictgen::InsensitiveStr::Ascii("rrhaging"),
        dictgen::InsensitiveStr::Ascii("rrhoid"),
        dictgen::InsensitiveStr::Ascii("rrhoidal"),
        dictgen::InsensitiveStr::Ascii("rrhoidectomy"),
        dictgen::InsensitiveStr::Ascii("rrhoids"),
        dictgen::InsensitiveStr::Ascii("sporid"),
        dictgen::InsensitiveStr::Ascii("sporidian"),
        dictgen::InsensitiveStr::Ascii("stases"),
        dictgen::InsensitiveStr::Ascii("stasia"),
        dictgen::InsensitiveStr::Ascii("stasis"),
        dictgen::InsensitiveStr::Ascii("static"),
        dictgen::InsensitiveStr::Ascii("thorax"),
        dictgen::InsensitiveStr::Ascii("toxic"),
        dictgen::InsensitiveStr::Ascii("toxin"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMOBLAST_1212952674211829865)],
        &[(0b11010, &ENTRY_HEMOCHROMATOSES_15366460809089499165)],
        &[(0b11010, &ENTRY_HEMOCHROMATOSIS_2585842551183947470)],
        &[(0b11010, &ENTRY_HEMOCHROME_2175430877481267405)],
        &[(0b11010, &ENTRY_HEMOCOEL_13831278213168049606)],
        &[(0b11010, &ENTRY_HEMOCOELS_18362432535121397233)],
        &[(0b11010, &ENTRY_HEMOCONCENTRATION_16358090763140109058)],
        &[(0b11010, &ENTRY_HEMOCONIA_16171119888057670146)],
        &[(0b11010, &ENTRY_HEMOCYANIN_12147015753804620517)],
        &[(0b11010, &ENTRY_HEMOCYANINS_17279027934588336382)],
        &[(0b11010, &ENTRY_HEMOCYTE_15334672110474097892)],
        &[(0b11010, &ENTRY_HEMOCYTES_11990928088518685379)],
        &[(0b11010, &ENTRY_HEMOCYTOBLAST_8571898144164238141)],
        &[(0b11010, &ENTRY_HEMOCYTOBLASTIC_15757846276939616596)],
        &[(0b11010, &ENTRY_HEMOCYTOMETER_12858869074539466859)],
        &[(0b10010, &ENTRY_HEMODIALYSES_11392463941635998019)],
        &[(0b10010, &ENTRY_HEMODIALYSIS_1163550974992047350)],
        &[(0b11010, &ENTRY_HEMODILUTION_11283430470235069221)],
        &[(0b11010, &ENTRY_HEMODYNAMIC_7240703745835327386)],
        &[(0b11010, &ENTRY_HEMODYNAMICS_15802810674260006804)],
        &[(0b11010, &ENTRY_HEMOFLAGELLATE_8230159863303274833)],
        &[(0b11010, &ENTRY_HEMOGLOBIC_14765854368021767231)],
        &[(0b10010, &ENTRY_HEMOGLOBIN_6804726008880716957)],
        &[(0b11010, &ENTRY_HEMOGLOBINOPATHIES_17410196980417446786)],
        &[(0b11010, &ENTRY_HEMOGLOBINOPATHY_14568715325380669233)],
        &[(0b11010, &ENTRY_HEMOGLOBINOUS_5070767689092245762)],
        &[(0b11010, &ENTRY_HEMOGLOBINURIA_4853343125806894750)],
        &[(0b11010, &ENTRY_HEMOGRAM_6271130824240485709)],
        &[(0b11010, &ENTRY_HEMOID_8415451507008006846)],
        &[(0b11010, &ENTRY_HEMOLYSIN_1274334236242292741)],
        &[(0b10010, &ENTRY_HEMOLYSIS_12608987784718295390)],
        &[(0b11010, &ENTRY_HEMOLYTIC_16715121281784730995)],
        &[(0b11010, &ENTRY_HEMOMETER_6044885281478125261)],
        &[(0b11010, &ENTRY_HEMON_8613843011077669238)],
        &[(0b11010, &ENTRY_HEMOPHILE_939872597781518278)],
        &[(0b10010, &ENTRY_HEMOPHILIA_438737295534097219)],
        &[(0b10010, &ENTRY_HEMOPHILIAC_6895884973735776837)],
        &[(0b10010, &ENTRY_HEMOPHILIACS_6189076765654799565)],
        &[(0b10010, &ENTRY_HEMOPHILIC_14204241671140169324)],
        &[(0b11010, &ENTRY_HEMOPOD_10686552211410032739)],
        &[(0b11010, &ENTRY_HEMOPOIESIS_2722325828942122456)],
        &[(0b11010, &ENTRY_HEMOPTYSES_5361818757552462001)],
        &[(0b11010, &ENTRY_HEMOPTYSIS_4816059883591909702)],
        &[(0b10010, &ENTRY_HEMORRHAGE_9520986120225337113)],
        &[(0b10010, &ENTRY_HEMORRHAGED_4698265870788181194)],
        &[(0b10010, &ENTRY_HEMORRHAGES_12805262983424280799)],
        &[(0b10010, &ENTRY_HEMORRHAGING_17455703193968736621)],
        &[(0b10010, &ENTRY_HEMORRHOID_12305272210878568670)],
        &[(0b10010, &ENTRY_HEMORRHOIDAL_8918031688638577890)],
        &[(0b11010, &ENTRY_HEMORRHOIDECTOMY_14512378041008423124)],
        &[(0b10010, &ENTRY_HEMORRHOIDS_7074206056862708793)],
        &[(0b11010, &ENTRY_HEMOSPORID_10539794951355089581)],
        &[(0b11010, &ENTRY_HEMOSPORIDIAN_12777425045521991692)],
        &[(0b11010, &ENTRY_HEMOSTASES_12539643331032997430)],
        &[(0b11010, &ENTRY_HEMOSTASIA_2707018494480397353)],
        &[(0b11010, &ENTRY_HEMOSTASIS_13491292460836556551)],
        &[(0b11010, &ENTRY_HEMOSTATIC_16725641889932539790)],
        &[(0b11010, &ENTRY_HEMOTHORAX_9888985812399256510)],
        &[(0b11010, &ENTRY_HEMOTOXIC_15421781554160520339)],
        &[(0b11010, &ENTRY_HEMOTOXIN_15634750057214615777)],
    ],
    range: 1..=14,
};

static VARS_HAEMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMI_CHILDREN),
    value: None,
};

pub static VARS_HAEMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("c"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("ns"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMIC_3956501241017708617)],
        &[(0b11010, &ENTRY_HEMIN_2159475285525852130)],
        &[(0b11010, &ENTRY_HEMINS_2205333871048481752)],
    ],
    range: 1..=2,
};

static VARS_HAEMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_HAEMA_CHILDREN),
    value: None,
};

static VARS_HAEMA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_HAEMAC_NODE),
    Some(&VARS_HAEMAD_NODE),
    None,
    None,
    Some(&VARS_HAEMAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_HAEMAL_NODE),
    None,
    Some(&VARS_HAEMAN_NODE),
    None,
    Some(&VARS_HAEMAP_NODE),
    None,
    None,
    Some(&VARS_HAEMAS_NODE),
    Some(&VARS_HAEMAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_HAEMAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAT_CHILDREN),
    value: None,
};

pub static VARS_HAEMAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("ein"),
        dictgen::InsensitiveStr::Ascii("emesis"),
        dictgen::InsensitiveStr::Ascii("herm"),
        dictgen::InsensitiveStr::Ascii("hermal"),
        dictgen::InsensitiveStr::Ascii("hermous"),
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("ics"),
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("in"),
        dictgen::InsensitiveStr::Ascii("inic"),
        dictgen::InsensitiveStr::Ascii("inics"),
        dictgen::InsensitiveStr::Ascii("ins"),
        dictgen::InsensitiveStr::Ascii("ite"),
        dictgen::InsensitiveStr::Ascii("ites"),
        dictgen::InsensitiveStr::Ascii("itic"),
        dictgen::InsensitiveStr::Ascii("oblast"),
        dictgen::InsensitiveStr::Ascii("oblasts"),
        dictgen::InsensitiveStr::Ascii("obranchiate"),
        dictgen::InsensitiveStr::Ascii("ocele"),
        dictgen::InsensitiveStr::Ascii("ocrit"),
        dictgen::InsensitiveStr::Ascii("ocrits"),
        dictgen::InsensitiveStr::Ascii("ocryal"),
        dictgen::InsensitiveStr::Ascii("ocyst"),
        dictgen::InsensitiveStr::Ascii("ocystis"),
        dictgen::InsensitiveStr::Ascii("ocyte"),
        dictgen::InsensitiveStr::Ascii("ogeneses"),
        dictgen::InsensitiveStr::Ascii("ogenesis"),
        dictgen::InsensitiveStr::Ascii("ogenous"),
        dictgen::InsensitiveStr::Ascii("oid"),
        dictgen::InsensitiveStr::Ascii("oidin"),
        dictgen::InsensitiveStr::Ascii("ologic"),
        dictgen::InsensitiveStr::Ascii("ological"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ologists"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("olysis"),
        dictgen::InsensitiveStr::Ascii("oma"),
        dictgen::InsensitiveStr::Ascii("omas"),
        dictgen::InsensitiveStr::Ascii("omata"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ophyte"),
        dictgen::InsensitiveStr::Ascii("opoieses"),
        dictgen::InsensitiveStr::Ascii("opoiesis"),
        dictgen::InsensitiveStr::Ascii("opoietic"),
        dictgen::InsensitiveStr::Ascii("orrhachis"),
        dictgen::InsensitiveStr::Ascii("osepsis"),
        dictgen::InsensitiveStr::Ascii("osin"),
        dictgen::InsensitiveStr::Ascii("osis"),
        dictgen::InsensitiveStr::Ascii("othermal"),
        dictgen::InsensitiveStr::Ascii("oxylic"),
        dictgen::InsensitiveStr::Ascii("oxylin"),
        dictgen::InsensitiveStr::Ascii("oxylins"),
        dictgen::InsensitiveStr::Ascii("ozoa"),
        dictgen::InsensitiveStr::Ascii("ozoal"),
        dictgen::InsensitiveStr::Ascii("ozoic"),
        dictgen::InsensitiveStr::Ascii("ozoon"),
        dictgen::InsensitiveStr::Ascii("ozzoa"),
        dictgen::InsensitiveStr::Ascii("uria"),
        dictgen::InsensitiveStr::Ascii("urias"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMATAL_7087036422270254482)],
        &[(0b11010, &ENTRY_HEMATEIN_15736414880744516603)],
        &[(0b11010, &ENTRY_HEMATEMESIS_1150278158641123049)],
        &[(0b11010, &ENTRY_HEMATHERM_5926070727779344344)],
        &[(0b11010, &ENTRY_HEMATHERMAL_1873265424030054420)],
        &[(0b11010, &ENTRY_HEMATHERMOUS_15573027130540325878)],
        &[(0b11010, &ENTRY_HEMATIC_12135656367189032895)],
        &[(0b11010, &ENTRY_HEMATICS_15442957672300497599)],
        &[(0b11010, &ENTRY_HEMATID_5688919815724817461)],
        &[(0b11010, &ENTRY_HEMATIN_7088374062718549777)],
        &[(0b11010, &ENTRY_HEMATINIC_13817867819850632982)],
        &[(0b11010, &ENTRY_HEMATINICS_14584691563755596573)],
        &[(0b11010, &ENTRY_HEMATINS_3508374996795413939)],
        &[(0b10010, &ENTRY_HEMATITE_18189725537336168240)],
        &[(0b10010, &ENTRY_HEMATITES_16664996411162525513)],
        &[(0b11010, &ENTRY_HEMATITIC_6519641012406286441)],
        &[(0b11010, &ENTRY_HEMATOBLAST_6156351493707158509)],
        &[(0b11010, &ENTRY_HEMATOBLASTS_11740583065401144309)],
        &[(0b11010, &ENTRY_HEMATOBRANCHIATE_6724889294153595153)],
        &[(0b10010, &ENTRY_HEMATOCELE_14219451917679449221)],
        &[(0b11010, &ENTRY_HEMATOCRIT_6552226497838822276)],
        &[(0b11010, &ENTRY_HEMATOCRITS_11851859531643542564)],
        &[(0b11010, &ENTRY_HEMATOCRYAL_14432690073423033477)],
        &[(0b11010, &ENTRY_HEMATOCYST_17378437902553802108)],
        &[(0b11010, &ENTRY_HEMATOCYSTIS_2331938888115761990)],
        &[(0b11010, &ENTRY_HEMATOCYTE_14737318323778154918)],
        &[(0b11010, &ENTRY_HEMATOGENESES_13718226437830070782)],
        &[(0b11010, &ENTRY_HEMATOGENESIS_17338628845528835521)],
        &[(0b11010, &ENTRY_HEMATOGENOUS_251917998139736524)],
        &[(0b11010, &ENTRY_HEMATOID_4321558159204018583)],
        &[(0b11010, &ENTRY_HEMATOIDIN_16093151429433672073)],
        &[(0b10010, &ENTRY_HEMATOLOGIC_2423209455187409759)],
        &[(0b10010, &ENTRY_HEMATOLOGICAL_2070290026293273654)],
        &[(0b10010, &ENTRY_HEMATOLOGIES_13320136886151112131)],
        &[(0b10010, &ENTRY_HEMATOLOGIST_3249312009468893819)],
        &[(0b10010, &ENTRY_HEMATOLOGISTS_4000147591809351359)],
        &[(0b10010, &ENTRY_HEMATOLOGY_8202738283142709840)],
        &[(0b11010, &ENTRY_HEMATOLYSIS_17421425993349650821)],
        &[(0b11010, &ENTRY_HEMATOMA_13408617756828997822)],
        &[(0b11010, &ENTRY_HEMATOMAS_16695820346078382946)],
        &[(0b11010, &ENTRY_HEMATOMATA_6404648405816919402)],
        &[(0b11010, &ENTRY_HEMATOMETER_16112233482898382242)],
        &[(0b11010, &ENTRY_HEMATOPHYTE_16898559278123185799)],
        &[(0b11010, &ENTRY_HEMATOPOIESES_6523522757774558460)],
        &[(0b11010, &ENTRY_HEMATOPOIESIS_13051150701975906944)],
        &[(0b11010, &ENTRY_HEMATOPOIETIC_7321368675852188024)],
        &[(0b11010, &ENTRY_HEMATORRHACHIS_14809769741461008390)],
        &[(0b11010, &ENTRY_HEMATOSEPSIS_13675575187899218762)],
        &[(0b11010, &ENTRY_HEMATOSIN_5725284952839086511)],
        &[(0b11010, &ENTRY_HEMATOSIS_10551613893224734170)],
        &[(0b11010, &ENTRY_HEMATOTHERMAL_5757070152932847531)],
        &[(0b11010, &ENTRY_HEMATOXYLIC_8256186193967626317)],
        &[(0b10010, &ENTRY_HEMATOXYLIN_3495797730607733321)],
        &[(0b10010, &ENTRY_HEMATOXYLINS_9008305718553626994)],
        &[(0b11010, &ENTRY_HEMATOZOA_4614122145286367461)],
        &[(0b11010, &ENTRY_HEMATOZOAL_15898976106203214908)],
        &[(0b11010, &ENTRY_HEMATOZOIC_3178088775054807745)],
        &[(0b11010, &ENTRY_HEMATOZOON_5429660456895400780)],
        &[(0b11010, &ENTRY_HEMATOZZOA_10055676600204821827)],
        &[(0b10010, &ENTRY_HEMATURIA_4282384524379690883)],
        &[(0b10010, &ENTRY_HEMATURIAS_210214870880694336)],
    ],
    range: 2..=11,
};

static VARS_HAEMAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAS_CHILDREN),
    value: None,
};

pub static VARS_HAEMAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("pectroscope")],
    values: &[&[(0b11010, &ENTRY_HEMASPECTROSCOPE_15636245578363276486)]],
    range: 11..=11,
};

static VARS_HAEMAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAP_CHILDREN),
    value: None,
};

pub static VARS_HAEMAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ophysis")],
    values: &[&[(0b11010, &ENTRY_HEMAPOPHYSIS_14410027549001408776)]],
    range: 7..=7,
};

static VARS_HAEMAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAN_CHILDREN),
    value: None,
};

pub static VARS_HAEMAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gioma"),
        dictgen::InsensitiveStr::Ascii("giomas"),
        dictgen::InsensitiveStr::Ascii("giomata"),
        dictgen::InsensitiveStr::Ascii("giomatosis"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMANGIOMA_4433290260611802687)],
        &[(0b11010, &ENTRY_HEMANGIOMAS_5403149239971967527)],
        &[(0b11010, &ENTRY_HEMANGIOMATA_17129056589733427049)],
        &[(0b11010, &ENTRY_HEMANGIOMATOSIS_6766889074360311777)],
    ],
    range: 5..=10,
};

static VARS_HAEMAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAL_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HEMAL_8174621070613039824)]),
};

pub static VARS_HAEMAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HAEMAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAG_CHILDREN),
    value: None,
};

pub static VARS_HAEMAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("glutinate"),
        dictgen::InsensitiveStr::Ascii("glutinated"),
        dictgen::InsensitiveStr::Ascii("glutinating"),
        dictgen::InsensitiveStr::Ascii("glutination"),
        dictgen::InsensitiveStr::Ascii("glutinative"),
        dictgen::InsensitiveStr::Ascii("glutinin"),
        dictgen::InsensitiveStr::Ascii("ogue"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMAGGLUTINATE_16094833305901311560)],
        &[(0b11010, &ENTRY_HEMAGGLUTINATED_847479788420217781)],
        &[(0b11010, &ENTRY_HEMAGGLUTINATING_406171148269136925)],
        &[(0b11010, &ENTRY_HEMAGGLUTINATION_16199920820699607422)],
        &[(0b11010, &ENTRY_HEMAGGLUTINATIVE_12088266750522338367)],
        &[(0b11010, &ENTRY_HEMAGGLUTININ_1512122070828458386)],
        &[(0b11010, &ENTRY_HEMAGOGUE_7911863114412250688)],
    ],
    range: 4..=11,
};

static VARS_HAEMAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAD_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HEMAD_13652123074339994243)]),
};

pub static VARS_HAEMAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HAEMAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAEMAC_CHILDREN),
    value: None,
};

pub static VARS_HAEMAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hrome"),
        dictgen::InsensitiveStr::Ascii("ytometer"),
    ],
    values: &[
        &[(0b11010, &ENTRY_HEMACHROME_6418660628406537270)],
        &[(0b11010, &ENTRY_HEMACYTOMETER_10171050284277896358)],
    ],
    range: 5..=8,
};

static VARS_HAED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAED_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_HED_13866725514010411690)]),
};

pub static VARS_HAED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_HAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_HAB_CHILDREN),
    value: None,
};

pub static VARS_HAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itualise"),
        dictgen::InsensitiveStr::Ascii("itualises"),
        dictgen::InsensitiveStr::Ascii("itualize"),
        dictgen::InsensitiveStr::Ascii("itualizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_HABITUALIZE_1807450546975383265)],
        &[(0b10010, &ENTRY_HABITUALIZES_15369684171096748006)],
        &[(0b01001, &ENTRY_HABITUALIZE_1807450546975383265)],
        &[(0b01001, &ENTRY_HABITUALIZES_15369684171096748006)],
    ],
    range: 8..=9,
};

static VARS_G_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_G_CHILDREN),
    value: None,
};

static VARS_G_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_GA_NODE),
    None,
    None,
    None,
    Some(&VARS_GE_NODE),
    None,
    None,
    Some(&VARS_GH_NODE),
    Some(&VARS_GI_NODE),
    None,
    None,
    Some(&VARS_GL_NODE),
    None,
    Some(&VARS_GN_NODE),
    Some(&VARS_GO_NODE),
    None,
    None,
    Some(&VARS_GR_NODE),
    None,
    None,
    Some(&VARS_GU_NODE),
    None,
    None,
    None,
    Some(&VARS_GY_NODE),
    None,
];

static VARS_GY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GY_CHILDREN),
    value: None,
};

static VARS_GY_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GYN_NODE),
    None,
    None,
    None,
    Some(&VARS_GYR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_GYR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GYR_CHILDREN),
    value: None,
};

pub static VARS_GYR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ostabilisation"),
        dictgen::InsensitiveStr::Ascii("ostabilisations"),
        dictgen::InsensitiveStr::Ascii("ostabiliser"),
        dictgen::InsensitiveStr::Ascii("ostabilisers"),
        dictgen::InsensitiveStr::Ascii("ostabilization"),
        dictgen::InsensitiveStr::Ascii("ostabilizations"),
        dictgen::InsensitiveStr::Ascii("ostabilizer"),
        dictgen::InsensitiveStr::Ascii("ostabilizers"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GYROSTABILIZATION_7444180417440707528)],
        &[(0b10010, &ENTRY_GYROSTABILIZATIONS_9084662166713279380)],
        &[(0b10010, &ENTRY_GYROSTABILIZER_14836570145756145064)],
        &[(0b10010, &ENTRY_GYROSTABILIZERS_4574473259133787027)],
        &[(0b01001, &ENTRY_GYROSTABILIZATION_7444180417440707528)],
        &[(0b01001, &ENTRY_GYROSTABILIZATIONS_9084662166713279380)],
        &[(0b01001, &ENTRY_GYROSTABILIZER_14836570145756145064)],
        &[(0b01001, &ENTRY_GYROSTABILIZERS_4574473259133787027)],
    ],
    range: 11..=15,
};

static VARS_GYN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GYN_CHILDREN),
    value: None,
};

static VARS_GYN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_GYNA_NODE),
    None,
    None,
    None,
    Some(&VARS_GYNE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GYNO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_GYNO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GYNO_CHILDREN),
    value: None,
};

pub static VARS_GYNO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("monecious"),
        dictgen::InsensitiveStr::Ascii("monoecious"),
    ],
    values: &[
        &[(0b10001, &ENTRY_GYNOMONECIOUS_14127738128183139919)],
        &[(0b11010, &ENTRY_GYNOMONECIOUS_14127738128183139919)],
    ],
    range: 9..=10,
};

static VARS_GYNE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GYNE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GYNE_1219733555746359489)]),
};

pub static VARS_GYNE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cic"),
        dictgen::InsensitiveStr::Ascii("cocracies"),
        dictgen::InsensitiveStr::Ascii("cocracy"),
        dictgen::InsensitiveStr::Ascii("cocrat"),
        dictgen::InsensitiveStr::Ascii("cocratic"),
        dictgen::InsensitiveStr::Ascii("cocraticer"),
        dictgen::InsensitiveStr::Ascii("cocraticest"),
        dictgen::InsensitiveStr::Ascii("cocrats"),
        dictgen::InsensitiveStr::Ascii("coid"),
        dictgen::InsensitiveStr::Ascii("col"),
        dictgen::InsensitiveStr::Ascii("cologic"),
        dictgen::InsensitiveStr::Ascii("cological"),
        dictgen::InsensitiveStr::Ascii("cologicaler"),
        dictgen::InsensitiveStr::Ascii("cologicalest"),
        dictgen::InsensitiveStr::Ascii("cologicals"),
        dictgen::InsensitiveStr::Ascii("cologicer"),
        dictgen::InsensitiveStr::Ascii("cologicest"),
        dictgen::InsensitiveStr::Ascii("cologics"),
        dictgen::InsensitiveStr::Ascii("cologies"),
        dictgen::InsensitiveStr::Ascii("cologist"),
        dictgen::InsensitiveStr::Ascii("cologists"),
        dictgen::InsensitiveStr::Ascii("cology"),
        dictgen::InsensitiveStr::Ascii("comastia"),
        dictgen::InsensitiveStr::Ascii("comastias"),
        dictgen::InsensitiveStr::Ascii("comasty"),
        dictgen::InsensitiveStr::Ascii("comorphous"),
        dictgen::InsensitiveStr::Ascii("conitis"),
        dictgen::InsensitiveStr::Ascii("ocracy"),
        dictgen::InsensitiveStr::Ascii("olater"),
        dictgen::InsensitiveStr::Ascii("olatry"),
    ],
    values: &[
        &[(0b10001, &ENTRY_GYNECIC_4612357248684171733)],
        &[(0b10001, &ENTRY_GYNECOCRACIES_6538377328563789775)],
        &[(0b10001, &ENTRY_GYNECOCRACY_17315257345269411088)],
        &[(0b10001, &ENTRY_GYNECOCRAT_13604809141318679905)],
        &[(0b10001, &ENTRY_GYNECOCRATIC_4397270957142341610)],
        &[(0b10001, &ENTRY_GYNECOCRATICER_11110554799282310698)],
        &[(0b10001, &ENTRY_GYNECOCRATICEST_9045896881169645560)],
        &[(0b10001, &ENTRY_GYNECOCRATS_17242768922364343193)],
        &[(0b10001, &ENTRY_GYNECOID_2669421810154584267)],
        &[(0b10001, &ENTRY_GYNECOL_9831784870183209183)],
        &[(0b10001, &ENTRY_GYNECOLOGIC_7095414145443907048)],
        &[(0b11001, &ENTRY_GYNECOLOGICAL_8191486902731594424)],
        &[(0b11001, &ENTRY_GYNECOLOGICALER_3649621888054805329)],
        &[(0b11001, &ENTRY_GYNECOLOGICALEST_11839192754845678028)],
        &[(0b11001, &ENTRY_GYNECOLOGICALS_12284377184405525261)],
        &[(0b10001, &ENTRY_GYNECOLOGICER_16168567216609951600)],
        &[(0b10001, &ENTRY_GYNECOLOGICEST_11194585440590421999)],
        &[(0b10001, &ENTRY_GYNECOLOGICS_15475065316407176832)],
        &[(0b11001, &ENTRY_GYNECOLOGIES_16136091029849906426)],
        &[(0b11001, &ENTRY_GYNECOLOGIST_7391903546685130646)],
        &[(0b11001, &ENTRY_GYNECOLOGISTS_1517096604835056713)],
        &[(0b11001, &ENTRY_GYNECOLOGY_16692090121570341125)],
        &[(0b11001, &ENTRY_GYNECOMASTIA_3933758254422394945)],
        &[(0b11001, &ENTRY_GYNECOMASTIAS_3172803406961308705)],
        &[(0b10001, &ENTRY_GYNECOMASTY_15555829153650441782)],
        &[(0b10001, &ENTRY_GYNECOMORPHOUS_3257314395419567917)],
        &[(0b10001, &ENTRY_GYNECONITIS_2677048082283197616)],
        &[(0b10001, &ENTRY_GYNEOCRACY_7561546985644041769)],
        &[(0b10001, &ENTRY_GYNEOLATER_7078383320128612624)],
        &[(0b10001, &ENTRY_GYNEOLATRY_15965664026622146712)],
    ],
    range: 3..=12,
};

static VARS_GYNA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GYNA_CHILDREN),
    value: None,
};

pub static VARS_GYNA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ecic"),
        dictgen::InsensitiveStr::Ascii("ecocracies"),
        dictgen::InsensitiveStr::Ascii("ecocracy"),
        dictgen::InsensitiveStr::Ascii("ecocrat"),
        dictgen::InsensitiveStr::Ascii("ecocratic"),
        dictgen::InsensitiveStr::Ascii("ecocraticer"),
        dictgen::InsensitiveStr::Ascii("ecocraticest"),
        dictgen::InsensitiveStr::Ascii("ecocrats"),
        dictgen::InsensitiveStr::Ascii("ecoid"),
        dictgen::InsensitiveStr::Ascii("ecol"),
        dictgen::InsensitiveStr::Ascii("ecologic"),
        dictgen::InsensitiveStr::Ascii("ecological"),
        dictgen::InsensitiveStr::Ascii("ecologicaler"),
        dictgen::InsensitiveStr::Ascii("ecologicalest"),
        dictgen::InsensitiveStr::Ascii("ecologicals"),
        dictgen::InsensitiveStr::Ascii("ecologicer"),
        dictgen::InsensitiveStr::Ascii("ecologicest"),
        dictgen::InsensitiveStr::Ascii("ecologics"),
        dictgen::InsensitiveStr::Ascii("ecologies"),
        dictgen::InsensitiveStr::Ascii("ecologist"),
        dictgen::InsensitiveStr::Ascii("ecologists"),
        dictgen::InsensitiveStr::Ascii("ecology"),
        dictgen::InsensitiveStr::Ascii("ecomastia"),
        dictgen::InsensitiveStr::Ascii("ecomastias"),
        dictgen::InsensitiveStr::Ascii("ecomasty"),
        dictgen::InsensitiveStr::Ascii("ecomorphous"),
        dictgen::InsensitiveStr::Ascii("econitis"),
        dictgen::InsensitiveStr::Ascii("eocracy"),
        dictgen::InsensitiveStr::Ascii("eolater"),
        dictgen::InsensitiveStr::Ascii("eolatry"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GYNE_1219733555746359489)],
        &[(0b11010, &ENTRY_GYNECIC_4612357248684171733)],
        &[(0b11010, &ENTRY_GYNECOCRACIES_6538377328563789775)],
        &[(0b11010, &ENTRY_GYNECOCRACY_17315257345269411088)],
        &[(0b11010, &ENTRY_GYNECOCRAT_13604809141318679905)],
        &[(0b11010, &ENTRY_GYNECOCRATIC_4397270957142341610)],
        &[(0b11010, &ENTRY_GYNECOCRATICER_11110554799282310698)],
        &[(0b11010, &ENTRY_GYNECOCRATICEST_9045896881169645560)],
        &[(0b11010, &ENTRY_GYNECOCRATS_17242768922364343193)],
        &[(0b11010, &ENTRY_GYNECOID_2669421810154584267)],
        &[(0b11010, &ENTRY_GYNECOL_9831784870183209183)],
        &[(0b11010, &ENTRY_GYNECOLOGIC_7095414145443907048)],
        &[(0b10010, &ENTRY_GYNECOLOGICAL_8191486902731594424)],
        &[(0b10010, &ENTRY_GYNECOLOGICALER_3649621888054805329)],
        &[(0b10010, &ENTRY_GYNECOLOGICALEST_11839192754845678028)],
        &[(0b10010, &ENTRY_GYNECOLOGICALS_12284377184405525261)],
        &[(0b11010, &ENTRY_GYNECOLOGICER_16168567216609951600)],
        &[(0b11010, &ENTRY_GYNECOLOGICEST_11194585440590421999)],
        &[(0b11010, &ENTRY_GYNECOLOGICS_15475065316407176832)],
        &[(0b11010, &ENTRY_GYNECOLOGIES_16136091029849906426)],
        &[(0b10010, &ENTRY_GYNECOLOGIST_7391903546685130646)],
        &[(0b10010, &ENTRY_GYNECOLOGISTS_1517096604835056713)],
        &[(0b11010, &ENTRY_GYNECOLOGY_16692090121570341125)],
        &[(0b11010, &ENTRY_GYNECOMASTIA_3933758254422394945)],
        &[(0b11010, &ENTRY_GYNECOMASTIAS_3172803406961308705)],
        &[(0b11010, &ENTRY_GYNECOMASTY_15555829153650441782)],
        &[(0b11010, &ENTRY_GYNECOMORPHOUS_3257314395419567917)],
        &[(0b11010, &ENTRY_GYNECONITIS_2677048082283197616)],
        &[(0b11010, &ENTRY_GYNEOCRACY_7561546985644041769)],
        &[(0b11010, &ENTRY_GYNEOLATER_7078383320128612624)],
        &[(0b11010, &ENTRY_GYNEOLATRY_15965664026622146712)],
    ],
    range: 1..=13,
};

static VARS_GU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GU_CHILDREN),
    value: None,
};

pub static VARS_GU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eber"),
        dictgen::InsensitiveStr::Ascii("ebers"),
        dictgen::InsensitiveStr::Ascii("ebre"),
        dictgen::InsensitiveStr::Ascii("ebres"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("isers"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("izers"),
        dictgen::InsensitiveStr::Ascii("lae"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("ttae"),
        dictgen::InsensitiveStr::Ascii("tte"),
        dictgen::InsensitiveStr::Ascii("ttulae"),
        dictgen::InsensitiveStr::Ascii("ttule"),
        dictgen::InsensitiveStr::Ascii("tturalisation"),
        dictgen::InsensitiveStr::Ascii("tturalisations"),
        dictgen::InsensitiveStr::Ascii("tturalise"),
        dictgen::InsensitiveStr::Ascii("tturalised"),
        dictgen::InsensitiveStr::Ascii("tturalises"),
        dictgen::InsensitiveStr::Ascii("tturalising"),
        dictgen::InsensitiveStr::Ascii("tturalization"),
        dictgen::InsensitiveStr::Ascii("tturalizations"),
        dictgen::InsensitiveStr::Ascii("tturalize"),
        dictgen::InsensitiveStr::Ascii("tturalized"),
        dictgen::InsensitiveStr::Ascii("tturalizes"),
        dictgen::InsensitiveStr::Ascii("tturalizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GUEBER_11407604006203913521)],
        &[(0b00001, &ENTRY_GUEBERS_8470590757377245464)],
        &[(0b11010, &ENTRY_GUEBER_11407604006203913521)],
        &[(0b11010, &ENTRY_GUEBERS_8470590757377245464)],
        &[(0b10010, &ENTRY_GUIZER_10053586555200196360)],
        &[(0b10010, &ENTRY_GUIZERS_14075758514368155583)],
        &[(0b01001, &ENTRY_GUIZER_10053586555200196360)],
        &[(0b01001, &ENTRY_GUIZERS_14075758514368155583)],
        &[(0b11010, &ENTRY_GULE_17891121426939931319)],
        &[(0b00001, &ENTRY_GULE_17891121426939931319)],
        &[(0b11010, &ENTRY_GUTTE_3525764560995535296)],
        &[(0b00001, &ENTRY_GUTTE_3525764560995535296)],
        &[(0b11010, &ENTRY_GUTTULE_6846811733996501915)],
        &[(0b00001, &ENTRY_GUTTULE_6846811733996501915)],
        &[(0b10010, &ENTRY_GUTTURALIZATION_8050117225444468225)],
        &[(0b10010, &ENTRY_GUTTURALIZATIONS_11653363940865133745)],
        &[(0b10010, &ENTRY_GUTTURALIZE_4985183622837803583)],
        &[(0b10010, &ENTRY_GUTTURALIZED_193161462369494648)],
        &[(0b10010, &ENTRY_GUTTURALIZES_347774313307163504)],
        &[(0b10010, &ENTRY_GUTTURALIZING_8987075679515454610)],
        &[(0b01001, &ENTRY_GUTTURALIZATION_8050117225444468225)],
        &[(0b01001, &ENTRY_GUTTURALIZATIONS_11653363940865133745)],
        &[(0b01001, &ENTRY_GUTTURALIZE_4985183622837803583)],
        &[(0b01001, &ENTRY_GUTTURALIZED_193161462369494648)],
        &[(0b01001, &ENTRY_GUTTURALIZES_347774313307163504)],
        &[(0b01001, &ENTRY_GUTTURALIZING_8987075679515454610)],
    ],
    range: 2..=14,
};

static VARS_GR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GR_CHILDREN),
    value: None,
};

static VARS_GR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_GRA_NODE),
    None,
    None,
    None,
    Some(&VARS_GRE_NODE),
    None,
    None,
    None,
    Some(&VARS_GRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GRU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_GRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRU_CHILDREN),
    value: None,
};

pub static VARS_GRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elingly"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellingly"),
        dictgen::InsensitiveStr::Ascii("ellings"),
    ],
    values: &[
        &[(0b01001, &ENTRY_GRUELED_489064457355388373)],
        &[(0b00001, &ENTRY_GRUELER_9855558082126824748)],
        &[(0b00001, &ENTRY_GRUELERS_14251257235203443661)],
        &[(0b01001, &ENTRY_GRUELING_4646165576783322871)],
        &[(0b00001, &ENTRY_GRUELINGLY_11060645752718216669)],
        &[(0b01001, &ENTRY_GRUELINGS_4182385732270423207)],
        &[(0b11010, &ENTRY_GRUELED_489064457355388373)],
        &[(0b11010, &ENTRY_GRUELER_9855558082126824748)],
        &[(0b11010, &ENTRY_GRUELERS_14251257235203443661)],
        &[(0b11010, &ENTRY_GRUELING_4646165576783322871)],
        &[(0b11010, &ENTRY_GRUELINGLY_11060645752718216669)],
        &[(0b11010, &ENTRY_GRUELINGS_4182385732270423207)],
    ],
    range: 4..=8,
};

static VARS_GRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRO_CHILDREN),
    value: None,
};

pub static VARS_GRO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("veled"),
        dictgen::InsensitiveStr::Ascii("veler"),
        dictgen::InsensitiveStr::Ascii("velers"),
        dictgen::InsensitiveStr::Ascii("veling"),
        dictgen::InsensitiveStr::Ascii("velinglier"),
        dictgen::InsensitiveStr::Ascii("velingliest"),
        dictgen::InsensitiveStr::Ascii("velingly"),
        dictgen::InsensitiveStr::Ascii("velled"),
        dictgen::InsensitiveStr::Ascii("veller"),
        dictgen::InsensitiveStr::Ascii("vellers"),
        dictgen::InsensitiveStr::Ascii("velling"),
        dictgen::InsensitiveStr::Ascii("vellinglier"),
        dictgen::InsensitiveStr::Ascii("vellingliest"),
        dictgen::InsensitiveStr::Ascii("vellingly"),
        dictgen::InsensitiveStr::Ascii("yne"),
        dictgen::InsensitiveStr::Ascii("ynes"),
    ],
    values: &[
        &[(0b01001, &ENTRY_GROVELED_2352401965482255212)],
        &[(0b00001, &ENTRY_GROVELER_9431310593606301755)],
        &[(0b00001, &ENTRY_GROVELERS_17279766420386335679)],
        &[(0b01001, &ENTRY_GROVELING_1726744122250600972)],
        &[(0b00001, &ENTRY_GROVELINGLIER_9586931247280041422)],
        &[(0b00001, &ENTRY_GROVELINGLIEST_1087361846884407532)],
        &[(0b00001, &ENTRY_GROVELINGLY_4473860279449450164)],
        &[(0b11010, &ENTRY_GROVELED_2352401965482255212)],
        &[(0b11010, &ENTRY_GROVELER_9431310593606301755)],
        &[(0b11010, &ENTRY_GROVELERS_17279766420386335679)],
        &[(0b11010, &ENTRY_GROVELING_1726744122250600972)],
        &[(0b11010, &ENTRY_GROVELINGLIER_9586931247280041422)],
        &[(0b11010, &ENTRY_GROVELINGLIEST_1087361846884407532)],
        &[(0b11010, &ENTRY_GROVELINGLY_4473860279449450164)],
        &[(0b11010, &ENTRY_GROIN_18030282935737915420)],
        &[(0b11010, &ENTRY_GROINS_18359122734169972948)],
    ],
    range: 3..=12,
};

static VARS_GRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRI_CHILDREN),
    value: None,
};

pub static VARS_GRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sard"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("zard"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GRIZARD_17063187695600909120)],
        &[(0b10010, &ENTRY_GRIZE_9453990615766627670)],
        &[(0b10010, &ENTRY_GRIZES_12774403152381854793)],
        &[(0b01001, &ENTRY_GRIZARD_17063187695600909120)],
        &[(0b01001, &ENTRY_GRIZE_9453990615766627670)],
        &[(0b01001, &ENTRY_GRIZES_12774403152381854793)],
    ],
    range: 2..=4,
};

static VARS_GRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_GER_10029915357597982133)]),
};

pub static VARS_GRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cian"),
        dictgen::InsensitiveStr::Ascii("cianise"),
        dictgen::InsensitiveStr::Ascii("cianises"),
        dictgen::InsensitiveStr::Ascii("cianize"),
        dictgen::InsensitiveStr::Ascii("cianizes"),
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cised"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cising"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cized"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("cizing"),
        dictgen::InsensitiveStr::Ascii("ekise"),
        dictgen::InsensitiveStr::Ascii("ekises"),
        dictgen::InsensitiveStr::Ascii("ekize"),
        dictgen::InsensitiveStr::Ascii("ekizes"),
        dictgen::InsensitiveStr::Ascii("enuk"),
        dictgen::InsensitiveStr::Ascii("isenisation"),
        dictgen::InsensitiveStr::Ascii("isenisations"),
        dictgen::InsensitiveStr::Ascii("isenise"),
        dictgen::InsensitiveStr::Ascii("isenised"),
        dictgen::InsensitiveStr::Ascii("isenises"),
        dictgen::InsensitiveStr::Ascii("isenising"),
        dictgen::InsensitiveStr::Ascii("isenization"),
        dictgen::InsensitiveStr::Ascii("isenizations"),
        dictgen::InsensitiveStr::Ascii("isenize"),
        dictgen::InsensitiveStr::Ascii("isenized"),
        dictgen::InsensitiveStr::Ascii("isenizes"),
        dictgen::InsensitiveStr::Ascii("isenizing"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("yish"),
        dictgen::InsensitiveStr::Ascii("yness"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GRECIAN_417997226095522101)],
        &[(0b10010, &ENTRY_GRECIANIZE_14716636147435581224)],
        &[(0b10010, &ENTRY_GRECIANIZES_14411759533003325711)],
        &[(0b01001, &ENTRY_GRECIANIZE_14716636147435581224)],
        &[(0b01001, &ENTRY_GRECIANIZES_14411759533003325711)],
        &[
            (0b00001, &ENTRY_GRECISE_14608473457893399178),
            (0b10010, &ENTRY_GRECIZE_4024125847440886583),
        ],
        &[
            (0b00001, &ENTRY_GRECISED_3839763344180915513),
            (0b10010, &ENTRY_GRECIZED_16527564747404543915),
        ],
        &[(0b10010, &ENTRY_GRECIZES_7044331661038018107)],
        &[
            (0b00001, &ENTRY_GRECISING_9235719733885081536),
            (0b10010, &ENTRY_GRECIZING_12172207206377092378),
        ],
        &[(0b01001, &ENTRY_GRECIZE_4024125847440886583)],
        &[(0b01001, &ENTRY_GRECIZED_16527564747404543915)],
        &[(0b01001, &ENTRY_GRECIZES_7044331661038018107)],
        &[(0b01001, &ENTRY_GRECIZING_12172207206377092378)],
        &[(0b10010, &ENTRY_GREEKIZE_15314566857028275164)],
        &[(0b10010, &ENTRY_GREEKIZES_3365945163605882813)],
        &[(0b01001, &ENTRY_GREEKIZE_15314566857028275164)],
        &[(0b01001, &ENTRY_GREEKIZES_3365945163605882813)],
        &[(0b11010, &ENTRY_GERENUK_11123017430709792003)],
        &[(0b10010, &ENTRY_GREISENIZATION_8128500031148376106)],
        &[(0b10010, &ENTRY_GREISENIZATIONS_4501697118968920476)],
        &[(0b10010, &ENTRY_GREISENIZE_15671456557302415783)],
        &[(0b10010, &ENTRY_GREISENIZED_773775153096936260)],
        &[(0b10010, &ENTRY_GREISENIZES_10589439824485596475)],
        &[(0b10010, &ENTRY_GREISENIZING_7840207760010207004)],
        &[(0b01001, &ENTRY_GREISENIZATION_8128500031148376106)],
        &[(0b01001, &ENTRY_GREISENIZATIONS_4501697118968920476)],
        &[(0b01001, &ENTRY_GREISENIZE_15671456557302415783)],
        &[(0b01001, &ENTRY_GREISENIZED_773775153096936260)],
        &[(0b01001, &ENTRY_GREISENIZES_10589439824485596475)],
        &[(0b01001, &ENTRY_GREISENIZING_7840207760010207004)],
        &[(0b11010, &ENTRY_GERNE_10723705562317631976)],
        &[(0b11010, &ENTRY_GERS_2810213260239783007)],
        &[(0b11010, &ENTRY_GRAYISH_17428631159661807756)],
        &[(0b11010, &ENTRY_GRAYNESS_3066378526993690701)],
    ],
    range: 1..=12,
};

static VARS_GRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GRA_CHILDREN),
    value: None,
};

static VARS_GRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_GRAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GRAM_NODE),
    Some(&VARS_GRAN_NODE),
    None,
    Some(&VARS_GRAP_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GRAV_NODE),
    None,
    None,
    Some(&VARS_GRAY_NODE),
    None,
];

static VARS_GRAY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAY_CHILDREN),
    value: None,
};

pub static VARS_GRAY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("est"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ish"),
        dictgen::InsensitiveStr::Ascii("ness"),
    ],
    values: &[
        &[(0b01001, &ENTRY_GRAYED_4224809419318876159)],
        &[(0b01001, &ENTRY_GRAYER_13451385637628432933)],
        &[(0b01001, &ENTRY_GRAYEST_8987957900625444290)],
        &[(0b01001, &ENTRY_GRAYING_14737562961746036658)],
        &[(0b00001, &ENTRY_GRAYISH_17428631159661807756)],
        &[(0b00001, &ENTRY_GRAYNESS_3066378526993690701)],
    ],
    range: 2..=4,
};

static VARS_GRAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAV_CHILDREN),
    value: None,
};

pub static VARS_GRAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GRAVELED_6396856593557403791)],
        &[(0b00001, &ENTRY_GRAVELING_11263938049794337387)],
        &[(0b11010, &ENTRY_GRAVELED_6396856593557403791)],
        &[(0b11010, &ENTRY_GRAVELING_11263938049794337387)],
    ],
    range: 4..=6,
};

static VARS_GRAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAP_CHILDREN),
    value: None,
};

pub static VARS_GRAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hitisable"),
        dictgen::InsensitiveStr::Ascii("hitisation"),
        dictgen::InsensitiveStr::Ascii("hitisations"),
        dictgen::InsensitiveStr::Ascii("hitise"),
        dictgen::InsensitiveStr::Ascii("hitised"),
        dictgen::InsensitiveStr::Ascii("hitises"),
        dictgen::InsensitiveStr::Ascii("hitising"),
        dictgen::InsensitiveStr::Ascii("hitizable"),
        dictgen::InsensitiveStr::Ascii("hitization"),
        dictgen::InsensitiveStr::Ascii("hitizations"),
        dictgen::InsensitiveStr::Ascii("hitize"),
        dictgen::InsensitiveStr::Ascii("hitized"),
        dictgen::InsensitiveStr::Ascii("hitizes"),
        dictgen::InsensitiveStr::Ascii("hitizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GRAPHITIZABLE_11399344742072531593)],
        &[(0b10010, &ENTRY_GRAPHITIZATION_9119232042069892055)],
        &[(0b10010, &ENTRY_GRAPHITIZATIONS_16745769267548580130)],
        &[(0b10010, &ENTRY_GRAPHITIZE_9940023022042490384)],
        &[(0b10010, &ENTRY_GRAPHITIZED_14900862347385247613)],
        &[(0b10010, &ENTRY_GRAPHITIZES_3949365548049490211)],
        &[(0b10010, &ENTRY_GRAPHITIZING_12925962006333789717)],
        &[(0b01001, &ENTRY_GRAPHITIZABLE_11399344742072531593)],
        &[(0b01001, &ENTRY_GRAPHITIZATION_9119232042069892055)],
        &[(0b01001, &ENTRY_GRAPHITIZATIONS_16745769267548580130)],
        &[(0b01001, &ENTRY_GRAPHITIZE_9940023022042490384)],
        &[(0b01001, &ENTRY_GRAPHITIZED_14900862347385247613)],
        &[(0b01001, &ENTRY_GRAPHITIZES_3949365548049490211)],
        &[(0b01001, &ENTRY_GRAPHITIZING_12925962006333789717)],
    ],
    range: 6..=11,
};

static VARS_GRAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAN_CHILDREN),
    value: None,
};

pub static VARS_GRAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gerisation"),
        dictgen::InsensitiveStr::Ascii("gerisations"),
        dictgen::InsensitiveStr::Ascii("gerise"),
        dictgen::InsensitiveStr::Ascii("gerised"),
        dictgen::InsensitiveStr::Ascii("geriser"),
        dictgen::InsensitiveStr::Ascii("gerisers"),
        dictgen::InsensitiveStr::Ascii("gerises"),
        dictgen::InsensitiveStr::Ascii("gerising"),
        dictgen::InsensitiveStr::Ascii("gerization"),
        dictgen::InsensitiveStr::Ascii("gerizations"),
        dictgen::InsensitiveStr::Ascii("gerize"),
        dictgen::InsensitiveStr::Ascii("gerized"),
        dictgen::InsensitiveStr::Ascii("gerizer"),
        dictgen::InsensitiveStr::Ascii("gerizers"),
        dictgen::InsensitiveStr::Ascii("gerizes"),
        dictgen::InsensitiveStr::Ascii("gerizing"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulitisation"),
        dictgen::InsensitiveStr::Ascii("ulitisations"),
        dictgen::InsensitiveStr::Ascii("ulitization"),
        dictgen::InsensitiveStr::Ascii("ulitizations"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GRANGERIZATION_8011757954292583522)],
        &[(0b10010, &ENTRY_GRANGERIZATIONS_6041546144988435113)],
        &[(0b10010, &ENTRY_GRANGERIZE_11685394624334929913)],
        &[(0b10010, &ENTRY_GRANGERIZED_11830731660884093072)],
        &[(0b10010, &ENTRY_GRANGERIZER_6895363933607390837)],
        &[(0b10010, &ENTRY_GRANGERIZERS_7048768465888760391)],
        &[(0b10010, &ENTRY_GRANGERIZES_13688800262712479914)],
        &[(0b10010, &ENTRY_GRANGERIZING_12003554918644431898)],
        &[(0b01001, &ENTRY_GRANGERIZATION_8011757954292583522)],
        &[(0b01001, &ENTRY_GRANGERIZATIONS_6041546144988435113)],
        &[(0b01001, &ENTRY_GRANGERIZE_11685394624334929913)],
        &[(0b01001, &ENTRY_GRANGERIZED_11830731660884093072)],
        &[(0b01001, &ENTRY_GRANGERIZER_6895363933607390837)],
        &[(0b01001, &ENTRY_GRANGERIZERS_7048768465888760391)],
        &[(0b01001, &ENTRY_GRANGERIZES_13688800262712479914)],
        &[(0b01001, &ENTRY_GRANGERIZING_12003554918644431898)],
        &[(0b10010, &ENTRY_GRANITIZATION_4587984666842037739)],
        &[(0b10010, &ENTRY_GRANITIZATIONS_5916561325992415976)],
        &[(0b10010, &ENTRY_GRANITIZE_6476105775849514242)],
        &[(0b10010, &ENTRY_GRANITIZED_9523467185555643497)],
        &[(0b10010, &ENTRY_GRANITIZES_5307213501352143475)],
        &[(0b10010, &ENTRY_GRANITIZING_12122977753813840228)],
        &[(0b01001, &ENTRY_GRANITIZATION_4587984666842037739)],
        &[(0b01001, &ENTRY_GRANITIZATIONS_5916561325992415976)],
        &[(0b01001, &ENTRY_GRANITIZE_6476105775849514242)],
        &[(0b01001, &ENTRY_GRANITIZED_9523467185555643497)],
        &[(0b01001, &ENTRY_GRANITIZES_5307213501352143475)],
        &[(0b01001, &ENTRY_GRANITIZING_12122977753813840228)],
        &[(0b10010, &ENTRY_GRANULIZE_106086847220442662)],
        &[(0b10010, &ENTRY_GRANULIZES_14251558873025935098)],
        &[(0b10010, &ENTRY_GRANULITIZATION_1914830872838686250)],
        &[(0b10010, &ENTRY_GRANULITIZATIONS_1898739157771447082)],
        &[(0b01001, &ENTRY_GRANULITIZATION_1914830872838686250)],
        &[(0b01001, &ENTRY_GRANULITIZATIONS_1898739157771447082)],
        &[(0b01001, &ENTRY_GRANULIZE_106086847220442662)],
        &[(0b01001, &ENTRY_GRANULIZES_14251558873025935098)],
    ],
    range: 5..=12,
};

static VARS_GRAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAM_CHILDREN),
    value: None,
};

pub static VARS_GRAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("maticise"),
        dictgen::InsensitiveStr::Ascii("maticised"),
        dictgen::InsensitiveStr::Ascii("maticises"),
        dictgen::InsensitiveStr::Ascii("maticising"),
        dictgen::InsensitiveStr::Ascii("maticize"),
        dictgen::InsensitiveStr::Ascii("maticized"),
        dictgen::InsensitiveStr::Ascii("maticizes"),
        dictgen::InsensitiveStr::Ascii("maticizing"),
        dictgen::InsensitiveStr::Ascii("me"),
        dictgen::InsensitiveStr::Ascii("mes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GRAMMATICIZE_11757970532171038610)],
        &[(0b10010, &ENTRY_GRAMMATICIZED_555586288585252490)],
        &[(0b10010, &ENTRY_GRAMMATICIZES_968607897093671885)],
        &[(0b10010, &ENTRY_GRAMMATICIZING_11302051616654926337)],
        &[(0b01001, &ENTRY_GRAMMATICIZE_11757970532171038610)],
        &[(0b01001, &ENTRY_GRAMMATICIZED_555586288585252490)],
        &[(0b01001, &ENTRY_GRAMMATICIZES_968607897093671885)],
        &[(0b01001, &ENTRY_GRAMMATICIZING_11302051616654926337)],
        &[(0b10010, &ENTRY_GRAM_9361867859862457841)],
        &[(0b10010, &ENTRY_GRAMS_8379840851265617318)],
    ],
    range: 2..=10,
};

static VARS_GRAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GRAE_CHILDREN),
    value: None,
};

pub static VARS_GRAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cian"),
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cised"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cising"),
        dictgen::InsensitiveStr::Ascii("cism"),
        dictgen::InsensitiveStr::Ascii("cisms"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cized"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("cizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GRECIAN_417997226095522101)],
        &[
            (0b10010, &ENTRY_GRAECIZE_13205262082109545793),
            (0b11010, &ENTRY_GRECISE_14608473457893399178),
        ],
        &[
            (0b10010, &ENTRY_GRAECIZED_15484035342864386624),
            (0b11010, &ENTRY_GRECISED_3839763344180915513),
        ],
        &[(0b10010, &ENTRY_GRAECIZES_18067197401205415693)],
        &[
            (0b10010, &ENTRY_GRAECIZING_4425395536860878106),
            (0b11010, &ENTRY_GRECISING_9235719733885081536),
        ],
        &[(0b11010, &ENTRY_GRECISM_16474963217213327368)],
        &[(0b11010, &ENTRY_GRECISMS_7677508798544264651)],
        &[(0b01001, &ENTRY_GRAECIZE_13205262082109545793)],
        &[(0b01001, &ENTRY_GRAECIZED_15484035342864386624)],
        &[(0b01001, &ENTRY_GRAECIZES_18067197401205415693)],
        &[(0b01001, &ENTRY_GRAECIZING_4425395536860878106)],
    ],
    range: 4..=6,
};

static VARS_GO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GO_CHILDREN),
    value: None,
};

static VARS_GO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    Some(&VARS_GOD_NODE),
    Some(&VARS_GOE_NODE),
    None,
    None,
    None,
    Some(&VARS_GOI_NODE),
    None,
    None,
    Some(&VARS_GOL_NODE),
    None,
    Some(&VARS_GON_NODE),
    Some(&VARS_GOO_NODE),
    None,
    None,
    Some(&VARS_GOR_NODE),
    Some(&VARS_GOS_NODE),
    Some(&VARS_GOT_NODE),
    Some(&VARS_GOU_NODE),
    Some(&VARS_GOV_NODE),
    None,
    None,
    Some(&VARS_GOY_NODE),
    None,
];

static VARS_GOY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOY_CHILDREN),
    value: None,
};

pub static VARS_GOY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesque"),
        dictgen::InsensitiveStr::Ascii("esque"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GOYESQUE_6877829052939471298)],
        &[(0b00001, &ENTRY_GOYESQUE_6877829052939471298)],
    ],
    range: 5..=6,
};

static VARS_GOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOV_CHILDREN),
    value: None,
};

pub static VARS_GOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernmentalise"),
        dictgen::InsensitiveStr::Ascii("ernmentalised"),
        dictgen::InsensitiveStr::Ascii("ernmentalises"),
        dictgen::InsensitiveStr::Ascii("ernmentalising"),
        dictgen::InsensitiveStr::Ascii("ernmentalize"),
        dictgen::InsensitiveStr::Ascii("ernmentalized"),
        dictgen::InsensitiveStr::Ascii("ernmentalizes"),
        dictgen::InsensitiveStr::Ascii("ernmentalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GOVERNMENTALIZE_15026957532237481776)],
        &[(0b10010, &ENTRY_GOVERNMENTALIZED_5332812387797598402)],
        &[(0b10010, &ENTRY_GOVERNMENTALIZES_15051032983194955811)],
        &[(0b10010, &ENTRY_GOVERNMENTALIZING_17023477988958404775)],
        &[(0b01001, &ENTRY_GOVERNMENTALIZE_15026957532237481776)],
        &[(0b01001, &ENTRY_GOVERNMENTALIZED_5332812387797598402)],
        &[(0b01001, &ENTRY_GOVERNMENTALIZES_15051032983194955811)],
        &[(0b01001, &ENTRY_GOVERNMENTALIZING_17023477988958404775)],
    ],
    range: 12..=14,
};

static VARS_GOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOU_CHILDREN),
    value: None,
};

pub static VARS_GOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("ra"),
        dictgen::InsensitiveStr::Ascii("ramies"),
        dictgen::InsensitiveStr::Ascii("rmandise"),
        dictgen::InsensitiveStr::Ascii("rmandised"),
        dictgen::InsensitiveStr::Ascii("rmandises"),
        dictgen::InsensitiveStr::Ascii("rmandising"),
        dictgen::InsensitiveStr::Ascii("rmandism"),
        dictgen::InsensitiveStr::Ascii("rmandisms"),
        dictgen::InsensitiveStr::Ascii("rmandize"),
        dictgen::InsensitiveStr::Ascii("rmandized"),
        dictgen::InsensitiveStr::Ascii("rmandizes"),
        dictgen::InsensitiveStr::Ascii("rmandizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GOR_14093694443247898321)],
        &[(0b11010, &ENTRY_GORA_171264175942816577)],
        &[(0b11010, &ENTRY_GORAMIES_15606246035840811431)],
        &[(0b10010, &ENTRY_GOURMANDIZE_9811561039675188095)],
        &[(0b10010, &ENTRY_GOURMANDIZED_17217066519006720059)],
        &[(0b10010, &ENTRY_GOURMANDIZES_10961415197081735)],
        &[(0b10010, &ENTRY_GOURMANDIZING_9468056354440853097)],
        &[(0b11010, &ENTRY_GORMANDISM_14784809580958247953)],
        &[(0b11010, &ENTRY_GORMANDISMS_2185039788447521753)],
        &[(0b01001, &ENTRY_GOURMANDIZE_9811561039675188095)],
        &[(0b01001, &ENTRY_GOURMANDIZED_17217066519006720059)],
        &[(0b01001, &ENTRY_GOURMANDIZES_10961415197081735)],
        &[(0b01001, &ENTRY_GOURMANDIZING_9468056354440853097)],
    ],
    range: 1..=10,
};

static VARS_GOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOT_CHILDREN),
    value: None,
};

pub static VARS_GOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hicise"),
        dictgen::InsensitiveStr::Ascii("hicised"),
        dictgen::InsensitiveStr::Ascii("hiciser"),
        dictgen::InsensitiveStr::Ascii("hicisers"),
        dictgen::InsensitiveStr::Ascii("hicises"),
        dictgen::InsensitiveStr::Ascii("hicising"),
        dictgen::InsensitiveStr::Ascii("hicize"),
        dictgen::InsensitiveStr::Ascii("hicized"),
        dictgen::InsensitiveStr::Ascii("hicizer"),
        dictgen::InsensitiveStr::Ascii("hicizers"),
        dictgen::InsensitiveStr::Ascii("hicizes"),
        dictgen::InsensitiveStr::Ascii("hicizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GOTHICIZE_10579445493165443468)],
        &[(0b10010, &ENTRY_GOTHICIZED_7190788483793513766)],
        &[(0b10010, &ENTRY_GOTHICIZER_9662675332797265708)],
        &[(0b10010, &ENTRY_GOTHICIZERS_14069671387176050924)],
        &[(0b10010, &ENTRY_GOTHICIZES_16217191150519097315)],
        &[(0b10010, &ENTRY_GOTHICIZING_955456591467188414)],
        &[(0b01001, &ENTRY_GOTHICIZE_10579445493165443468)],
        &[(0b01001, &ENTRY_GOTHICIZED_7190788483793513766)],
        &[(0b01001, &ENTRY_GOTHICIZER_9662675332797265708)],
        &[(0b01001, &ENTRY_GOTHICIZERS_14069671387176050924)],
        &[(0b01001, &ENTRY_GOTHICIZES_16217191150519097315)],
        &[(0b01001, &ENTRY_GOTHICIZING_955456591467188414)],
    ],
    range: 6..=8,
};

static VARS_GOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOS_CHILDREN),
    value: None,
};

pub static VARS_GOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("peler"),
        dictgen::InsensitiveStr::Ascii("pelers"),
        dictgen::InsensitiveStr::Ascii("pelise"),
        dictgen::InsensitiveStr::Ascii("pelised"),
        dictgen::InsensitiveStr::Ascii("pelises"),
        dictgen::InsensitiveStr::Ascii("pelising"),
        dictgen::InsensitiveStr::Ascii("pelize"),
        dictgen::InsensitiveStr::Ascii("pelized"),
        dictgen::InsensitiveStr::Ascii("pelizes"),
        dictgen::InsensitiveStr::Ascii("pelizing"),
        dictgen::InsensitiveStr::Ascii("peller"),
        dictgen::InsensitiveStr::Ascii("pellers"),
        dictgen::InsensitiveStr::Ascii("pellise"),
        dictgen::InsensitiveStr::Ascii("pellised"),
        dictgen::InsensitiveStr::Ascii("pellises"),
        dictgen::InsensitiveStr::Ascii("pellising"),
        dictgen::InsensitiveStr::Ascii("pellize"),
        dictgen::InsensitiveStr::Ascii("pellized"),
        dictgen::InsensitiveStr::Ascii("pellizes"),
        dictgen::InsensitiveStr::Ascii("pellizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GOSPELER_17427415273172338485)],
        &[(0b00001, &ENTRY_GOSPELERS_15768484320655667045)],
        &[(0b10010, &ENTRY_GOSPELIZE_17132485493253272517)],
        &[(0b10010, &ENTRY_GOSPELIZED_8655666473040197182)],
        &[(0b10010, &ENTRY_GOSPELIZES_4662692098801017919)],
        &[(0b10010, &ENTRY_GOSPELIZING_10127509527627836099)],
        &[(0b01001, &ENTRY_GOSPELIZE_17132485493253272517)],
        &[(0b01001, &ENTRY_GOSPELIZED_8655666473040197182)],
        &[(0b01001, &ENTRY_GOSPELIZES_4662692098801017919)],
        &[(0b01001, &ENTRY_GOSPELIZING_10127509527627836099)],
        &[(0b11010, &ENTRY_GOSPELER_17427415273172338485)],
        &[(0b11010, &ENTRY_GOSPELERS_15768484320655667045)],
        &[(0b10010, &ENTRY_GOSPELLIZE_5327023394143893963)],
        &[(0b10010, &ENTRY_GOSPELLIZED_6528515629885778069)],
        &[(0b10010, &ENTRY_GOSPELLIZES_16267739496287009593)],
        &[(0b10010, &ENTRY_GOSPELLIZING_2085328678616691449)],
        &[(0b01001, &ENTRY_GOSPELLIZE_5327023394143893963)],
        &[(0b01001, &ENTRY_GOSPELLIZED_6528515629885778069)],
        &[(0b01001, &ENTRY_GOSPELLIZES_16267739496287009593)],
        &[(0b01001, &ENTRY_GOSPELLIZING_2085328678616691449)],
    ],
    range: 5..=9,
};

static VARS_GOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOR_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GOR_14093694443247898321)]),
};

pub static VARS_GOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("amies"),
        dictgen::InsensitiveStr::Ascii("gonise"),
        dictgen::InsensitiveStr::Ascii("gonised"),
        dictgen::InsensitiveStr::Ascii("gonises"),
        dictgen::InsensitiveStr::Ascii("gonising"),
        dictgen::InsensitiveStr::Ascii("gonize"),
        dictgen::InsensitiveStr::Ascii("gonized"),
        dictgen::InsensitiveStr::Ascii("gonizes"),
        dictgen::InsensitiveStr::Ascii("gonizing"),
        dictgen::InsensitiveStr::Ascii("mandise"),
        dictgen::InsensitiveStr::Ascii("mandised"),
        dictgen::InsensitiveStr::Ascii("mandiser"),
        dictgen::InsensitiveStr::Ascii("mandisers"),
        dictgen::InsensitiveStr::Ascii("mandises"),
        dictgen::InsensitiveStr::Ascii("mandising"),
        dictgen::InsensitiveStr::Ascii("mandisings"),
        dictgen::InsensitiveStr::Ascii("mandism"),
        dictgen::InsensitiveStr::Ascii("mandisms"),
        dictgen::InsensitiveStr::Ascii("mandize"),
        dictgen::InsensitiveStr::Ascii("mandized"),
        dictgen::InsensitiveStr::Ascii("mandizer"),
        dictgen::InsensitiveStr::Ascii("mandizers"),
        dictgen::InsensitiveStr::Ascii("mandizes"),
        dictgen::InsensitiveStr::Ascii("mandizing"),
        dictgen::InsensitiveStr::Ascii("mandizings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GORA_171264175942816577)],
        &[(0b00001, &ENTRY_GORAMIES_15606246035840811431)],
        &[(0b10010, &ENTRY_GORGONIZE_7879285325029434471)],
        &[(0b10010, &ENTRY_GORGONIZED_1752725026865323443)],
        &[(0b10010, &ENTRY_GORGONIZES_4219989310312833047)],
        &[(0b10010, &ENTRY_GORGONIZING_17245443610611935765)],
        &[(0b01001, &ENTRY_GORGONIZE_7879285325029434471)],
        &[(0b01001, &ENTRY_GORGONIZED_1752725026865323443)],
        &[(0b01001, &ENTRY_GORGONIZES_4219989310312833047)],
        &[(0b01001, &ENTRY_GORGONIZING_17245443610611935765)],
        &[(0b10010, &ENTRY_GORMANDIZE_13620361302078181878)],
        &[(0b10010, &ENTRY_GORMANDIZED_10731842314325530180)],
        &[(0b10010, &ENTRY_GORMANDIZER_6966761925725934534)],
        &[(0b10010, &ENTRY_GORMANDIZERS_18411470761457014582)],
        &[(0b10010, &ENTRY_GORMANDIZES_2590069975381378998)],
        &[(0b10010, &ENTRY_GORMANDIZING_2185616084567137)],
        &[(0b10010, &ENTRY_GORMANDIZINGS_10921893709340323072)],
        &[(0b00001, &ENTRY_GORMANDISM_14784809580958247953)],
        &[(0b00001, &ENTRY_GORMANDISMS_2185039788447521753)],
        &[(0b01001, &ENTRY_GORMANDIZE_13620361302078181878)],
        &[(0b01001, &ENTRY_GORMANDIZED_10731842314325530180)],
        &[(0b01001, &ENTRY_GORMANDIZER_6966761925725934534)],
        &[(0b01001, &ENTRY_GORMANDIZERS_18411470761457014582)],
        &[(0b01001, &ENTRY_GORMANDIZES_2590069975381378998)],
        &[(0b01001, &ENTRY_GORMANDIZING_2185616084567137)],
        &[(0b01001, &ENTRY_GORMANDIZINGS_10921893709340323072)],
    ],
    range: 1..=10,
};

static VARS_GOO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOO_CHILDREN),
    value: None,
};

pub static VARS_GOO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dby"),
        dictgen::InsensitiveStr::Ascii("dbys"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GOODBYE_14384898326063678406)],
        &[(0b00001, &ENTRY_GOODBYES_1825161685740062266)],
    ],
    range: 3..=4,
};

static VARS_GON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GON_CHILDREN),
    value: None,
};

pub static VARS_GON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orrhea"),
        dictgen::InsensitiveStr::Ascii("orrheal"),
        dictgen::InsensitiveStr::Ascii("orrhealer"),
        dictgen::InsensitiveStr::Ascii("orrhealest"),
        dictgen::InsensitiveStr::Ascii("orrheas"),
        dictgen::InsensitiveStr::Ascii("orrheic"),
        dictgen::InsensitiveStr::Ascii("orrhoea"),
        dictgen::InsensitiveStr::Ascii("orrhoeal"),
        dictgen::InsensitiveStr::Ascii("orrhoealer"),
        dictgen::InsensitiveStr::Ascii("orrhoealest"),
        dictgen::InsensitiveStr::Ascii("orrhoeas"),
        dictgen::InsensitiveStr::Ascii("orrhoeic"),
    ],
    values: &[
        &[(0b11001, &ENTRY_GONORRHEA_16582247655129058477)],
        &[(0b11001, &ENTRY_GONORRHEAL_7680154103977443792)],
        &[(0b11001, &ENTRY_GONORRHEALER_7420289375074953561)],
        &[(0b11001, &ENTRY_GONORRHEALEST_7581818766613734397)],
        &[(0b11001, &ENTRY_GONORRHEAS_7303597805840900864)],
        &[(0b11001, &ENTRY_GONORRHEIC_9854545577426970058)],
        &[(0b10010, &ENTRY_GONORRHEA_16582247655129058477)],
        &[(0b10010, &ENTRY_GONORRHEAL_7680154103977443792)],
        &[(0b10010, &ENTRY_GONORRHEALER_7420289375074953561)],
        &[(0b10010, &ENTRY_GONORRHEALEST_7581818766613734397)],
        &[(0b10010, &ENTRY_GONORRHEAS_7303597805840900864)],
        &[(0b10010, &ENTRY_GONORRHEIC_9854545577426970058)],
    ],
    range: 6..=11,
};

static VARS_GOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOL_CHILDREN),
    value: None,
};

pub static VARS_GOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("iathise"),
        dictgen::InsensitiveStr::Ascii("iathised"),
        dictgen::InsensitiveStr::Ascii("iathises"),
        dictgen::InsensitiveStr::Ascii("iathising"),
        dictgen::InsensitiveStr::Ascii("iathize"),
        dictgen::InsensitiveStr::Ascii("iathized"),
        dictgen::InsensitiveStr::Ascii("iathizes"),
        dictgen::InsensitiveStr::Ascii("iathizing"),
        dictgen::InsensitiveStr::Ascii("oe"),
        dictgen::InsensitiveStr::Ascii("oshes"),
        dictgen::InsensitiveStr::Ascii("oshoes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GOLE_9737246898983155612)],
        &[(0b10010, &ENTRY_GOLIATHIZE_9937408085419338264)],
        &[(0b10010, &ENTRY_GOLIATHIZED_12398672876213122059)],
        &[(0b10010, &ENTRY_GOLIATHIZES_5680945343906319918)],
        &[(0b10010, &ENTRY_GOLIATHIZING_4244029082966162435)],
        &[(0b01001, &ENTRY_GOLIATHIZE_9937408085419338264)],
        &[(0b01001, &ENTRY_GOLIATHIZED_12398672876213122059)],
        &[(0b01001, &ENTRY_GOLIATHIZES_5680945343906319918)],
        &[(0b01001, &ENTRY_GOLIATHIZING_4244029082966162435)],
        &[(0b11010, &ENTRY_GOLE_9737246898983155612)],
        &[(0b00001, &ENTRY_GOLOSHES_13775493769643547174)],
        &[(0b11010, &ENTRY_GOLOSHES_13775493769643547174)],
    ],
    range: 1..=9,
};

static VARS_GOI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOI_CHILDREN),
    value: None,
};

pub static VARS_GOI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GOITER_17716281509178141747)],
        &[(0b00001, &ENTRY_GOITERS_9278089062698566328)],
        &[(0b11010, &ENTRY_GOITER_17716281509178141747)],
        &[(0b11010, &ENTRY_GOITERS_9278089062698566328)],
    ],
    range: 3..=4,
};

static VARS_GOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_GE_2544027066948517700)]),
};

pub static VARS_GOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("tz"),
        dictgen::InsensitiveStr::Ascii("tzville"),
        dictgen::InsensitiveStr::Ascii("y"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GES_7892709255819401837)],
        &[(0b11010, &ENTRY_GETAE_1718634175022590867)],
        &[(0b11010, &ENTRY_GETZ_669206341459593812)],
        &[(0b11010, &ENTRY_GETZVILLE_17657251283898385513)],
        &[(0b11010, &ENTRY_GEY_16134682750611747069)],
    ],
    range: 1..=7,
};

static VARS_GOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GOD_CHILDREN),
    value: None,
};

pub static VARS_GOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dise"),
        dictgen::InsensitiveStr::Ascii("dises"),
        dictgen::InsensitiveStr::Ascii("dize"),
        dictgen::InsensitiveStr::Ascii("dizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GODDIZE_4286830355302335842)],
        &[(0b10010, &ENTRY_GODDIZES_4605603392452105679)],
        &[(0b01001, &ENTRY_GODDIZE_4286830355302335842)],
        &[(0b01001, &ENTRY_GODDIZES_4605603392452105679)],
    ],
    range: 4..=5,
};

static VARS_GN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GN_CHILDREN),
    value: None,
};

pub static VARS_GN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("osticise"),
        dictgen::InsensitiveStr::Ascii("osticised"),
        dictgen::InsensitiveStr::Ascii("osticiser"),
        dictgen::InsensitiveStr::Ascii("osticisers"),
        dictgen::InsensitiveStr::Ascii("osticises"),
        dictgen::InsensitiveStr::Ascii("osticising"),
        dictgen::InsensitiveStr::Ascii("osticize"),
        dictgen::InsensitiveStr::Ascii("osticized"),
        dictgen::InsensitiveStr::Ascii("osticizer"),
        dictgen::InsensitiveStr::Ascii("osticizers"),
        dictgen::InsensitiveStr::Ascii("osticizes"),
        dictgen::InsensitiveStr::Ascii("osticizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GNOSTICIZE_11128074972430661057)],
        &[(0b10010, &ENTRY_GNOSTICIZED_6607237294915929614)],
        &[(0b10010, &ENTRY_GNOSTICIZER_12421398403440384920)],
        &[(0b10010, &ENTRY_GNOSTICIZERS_6404772314227170997)],
        &[(0b10010, &ENTRY_GNOSTICIZES_14521008554147102135)],
        &[(0b10010, &ENTRY_GNOSTICIZING_16518069417018650782)],
        &[(0b01001, &ENTRY_GNOSTICIZE_11128074972430661057)],
        &[(0b01001, &ENTRY_GNOSTICIZED_6607237294915929614)],
        &[(0b01001, &ENTRY_GNOSTICIZER_12421398403440384920)],
        &[(0b01001, &ENTRY_GNOSTICIZERS_6404772314227170997)],
        &[(0b01001, &ENTRY_GNOSTICIZES_14521008554147102135)],
        &[(0b01001, &ENTRY_GNOSTICIZING_16518069417018650782)],
    ],
    range: 8..=10,
};

static VARS_GL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GL_CHILDREN),
    value: None,
};

static VARS_GL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_GLA_NODE),
    None,
    None,
    None,
    Some(&VARS_GLE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GLU_NODE),
    None,
    None,
    None,
    Some(&VARS_GLY_NODE),
    None,
];

static VARS_GLY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLY_CHILDREN),
    value: None,
};

pub static VARS_GLY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caemia"),
        dictgen::InsensitiveStr::Ascii("caemic"),
        dictgen::InsensitiveStr::Ascii("cemia"),
        dictgen::InsensitiveStr::Ascii("cemic"),
        dictgen::InsensitiveStr::Ascii("cerin"),
        dictgen::InsensitiveStr::Ascii("cerinise"),
        dictgen::InsensitiveStr::Ascii("cerinises"),
        dictgen::InsensitiveStr::Ascii("cerinize"),
        dictgen::InsensitiveStr::Ascii("cerinizes"),
        dictgen::InsensitiveStr::Ascii("cerins"),
        dictgen::InsensitiveStr::Ascii("cerolise"),
        dictgen::InsensitiveStr::Ascii("cerolised"),
        dictgen::InsensitiveStr::Ascii("cerolises"),
        dictgen::InsensitiveStr::Ascii("cerolize"),
        dictgen::InsensitiveStr::Ascii("cerolized"),
        dictgen::InsensitiveStr::Ascii("cerolizes"),
        dictgen::InsensitiveStr::Ascii("cogenise"),
        dictgen::InsensitiveStr::Ascii("cogenises"),
        dictgen::InsensitiveStr::Ascii("cogenize"),
        dictgen::InsensitiveStr::Ascii("cogenizes"),
        dictgen::InsensitiveStr::Ascii("cohaemia"),
        dictgen::InsensitiveStr::Ascii("cohemia"),
        dictgen::InsensitiveStr::Ascii("cosaemia"),
        dictgen::InsensitiveStr::Ascii("cosemia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GLYCEMIA_11995000715174302478)],
        &[(0b11010, &ENTRY_GLYCEMIC_11032815698109543693)],
        &[(0b10001, &ENTRY_GLYCEMIA_11995000715174302478)],
        &[(0b10001, &ENTRY_GLYCEMIC_11032815698109543693)],
        &[(0b00001, &ENTRY_GLYCERIN_13570623165649901397)],
        &[(0b10010, &ENTRY_GLYCERINIZE_15525365444232192960)],
        &[(0b10010, &ENTRY_GLYCERINIZES_17601869911441127120)],
        &[(0b01001, &ENTRY_GLYCERINIZE_15525365444232192960)],
        &[(0b01001, &ENTRY_GLYCERINIZES_17601869911441127120)],
        &[(0b00001, &ENTRY_GLYCERINS_12602551092241423563)],
        &[(0b10010, &ENTRY_GLYCEROLIZE_14402503186408445056)],
        &[(0b10010, &ENTRY_GLYCEROLIZED_835284803246529776)],
        &[(0b10010, &ENTRY_GLYCEROLIZES_16560265368755341391)],
        &[(0b01001, &ENTRY_GLYCEROLIZE_14402503186408445056)],
        &[(0b01001, &ENTRY_GLYCEROLIZED_835284803246529776)],
        &[(0b01001, &ENTRY_GLYCEROLIZES_16560265368755341391)],
        &[(0b10010, &ENTRY_GLYCOGENIZE_2541584719829339590)],
        &[(0b10010, &ENTRY_GLYCOGENIZES_8753992975266531652)],
        &[(0b01001, &ENTRY_GLYCOGENIZE_2541584719829339590)],
        &[(0b01001, &ENTRY_GLYCOGENIZES_8753992975266531652)],
        &[(0b11010, &ENTRY_GLYCOHEMIA_5170811597574477308)],
        &[(0b10001, &ENTRY_GLYCOHEMIA_5170811597574477308)],
        &[(0b11010, &ENTRY_GLYCOSEMIA_9241245255757665402)],
        &[(0b10001, &ENTRY_GLYCOSEMIA_9241245255757665402)],
    ],
    range: 5..=9,
};

static VARS_GLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLU_CHILDREN),
    value: None,
};

pub static VARS_GLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caemia"),
        dictgen::InsensitiveStr::Ascii("cemia"),
        dictgen::InsensitiveStr::Ascii("cosaemia"),
        dictgen::InsensitiveStr::Ascii("cosemia"),
        dictgen::InsensitiveStr::Ascii("taeal"),
        dictgen::InsensitiveStr::Ascii("taei"),
        dictgen::InsensitiveStr::Ascii("taeus"),
        dictgen::InsensitiveStr::Ascii("tei"),
        dictgen::InsensitiveStr::Ascii("teus"),
        dictgen::InsensitiveStr::Ascii("ttonise"),
        dictgen::InsensitiveStr::Ascii("ttonised"),
        dictgen::InsensitiveStr::Ascii("ttonises"),
        dictgen::InsensitiveStr::Ascii("ttonising"),
        dictgen::InsensitiveStr::Ascii("ttonize"),
        dictgen::InsensitiveStr::Ascii("ttonized"),
        dictgen::InsensitiveStr::Ascii("ttonizes"),
        dictgen::InsensitiveStr::Ascii("ttonizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GLUCEMIA_16714227962549234650)],
        &[(0b10001, &ENTRY_GLUCEMIA_16714227962549234650)],
        &[(0b11010, &ENTRY_GLUCOSEMIA_10620016314334807991)],
        &[(0b10001, &ENTRY_GLUCOSEMIA_10620016314334807991)],
        &[(0b11010, &ENTRY_GLUTEAL_13945486219027643389)],
        &[(0b11010, &ENTRY_GLUTEI_16791170565919408237)],
        &[(0b11010, &ENTRY_GLUTEUS_1051154314043721205)],
        &[(0b00001, &ENTRY_GLUTEI_16791170565919408237)],
        &[(0b00001, &ENTRY_GLUTEUS_1051154314043721205)],
        &[(0b10010, &ENTRY_GLUTTONIZE_10450449431254721690)],
        &[(0b10010, &ENTRY_GLUTTONIZED_4146378212700912723)],
        &[(0b10010, &ENTRY_GLUTTONIZES_15763514001401508118)],
        &[(0b10010, &ENTRY_GLUTTONIZING_4580260495228977044)],
        &[(0b01001, &ENTRY_GLUTTONIZE_10450449431254721690)],
        &[(0b01001, &ENTRY_GLUTTONIZED_4146378212700912723)],
        &[(0b01001, &ENTRY_GLUTTONIZES_15763514001401508118)],
        &[(0b01001, &ENTRY_GLUTTONIZING_4580260495228977044)],
    ],
    range: 3..=9,
};

static VARS_GLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLO_CHILDREN),
    value: None,
};

pub static VARS_GLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("balisation"),
        dictgen::InsensitiveStr::Ascii("balisations"),
        dictgen::InsensitiveStr::Ascii("balise"),
        dictgen::InsensitiveStr::Ascii("balised"),
        dictgen::InsensitiveStr::Ascii("balises"),
        dictgen::InsensitiveStr::Ascii("balising"),
        dictgen::InsensitiveStr::Ascii("balization"),
        dictgen::InsensitiveStr::Ascii("balizations"),
        dictgen::InsensitiveStr::Ascii("balize"),
        dictgen::InsensitiveStr::Ascii("balized"),
        dictgen::InsensitiveStr::Ascii("balizes"),
        dictgen::InsensitiveStr::Ascii("balizing"),
        dictgen::InsensitiveStr::Ascii("bigerinae"),
        dictgen::InsensitiveStr::Ascii("bigerine"),
        dictgen::InsensitiveStr::Ascii("ttalisation"),
        dictgen::InsensitiveStr::Ascii("ttalise"),
        dictgen::InsensitiveStr::Ascii("ttalises"),
        dictgen::InsensitiveStr::Ascii("ttalization"),
        dictgen::InsensitiveStr::Ascii("ttalize"),
        dictgen::InsensitiveStr::Ascii("ttalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GLOBALIZATION_7581407957860146976)],
        &[(0b10010, &ENTRY_GLOBALIZATIONS_17494053183467714670)],
        &[(0b10010, &ENTRY_GLOBALIZE_11826473684785302147)],
        &[(0b10010, &ENTRY_GLOBALIZED_11948697689508441693)],
        &[(0b10010, &ENTRY_GLOBALIZES_1812285942441846479)],
        &[(0b10010, &ENTRY_GLOBALIZING_12872973526407105523)],
        &[(0b01001, &ENTRY_GLOBALIZATION_7581407957860146976)],
        &[(0b01001, &ENTRY_GLOBALIZATIONS_17494053183467714670)],
        &[(0b01001, &ENTRY_GLOBALIZE_11826473684785302147)],
        &[(0b01001, &ENTRY_GLOBALIZED_11948697689508441693)],
        &[(0b01001, &ENTRY_GLOBALIZES_1812285942441846479)],
        &[(0b01001, &ENTRY_GLOBALIZING_12872973526407105523)],
        &[(0b11010, &ENTRY_GLOBIGERINE_8558263536879852579)],
        &[(0b00001, &ENTRY_GLOBIGERINE_8558263536879852579)],
        &[(0b10010, &ENTRY_GLOTTALIZATION_8617780925137236905)],
        &[(0b10010, &ENTRY_GLOTTALIZE_11936017486575639215)],
        &[(0b10010, &ENTRY_GLOTTALIZES_1521812381984608242)],
        &[(0b01001, &ENTRY_GLOTTALIZATION_8617780925137236905)],
        &[(0b01001, &ENTRY_GLOTTALIZE_11936017486575639215)],
        &[(0b01001, &ENTRY_GLOTTALIZES_1521812381984608242)],
    ],
    range: 6..=11,
};

static VARS_GLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLE_CHILDREN),
    value: None,
};

pub static VARS_GLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bae"),
        dictgen::InsensitiveStr::Ascii("be"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GLEBE_8123454513306882083)],
        &[(0b00001, &ENTRY_GLEBE_8123454513306882083)],
    ],
    range: 2..=3,
};

static VARS_GLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GLA_CHILDREN),
    value: None,
};

pub static VARS_GLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cialise"),
        dictgen::InsensitiveStr::Ascii("cialises"),
        dictgen::InsensitiveStr::Ascii("cialize"),
        dictgen::InsensitiveStr::Ascii("cializes"),
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moring"),
        dictgen::InsensitiveStr::Ascii("morisation"),
        dictgen::InsensitiveStr::Ascii("morisations"),
        dictgen::InsensitiveStr::Ascii("morise"),
        dictgen::InsensitiveStr::Ascii("morised"),
        dictgen::InsensitiveStr::Ascii("moriser"),
        dictgen::InsensitiveStr::Ascii("morisers"),
        dictgen::InsensitiveStr::Ascii("morises"),
        dictgen::InsensitiveStr::Ascii("morising"),
        dictgen::InsensitiveStr::Ascii("morization"),
        dictgen::InsensitiveStr::Ascii("morizations"),
        dictgen::InsensitiveStr::Ascii("morize"),
        dictgen::InsensitiveStr::Ascii("morized"),
        dictgen::InsensitiveStr::Ascii("morizer"),
        dictgen::InsensitiveStr::Ascii("morizers"),
        dictgen::InsensitiveStr::Ascii("morizes"),
        dictgen::InsensitiveStr::Ascii("morizing"),
        dictgen::InsensitiveStr::Ascii("morless"),
        dictgen::InsensitiveStr::Ascii("mors"),
        dictgen::InsensitiveStr::Ascii("mourization"),
        dictgen::InsensitiveStr::Ascii("mourize"),
        dictgen::InsensitiveStr::Ascii("mourized"),
        dictgen::InsensitiveStr::Ascii("mourizer"),
        dictgen::InsensitiveStr::Ascii("mourizers"),
        dictgen::InsensitiveStr::Ascii("mourizes"),
        dictgen::InsensitiveStr::Ascii("mourizing"),
        dictgen::InsensitiveStr::Ascii("mourless"),
        dictgen::InsensitiveStr::Ascii("mourous"),
        dictgen::InsensitiveStr::Ascii("mourousness"),
        dictgen::InsensitiveStr::Ascii("uconitisation"),
        dictgen::InsensitiveStr::Ascii("uconitisations"),
        dictgen::InsensitiveStr::Ascii("uconitization"),
        dictgen::InsensitiveStr::Ascii("uconitizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GLACIALIZE_702243778246280222)],
        &[(0b10010, &ENTRY_GLACIALIZES_1227166762771762813)],
        &[(0b01001, &ENTRY_GLACIALIZE_702243778246280222)],
        &[(0b01001, &ENTRY_GLACIALIZES_1227166762771762813)],
        &[(0b11001, &ENTRY_GLAMOUR_660428055727744225)],
        &[(0b11001, &ENTRY_GLAMOURED_11154619017989846487)],
        &[(0b11001, &ENTRY_GLAMOURING_6375193716164556692)],
        &[(0b10010, &ENTRY_GLAMORIZATION_17627840945549800707)],
        &[(0b10010, &ENTRY_GLAMORIZATIONS_13386360280962328056)],
        &[(0b10010, &ENTRY_GLAMORIZE_15623953511855635687)],
        &[(0b10010, &ENTRY_GLAMORIZED_7629491500086174456)],
        &[(0b10010, &ENTRY_GLAMORIZER_1273764306977330242)],
        &[(0b10010, &ENTRY_GLAMORIZERS_4548388194452180185)],
        &[(0b10010, &ENTRY_GLAMORIZES_13581885236350696198)],
        &[(0b10010, &ENTRY_GLAMORIZING_13126163444695612437)],
        &[(0b01001, &ENTRY_GLAMORIZATION_17627840945549800707)],
        &[(0b01001, &ENTRY_GLAMORIZATIONS_13386360280962328056)],
        &[(0b01001, &ENTRY_GLAMORIZE_15623953511855635687)],
        &[(0b01001, &ENTRY_GLAMORIZED_7629491500086174456)],
        &[(0b01001, &ENTRY_GLAMORIZER_1273764306977330242)],
        &[(0b01001, &ENTRY_GLAMORIZERS_4548388194452180185)],
        &[(0b01001, &ENTRY_GLAMORIZES_13581885236350696198)],
        &[(0b01001, &ENTRY_GLAMORIZING_13126163444695612437)],
        &[(0b10001, &ENTRY_GLAMORLESS_3213378030533857078)],
        &[(0b11001, &ENTRY_GLAMOURS_12982136149572203520)],
        &[(0b00001, &ENTRY_GLAMORIZATION_17627840945549800707)],
        &[(0b01001, &ENTRY_GLAMORIZE_15623953511855635687)],
        &[(0b01001, &ENTRY_GLAMORIZED_7629491500086174456)],
        &[(0b00001, &ENTRY_GLAMORIZER_1273764306977330242)],
        &[(0b00001, &ENTRY_GLAMORIZERS_4548388194452180185)],
        &[(0b01001, &ENTRY_GLAMORIZES_13581885236350696198)],
        &[(0b01001, &ENTRY_GLAMORIZING_13126163444695612437)],
        &[(0b11010, &ENTRY_GLAMORLESS_3213378030533857078)],
        &[(0b11010, &ENTRY_GLAMOROUS_12197747715827471126)],
        &[(0b11010, &ENTRY_GLAMOROUSNESS_2689045081256261571)],
        &[(0b10010, &ENTRY_GLAUCONITIZATION_7362785196117563859)],
        &[(0b10010, &ENTRY_GLAUCONITIZATIONS_735392238221192579)],
        &[(0b01001, &ENTRY_GLAUCONITIZATION_7362785196117563859)],
        &[(0b01001, &ENTRY_GLAUCONITIZATIONS_735392238221192579)],
    ],
    range: 3..=14,
};

static VARS_GI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GI_CHILDREN),
    value: None,
};

pub static VARS_GI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("antise"),
        dictgen::InsensitiveStr::Ascii("antises"),
        dictgen::InsensitiveStr::Ascii("antize"),
        dictgen::InsensitiveStr::Ascii("antizes"),
        dictgen::InsensitiveStr::Ascii("mbaled"),
        dictgen::InsensitiveStr::Ascii("mbaling"),
        dictgen::InsensitiveStr::Ascii("mballed"),
        dictgen::InsensitiveStr::Ascii("mballing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GIANTIZE_9114588567776629038)],
        &[(0b10010, &ENTRY_GIANTIZES_12359859620616821617)],
        &[(0b01001, &ENTRY_GIANTIZE_9114588567776629038)],
        &[(0b01001, &ENTRY_GIANTIZES_12359859620616821617)],
        &[(0b00001, &ENTRY_GIMBALED_13438863350515119161)],
        &[(0b00001, &ENTRY_GIMBALING_17481044329427103960)],
        &[(0b11010, &ENTRY_GIMBALED_13438863350515119161)],
        &[(0b11010, &ENTRY_GIMBALING_17481044329427103960)],
    ],
    range: 6..=8,
};

static VARS_GH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GH_CHILDREN),
    value: None,
};

pub static VARS_GH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eber"),
        dictgen::InsensitiveStr::Ascii("ebers"),
        dictgen::InsensitiveStr::Ascii("ebre"),
        dictgen::InsensitiveStr::Ascii("ebres"),
        dictgen::InsensitiveStr::Ascii("ettoisation"),
        dictgen::InsensitiveStr::Ascii("ettoisations"),
        dictgen::InsensitiveStr::Ascii("ettoise"),
        dictgen::InsensitiveStr::Ascii("ettoised"),
        dictgen::InsensitiveStr::Ascii("ettoises"),
        dictgen::InsensitiveStr::Ascii("ettoising"),
        dictgen::InsensitiveStr::Ascii("ettoization"),
        dictgen::InsensitiveStr::Ascii("ettoizations"),
        dictgen::InsensitiveStr::Ascii("ettoize"),
        dictgen::InsensitiveStr::Ascii("ettoized"),
        dictgen::InsensitiveStr::Ascii("ettoizes"),
        dictgen::InsensitiveStr::Ascii("ettoizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GHEBER_4914782193870428634)],
        &[(0b00001, &ENTRY_GHEBERS_8157544588744048409)],
        &[(0b11010, &ENTRY_GHEBER_4914782193870428634)],
        &[(0b11010, &ENTRY_GHEBERS_8157544588744048409)],
        &[(0b10010, &ENTRY_GHETTOIZATION_6096956430126090676)],
        &[(0b10010, &ENTRY_GHETTOIZATIONS_4010150485854957474)],
        &[(0b10010, &ENTRY_GHETTOIZE_8424380127281823491)],
        &[(0b10010, &ENTRY_GHETTOIZED_6310643312381201018)],
        &[(0b10010, &ENTRY_GHETTOIZES_13127566176097583611)],
        &[(0b10010, &ENTRY_GHETTOIZING_12012772692961443803)],
        &[(0b01001, &ENTRY_GHETTOIZATION_6096956430126090676)],
        &[(0b01001, &ENTRY_GHETTOIZATIONS_4010150485854957474)],
        &[(0b01001, &ENTRY_GHETTOIZE_8424380127281823491)],
        &[(0b01001, &ENTRY_GHETTOIZED_6310643312381201018)],
        &[(0b01001, &ENTRY_GHETTOIZES_13127566176097583611)],
        &[(0b01001, &ENTRY_GHETTOIZING_12012772692961443803)],
    ],
    range: 4..=12,
};

static VARS_GE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GE_CHILDREN),
    value: Some(&[
        (0b00001, &ENTRY_GE_12788931716494377180),
        (0b00001, &ENTRY_GE_2544027066948517700),
    ]),
};

static VARS_GE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    Some(&VARS_GED_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GEL_NODE),
    Some(&VARS_GEM_NODE),
    Some(&VARS_GEN_NODE),
    Some(&VARS_GEO_NODE),
    None,
    None,
    Some(&VARS_GER_NODE),
    Some(&VARS_GES_NODE),
    Some(&VARS_GET_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_GEY_NODE),
    None,
];

static VARS_GEY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GEY_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GEY_16134682750611747069)]),
};

pub static VARS_GEY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_GET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GET_CHILDREN),
    value: None,
};

pub static VARS_GET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("z"),
        dictgen::InsensitiveStr::Ascii("zville"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GETAE_1718634175022590867)],
        &[(0b00001, &ENTRY_GETZ_669206341459593812)],
        &[(0b00001, &ENTRY_GETZVILLE_17657251283898385513)],
    ],
    range: 1..=6,
};

static VARS_GES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GES_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GES_7892709255819401837)]),
};

pub static VARS_GES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sed"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("soed"),
        dictgen::InsensitiveStr::Ascii("soes"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GESSED_3943057156251643468)],
        &[(0b00001, &ENTRY_GESSES_9447403161510644444)],
        &[(0b11010, &ENTRY_GESSED_3943057156251643468)],
        &[(0b11010, &ENTRY_GESSES_9447403161510644444)],
        &[(0b11010, &ENTRY_GESTE_7096843185027205462)],
        &[(0b00001, &ENTRY_GESTE_7096843185027205462)],
    ],
    range: 2..=4,
};

static VARS_GER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GER_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GER_10029915357597982133)]),
};

pub static VARS_GER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enuk"),
        dictgen::InsensitiveStr::Ascii("manisation"),
        dictgen::InsensitiveStr::Ascii("manisations"),
        dictgen::InsensitiveStr::Ascii("manise"),
        dictgen::InsensitiveStr::Ascii("manised"),
        dictgen::InsensitiveStr::Ascii("maniser"),
        dictgen::InsensitiveStr::Ascii("manisers"),
        dictgen::InsensitiveStr::Ascii("manises"),
        dictgen::InsensitiveStr::Ascii("manising"),
        dictgen::InsensitiveStr::Ascii("manization"),
        dictgen::InsensitiveStr::Ascii("manizations"),
        dictgen::InsensitiveStr::Ascii("manize"),
        dictgen::InsensitiveStr::Ascii("manized"),
        dictgen::InsensitiveStr::Ascii("manizer"),
        dictgen::InsensitiveStr::Ascii("manizers"),
        dictgen::InsensitiveStr::Ascii("manizes"),
        dictgen::InsensitiveStr::Ascii("manizing"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GERENUK_11123017430709792003)],
        &[(0b10010, &ENTRY_GERMANIZATION_13476131946585281058)],
        &[(0b10010, &ENTRY_GERMANIZATIONS_10792953229272520133)],
        &[(0b10010, &ENTRY_GERMANIZE_7257619738631033318)],
        &[(0b10010, &ENTRY_GERMANIZED_17675668489240602495)],
        &[(0b10010, &ENTRY_GERMANIZER_1963166703182074320)],
        &[(0b10010, &ENTRY_GERMANIZERS_4983145568179588365)],
        &[(0b10010, &ENTRY_GERMANIZES_1350487394674561657)],
        &[(0b10010, &ENTRY_GERMANIZING_10332352803362198758)],
        &[(0b01001, &ENTRY_GERMANIZATION_13476131946585281058)],
        &[(0b01001, &ENTRY_GERMANIZATIONS_10792953229272520133)],
        &[(0b01001, &ENTRY_GERMANIZE_7257619738631033318)],
        &[(0b01001, &ENTRY_GERMANIZED_17675668489240602495)],
        &[(0b01001, &ENTRY_GERMANIZER_1963166703182074320)],
        &[(0b01001, &ENTRY_GERMANIZERS_4983145568179588365)],
        &[(0b01001, &ENTRY_GERMANIZES_1350487394674561657)],
        &[(0b01001, &ENTRY_GERMANIZING_10332352803362198758)],
        &[(0b00001, &ENTRY_GERNE_10723705562317631976)],
        &[(0b00001, &ENTRY_GERS_2810213260239783007)],
    ],
    range: 1..=11,
};

static VARS_GEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GEO_CHILDREN),
    value: None,
};

pub static VARS_GEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daesia"),
        dictgen::InsensitiveStr::Ascii("desia"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logised"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logising"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logized"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("logizing"),
        dictgen::InsensitiveStr::Ascii("metricise"),
        dictgen::InsensitiveStr::Ascii("metricises"),
        dictgen::InsensitiveStr::Ascii("metricize"),
        dictgen::InsensitiveStr::Ascii("metricizes"),
        dictgen::InsensitiveStr::Ascii("metrisation"),
        dictgen::InsensitiveStr::Ascii("metrisations"),
        dictgen::InsensitiveStr::Ascii("metrise"),
        dictgen::InsensitiveStr::Ascii("metrised"),
        dictgen::InsensitiveStr::Ascii("metrises"),
        dictgen::InsensitiveStr::Ascii("metrising"),
        dictgen::InsensitiveStr::Ascii("metrization"),
        dictgen::InsensitiveStr::Ascii("metrizations"),
        dictgen::InsensitiveStr::Ascii("metrize"),
        dictgen::InsensitiveStr::Ascii("metrized"),
        dictgen::InsensitiveStr::Ascii("metrizes"),
        dictgen::InsensitiveStr::Ascii("metrizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GEODESIA_7909094250144256129)],
        &[(0b00001, &ENTRY_GEODESIA_7909094250144256129)],
        &[(0b10010, &ENTRY_GEOLOGIZE_1348394399033582028)],
        &[(0b10010, &ENTRY_GEOLOGIZED_7625975766262838426)],
        &[(0b10010, &ENTRY_GEOLOGIZES_9944756831526943986)],
        &[(0b10010, &ENTRY_GEOLOGIZING_1596141849146660093)],
        &[(0b01001, &ENTRY_GEOLOGIZE_1348394399033582028)],
        &[(0b01001, &ENTRY_GEOLOGIZED_7625975766262838426)],
        &[(0b01001, &ENTRY_GEOLOGIZES_9944756831526943986)],
        &[(0b01001, &ENTRY_GEOLOGIZING_1596141849146660093)],
        &[(0b10010, &ENTRY_GEOMETRICIZE_13223434468003425706)],
        &[(0b10010, &ENTRY_GEOMETRICIZES_10361400394464768294)],
        &[(0b01001, &ENTRY_GEOMETRICIZE_13223434468003425706)],
        &[(0b01001, &ENTRY_GEOMETRICIZES_10361400394464768294)],
        &[(0b10010, &ENTRY_GEOMETRIZATION_1547434209754062568)],
        &[(0b10010, &ENTRY_GEOMETRIZATIONS_5268337436538042853)],
        &[(0b10010, &ENTRY_GEOMETRIZE_16268499732063085651)],
        &[(0b10010, &ENTRY_GEOMETRIZED_2308132544249842146)],
        &[(0b10010, &ENTRY_GEOMETRIZES_1053479766754519420)],
        &[(0b10010, &ENTRY_GEOMETRIZING_16924051865978425252)],
        &[(0b01001, &ENTRY_GEOMETRIZATION_1547434209754062568)],
        &[(0b01001, &ENTRY_GEOMETRIZATIONS_5268337436538042853)],
        &[(0b01001, &ENTRY_GEOMETRIZE_16268499732063085651)],
        &[(0b01001, &ENTRY_GEOMETRIZED_2308132544249842146)],
        &[(0b01001, &ENTRY_GEOMETRIZES_1053479766754519420)],
        &[(0b01001, &ENTRY_GEOMETRIZING_16924051865978425252)],
    ],
    range: 5..=12,
};

static VARS_GEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GEN_CHILDREN),
    value: None,
};

static VARS_GEN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_GENE_NODE),
    None,
    None,
    None,
    Some(&VARS_GENI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GENT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_GENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GENT_CHILDREN),
    value: None,
};

pub static VARS_GENT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eelise"),
        dictgen::InsensitiveStr::Ascii("eelised"),
        dictgen::InsensitiveStr::Ascii("eelises"),
        dictgen::InsensitiveStr::Ascii("eelising"),
        dictgen::InsensitiveStr::Ascii("eelize"),
        dictgen::InsensitiveStr::Ascii("eelized"),
        dictgen::InsensitiveStr::Ascii("eelizes"),
        dictgen::InsensitiveStr::Ascii("eelizing"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
        dictgen::InsensitiveStr::Ascii("lemanise"),
        dictgen::InsensitiveStr::Ascii("lemanises"),
        dictgen::InsensitiveStr::Ascii("lemanize"),
        dictgen::InsensitiveStr::Ascii("lemanizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GENTEELIZE_14522302934582101081)],
        &[(0b10010, &ENTRY_GENTEELIZED_5594609915067062644)],
        &[(0b10010, &ENTRY_GENTEELIZES_5600744917352856646)],
        &[(0b10010, &ENTRY_GENTEELIZING_2357828715581131859)],
        &[(0b01001, &ENTRY_GENTEELIZE_14522302934582101081)],
        &[(0b01001, &ENTRY_GENTEELIZED_5594609915067062644)],
        &[(0b01001, &ENTRY_GENTEELIZES_5600744917352856646)],
        &[(0b01001, &ENTRY_GENTEELIZING_2357828715581131859)],
        &[(0b10010, &ENTRY_GENTILIZATION_3445514503508341831)],
        &[(0b10010, &ENTRY_GENTILIZATIONS_13953898362386713218)],
        &[(0b10010, &ENTRY_GENTILIZE_10418158534488896119)],
        &[(0b10010, &ENTRY_GENTILIZED_1215745904639546573)],
        &[(0b10010, &ENTRY_GENTILIZES_15090273186836336681)],
        &[(0b10010, &ENTRY_GENTILIZING_12868465986545165261)],
        &[(0b01001, &ENTRY_GENTILIZATION_3445514503508341831)],
        &[(0b01001, &ENTRY_GENTILIZATIONS_13953898362386713218)],
        &[(0b01001, &ENTRY_GENTILIZE_10418158534488896119)],
        &[(0b01001, &ENTRY_GENTILIZED_1215745904639546573)],
        &[(0b01001, &ENTRY_GENTILIZES_15090273186836336681)],
        &[(0b01001, &ENTRY_GENTILIZING_12868465986545165261)],
        &[(0b10010, &ENTRY_GENTLEMANIZE_15496358844070377790)],
        &[(0b10010, &ENTRY_GENTLEMANIZES_387005180021803735)],
        &[(0b01001, &ENTRY_GENTLEMANIZE_15496358844070377790)],
        &[(0b01001, &ENTRY_GENTLEMANIZES_387005180021803735)],
    ],
    range: 5..=10,
};

static VARS_GENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GENI_CHILDREN),
    value: None,
};

pub static VARS_GENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GENIALIZE_17059263283369696837)],
        &[(0b10010, &ENTRY_GENIALIZED_324742209355172939)],
        &[(0b10010, &ENTRY_GENIALIZES_12942921211709985866)],
        &[(0b10010, &ENTRY_GENIALIZING_7362104883847556545)],
        &[(0b01001, &ENTRY_GENIALIZE_17059263283369696837)],
        &[(0b01001, &ENTRY_GENIALIZED_324742209355172939)],
        &[(0b01001, &ENTRY_GENIALIZES_12942921211709985866)],
        &[(0b01001, &ENTRY_GENIALIZING_7362104883847556545)],
    ],
    range: 5..=7,
};

static VARS_GENE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GENE_CHILDREN),
    value: None,
};

pub static VARS_GENE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alogise"),
        dictgen::InsensitiveStr::Ascii("alogised"),
        dictgen::InsensitiveStr::Ascii("alogises"),
        dictgen::InsensitiveStr::Ascii("alogising"),
        dictgen::InsensitiveStr::Ascii("alogize"),
        dictgen::InsensitiveStr::Ascii("alogized"),
        dictgen::InsensitiveStr::Ascii("alogizes"),
        dictgen::InsensitiveStr::Ascii("alogizing"),
        dictgen::InsensitiveStr::Ascii("ralisability"),
        dictgen::InsensitiveStr::Ascii("ralisable"),
        dictgen::InsensitiveStr::Ascii("ralisabler"),
        dictgen::InsensitiveStr::Ascii("ralisables"),
        dictgen::InsensitiveStr::Ascii("ralisablest"),
        dictgen::InsensitiveStr::Ascii("ralisation"),
        dictgen::InsensitiveStr::Ascii("ralisational"),
        dictgen::InsensitiveStr::Ascii("ralisations"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralised"),
        dictgen::InsensitiveStr::Ascii("raliser"),
        dictgen::InsensitiveStr::Ascii("ralisers"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralising"),
        dictgen::InsensitiveStr::Ascii("ralizability"),
        dictgen::InsensitiveStr::Ascii("ralizable"),
        dictgen::InsensitiveStr::Ascii("ralizabler"),
        dictgen::InsensitiveStr::Ascii("ralizables"),
        dictgen::InsensitiveStr::Ascii("ralizablest"),
        dictgen::InsensitiveStr::Ascii("ralization"),
        dictgen::InsensitiveStr::Ascii("ralizational"),
        dictgen::InsensitiveStr::Ascii("ralizations"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralized"),
        dictgen::InsensitiveStr::Ascii("ralizer"),
        dictgen::InsensitiveStr::Ascii("ralizers"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ralizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GENEALOGIZE_17112730041204882193)],
        &[(0b10010, &ENTRY_GENEALOGIZED_15135168981468576631)],
        &[(0b10010, &ENTRY_GENEALOGIZES_5856649031077446545)],
        &[(0b10010, &ENTRY_GENEALOGIZING_11925321824699543417)],
        &[(0b01001, &ENTRY_GENEALOGIZE_17112730041204882193)],
        &[(0b01001, &ENTRY_GENEALOGIZED_15135168981468576631)],
        &[(0b01001, &ENTRY_GENEALOGIZES_5856649031077446545)],
        &[(0b01001, &ENTRY_GENEALOGIZING_11925321824699543417)],
        &[(0b10010, &ENTRY_GENERALIZABILITY_9240080688246772673)],
        &[(0b10010, &ENTRY_GENERALIZABLE_3955655563914794831)],
        &[(0b10010, &ENTRY_GENERALIZABLER_8571039159263369925)],
        &[(0b10010, &ENTRY_GENERALIZABLES_5230645008689603385)],
        &[(0b10010, &ENTRY_GENERALIZABLEST_1782032942011166169)],
        &[(0b10010, &ENTRY_GENERALIZATION_8859013031721640663)],
        &[(0b10010, &ENTRY_GENERALIZATIONAL_14098063634295023057)],
        &[(0b10010, &ENTRY_GENERALIZATIONS_1697442498275043901)],
        &[(0b10010, &ENTRY_GENERALIZE_13655318696543936715)],
        &[(0b10010, &ENTRY_GENERALIZED_10792630556248421768)],
        &[(0b10010, &ENTRY_GENERALIZER_4079171119694564254)],
        &[(0b10010, &ENTRY_GENERALIZERS_2408957385743792554)],
        &[(0b10010, &ENTRY_GENERALIZES_3420734890670492638)],
        &[(0b10010, &ENTRY_GENERALIZING_14156289456455119636)],
        &[(0b01001, &ENTRY_GENERALIZABILITY_9240080688246772673)],
        &[(0b01001, &ENTRY_GENERALIZABLE_3955655563914794831)],
        &[(0b01001, &ENTRY_GENERALIZABLER_8571039159263369925)],
        &[(0b01001, &ENTRY_GENERALIZABLES_5230645008689603385)],
        &[(0b01001, &ENTRY_GENERALIZABLEST_1782032942011166169)],
        &[(0b01001, &ENTRY_GENERALIZATION_8859013031721640663)],
        &[(0b01001, &ENTRY_GENERALIZATIONAL_14098063634295023057)],
        &[(0b01001, &ENTRY_GENERALIZATIONS_1697442498275043901)],
        &[(0b01001, &ENTRY_GENERALIZE_13655318696543936715)],
        &[(0b01001, &ENTRY_GENERALIZED_10792630556248421768)],
        &[(0b01001, &ENTRY_GENERALIZER_4079171119694564254)],
        &[(0b01001, &ENTRY_GENERALIZERS_2408957385743792554)],
        &[(0b01001, &ENTRY_GENERALIZES_3420734890670492638)],
        &[(0b01001, &ENTRY_GENERALIZING_14156289456455119636)],
    ],
    range: 6..=12,
};

static VARS_GEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GEM_CHILDREN),
    value: None,
};

pub static VARS_GEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mologies"),
        dictgen::InsensitiveStr::Ascii("mology"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ology"),
    ],
    values: &[
        &[(0b10011, &ENTRY_GEMOLOGIES_213255465904446050)],
        &[(0b10011, &ENTRY_GEMOLOGY_1138665796390032600)],
        &[(0b01001, &ENTRY_GEMOLOGIES_213255465904446050)],
        &[(0b01001, &ENTRY_GEMOLOGY_1138665796390032600)],
    ],
    range: 5..=8,
};

static VARS_GEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GEL_CHILDREN),
    value: None,
};

pub static VARS_GEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atinisabilities"),
        dictgen::InsensitiveStr::Ascii("atinisability"),
        dictgen::InsensitiveStr::Ascii("atinisable"),
        dictgen::InsensitiveStr::Ascii("atinisables"),
        dictgen::InsensitiveStr::Ascii("atinisation"),
        dictgen::InsensitiveStr::Ascii("atinisations"),
        dictgen::InsensitiveStr::Ascii("atinise"),
        dictgen::InsensitiveStr::Ascii("atinised"),
        dictgen::InsensitiveStr::Ascii("atiniser"),
        dictgen::InsensitiveStr::Ascii("atinisers"),
        dictgen::InsensitiveStr::Ascii("atinises"),
        dictgen::InsensitiveStr::Ascii("atinising"),
        dictgen::InsensitiveStr::Ascii("atinizabilities"),
        dictgen::InsensitiveStr::Ascii("atinizability"),
        dictgen::InsensitiveStr::Ascii("atinizable"),
        dictgen::InsensitiveStr::Ascii("atinizables"),
        dictgen::InsensitiveStr::Ascii("atinization"),
        dictgen::InsensitiveStr::Ascii("atinizations"),
        dictgen::InsensitiveStr::Ascii("atinize"),
        dictgen::InsensitiveStr::Ascii("atinized"),
        dictgen::InsensitiveStr::Ascii("atinizer"),
        dictgen::InsensitiveStr::Ascii("atinizers"),
        dictgen::InsensitiveStr::Ascii("atinizes"),
        dictgen::InsensitiveStr::Ascii("atinizing"),
        dictgen::InsensitiveStr::Ascii("ofer"),
        dictgen::InsensitiveStr::Ascii("ofre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GELATINIZABILITIES_748271501802959782)],
        &[(0b10010, &ENTRY_GELATINIZABILITY_11867008106433996321)],
        &[(0b10010, &ENTRY_GELATINIZABLE_6328870207727669555)],
        &[(0b10010, &ENTRY_GELATINIZABLES_8035198156456837735)],
        &[(0b10010, &ENTRY_GELATINIZATION_10324652004562240168)],
        &[(0b10010, &ENTRY_GELATINIZATIONS_16405129470904980935)],
        &[(0b10010, &ENTRY_GELATINIZE_14320678590118078567)],
        &[(0b10010, &ENTRY_GELATINIZED_15612523973238289644)],
        &[(0b10010, &ENTRY_GELATINIZER_16640437269227566274)],
        &[(0b10010, &ENTRY_GELATINIZERS_376307577145206460)],
        &[(0b10010, &ENTRY_GELATINIZES_1595883472582938174)],
        &[(0b10010, &ENTRY_GELATINIZING_11893129576765756087)],
        &[(0b01001, &ENTRY_GELATINIZABILITIES_748271501802959782)],
        &[(0b01001, &ENTRY_GELATINIZABILITY_11867008106433996321)],
        &[(0b01001, &ENTRY_GELATINIZABLE_6328870207727669555)],
        &[(0b01001, &ENTRY_GELATINIZABLES_8035198156456837735)],
        &[(0b01001, &ENTRY_GELATINIZATION_10324652004562240168)],
        &[(0b01001, &ENTRY_GELATINIZATIONS_16405129470904980935)],
        &[(0b01001, &ENTRY_GELATINIZE_14320678590118078567)],
        &[(0b01001, &ENTRY_GELATINIZED_15612523973238289644)],
        &[(0b01001, &ENTRY_GELATINIZER_16640437269227566274)],
        &[(0b01001, &ENTRY_GELATINIZERS_376307577145206460)],
        &[(0b01001, &ENTRY_GELATINIZES_1595883472582938174)],
        &[(0b01001, &ENTRY_GELATINIZING_11893129576765756087)],
        &[(0b00001, &ENTRY_GELOFER_13059100954606393660)],
        &[(0b11010, &ENTRY_GELOFER_13059100954606393660)],
    ],
    range: 4..=15,
};

static VARS_GED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GED_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_GED_14965506371479666929)]),
};

pub static VARS_GED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_GA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_GA_CHILDREN),
    value: None,
};

static VARS_GA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_GAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_GAL_NODE),
    Some(&VARS_GAM_NODE),
    None,
    Some(&VARS_GAO_NODE),
    None,
    None,
    Some(&VARS_GAR_NODE),
    Some(&VARS_GAS_NODE),
    None,
    Some(&VARS_GAU_NODE),
    Some(&VARS_GAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_GAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAV_CHILDREN),
    value: None,
};

pub static VARS_GAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("elling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GAVELED_9330937849179337117)],
        &[(0b00001, &ENTRY_GAVELER_7497808590664149917)],
        &[(0b00001, &ENTRY_GAVELING_8183429774339518895)],
        &[(0b11010, &ENTRY_GAVELED_9330937849179337117)],
        &[(0b11010, &ENTRY_GAVELER_7497808590664149917)],
        &[(0b11010, &ENTRY_GAVELING_8183429774339518895)],
    ],
    range: 4..=6,
};

static VARS_GAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAU_CHILDREN),
    value: None,
};

pub static VARS_GAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fer"),
        dictgen::InsensitiveStr::Ascii("fers"),
        dictgen::InsensitiveStr::Ascii("ffer"),
        dictgen::InsensitiveStr::Ascii("ffre"),
        dictgen::InsensitiveStr::Ascii("fre"),
        dictgen::InsensitiveStr::Ascii("fres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GAUFER_8821271674575489008)],
        &[(0b00001, &ENTRY_GAUFERS_8535552125608729352)],
        &[(0b00001, &ENTRY_GAUFFER_971344940707830760)],
        &[(0b11010, &ENTRY_GAUFFER_971344940707830760)],
        &[(0b11010, &ENTRY_GAUFER_8821271674575489008)],
        &[(0b11010, &ENTRY_GAUFERS_8535552125608729352)],
    ],
    range: 3..=4,
};

static VARS_GAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAS_CHILDREN),
    value: None,
};

pub static VARS_GAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olene"),
        dictgen::InsensitiveStr::Ascii("olenes"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("traea"),
        dictgen::InsensitiveStr::Ascii("traeas"),
        dictgen::InsensitiveStr::Ascii("trea"),
        dictgen::InsensitiveStr::Ascii("treas"),
        dictgen::InsensitiveStr::Ascii("trocele"),
        dictgen::InsensitiveStr::Ascii("trocoele"),
    ],
    values: &[
        &[(0b10011, &ENTRY_GASOLINE_9743796479901328135)],
        &[(0b10011, &ENTRY_GASOLINES_15626523562905232226)],
        &[(0b00001, &ENTRY_GASES_7393603411853163261)],
        &[(0b11010, &ENTRY_GASTREA_17996449355628413865)],
        &[(0b11010, &ENTRY_GASTREAS_1400735590131613456)],
        &[(0b00001, &ENTRY_GASTREA_17996449355628413865)],
        &[(0b00001, &ENTRY_GASTREAS_1400735590131613456)],
        &[(0b00001, &ENTRY_GASTROCELE_17796500068789968080)],
        &[(0b11010, &ENTRY_GASTROCELE_17796500068789968080)],
    ],
    range: 3..=8,
};

static VARS_GAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAR_CHILDREN),
    value: None,
};

pub static VARS_GAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("garise"),
        dictgen::InsensitiveStr::Ascii("garised"),
        dictgen::InsensitiveStr::Ascii("garises"),
        dictgen::InsensitiveStr::Ascii("garising"),
        dictgen::InsensitiveStr::Ascii("garize"),
        dictgen::InsensitiveStr::Ascii("garized"),
        dictgen::InsensitiveStr::Ascii("garizes"),
        dictgen::InsensitiveStr::Ascii("garizing"),
        dictgen::InsensitiveStr::Ascii("rulinae"),
        dictgen::InsensitiveStr::Ascii("ruline"),
    ],
    values: &[
        &[(0b10010, &ENTRY_GARGARIZE_17950177829492366541)],
        &[(0b10010, &ENTRY_GARGARIZED_7909042564689432197)],
        &[(0b10010, &ENTRY_GARGARIZES_1914026990505406207)],
        &[(0b10010, &ENTRY_GARGARIZING_2729312478798944101)],
        &[(0b01001, &ENTRY_GARGARIZE_17950177829492366541)],
        &[(0b01001, &ENTRY_GARGARIZED_7909042564689432197)],
        &[(0b01001, &ENTRY_GARGARIZES_1914026990505406207)],
        &[(0b01001, &ENTRY_GARGARIZING_2729312478798944101)],
        &[(0b11010, &ENTRY_GARRULINE_2763058909710775755)],
        &[(0b00001, &ENTRY_GARRULINE_2763058909710775755)],
    ],
    range: 6..=8,
};

static VARS_GAO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAO_CHILDREN),
    value: None,
};

pub static VARS_GAO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("l"),
        dictgen::InsensitiveStr::Ascii("lbird"),
        dictgen::InsensitiveStr::Ascii("lbirds"),
        dictgen::InsensitiveStr::Ascii("lbreak"),
        dictgen::InsensitiveStr::Ascii("lbreaks"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("ls"),
    ],
    values: &[
        &[(0b11010, &ENTRY_JAIL_4946485521529004110)],
        &[(0b11010, &ENTRY_JAILBIRD_1273591597781321313)],
        &[(0b11010, &ENTRY_JAILBIRDS_10419139708074863941)],
        &[(0b11010, &ENTRY_JAILBREAK_12440650553847734510)],
        &[(0b11010, &ENTRY_JAILBREAKS_14725005275090937373)],
        &[(0b11010, &ENTRY_JAILED_10386460292544209566)],
        &[(0b10010, &ENTRY_JAILER_1369890010036246012)],
        &[(0b10010, &ENTRY_JAILERS_2346423461770093206)],
        &[(0b11010, &ENTRY_JAILING_12075029104559606493)],
        &[(0b11010, &ENTRY_JAILS_1981100286375396548)],
    ],
    range: 1..=7,
};

static VARS_GAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAM_CHILDREN),
    value: None,
};

pub static VARS_GAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bades"),
        dictgen::InsensitiveStr::Ascii("badoes"),
        dictgen::InsensitiveStr::Ascii("boled"),
        dictgen::InsensitiveStr::Ascii("boling"),
        dictgen::InsensitiveStr::Ascii("bolled"),
        dictgen::InsensitiveStr::Ascii("bolling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_GAMBADES_5475546338206383518)],
        &[(0b11010, &ENTRY_GAMBADES_5475546338206383518)],
        &[(0b00001, &ENTRY_GAMBOLED_11853362628222994576)],
        &[(0b00001, &ENTRY_GAMBOLING_10784908367530707096)],
        &[(0b11010, &ENTRY_GAMBOLED_11853362628222994576)],
        &[(0b11010, &ENTRY_GAMBOLING_10784908367530707096)],
    ],
    range: 5..=7,
};

static VARS_GAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAL_CHILDREN),
    value: None,
};

pub static VARS_GAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("actorrhea"),
        dictgen::InsensitiveStr::Ascii("actorrheas"),
        dictgen::InsensitiveStr::Ascii("actorrhoea"),
        dictgen::InsensitiveStr::Ascii("actorrhoeas"),
        dictgen::InsensitiveStr::Ascii("actosaemia"),
        dictgen::InsensitiveStr::Ascii("actosaemias"),
        dictgen::InsensitiveStr::Ascii("actosemia"),
        dictgen::InsensitiveStr::Ascii("actosemias"),
        dictgen::InsensitiveStr::Ascii("eae"),
        dictgen::InsensitiveStr::Ascii("ee"),
        dictgen::InsensitiveStr::Ascii("lantise"),
        dictgen::InsensitiveStr::Ascii("lantises"),
        dictgen::InsensitiveStr::Ascii("lantize"),
        dictgen::InsensitiveStr::Ascii("lantizes"),
        dictgen::InsensitiveStr::Ascii("liardise"),
        dictgen::InsensitiveStr::Ascii("liardize"),
        dictgen::InsensitiveStr::Ascii("licisation"),
        dictgen::InsensitiveStr::Ascii("licisations"),
        dictgen::InsensitiveStr::Ascii("licise"),
        dictgen::InsensitiveStr::Ascii("licised"),
        dictgen::InsensitiveStr::Ascii("liciser"),
        dictgen::InsensitiveStr::Ascii("licises"),
        dictgen::InsensitiveStr::Ascii("licising"),
        dictgen::InsensitiveStr::Ascii("licization"),
        dictgen::InsensitiveStr::Ascii("licizations"),
        dictgen::InsensitiveStr::Ascii("licize"),
        dictgen::InsensitiveStr::Ascii("licized"),
        dictgen::InsensitiveStr::Ascii("licizer"),
        dictgen::InsensitiveStr::Ascii("licizes"),
        dictgen::InsensitiveStr::Ascii("licizing"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lisise"),
        dictgen::InsensitiveStr::Ascii("lisised"),
        dictgen::InsensitiveStr::Ascii("lisises"),
        dictgen::InsensitiveStr::Ascii("lisising"),
        dictgen::InsensitiveStr::Ascii("lisize"),
        dictgen::InsensitiveStr::Ascii("lisized"),
        dictgen::InsensitiveStr::Ascii("lisizes"),
        dictgen::InsensitiveStr::Ascii("lisizing"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
        dictgen::InsensitiveStr::Ascii("vanisation"),
        dictgen::InsensitiveStr::Ascii("vanisations"),
        dictgen::InsensitiveStr::Ascii("vanise"),
        dictgen::InsensitiveStr::Ascii("vanised"),
        dictgen::InsensitiveStr::Ascii("vaniser"),
        dictgen::InsensitiveStr::Ascii("vanisers"),
        dictgen::InsensitiveStr::Ascii("vanises"),
        dictgen::InsensitiveStr::Ascii("vanising"),
        dictgen::InsensitiveStr::Ascii("vanization"),
        dictgen::InsensitiveStr::Ascii("vanizations"),
        dictgen::InsensitiveStr::Ascii("vanize"),
        dictgen::InsensitiveStr::Ascii("vanized"),
        dictgen::InsensitiveStr::Ascii("vanizer"),
        dictgen::InsensitiveStr::Ascii("vanizers"),
        dictgen::InsensitiveStr::Ascii("vanizes"),
        dictgen::InsensitiveStr::Ascii("vanizing"),
    ],
    values: &[
        &[(0b10001, &ENTRY_GALACTORRHEA_8939201946132666128)],
        &[(0b10001, &ENTRY_GALACTORRHEAS_2348752207273598936)],
        &[(0b11010, &ENTRY_GALACTORRHEA_8939201946132666128)],
        &[(0b11010, &ENTRY_GALACTORRHEAS_2348752207273598936)],
        &[(0b11010, &ENTRY_GALACTOSEMIA_15356026729538488621)],
        &[(0b11010, &ENTRY_GALACTOSEMIAS_2689872380032083965)],
        &[(0b10001, &ENTRY_GALACTOSEMIA_15356026729538488621)],
        &[(0b10001, &ENTRY_GALACTOSEMIAS_2689872380032083965)],
        &[(0b11010, &ENTRY_GALEE_18295229614385569377)],
        &[(0b00001, &ENTRY_GALEE_18295229614385569377)],
        &[(0b10010, &ENTRY_GALLANTIZE_7623840749699418706)],
        &[(0b10010, &ENTRY_GALLANTIZES_4128021680900042331)],
        &[(0b01001, &ENTRY_GALLANTIZE_7623840749699418706)],
        &[(0b01001, &ENTRY_GALLANTIZES_4128021680900042331)],
        &[(0b10010, &ENTRY_GALLIARDIZE_10773583765831320043)],
        &[(0b01001, &ENTRY_GALLIARDIZE_10773583765831320043)],
        &[(0b10010, &ENTRY_GALLICIZATION_7390977763303794298)],
        &[(0b10010, &ENTRY_GALLICIZATIONS_12711889075161842819)],
        &[(0b10010, &ENTRY_GALLICIZE_5782054308440267768)],
        &[(0b10010, &ENTRY_GALLICIZED_2318131892486296201)],
        &[(0b10010, &ENTRY_GALLICIZER_6758989856264558701)],
        &[(0b10010, &ENTRY_GALLICIZES_10712473299204337290)],
        &[(0b10010, &ENTRY_GALLICIZING_8856226220615441726)],
        &[(0b01001, &ENTRY_GALLICIZATION_7390977763303794298)],
        &[(0b01001, &ENTRY_GALLICIZATIONS_12711889075161842819)],
        &[(0b01001, &ENTRY_GALLICIZE_5782054308440267768)],
        &[(0b01001, &ENTRY_GALLICIZED_2318131892486296201)],
        &[(0b01001, &ENTRY_GALLICIZER_6758989856264558701)],
        &[(0b01001, &ENTRY_GALLICIZES_10712473299204337290)],
        &[(0b01001, &ENTRY_GALLICIZING_8856226220615441726)],
        &[(0b10010, &ENTRY_GALLIZE_13402144085043483688)],
        &[(0b10010, &ENTRY_GALLIZED_7598224524799520474)],
        &[(0b10010, &ENTRY_GALLIZES_5299390371661987813)],
        &[(0b10010, &ENTRY_GALLIZING_18199311276947490914)],
        &[(0b10010, &ENTRY_GALLISIZE_7892805864302635869)],
        &[(0b10010, &ENTRY_GALLISIZED_16338847595067555930)],
        &[(0b10010, &ENTRY_GALLISIZES_10805104078374630074)],
        &[(0b10010, &ENTRY_GALLISIZING_11425765967668875369)],
        &[(0b01001, &ENTRY_GALLISIZE_7892805864302635869)],
        &[(0b01001, &ENTRY_GALLISIZED_16338847595067555930)],
        &[(0b01001, &ENTRY_GALLISIZES_10805104078374630074)],
        &[(0b01001, &ENTRY_GALLISIZING_11425765967668875369)],
        &[(0b01001, &ENTRY_GALLIZE_13402144085043483688)],
        &[(0b01001, &ENTRY_GALLIZED_7598224524799520474)],
        &[(0b01001, &ENTRY_GALLIZES_5299390371661987813)],
        &[(0b01001, &ENTRY_GALLIZING_18199311276947490914)],
        &[(0b10010, &ENTRY_GALVANIZATION_5356855464894954705)],
        &[(0b10010, &ENTRY_GALVANIZATIONS_16208569109815481187)],
        &[(0b10010, &ENTRY_GALVANIZE_19760109166282156)],
        &[(0b10010, &ENTRY_GALVANIZED_7283862664171222860)],
        &[(0b10010, &ENTRY_GALVANIZER_1389412242269095024)],
        &[(0b10010, &ENTRY_GALVANIZERS_9514387945647000415)],
        &[(0b10010, &ENTRY_GALVANIZES_1489880893900166762)],
        &[(0b10010, &ENTRY_GALVANIZING_12147310365523234397)],
        &[(0b01001, &ENTRY_GALVANIZATION_5356855464894954705)],
        &[(0b01001, &ENTRY_GALVANIZATIONS_16208569109815481187)],
        &[(0b01001, &ENTRY_GALVANIZE_19760109166282156)],
        &[(0b01001, &ENTRY_GALVANIZED_7283862664171222860)],
        &[(0b01001, &ENTRY_GALVANIZER_1389412242269095024)],
        &[(0b01001, &ENTRY_GALVANIZERS_9514387945647000415)],
        &[(0b01001, &ENTRY_GALVANIZES_1489880893900166762)],
        &[(0b01001, &ENTRY_GALVANIZING_12147310365523234397)],
    ],
    range: 2..=11,
};

static VARS_GAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_GAE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_GE_12788931716494377180)]),
};

pub static VARS_GAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("licisation"),
        dictgen::InsensitiveStr::Ascii("licisations"),
        dictgen::InsensitiveStr::Ascii("licise"),
        dictgen::InsensitiveStr::Ascii("licised"),
        dictgen::InsensitiveStr::Ascii("licises"),
        dictgen::InsensitiveStr::Ascii("licising"),
        dictgen::InsensitiveStr::Ascii("licization"),
        dictgen::InsensitiveStr::Ascii("licizations"),
        dictgen::InsensitiveStr::Ascii("licize"),
        dictgen::InsensitiveStr::Ascii("licized"),
        dictgen::InsensitiveStr::Ascii("licizes"),
        dictgen::InsensitiveStr::Ascii("licizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_GED_14965506371479666929)],
        &[(0b10010, &ENTRY_GAELICIZATION_8229079546606253770)],
        &[(0b10010, &ENTRY_GAELICIZATIONS_10913123988645786103)],
        &[(0b10010, &ENTRY_GAELICIZE_13150850139207150741)],
        &[(0b10010, &ENTRY_GAELICIZED_9134821684445081472)],
        &[(0b10010, &ENTRY_GAELICIZES_5628051894918807993)],
        &[(0b10010, &ENTRY_GAELICIZING_4239545936064142475)],
        &[(0b01001, &ENTRY_GAELICIZATION_8229079546606253770)],
        &[(0b01001, &ENTRY_GAELICIZATIONS_10913123988645786103)],
        &[(0b01001, &ENTRY_GAELICIZE_13150850139207150741)],
        &[(0b01001, &ENTRY_GAELICIZED_9134821684445081472)],
        &[(0b01001, &ENTRY_GAELICIZES_5628051894918807993)],
        &[(0b01001, &ENTRY_GAELICIZING_4239545936064142475)],
    ],
    range: 1..=11,
};

static VARS_F_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_F_CHILDREN),
    value: None,
};

static VARS_F_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_FA_NODE),
    None,
    None,
    None,
    Some(&VARS_FE_NODE),
    None,
    None,
    None,
    Some(&VARS_FI_NODE),
    None,
    None,
    Some(&VARS_FL_NODE),
    None,
    None,
    Some(&VARS_FO_NODE),
    None,
    None,
    Some(&VARS_FR_NODE),
    None,
    None,
    Some(&VARS_FU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FU_CHILDREN),
    value: None,
};

static VARS_FU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_FUE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FUL_NODE),
    None,
    Some(&VARS_FUN_NODE),
    None,
    None,
    None,
    Some(&VARS_FUR_NODE),
    Some(&VARS_FUS_NODE),
    Some(&VARS_FUT_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FUZ_NODE),
];

static VARS_FUZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUZ_CHILDREN),
    value: None,
};

pub static VARS_FUZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("ing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_FUSE_893930905974771271)],
        &[(0b01001, &ENTRY_FUSED_1257081415466555403)],
        &[(0b01001, &ENTRY_FUSES_9497075982077327392)],
        &[(0b01001, &ENTRY_FUSING_5104655535944150194)],
    ],
    range: 1..=3,
};

static VARS_FUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUT_CHILDREN),
    value: None,
};

pub static VARS_FUT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FUTILIZE_12137872016940583123)],
        &[(0b10010, &ENTRY_FUTILIZES_10238957534551686752)],
        &[(0b01001, &ENTRY_FUTILIZE_12137872016940583123)],
        &[(0b01001, &ENTRY_FUTILIZES_10238957534551686752)],
        &[(0b10010, &ENTRY_FUTURIZE_7365851347469569206)],
        &[(0b10010, &ENTRY_FUTURIZES_17164339410840070834)],
        &[(0b01001, &ENTRY_FUTURIZE_7365851347469569206)],
        &[(0b01001, &ENTRY_FUTURIZES_17164339410840070834)],
    ],
    range: 5..=6,
};

static VARS_FUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUS_CHILDREN),
    value: None,
};

pub static VARS_FUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tianise"),
        dictgen::InsensitiveStr::Ascii("tianised"),
        dictgen::InsensitiveStr::Ascii("tianises"),
        dictgen::InsensitiveStr::Ascii("tianising"),
        dictgen::InsensitiveStr::Ascii("tianize"),
        dictgen::InsensitiveStr::Ascii("tianized"),
        dictgen::InsensitiveStr::Ascii("tianizes"),
        dictgen::InsensitiveStr::Ascii("tianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FUSTIANIZE_10532729281019581804)],
        &[(0b10010, &ENTRY_FUSTIANIZED_9552600907569960981)],
        &[(0b10010, &ENTRY_FUSTIANIZES_8593570763530200647)],
        &[(0b10010, &ENTRY_FUSTIANIZING_51176411829303510)],
        &[(0b01001, &ENTRY_FUSTIANIZE_10532729281019581804)],
        &[(0b01001, &ENTRY_FUSTIANIZED_9552600907569960981)],
        &[(0b01001, &ENTRY_FUSTIANIZES_8593570763530200647)],
        &[(0b01001, &ENTRY_FUSTIANIZING_51176411829303510)],
    ],
    range: 7..=9,
};

static VARS_FUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUR_CHILDREN),
    value: None,
};

pub static VARS_FUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("culae"),
        dictgen::InsensitiveStr::Ascii("cule"),
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("ie"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ore"),
        dictgen::InsensitiveStr::Ascii("ores"),
        dictgen::InsensitiveStr::Ascii("ors"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FURCULE_1236868035751287961)],
        &[(0b00001, &ENTRY_FURCULE_1236868035751287961)],
        &[(0b11010, &ENTRY_FURIE_8435947989235934110)],
        &[(0b00001, &ENTRY_FURIE_8435947989235934110)],
        &[(0b11001, &ENTRY_FUROR_15595174347085500171)],
        &[(0b10010, &ENTRY_FUROR_15595174347085500171)],
        &[(0b10010, &ENTRY_FURORS_10433443116205259945)],
        &[(0b11001, &ENTRY_FURORS_10433443116205259945)],
    ],
    range: 2..=5,
};

static VARS_FUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUN_CHILDREN),
    value: None,
};

pub static VARS_FUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctionalise"),
        dictgen::InsensitiveStr::Ascii("ctionalises"),
        dictgen::InsensitiveStr::Ascii("ctionalize"),
        dictgen::InsensitiveStr::Ascii("ctionalizes"),
        dictgen::InsensitiveStr::Ascii("ctionise"),
        dictgen::InsensitiveStr::Ascii("ctionises"),
        dictgen::InsensitiveStr::Ascii("ctionize"),
        dictgen::InsensitiveStr::Ascii("ctionizes"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("neled"),
        dictgen::InsensitiveStr::Ascii("neler"),
        dictgen::InsensitiveStr::Ascii("neling"),
        dictgen::InsensitiveStr::Ascii("nelled"),
        dictgen::InsensitiveStr::Ascii("neller"),
        dictgen::InsensitiveStr::Ascii("nelling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FUNCTIONALIZE_5343336178576091473)],
        &[(0b10010, &ENTRY_FUNCTIONALIZES_6846988132021502765)],
        &[(0b01001, &ENTRY_FUNCTIONALIZE_5343336178576091473)],
        &[(0b01001, &ENTRY_FUNCTIONALIZES_6846988132021502765)],
        &[(0b10010, &ENTRY_FUNCTIONIZE_14138434827093737545)],
        &[(0b10010, &ENTRY_FUNCTIONIZES_2783436360735686441)],
        &[(0b01001, &ENTRY_FUNCTIONIZE_14138434827093737545)],
        &[(0b01001, &ENTRY_FUNCTIONIZES_2783436360735686441)],
        &[(0b10010, &ENTRY_FUNERALIZE_16393341863187882210)],
        &[(0b10010, &ENTRY_FUNERALIZES_17860739737691518434)],
        &[(0b01001, &ENTRY_FUNERALIZE_16393341863187882210)],
        &[(0b01001, &ENTRY_FUNERALIZES_17860739737691518434)],
        &[(0b00001, &ENTRY_FUNNELED_5447998884730678168)],
        &[(0b00001, &ENTRY_FUNNELER_2628031221069632410)],
        &[(0b00001, &ENTRY_FUNNELING_7298662514265886848)],
        &[(0b11010, &ENTRY_FUNNELED_5447998884730678168)],
        &[(0b11010, &ENTRY_FUNNELER_2628031221069632410)],
        &[(0b11010, &ENTRY_FUNNELING_7298662514265886848)],
    ],
    range: 5..=11,
};

static VARS_FUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUL_CHILDREN),
    value: None,
};

pub static VARS_FUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fil"),
        dictgen::InsensitiveStr::Ascii("fill"),
        dictgen::InsensitiveStr::Ascii("fillment"),
        dictgen::InsensitiveStr::Ascii("fillments"),
        dictgen::InsensitiveStr::Ascii("fills"),
        dictgen::InsensitiveStr::Ascii("filment"),
        dictgen::InsensitiveStr::Ascii("filments"),
        dictgen::InsensitiveStr::Ascii("fils"),
        dictgen::InsensitiveStr::Ascii("gor"),
        dictgen::InsensitiveStr::Ascii("gorous"),
        dictgen::InsensitiveStr::Ascii("gors"),
        dictgen::InsensitiveStr::Ascii("gour"),
        dictgen::InsensitiveStr::Ascii("gourous"),
        dictgen::InsensitiveStr::Ascii("gours"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FULFILL_18191138303913847238)],
        &[(0b11001, &ENTRY_FULFILL_18191138303913847238)],
        &[(0b01001, &ENTRY_FULFILLMENT_1403777125945191804)],
        &[(0b01001, &ENTRY_FULFILLMENTS_6744331514311877547)],
        &[(0b11001, &ENTRY_FULFILLS_6573936474908938280)],
        &[(0b11010, &ENTRY_FULFILLMENT_1403777125945191804)],
        &[(0b11010, &ENTRY_FULFILLMENTS_6744331514311877547)],
        &[(0b11010, &ENTRY_FULFILLS_6573936474908938280)],
        &[(0b00001, &ENTRY_FULGOR_15723323666395416985)],
        &[(0b00001, &ENTRY_FULGOROUS_16556587498459255650)],
        &[(0b00001, &ENTRY_FULGORS_5277629573271194326)],
        &[(0b11010, &ENTRY_FULGOR_15723323666395416985)],
        &[(0b11010, &ENTRY_FULGOROUS_16556587498459255650)],
        &[(0b11010, &ENTRY_FULGORS_5277629573271194326)],
    ],
    range: 3..=9,
};

static VARS_FUE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FUE_CHILDREN),
    value: None,
};

pub static VARS_FUE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FUELED_17965004435497699778)],
        &[(0b00001, &ENTRY_FUELER_6832234238493701204)],
        &[(0b00001, &ENTRY_FUELERS_1336950632325652930)],
        &[(0b00001, &ENTRY_FUELING_16451678036489651807)],
        &[(0b10010, &ENTRY_FUELIZER_13619298163080844334)],
        &[(0b10010, &ENTRY_FUELIZERS_9948040613184527499)],
        &[(0b01001, &ENTRY_FUELIZER_13619298163080844334)],
        &[(0b01001, &ENTRY_FUELIZERS_9948040613184527499)],
        &[(0b11010, &ENTRY_FUELED_17965004435497699778)],
        &[(0b11010, &ENTRY_FUELER_6832234238493701204)],
        &[(0b11010, &ENTRY_FUELERS_1336950632325652930)],
        &[(0b11010, &ENTRY_FUELING_16451678036489651807)],
    ],
    range: 3..=6,
};

static VARS_FR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FR_CHILDREN),
    value: None,
};

static VARS_FR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_FRA_NODE),
    None,
    None,
    None,
    Some(&VARS_FRE_NODE),
    None,
    None,
    None,
    Some(&VARS_FRI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_FRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRI_CHILDREN),
    value: None,
};

pub static VARS_FRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("borg"),
        dictgen::InsensitiveStr::Ascii("bourg"),
        dictgen::InsensitiveStr::Ascii("ctionise"),
        dictgen::InsensitiveStr::Ascii("ctionises"),
        dictgen::InsensitiveStr::Ascii("ctionize"),
        dictgen::InsensitiveStr::Ascii("ctionizes"),
        dictgen::InsensitiveStr::Ascii("sado"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sette"),
        dictgen::InsensitiveStr::Ascii("settes"),
        dictgen::InsensitiveStr::Ascii("voled"),
        dictgen::InsensitiveStr::Ascii("voler"),
        dictgen::InsensitiveStr::Ascii("volers"),
        dictgen::InsensitiveStr::Ascii("voling"),
        dictgen::InsensitiveStr::Ascii("volled"),
        dictgen::InsensitiveStr::Ascii("voller"),
        dictgen::InsensitiveStr::Ascii("vollers"),
        dictgen::InsensitiveStr::Ascii("volling"),
        dictgen::InsensitiveStr::Ascii("zado"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zette"),
        dictgen::InsensitiveStr::Ascii("zettes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FRIBORG_4949505244575953624)],
        &[(0b11010, &ENTRY_FRIBORG_4949505244575953624)],
        &[(0b10010, &ENTRY_FRICTIONIZE_8871056937955154076)],
        &[(0b10010, &ENTRY_FRICTIONIZES_13547838814049221356)],
        &[(0b01001, &ENTRY_FRICTIONIZE_8871056937955154076)],
        &[(0b01001, &ENTRY_FRICTIONIZES_13547838814049221356)],
        &[(0b10010, &ENTRY_FRIZADO_2372790959778652776)],
        &[(0b10010, &ENTRY_FRIZE_5835366874549032177)],
        &[(0b10010, &ENTRY_FRIZETTE_15044855804093147853)],
        &[(0b10010, &ENTRY_FRIZETTES_11347760157442901920)],
        &[(0b00001, &ENTRY_FRIVOLED_6394892650858522123)],
        &[(0b00001, &ENTRY_FRIVOLER_2732794850565415627)],
        &[(0b00001, &ENTRY_FRIVOLERS_6222087214473089062)],
        &[(0b00001, &ENTRY_FRIVOLING_18278706907289454096)],
        &[(0b11010, &ENTRY_FRIVOLED_6394892650858522123)],
        &[(0b11010, &ENTRY_FRIVOLER_2732794850565415627)],
        &[(0b11010, &ENTRY_FRIVOLERS_6222087214473089062)],
        &[(0b11010, &ENTRY_FRIVOLING_18278706907289454096)],
        &[(0b01001, &ENTRY_FRIZADO_2372790959778652776)],
        &[(0b01001, &ENTRY_FRIZE_5835366874549032177)],
        &[(0b01001, &ENTRY_FRIZETTE_15044855804093147853)],
        &[(0b01001, &ENTRY_FRIZETTES_11347760157442901920)],
    ],
    range: 2..=9,
};

static VARS_FRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRE_CHILDREN),
    value: None,
};

pub static VARS_FRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ity"),
        dictgen::InsensitiveStr::Ascii("na"),
        dictgen::InsensitiveStr::Ascii("nchise"),
        dictgen::InsensitiveStr::Ascii("nchises"),
        dictgen::InsensitiveStr::Ascii("nchize"),
        dictgen::InsensitiveStr::Ascii("nchizes"),
        dictgen::InsensitiveStr::Ascii("neau"),
        dictgen::InsensitiveStr::Ascii("nula"),
        dictgen::InsensitiveStr::Ascii("nular"),
        dictgen::InsensitiveStr::Ascii("nulum"),
        dictgen::InsensitiveStr::Ascii("num"),
        dictgen::InsensitiveStr::Ascii("nums"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FERD_17290726529250186020)],
        &[(0b11010, &ENTRY_FERITY_4632811736178249944)],
        &[(0b00001, &ENTRY_FRENA_5299955759546711915)],
        &[(0b10010, &ENTRY_FRENCHIZE_9878626967854112935)],
        &[(0b10010, &ENTRY_FRENCHIZES_8275972422395013693)],
        &[(0b01001, &ENTRY_FRENCHIZE_9878626967854112935)],
        &[(0b01001, &ENTRY_FRENCHIZES_8275972422395013693)],
        &[(0b11010, &ENTRY_FERNEAU_10155755211254630197)],
        &[(0b00001, &ENTRY_FRENULA_10450628952852883483)],
        &[(0b00001, &ENTRY_FRENULAR_17354217019987840503)],
        &[(0b00001, &ENTRY_FRENULUM_8351124618829742055)],
        &[(0b00001, &ENTRY_FRENUM_7603649563431435410)],
        &[(0b00001, &ENTRY_FRENUMS_7693321222408886713)],
    ],
    range: 1..=7,
};

static VARS_FRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FRA_CHILDREN),
    value: None,
};

static VARS_FRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_FRAC_NODE),
    None,
    Some(&VARS_FRAE_NODE),
    None,
    Some(&VARS_FRAG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FRAM_NODE),
    Some(&VARS_FRAN_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FRAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_FRAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAT_CHILDREN),
    value: None,
};

pub static VARS_FRAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernisation"),
        dictgen::InsensitiveStr::Ascii("ernisations"),
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernised"),
        dictgen::InsensitiveStr::Ascii("erniser"),
        dictgen::InsensitiveStr::Ascii("ernisers"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernising"),
        dictgen::InsensitiveStr::Ascii("ernization"),
        dictgen::InsensitiveStr::Ascii("ernizations"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernized"),
        dictgen::InsensitiveStr::Ascii("ernizer"),
        dictgen::InsensitiveStr::Ascii("ernizers"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
        dictgen::InsensitiveStr::Ascii("ernizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FRATERNIZATION_12516017912114447659)],
        &[(0b10010, &ENTRY_FRATERNIZATIONS_14137130464047726144)],
        &[(0b10010, &ENTRY_FRATERNIZE_10028051674996391984)],
        &[(0b10010, &ENTRY_FRATERNIZED_17667910852812961677)],
        &[(0b10010, &ENTRY_FRATERNIZER_11810525370100192642)],
        &[(0b10010, &ENTRY_FRATERNIZERS_1812552429137645817)],
        &[(0b10010, &ENTRY_FRATERNIZES_13101824246485565774)],
        &[(0b10010, &ENTRY_FRATERNIZING_15346620157919397341)],
        &[(0b01001, &ENTRY_FRATERNIZATION_12516017912114447659)],
        &[(0b01001, &ENTRY_FRATERNIZATIONS_14137130464047726144)],
        &[(0b01001, &ENTRY_FRATERNIZE_10028051674996391984)],
        &[(0b01001, &ENTRY_FRATERNIZED_17667910852812961677)],
        &[(0b01001, &ENTRY_FRATERNIZER_11810525370100192642)],
        &[(0b01001, &ENTRY_FRATERNIZERS_1812552429137645817)],
        &[(0b01001, &ENTRY_FRATERNIZES_13101824246485565774)],
        &[(0b01001, &ENTRY_FRATERNIZING_15346620157919397341)],
    ],
    range: 6..=11,
};

static VARS_FRAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAN_CHILDREN),
    value: None,
};

pub static VARS_FRAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cise"),
        dictgen::InsensitiveStr::Ascii("cises"),
        dictgen::InsensitiveStr::Ascii("cize"),
        dictgen::InsensitiveStr::Ascii("cizes"),
        dictgen::InsensitiveStr::Ascii("klinisation"),
        dictgen::InsensitiveStr::Ascii("klinisations"),
        dictgen::InsensitiveStr::Ascii("klinization"),
        dictgen::InsensitiveStr::Ascii("klinizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FRANCIZE_124885689522532518)],
        &[(0b10010, &ENTRY_FRANCIZES_12871352264589337299)],
        &[(0b01001, &ENTRY_FRANCIZE_124885689522532518)],
        &[(0b01001, &ENTRY_FRANCIZES_12871352264589337299)],
        &[(0b10010, &ENTRY_FRANKLINIZATION_6438755640265619569)],
        &[(0b10010, &ENTRY_FRANKLINIZATIONS_8001068711757005090)],
        &[(0b01001, &ENTRY_FRANKLINIZATION_6438755640265619569)],
        &[(0b01001, &ENTRY_FRANKLINIZATIONS_8001068711757005090)],
    ],
    range: 4..=12,
};

static VARS_FRAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAM_CHILDREN),
    value: None,
};

pub static VARS_FRAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("besia"),
        dictgen::InsensitiveStr::Ascii("besias"),
        dictgen::InsensitiveStr::Ascii("boesia"),
        dictgen::InsensitiveStr::Ascii("boesias"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FRAMBESIA_3541343355805747476)],
        &[(0b00001, &ENTRY_FRAMBESIAS_6675406155055169863)],
        &[(0b11010, &ENTRY_FRAMBESIA_3541343355805747476)],
        &[(0b11010, &ENTRY_FRAMBESIAS_6675406155055169863)],
    ],
    range: 5..=7,
};

static VARS_FRAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAG_CHILDREN),
    value: None,
};

pub static VARS_FRAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mentisation"),
        dictgen::InsensitiveStr::Ascii("mentise"),
        dictgen::InsensitiveStr::Ascii("mentised"),
        dictgen::InsensitiveStr::Ascii("mentiser"),
        dictgen::InsensitiveStr::Ascii("mentises"),
        dictgen::InsensitiveStr::Ascii("mentising"),
        dictgen::InsensitiveStr::Ascii("mentization"),
        dictgen::InsensitiveStr::Ascii("mentize"),
        dictgen::InsensitiveStr::Ascii("mentized"),
        dictgen::InsensitiveStr::Ascii("mentizer"),
        dictgen::InsensitiveStr::Ascii("mentizes"),
        dictgen::InsensitiveStr::Ascii("mentizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FRAGMENTIZATION_13686229545603363988)],
        &[(0b10010, &ENTRY_FRAGMENTIZE_7391127946985078106)],
        &[(0b10010, &ENTRY_FRAGMENTIZED_10911876725635952911)],
        &[(0b10010, &ENTRY_FRAGMENTIZER_7600451912254376830)],
        &[(0b10010, &ENTRY_FRAGMENTIZES_9129150506354302185)],
        &[(0b10010, &ENTRY_FRAGMENTIZING_7217264286732775271)],
        &[(0b01001, &ENTRY_FRAGMENTIZATION_13686229545603363988)],
        &[(0b01001, &ENTRY_FRAGMENTIZE_7391127946985078106)],
        &[(0b01001, &ENTRY_FRAGMENTIZED_10911876725635952911)],
        &[(0b01001, &ENTRY_FRAGMENTIZER_7600451912254376830)],
        &[(0b01001, &ENTRY_FRAGMENTIZES_9129150506354302185)],
        &[(0b01001, &ENTRY_FRAGMENTIZING_7217264286732775271)],
    ],
    range: 7..=11,
};

static VARS_FRAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAE_CHILDREN),
    value: None,
};

pub static VARS_FRAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("na"),
        dictgen::InsensitiveStr::Ascii("nula"),
        dictgen::InsensitiveStr::Ascii("nular"),
        dictgen::InsensitiveStr::Ascii("nulum"),
        dictgen::InsensitiveStr::Ascii("num"),
        dictgen::InsensitiveStr::Ascii("nums"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FRENA_5299955759546711915)],
        &[(0b11010, &ENTRY_FRENULA_10450628952852883483)],
        &[(0b11010, &ENTRY_FRENULAR_17354217019987840503)],
        &[(0b11010, &ENTRY_FRENULUM_8351124618829742055)],
        &[(0b11010, &ENTRY_FRENUM_7603649563431435410)],
        &[(0b11010, &ENTRY_FRENUMS_7693321222408886713)],
    ],
    range: 2..=5,
};

static VARS_FRAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FRAC_CHILDREN),
    value: None,
};

pub static VARS_FRAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalisation"),
        dictgen::InsensitiveStr::Ascii("tionalisations"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalization"),
        dictgen::InsensitiveStr::Ascii("tionalizations"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("tionisation"),
        dictgen::InsensitiveStr::Ascii("tionisations"),
        dictgen::InsensitiveStr::Ascii("tionise"),
        dictgen::InsensitiveStr::Ascii("tionised"),
        dictgen::InsensitiveStr::Ascii("tionises"),
        dictgen::InsensitiveStr::Ascii("tionising"),
        dictgen::InsensitiveStr::Ascii("tionization"),
        dictgen::InsensitiveStr::Ascii("tionizations"),
        dictgen::InsensitiveStr::Ascii("tionize"),
        dictgen::InsensitiveStr::Ascii("tionized"),
        dictgen::InsensitiveStr::Ascii("tionizes"),
        dictgen::InsensitiveStr::Ascii("tionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FRACTIONALIZATION_8741548311534296932)],
        &[(0b10010, &ENTRY_FRACTIONALIZATIONS_8934904189796674249)],
        &[(0b10010, &ENTRY_FRACTIONALIZE_6994927438734081827)],
        &[(0b10010, &ENTRY_FRACTIONALIZED_1638721305897569649)],
        &[(0b10010, &ENTRY_FRACTIONALIZES_5842077662678248264)],
        &[(0b10010, &ENTRY_FRACTIONALIZING_5293926974627714004)],
        &[(0b01001, &ENTRY_FRACTIONALIZATION_8741548311534296932)],
        &[(0b01001, &ENTRY_FRACTIONALIZATIONS_8934904189796674249)],
        &[(0b01001, &ENTRY_FRACTIONALIZE_6994927438734081827)],
        &[(0b01001, &ENTRY_FRACTIONALIZED_1638721305897569649)],
        &[(0b01001, &ENTRY_FRACTIONALIZES_5842077662678248264)],
        &[(0b01001, &ENTRY_FRACTIONALIZING_5293926974627714004)],
        &[(0b10010, &ENTRY_FRACTIONIZATION_15598581478527181020)],
        &[(0b10010, &ENTRY_FRACTIONIZATIONS_15392396968809874240)],
        &[(0b10010, &ENTRY_FRACTIONIZE_2094786255743540739)],
        &[(0b10010, &ENTRY_FRACTIONIZED_10758840764680531186)],
        &[(0b10010, &ENTRY_FRACTIONIZES_4188934241716763343)],
        &[(0b10010, &ENTRY_FRACTIONIZING_15905405027559811921)],
        &[(0b01001, &ENTRY_FRACTIONIZATION_15598581478527181020)],
        &[(0b01001, &ENTRY_FRACTIONIZATIONS_15392396968809874240)],
        &[(0b01001, &ENTRY_FRACTIONIZE_2094786255743540739)],
        &[(0b01001, &ENTRY_FRACTIONIZED_10758840764680531186)],
        &[(0b01001, &ENTRY_FRACTIONIZES_4188934241716763343)],
        &[(0b01001, &ENTRY_FRACTIONIZING_15905405027559811921)],
    ],
    range: 7..=14,
};

static VARS_FO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FO_CHILDREN),
    value: None,
};

static VARS_FO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_FOC_NODE),
    None,
    Some(&VARS_FOE_NODE),
    None,
    Some(&VARS_FOG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FON_NODE),
    Some(&VARS_FOO_NODE),
    None,
    None,
    Some(&VARS_FOR_NODE),
    Some(&VARS_FOS_NODE),
    None,
    Some(&VARS_FOU_NODE),
    Some(&VARS_FOV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_FOV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOV_CHILDREN),
    value: None,
};

pub static VARS_FOV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eolae"),
        dictgen::InsensitiveStr::Ascii("eole"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FOVEOLE_11823716102342610928)],
        &[(0b00001, &ENTRY_FOVEOLE_11823716102342610928)],
    ],
    range: 4..=5,
};

static VARS_FOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOU_CHILDREN),
    value: None,
};

pub static VARS_FOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("ldre"),
        dictgen::InsensitiveStr::Ascii("rb"),
        dictgen::InsensitiveStr::Ascii("rche"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FOULDER_5820992871688859169)],
        &[(0b11010, &ENTRY_FOULDER_5820992871688859169)],
        &[(0b11010, &ENTRY_FORB_9679413672356101479)],
        &[(0b11010, &ENTRY_FORCHE_7953345641228779575)],
        &[(0b00001, &ENTRY_FOUTER_16408335415437635545)],
        &[(0b00001, &ENTRY_FOUTERS_6533881490801158798)],
        &[(0b11010, &ENTRY_FOUTER_16408335415437635545)],
        &[(0b11010, &ENTRY_FOUTERS_6533881490801158798)],
    ],
    range: 2..=4,
};

static VARS_FOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOS_CHILDREN),
    value: None,
};

pub static VARS_FOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sae"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("siled"),
        dictgen::InsensitiveStr::Ascii("silisable"),
        dictgen::InsensitiveStr::Ascii("silisabler"),
        dictgen::InsensitiveStr::Ascii("silisables"),
        dictgen::InsensitiveStr::Ascii("silisablest"),
        dictgen::InsensitiveStr::Ascii("silisation"),
        dictgen::InsensitiveStr::Ascii("silisations"),
        dictgen::InsensitiveStr::Ascii("silise"),
        dictgen::InsensitiveStr::Ascii("silised"),
        dictgen::InsensitiveStr::Ascii("silises"),
        dictgen::InsensitiveStr::Ascii("silising"),
        dictgen::InsensitiveStr::Ascii("silizable"),
        dictgen::InsensitiveStr::Ascii("silizabler"),
        dictgen::InsensitiveStr::Ascii("silizables"),
        dictgen::InsensitiveStr::Ascii("silizablest"),
        dictgen::InsensitiveStr::Ascii("silization"),
        dictgen::InsensitiveStr::Ascii("silizations"),
        dictgen::InsensitiveStr::Ascii("silize"),
        dictgen::InsensitiveStr::Ascii("silized"),
        dictgen::InsensitiveStr::Ascii("silizes"),
        dictgen::InsensitiveStr::Ascii("silizing"),
        dictgen::InsensitiveStr::Ascii("silled"),
        dictgen::InsensitiveStr::Ascii("sulae"),
        dictgen::InsensitiveStr::Ascii("sule"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FOSSE_13143491485595457015)],
        &[(0b00001, &ENTRY_FOSSE_13143491485595457015)],
        &[(0b00001, &ENTRY_FOSSILED_6681230805038992201)],
        &[(0b10010, &ENTRY_FOSSILIZABLE_16442685154631302293)],
        &[(0b10010, &ENTRY_FOSSILIZABLER_9629581083024138184)],
        &[(0b10010, &ENTRY_FOSSILIZABLES_850215141590149031)],
        &[(0b10010, &ENTRY_FOSSILIZABLEST_12458438397842223206)],
        &[(0b10010, &ENTRY_FOSSILIZATION_18247511318058151007)],
        &[(0b10010, &ENTRY_FOSSILIZATIONS_5273119211786261405)],
        &[(0b10010, &ENTRY_FOSSILIZE_16499579356323869709)],
        &[(0b10010, &ENTRY_FOSSILIZED_16904263175369675937)],
        &[(0b10010, &ENTRY_FOSSILIZES_16548112466000258743)],
        &[(0b10010, &ENTRY_FOSSILIZING_3467552662674039049)],
        &[(0b01001, &ENTRY_FOSSILIZABLE_16442685154631302293)],
        &[(0b01001, &ENTRY_FOSSILIZABLER_9629581083024138184)],
        &[(0b01001, &ENTRY_FOSSILIZABLES_850215141590149031)],
        &[(0b01001, &ENTRY_FOSSILIZABLEST_12458438397842223206)],
        &[(0b01001, &ENTRY_FOSSILIZATION_18247511318058151007)],
        &[(0b01001, &ENTRY_FOSSILIZATIONS_5273119211786261405)],
        &[(0b01001, &ENTRY_FOSSILIZE_16499579356323869709)],
        &[(0b01001, &ENTRY_FOSSILIZED_16904263175369675937)],
        &[(0b01001, &ENTRY_FOSSILIZES_16548112466000258743)],
        &[(0b01001, &ENTRY_FOSSILIZING_3467552662674039049)],
        &[(0b11010, &ENTRY_FOSSILED_6681230805038992201)],
        &[(0b11010, &ENTRY_FOSSULE_3767722355901060753)],
        &[(0b00001, &ENTRY_FOSSULE_3767722355901060753)],
    ],
    range: 2..=11,
};

static VARS_FOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FOR_CHILDREN),
    value: None,
};

static VARS_FOR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_FORB_NODE),
    Some(&VARS_FORC_NODE),
    None,
    Some(&VARS_FORE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FORM_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FORU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FORU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORU_CHILDREN),
    value: None,
};

pub static VARS_FORU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mise"),
        dictgen::InsensitiveStr::Ascii("mises"),
        dictgen::InsensitiveStr::Ascii("mize"),
        dictgen::InsensitiveStr::Ascii("mizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FORUMIZE_2328995390050560414)],
        &[(0b10010, &ENTRY_FORUMIZES_16506356693418413171)],
        &[(0b01001, &ENTRY_FORUMIZE_2328995390050560414)],
        &[(0b01001, &ENTRY_FORUMIZES_16506356693418413171)],
    ],
    range: 4..=5,
};

static VARS_FORM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORM_CHILDREN),
    value: None,
};

pub static VARS_FORM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("icidae"),
        dictgen::InsensitiveStr::Ascii("icide"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularised"),
        dictgen::InsensitiveStr::Ascii("ulariser"),
        dictgen::InsensitiveStr::Ascii("ularisers"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularising"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularized"),
        dictgen::InsensitiveStr::Ascii("ularizer"),
        dictgen::InsensitiveStr::Ascii("ularizers"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
        dictgen::InsensitiveStr::Ascii("ularizing"),
        dictgen::InsensitiveStr::Ascii("ulisation"),
        dictgen::InsensitiveStr::Ascii("ulisations"),
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulised"),
        dictgen::InsensitiveStr::Ascii("uliser"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulising"),
        dictgen::InsensitiveStr::Ascii("ulization"),
        dictgen::InsensitiveStr::Ascii("ulizations"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulized"),
        dictgen::InsensitiveStr::Ascii("ulizer"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
        dictgen::InsensitiveStr::Ascii("ulizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FORME_17813592903189666121)],
        &[(0b10010, &ENTRY_FORMALIZABLE_6664723737959773302)],
        &[(0b10010, &ENTRY_FORMALIZATION_3676651268193150145)],
        &[(0b10010, &ENTRY_FORMALIZATIONS_4885129653293673852)],
        &[(0b10010, &ENTRY_FORMALIZE_2062294330762511135)],
        &[(0b10010, &ENTRY_FORMALIZED_8942791564083823012)],
        &[(0b10010, &ENTRY_FORMALIZER_12142743809421262488)],
        &[(0b10010, &ENTRY_FORMALIZERS_2220190158856468837)],
        &[(0b10010, &ENTRY_FORMALIZES_15952411364716226248)],
        &[(0b10010, &ENTRY_FORMALIZING_14987435811550688603)],
        &[(0b01001, &ENTRY_FORMALIZABLE_6664723737959773302)],
        &[(0b01001, &ENTRY_FORMALIZATION_3676651268193150145)],
        &[(0b01001, &ENTRY_FORMALIZATIONS_4885129653293673852)],
        &[(0b01001, &ENTRY_FORMALIZE_2062294330762511135)],
        &[(0b01001, &ENTRY_FORMALIZED_8942791564083823012)],
        &[(0b01001, &ENTRY_FORMALIZER_12142743809421262488)],
        &[(0b01001, &ENTRY_FORMALIZERS_2220190158856468837)],
        &[(0b01001, &ENTRY_FORMALIZES_15952411364716226248)],
        &[(0b01001, &ENTRY_FORMALIZING_14987435811550688603)],
        &[(0b00001, &ENTRY_FORME_17813592903189666121)],
        &[(0b11010, &ENTRY_FORMICIDE_1909286592081562828)],
        &[(0b00001, &ENTRY_FORMICIDE_1909286592081562828)],
        &[(0b10010, &ENTRY_FORMULARIZATION_12271501529394856515)],
        &[(0b10010, &ENTRY_FORMULARIZATIONS_14807438866090777526)],
        &[(0b10010, &ENTRY_FORMULARIZE_13855848211751134881)],
        &[(0b10010, &ENTRY_FORMULARIZED_13568613489170427732)],
        &[(0b10010, &ENTRY_FORMULARIZER_6098631881104862148)],
        &[(0b10010, &ENTRY_FORMULARIZERS_5289341589375736287)],
        &[(0b10010, &ENTRY_FORMULARIZES_4653655791226941263)],
        &[(0b10010, &ENTRY_FORMULARIZING_7416917489055476160)],
        &[(0b01001, &ENTRY_FORMULARIZATION_12271501529394856515)],
        &[(0b01001, &ENTRY_FORMULARIZATIONS_14807438866090777526)],
        &[(0b01001, &ENTRY_FORMULARIZE_13855848211751134881)],
        &[(0b01001, &ENTRY_FORMULARIZED_13568613489170427732)],
        &[(0b01001, &ENTRY_FORMULARIZER_6098631881104862148)],
        &[(0b01001, &ENTRY_FORMULARIZERS_5289341589375736287)],
        &[(0b01001, &ENTRY_FORMULARIZES_4653655791226941263)],
        &[(0b01001, &ENTRY_FORMULARIZING_7416917489055476160)],
        &[(0b10010, &ENTRY_FORMULIZATION_7090367550673650726)],
        &[(0b10010, &ENTRY_FORMULIZATIONS_5844779062261258067)],
        &[(0b10010, &ENTRY_FORMULIZE_2914526413744900996)],
        &[(0b10010, &ENTRY_FORMULIZED_15428824740043784891)],
        &[(0b10010, &ENTRY_FORMULIZER_16549374471213376016)],
        &[(0b10010, &ENTRY_FORMULIZES_7344560378444034263)],
        &[(0b10010, &ENTRY_FORMULIZING_15115678763836572629)],
        &[(0b01001, &ENTRY_FORMULIZATION_7090367550673650726)],
        &[(0b01001, &ENTRY_FORMULIZATIONS_5844779062261258067)],
        &[(0b01001, &ENTRY_FORMULIZE_2914526413744900996)],
        &[(0b01001, &ENTRY_FORMULIZED_15428824740043784891)],
        &[(0b01001, &ENTRY_FORMULIZER_16549374471213376016)],
        &[(0b01001, &ENTRY_FORMULIZES_7344560378444034263)],
        &[(0b01001, &ENTRY_FORMULIZING_15115678763836572629)],
    ],
    range: 1..=12,
};

static VARS_FORE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORE_CHILDREN),
    value: None,
};

pub static VARS_FORE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ignisation"),
        dictgen::InsensitiveStr::Ascii("ignisations"),
        dictgen::InsensitiveStr::Ascii("ignise"),
        dictgen::InsensitiveStr::Ascii("ignises"),
        dictgen::InsensitiveStr::Ascii("ignization"),
        dictgen::InsensitiveStr::Ascii("ignizations"),
        dictgen::InsensitiveStr::Ascii("ignize"),
        dictgen::InsensitiveStr::Ascii("ignizes"),
        dictgen::InsensitiveStr::Ascii("judgement"),
        dictgen::InsensitiveStr::Ascii("judgements"),
        dictgen::InsensitiveStr::Ascii("judgment"),
        dictgen::InsensitiveStr::Ascii("judgments"),
        dictgen::InsensitiveStr::Ascii("prise"),
        dictgen::InsensitiveStr::Ascii("prize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FOREIGNIZATION_12772414430467369432)],
        &[(0b10010, &ENTRY_FOREIGNIZATIONS_1673640877548882914)],
        &[(0b10010, &ENTRY_FOREIGNIZE_5421502222612225073)],
        &[(0b10010, &ENTRY_FOREIGNIZES_17287836650502268788)],
        &[(0b01001, &ENTRY_FOREIGNIZATION_12772414430467369432)],
        &[(0b01001, &ENTRY_FOREIGNIZATIONS_1673640877548882914)],
        &[(0b01001, &ENTRY_FOREIGNIZE_5421502222612225073)],
        &[(0b01001, &ENTRY_FOREIGNIZES_17287836650502268788)],
        &[(0b11010, &ENTRY_FOREJUDGMENT_18186411586344216775)],
        &[(0b11010, &ENTRY_FOREJUDGMENTS_12337114003687174866)],
        &[(0b00001, &ENTRY_FOREJUDGMENT_18186411586344216775)],
        &[(0b00001, &ENTRY_FOREJUDGMENTS_12337114003687174866)],
        &[(0b10010, &ENTRY_FOREPRIZE_14829680777562161527)],
        &[(0b01001, &ENTRY_FOREPRIZE_14829680777562161527)],
    ],
    range: 5..=11,
};

static VARS_FORC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORC_CHILDREN),
    value: None,
};

pub static VARS_FORC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("he")],
    values: &[&[(0b00001, &ENTRY_FORCHE_7953345641228779575)]],
    range: 2..=2,
};

static VARS_FORB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FORB_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_FORB_9679413672356101479)]),
};

pub static VARS_FORB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_FOO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOO_CHILDREN),
    value: None,
};

pub static VARS_FOO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lhardise"),
        dictgen::InsensitiveStr::Ascii("lhardised"),
        dictgen::InsensitiveStr::Ascii("lhardises"),
        dictgen::InsensitiveStr::Ascii("lhardising"),
        dictgen::InsensitiveStr::Ascii("lhardize"),
        dictgen::InsensitiveStr::Ascii("lhardized"),
        dictgen::InsensitiveStr::Ascii("lhardizes"),
        dictgen::InsensitiveStr::Ascii("lhardizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FOOLHARDIZE_5967520092159682639)],
        &[(0b10010, &ENTRY_FOOLHARDIZED_17362186477311628401)],
        &[(0b10010, &ENTRY_FOOLHARDIZES_10067494006367806341)],
        &[(0b10010, &ENTRY_FOOLHARDIZING_14970024232233507775)],
        &[(0b01001, &ENTRY_FOOLHARDIZE_5967520092159682639)],
        &[(0b01001, &ENTRY_FOOLHARDIZED_17362186477311628401)],
        &[(0b01001, &ENTRY_FOOLHARDIZES_10067494006367806341)],
        &[(0b01001, &ENTRY_FOOLHARDIZING_14970024232233507775)],
    ],
    range: 8..=10,
};

static VARS_FON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FON_CHILDREN),
    value: None,
};

pub static VARS_FON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tanel"),
        dictgen::InsensitiveStr::Ascii("tanels"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FONTANEL_7739265077938422568)],
        &[(0b00001, &ENTRY_FONTANELS_12210678121288501630)],
    ],
    range: 5..=6,
};

static VARS_FOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOG_CHILDREN),
    value: None,
};

pub static VARS_FOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ey"),
        dictgen::InsensitiveStr::Ascii("eys"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FOGY_8196900434631652171)],
        &[(0b11010, &ENTRY_FOGIES_2124096126255173426)],
    ],
    range: 2..=3,
};

static VARS_FOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOE_CHILDREN),
    value: None,
};

pub static VARS_FOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cunditatis"),
        dictgen::InsensitiveStr::Ascii("darie"),
        dictgen::InsensitiveStr::Ascii("daries"),
        dictgen::InsensitiveStr::Ascii("tal"),
        dictgen::InsensitiveStr::Ascii("talism"),
        dictgen::InsensitiveStr::Ascii("tation"),
        dictgen::InsensitiveStr::Ascii("ticidal"),
        dictgen::InsensitiveStr::Ascii("ticide"),
        dictgen::InsensitiveStr::Ascii("ticides"),
        dictgen::InsensitiveStr::Ascii("tid"),
        dictgen::InsensitiveStr::Ascii("tider"),
        dictgen::InsensitiveStr::Ascii("tidest"),
        dictgen::InsensitiveStr::Ascii("tiferous"),
        dictgen::InsensitiveStr::Ascii("tiparous"),
        dictgen::InsensitiveStr::Ascii("tor"),
        dictgen::InsensitiveStr::Ascii("tors"),
        dictgen::InsensitiveStr::Ascii("toscopies"),
        dictgen::InsensitiveStr::Ascii("toscopy"),
        dictgen::InsensitiveStr::Ascii("ture"),
        dictgen::InsensitiveStr::Ascii("tus"),
        dictgen::InsensitiveStr::Ascii("tuses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FECUNDITATIS_17976813521315556327)],
        &[(0b11010, &ENTRY_FEDARIE_6394349204716498948)],
        &[(0b11010, &ENTRY_FEDARIES_10652713739066961630)],
        &[(0b10010, &ENTRY_FETAL_17518999091217091154)],
        &[(0b10010, &ENTRY_FETALISM_13684319792675234496)],
        &[(0b10010, &ENTRY_FETATION_5535322770903610684)],
        &[(0b10010, &ENTRY_FETICIDAL_3234468490191462297)],
        &[(0b10010, &ENTRY_FETICIDE_17603941273141945408)],
        &[(0b10010, &ENTRY_FETICIDES_13716695115962439528)],
        &[(0b10010, &ENTRY_FETID_1081410302491831537)],
        &[(0b10010, &ENTRY_FETIDER_5915159455988754255)],
        &[(0b10010, &ENTRY_FETIDEST_17027395037056500217)],
        &[(0b11010, &ENTRY_FETIFEROUS_14513038138855763869)],
        &[(0b11010, &ENTRY_FETIPAROUS_7738738846683585946)],
        &[(0b11010, &ENTRY_FETOR_17434398877973743789)],
        &[(0b11010, &ENTRY_FETORS_12891768447462956139)],
        &[(0b11010, &ENTRY_FETOSCOPIES_10494050521017109189)],
        &[(0b11010, &ENTRY_FETOSCOPY_17563505119899523779)],
        &[(0b11010, &ENTRY_FETURE_14671868018697186605)],
        &[(0b10010, &ENTRY_FETUS_14529005438973048712)],
        &[(0b10010, &ENTRY_FETUSES_1754409052194239428)],
    ],
    range: 3..=10,
};

static VARS_FOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FOC_CHILDREN),
    value: None,
};

pub static VARS_FOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FOCALIZATION_17882330704863832560)],
        &[(0b10010, &ENTRY_FOCALIZATIONS_16231123162455166109)],
        &[(0b10010, &ENTRY_FOCALIZE_10950232880240497629)],
        &[(0b10010, &ENTRY_FOCALIZED_5282149808777869906)],
        &[(0b10010, &ENTRY_FOCALIZES_17823194392580987761)],
        &[(0b10010, &ENTRY_FOCALIZING_4851388567122001857)],
        &[(0b01001, &ENTRY_FOCALIZATION_17882330704863832560)],
        &[(0b01001, &ENTRY_FOCALIZATIONS_16231123162455166109)],
        &[(0b01001, &ENTRY_FOCALIZE_10950232880240497629)],
        &[(0b01001, &ENTRY_FOCALIZED_5282149808777869906)],
        &[(0b01001, &ENTRY_FOCALIZES_17823194392580987761)],
        &[(0b01001, &ENTRY_FOCALIZING_4851388567122001857)],
    ],
    range: 5..=10,
};

static VARS_FL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FL_CHILDREN),
    value: None,
};

static VARS_FL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_FLA_NODE),
    None,
    None,
    None,
    Some(&VARS_FLE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FLU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FLU_CHILDREN),
    value: None,
};

pub static VARS_FLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("idisation"),
        dictgen::InsensitiveStr::Ascii("idisations"),
        dictgen::InsensitiveStr::Ascii("idise"),
        dictgen::InsensitiveStr::Ascii("idised"),
        dictgen::InsensitiveStr::Ascii("idiser"),
        dictgen::InsensitiveStr::Ascii("idisers"),
        dictgen::InsensitiveStr::Ascii("idises"),
        dictgen::InsensitiveStr::Ascii("idising"),
        dictgen::InsensitiveStr::Ascii("idization"),
        dictgen::InsensitiveStr::Ascii("idizations"),
        dictgen::InsensitiveStr::Ascii("idize"),
        dictgen::InsensitiveStr::Ascii("idized"),
        dictgen::InsensitiveStr::Ascii("idizer"),
        dictgen::InsensitiveStr::Ascii("idizers"),
        dictgen::InsensitiveStr::Ascii("idizes"),
        dictgen::InsensitiveStr::Ascii("idizing"),
        dictgen::InsensitiveStr::Ascii("oridisation"),
        dictgen::InsensitiveStr::Ascii("oridisations"),
        dictgen::InsensitiveStr::Ascii("oridise"),
        dictgen::InsensitiveStr::Ascii("oridised"),
        dictgen::InsensitiveStr::Ascii("oridises"),
        dictgen::InsensitiveStr::Ascii("oridising"),
        dictgen::InsensitiveStr::Ascii("oridization"),
        dictgen::InsensitiveStr::Ascii("oridizations"),
        dictgen::InsensitiveStr::Ascii("oridize"),
        dictgen::InsensitiveStr::Ascii("oridized"),
        dictgen::InsensitiveStr::Ascii("oridizes"),
        dictgen::InsensitiveStr::Ascii("oridizing"),
        dictgen::InsensitiveStr::Ascii("tist"),
        dictgen::InsensitiveStr::Ascii("tists"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FLUIDIZATION_16411400305912346218)],
        &[(0b10010, &ENTRY_FLUIDIZATIONS_2883736667208171344)],
        &[(0b10010, &ENTRY_FLUIDIZE_3228666754770451931)],
        &[(0b10010, &ENTRY_FLUIDIZED_4140228345030695002)],
        &[(0b10010, &ENTRY_FLUIDIZER_8317198903618780857)],
        &[(0b10010, &ENTRY_FLUIDIZERS_1532884574807524059)],
        &[(0b10010, &ENTRY_FLUIDIZES_15400536994754984208)],
        &[(0b10010, &ENTRY_FLUIDIZING_18408628175522942192)],
        &[(0b01001, &ENTRY_FLUIDIZATION_16411400305912346218)],
        &[(0b01001, &ENTRY_FLUIDIZATIONS_2883736667208171344)],
        &[(0b01001, &ENTRY_FLUIDIZE_3228666754770451931)],
        &[(0b01001, &ENTRY_FLUIDIZED_4140228345030695002)],
        &[(0b01001, &ENTRY_FLUIDIZER_8317198903618780857)],
        &[(0b01001, &ENTRY_FLUIDIZERS_1532884574807524059)],
        &[(0b01001, &ENTRY_FLUIDIZES_15400536994754984208)],
        &[(0b01001, &ENTRY_FLUIDIZING_18408628175522942192)],
        &[(0b10010, &ENTRY_FLUORIDIZATION_14827318202477553831)],
        &[(0b10010, &ENTRY_FLUORIDIZATIONS_8146935928129561754)],
        &[(0b10010, &ENTRY_FLUORIDIZE_7749548833135664422)],
        &[(0b10010, &ENTRY_FLUORIDIZED_3488303050093414681)],
        &[(0b10010, &ENTRY_FLUORIDIZES_13091150879113382645)],
        &[(0b10010, &ENTRY_FLUORIDIZING_15655433412990428539)],
        &[(0b01001, &ENTRY_FLUORIDIZATION_14827318202477553831)],
        &[(0b01001, &ENTRY_FLUORIDIZATIONS_8146935928129561754)],
        &[(0b01001, &ENTRY_FLUORIDIZE_7749548833135664422)],
        &[(0b01001, &ENTRY_FLUORIDIZED_3488303050093414681)],
        &[(0b01001, &ENTRY_FLUORIDIZES_13091150879113382645)],
        &[(0b01001, &ENTRY_FLUORIDIZING_15655433412990428539)],
        &[(0b01001, &ENTRY_FLUTIST_11416410543776393575)],
        &[(0b01001, &ENTRY_FLUTISTS_7891281533553389633)],
    ],
    range: 4..=12,
};

static VARS_FLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FLO_CHILDREN),
    value: None,
};

pub static VARS_FLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ramor"),
        dictgen::InsensitiveStr::Ascii("ramour"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FLORALIZE_16091946751913584148)],
        &[(0b10010, &ENTRY_FLORALIZES_9204519605461520054)],
        &[(0b01001, &ENTRY_FLORALIZE_16091946751913584148)],
        &[(0b01001, &ENTRY_FLORALIZES_9204519605461520054)],
        &[(0b00001, &ENTRY_FLORAMOR_6523671428808024045)],
        &[(0b11010, &ENTRY_FLORAMOR_6523671428808024045)],
    ],
    range: 5..=7,
};

static VARS_FLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FLE_CHILDREN),
    value: None,
};

pub static VARS_FLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dgeling"),
        dictgen::InsensitiveStr::Ascii("dgelings"),
        dictgen::InsensitiveStr::Ascii("tcherise"),
        dictgen::InsensitiveStr::Ascii("tcherised"),
        dictgen::InsensitiveStr::Ascii("tcherises"),
        dictgen::InsensitiveStr::Ascii("tcherising"),
        dictgen::InsensitiveStr::Ascii("tcherize"),
        dictgen::InsensitiveStr::Ascii("tcherized"),
        dictgen::InsensitiveStr::Ascii("tcherizes"),
        dictgen::InsensitiveStr::Ascii("tcherizing"),
    ],
    values: &[
        &[(0b10011, &ENTRY_FLEDGLING_16171712275155767970)],
        &[(0b10011, &ENTRY_FLEDGLINGS_15894553198111159741)],
        &[(0b10010, &ENTRY_FLETCHERIZE_13571050359642201090)],
        &[(0b10010, &ENTRY_FLETCHERIZED_13084731314883103945)],
        &[(0b10010, &ENTRY_FLETCHERIZES_9045962588657153054)],
        &[(0b10010, &ENTRY_FLETCHERIZING_13648398213116551529)],
        &[(0b01001, &ENTRY_FLETCHERIZE_13571050359642201090)],
        &[(0b01001, &ENTRY_FLETCHERIZED_13084731314883103945)],
        &[(0b01001, &ENTRY_FLETCHERIZES_9045962588657153054)],
        &[(0b01001, &ENTRY_FLETCHERIZING_13648398213116551529)],
    ],
    range: 7..=10,
};

static VARS_FLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FLA_CHILDREN),
    value: None,
};

pub static VARS_FLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mboyantise"),
        dictgen::InsensitiveStr::Ascii("mboyantises"),
        dictgen::InsensitiveStr::Ascii("mboyantize"),
        dictgen::InsensitiveStr::Ascii("mboyantizes"),
        dictgen::InsensitiveStr::Ascii("nneled"),
        dictgen::InsensitiveStr::Ascii("nnelet"),
        dictgen::InsensitiveStr::Ascii("nneling"),
        dictgen::InsensitiveStr::Ascii("nnelled"),
        dictgen::InsensitiveStr::Ascii("nnelling"),
        dictgen::InsensitiveStr::Ascii("utist"),
        dictgen::InsensitiveStr::Ascii("utists"),
        dictgen::InsensitiveStr::Ascii("vor"),
        dictgen::InsensitiveStr::Ascii("vored"),
        dictgen::InsensitiveStr::Ascii("vorer"),
        dictgen::InsensitiveStr::Ascii("vorers"),
        dictgen::InsensitiveStr::Ascii("vorful"),
        dictgen::InsensitiveStr::Ascii("vorfuler"),
        dictgen::InsensitiveStr::Ascii("vorfulest"),
        dictgen::InsensitiveStr::Ascii("vorfullier"),
        dictgen::InsensitiveStr::Ascii("vorfulliest"),
        dictgen::InsensitiveStr::Ascii("vorfully"),
        dictgen::InsensitiveStr::Ascii("vorier"),
        dictgen::InsensitiveStr::Ascii("voriest"),
        dictgen::InsensitiveStr::Ascii("voring"),
        dictgen::InsensitiveStr::Ascii("vorings"),
        dictgen::InsensitiveStr::Ascii("vorless"),
        dictgen::InsensitiveStr::Ascii("vorlesser"),
        dictgen::InsensitiveStr::Ascii("vorlesses"),
        dictgen::InsensitiveStr::Ascii("vorlessest"),
        dictgen::InsensitiveStr::Ascii("vors"),
        dictgen::InsensitiveStr::Ascii("vorsome"),
        dictgen::InsensitiveStr::Ascii("vorsomer"),
        dictgen::InsensitiveStr::Ascii("vorsomest"),
        dictgen::InsensitiveStr::Ascii("vory"),
        dictgen::InsensitiveStr::Ascii("vour"),
        dictgen::InsensitiveStr::Ascii("voured"),
        dictgen::InsensitiveStr::Ascii("vourer"),
        dictgen::InsensitiveStr::Ascii("vourers"),
        dictgen::InsensitiveStr::Ascii("vourful"),
        dictgen::InsensitiveStr::Ascii("vourfuler"),
        dictgen::InsensitiveStr::Ascii("vourfulest"),
        dictgen::InsensitiveStr::Ascii("vourfullier"),
        dictgen::InsensitiveStr::Ascii("vourfulliest"),
        dictgen::InsensitiveStr::Ascii("vourfully"),
        dictgen::InsensitiveStr::Ascii("vourier"),
        dictgen::InsensitiveStr::Ascii("vouriest"),
        dictgen::InsensitiveStr::Ascii("vouring"),
        dictgen::InsensitiveStr::Ascii("vourings"),
        dictgen::InsensitiveStr::Ascii("vourless"),
        dictgen::InsensitiveStr::Ascii("vourlesser"),
        dictgen::InsensitiveStr::Ascii("vourlesses"),
        dictgen::InsensitiveStr::Ascii("vourlessest"),
        dictgen::InsensitiveStr::Ascii("vourous"),
        dictgen::InsensitiveStr::Ascii("vours"),
        dictgen::InsensitiveStr::Ascii("voursome"),
        dictgen::InsensitiveStr::Ascii("voursomer"),
        dictgen::InsensitiveStr::Ascii("voursomest"),
        dictgen::InsensitiveStr::Ascii("voury"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FLAMBOYANTIZE_10665310261460088576)],
        &[(0b10010, &ENTRY_FLAMBOYANTIZES_13178578745419937978)],
        &[(0b01001, &ENTRY_FLAMBOYANTIZE_10665310261460088576)],
        &[(0b01001, &ENTRY_FLAMBOYANTIZES_13178578745419937978)],
        &[(0b01001, &ENTRY_FLANNELED_17580849639984803258)],
        &[(0b00001, &ENTRY_FLANNELETTE_17407058729842674548)],
        &[(0b01001, &ENTRY_FLANNELING_11086853821529088619)],
        &[(0b11010, &ENTRY_FLANNELED_17580849639984803258)],
        &[(0b11010, &ENTRY_FLANNELING_11086853821529088619)],
        &[(0b11010, &ENTRY_FLUTIST_11416410543776393575)],
        &[(0b11010, &ENTRY_FLUTISTS_7891281533553389633)],
        &[(0b11001, &ENTRY_FLAVOR_5944890422119857447)],
        &[(0b11001, &ENTRY_FLAVORED_525661928043886116)],
        &[(0b11001, &ENTRY_FLAVORER_18085561157245164723)],
        &[(0b11001, &ENTRY_FLAVORERS_8743617427163027351)],
        &[(0b11001, &ENTRY_FLAVORFUL_3364515868787360493)],
        &[(0b11001, &ENTRY_FLAVORFULER_15725987112799498805)],
        &[(0b11001, &ENTRY_FLAVORFULEST_4668841165513179755)],
        &[(0b11001, &ENTRY_FLAVORFULLIER_11289585236476375035)],
        &[(0b11001, &ENTRY_FLAVORFULLIEST_16131025075943257190)],
        &[(0b11001, &ENTRY_FLAVORFULLY_554851301589979567)],
        &[(0b11001, &ENTRY_FLAVORIER_5245362258137267071)],
        &[(0b11001, &ENTRY_FLAVORIEST_6780248413885561418)],
        &[(0b11001, &ENTRY_FLAVORING_1483810932321135411)],
        &[(0b11001, &ENTRY_FLAVORINGS_1645163762707862008)],
        &[(0b11001, &ENTRY_FLAVORLESS_254570914842921432)],
        &[(0b11001, &ENTRY_FLAVORLESSER_12189097008069848011)],
        &[(0b11001, &ENTRY_FLAVORLESSES_6887571633548882211)],
        &[(0b11001, &ENTRY_FLAVORLESSEST_3238763211273729754)],
        &[(0b11001, &ENTRY_FLAVORS_4210116483931656755)],
        &[(0b11001, &ENTRY_FLAVORSOME_16308753816531755807)],
        &[(0b11001, &ENTRY_FLAVORSOMER_14092054357849095537)],
        &[(0b11001, &ENTRY_FLAVORSOMEST_10683456501512121672)],
        &[(0b11001, &ENTRY_FLAVORY_14845529741701932399)],
        &[(0b11010, &ENTRY_FLAVOR_5944890422119857447)],
        &[(0b11010, &ENTRY_FLAVORED_525661928043886116)],
        &[(0b11010, &ENTRY_FLAVORER_18085561157245164723)],
        &[(0b11010, &ENTRY_FLAVORERS_8743617427163027351)],
        &[(0b11010, &ENTRY_FLAVORFUL_3364515868787360493)],
        &[(0b11010, &ENTRY_FLAVORFULER_15725987112799498805)],
        &[(0b11010, &ENTRY_FLAVORFULEST_4668841165513179755)],
        &[(0b11010, &ENTRY_FLAVORFULLIER_11289585236476375035)],
        &[(0b11010, &ENTRY_FLAVORFULLIEST_16131025075943257190)],
        &[(0b11010, &ENTRY_FLAVORFULLY_554851301589979567)],
        &[(0b11010, &ENTRY_FLAVORIER_5245362258137267071)],
        &[(0b11010, &ENTRY_FLAVORIEST_6780248413885561418)],
        &[(0b11010, &ENTRY_FLAVORING_1483810932321135411)],
        &[(0b11010, &ENTRY_FLAVORINGS_1645163762707862008)],
        &[(0b11010, &ENTRY_FLAVORLESS_254570914842921432)],
        &[(0b11010, &ENTRY_FLAVORLESSER_12189097008069848011)],
        &[(0b11010, &ENTRY_FLAVORLESSES_6887571633548882211)],
        &[(0b11010, &ENTRY_FLAVORLESSEST_3238763211273729754)],
        &[(0b11010, &ENTRY_FLAVOROUS_4316380042967520904)],
        &[(0b11010, &ENTRY_FLAVORS_4210116483931656755)],
        &[(0b11010, &ENTRY_FLAVORSOME_16308753816531755807)],
        &[(0b11010, &ENTRY_FLAVORSOMER_14092054357849095537)],
        &[(0b11010, &ENTRY_FLAVORSOMEST_10683456501512121672)],
        &[(0b11010, &ENTRY_FLAVORY_14845529741701932399)],
    ],
    range: 3..=12,
};

static VARS_FI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FI_CHILDREN),
    value: None,
};

static VARS_FI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_FIB_NODE),
    Some(&VARS_FIC_NODE),
    None,
    None,
    None,
    Some(&VARS_FIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_FIL_NODE),
    None,
    Some(&VARS_FIN_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_FIS_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_FIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIS_CHILDREN),
    value: None,
};

pub static VARS_FIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("calisation"),
        dictgen::InsensitiveStr::Ascii("calisations"),
        dictgen::InsensitiveStr::Ascii("calise"),
        dictgen::InsensitiveStr::Ascii("calises"),
        dictgen::InsensitiveStr::Ascii("calization"),
        dictgen::InsensitiveStr::Ascii("calizations"),
        dictgen::InsensitiveStr::Ascii("calize"),
        dictgen::InsensitiveStr::Ascii("calizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FISCALIZATION_3524679306286726467)],
        &[(0b10010, &ENTRY_FISCALIZATIONS_5487988177733166944)],
        &[(0b10010, &ENTRY_FISCALIZE_7774689209313530004)],
        &[(0b10010, &ENTRY_FISCALIZES_16628961294565852240)],
        &[(0b01001, &ENTRY_FISCALIZATION_3524679306286726467)],
        &[(0b01001, &ENTRY_FISCALIZATIONS_5487988177733166944)],
        &[(0b01001, &ENTRY_FISCALIZE_7774689209313530004)],
        &[(0b01001, &ENTRY_FISCALIZES_16628961294565852240)],
    ],
    range: 6..=11,
};

static VARS_FIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIN_CHILDREN),
    value: None,
};

pub static VARS_FIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("landisation"),
        dictgen::InsensitiveStr::Ascii("landisations"),
        dictgen::InsensitiveStr::Ascii("landization"),
        dictgen::InsensitiveStr::Ascii("landizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FINALIZATION_5389362780452251733)],
        &[(0b10010, &ENTRY_FINALIZATIONS_10467708361376087611)],
        &[(0b10010, &ENTRY_FINALIZE_7368891692414429008)],
        &[(0b10010, &ENTRY_FINALIZED_17116867203523473286)],
        &[(0b10010, &ENTRY_FINALIZES_15580788945544450334)],
        &[(0b10010, &ENTRY_FINALIZING_12863153952708494256)],
        &[(0b01001, &ENTRY_FINALIZATION_5389362780452251733)],
        &[(0b01001, &ENTRY_FINALIZATIONS_10467708361376087611)],
        &[(0b01001, &ENTRY_FINALIZE_7368891692414429008)],
        &[(0b01001, &ENTRY_FINALIZED_17116867203523473286)],
        &[(0b01001, &ENTRY_FINALIZES_15580788945544450334)],
        &[(0b01001, &ENTRY_FINALIZING_12863153952708494256)],
        &[(0b10010, &ENTRY_FINLANDIZATION_8745466326361207485)],
        &[(0b10010, &ENTRY_FINLANDIZATIONS_6441501577080440734)],
        &[(0b01001, &ENTRY_FINLANDIZATION_8745466326361207485)],
        &[(0b01001, &ENTRY_FINLANDIZATIONS_6441501577080440734)],
    ],
    range: 5..=12,
};

static VARS_FIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIL_CHILDREN),
    value: None,
};

pub static VARS_FIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mise"),
        dictgen::InsensitiveStr::Ascii("mises"),
        dictgen::InsensitiveStr::Ascii("mize"),
        dictgen::InsensitiveStr::Ascii("mizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FILMIZE_7155150221464159291)],
        &[(0b10010, &ENTRY_FILMIZES_15115815173662536994)],
        &[(0b01001, &ENTRY_FILMIZE_7155150221464159291)],
        &[(0b01001, &ENTRY_FILMIZES_15115815173662536994)],
    ],
    range: 4..=5,
};

static VARS_FIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIG_CHILDREN),
    value: None,
};

pub static VARS_FIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FIGURIZE_7661939521561734817)],
        &[(0b10010, &ENTRY_FIGURIZES_6013645329552207900)],
        &[(0b01001, &ENTRY_FIGURIZE_7661939521561734817)],
        &[(0b01001, &ENTRY_FIGURIZES_6013645329552207900)],
    ],
    range: 5..=6,
};

static VARS_FIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIC_CHILDREN),
    value: None,
};

pub static VARS_FIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalisation"),
        dictgen::InsensitiveStr::Ascii("tionalisations"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalization"),
        dictgen::InsensitiveStr::Ascii("tionalizations"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("tionisation"),
        dictgen::InsensitiveStr::Ascii("tionisations"),
        dictgen::InsensitiveStr::Ascii("tionise"),
        dictgen::InsensitiveStr::Ascii("tionised"),
        dictgen::InsensitiveStr::Ascii("tionises"),
        dictgen::InsensitiveStr::Ascii("tionising"),
        dictgen::InsensitiveStr::Ascii("tionization"),
        dictgen::InsensitiveStr::Ascii("tionizations"),
        dictgen::InsensitiveStr::Ascii("tionize"),
        dictgen::InsensitiveStr::Ascii("tionized"),
        dictgen::InsensitiveStr::Ascii("tionizes"),
        dictgen::InsensitiveStr::Ascii("tionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FICTIONALIZATION_11692879889381010340)],
        &[(0b10010, &ENTRY_FICTIONALIZATIONS_15175949905460110834)],
        &[(0b10010, &ENTRY_FICTIONALIZE_14824190480215773487)],
        &[(0b10010, &ENTRY_FICTIONALIZED_12033706812575403958)],
        &[(0b10010, &ENTRY_FICTIONALIZES_9852400248787060636)],
        &[(0b10010, &ENTRY_FICTIONALIZING_783960443322171580)],
        &[(0b01001, &ENTRY_FICTIONALIZATION_11692879889381010340)],
        &[(0b01001, &ENTRY_FICTIONALIZATIONS_15175949905460110834)],
        &[(0b01001, &ENTRY_FICTIONALIZE_14824190480215773487)],
        &[(0b01001, &ENTRY_FICTIONALIZED_12033706812575403958)],
        &[(0b01001, &ENTRY_FICTIONALIZES_9852400248787060636)],
        &[(0b01001, &ENTRY_FICTIONALIZING_783960443322171580)],
        &[(0b10010, &ENTRY_FICTIONIZATION_18268699499501030808)],
        &[(0b10010, &ENTRY_FICTIONIZATIONS_8973608411174529758)],
        &[(0b10010, &ENTRY_FICTIONIZE_8954439194060631064)],
        &[(0b10010, &ENTRY_FICTIONIZED_653881811178594366)],
        &[(0b10010, &ENTRY_FICTIONIZES_10384497571420374630)],
        &[(0b10010, &ENTRY_FICTIONIZING_8996574763647367439)],
        &[(0b01001, &ENTRY_FICTIONIZATION_18268699499501030808)],
        &[(0b01001, &ENTRY_FICTIONIZATIONS_8973608411174529758)],
        &[(0b01001, &ENTRY_FICTIONIZE_8954439194060631064)],
        &[(0b01001, &ENTRY_FICTIONIZED_653881811178594366)],
        &[(0b01001, &ENTRY_FICTIONIZES_10384497571420374630)],
        &[(0b01001, &ENTRY_FICTIONIZING_8996574763647367439)],
    ],
    range: 7..=14,
};

static VARS_FIB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FIB_CHILDREN),
    value: None,
};

pub static VARS_FIB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("erboard"),
        dictgen::InsensitiveStr::Ascii("erboards"),
        dictgen::InsensitiveStr::Ascii("ered"),
        dictgen::InsensitiveStr::Ascii("erfill"),
        dictgen::InsensitiveStr::Ascii("erfills"),
        dictgen::InsensitiveStr::Ascii("erglass"),
        dictgen::InsensitiveStr::Ascii("erglasses"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizer"),
        dictgen::InsensitiveStr::Ascii("erizers"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("erless"),
        dictgen::InsensitiveStr::Ascii("erlesser"),
        dictgen::InsensitiveStr::Ascii("erlesses"),
        dictgen::InsensitiveStr::Ascii("erlessest"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("erscope"),
        dictgen::InsensitiveStr::Ascii("erscopes"),
        dictgen::InsensitiveStr::Ascii("erware"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("reboard"),
        dictgen::InsensitiveStr::Ascii("reboards"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("refill"),
        dictgen::InsensitiveStr::Ascii("refills"),
        dictgen::InsensitiveStr::Ascii("reglass"),
        dictgen::InsensitiveStr::Ascii("reglasses"),
        dictgen::InsensitiveStr::Ascii("reless"),
        dictgen::InsensitiveStr::Ascii("relesser"),
        dictgen::InsensitiveStr::Ascii("relesses"),
        dictgen::InsensitiveStr::Ascii("relessest"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("rescope"),
        dictgen::InsensitiveStr::Ascii("rescopes"),
        dictgen::InsensitiveStr::Ascii("reware"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("rise"),
        dictgen::InsensitiveStr::Ascii("rised"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("risers"),
        dictgen::InsensitiveStr::Ascii("rises"),
        dictgen::InsensitiveStr::Ascii("rising"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rize"),
        dictgen::InsensitiveStr::Ascii("rized"),
        dictgen::InsensitiveStr::Ascii("rizer"),
        dictgen::InsensitiveStr::Ascii("rizers"),
        dictgen::InsensitiveStr::Ascii("rizes"),
        dictgen::InsensitiveStr::Ascii("rizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FIBER_14507009441549378513)],
        &[(0b00001, &ENTRY_FIBERBOARD_10324118796464858065)],
        &[(0b00001, &ENTRY_FIBERBOARDS_269218288221177098)],
        &[(0b00001, &ENTRY_FIBERED_14866184343878669662)],
        &[(0b00001, &ENTRY_FIBERFILL_15892338090700624301)],
        &[(0b00001, &ENTRY_FIBERFILLS_10714754498813286510)],
        &[(0b00001, &ENTRY_FIBERGLASS_13840692803898764317)],
        &[(0b00001, &ENTRY_FIBERGLASSES_9573599106910515750)],
        &[(0b00001, &ENTRY_FIBERIZATION_9448789050279142343)],
        &[(0b00001, &ENTRY_FIBERIZE_10354491173153304112)],
        &[(0b00001, &ENTRY_FIBERIZED_16418419709512190847)],
        &[(0b00001, &ENTRY_FIBERIZER_2701702218944894305)],
        &[(0b00001, &ENTRY_FIBERIZERS_11340645263185175813)],
        &[(0b00001, &ENTRY_FIBERIZES_17105028343308432924)],
        &[(0b00001, &ENTRY_FIBERIZING_4344905904350693098)],
        &[(0b00001, &ENTRY_FIBERLESS_13606825025487113070)],
        &[(0b00001, &ENTRY_FIBERLESSER_10368335487999390386)],
        &[(0b00001, &ENTRY_FIBERLESSES_1834703312046091949)],
        &[(0b00001, &ENTRY_FIBERLESSEST_6306196796958857387)],
        &[(0b00001, &ENTRY_FIBERS_1624245329619960183)],
        &[(0b00001, &ENTRY_FIBERSCOPE_4051287012646069815)],
        &[(0b00001, &ENTRY_FIBERSCOPES_5722286864782871846)],
        &[(0b00001, &ENTRY_FIBERWARE_17783914386673468694)],
        &[(0b11010, &ENTRY_FIBER_14507009441549378513)],
        &[(0b11010, &ENTRY_FIBERBOARD_10324118796464858065)],
        &[(0b11010, &ENTRY_FIBERBOARDS_269218288221177098)],
        &[(0b11010, &ENTRY_FIBERED_14866184343878669662)],
        &[(0b11010, &ENTRY_FIBERFILL_15892338090700624301)],
        &[(0b11010, &ENTRY_FIBERFILLS_10714754498813286510)],
        &[(0b11010, &ENTRY_FIBERGLASS_13840692803898764317)],
        &[(0b11010, &ENTRY_FIBERGLASSES_9573599106910515750)],
        &[(0b11010, &ENTRY_FIBERLESS_13606825025487113070)],
        &[(0b11010, &ENTRY_FIBERLESSER_10368335487999390386)],
        &[(0b11010, &ENTRY_FIBERLESSES_1834703312046091949)],
        &[(0b11010, &ENTRY_FIBERLESSEST_6306196796958857387)],
        &[(0b11010, &ENTRY_FIBERS_1624245329619960183)],
        &[(0b11010, &ENTRY_FIBERSCOPE_4051287012646069815)],
        &[(0b11010, &ENTRY_FIBERSCOPES_5722286864782871846)],
        &[(0b11010, &ENTRY_FIBERWARE_17783914386673468694)],
        &[(0b10010, &ENTRY_FIBERIZATION_9448789050279142343)],
        &[(0b10010, &ENTRY_FIBERIZE_10354491173153304112)],
        &[(0b10010, &ENTRY_FIBERIZED_16418419709512190847)],
        &[(0b10010, &ENTRY_FIBERIZER_2701702218944894305)],
        &[(0b10010, &ENTRY_FIBERIZERS_11340645263185175813)],
        &[(0b10010, &ENTRY_FIBERIZES_17105028343308432924)],
        &[(0b10010, &ENTRY_FIBERIZING_4344905904350693098)],
        &[(0b01000, &ENTRY_FIBERIZATION_9448789050279142343)],
        &[(0b01000, &ENTRY_FIBERIZE_10354491173153304112)],
        &[(0b01000, &ENTRY_FIBERIZED_16418419709512190847)],
        &[(0b01000, &ENTRY_FIBERIZER_2701702218944894305)],
        &[(0b01000, &ENTRY_FIBERIZERS_11340645263185175813)],
        &[(0b01000, &ENTRY_FIBERIZES_17105028343308432924)],
        &[(0b01000, &ENTRY_FIBERIZING_4344905904350693098)],
    ],
    range: 2..=9,
};

static VARS_FE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_FE_6412855417629126837)]),
};

static VARS_FE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_FEC_NODE),
    Some(&VARS_FED_NODE),
    Some(&VARS_FEE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FEM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_FER_NODE),
    None,
    Some(&VARS_FET_NODE),
    Some(&VARS_FEU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FEU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FEU_CHILDREN),
    value: None,
};

pub static VARS_FEU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dalisable"),
        dictgen::InsensitiveStr::Ascii("dalisables"),
        dictgen::InsensitiveStr::Ascii("dalisation"),
        dictgen::InsensitiveStr::Ascii("dalisations"),
        dictgen::InsensitiveStr::Ascii("dalise"),
        dictgen::InsensitiveStr::Ascii("dalised"),
        dictgen::InsensitiveStr::Ascii("dalises"),
        dictgen::InsensitiveStr::Ascii("dalising"),
        dictgen::InsensitiveStr::Ascii("dalizable"),
        dictgen::InsensitiveStr::Ascii("dalizables"),
        dictgen::InsensitiveStr::Ascii("dalization"),
        dictgen::InsensitiveStr::Ascii("dalizations"),
        dictgen::InsensitiveStr::Ascii("dalize"),
        dictgen::InsensitiveStr::Ascii("dalized"),
        dictgen::InsensitiveStr::Ascii("dalizes"),
        dictgen::InsensitiveStr::Ascii("dalizing"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FEUDALIZABLE_15718855955843354838)],
        &[(0b10010, &ENTRY_FEUDALIZABLES_10938382425763284765)],
        &[(0b10010, &ENTRY_FEUDALIZATION_6620838161591814945)],
        &[(0b10010, &ENTRY_FEUDALIZATIONS_10450459550757796831)],
        &[(0b10010, &ENTRY_FEUDALIZE_17118096652700433458)],
        &[(0b10010, &ENTRY_FEUDALIZED_3120776651742142949)],
        &[(0b10010, &ENTRY_FEUDALIZES_10374158201177897598)],
        &[(0b10010, &ENTRY_FEUDALIZING_5894661627571637958)],
        &[(0b01001, &ENTRY_FEUDALIZABLE_15718855955843354838)],
        &[(0b01001, &ENTRY_FEUDALIZABLES_10938382425763284765)],
        &[(0b01001, &ENTRY_FEUDALIZATION_6620838161591814945)],
        &[(0b01001, &ENTRY_FEUDALIZATIONS_10450459550757796831)],
        &[(0b01001, &ENTRY_FEUDALIZE_17118096652700433458)],
        &[(0b01001, &ENTRY_FEUDALIZED_3120776651742142949)],
        &[(0b01001, &ENTRY_FEUDALIZES_10374158201177897598)],
        &[(0b01001, &ENTRY_FEUDALIZING_5894661627571637958)],
        &[(0b00001, &ENTRY_FEUTER_11733789004079348259)],
        &[(0b11010, &ENTRY_FEUTER_11733789004079348259)],
    ],
    range: 3..=11,
};

static VARS_FET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FET_CHILDREN),
    value: None,
};

pub static VARS_FET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ich"),
        dictgen::InsensitiveStr::Ascii("iches"),
        dictgen::InsensitiveStr::Ascii("ichise"),
        dictgen::InsensitiveStr::Ascii("ichised"),
        dictgen::InsensitiveStr::Ascii("ichises"),
        dictgen::InsensitiveStr::Ascii("ichising"),
        dictgen::InsensitiveStr::Ascii("ichize"),
        dictgen::InsensitiveStr::Ascii("ichized"),
        dictgen::InsensitiveStr::Ascii("ichizes"),
        dictgen::InsensitiveStr::Ascii("ichizing"),
        dictgen::InsensitiveStr::Ascii("iferous"),
        dictgen::InsensitiveStr::Ascii("iparous"),
        dictgen::InsensitiveStr::Ascii("ishisation"),
        dictgen::InsensitiveStr::Ascii("ishisations"),
        dictgen::InsensitiveStr::Ascii("ishise"),
        dictgen::InsensitiveStr::Ascii("ishised"),
        dictgen::InsensitiveStr::Ascii("ishises"),
        dictgen::InsensitiveStr::Ascii("ishising"),
        dictgen::InsensitiveStr::Ascii("ishization"),
        dictgen::InsensitiveStr::Ascii("ishizations"),
        dictgen::InsensitiveStr::Ascii("ishize"),
        dictgen::InsensitiveStr::Ascii("ishized"),
        dictgen::InsensitiveStr::Ascii("ishizes"),
        dictgen::InsensitiveStr::Ascii("ishizing"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("oscopies"),
        dictgen::InsensitiveStr::Ascii("oscopy"),
        dictgen::InsensitiveStr::Ascii("ure"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FETISH_2114965296682700947)],
        &[(0b00001, &ENTRY_FETISHES_16284953087435679568)],
        &[(0b10010, &ENTRY_FETICHIZE_8516800402008488712)],
        &[(0b10010, &ENTRY_FETICHIZED_2364538138643524022)],
        &[(0b10010, &ENTRY_FETICHIZES_6929284398655519177)],
        &[(0b10010, &ENTRY_FETICHIZING_5672695629869318515)],
        &[(0b01001, &ENTRY_FETICHIZE_8516800402008488712)],
        &[(0b01001, &ENTRY_FETICHIZED_2364538138643524022)],
        &[(0b01001, &ENTRY_FETICHIZES_6929284398655519177)],
        &[(0b01001, &ENTRY_FETICHIZING_5672695629869318515)],
        &[(0b00001, &ENTRY_FETIFEROUS_14513038138855763869)],
        &[(0b00001, &ENTRY_FETIPAROUS_7738738846683585946)],
        &[(0b10010, &ENTRY_FETISHIZATION_879526721515241266)],
        &[(0b10010, &ENTRY_FETISHIZATIONS_16366493538042913498)],
        &[(0b10010, &ENTRY_FETISHIZE_16589623506909480927)],
        &[(0b10010, &ENTRY_FETISHIZED_5250641916695551285)],
        &[(0b10010, &ENTRY_FETISHIZES_1721613276947375571)],
        &[(0b10010, &ENTRY_FETISHIZING_13625208754682318629)],
        &[(0b01001, &ENTRY_FETISHIZATION_879526721515241266)],
        &[(0b01001, &ENTRY_FETISHIZATIONS_16366493538042913498)],
        &[(0b01001, &ENTRY_FETISHIZE_16589623506909480927)],
        &[(0b01001, &ENTRY_FETISHIZED_5250641916695551285)],
        &[(0b01001, &ENTRY_FETISHIZES_1721613276947375571)],
        &[(0b01001, &ENTRY_FETISHIZING_13625208754682318629)],
        &[(0b00001, &ENTRY_FETOR_17434398877973743789)],
        &[(0b00001, &ENTRY_FETORS_12891768447462956139)],
        &[(0b00001, &ENTRY_FETOSCOPIES_10494050521017109189)],
        &[(0b00001, &ENTRY_FETOSCOPY_17563505119899523779)],
        &[(0b00001, &ENTRY_FETURE_14671868018697186605)],
    ],
    range: 2..=11,
};

static VARS_FER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FER_CHILDREN),
    value: None,
};

pub static VARS_FER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("ie"),
        dictgen::InsensitiveStr::Ascii("ity"),
        dictgen::InsensitiveStr::Ascii("neau"),
        dictgen::InsensitiveStr::Ascii("reled"),
        dictgen::InsensitiveStr::Ascii("reling"),
        dictgen::InsensitiveStr::Ascii("relled"),
        dictgen::InsensitiveStr::Ascii("relling"),
        dictgen::InsensitiveStr::Ascii("ritisation"),
        dictgen::InsensitiveStr::Ascii("ritisations"),
        dictgen::InsensitiveStr::Ascii("ritization"),
        dictgen::InsensitiveStr::Ascii("ritizations"),
        dictgen::InsensitiveStr::Ascii("tilisability"),
        dictgen::InsensitiveStr::Ascii("tilisable"),
        dictgen::InsensitiveStr::Ascii("tilisabler"),
        dictgen::InsensitiveStr::Ascii("tilisables"),
        dictgen::InsensitiveStr::Ascii("tilisablest"),
        dictgen::InsensitiveStr::Ascii("tilisation"),
        dictgen::InsensitiveStr::Ascii("tilisational"),
        dictgen::InsensitiveStr::Ascii("tilisationaler"),
        dictgen::InsensitiveStr::Ascii("tilisationalest"),
        dictgen::InsensitiveStr::Ascii("tilisationals"),
        dictgen::InsensitiveStr::Ascii("tilisations"),
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilised"),
        dictgen::InsensitiveStr::Ascii("tiliser"),
        dictgen::InsensitiveStr::Ascii("tilisers"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilising"),
        dictgen::InsensitiveStr::Ascii("tilizability"),
        dictgen::InsensitiveStr::Ascii("tilizable"),
        dictgen::InsensitiveStr::Ascii("tilizabler"),
        dictgen::InsensitiveStr::Ascii("tilizables"),
        dictgen::InsensitiveStr::Ascii("tilizablest"),
        dictgen::InsensitiveStr::Ascii("tilization"),
        dictgen::InsensitiveStr::Ascii("tilizational"),
        dictgen::InsensitiveStr::Ascii("tilizationaler"),
        dictgen::InsensitiveStr::Ascii("tilizationalest"),
        dictgen::InsensitiveStr::Ascii("tilizationals"),
        dictgen::InsensitiveStr::Ascii("tilizations"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilized"),
        dictgen::InsensitiveStr::Ascii("tilizer"),
        dictgen::InsensitiveStr::Ascii("tilizers"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
        dictgen::InsensitiveStr::Ascii("tilizing"),
        dictgen::InsensitiveStr::Ascii("vor"),
        dictgen::InsensitiveStr::Ascii("vorless"),
        dictgen::InsensitiveStr::Ascii("vorlesses"),
        dictgen::InsensitiveStr::Ascii("vors"),
        dictgen::InsensitiveStr::Ascii("vour"),
        dictgen::InsensitiveStr::Ascii("vourless"),
        dictgen::InsensitiveStr::Ascii("vourlesses"),
        dictgen::InsensitiveStr::Ascii("vours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FERALIZED_2129540690752206051)],
        &[(0b01001, &ENTRY_FERALIZED_2129540690752206051)],
        &[(0b00001, &ENTRY_FERD_17290726529250186020)],
        &[(0b11010, &ENTRY_FEER_11532652647843640304)],
        &[(0b11010, &ENTRY_FEERS_9816318192129301807)],
        &[(0b11010, &ENTRY_FERIE_16904944536625577586)],
        &[(0b00001, &ENTRY_FERIE_16904944536625577586)],
        &[(0b00001, &ENTRY_FERITY_4632811736178249944)],
        &[(0b00001, &ENTRY_FERNEAU_10155755211254630197)],
        &[(0b00001, &ENTRY_FERRELED_6636427247803722942)],
        &[(0b00001, &ENTRY_FERRELING_4899567902997737912)],
        &[(0b11010, &ENTRY_FERRELED_6636427247803722942)],
        &[(0b11010, &ENTRY_FERRELING_4899567902997737912)],
        &[(0b10010, &ENTRY_FERRITIZATION_18074134739966612229)],
        &[(0b10010, &ENTRY_FERRITIZATIONS_18305080996112489502)],
        &[(0b01001, &ENTRY_FERRITIZATION_18074134739966612229)],
        &[(0b01001, &ENTRY_FERRITIZATIONS_18305080996112489502)],
        &[(0b10010, &ENTRY_FERTILIZABILITY_5460980983219934852)],
        &[(0b10010, &ENTRY_FERTILIZABLE_12448840079739843294)],
        &[(0b10010, &ENTRY_FERTILIZABLER_17085580719524585364)],
        &[(0b10010, &ENTRY_FERTILIZABLES_15426058595213862560)],
        &[(0b10010, &ENTRY_FERTILIZABLEST_11600087757233912795)],
        &[(0b10010, &ENTRY_FERTILIZATION_17841696658117857659)],
        &[(0b10010, &ENTRY_FERTILIZATIONAL_6643363430121231287)],
        &[(0b10010, &ENTRY_FERTILIZATIONALER_5809694016637303037)],
        &[(0b10010, &ENTRY_FERTILIZATIONALEST_1268407861451405565)],
        &[(0b10010, &ENTRY_FERTILIZATIONALS_5388571387610968490)],
        &[(0b10010, &ENTRY_FERTILIZATIONS_10565985675957455353)],
        &[(0b10010, &ENTRY_FERTILIZE_8254091234870358890)],
        &[(0b10010, &ENTRY_FERTILIZED_3235991417813432465)],
        &[(0b10010, &ENTRY_FERTILIZER_17245657864487752834)],
        &[(0b10010, &ENTRY_FERTILIZERS_2400009978178899509)],
        &[(0b10010, &ENTRY_FERTILIZES_5502375627064483003)],
        &[(0b10010, &ENTRY_FERTILIZING_2726744554859969827)],
        &[(0b01001, &ENTRY_FERTILIZABILITY_5460980983219934852)],
        &[(0b01001, &ENTRY_FERTILIZABLE_12448840079739843294)],
        &[(0b01001, &ENTRY_FERTILIZABLER_17085580719524585364)],
        &[(0b01001, &ENTRY_FERTILIZABLES_15426058595213862560)],
        &[(0b01001, &ENTRY_FERTILIZABLEST_11600087757233912795)],
        &[(0b01001, &ENTRY_FERTILIZATION_17841696658117857659)],
        &[(0b01001, &ENTRY_FERTILIZATIONAL_6643363430121231287)],
        &[(0b01001, &ENTRY_FERTILIZATIONALER_5809694016637303037)],
        &[(0b01001, &ENTRY_FERTILIZATIONALEST_1268407861451405565)],
        &[(0b01001, &ENTRY_FERTILIZATIONALS_5388571387610968490)],
        &[(0b01001, &ENTRY_FERTILIZATIONS_10565985675957455353)],
        &[(0b01001, &ENTRY_FERTILIZE_8254091234870358890)],
        &[(0b01001, &ENTRY_FERTILIZED_3235991417813432465)],
        &[(0b01001, &ENTRY_FERTILIZER_17245657864487752834)],
        &[(0b01001, &ENTRY_FERTILIZERS_2400009978178899509)],
        &[(0b01001, &ENTRY_FERTILIZES_5502375627064483003)],
        &[(0b01001, &ENTRY_FERTILIZING_2726744554859969827)],
        &[(0b11001, &ENTRY_FERVOR_17743643839771539323)],
        &[(0b11001, &ENTRY_FERVORLESS_4739772680862683322)],
        &[(0b11001, &ENTRY_FERVORLESSES_13320651864382195163)],
        &[(0b11001, &ENTRY_FERVORS_4717213096370119384)],
        &[(0b11010, &ENTRY_FERVOR_17743643839771539323)],
        &[(0b11010, &ENTRY_FERVORLESS_4739772680862683322)],
        &[(0b11010, &ENTRY_FERVORLESSES_13320651864382195163)],
        &[(0b11010, &ENTRY_FERVORS_4717213096370119384)],
    ],
    range: 1..=15,
};

static VARS_FEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FEM_CHILDREN),
    value: None,
};

pub static VARS_FEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
        dictgen::InsensitiveStr::Ascii("tometer"),
        dictgen::InsensitiveStr::Ascii("tometre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FEMALIZE_13901043989723708165)],
        &[(0b10010, &ENTRY_FEMALIZES_16947353395960099765)],
        &[(0b01001, &ENTRY_FEMALIZE_13901043989723708165)],
        &[(0b01001, &ENTRY_FEMALIZES_16947353395960099765)],
        &[(0b10010, &ENTRY_FEMINIZATION_8522419792968789128)],
        &[(0b10010, &ENTRY_FEMINIZATIONS_4574886318648206346)],
        &[(0b10010, &ENTRY_FEMINIZE_6528476134483497288)],
        &[(0b10010, &ENTRY_FEMINIZED_8194884343298056834)],
        &[(0b10010, &ENTRY_FEMINIZES_7032574753251926864)],
        &[(0b10010, &ENTRY_FEMINIZING_4796004961681233661)],
        &[(0b01001, &ENTRY_FEMINIZATION_8522419792968789128)],
        &[(0b01001, &ENTRY_FEMINIZATIONS_4574886318648206346)],
        &[(0b01001, &ENTRY_FEMINIZE_6528476134483497288)],
        &[(0b01001, &ENTRY_FEMINIZED_8194884343298056834)],
        &[(0b01001, &ENTRY_FEMINIZES_7032574753251926864)],
        &[(0b01001, &ENTRY_FEMINIZING_4796004961681233661)],
        &[(0b00001, &ENTRY_FEMTOMETER_10416943962185360317)],
        &[(0b11010, &ENTRY_FEMTOMETER_10416943962185360317)],
    ],
    range: 5..=10,
};

static VARS_FEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FEE_CHILDREN),
    value: None,
};

pub static VARS_FEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FEER_11532652647843640304)],
        &[(0b00001, &ENTRY_FEERS_9816318192129301807)],
    ],
    range: 1..=2,
};

static VARS_FED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FED_CHILDREN),
    value: None,
};

pub static VARS_FED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arie"),
        dictgen::InsensitiveStr::Ascii("aries"),
        dictgen::InsensitiveStr::Ascii("eralisation"),
        dictgen::InsensitiveStr::Ascii("eralisations"),
        dictgen::InsensitiveStr::Ascii("eralise"),
        dictgen::InsensitiveStr::Ascii("eralised"),
        dictgen::InsensitiveStr::Ascii("eralises"),
        dictgen::InsensitiveStr::Ascii("eralising"),
        dictgen::InsensitiveStr::Ascii("eralization"),
        dictgen::InsensitiveStr::Ascii("eralizations"),
        dictgen::InsensitiveStr::Ascii("eralize"),
        dictgen::InsensitiveStr::Ascii("eralized"),
        dictgen::InsensitiveStr::Ascii("eralizes"),
        dictgen::InsensitiveStr::Ascii("eralizing"),
        dictgen::InsensitiveStr::Ascii("or"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FEDARIE_6394349204716498948)],
        &[(0b00001, &ENTRY_FEDARIES_10652713739066961630)],
        &[(0b10010, &ENTRY_FEDERALIZATION_2999038236760622034)],
        &[(0b10010, &ENTRY_FEDERALIZATIONS_16597754848421860206)],
        &[(0b10010, &ENTRY_FEDERALIZE_15318475887938618914)],
        &[(0b10010, &ENTRY_FEDERALIZED_4780345550916631576)],
        &[(0b10010, &ENTRY_FEDERALIZES_2587577566789708184)],
        &[(0b10010, &ENTRY_FEDERALIZING_16718667241930274816)],
        &[(0b01001, &ENTRY_FEDERALIZATION_2999038236760622034)],
        &[(0b01001, &ENTRY_FEDERALIZATIONS_16597754848421860206)],
        &[(0b01001, &ENTRY_FEDERALIZE_15318475887938618914)],
        &[(0b01001, &ENTRY_FEDERALIZED_4780345550916631576)],
        &[(0b01001, &ENTRY_FEDERALIZES_2587577566789708184)],
        &[(0b01001, &ENTRY_FEDERALIZING_16718667241930274816)],
        &[(0b00001, &ENTRY_FEDOR_8887412529233148008)],
    ],
    range: 2..=12,
};

static VARS_FEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FEC_CHILDREN),
    value: None,
};

pub static VARS_FEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("alith"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("ula"),
        dictgen::InsensitiveStr::Ascii("ulence"),
        dictgen::InsensitiveStr::Ascii("undise"),
        dictgen::InsensitiveStr::Ascii("undises"),
        dictgen::InsensitiveStr::Ascii("unditatis"),
        dictgen::InsensitiveStr::Ascii("undize"),
        dictgen::InsensitiveStr::Ascii("undizes"),
    ],
    values: &[
        &[(0b11001, &ENTRY_FECAL_14357706927402634040)],
        &[(0b11001, &ENTRY_FECALITH_1709239582298935153)],
        &[(0b11001, &ENTRY_FECES_6588400696084582030)],
        &[(0b00001, &ENTRY_FECULA_9980537314701284779)],
        &[(0b00001, &ENTRY_FECULENCE_2631357115871198711)],
        &[(0b10010, &ENTRY_FECUNDIZE_13656177531635615400)],
        &[(0b10010, &ENTRY_FECUNDIZES_2678423876082081224)],
        &[(0b00001, &ENTRY_FECUNDITATIS_17976813521315556327)],
        &[(0b01001, &ENTRY_FECUNDIZE_13656177531635615400)],
        &[(0b01001, &ENTRY_FECUNDIZES_2678423876082081224)],
    ],
    range: 2..=9,
};

static VARS_FA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FA_CHILDREN),
    value: None,
};

static VARS_FA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_FAB_NODE),
    Some(&VARS_FAC_NODE),
    None,
    Some(&VARS_FAE_NODE),
    None,
    Some(&VARS_FAG_NODE),
    None,
    Some(&VARS_FAI_NODE),
    None,
    None,
    None,
    Some(&VARS_FAM_NODE),
    Some(&VARS_FAN_NODE),
    Some(&VARS_FAO_NODE),
    None,
    None,
    Some(&VARS_FAR_NODE),
    Some(&VARS_FAS_NODE),
    Some(&VARS_FAT_NODE),
    None,
    Some(&VARS_FAV_NODE),
    None,
    None,
    Some(&VARS_FAY_NODE),
    None,
];

static VARS_FAY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAY_CHILDREN),
    value: None,
};

pub static VARS_FAY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FAYER_14342952204863965335)],
        &[(0b11010, &ENTRY_FAYER_14342952204863965335)],
    ],
    range: 2..=2,
};

static VARS_FAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FAV_CHILDREN),
    value: None,
};

static VARS_FAV_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FAVO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_FAVO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_FAVO_CHILDREN),
    value: None,
};

static VARS_FAVO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_FAVOR_NODE),
    None,
    None,
    Some(&VARS_FAVOU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_FAVOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAVOU_CHILDREN),
    value: None,
};

pub static VARS_FAVOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rable"),
        dictgen::InsensitiveStr::Ascii("rableness"),
        dictgen::InsensitiveStr::Ascii("rablenesses"),
        dictgen::InsensitiveStr::Ascii("rabler"),
        dictgen::InsensitiveStr::Ascii("rables"),
        dictgen::InsensitiveStr::Ascii("rablest"),
        dictgen::InsensitiveStr::Ascii("rablier"),
        dictgen::InsensitiveStr::Ascii("rabliest"),
        dictgen::InsensitiveStr::Ascii("rably"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("redlier"),
        dictgen::InsensitiveStr::Ascii("redliest"),
        dictgen::InsensitiveStr::Ascii("redly"),
        dictgen::InsensitiveStr::Ascii("redness"),
        dictgen::InsensitiveStr::Ascii("rednesses"),
        dictgen::InsensitiveStr::Ascii("reds"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("ress"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("ringlier"),
        dictgen::InsensitiveStr::Ascii("ringliest"),
        dictgen::InsensitiveStr::Ascii("ringly"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("rite"),
        dictgen::InsensitiveStr::Ascii("riter"),
        dictgen::InsensitiveStr::Ascii("rites"),
        dictgen::InsensitiveStr::Ascii("ritest"),
        dictgen::InsensitiveStr::Ascii("ritism"),
        dictgen::InsensitiveStr::Ascii("ritisms"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesser"),
        dictgen::InsensitiveStr::Ascii("rlesses"),
        dictgen::InsensitiveStr::Ascii("rlessest"),
        dictgen::InsensitiveStr::Ascii("rs"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FAVOR_16174102806904091593)],
        &[(0b11010, &ENTRY_FAVORABLE_16585220116684679375)],
        &[(0b11010, &ENTRY_FAVORABLENESS_15076889136273638786)],
        &[(0b11010, &ENTRY_FAVORABLENESSES_7104998476741346696)],
        &[(0b11010, &ENTRY_FAVORABLER_7172677352588609327)],
        &[(0b11010, &ENTRY_FAVORABLES_8653228504507516682)],
        &[(0b11010, &ENTRY_FAVORABLEST_3654396515225860920)],
        &[(0b11010, &ENTRY_FAVORABLIER_7406446644901287938)],
        &[(0b11010, &ENTRY_FAVORABLIEST_13749538246766915905)],
        &[(0b11010, &ENTRY_FAVORABLY_8642546699578488365)],
        &[(0b11010, &ENTRY_FAVORED_16162807193690319578)],
        &[(0b11010, &ENTRY_FAVOREDLIER_5765865123462240199)],
        &[(0b11010, &ENTRY_FAVOREDLIEST_10832270749334107398)],
        &[(0b11010, &ENTRY_FAVOREDLY_18181324612001665281)],
        &[(0b11010, &ENTRY_FAVOREDNESS_12375820644528192720)],
        &[(0b11010, &ENTRY_FAVOREDNESSES_13201622995255558661)],
        &[(0b11010, &ENTRY_FAVOREDS_3475186581170652773)],
        &[(0b11010, &ENTRY_FAVORER_14571533058900750983)],
        &[(0b11010, &ENTRY_FAVORERS_12669438738558310747)],
        &[(0b11010, &ENTRY_FAVORESS_10320527329712113257)],
        &[(0b11010, &ENTRY_FAVORING_2135325073071899230)],
        &[(0b11010, &ENTRY_FAVORINGLIER_13234382898335132498)],
        &[(0b11010, &ENTRY_FAVORINGLIEST_10272028216258766759)],
        &[(0b11010, &ENTRY_FAVORINGLY_11595619512304812227)],
        &[(0b11010, &ENTRY_FAVORINGS_8617057820176781510)],
        &[(0b11010, &ENTRY_FAVORITE_2808981011176955343)],
        &[(0b11010, &ENTRY_FAVORITER_7692783527526236076)],
        &[(0b11010, &ENTRY_FAVORITES_2546901638617062205)],
        &[(0b11010, &ENTRY_FAVORITEST_13292407585100266353)],
        &[(0b11010, &ENTRY_FAVORITISM_14860734505967533306)],
        &[(0b11010, &ENTRY_FAVORITISMS_11770976052678857781)],
        &[(0b11010, &ENTRY_FAVORLESS_5516474921410922467)],
        &[(0b11010, &ENTRY_FAVORLESSER_9070895795594476859)],
        &[(0b11010, &ENTRY_FAVORLESSES_8809391561835385510)],
        &[(0b11010, &ENTRY_FAVORLESSEST_6458711572083420541)],
        &[(0b11010, &ENTRY_FAVORS_12388610586480585674)],
    ],
    range: 1..=11,
};

static VARS_FAVOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAVOR_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_FAVOR_16174102806904091593)]),
};

pub static VARS_FAVOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("able"),
        dictgen::InsensitiveStr::Ascii("ableness"),
        dictgen::InsensitiveStr::Ascii("ablenesses"),
        dictgen::InsensitiveStr::Ascii("abler"),
        dictgen::InsensitiveStr::Ascii("ables"),
        dictgen::InsensitiveStr::Ascii("ablest"),
        dictgen::InsensitiveStr::Ascii("ablier"),
        dictgen::InsensitiveStr::Ascii("abliest"),
        dictgen::InsensitiveStr::Ascii("ably"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("edlier"),
        dictgen::InsensitiveStr::Ascii("edliest"),
        dictgen::InsensitiveStr::Ascii("edly"),
        dictgen::InsensitiveStr::Ascii("edness"),
        dictgen::InsensitiveStr::Ascii("ednesses"),
        dictgen::InsensitiveStr::Ascii("eds"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ess"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("inglier"),
        dictgen::InsensitiveStr::Ascii("ingliest"),
        dictgen::InsensitiveStr::Ascii("ingly"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("ite"),
        dictgen::InsensitiveStr::Ascii("iter"),
        dictgen::InsensitiveStr::Ascii("ites"),
        dictgen::InsensitiveStr::Ascii("itest"),
        dictgen::InsensitiveStr::Ascii("itism"),
        dictgen::InsensitiveStr::Ascii("itisms"),
        dictgen::InsensitiveStr::Ascii("less"),
        dictgen::InsensitiveStr::Ascii("lesser"),
        dictgen::InsensitiveStr::Ascii("lesses"),
        dictgen::InsensitiveStr::Ascii("lessest"),
        dictgen::InsensitiveStr::Ascii("s"),
    ],
    values: &[
        &[(0b11001, &ENTRY_FAVORABLE_16585220116684679375)],
        &[(0b11001, &ENTRY_FAVORABLENESS_15076889136273638786)],
        &[(0b11001, &ENTRY_FAVORABLENESSES_7104998476741346696)],
        &[(0b11001, &ENTRY_FAVORABLER_7172677352588609327)],
        &[(0b11001, &ENTRY_FAVORABLES_8653228504507516682)],
        &[(0b11001, &ENTRY_FAVORABLEST_3654396515225860920)],
        &[(0b11001, &ENTRY_FAVORABLIER_7406446644901287938)],
        &[(0b11001, &ENTRY_FAVORABLIEST_13749538246766915905)],
        &[(0b11001, &ENTRY_FAVORABLY_8642546699578488365)],
        &[(0b11001, &ENTRY_FAVORED_16162807193690319578)],
        &[(0b11001, &ENTRY_FAVOREDLIER_5765865123462240199)],
        &[(0b11001, &ENTRY_FAVOREDLIEST_10832270749334107398)],
        &[(0b11001, &ENTRY_FAVOREDLY_18181324612001665281)],
        &[(0b11001, &ENTRY_FAVOREDNESS_12375820644528192720)],
        &[(0b11001, &ENTRY_FAVOREDNESSES_13201622995255558661)],
        &[(0b11001, &ENTRY_FAVOREDS_3475186581170652773)],
        &[(0b11001, &ENTRY_FAVORER_14571533058900750983)],
        &[(0b11001, &ENTRY_FAVORERS_12669438738558310747)],
        &[(0b11001, &ENTRY_FAVORESS_10320527329712113257)],
        &[(0b11001, &ENTRY_FAVORING_2135325073071899230)],
        &[(0b11001, &ENTRY_FAVORINGLIER_13234382898335132498)],
        &[(0b11001, &ENTRY_FAVORINGLIEST_10272028216258766759)],
        &[(0b11001, &ENTRY_FAVORINGLY_11595619512304812227)],
        &[(0b11001, &ENTRY_FAVORINGS_8617057820176781510)],
        &[(0b11001, &ENTRY_FAVORITE_2808981011176955343)],
        &[(0b11001, &ENTRY_FAVORITER_7692783527526236076)],
        &[(0b11001, &ENTRY_FAVORITES_2546901638617062205)],
        &[(0b11001, &ENTRY_FAVORITEST_13292407585100266353)],
        &[(0b11001, &ENTRY_FAVORITISM_14860734505967533306)],
        &[(0b11001, &ENTRY_FAVORITISMS_11770976052678857781)],
        &[(0b11001, &ENTRY_FAVORLESS_5516474921410922467)],
        &[(0b11001, &ENTRY_FAVORLESSER_9070895795594476859)],
        &[(0b11001, &ENTRY_FAVORLESSES_8809391561835385510)],
        &[(0b11001, &ENTRY_FAVORLESSEST_6458711572083420541)],
        &[(0b11001, &ENTRY_FAVORS_12388610586480585674)],
    ],
    range: 1..=10,
};

static VARS_FAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAT_CHILDREN),
    value: None,
};

pub static VARS_FAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FATALIZE_5795723412936271094)],
        &[(0b10010, &ENTRY_FATALIZES_16154483171742069422)],
        &[(0b01001, &ENTRY_FATALIZE_5795723412936271094)],
        &[(0b01001, &ENTRY_FATALIZES_16154483171742069422)],
    ],
    range: 5..=6,
};

static VARS_FAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAS_CHILDREN),
    value: None,
};

pub static VARS_FAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ciolae"),
        dictgen::InsensitiveStr::Ascii("ciole"),
        dictgen::InsensitiveStr::Ascii("cisticisation"),
        dictgen::InsensitiveStr::Ascii("cisticisations"),
        dictgen::InsensitiveStr::Ascii("cisticise"),
        dictgen::InsensitiveStr::Ascii("cisticises"),
        dictgen::InsensitiveStr::Ascii("cisticization"),
        dictgen::InsensitiveStr::Ascii("cisticizations"),
        dictgen::InsensitiveStr::Ascii("cisticize"),
        dictgen::InsensitiveStr::Ascii("cisticizes"),
        dictgen::InsensitiveStr::Ascii("cistisation"),
        dictgen::InsensitiveStr::Ascii("cistisations"),
        dictgen::InsensitiveStr::Ascii("cistise"),
        dictgen::InsensitiveStr::Ascii("cistised"),
        dictgen::InsensitiveStr::Ascii("cistises"),
        dictgen::InsensitiveStr::Ascii("cistising"),
        dictgen::InsensitiveStr::Ascii("cistization"),
        dictgen::InsensitiveStr::Ascii("cistizations"),
        dictgen::InsensitiveStr::Ascii("cistize"),
        dictgen::InsensitiveStr::Ascii("cistized"),
        dictgen::InsensitiveStr::Ascii("cistizes"),
        dictgen::InsensitiveStr::Ascii("cistizing"),
        dictgen::InsensitiveStr::Ascii("hionise"),
        dictgen::InsensitiveStr::Ascii("hionises"),
        dictgen::InsensitiveStr::Ascii("hionize"),
        dictgen::InsensitiveStr::Ascii("hionizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_FASCIOLE_7639436908568338351)],
        &[(0b00001, &ENTRY_FASCIOLE_7639436908568338351)],
        &[(0b10010, &ENTRY_FASCISTICIZATION_4858667405774331216)],
        &[(0b10010, &ENTRY_FASCISTICIZATIONS_18053530396662800587)],
        &[(0b10010, &ENTRY_FASCISTICIZE_8685639468575663113)],
        &[(0b10010, &ENTRY_FASCISTICIZES_5781725162251103852)],
        &[(0b01001, &ENTRY_FASCISTICIZATION_4858667405774331216)],
        &[(0b01001, &ENTRY_FASCISTICIZATIONS_18053530396662800587)],
        &[(0b01001, &ENTRY_FASCISTICIZE_8685639468575663113)],
        &[(0b01001, &ENTRY_FASCISTICIZES_5781725162251103852)],
        &[(0b10010, &ENTRY_FASCISTIZATION_6926224020620442283)],
        &[(0b10010, &ENTRY_FASCISTIZATIONS_3946675109662693253)],
        &[(0b10010, &ENTRY_FASCISTIZE_11043251862767140703)],
        &[(0b10010, &ENTRY_FASCISTIZED_17858786995192876357)],
        &[(0b10010, &ENTRY_FASCISTIZES_10726309171561350516)],
        &[(0b10010, &ENTRY_FASCISTIZING_14842848351094053038)],
        &[(0b01001, &ENTRY_FASCISTIZATION_6926224020620442283)],
        &[(0b01001, &ENTRY_FASCISTIZATIONS_3946675109662693253)],
        &[(0b01001, &ENTRY_FASCISTIZE_11043251862767140703)],
        &[(0b01001, &ENTRY_FASCISTIZED_17858786995192876357)],
        &[(0b01001, &ENTRY_FASCISTIZES_10726309171561350516)],
        &[(0b01001, &ENTRY_FASCISTIZING_14842848351094053038)],
        &[(0b10010, &ENTRY_FASHIONIZE_9487132676031513779)],
        &[(0b10010, &ENTRY_FASHIONIZES_12948391454225982571)],
        &[(0b01001, &ENTRY_FASHIONIZE_9487132676031513779)],
        &[(0b01001, &ENTRY_FASHIONIZES_12948391454225982571)],
    ],
    range: 5..=14,
};

static VARS_FAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAR_CHILDREN),
    value: None,
};

pub static VARS_FAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adisation"),
        dictgen::InsensitiveStr::Ascii("adisations"),
        dictgen::InsensitiveStr::Ascii("adise"),
        dictgen::InsensitiveStr::Ascii("adised"),
        dictgen::InsensitiveStr::Ascii("adiser"),
        dictgen::InsensitiveStr::Ascii("adisers"),
        dictgen::InsensitiveStr::Ascii("adises"),
        dictgen::InsensitiveStr::Ascii("adising"),
        dictgen::InsensitiveStr::Ascii("adization"),
        dictgen::InsensitiveStr::Ascii("adizations"),
        dictgen::InsensitiveStr::Ascii("adize"),
        dictgen::InsensitiveStr::Ascii("adized"),
        dictgen::InsensitiveStr::Ascii("adizer"),
        dictgen::InsensitiveStr::Ascii("adizers"),
        dictgen::InsensitiveStr::Ascii("adizes"),
        dictgen::InsensitiveStr::Ascii("adizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FARADIZATION_15891788669706277797)],
        &[(0b10010, &ENTRY_FARADIZATIONS_4526439476664692216)],
        &[(0b10010, &ENTRY_FARADIZE_13316438844181300579)],
        &[(0b10010, &ENTRY_FARADIZED_2216631753438049544)],
        &[(0b10010, &ENTRY_FARADIZER_12209074437517416364)],
        &[(0b10010, &ENTRY_FARADIZERS_96577301703372931)],
        &[(0b10010, &ENTRY_FARADIZES_516381975059492431)],
        &[(0b10010, &ENTRY_FARADIZING_7236430722652054967)],
        &[(0b01001, &ENTRY_FARADIZATION_15891788669706277797)],
        &[(0b01001, &ENTRY_FARADIZATIONS_4526439476664692216)],
        &[(0b01001, &ENTRY_FARADIZE_13316438844181300579)],
        &[(0b01001, &ENTRY_FARADIZED_2216631753438049544)],
        &[(0b01001, &ENTRY_FARADIZER_12209074437517416364)],
        &[(0b01001, &ENTRY_FARADIZERS_96577301703372931)],
        &[(0b01001, &ENTRY_FARADIZES_516381975059492431)],
        &[(0b01001, &ENTRY_FARADIZING_7236430722652054967)],
    ],
    range: 5..=10,
};

static VARS_FAO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAO_CHILDREN),
    value: None,
};

pub static VARS_FAO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ence")],
    values: &[&[(0b11010, &ENTRY_FAENCE_6852965957276318244)]],
    range: 4..=4,
};

static VARS_FAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAN_CHILDREN),
    value: None,
};

pub static VARS_FAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aticise"),
        dictgen::InsensitiveStr::Ascii("aticised"),
        dictgen::InsensitiveStr::Ascii("aticises"),
        dictgen::InsensitiveStr::Ascii("aticising"),
        dictgen::InsensitiveStr::Ascii("aticize"),
        dictgen::InsensitiveStr::Ascii("aticized"),
        dictgen::InsensitiveStr::Ascii("aticizes"),
        dictgen::InsensitiveStr::Ascii("aticizing"),
        dictgen::InsensitiveStr::Ascii("tasise"),
        dictgen::InsensitiveStr::Ascii("tasised"),
        dictgen::InsensitiveStr::Ascii("tasiser"),
        dictgen::InsensitiveStr::Ascii("tasises"),
        dictgen::InsensitiveStr::Ascii("tasising"),
        dictgen::InsensitiveStr::Ascii("tasize"),
        dictgen::InsensitiveStr::Ascii("tasized"),
        dictgen::InsensitiveStr::Ascii("tasizer"),
        dictgen::InsensitiveStr::Ascii("tasizes"),
        dictgen::InsensitiveStr::Ascii("tasizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FANATICIZE_175890918610710058)],
        &[(0b10010, &ENTRY_FANATICIZED_5234463871342267005)],
        &[(0b10010, &ENTRY_FANATICIZES_11857074349260388346)],
        &[(0b10010, &ENTRY_FANATICIZING_13797711926894006340)],
        &[(0b01001, &ENTRY_FANATICIZE_175890918610710058)],
        &[(0b01001, &ENTRY_FANATICIZED_5234463871342267005)],
        &[(0b01001, &ENTRY_FANATICIZES_11857074349260388346)],
        &[(0b01001, &ENTRY_FANATICIZING_13797711926894006340)],
        &[(0b10010, &ENTRY_FANTASIZE_16667407006128337409)],
        &[(0b10010, &ENTRY_FANTASIZED_9815854138753209894)],
        &[(0b10010, &ENTRY_FANTASIZER_9698455867221961502)],
        &[(0b10010, &ENTRY_FANTASIZES_10834180084204721653)],
        &[(0b10010, &ENTRY_FANTASIZING_17657564354102329164)],
        &[(0b01001, &ENTRY_FANTASIZE_16667407006128337409)],
        &[(0b01001, &ENTRY_FANTASIZED_9815854138753209894)],
        &[(0b01001, &ENTRY_FANTASIZER_9698455867221961502)],
        &[(0b01001, &ENTRY_FANTASIZES_10834180084204721653)],
        &[(0b01001, &ENTRY_FANTASIZING_17657564354102329164)],
    ],
    range: 6..=9,
};

static VARS_FAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAM_CHILDREN),
    value: None,
};

pub static VARS_FAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iliarisation"),
        dictgen::InsensitiveStr::Ascii("iliarisations"),
        dictgen::InsensitiveStr::Ascii("iliarise"),
        dictgen::InsensitiveStr::Ascii("iliarised"),
        dictgen::InsensitiveStr::Ascii("iliariser"),
        dictgen::InsensitiveStr::Ascii("iliarisers"),
        dictgen::InsensitiveStr::Ascii("iliarises"),
        dictgen::InsensitiveStr::Ascii("iliarising"),
        dictgen::InsensitiveStr::Ascii("iliarisingly"),
        dictgen::InsensitiveStr::Ascii("iliarization"),
        dictgen::InsensitiveStr::Ascii("iliarizations"),
        dictgen::InsensitiveStr::Ascii("iliarize"),
        dictgen::InsensitiveStr::Ascii("iliarized"),
        dictgen::InsensitiveStr::Ascii("iliarizer"),
        dictgen::InsensitiveStr::Ascii("iliarizers"),
        dictgen::InsensitiveStr::Ascii("iliarizes"),
        dictgen::InsensitiveStr::Ascii("iliarizing"),
        dictgen::InsensitiveStr::Ascii("iliarizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FAMILIARIZATION_7435436227522581935)],
        &[(0b10010, &ENTRY_FAMILIARIZATIONS_7744496085896785322)],
        &[(0b10010, &ENTRY_FAMILIARIZE_6458271230166262342)],
        &[(0b10010, &ENTRY_FAMILIARIZED_9635879804250335511)],
        &[(0b10010, &ENTRY_FAMILIARIZER_12769069348636773119)],
        &[(0b10010, &ENTRY_FAMILIARIZERS_8503690372223478730)],
        &[(0b10010, &ENTRY_FAMILIARIZES_15552999136886444100)],
        &[(0b10010, &ENTRY_FAMILIARIZING_3497704747397161180)],
        &[(0b10010, &ENTRY_FAMILIARIZINGLY_17102975447523114031)],
        &[(0b01001, &ENTRY_FAMILIARIZATION_7435436227522581935)],
        &[(0b01001, &ENTRY_FAMILIARIZATIONS_7744496085896785322)],
        &[(0b01001, &ENTRY_FAMILIARIZE_6458271230166262342)],
        &[(0b01001, &ENTRY_FAMILIARIZED_9635879804250335511)],
        &[(0b01001, &ENTRY_FAMILIARIZER_12769069348636773119)],
        &[(0b01001, &ENTRY_FAMILIARIZERS_8503690372223478730)],
        &[(0b01001, &ENTRY_FAMILIARIZES_15552999136886444100)],
        &[(0b01001, &ENTRY_FAMILIARIZING_3497704747397161180)],
        &[(0b01001, &ENTRY_FAMILIARIZINGLY_17102975447523114031)],
    ],
    range: 8..=13,
};

static VARS_FAI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAI_CHILDREN),
    value: None,
};

pub static VARS_FAI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tor"),
        dictgen::InsensitiveStr::Ascii("tors"),
        dictgen::InsensitiveStr::Ascii("tour"),
        dictgen::InsensitiveStr::Ascii("tours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_FAITOR_14739031312979666111)],
        &[(0b00001, &ENTRY_FAITORS_16017382139132171207)],
        &[(0b11010, &ENTRY_FAITOR_14739031312979666111)],
        &[(0b11010, &ENTRY_FAITORS_16017382139132171207)],
    ],
    range: 3..=5,
};

static VARS_FAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAG_CHILDREN),
    value: None,
};

pub static VARS_FAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ot"),
        dictgen::InsensitiveStr::Ascii("oted"),
        dictgen::InsensitiveStr::Ascii("oting"),
        dictgen::InsensitiveStr::Ascii("ots"),
    ],
    values: &[
        &[
            (0b01001, &ENTRY_FAGOT_12511557487040804077),
            (0b01001, &ENTRY_FAGOT_2908150994909348842),
        ],
        &[(0b01001, &ENTRY_FAGOTED_18130244201646636018)],
        &[(0b01001, &ENTRY_FAGOTING_14091007799386400971)],
        &[
            (0b01001, &ENTRY_FAGOTS_13347829079007571091),
            (0b01001, &ENTRY_FAGOTS_9448080982481828615),
        ],
    ],
    range: 2..=5,
};

static VARS_FAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_FE_6412855417629126837)]),
};

pub static VARS_FAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cal"),
        dictgen::InsensitiveStr::Ascii("calith"),
        dictgen::InsensitiveStr::Ascii("ces"),
        dictgen::InsensitiveStr::Ascii("cula"),
        dictgen::InsensitiveStr::Ascii("culence"),
        dictgen::InsensitiveStr::Ascii("dor"),
        dictgen::InsensitiveStr::Ascii("nce"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FECAL_14357706927402634040)],
        &[(0b10010, &ENTRY_FECALITH_1709239582298935153)],
        &[(0b11010, &ENTRY_FECES_6588400696084582030)],
        &[(0b11010, &ENTRY_FECULA_9980537314701284779)],
        &[(0b11010, &ENTRY_FECULENCE_2631357115871198711)],
        &[(0b11010, &ENTRY_FEDOR_8887412529233148008)],
        &[(0b00001, &ENTRY_FAENCE_6852965957276318244)],
    ],
    range: 3..=7,
};

static VARS_FAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAC_CHILDREN),
    value: None,
};

pub static VARS_FAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("similise"),
        dictgen::InsensitiveStr::Ascii("similises"),
        dictgen::InsensitiveStr::Ascii("similize"),
        dictgen::InsensitiveStr::Ascii("similizes"),
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torising"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("torizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FACSIMILIZE_9828221696654309927)],
        &[(0b10010, &ENTRY_FACSIMILIZES_13852505000433399295)],
        &[(0b01001, &ENTRY_FACSIMILIZE_9828221696654309927)],
        &[(0b01001, &ENTRY_FACSIMILIZES_13852505000433399295)],
        &[(0b10010, &ENTRY_FACTORIZATION_3182572715959186659)],
        &[(0b10010, &ENTRY_FACTORIZATIONS_16583219313061102178)],
        &[(0b10010, &ENTRY_FACTORIZE_8969914975304697583)],
        &[(0b10010, &ENTRY_FACTORIZED_15433924875237664508)],
        &[(0b10010, &ENTRY_FACTORIZES_7790021725855776528)],
        &[(0b10010, &ENTRY_FACTORIZING_6633915971235070053)],
        &[(0b01001, &ENTRY_FACTORIZATION_3182572715959186659)],
        &[(0b01001, &ENTRY_FACTORIZATIONS_16583219313061102178)],
        &[(0b01001, &ENTRY_FACTORIZE_8969914975304697583)],
        &[(0b01001, &ENTRY_FACTORIZED_15433924875237664508)],
        &[(0b01001, &ENTRY_FACTORIZES_7790021725855776528)],
        &[(0b01001, &ENTRY_FACTORIZING_6633915971235070053)],
    ],
    range: 6..=11,
};

static VARS_FAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_FAB_CHILDREN),
    value: None,
};

pub static VARS_FAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ulise"),
        dictgen::InsensitiveStr::Ascii("ulised"),
        dictgen::InsensitiveStr::Ascii("ulises"),
        dictgen::InsensitiveStr::Ascii("ulising"),
        dictgen::InsensitiveStr::Ascii("ulize"),
        dictgen::InsensitiveStr::Ascii("ulized"),
        dictgen::InsensitiveStr::Ascii("ulizes"),
        dictgen::InsensitiveStr::Ascii("ulizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_FABULIZE_6554520750007678638)],
        &[(0b10010, &ENTRY_FABULIZED_7556454061259147422)],
        &[(0b10010, &ENTRY_FABULIZES_13117215117496144014)],
        &[(0b10010, &ENTRY_FABULIZING_8547130161556656861)],
        &[(0b01001, &ENTRY_FABULIZE_6554520750007678638)],
        &[(0b01001, &ENTRY_FABULIZED_7556454061259147422)],
        &[(0b01001, &ENTRY_FABULIZES_13117215117496144014)],
        &[(0b01001, &ENTRY_FABULIZING_8547130161556656861)],
    ],
    range: 5..=7,
};

static VARS_E_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_E_CHILDREN),
    value: None,
};

static VARS_E_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_EA_NODE),
    Some(&VARS_EB_NODE),
    Some(&VARS_EC_NODE),
    Some(&VARS_ED_NODE),
    Some(&VARS_EE_NODE),
    Some(&VARS_EF_NODE),
    Some(&VARS_EG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_EL_NODE),
    Some(&VARS_EM_NODE),
    Some(&VARS_EN_NODE),
    Some(&VARS_EO_NODE),
    Some(&VARS_EP_NODE),
    Some(&VARS_EQ_NODE),
    Some(&VARS_ER_NODE),
    Some(&VARS_ES_NODE),
    Some(&VARS_ET_NODE),
    Some(&VARS_EU_NODE),
    Some(&VARS_EV_NODE),
    None,
    Some(&VARS_EX_NODE),
    None,
    None,
];

static VARS_EX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EX_CHILDREN),
    value: None,
};

static VARS_EX_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_EXA_NODE),
    None,
    Some(&VARS_EXC_NODE),
    None,
    Some(&VARS_EXE_NODE),
    None,
    None,
    Some(&VARS_EXH_NODE),
    Some(&VARS_EXI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_EXO_NODE),
    Some(&VARS_EXP_NODE),
    None,
    None,
    Some(&VARS_EXS_NODE),
    Some(&VARS_EXT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EXT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXT_CHILDREN),
    value: None,
};

pub static VARS_EXT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emporisation"),
        dictgen::InsensitiveStr::Ascii("emporisations"),
        dictgen::InsensitiveStr::Ascii("emporise"),
        dictgen::InsensitiveStr::Ascii("emporised"),
        dictgen::InsensitiveStr::Ascii("emporiser"),
        dictgen::InsensitiveStr::Ascii("emporisers"),
        dictgen::InsensitiveStr::Ascii("emporises"),
        dictgen::InsensitiveStr::Ascii("emporising"),
        dictgen::InsensitiveStr::Ascii("emporization"),
        dictgen::InsensitiveStr::Ascii("emporizations"),
        dictgen::InsensitiveStr::Ascii("emporize"),
        dictgen::InsensitiveStr::Ascii("emporized"),
        dictgen::InsensitiveStr::Ascii("emporizer"),
        dictgen::InsensitiveStr::Ascii("emporizers"),
        dictgen::InsensitiveStr::Ascii("emporizes"),
        dictgen::InsensitiveStr::Ascii("emporizing"),
        dictgen::InsensitiveStr::Ascii("eriorisation"),
        dictgen::InsensitiveStr::Ascii("eriorisations"),
        dictgen::InsensitiveStr::Ascii("eriorise"),
        dictgen::InsensitiveStr::Ascii("eriorised"),
        dictgen::InsensitiveStr::Ascii("eriorises"),
        dictgen::InsensitiveStr::Ascii("eriorising"),
        dictgen::InsensitiveStr::Ascii("eriorization"),
        dictgen::InsensitiveStr::Ascii("eriorizations"),
        dictgen::InsensitiveStr::Ascii("eriorize"),
        dictgen::InsensitiveStr::Ascii("eriorized"),
        dictgen::InsensitiveStr::Ascii("eriorizes"),
        dictgen::InsensitiveStr::Ascii("eriorizing"),
        dictgen::InsensitiveStr::Ascii("ernalisation"),
        dictgen::InsensitiveStr::Ascii("ernalisations"),
        dictgen::InsensitiveStr::Ascii("ernalise"),
        dictgen::InsensitiveStr::Ascii("ernalised"),
        dictgen::InsensitiveStr::Ascii("ernalises"),
        dictgen::InsensitiveStr::Ascii("ernalising"),
        dictgen::InsensitiveStr::Ascii("ernalization"),
        dictgen::InsensitiveStr::Ascii("ernalizations"),
        dictgen::InsensitiveStr::Ascii("ernalize"),
        dictgen::InsensitiveStr::Ascii("ernalized"),
        dictgen::InsensitiveStr::Ascii("ernalizes"),
        dictgen::InsensitiveStr::Ascii("ernalizing"),
        dictgen::InsensitiveStr::Ascii("oll"),
        dictgen::InsensitiveStr::Ascii("olls"),
        dictgen::InsensitiveStr::Ascii("ravert"),
        dictgen::InsensitiveStr::Ascii("raverted"),
        dictgen::InsensitiveStr::Ascii("raverts"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXTEMPORIZATION_6498516717162293633)],
        &[(0b10010, &ENTRY_EXTEMPORIZATIONS_17970202292616391802)],
        &[(0b10010, &ENTRY_EXTEMPORIZE_8490706080912375039)],
        &[(0b10010, &ENTRY_EXTEMPORIZED_8884254797509015457)],
        &[(0b10010, &ENTRY_EXTEMPORIZER_15042169661772082145)],
        &[(0b10010, &ENTRY_EXTEMPORIZERS_10144332391226789510)],
        &[(0b10010, &ENTRY_EXTEMPORIZES_10662898516430920590)],
        &[(0b10010, &ENTRY_EXTEMPORIZING_10937023320075355586)],
        &[(0b01001, &ENTRY_EXTEMPORIZATION_6498516717162293633)],
        &[(0b01001, &ENTRY_EXTEMPORIZATIONS_17970202292616391802)],
        &[(0b01001, &ENTRY_EXTEMPORIZE_8490706080912375039)],
        &[(0b01001, &ENTRY_EXTEMPORIZED_8884254797509015457)],
        &[(0b01001, &ENTRY_EXTEMPORIZER_15042169661772082145)],
        &[(0b01001, &ENTRY_EXTEMPORIZERS_10144332391226789510)],
        &[(0b01001, &ENTRY_EXTEMPORIZES_10662898516430920590)],
        &[(0b01001, &ENTRY_EXTEMPORIZING_10937023320075355586)],
        &[(0b10010, &ENTRY_EXTERIORIZATION_8592258252267171531)],
        &[(0b10010, &ENTRY_EXTERIORIZATIONS_10258294511167010008)],
        &[(0b10010, &ENTRY_EXTERIORIZE_6928562918919697659)],
        &[(0b10010, &ENTRY_EXTERIORIZED_2593224941672461767)],
        &[(0b10010, &ENTRY_EXTERIORIZES_10941715232314771538)],
        &[(0b10010, &ENTRY_EXTERIORIZING_3361516313097201672)],
        &[(0b01001, &ENTRY_EXTERIORIZATION_8592258252267171531)],
        &[(0b01001, &ENTRY_EXTERIORIZATIONS_10258294511167010008)],
        &[(0b01001, &ENTRY_EXTERIORIZE_6928562918919697659)],
        &[(0b01001, &ENTRY_EXTERIORIZED_2593224941672461767)],
        &[(0b01001, &ENTRY_EXTERIORIZES_10941715232314771538)],
        &[(0b01001, &ENTRY_EXTERIORIZING_3361516313097201672)],
        &[(0b10010, &ENTRY_EXTERNALIZATION_5637241595479106962)],
        &[(0b10010, &ENTRY_EXTERNALIZATIONS_13981636890729920109)],
        &[(0b10010, &ENTRY_EXTERNALIZE_6421333850383600915)],
        &[(0b10010, &ENTRY_EXTERNALIZED_595019063900238343)],
        &[(0b10010, &ENTRY_EXTERNALIZES_11960788314575642832)],
        &[(0b10010, &ENTRY_EXTERNALIZING_17289102227300964437)],
        &[(0b01001, &ENTRY_EXTERNALIZATION_5637241595479106962)],
        &[(0b01001, &ENTRY_EXTERNALIZATIONS_13981636890729920109)],
        &[(0b01001, &ENTRY_EXTERNALIZE_6421333850383600915)],
        &[(0b01001, &ENTRY_EXTERNALIZED_595019063900238343)],
        &[(0b01001, &ENTRY_EXTERNALIZES_11960788314575642832)],
        &[(0b01001, &ENTRY_EXTERNALIZING_17289102227300964437)],
        &[(0b00001, &ENTRY_EXTOL_17049600042027760409)],
        &[(0b00001, &ENTRY_EXTOLS_435999545191713231)],
        &[(0b10011, &ENTRY_EXTROVERT_3459138457522989101)],
        &[(0b10011, &ENTRY_EXTROVERTED_9249661851858893561)],
        &[(0b10011, &ENTRY_EXTROVERTS_17343931619747038542)],
    ],
    range: 3..=13,
};

static VARS_EXS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXS_CHILDREN),
    value: None,
};

pub static VARS_EXS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iccatae"),
        dictgen::InsensitiveStr::Ascii("iccate"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EXSICCATE_17097371061751609281)],
        &[(0b00001, &ENTRY_EXSICCATE_17097371061751609281)],
    ],
    range: 6..=7,
};

static VARS_EXP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXP_CHILDREN),
    value: None,
};

pub static VARS_EXP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erimentalise"),
        dictgen::InsensitiveStr::Ascii("erimentalised"),
        dictgen::InsensitiveStr::Ascii("erimentalises"),
        dictgen::InsensitiveStr::Ascii("erimentalising"),
        dictgen::InsensitiveStr::Ascii("erimentalize"),
        dictgen::InsensitiveStr::Ascii("erimentalized"),
        dictgen::InsensitiveStr::Ascii("erimentalizes"),
        dictgen::InsensitiveStr::Ascii("erimentalizing"),
        dictgen::InsensitiveStr::Ascii("erimentise"),
        dictgen::InsensitiveStr::Ascii("erimentises"),
        dictgen::InsensitiveStr::Ascii("erimentize"),
        dictgen::InsensitiveStr::Ascii("erimentizes"),
        dictgen::InsensitiveStr::Ascii("ertised"),
        dictgen::InsensitiveStr::Ascii("ertising"),
        dictgen::InsensitiveStr::Ascii("ertized"),
        dictgen::InsensitiveStr::Ascii("ertizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXPERIMENTALIZE_7321825952497189376)],
        &[(0b10010, &ENTRY_EXPERIMENTALIZED_3235996828077232088)],
        &[(0b10010, &ENTRY_EXPERIMENTALIZES_17353857217605159387)],
        &[(0b10010, &ENTRY_EXPERIMENTALIZING_8250407124148404694)],
        &[(0b01001, &ENTRY_EXPERIMENTALIZE_7321825952497189376)],
        &[(0b01001, &ENTRY_EXPERIMENTALIZED_3235996828077232088)],
        &[(0b01001, &ENTRY_EXPERIMENTALIZES_17353857217605159387)],
        &[(0b01001, &ENTRY_EXPERIMENTALIZING_8250407124148404694)],
        &[(0b10010, &ENTRY_EXPERIMENTIZE_12814319320920140623)],
        &[(0b10010, &ENTRY_EXPERIMENTIZES_9176567868167120281)],
        &[(0b01001, &ENTRY_EXPERIMENTIZE_12814319320920140623)],
        &[(0b01001, &ENTRY_EXPERIMENTIZES_9176567868167120281)],
        &[(0b10010, &ENTRY_EXPERTIZED_9523121825282850630)],
        &[(0b10010, &ENTRY_EXPERTIZING_14124314311673129338)],
        &[(0b01001, &ENTRY_EXPERTIZED_9523121825282850630)],
        &[(0b01001, &ENTRY_EXPERTIZING_14124314311673129338)],
    ],
    range: 7..=14,
};

static VARS_EXO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXO_CHILDREN),
    value: None,
};

pub static VARS_EXO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rcisation"),
        dictgen::InsensitiveStr::Ascii("rcisement"),
        dictgen::InsensitiveStr::Ascii("rciser"),
        dictgen::InsensitiveStr::Ascii("rcisers"),
        dictgen::InsensitiveStr::Ascii("rcization"),
        dictgen::InsensitiveStr::Ascii("rcize"),
        dictgen::InsensitiveStr::Ascii("rcized"),
        dictgen::InsensitiveStr::Ascii("rcizement"),
        dictgen::InsensitiveStr::Ascii("rcizer"),
        dictgen::InsensitiveStr::Ascii("rcizers"),
        dictgen::InsensitiveStr::Ascii("rcizes"),
        dictgen::InsensitiveStr::Ascii("rcizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXORCIZATION_7841196157883660249)],
        &[(0b10010, &ENTRY_EXORCIZEMENT_13755936147137266553)],
        &[(0b10010, &ENTRY_EXORCIZER_10300614530359206460)],
        &[(0b10010, &ENTRY_EXORCIZERS_15464358492441086034)],
        &[(0b01001, &ENTRY_EXORCIZATION_7841196157883660249)],
        &[(0b01001, &ENTRY_EXORCISE_9017869478115489494)],
        &[(0b01001, &ENTRY_EXORCISED_12908864464482354367)],
        &[(0b01001, &ENTRY_EXORCIZEMENT_13755936147137266553)],
        &[(0b01001, &ENTRY_EXORCIZER_10300614530359206460)],
        &[(0b01001, &ENTRY_EXORCIZERS_15464358492441086034)],
        &[(0b01001, &ENTRY_EXORCISES_3937603215249944418)],
        &[(0b01001, &ENTRY_EXORCISING_9037133836520531203)],
    ],
    range: 5..=9,
};

static VARS_EXI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXI_CHILDREN),
    value: None,
};

pub static VARS_EXI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("stentialise"),
        dictgen::InsensitiveStr::Ascii("stentialises"),
        dictgen::InsensitiveStr::Ascii("stentialize"),
        dictgen::InsensitiveStr::Ascii("stentializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXISTENTIALIZE_7223214416858975418)],
        &[(0b10010, &ENTRY_EXISTENTIALIZES_8959667143883061799)],
        &[(0b01001, &ENTRY_EXISTENTIALIZE_7223214416858975418)],
        &[(0b01001, &ENTRY_EXISTENTIALIZES_8959667143883061799)],
    ],
    range: 11..=12,
};

static VARS_EXH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXH_CHILDREN),
    value: None,
};

pub static VARS_EXH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ibitionise"),
        dictgen::InsensitiveStr::Ascii("ibitionises"),
        dictgen::InsensitiveStr::Ascii("ibitionize"),
        dictgen::InsensitiveStr::Ascii("ibitionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXHIBITIONIZE_8148713998545988736)],
        &[(0b10010, &ENTRY_EXHIBITIONIZES_9279135115141727061)],
        &[(0b01001, &ENTRY_EXHIBITIONIZE_8148713998545988736)],
        &[(0b01001, &ENTRY_EXHIBITIONIZES_9279135115141727061)],
    ],
    range: 10..=11,
};

static VARS_EXE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXE_CHILDREN),
    value: None,
};

pub static VARS_EXE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("stuate")],
    values: &[&[(0b00001, &ENTRY_EXESTUATE_9637260798228903273)]],
    range: 6..=6,
};

static VARS_EXC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXC_CHILDREN),
    value: None,
};

pub static VARS_EXC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ursionise"),
        dictgen::InsensitiveStr::Ascii("ursionised"),
        dictgen::InsensitiveStr::Ascii("ursionises"),
        dictgen::InsensitiveStr::Ascii("ursionising"),
        dictgen::InsensitiveStr::Ascii("ursionize"),
        dictgen::InsensitiveStr::Ascii("ursionized"),
        dictgen::InsensitiveStr::Ascii("ursionizes"),
        dictgen::InsensitiveStr::Ascii("ursionizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EXCURSIONIZE_6141947279836282456)],
        &[(0b10010, &ENTRY_EXCURSIONIZED_1665688933464332989)],
        &[(0b10010, &ENTRY_EXCURSIONIZES_8190667252177395210)],
        &[(0b10010, &ENTRY_EXCURSIONIZING_17254186462773543752)],
        &[(0b01001, &ENTRY_EXCURSIONIZE_6141947279836282456)],
        &[(0b01001, &ENTRY_EXCURSIONIZED_1665688933464332989)],
        &[(0b01001, &ENTRY_EXCURSIONIZES_8190667252177395210)],
        &[(0b01001, &ENTRY_EXCURSIONIZING_17254186462773543752)],
    ],
    range: 9..=11,
};

static VARS_EXA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EXA_CHILDREN),
    value: None,
};

pub static VARS_EXA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("estuate")],
    values: &[&[(0b11010, &ENTRY_EXESTUATE_9637260798228903273)]],
    range: 7..=7,
};

static VARS_EV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EV_CHILDREN),
    value: None,
};

pub static VARS_EV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("angelisation"),
        dictgen::InsensitiveStr::Ascii("angelisations"),
        dictgen::InsensitiveStr::Ascii("angelise"),
        dictgen::InsensitiveStr::Ascii("angelised"),
        dictgen::InsensitiveStr::Ascii("angeliser"),
        dictgen::InsensitiveStr::Ascii("angelisers"),
        dictgen::InsensitiveStr::Ascii("angelises"),
        dictgen::InsensitiveStr::Ascii("angelising"),
        dictgen::InsensitiveStr::Ascii("angelization"),
        dictgen::InsensitiveStr::Ascii("angelizations"),
        dictgen::InsensitiveStr::Ascii("angelize"),
        dictgen::InsensitiveStr::Ascii("angelized"),
        dictgen::InsensitiveStr::Ascii("angelizer"),
        dictgen::InsensitiveStr::Ascii("angelizers"),
        dictgen::InsensitiveStr::Ascii("angelizes"),
        dictgen::InsensitiveStr::Ascii("angelizing"),
        dictgen::InsensitiveStr::Ascii("entualise"),
        dictgen::InsensitiveStr::Ascii("entualised"),
        dictgen::InsensitiveStr::Ascii("entualises"),
        dictgen::InsensitiveStr::Ascii("entualising"),
        dictgen::InsensitiveStr::Ascii("entualize"),
        dictgen::InsensitiveStr::Ascii("entualized"),
        dictgen::InsensitiveStr::Ascii("entualizes"),
        dictgen::InsensitiveStr::Ascii("entualizing"),
        dictgen::InsensitiveStr::Ascii("iler"),
        dictgen::InsensitiveStr::Ascii("ilest"),
        dictgen::InsensitiveStr::Ascii("iller"),
        dictgen::InsensitiveStr::Ascii("illest"),
        dictgen::InsensitiveStr::Ascii("iternal"),
        dictgen::InsensitiveStr::Ascii("olutionise"),
        dictgen::InsensitiveStr::Ascii("olutionises"),
        dictgen::InsensitiveStr::Ascii("olutionize"),
        dictgen::InsensitiveStr::Ascii("olutionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EVANGELIZATION_4680427557456788664)],
        &[(0b10010, &ENTRY_EVANGELIZATIONS_14789777873996157817)],
        &[(0b10010, &ENTRY_EVANGELIZE_14654810833594718867)],
        &[(0b10010, &ENTRY_EVANGELIZED_17876535001172708816)],
        &[(0b10010, &ENTRY_EVANGELIZER_23648629311545236)],
        &[(0b10010, &ENTRY_EVANGELIZERS_14546686203602221124)],
        &[(0b10010, &ENTRY_EVANGELIZES_1437826998377524710)],
        &[(0b10010, &ENTRY_EVANGELIZING_16366309279292917989)],
        &[(0b01001, &ENTRY_EVANGELIZATION_4680427557456788664)],
        &[(0b01001, &ENTRY_EVANGELIZATIONS_14789777873996157817)],
        &[(0b01001, &ENTRY_EVANGELIZE_14654810833594718867)],
        &[(0b01001, &ENTRY_EVANGELIZED_17876535001172708816)],
        &[(0b01001, &ENTRY_EVANGELIZER_23648629311545236)],
        &[(0b01001, &ENTRY_EVANGELIZERS_14546686203602221124)],
        &[(0b01001, &ENTRY_EVANGELIZES_1437826998377524710)],
        &[(0b01001, &ENTRY_EVANGELIZING_16366309279292917989)],
        &[(0b10010, &ENTRY_EVENTUALIZE_367328542530437546)],
        &[(0b10010, &ENTRY_EVENTUALIZED_6892945154115451414)],
        &[(0b10010, &ENTRY_EVENTUALIZES_2708156416876716226)],
        &[(0b10010, &ENTRY_EVENTUALIZING_3264561079067185461)],
        &[(0b01001, &ENTRY_EVENTUALIZE_367328542530437546)],
        &[(0b01001, &ENTRY_EVENTUALIZED_6892945154115451414)],
        &[(0b01001, &ENTRY_EVENTUALIZES_2708156416876716226)],
        &[(0b01001, &ENTRY_EVENTUALIZING_3264561079067185461)],
        &[(0b00001, &ENTRY_EVILER_16165460214642184499)],
        &[(0b00001, &ENTRY_EVILEST_2003136876659939656)],
        &[(0b11010, &ENTRY_EVILER_16165460214642184499)],
        &[(0b11010, &ENTRY_EVILEST_2003136876659939656)],
        &[(0b00001, &ENTRY_EVITERNAL_11859651719653588022)],
        &[(0b10010, &ENTRY_EVOLUTIONIZE_8517112820891861723)],
        &[(0b10010, &ENTRY_EVOLUTIONIZES_7496995105206806629)],
        &[(0b01001, &ENTRY_EVOLUTIONIZE_8517112820891861723)],
        &[(0b01001, &ENTRY_EVOLUTIONIZES_7496995105206806629)],
    ],
    range: 4..=13,
};

static VARS_EU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EU_CHILDREN),
    value: None,
};

static VARS_EU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    Some(&VARS_EUD_NODE),
    None,
    None,
    None,
    Some(&VARS_EUH_NODE),
    None,
    None,
    None,
    Some(&VARS_EUL_NODE),
    None,
    Some(&VARS_EUN_NODE),
    None,
    Some(&VARS_EUP_NODE),
    None,
    Some(&VARS_EUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUR_CHILDREN),
    value: None,
};

pub static VARS_EUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("opeanisation"),
        dictgen::InsensitiveStr::Ascii("opeanisations"),
        dictgen::InsensitiveStr::Ascii("opeanise"),
        dictgen::InsensitiveStr::Ascii("opeanised"),
        dictgen::InsensitiveStr::Ascii("opeanises"),
        dictgen::InsensitiveStr::Ascii("opeanising"),
        dictgen::InsensitiveStr::Ascii("opeanization"),
        dictgen::InsensitiveStr::Ascii("opeanizations"),
        dictgen::InsensitiveStr::Ascii("opeanize"),
        dictgen::InsensitiveStr::Ascii("opeanized"),
        dictgen::InsensitiveStr::Ascii("opeanizes"),
        dictgen::InsensitiveStr::Ascii("opeanizing"),
        dictgen::InsensitiveStr::Ascii("yalae"),
        dictgen::InsensitiveStr::Ascii("yale"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EUROPEANIZATION_1560895436028194898)],
        &[(0b10010, &ENTRY_EUROPEANIZATIONS_10170958288412142340)],
        &[(0b10010, &ENTRY_EUROPEANIZE_9458498374082461253)],
        &[(0b10010, &ENTRY_EUROPEANIZED_4342167856841628431)],
        &[(0b10010, &ENTRY_EUROPEANIZES_12996997230914775868)],
        &[(0b10010, &ENTRY_EUROPEANIZING_17501868806425018896)],
        &[(0b01001, &ENTRY_EUROPEANIZATION_1560895436028194898)],
        &[(0b01001, &ENTRY_EUROPEANIZATIONS_10170958288412142340)],
        &[(0b01001, &ENTRY_EUROPEANIZE_9458498374082461253)],
        &[(0b01001, &ENTRY_EUROPEANIZED_4342167856841628431)],
        &[(0b01001, &ENTRY_EUROPEANIZES_12996997230914775868)],
        &[(0b01001, &ENTRY_EUROPEANIZING_17501868806425018896)],
        &[(0b11010, &ENTRY_EURYALE_4488395712087565374)],
        &[(0b00001, &ENTRY_EURYALE_4488395712087565374)],
    ],
    range: 4..=13,
};

static VARS_EUP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUP_CHILDREN),
    value: None,
};

pub static VARS_EUP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hemisation"),
        dictgen::InsensitiveStr::Ascii("hemise"),
        dictgen::InsensitiveStr::Ascii("hemised"),
        dictgen::InsensitiveStr::Ascii("hemiser"),
        dictgen::InsensitiveStr::Ascii("hemisers"),
        dictgen::InsensitiveStr::Ascii("hemises"),
        dictgen::InsensitiveStr::Ascii("hemising"),
        dictgen::InsensitiveStr::Ascii("hemization"),
        dictgen::InsensitiveStr::Ascii("hemize"),
        dictgen::InsensitiveStr::Ascii("hemized"),
        dictgen::InsensitiveStr::Ascii("hemizer"),
        dictgen::InsensitiveStr::Ascii("hemizers"),
        dictgen::InsensitiveStr::Ascii("hemizes"),
        dictgen::InsensitiveStr::Ascii("hemizing"),
        dictgen::InsensitiveStr::Ascii("honisation"),
        dictgen::InsensitiveStr::Ascii("honise"),
        dictgen::InsensitiveStr::Ascii("honised"),
        dictgen::InsensitiveStr::Ascii("honises"),
        dictgen::InsensitiveStr::Ascii("honising"),
        dictgen::InsensitiveStr::Ascii("honization"),
        dictgen::InsensitiveStr::Ascii("honize"),
        dictgen::InsensitiveStr::Ascii("honized"),
        dictgen::InsensitiveStr::Ascii("honizes"),
        dictgen::InsensitiveStr::Ascii("honizing"),
        dictgen::InsensitiveStr::Ascii("huise"),
        dictgen::InsensitiveStr::Ascii("huised"),
        dictgen::InsensitiveStr::Ascii("huises"),
        dictgen::InsensitiveStr::Ascii("huising"),
        dictgen::InsensitiveStr::Ascii("huize"),
        dictgen::InsensitiveStr::Ascii("huized"),
        dictgen::InsensitiveStr::Ascii("huizes"),
        dictgen::InsensitiveStr::Ascii("huizing"),
        dictgen::InsensitiveStr::Ascii("nea"),
        dictgen::InsensitiveStr::Ascii("neas"),
        dictgen::InsensitiveStr::Ascii("neic"),
        dictgen::InsensitiveStr::Ascii("noea"),
        dictgen::InsensitiveStr::Ascii("noeas"),
        dictgen::InsensitiveStr::Ascii("noeic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EUPHEMIZATION_15897062775810681100)],
        &[(0b10010, &ENTRY_EUPHEMIZE_6156608839130565166)],
        &[(0b10010, &ENTRY_EUPHEMIZED_16524474124949436387)],
        &[(0b10010, &ENTRY_EUPHEMIZER_3905220143608307778)],
        &[(0b10010, &ENTRY_EUPHEMIZERS_14865306922922439267)],
        &[(0b10010, &ENTRY_EUPHEMIZES_13615629412067350528)],
        &[(0b10010, &ENTRY_EUPHEMIZING_14044452417298877788)],
        &[(0b01001, &ENTRY_EUPHEMIZATION_15897062775810681100)],
        &[(0b01001, &ENTRY_EUPHEMIZE_6156608839130565166)],
        &[(0b01001, &ENTRY_EUPHEMIZED_16524474124949436387)],
        &[(0b01001, &ENTRY_EUPHEMIZER_3905220143608307778)],
        &[(0b01001, &ENTRY_EUPHEMIZERS_14865306922922439267)],
        &[(0b01001, &ENTRY_EUPHEMIZES_13615629412067350528)],
        &[(0b01001, &ENTRY_EUPHEMIZING_14044452417298877788)],
        &[(0b10010, &ENTRY_EUPHONIZATION_8160800683971054658)],
        &[(0b10010, &ENTRY_EUPHONIZE_12154684566192054671)],
        &[(0b10010, &ENTRY_EUPHONIZED_2332221337646658561)],
        &[(0b10010, &ENTRY_EUPHONIZES_10361394233532999333)],
        &[(0b10010, &ENTRY_EUPHONIZING_12869225507816001400)],
        &[(0b01001, &ENTRY_EUPHONIZATION_8160800683971054658)],
        &[(0b01001, &ENTRY_EUPHONIZE_12154684566192054671)],
        &[(0b01001, &ENTRY_EUPHONIZED_2332221337646658561)],
        &[(0b01001, &ENTRY_EUPHONIZES_10361394233532999333)],
        &[(0b01001, &ENTRY_EUPHONIZING_12869225507816001400)],
        &[(0b10010, &ENTRY_EUPHUIZE_7719186029258614802)],
        &[(0b10010, &ENTRY_EUPHUIZED_16530053689080256866)],
        &[(0b10010, &ENTRY_EUPHUIZES_1610646119362678571)],
        &[(0b10010, &ENTRY_EUPHUIZING_13793329409991103775)],
        &[(0b01001, &ENTRY_EUPHUIZE_7719186029258614802)],
        &[(0b01001, &ENTRY_EUPHUIZED_16530053689080256866)],
        &[(0b01001, &ENTRY_EUPHUIZES_1610646119362678571)],
        &[(0b01001, &ENTRY_EUPHUIZING_13793329409991103775)],
        &[(0b10001, &ENTRY_EUPNEA_15696889609657452284)],
        &[(0b10001, &ENTRY_EUPNEAS_17113263914966538934)],
        &[(0b10001, &ENTRY_EUPNEIC_10760124621699958430)],
        &[(0b11010, &ENTRY_EUPNEA_15696889609657452284)],
        &[(0b11010, &ENTRY_EUPNEAS_17113263914966538934)],
        &[(0b11010, &ENTRY_EUPNEIC_10760124621699958430)],
    ],
    range: 3..=10,
};

static VARS_EUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUN_CHILDREN),
    value: None,
};

pub static VARS_EUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uchise"),
        dictgen::InsensitiveStr::Ascii("uchised"),
        dictgen::InsensitiveStr::Ascii("uchises"),
        dictgen::InsensitiveStr::Ascii("uchising"),
        dictgen::InsensitiveStr::Ascii("uchize"),
        dictgen::InsensitiveStr::Ascii("uchized"),
        dictgen::InsensitiveStr::Ascii("uchizes"),
        dictgen::InsensitiveStr::Ascii("uchizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EUNUCHIZE_15135167016143668512)],
        &[(0b10010, &ENTRY_EUNUCHIZED_13625235435443656462)],
        &[(0b10010, &ENTRY_EUNUCHIZES_13328477625215260244)],
        &[(0b10010, &ENTRY_EUNUCHIZING_1999758532637837177)],
        &[(0b01001, &ENTRY_EUNUCHIZE_15135167016143668512)],
        &[(0b01001, &ENTRY_EUNUCHIZED_13625235435443656462)],
        &[(0b01001, &ENTRY_EUNUCHIZES_13328477625215260244)],
        &[(0b01001, &ENTRY_EUNUCHIZING_1999758532637837177)],
    ],
    range: 6..=8,
};

static VARS_EUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUL_CHILDREN),
    value: None,
};

pub static VARS_EUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogisation"),
        dictgen::InsensitiveStr::Ascii("ogisations"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogiser"),
        dictgen::InsensitiveStr::Ascii("ogisers"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogization"),
        dictgen::InsensitiveStr::Ascii("ogizations"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizer"),
        dictgen::InsensitiveStr::Ascii("ogizers"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EULOGIZATION_10282426959041271101)],
        &[(0b10010, &ENTRY_EULOGIZATIONS_7636756562230100487)],
        &[(0b10010, &ENTRY_EULOGIZE_1653837351412814344)],
        &[(0b10010, &ENTRY_EULOGIZED_2725015015260591952)],
        &[(0b10010, &ENTRY_EULOGIZER_1964342767045376178)],
        &[(0b10010, &ENTRY_EULOGIZERS_14136473823163628988)],
        &[(0b10010, &ENTRY_EULOGIZES_14586567692374933834)],
        &[(0b10010, &ENTRY_EULOGIZING_12476629388826192151)],
        &[(0b01001, &ENTRY_EULOGIZATION_10282426959041271101)],
        &[(0b01001, &ENTRY_EULOGIZATIONS_7636756562230100487)],
        &[(0b01001, &ENTRY_EULOGIZE_1653837351412814344)],
        &[(0b01001, &ENTRY_EULOGIZED_2725015015260591952)],
        &[(0b01001, &ENTRY_EULOGIZER_1964342767045376178)],
        &[(0b01001, &ENTRY_EULOGIZERS_14136473823163628988)],
        &[(0b01001, &ENTRY_EULOGIZES_14586567692374933834)],
        &[(0b01001, &ENTRY_EULOGIZING_12476629388826192151)],
    ],
    range: 5..=10,
};

static VARS_EUH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUH_CHILDREN),
    value: None,
};

pub static VARS_EUH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emerise"),
        dictgen::InsensitiveStr::Ascii("emerised"),
        dictgen::InsensitiveStr::Ascii("emerises"),
        dictgen::InsensitiveStr::Ascii("emerising"),
        dictgen::InsensitiveStr::Ascii("emerize"),
        dictgen::InsensitiveStr::Ascii("emerized"),
        dictgen::InsensitiveStr::Ascii("emerizes"),
        dictgen::InsensitiveStr::Ascii("emerizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EUHEMERIZE_10861960486485255136)],
        &[(0b10010, &ENTRY_EUHEMERIZED_13249306373968955924)],
        &[(0b10010, &ENTRY_EUHEMERIZES_2599757245144591712)],
        &[(0b10010, &ENTRY_EUHEMERIZING_9558743899414823460)],
        &[(0b01001, &ENTRY_EUHEMERIZE_10861960486485255136)],
        &[(0b01001, &ENTRY_EUHEMERIZED_13249306373968955924)],
        &[(0b01001, &ENTRY_EUHEMERIZES_2599757245144591712)],
        &[(0b01001, &ENTRY_EUHEMERIZING_9558743899414823460)],
    ],
    range: 7..=9,
};

static VARS_EUD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EUD_CHILDREN),
    value: None,
};

pub static VARS_EUD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemon"),
        dictgen::InsensitiveStr::Ascii("aemonia"),
        dictgen::InsensitiveStr::Ascii("aemonic"),
        dictgen::InsensitiveStr::Ascii("aemonics"),
        dictgen::InsensitiveStr::Ascii("aemonism"),
        dictgen::InsensitiveStr::Ascii("aemonisms"),
        dictgen::InsensitiveStr::Ascii("aemonist"),
        dictgen::InsensitiveStr::Ascii("aemonistic"),
        dictgen::InsensitiveStr::Ascii("aemonistical"),
        dictgen::InsensitiveStr::Ascii("aemonistically"),
        dictgen::InsensitiveStr::Ascii("aemonists"),
        dictgen::InsensitiveStr::Ascii("aemons"),
        dictgen::InsensitiveStr::Ascii("aemony"),
        dictgen::InsensitiveStr::Ascii("emon"),
        dictgen::InsensitiveStr::Ascii("emonia"),
        dictgen::InsensitiveStr::Ascii("emonic"),
        dictgen::InsensitiveStr::Ascii("emonics"),
        dictgen::InsensitiveStr::Ascii("emonism"),
        dictgen::InsensitiveStr::Ascii("emonisms"),
        dictgen::InsensitiveStr::Ascii("emonist"),
        dictgen::InsensitiveStr::Ascii("emonistic"),
        dictgen::InsensitiveStr::Ascii("emonistical"),
        dictgen::InsensitiveStr::Ascii("emonistically"),
        dictgen::InsensitiveStr::Ascii("emonists"),
        dictgen::InsensitiveStr::Ascii("emons"),
        dictgen::InsensitiveStr::Ascii("emony"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EUDEMON_11438303724932164772)],
        &[(0b11010, &ENTRY_EUDEMONIA_8536611909974853285)],
        &[(0b11010, &ENTRY_EUDEMONIC_10703096338080832052)],
        &[(0b11010, &ENTRY_EUDEMONICS_11983069269785700336)],
        &[(0b11010, &ENTRY_EUDEMONISM_2030451125927147437)],
        &[(0b11010, &ENTRY_EUDEMONISMS_9663152886088963814)],
        &[(0b11010, &ENTRY_EUDEMONIST_10437519314337880945)],
        &[(0b11010, &ENTRY_EUDEMONISTIC_4092483053014414870)],
        &[(0b11010, &ENTRY_EUDEMONISTICAL_5594575273383737360)],
        &[(0b11010, &ENTRY_EUDEMONISTICALLY_11557458762944374366)],
        &[(0b11010, &ENTRY_EUDEMONISTS_8607780052774605016)],
        &[(0b11010, &ENTRY_EUDEMONS_619440478160622096)],
        &[(0b11010, &ENTRY_EUDEMONY_7203436464418206960)],
        &[(0b00001, &ENTRY_EUDEMON_11438303724932164772)],
        &[(0b00001, &ENTRY_EUDEMONIA_8536611909974853285)],
        &[(0b00001, &ENTRY_EUDEMONIC_10703096338080832052)],
        &[(0b00001, &ENTRY_EUDEMONICS_11983069269785700336)],
        &[(0b00001, &ENTRY_EUDEMONISM_2030451125927147437)],
        &[(0b00001, &ENTRY_EUDEMONISMS_9663152886088963814)],
        &[(0b00001, &ENTRY_EUDEMONIST_10437519314337880945)],
        &[(0b00001, &ENTRY_EUDEMONISTIC_4092483053014414870)],
        &[(0b00001, &ENTRY_EUDEMONISTICAL_5594575273383737360)],
        &[(0b00001, &ENTRY_EUDEMONISTICALLY_11557458762944374366)],
        &[(0b00001, &ENTRY_EUDEMONISTS_8607780052774605016)],
        &[(0b00001, &ENTRY_EUDEMONS_619440478160622096)],
        &[(0b00001, &ENTRY_EUDEMONY_7203436464418206960)],
    ],
    range: 4..=14,
};

static VARS_ET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ET_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_ET_11650800039480951541)]),
};

static VARS_ET_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_ETE_NODE),
    None,
    None,
    Some(&VARS_ETH_NODE),
    Some(&VARS_ETI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ETY_NODE),
    None,
];

static VARS_ETY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ETY_CHILDREN),
    value: None,
};

pub static VARS_ETY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mologisable"),
        dictgen::InsensitiveStr::Ascii("mologisation"),
        dictgen::InsensitiveStr::Ascii("mologise"),
        dictgen::InsensitiveStr::Ascii("mologised"),
        dictgen::InsensitiveStr::Ascii("mologises"),
        dictgen::InsensitiveStr::Ascii("mologising"),
        dictgen::InsensitiveStr::Ascii("mologizable"),
        dictgen::InsensitiveStr::Ascii("mologization"),
        dictgen::InsensitiveStr::Ascii("mologize"),
        dictgen::InsensitiveStr::Ascii("mologized"),
        dictgen::InsensitiveStr::Ascii("mologizes"),
        dictgen::InsensitiveStr::Ascii("mologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ETYMOLOGIZABLE_14324009501183818334)],
        &[(0b10010, &ENTRY_ETYMOLOGIZATION_6720014631573230453)],
        &[(0b10010, &ENTRY_ETYMOLOGIZE_9732898285094826377)],
        &[(0b10010, &ENTRY_ETYMOLOGIZED_9179162719754519975)],
        &[(0b10010, &ENTRY_ETYMOLOGIZES_18258268798885199036)],
        &[(0b10010, &ENTRY_ETYMOLOGIZING_10793154235770650022)],
        &[(0b01001, &ENTRY_ETYMOLOGIZABLE_14324009501183818334)],
        &[(0b01001, &ENTRY_ETYMOLOGIZATION_6720014631573230453)],
        &[(0b01001, &ENTRY_ETYMOLOGIZE_9732898285094826377)],
        &[(0b01001, &ENTRY_ETYMOLOGIZED_9179162719754519975)],
        &[(0b01001, &ENTRY_ETYMOLOGIZES_18258268798885199036)],
        &[(0b01001, &ENTRY_ETYMOLOGIZING_10793154235770650022)],
    ],
    range: 8..=12,
};

static VARS_ETI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ETI_CHILDREN),
    value: None,
};

pub static VARS_ETI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogenic"),
        dictgen::InsensitiveStr::Ascii("ologically"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ologue"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("ophyllin"),
        dictgen::InsensitiveStr::Ascii("otropic"),
        dictgen::InsensitiveStr::Ascii("otropically"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ETIOGENIC_4607596180327733291)],
        &[(0b11001, &ENTRY_ETIOLOGICALLY_16961054798674884692)],
        &[(0b10001, &ENTRY_ETIOLOGIST_11212980661305626571)],
        &[(0b10001, &ENTRY_ETIOLOGUE_3427764260416926249)],
        &[(0b11001, &ENTRY_ETIOLOGY_7123968270032580321)],
        &[(0b10001, &ENTRY_ETIOPHYLLIN_9404514496968390932)],
        &[(0b10001, &ENTRY_ETIOTROPIC_17191333273430729692)],
        &[(0b10001, &ENTRY_ETIOTROPICALLY_9902369940420748380)],
    ],
    range: 5..=11,
};

static VARS_ETH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ETH_CHILDREN),
    value: None,
};

pub static VARS_ETH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("erealisation"),
        dictgen::InsensitiveStr::Ascii("erealisations"),
        dictgen::InsensitiveStr::Ascii("erealise"),
        dictgen::InsensitiveStr::Ascii("erealised"),
        dictgen::InsensitiveStr::Ascii("erealises"),
        dictgen::InsensitiveStr::Ascii("erealising"),
        dictgen::InsensitiveStr::Ascii("erealization"),
        dictgen::InsensitiveStr::Ascii("erealizations"),
        dictgen::InsensitiveStr::Ascii("erealize"),
        dictgen::InsensitiveStr::Ascii("erealized"),
        dictgen::InsensitiveStr::Ascii("erealizes"),
        dictgen::InsensitiveStr::Ascii("erealizing"),
        dictgen::InsensitiveStr::Ascii("ered"),
        dictgen::InsensitiveStr::Ascii("erialisation"),
        dictgen::InsensitiveStr::Ascii("erialise"),
        dictgen::InsensitiveStr::Ascii("erialised"),
        dictgen::InsensitiveStr::Ascii("erialising"),
        dictgen::InsensitiveStr::Ascii("erialization"),
        dictgen::InsensitiveStr::Ascii("erialize"),
        dictgen::InsensitiveStr::Ascii("erialized"),
        dictgen::InsensitiveStr::Ascii("erializing"),
        dictgen::InsensitiveStr::Ascii("eric"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("eriser"),
        dictgen::InsensitiveStr::Ascii("erisers"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizer"),
        dictgen::InsensitiveStr::Ascii("erizers"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("icisation"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icization"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("nicise"),
        dictgen::InsensitiveStr::Ascii("nicises"),
        dictgen::InsensitiveStr::Ascii("nicize"),
        dictgen::InsensitiveStr::Ascii("nicizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ETHELING_7453000440584654761)],
        &[(0b10010, &ENTRY_ETHEREALIZATION_12734652389847905816)],
        &[(0b10010, &ENTRY_ETHEREALIZATIONS_2132392675240347392)],
        &[(0b10010, &ENTRY_ETHEREALIZE_2065340124732116568)],
        &[(0b10010, &ENTRY_ETHEREALIZED_5421449992122948198)],
        &[(0b10010, &ENTRY_ETHEREALIZES_5231734843750416436)],
        &[(0b10010, &ENTRY_ETHEREALIZING_17209337922860403926)],
        &[(0b01001, &ENTRY_ETHEREALIZATION_12734652389847905816)],
        &[(0b01001, &ENTRY_ETHEREALIZATIONS_2132392675240347392)],
        &[(0b01001, &ENTRY_ETHEREALIZE_2065340124732116568)],
        &[(0b01001, &ENTRY_ETHEREALIZED_5421449992122948198)],
        &[(0b01001, &ENTRY_ETHEREALIZES_5231734843750416436)],
        &[(0b01001, &ENTRY_ETHEREALIZING_17209337922860403926)],
        &[(0b00001, &ENTRY_ETHERED_11737830389019716848)],
        &[(0b10010, &ENTRY_ETHERIALIZATION_13934934240531358321)],
        &[(0b10010, &ENTRY_ETHERIALIZE_16410637034856874095)],
        &[(0b10010, &ENTRY_ETHERIALIZED_6425316747358472251)],
        &[(0b10010, &ENTRY_ETHERIALIZING_5420182430706962967)],
        &[(0b01001, &ENTRY_ETHERIALIZATION_13934934240531358321)],
        &[(0b01001, &ENTRY_ETHERIALIZE_16410637034856874095)],
        &[(0b01001, &ENTRY_ETHERIALIZED_6425316747358472251)],
        &[(0b01001, &ENTRY_ETHERIALIZING_5420182430706962967)],
        &[(0b00001, &ENTRY_ETHERIC_14308840270744949246)],
        &[(0b10010, &ENTRY_ETHERIZATION_2978885687909295823)],
        &[(0b10010, &ENTRY_ETHERIZATIONS_12592394080916973256)],
        &[(0b10010, &ENTRY_ETHERIZE_14089274929682497230)],
        &[(0b10010, &ENTRY_ETHERIZED_13463455547519294082)],
        &[(0b10010, &ENTRY_ETHERIZER_10217889819429808699)],
        &[(0b10010, &ENTRY_ETHERIZERS_10538480316981131131)],
        &[(0b10010, &ENTRY_ETHERIZES_13469750050699304076)],
        &[(0b10010, &ENTRY_ETHERIZING_5812365847799688656)],
        &[(0b01001, &ENTRY_ETHERIZATION_2978885687909295823)],
        &[(0b01001, &ENTRY_ETHERIZATIONS_12592394080916973256)],
        &[(0b01001, &ENTRY_ETHERIZE_14089274929682497230)],
        &[(0b01001, &ENTRY_ETHERIZED_13463455547519294082)],
        &[(0b01001, &ENTRY_ETHERIZER_10217889819429808699)],
        &[(0b01001, &ENTRY_ETHERIZERS_10538480316981131131)],
        &[(0b01001, &ENTRY_ETHERIZES_13469750050699304076)],
        &[(0b01001, &ENTRY_ETHERIZING_5812365847799688656)],
        &[(0b10010, &ENTRY_ETHICIZATION_7982960618336992609)],
        &[(0b10010, &ENTRY_ETHICIZE_9319969408983326697)],
        &[(0b10010, &ENTRY_ETHICIZED_13298420094237367669)],
        &[(0b10010, &ENTRY_ETHICIZES_4425545207707744116)],
        &[(0b10010, &ENTRY_ETHICIZING_13920935019894378060)],
        &[(0b01001, &ENTRY_ETHICIZATION_7982960618336992609)],
        &[(0b01001, &ENTRY_ETHICIZE_9319969408983326697)],
        &[(0b01001, &ENTRY_ETHICIZED_13298420094237367669)],
        &[(0b01001, &ENTRY_ETHICIZES_4425545207707744116)],
        &[(0b01001, &ENTRY_ETHICIZING_13920935019894378060)],
        &[(0b10010, &ENTRY_ETHNICIZE_9658075899558980564)],
        &[(0b10010, &ENTRY_ETHNICIZES_17717835002455612610)],
        &[(0b01001, &ENTRY_ETHNICIZE_9658075899558980564)],
        &[(0b01001, &ENTRY_ETHNICIZES_17717835002455612610)],
    ],
    range: 4..=13,
};

static VARS_ETE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ETE_CHILDREN),
    value: None,
};

pub static VARS_ETE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rnalisation"),
        dictgen::InsensitiveStr::Ascii("rnalisations"),
        dictgen::InsensitiveStr::Ascii("rnalise"),
        dictgen::InsensitiveStr::Ascii("rnalised"),
        dictgen::InsensitiveStr::Ascii("rnalises"),
        dictgen::InsensitiveStr::Ascii("rnalising"),
        dictgen::InsensitiveStr::Ascii("rnalization"),
        dictgen::InsensitiveStr::Ascii("rnalizations"),
        dictgen::InsensitiveStr::Ascii("rnalize"),
        dictgen::InsensitiveStr::Ascii("rnalized"),
        dictgen::InsensitiveStr::Ascii("rnalizes"),
        dictgen::InsensitiveStr::Ascii("rnalizing"),
        dictgen::InsensitiveStr::Ascii("rnisation"),
        dictgen::InsensitiveStr::Ascii("rnisations"),
        dictgen::InsensitiveStr::Ascii("rnise"),
        dictgen::InsensitiveStr::Ascii("rnised"),
        dictgen::InsensitiveStr::Ascii("rnises"),
        dictgen::InsensitiveStr::Ascii("rnising"),
        dictgen::InsensitiveStr::Ascii("rnization"),
        dictgen::InsensitiveStr::Ascii("rnizations"),
        dictgen::InsensitiveStr::Ascii("rnize"),
        dictgen::InsensitiveStr::Ascii("rnized"),
        dictgen::InsensitiveStr::Ascii("rnizes"),
        dictgen::InsensitiveStr::Ascii("rnizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ETERNALIZATION_3734495480513175198)],
        &[(0b10010, &ENTRY_ETERNALIZATIONS_1580610116895380250)],
        &[(0b10010, &ENTRY_ETERNALIZE_11131798101969437364)],
        &[(0b10010, &ENTRY_ETERNALIZED_9585284058759840856)],
        &[(0b10010, &ENTRY_ETERNALIZES_4326233422849452608)],
        &[(0b10010, &ENTRY_ETERNALIZING_14008573203681681715)],
        &[(0b01001, &ENTRY_ETERNALIZATION_3734495480513175198)],
        &[(0b01001, &ENTRY_ETERNALIZATIONS_1580610116895380250)],
        &[(0b01001, &ENTRY_ETERNALIZE_11131798101969437364)],
        &[(0b01001, &ENTRY_ETERNALIZED_9585284058759840856)],
        &[(0b01001, &ENTRY_ETERNALIZES_4326233422849452608)],
        &[(0b01001, &ENTRY_ETERNALIZING_14008573203681681715)],
        &[(0b10010, &ENTRY_ETERNIZATION_2995449191647800002)],
        &[(0b10010, &ENTRY_ETERNIZATIONS_8586384193807168026)],
        &[(0b10010, &ENTRY_ETERNIZE_9225349190347066102)],
        &[(0b10010, &ENTRY_ETERNIZED_803700093303685693)],
        &[(0b10010, &ENTRY_ETERNIZES_13889836130672451566)],
        &[(0b10010, &ENTRY_ETERNIZING_10174905521874007767)],
        &[(0b01001, &ENTRY_ETERNIZATION_2995449191647800002)],
        &[(0b01001, &ENTRY_ETERNIZATIONS_8586384193807168026)],
        &[(0b01001, &ENTRY_ETERNIZE_9225349190347066102)],
        &[(0b01001, &ENTRY_ETERNIZED_803700093303685693)],
        &[(0b01001, &ENTRY_ETERNIZES_13889836130672451566)],
        &[(0b01001, &ENTRY_ETERNIZING_10174905521874007767)],
    ],
    range: 5..=12,
};

static VARS_ES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ES_CHILDREN),
    value: None,
};

static VARS_ES_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_ESC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ESK_NODE),
    None,
    None,
    None,
    Some(&VARS_ESO_NODE),
    None,
    None,
    None,
    Some(&VARS_ESS_NODE),
    Some(&VARS_EST_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EST_CHILDREN),
    value: None,
};

pub static VARS_EST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("heses"),
        dictgen::InsensitiveStr::Ascii("hesia"),
        dictgen::InsensitiveStr::Ascii("hesias"),
        dictgen::InsensitiveStr::Ascii("hesiogen"),
        dictgen::InsensitiveStr::Ascii("hesiogenic"),
        dictgen::InsensitiveStr::Ascii("hesiogens"),
        dictgen::InsensitiveStr::Ascii("hesis"),
        dictgen::InsensitiveStr::Ascii("hete"),
        dictgen::InsensitiveStr::Ascii("hetes"),
        dictgen::InsensitiveStr::Ascii("hetic"),
        dictgen::InsensitiveStr::Ascii("hetical"),
        dictgen::InsensitiveStr::Ascii("hetically"),
        dictgen::InsensitiveStr::Ascii("hetician"),
        dictgen::InsensitiveStr::Ascii("heticians"),
        dictgen::InsensitiveStr::Ascii("hetics"),
        dictgen::InsensitiveStr::Ascii("ival"),
        dictgen::InsensitiveStr::Ascii("ivate"),
        dictgen::InsensitiveStr::Ascii("ivated"),
        dictgen::InsensitiveStr::Ascii("ivates"),
        dictgen::InsensitiveStr::Ascii("ivating"),
        dictgen::InsensitiveStr::Ascii("ivation"),
        dictgen::InsensitiveStr::Ascii("ivations"),
        dictgen::InsensitiveStr::Ascii("ivator"),
        dictgen::InsensitiveStr::Ascii("ive"),
        dictgen::InsensitiveStr::Ascii("radiol"),
        dictgen::InsensitiveStr::Ascii("radiols"),
        dictgen::InsensitiveStr::Ascii("ral"),
        dictgen::InsensitiveStr::Ascii("rin"),
        dictgen::InsensitiveStr::Ascii("rins"),
        dictgen::InsensitiveStr::Ascii("riol"),
        dictgen::InsensitiveStr::Ascii("riols"),
        dictgen::InsensitiveStr::Ascii("rogen"),
        dictgen::InsensitiveStr::Ascii("rogenic"),
        dictgen::InsensitiveStr::Ascii("rogens"),
        dictgen::InsensitiveStr::Ascii("rone"),
        dictgen::InsensitiveStr::Ascii("rones"),
        dictgen::InsensitiveStr::Ascii("rous"),
        dictgen::InsensitiveStr::Ascii("rual"),
        dictgen::InsensitiveStr::Ascii("ruate"),
        dictgen::InsensitiveStr::Ascii("ruation"),
        dictgen::InsensitiveStr::Ascii("rum"),
        dictgen::InsensitiveStr::Ascii("rums"),
        dictgen::InsensitiveStr::Ascii("rus"),
        dictgen::InsensitiveStr::Ascii("ruses"),
        dictgen::InsensitiveStr::Ascii("uate"),
        dictgen::InsensitiveStr::Ascii("uous"),
        dictgen::InsensitiveStr::Ascii("ure"),
        dictgen::InsensitiveStr::Ascii("us"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ESTERIZATION_1838643342430239163)],
        &[(0b10010, &ENTRY_ESTERIZATIONS_13064103908051692902)],
        &[(0b10010, &ENTRY_ESTERIZE_14328305651236035983)],
        &[(0b10010, &ENTRY_ESTERIZES_1807746540502831909)],
        &[(0b01001, &ENTRY_ESTERIZATION_1838643342430239163)],
        &[(0b01001, &ENTRY_ESTERIZATIONS_13064103908051692902)],
        &[(0b01001, &ENTRY_ESTERIZE_14328305651236035983)],
        &[(0b01001, &ENTRY_ESTERIZES_1807746540502831909)],
        &[(0b00001, &ENTRY_ESTHESES_16116389526306967239)],
        &[(0b00001, &ENTRY_ESTHESIA_12451548753996008599)],
        &[(0b00001, &ENTRY_ESTHESIAS_5684600885047217053)],
        &[(0b00001, &ENTRY_ESTHESIOGEN_10989515066374267030)],
        &[(0b00001, &ENTRY_ESTHESIOGENIC_8056723690025617876)],
        &[(0b00001, &ENTRY_ESTHESIOGENS_8380315319153501054)],
        &[(0b00001, &ENTRY_ESTHESIS_7143001285276086388)],
        &[(0b00001, &ENTRY_AESTHETE_1223222359482085570)],
        &[(0b00001, &ENTRY_AESTHETES_9473189152352933863)],
        &[(0b11001, &ENTRY_AESTHETIC_854984485637846897)],
        &[(0b00001, &ENTRY_ESTHETICAL_827198906307006506)],
        &[(0b00001, &ENTRY_AESTHETICALLY_17149093527344769493)],
        &[(0b01001, &ENTRY_ESTHETICIAN_4531333424171533067)],
        &[(0b01001, &ENTRY_ESTHETICIANS_4428473313020471578)],
        &[(0b11001, &ENTRY_AESTHETICS_9838605701252615431)],
        &[(0b01001, &ENTRY_ESTIVAL_7252793851065540137)],
        &[(0b01001, &ENTRY_ESTIVATE_6682485567558262552)],
        &[(0b01001, &ENTRY_ESTIVATED_17659059957305359175)],
        &[(0b01001, &ENTRY_ESTIVATES_15795900041274255113)],
        &[(0b01001, &ENTRY_ESTIVATING_3590628019702465357)],
        &[(0b01001, &ENTRY_ESTIVATION_970593505059854945)],
        &[(0b01001, &ENTRY_ESTIVATIONS_11925170250729275718)],
        &[(0b00001, &ENTRY_ESTIVATOR_17192827254089360161)],
        &[(0b00001, &ENTRY_ESTIVE_5420134362059951702)],
        &[(0b00001, &ENTRY_ESTRADIOL_634787677538270649)],
        &[(0b00001, &ENTRY_ESTRADIOLS_6587359583583660465)],
        &[(0b00001, &ENTRY_ESTRAL_250960197285450439)],
        &[(0b00001, &ENTRY_ESTRIN_1271537042891040806)],
        &[(0b00001, &ENTRY_ESTRINS_11482863399944620630)],
        &[(0b00001, &ENTRY_ESTRIOL_5700840801301268453)],
        &[(0b00001, &ENTRY_ESTRIOLS_15504531823851684601)],
        &[(0b11001, &ENTRY_ESTROGEN_9296702706992805950)],
        &[(0b11001, &ENTRY_ESTROGENIC_9825757897324531986)],
        &[(0b11001, &ENTRY_ESTROGENS_13879624153768181446)],
        &[(0b00001, &ENTRY_ESTRONE_5235731124564419249)],
        &[(0b00001, &ENTRY_ESTRONES_396980696513423065)],
        &[(0b01001, &ENTRY_ESTROUS_3175557539569890653)],
        &[(0b00001, &ENTRY_ESTRUAL_2760322156873020612)],
        &[(0b00001, &ENTRY_ESTRUATE_9742423605759945651)],
        &[(0b00001, &ENTRY_ESTRUATION_528782982925379226)],
        &[(0b00001, &ENTRY_ESTRUM_80713081920872301)],
        &[(0b00001, &ENTRY_ESTRUMS_13425140989742183588)],
        &[(0b01001, &ENTRY_ESTRUS_12109407348878630371)],
        &[(0b01001, &ENTRY_ESTRUSES_10476871772114155317)],
        &[(0b00001, &ENTRY_ESTUATE_7237204571723121927)],
        &[(0b00001, &ENTRY_ESTUOUS_15581034853542643799)],
        &[(0b00001, &ENTRY_ESTURE_3483676630062562550)],
        &[(0b00001, &ENTRY_ESTUS_10309034292162795617)],
    ],
    range: 2..=10,
};

static VARS_ESS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ESS_CHILDREN),
    value: None,
};

pub static VARS_ESS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("entialise"),
        dictgen::InsensitiveStr::Ascii("entialises"),
        dictgen::InsensitiveStr::Ascii("entialize"),
        dictgen::InsensitiveStr::Ascii("entializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ESSENIZE_17352973219499483146)],
        &[(0b10010, &ENTRY_ESSENIZES_6228789074305241285)],
        &[(0b01001, &ENTRY_ESSENIZE_17352973219499483146)],
        &[(0b01001, &ENTRY_ESSENIZES_6228789074305241285)],
        &[(0b10010, &ENTRY_ESSENTIALIZE_6300653085008787820)],
        &[(0b10010, &ENTRY_ESSENTIALIZES_1314761290667427999)],
        &[(0b01001, &ENTRY_ESSENTIALIZE_6300653085008787820)],
        &[(0b01001, &ENTRY_ESSENTIALIZES_1314761290667427999)],
    ],
    range: 5..=10,
};

static VARS_ESO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ESO_CHILDREN),
    value: None,
};

pub static VARS_ESO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("p"),
        dictgen::InsensitiveStr::Ascii("phagal"),
        dictgen::InsensitiveStr::Ascii("phagean"),
        dictgen::InsensitiveStr::Ascii("phagi"),
        dictgen::InsensitiveStr::Ascii("phagism"),
        dictgen::InsensitiveStr::Ascii("phagismus"),
        dictgen::InsensitiveStr::Ascii("phagitis"),
        dictgen::InsensitiveStr::Ascii("phagus"),
        dictgen::InsensitiveStr::Ascii("phaguses"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ESOP_13490095149926411543)],
        &[(0b10001, &ENTRY_ESOPHAGAL_17089437120427101379)],
        &[(0b10001, &ENTRY_ESOPHAGEAN_1258506141459731259)],
        &[(0b11001, &ENTRY_ESOPHAGI_16651245992122782472)],
        &[(0b10001, &ENTRY_ESOPHAGISM_11099656979396238835)],
        &[(0b10001, &ENTRY_ESOPHAGISMUS_6650076607428716726)],
        &[(0b10001, &ENTRY_ESOPHAGITIS_2344628816303730914)],
        &[(0b10001, &ENTRY_ESOPHAGUS_11192235604123814381)],
        &[(0b01001, &ENTRY_ESOPHAGI_16651245992122782472)],
    ],
    range: 1..=9,
};

static VARS_ESK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ESK_CHILDREN),
    value: None,
};

pub static VARS_ESK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imoised"),
        dictgen::InsensitiveStr::Ascii("imoiseds"),
        dictgen::InsensitiveStr::Ascii("imoized"),
        dictgen::InsensitiveStr::Ascii("imoizeds"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ESKIMOIZED_4978095404438860814)],
        &[(0b10010, &ENTRY_ESKIMOIZEDS_8971879976387648671)],
        &[(0b01001, &ENTRY_ESKIMOIZED_4978095404438860814)],
        &[(0b01001, &ENTRY_ESKIMOIZEDS_8971879976387648671)],
    ],
    range: 7..=8,
};

static VARS_ESC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ESC_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_ESC_734356833349788703)]),
};

pub static VARS_ESC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alades"),
        dictgen::InsensitiveStr::Ascii("aladoes"),
        dictgen::InsensitiveStr::Ascii("hynite"),
        dictgen::InsensitiveStr::Ascii("ulapian"),
        dictgen::InsensitiveStr::Ascii("uletin"),
        dictgen::InsensitiveStr::Ascii("ulin"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ESCALADES_8447970127642962693)],
        &[(0b11010, &ENTRY_ESCALADES_8447970127642962693)],
        &[(0b00001, &ENTRY_ESCHYNITE_18313041144585925088)],
        &[(0b00001, &ENTRY_ESCULAPIAN_490183703265219666)],
        &[(0b00001, &ENTRY_ESCULETIN_4799035190382857787)],
        &[(0b00001, &ENTRY_ESCULIN_10740850830469064996)],
    ],
    range: 4..=7,
};

static VARS_ER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ER_CHILDREN),
    value: None,
};

pub static VARS_ER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bia"),
        dictgen::InsensitiveStr::Ascii("bias"),
        dictgen::InsensitiveStr::Ascii("gotise"),
        dictgen::InsensitiveStr::Ascii("gotised"),
        dictgen::InsensitiveStr::Ascii("gotises"),
        dictgen::InsensitiveStr::Ascii("gotising"),
        dictgen::InsensitiveStr::Ascii("gotize"),
        dictgen::InsensitiveStr::Ascii("gotized"),
        dictgen::InsensitiveStr::Ascii("gotizes"),
        dictgen::InsensitiveStr::Ascii("gotizing"),
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("ical"),
        dictgen::InsensitiveStr::Ascii("ke"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("nes"),
        dictgen::InsensitiveStr::Ascii("nest"),
        dictgen::InsensitiveStr::Ascii("ns"),
        dictgen::InsensitiveStr::Ascii("ogenesis"),
        dictgen::InsensitiveStr::Ascii("ogenic"),
        dictgen::InsensitiveStr::Ascii("os"),
        dictgen::InsensitiveStr::Ascii("ose"),
        dictgen::InsensitiveStr::Ascii("oticisation"),
        dictgen::InsensitiveStr::Ascii("oticise"),
        dictgen::InsensitiveStr::Ascii("oticised"),
        dictgen::InsensitiveStr::Ascii("oticises"),
        dictgen::InsensitiveStr::Ascii("oticising"),
        dictgen::InsensitiveStr::Ascii("oticization"),
        dictgen::InsensitiveStr::Ascii("oticize"),
        dictgen::InsensitiveStr::Ascii("oticized"),
        dictgen::InsensitiveStr::Ascii("oticizes"),
        dictgen::InsensitiveStr::Ascii("oticizing"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("sh"),
        dictgen::InsensitiveStr::Ascii("t"),
        dictgen::InsensitiveStr::Ascii("uginous"),
        dictgen::InsensitiveStr::Ascii("ugo"),
        dictgen::InsensitiveStr::Ascii("ugos"),
        dictgen::InsensitiveStr::Ascii("valenta"),
        dictgen::InsensitiveStr::Ascii("valentas"),
        dictgen::InsensitiveStr::Ascii("ythraean"),
        dictgen::InsensitiveStr::Ascii("ythraemia"),
        dictgen::InsensitiveStr::Ascii("ythrean"),
        dictgen::InsensitiveStr::Ascii("ythremia"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ERBIA_3590263034241709068)],
        &[(0b00001, &ENTRY_ERBIAS_7628332259520876430)],
        &[(0b10010, &ENTRY_ERGOTIZE_2413804013154734092)],
        &[(0b10010, &ENTRY_ERGOTIZED_8120537335211967484)],
        &[(0b10010, &ENTRY_ERGOTIZES_2875829986652402100)],
        &[(0b10010, &ENTRY_ERGOTIZING_3389078505132496781)],
        &[(0b01001, &ENTRY_ERGOTIZE_2413804013154734092)],
        &[(0b01001, &ENTRY_ERGOTIZED_8120537335211967484)],
        &[(0b01001, &ENTRY_ERGOTIZES_2875829986652402100)],
        &[(0b01001, &ENTRY_ERGOTIZING_3389078505132496781)],
        &[(0b00001, &ENTRY_ERIC_7184163800386574200)],
        &[(0b00001, &ENTRY_ERICAL_12478419361229949219)],
        &[(0b00001, &ENTRY_ERKE_6039553976467525040)],
        &[(0b00001, &ENTRY_ERN_10092184086657301009)],
        &[(0b00001, &ENTRY_ERNES_16282144925287112174)],
        &[(0b00001, &ENTRY_ERNEST_2869565578515229588)],
        &[(0b00001, &ENTRY_ERNS_11958672731540988082)],
        &[(0b00001, &ENTRY_EROGENESIS_4465855575040947833)],
        &[(0b00001, &ENTRY_EROGENIC_3058184513432824304)],
        &[(0b00001, &ENTRY_EROS_265509765297093167)],
        &[(0b00001, &ENTRY_EROSE_5357559857770402424)],
        &[(0b10010, &ENTRY_EROTICIZATION_2630432213360033255)],
        &[(0b10010, &ENTRY_EROTICIZE_10103435938228728741)],
        &[(0b10010, &ENTRY_EROTICIZED_13157811206734809042)],
        &[(0b10010, &ENTRY_EROTICIZES_4798707540088705022)],
        &[(0b10010, &ENTRY_EROTICIZING_7294701366490544040)],
        &[(0b01001, &ENTRY_EROTICIZATION_2630432213360033255)],
        &[(0b01001, &ENTRY_EROTICIZE_10103435938228728741)],
        &[(0b01001, &ENTRY_EROTICIZED_13157811206734809042)],
        &[(0b01001, &ENTRY_EROTICIZES_4798707540088705022)],
        &[(0b01001, &ENTRY_EROTICIZING_7294701366490544040)],
        &[(0b00001, &ENTRY_ERSES_5709814492624908686)],
        &[(0b00001, &ENTRY_ERSH_939187057767591954)],
        &[(0b00001, &ENTRY_ERT_3341098308248153715)],
        &[(0b00001, &ENTRY_ERUGINOUS_5828853281772845437)],
        &[(0b00001, &ENTRY_ERUGO_17158132187061977414)],
        &[(0b00001, &ENTRY_ERUGOS_15673647349394448977)],
        &[(0b00001, &ENTRY_ERVALENTA_10785450433515167284)],
        &[(0b00001, &ENTRY_ERVALENTAS_18174157063570728071)],
        &[(0b11010, &ENTRY_ERYTHREAN_10329526815525592119)],
        &[(0b11010, &ENTRY_ERYTHREMIA_836879494064020428)],
        &[(0b00001, &ENTRY_ERYTHREAN_10329526815525592119)],
        &[(0b00001, &ENTRY_ERYTHREMIA_836879494064020428)],
    ],
    range: 1..=11,
};

static VARS_EQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EQ_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_EQ_17801056412005353118)]),
};

pub static VARS_EQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ualed"),
        dictgen::InsensitiveStr::Ascii("ualing"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualiser"),
        dictgen::InsensitiveStr::Ascii("ualisers"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualisings"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizer"),
        dictgen::InsensitiveStr::Ascii("ualizers"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
        dictgen::InsensitiveStr::Ascii("ualizings"),
        dictgen::InsensitiveStr::Ascii("ualled"),
        dictgen::InsensitiveStr::Ascii("ualling"),
        dictgen::InsensitiveStr::Ascii("uestrianise"),
        dictgen::InsensitiveStr::Ascii("uestrianises"),
        dictgen::InsensitiveStr::Ascii("uestrianize"),
        dictgen::InsensitiveStr::Ascii("uestrianizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EQUALED_8356361230889842625)],
        &[(0b00001, &ENTRY_EQUALING_76827185743864845)],
        &[(0b10010, &ENTRY_EQUALIZATION_417591381258528869)],
        &[(0b10010, &ENTRY_EQUALIZATIONS_682915140211915244)],
        &[(0b10010, &ENTRY_EQUALIZE_6433971949536645353)],
        &[(0b10010, &ENTRY_EQUALIZED_5400608554561448474)],
        &[(0b10010, &ENTRY_EQUALIZER_2855584392309830652)],
        &[(0b10010, &ENTRY_EQUALIZERS_11614687339668491001)],
        &[(0b10010, &ENTRY_EQUALIZES_1676516165012158279)],
        &[(0b10010, &ENTRY_EQUALIZING_14679492934035290518)],
        &[(0b10010, &ENTRY_EQUALIZINGS_10284543548419639437)],
        &[(0b01001, &ENTRY_EQUALIZATION_417591381258528869)],
        &[(0b01001, &ENTRY_EQUALIZATIONS_682915140211915244)],
        &[(0b01001, &ENTRY_EQUALIZE_6433971949536645353)],
        &[(0b01001, &ENTRY_EQUALIZED_5400608554561448474)],
        &[(0b01001, &ENTRY_EQUALIZER_2855584392309830652)],
        &[(0b01001, &ENTRY_EQUALIZERS_11614687339668491001)],
        &[(0b01001, &ENTRY_EQUALIZES_1676516165012158279)],
        &[(0b01001, &ENTRY_EQUALIZING_14679492934035290518)],
        &[(0b01001, &ENTRY_EQUALIZINGS_10284543548419639437)],
        &[(0b11010, &ENTRY_EQUALED_8356361230889842625)],
        &[(0b11010, &ENTRY_EQUALING_76827185743864845)],
        &[(0b10010, &ENTRY_EQUESTRIANIZE_13136044868803266911)],
        &[(0b10010, &ENTRY_EQUESTRIANIZES_3846608224700022412)],
        &[(0b01001, &ENTRY_EQUESTRIANIZE_13136044868803266911)],
        &[(0b01001, &ENTRY_EQUESTRIANIZES_3846608224700022412)],
    ],
    range: 5..=12,
};

static VARS_EP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EP_CHILDREN),
    value: None,
};

static VARS_EP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_EPA_NODE),
    None,
    None,
    None,
    Some(&VARS_EPE_NODE),
    None,
    None,
    Some(&VARS_EPH_NODE),
    Some(&VARS_EPI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EPI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EPI_CHILDREN),
    value: None,
};

static VARS_EPI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_EPIC_NODE),
    Some(&VARS_EPID_NODE),
    None,
    None,
    Some(&VARS_EPIG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_EPIL_NODE),
    Some(&VARS_EPIM_NODE),
    None,
    None,
    Some(&VARS_EPIP_NODE),
    None,
    None,
    Some(&VARS_EPIS_NODE),
    Some(&VARS_EPIT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_EPIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIT_CHILDREN),
    value: None,
};

pub static VARS_EPIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aphise"),
        dictgen::InsensitiveStr::Ascii("aphises"),
        dictgen::InsensitiveStr::Ascii("aphize"),
        dictgen::InsensitiveStr::Ascii("aphizes"),
        dictgen::InsensitiveStr::Ascii("hetise"),
        dictgen::InsensitiveStr::Ascii("hetises"),
        dictgen::InsensitiveStr::Ascii("hetize"),
        dictgen::InsensitiveStr::Ascii("hetizes"),
        dictgen::InsensitiveStr::Ascii("omisation"),
        dictgen::InsensitiveStr::Ascii("omisations"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omiser"),
        dictgen::InsensitiveStr::Ascii("omisers"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omization"),
        dictgen::InsensitiveStr::Ascii("omizations"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizer"),
        dictgen::InsensitiveStr::Ascii("omizers"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("omizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPITAPHIZE_13795478585860811984)],
        &[(0b10010, &ENTRY_EPITAPHIZES_162759418609625372)],
        &[(0b01001, &ENTRY_EPITAPHIZE_13795478585860811984)],
        &[(0b01001, &ENTRY_EPITAPHIZES_162759418609625372)],
        &[(0b10010, &ENTRY_EPITHETIZE_14011874895566642629)],
        &[(0b10010, &ENTRY_EPITHETIZES_12815056524749670860)],
        &[(0b01001, &ENTRY_EPITHETIZE_14011874895566642629)],
        &[(0b01001, &ENTRY_EPITHETIZES_12815056524749670860)],
        &[(0b10010, &ENTRY_EPITOMIZATION_16124019439482652962)],
        &[(0b10010, &ENTRY_EPITOMIZATIONS_16374827024040589670)],
        &[(0b10010, &ENTRY_EPITOMIZE_13528530811124562195)],
        &[(0b10010, &ENTRY_EPITOMIZED_5424880168543124583)],
        &[(0b10010, &ENTRY_EPITOMIZER_8562118215235688018)],
        &[(0b10010, &ENTRY_EPITOMIZERS_4593373083947475967)],
        &[(0b10010, &ENTRY_EPITOMIZES_10955147197853926635)],
        &[(0b10010, &ENTRY_EPITOMIZING_9913028102891579136)],
        &[(0b01001, &ENTRY_EPITOMIZATION_16124019439482652962)],
        &[(0b01001, &ENTRY_EPITOMIZATIONS_16374827024040589670)],
        &[(0b01001, &ENTRY_EPITOMIZE_13528530811124562195)],
        &[(0b01001, &ENTRY_EPITOMIZED_5424880168543124583)],
        &[(0b01001, &ENTRY_EPITOMIZER_8562118215235688018)],
        &[(0b01001, &ENTRY_EPITOMIZERS_4593373083947475967)],
        &[(0b01001, &ENTRY_EPITOMIZES_10955147197853926635)],
        &[(0b01001, &ENTRY_EPITOMIZING_9913028102891579136)],
    ],
    range: 5..=10,
};

static VARS_EPIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIS_CHILDREN),
    value: None,
};

pub static VARS_EPIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("copalianise"),
        dictgen::InsensitiveStr::Ascii("copalianises"),
        dictgen::InsensitiveStr::Ascii("copalianize"),
        dictgen::InsensitiveStr::Ascii("copalianizes"),
        dictgen::InsensitiveStr::Ascii("copise"),
        dictgen::InsensitiveStr::Ascii("copised"),
        dictgen::InsensitiveStr::Ascii("copises"),
        dictgen::InsensitiveStr::Ascii("copising"),
        dictgen::InsensitiveStr::Ascii("copize"),
        dictgen::InsensitiveStr::Ascii("copized"),
        dictgen::InsensitiveStr::Ascii("copizes"),
        dictgen::InsensitiveStr::Ascii("copizing"),
        dictgen::InsensitiveStr::Ascii("tolise"),
        dictgen::InsensitiveStr::Ascii("tolised"),
        dictgen::InsensitiveStr::Ascii("tolises"),
        dictgen::InsensitiveStr::Ascii("tolising"),
        dictgen::InsensitiveStr::Ascii("tolize"),
        dictgen::InsensitiveStr::Ascii("tolized"),
        dictgen::InsensitiveStr::Ascii("tolizes"),
        dictgen::InsensitiveStr::Ascii("tolizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPISCOPALIANIZE_13601906048877534433)],
        &[(0b10010, &ENTRY_EPISCOPALIANIZES_14297906488956283731)],
        &[(0b01001, &ENTRY_EPISCOPALIANIZE_13601906048877534433)],
        &[(0b01001, &ENTRY_EPISCOPALIANIZES_14297906488956283731)],
        &[(0b10010, &ENTRY_EPISCOPIZE_5941157562787933973)],
        &[(0b10010, &ENTRY_EPISCOPIZED_16650182802365832304)],
        &[(0b10010, &ENTRY_EPISCOPIZES_9627859512937099394)],
        &[(0b10010, &ENTRY_EPISCOPIZING_17988499911565815852)],
        &[(0b01001, &ENTRY_EPISCOPIZE_5941157562787933973)],
        &[(0b01001, &ENTRY_EPISCOPIZED_16650182802365832304)],
        &[(0b01001, &ENTRY_EPISCOPIZES_9627859512937099394)],
        &[(0b01001, &ENTRY_EPISCOPIZING_17988499911565815852)],
        &[(0b10010, &ENTRY_EPISTOLIZE_12798380956553546634)],
        &[(0b10010, &ENTRY_EPISTOLIZED_2534518570318818508)],
        &[(0b10010, &ENTRY_EPISTOLIZES_12529001542994955479)],
        &[(0b10010, &ENTRY_EPISTOLIZING_12184368088240887297)],
        &[(0b01001, &ENTRY_EPISTOLIZE_12798380956553546634)],
        &[(0b01001, &ENTRY_EPISTOLIZED_2534518570318818508)],
        &[(0b01001, &ENTRY_EPISTOLIZES_12529001542994955479)],
        &[(0b01001, &ENTRY_EPISTOLIZING_12184368088240887297)],
    ],
    range: 6..=12,
};

static VARS_EPIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIP_CHILDREN),
    value: None,
};

pub static VARS_EPIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hanise"),
        dictgen::InsensitiveStr::Ascii("hanised"),
        dictgen::InsensitiveStr::Ascii("hanising"),
        dictgen::InsensitiveStr::Ascii("hanize"),
        dictgen::InsensitiveStr::Ascii("hanized"),
        dictgen::InsensitiveStr::Ascii("hanizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPIPHANIZE_3444458754608259700)],
        &[(0b10010, &ENTRY_EPIPHANIZED_9129723971945803343)],
        &[(0b10010, &ENTRY_EPIPHANIZING_5611514449736046211)],
        &[(0b01001, &ENTRY_EPIPHANIZE_3444458754608259700)],
        &[(0b01001, &ENTRY_EPIPHANIZED_9129723971945803343)],
        &[(0b01001, &ENTRY_EPIPHANIZING_5611514449736046211)],
    ],
    range: 6..=8,
};

static VARS_EPIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIM_CHILDREN),
    value: None,
};

pub static VARS_EPIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPIMERIZE_823465573203429173)],
        &[(0b10010, &ENTRY_EPIMERIZED_14134076359123551022)],
        &[(0b10010, &ENTRY_EPIMERIZING_11872554676821586844)],
        &[(0b01001, &ENTRY_EPIMERIZE_823465573203429173)],
        &[(0b01001, &ENTRY_EPIMERIZED_14134076359123551022)],
        &[(0b01001, &ENTRY_EPIMERIZING_11872554676821586844)],
    ],
    range: 5..=7,
};

static VARS_EPIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIL_CHILDREN),
    value: None,
};

pub static VARS_EPIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("og"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ogs"),
        dictgen::InsensitiveStr::Ascii("oguise"),
        dictgen::InsensitiveStr::Ascii("oguised"),
        dictgen::InsensitiveStr::Ascii("oguises"),
        dictgen::InsensitiveStr::Ascii("oguising"),
        dictgen::InsensitiveStr::Ascii("oguize"),
        dictgen::InsensitiveStr::Ascii("oguized"),
        dictgen::InsensitiveStr::Ascii("oguizes"),
        dictgen::InsensitiveStr::Ascii("oguizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EPILOGUE_10590439015464966835)],
        &[(0b10010, &ENTRY_EPILOGIZE_5104820820812023953)],
        &[(0b10010, &ENTRY_EPILOGIZED_13747207713324695603)],
        &[(0b10010, &ENTRY_EPILOGIZES_6060812301091580461)],
        &[(0b10010, &ENTRY_EPILOGIZING_16045388830092914645)],
        &[(0b01001, &ENTRY_EPILOGIZE_5104820820812023953)],
        &[(0b01001, &ENTRY_EPILOGIZED_13747207713324695603)],
        &[(0b01001, &ENTRY_EPILOGIZES_6060812301091580461)],
        &[(0b01001, &ENTRY_EPILOGIZING_16045388830092914645)],
        &[(0b00001, &ENTRY_EPILOGUES_1045687645770537326)],
        &[(0b10010, &ENTRY_EPILOGUIZE_689201102200555729)],
        &[(0b10010, &ENTRY_EPILOGUIZED_12441365755453529023)],
        &[(0b10010, &ENTRY_EPILOGUIZES_2292690148409428255)],
        &[(0b10010, &ENTRY_EPILOGUIZING_8986609211873957773)],
        &[(0b01001, &ENTRY_EPILOGUIZE_689201102200555729)],
        &[(0b01001, &ENTRY_EPILOGUIZED_12441365755453529023)],
        &[(0b01001, &ENTRY_EPILOGUIZES_2292690148409428255)],
        &[(0b01001, &ENTRY_EPILOGUIZING_8986609211873957773)],
    ],
    range: 2..=8,
};

static VARS_EPIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIG_CHILDREN),
    value: None,
};

pub static VARS_EPIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aeal"),
        dictgen::InsensitiveStr::Ascii("aean"),
        dictgen::InsensitiveStr::Ascii("aeous"),
        dictgen::InsensitiveStr::Ascii("eal"),
        dictgen::InsensitiveStr::Ascii("ean"),
        dictgen::InsensitiveStr::Ascii("eous"),
        dictgen::InsensitiveStr::Ascii("rammatisation"),
        dictgen::InsensitiveStr::Ascii("rammatise"),
        dictgen::InsensitiveStr::Ascii("rammatised"),
        dictgen::InsensitiveStr::Ascii("rammatiser"),
        dictgen::InsensitiveStr::Ascii("rammatises"),
        dictgen::InsensitiveStr::Ascii("rammatising"),
        dictgen::InsensitiveStr::Ascii("rammatization"),
        dictgen::InsensitiveStr::Ascii("rammatize"),
        dictgen::InsensitiveStr::Ascii("rammatized"),
        dictgen::InsensitiveStr::Ascii("rammatizer"),
        dictgen::InsensitiveStr::Ascii("rammatizes"),
        dictgen::InsensitiveStr::Ascii("rammatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EPIGEAL_9418200985174229088)],
        &[(0b11010, &ENTRY_EPIGEAN_1067479460708884657)],
        &[(0b11010, &ENTRY_EPIGEOUS_2793155818327732975)],
        &[(0b00001, &ENTRY_EPIGEAL_9418200985174229088)],
        &[(0b00001, &ENTRY_EPIGEAN_1067479460708884657)],
        &[(0b00001, &ENTRY_EPIGEOUS_2793155818327732975)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZATION_3435997769901871314)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZE_13553329783728837308)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZED_3366561652151146715)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZER_202382434686912143)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZES_9870871179457908060)],
        &[(0b10010, &ENTRY_EPIGRAMMATIZING_9925592242854198273)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZATION_3435997769901871314)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZE_13553329783728837308)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZED_3366561652151146715)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZER_202382434686912143)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZES_9870871179457908060)],
        &[(0b01001, &ENTRY_EPIGRAMMATIZING_9925592242854198273)],
    ],
    range: 3..=13,
};

static VARS_EPID_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPID_CHILDREN),
    value: None,
};

pub static VARS_EPID_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otisation"),
        dictgen::InsensitiveStr::Ascii("otisations"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otization"),
        dictgen::InsensitiveStr::Ascii("otizations"),
        dictgen::InsensitiveStr::Ascii("otized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EPIDOTIZATION_14022545118965805510)],
        &[(0b10010, &ENTRY_EPIDOTIZATIONS_17986813465862906948)],
        &[(0b10010, &ENTRY_EPIDOTIZED_18043278384935210029)],
        &[(0b01001, &ENTRY_EPIDOTIZATION_14022545118965805510)],
        &[(0b01001, &ENTRY_EPIDOTIZATIONS_17986813465862906948)],
        &[(0b01001, &ENTRY_EPIDOTIZED_18043278384935210029)],
    ],
    range: 6..=10,
};

static VARS_EPIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPIC_CHILDREN),
    value: None,
};

pub static VARS_EPIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ele"),
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entres"),
        dictgen::InsensitiveStr::Ascii("oele"),
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urised"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urising"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urized"),
        dictgen::InsensitiveStr::Ascii("urizes"),
        dictgen::InsensitiveStr::Ascii("urizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EPICELE_12455055708908810351)],
        &[(0b00001, &ENTRY_EPICENTER_16342724518099488548)],
        &[(0b00001, &ENTRY_EPICENTERS_13863528771268891291)],
        &[(0b11010, &ENTRY_EPICENTER_16342724518099488548)],
        &[(0b11010, &ENTRY_EPICENTERS_13863528771268891291)],
        &[(0b11010, &ENTRY_EPICELE_12455055708908810351)],
        &[(0b10010, &ENTRY_EPICURIZE_9792021232282849861)],
        &[(0b10010, &ENTRY_EPICURIZED_8210844038944440883)],
        &[(0b10010, &ENTRY_EPICURIZES_604659561636523665)],
        &[(0b10010, &ENTRY_EPICURIZING_15655666870475102269)],
        &[(0b01001, &ENTRY_EPICURIZE_9792021232282849861)],
        &[(0b01001, &ENTRY_EPICURIZED_8210844038944440883)],
        &[(0b01001, &ENTRY_EPICURIZES_604659561636523665)],
        &[(0b01001, &ENTRY_EPICURIZING_15655666870475102269)],
    ],
    range: 3..=7,
};

static VARS_EPH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPH_CHILDREN),
    value: None,
};

pub static VARS_EPH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etae"),
        dictgen::InsensitiveStr::Ascii("ete"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EPHETE_2596523211716991798)],
        &[(0b00001, &ENTRY_EPHETE_2596523211716991798)],
    ],
    range: 3..=4,
};

static VARS_EPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPE_CHILDREN),
    value: None,
};

pub static VARS_EPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("netic")],
    values: &[&[(0b00001, &ENTRY_EPENETIC_4078091931289223174)]],
    range: 5..=5,
};

static VARS_EPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EPA_CHILDREN),
    value: None,
};

pub static VARS_EPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enetic"),
        dictgen::InsensitiveStr::Ascii("ulet"),
        dictgen::InsensitiveStr::Ascii("ulets"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EPENETIC_4078091931289223174)],
        &[(0b01001, &ENTRY_EPAULET_387424623527969944)],
        &[(0b01001, &ENTRY_EPAULETS_16015840258717142271)],
    ],
    range: 4..=6,
};

static VARS_EO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EO_CHILDREN),
    value: None,
};

pub static VARS_EO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lic"),
        dictgen::InsensitiveStr::Ascii("lipile"),
        dictgen::InsensitiveStr::Ascii("lipiles"),
        dictgen::InsensitiveStr::Ascii("lotropic"),
        dictgen::InsensitiveStr::Ascii("nian"),
        dictgen::InsensitiveStr::Ascii("nism"),
        dictgen::InsensitiveStr::Ascii("nisms"),
        dictgen::InsensitiveStr::Ascii("palaeozoic"),
        dictgen::InsensitiveStr::Ascii("paleozoic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EOLIC_690118974702284625)],
        &[(0b00001, &ENTRY_EOLIPILE_11849651097249565492)],
        &[(0b00001, &ENTRY_EOLIPILES_6469066293612545970)],
        &[(0b00001, &ENTRY_EOLOTROPIC_9928061474103766564)],
        &[(0b00001, &ENTRY_EONIAN_2585817843108266796)],
        &[(0b00001, &ENTRY_EONISM_12314541365765950888)],
        &[(0b00001, &ENTRY_EONISMS_13022437471464751142)],
        &[(0b11010, &ENTRY_EOPALEOZOIC_13858730559448370168)],
        &[(0b00001, &ENTRY_EOPALEOZOIC_13858730559448370168)],
    ],
    range: 3..=10,
};

static VARS_EN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EN_CHILDREN),
    value: None,
};

static VARS_EN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ENA_NODE),
    None,
    Some(&VARS_ENC_NODE),
    Some(&VARS_END_NODE),
    Some(&VARS_ENE_NODE),
    None,
    Some(&VARS_ENG_NODE),
    Some(&VARS_ENH_NODE),
    Some(&VARS_ENI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ENO_NODE),
    None,
    Some(&VARS_ENQ_NODE),
    Some(&VARS_ENR_NODE),
    Some(&VARS_ENS_NODE),
    Some(&VARS_ENT_NODE),
    None,
    Some(&VARS_ENV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_ENV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENV_CHILDREN),
    value: None,
};

pub static VARS_ENV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apor"),
        dictgen::InsensitiveStr::Ascii("apors"),
        dictgen::InsensitiveStr::Ascii("apour"),
        dictgen::InsensitiveStr::Ascii("apours"),
        dictgen::InsensitiveStr::Ascii("enomisation"),
        dictgen::InsensitiveStr::Ascii("enomization"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ENVAPOR_3613458891591634750)],
        &[(0b10001, &ENTRY_ENVAPORS_5110885845552232253)],
        &[(0b11010, &ENTRY_ENVAPOR_3613458891591634750)],
        &[(0b11010, &ENTRY_ENVAPORS_5110885845552232253)],
        &[(0b10010, &ENTRY_ENVENOMIZATION_641743467429707201)],
        &[(0b01001, &ENTRY_ENVENOMIZATION_641743467429707201)],
    ],
    range: 4..=11,
};

static VARS_ENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENT_CHILDREN),
    value: None,
};

pub static VARS_ENT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ameba"),
        dictgen::InsensitiveStr::Ascii("amebae"),
        dictgen::InsensitiveStr::Ascii("amebas"),
        dictgen::InsensitiveStr::Ascii("amebic"),
        dictgen::InsensitiveStr::Ascii("amoeba"),
        dictgen::InsensitiveStr::Ascii("amoebae"),
        dictgen::InsensitiveStr::Ascii("amoebas"),
        dictgen::InsensitiveStr::Ascii("amoebic"),
        dictgen::InsensitiveStr::Ascii("ender"),
        dictgen::InsensitiveStr::Ascii("enders"),
        dictgen::InsensitiveStr::Ascii("endre"),
        dictgen::InsensitiveStr::Ascii("endres"),
        dictgen::InsensitiveStr::Ascii("erocele"),
        dictgen::InsensitiveStr::Ascii("eroceles"),
        dictgen::InsensitiveStr::Ascii("erocoele"),
        dictgen::InsensitiveStr::Ascii("erocoeles"),
        dictgen::InsensitiveStr::Ascii("hral"),
        dictgen::InsensitiveStr::Ascii("hrall"),
        dictgen::InsensitiveStr::Ascii("hrallment"),
        dictgen::InsensitiveStr::Ascii("hrallments"),
        dictgen::InsensitiveStr::Ascii("hralls"),
        dictgen::InsensitiveStr::Ascii("hralment"),
        dictgen::InsensitiveStr::Ascii("hralments"),
        dictgen::InsensitiveStr::Ascii("hrals"),
        dictgen::InsensitiveStr::Ascii("hronisation"),
        dictgen::InsensitiveStr::Ascii("hronisations"),
        dictgen::InsensitiveStr::Ascii("hronise"),
        dictgen::InsensitiveStr::Ascii("hronised"),
        dictgen::InsensitiveStr::Ascii("hronises"),
        dictgen::InsensitiveStr::Ascii("hronising"),
        dictgen::InsensitiveStr::Ascii("hronization"),
        dictgen::InsensitiveStr::Ascii("hronizations"),
        dictgen::InsensitiveStr::Ascii("hronize"),
        dictgen::InsensitiveStr::Ascii("hronized"),
        dictgen::InsensitiveStr::Ascii("hronizes"),
        dictgen::InsensitiveStr::Ascii("hronizing"),
        dictgen::InsensitiveStr::Ascii("ocele"),
        dictgen::InsensitiveStr::Ascii("ocoele"),
        dictgen::InsensitiveStr::Ascii("omologise"),
        dictgen::InsensitiveStr::Ascii("omologised"),
        dictgen::InsensitiveStr::Ascii("omologises"),
        dictgen::InsensitiveStr::Ascii("omologising"),
        dictgen::InsensitiveStr::Ascii("omologize"),
        dictgen::InsensitiveStr::Ascii("omologized"),
        dictgen::InsensitiveStr::Ascii("omologizes"),
        dictgen::InsensitiveStr::Ascii("omologizing"),
        dictgen::InsensitiveStr::Ascii("rae"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENTAMEBA_11793706106302208785)],
        &[(0b00001, &ENTRY_ENTAMEBAE_2341236739078532290)],
        &[(0b00001, &ENTRY_ENTAMEBAS_2809555012037452245)],
        &[(0b00001, &ENTRY_ENTAMEBIC_8920229737132161042)],
        &[(0b11010, &ENTRY_ENTAMEBA_11793706106302208785)],
        &[(0b11010, &ENTRY_ENTAMEBAE_2341236739078532290)],
        &[(0b11010, &ENTRY_ENTAMEBAS_2809555012037452245)],
        &[(0b11010, &ENTRY_ENTAMEBIC_8920229737132161042)],
        &[(0b00001, &ENTRY_ENTENDER_17085849552645364509)],
        &[(0b00001, &ENTRY_ENTENDERS_7310937866697087291)],
        &[(0b11010, &ENTRY_ENTENDER_17085849552645364509)],
        &[(0b11010, &ENTRY_ENTENDERS_7310937866697087291)],
        &[(0b00001, &ENTRY_ENTEROCELE_7421588424099714866)],
        &[(0b00001, &ENTRY_ENTEROCELES_5370389164173622202)],
        &[(0b11010, &ENTRY_ENTEROCELE_7421588424099714866)],
        &[(0b11010, &ENTRY_ENTEROCELES_5370389164173622202)],
        &[
            (0b11010, &ENTRY_ENTHRALL_10463703031933500557),
            (0b11010, &ENTRY_ENTHRALL_16443508848218743746),
        ],
        &[
            (0b01001, &ENTRY_ENTHRALL_10463703031933500557),
            (0b01001, &ENTRY_ENTHRALL_16443508848218743746),
        ],
        &[(0b01001, &ENTRY_ENTHRALLMENT_17889486799769196724)],
        &[(0b01001, &ENTRY_ENTHRALLMENTS_16482738497663374563)],
        &[
            (0b01001, &ENTRY_ENTHRALLS_4618745032526572838),
            (0b01001, &ENTRY_ENTHRALLS_6896071459165900179),
        ],
        &[(0b11010, &ENTRY_ENTHRALLMENT_17889486799769196724)],
        &[(0b11010, &ENTRY_ENTHRALLMENTS_16482738497663374563)],
        &[
            (0b11010, &ENTRY_ENTHRALLS_4618745032526572838),
            (0b11010, &ENTRY_ENTHRALLS_6896071459165900179),
        ],
        &[(0b10010, &ENTRY_ENTHRONIZATION_6974028193403231299)],
        &[(0b10010, &ENTRY_ENTHRONIZATIONS_17542858977423549781)],
        &[(0b10010, &ENTRY_ENTHRONIZE_8479472121396981406)],
        &[(0b10010, &ENTRY_ENTHRONIZED_15570973078812509329)],
        &[(0b10010, &ENTRY_ENTHRONIZES_6728807480218746557)],
        &[(0b10010, &ENTRY_ENTHRONIZING_5022467519558443336)],
        &[(0b01001, &ENTRY_ENTHRONIZATION_6974028193403231299)],
        &[(0b01001, &ENTRY_ENTHRONIZATIONS_17542858977423549781)],
        &[(0b01001, &ENTRY_ENTHRONIZE_8479472121396981406)],
        &[(0b01001, &ENTRY_ENTHRONIZED_15570973078812509329)],
        &[(0b01001, &ENTRY_ENTHRONIZES_6728807480218746557)],
        &[(0b01001, &ENTRY_ENTHRONIZING_5022467519558443336)],
        &[(0b00001, &ENTRY_ENTOCELE_16862864757875933672)],
        &[(0b11010, &ENTRY_ENTOCELE_16862864757875933672)],
        &[(0b10010, &ENTRY_ENTOMOLOGIZE_12930471317891860313)],
        &[(0b10010, &ENTRY_ENTOMOLOGIZED_17180055652025722891)],
        &[(0b10010, &ENTRY_ENTOMOLOGIZES_14741971157180428511)],
        &[(0b10010, &ENTRY_ENTOMOLOGIZING_541087590579894951)],
        &[(0b01001, &ENTRY_ENTOMOLOGIZE_12930471317891860313)],
        &[(0b01001, &ENTRY_ENTOMOLOGIZED_17180055652025722891)],
        &[(0b01001, &ENTRY_ENTOMOLOGIZES_14741971157180428511)],
        &[(0b01001, &ENTRY_ENTOMOLOGIZING_541087590579894951)],
        &[(0b11010, &ENTRY_ENTRE_13397912193554137949)],
        &[(0b00001, &ENTRY_ENTRE_13397912193554137949)],
    ],
    range: 2..=12,
};

static VARS_ENS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENS_CHILDREN),
    value: None,
};

pub static VARS_ENS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("epulcher"),
        dictgen::InsensitiveStr::Ascii("epulcherred"),
        dictgen::InsensitiveStr::Ascii("epulcherring"),
        dictgen::InsensitiveStr::Ascii("epulchers"),
        dictgen::InsensitiveStr::Ascii("epulchre"),
        dictgen::InsensitiveStr::Ascii("epulchred"),
        dictgen::InsensitiveStr::Ascii("epulchres"),
        dictgen::InsensitiveStr::Ascii("epulchring"),
        dictgen::InsensitiveStr::Ascii("orceled"),
        dictgen::InsensitiveStr::Ascii("orcelled"),
        dictgen::InsensitiveStr::Ascii("orcells"),
        dictgen::InsensitiveStr::Ascii("orcels"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENSEPULCHER_18433050111369773849)],
        &[(0b00001, &ENTRY_ENSEPULCHERRED_2215822898020041532)],
        &[(0b00001, &ENTRY_ENSEPULCHERRING_16534463950868972468)],
        &[(0b00001, &ENTRY_ENSEPULCHERS_15911081178953815823)],
        &[(0b11010, &ENTRY_ENSEPULCHER_18433050111369773849)],
        &[(0b11010, &ENTRY_ENSEPULCHERRED_2215822898020041532)],
        &[(0b11010, &ENTRY_ENSEPULCHERS_15911081178953815823)],
        &[(0b11010, &ENTRY_ENSEPULCHERRING_16534463950868972468)],
        &[(0b00001, &ENTRY_ENSORCELED_12229416995193303781)],
        &[(0b11010, &ENTRY_ENSORCELED_12229416995193303781)],
        &[(0b11010, &ENTRY_ENSORCELS_14124680308015897322)],
        &[(0b00001, &ENTRY_ENSORCELS_14124680308015897322)],
    ],
    range: 6..=12,
};

static VARS_ENR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENR_CHILDREN),
    value: None,
};

pub static VARS_ENR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ol"),
        dictgen::InsensitiveStr::Ascii("oll"),
        dictgen::InsensitiveStr::Ascii("ollment"),
        dictgen::InsensitiveStr::Ascii("ollments"),
        dictgen::InsensitiveStr::Ascii("olls"),
        dictgen::InsensitiveStr::Ascii("olment"),
        dictgen::InsensitiveStr::Ascii("olments"),
        dictgen::InsensitiveStr::Ascii("ols"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ENROLL_1364506938148213622)],
        &[(0b11001, &ENTRY_ENROLL_1364506938148213622)],
        &[(0b11001, &ENTRY_ENROLLMENT_11988649571385805864)],
        &[(0b11001, &ENTRY_ENROLLMENTS_9654042434029037164)],
        &[(0b11001, &ENTRY_ENROLLS_13608920793429098761)],
        &[(0b11010, &ENTRY_ENROLLMENT_11988649571385805864)],
        &[(0b11010, &ENTRY_ENROLLMENTS_9654042434029037164)],
        &[(0b11010, &ENTRY_ENROLLS_13608920793429098761)],
    ],
    range: 2..=8,
};

static VARS_ENQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENQ_CHILDREN),
    value: None,
};

pub static VARS_ENQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uire"),
        dictgen::InsensitiveStr::Ascii("uired"),
        dictgen::InsensitiveStr::Ascii("uires"),
        dictgen::InsensitiveStr::Ascii("uiries"),
        dictgen::InsensitiveStr::Ascii("uiring"),
        dictgen::InsensitiveStr::Ascii("uiry"),
    ],
    values: &[
        &[(0b11010, &ENTRY_INQUIRE_13984560274152171356)],
        &[(0b11010, &ENTRY_INQUIRED_13488148321304019081)],
        &[(0b11010, &ENTRY_INQUIRES_3832461159884672820)],
        &[(0b11010, &ENTRY_INQUIRIES_9592346579573413198)],
        &[(0b11010, &ENTRY_INQUIRING_11670725526763123090)],
        &[(0b11010, &ENTRY_INQUIRY_3419756106654954762)],
    ],
    range: 4..=6,
};

static VARS_ENO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENO_CHILDREN),
    value: None,
};

pub static VARS_ENO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cyte"),
        dictgen::InsensitiveStr::Ascii("lic"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("logical"),
        dictgen::InsensitiveStr::Ascii("logist"),
        dictgen::InsensitiveStr::Ascii("logists"),
        dictgen::InsensitiveStr::Ascii("mania"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENOCYTE_5031071790616444705)],
        &[(0b00001, &ENTRY_ENOLIC_8677666364536262517)],
        &[(0b10010, &ENTRY_ENOLIZATION_9705682977867724521)],
        &[(0b10010, &ENTRY_ENOLIZATIONS_15361842836817529123)],
        &[(0b10010, &ENTRY_ENOLIZE_5068170608685889108)],
        &[(0b10010, &ENTRY_ENOLIZES_16347391140858353185)],
        &[(0b01001, &ENTRY_ENOLIZATION_9705682977867724521)],
        &[(0b01001, &ENTRY_ENOLIZATIONS_15361842836817529123)],
        &[(0b01001, &ENTRY_ENOLIZE_5068170608685889108)],
        &[(0b01001, &ENTRY_ENOLIZES_16347391140858353185)],
        &[(0b00001, &ENTRY_ENOLOGICAL_13435934594635959021)],
        &[(0b00001, &ENTRY_ENOLOGIST_7144439191139309152)],
        &[(0b00001, &ENTRY_ENOLOGISTS_17383228974239236048)],
        &[(0b00001, &ENTRY_ENOMANIA_2005674743319272403)],
    ],
    range: 3..=9,
};

static VARS_ENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENI_CHILDREN),
    value: None,
};

pub static VARS_ENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gmatise"),
        dictgen::InsensitiveStr::Ascii("gmatised"),
        dictgen::InsensitiveStr::Ascii("gmatises"),
        dictgen::InsensitiveStr::Ascii("gmatising"),
        dictgen::InsensitiveStr::Ascii("gmatize"),
        dictgen::InsensitiveStr::Ascii("gmatized"),
        dictgen::InsensitiveStr::Ascii("gmatizes"),
        dictgen::InsensitiveStr::Ascii("gmatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ENIGMATIZE_10416979299826385433)],
        &[(0b10010, &ENTRY_ENIGMATIZED_17096479822940125639)],
        &[(0b10010, &ENTRY_ENIGMATIZES_13870261966778024845)],
        &[(0b10010, &ENTRY_ENIGMATIZING_7497242872817041134)],
        &[(0b01001, &ENTRY_ENIGMATIZE_10416979299826385433)],
        &[(0b01001, &ENTRY_ENIGMATIZED_17096479822940125639)],
        &[(0b01001, &ENTRY_ENIGMATIZES_13870261966778024845)],
        &[(0b01001, &ENTRY_ENIGMATIZING_7497242872817041134)],
    ],
    range: 7..=9,
};

static VARS_ENH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENH_CHILDREN),
    value: None,
};

pub static VARS_ENH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aemospore"),
        dictgen::InsensitiveStr::Ascii("arbor"),
        dictgen::InsensitiveStr::Ascii("arbour"),
        dictgen::InsensitiveStr::Ascii("emospore"),
        dictgen::InsensitiveStr::Ascii("ypostatise"),
        dictgen::InsensitiveStr::Ascii("ypostatised"),
        dictgen::InsensitiveStr::Ascii("ypostatises"),
        dictgen::InsensitiveStr::Ascii("ypostatising"),
        dictgen::InsensitiveStr::Ascii("ypostatize"),
        dictgen::InsensitiveStr::Ascii("ypostatized"),
        dictgen::InsensitiveStr::Ascii("ypostatizes"),
        dictgen::InsensitiveStr::Ascii("ypostatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ENHEMOSPORE_15543189487115046896)],
        &[(0b00001, &ENTRY_ENHARBOR_153070629897735018)],
        &[(0b11010, &ENTRY_ENHARBOR_153070629897735018)],
        &[(0b00001, &ENTRY_ENHEMOSPORE_15543189487115046896)],
        &[(0b10010, &ENTRY_ENHYPOSTATIZE_15302074165806361600)],
        &[(0b10010, &ENTRY_ENHYPOSTATIZED_1834900422070850325)],
        &[(0b10010, &ENTRY_ENHYPOSTATIZES_11790227835392026149)],
        &[(0b10010, &ENTRY_ENHYPOSTATIZING_13001414271119905921)],
        &[(0b01001, &ENTRY_ENHYPOSTATIZE_15302074165806361600)],
        &[(0b01001, &ENTRY_ENHYPOSTATIZED_1834900422070850325)],
        &[(0b01001, &ENTRY_ENHYPOSTATIZES_11790227835392026149)],
        &[(0b01001, &ENTRY_ENHYPOSTATIZING_13001414271119905921)],
    ],
    range: 5..=12,
};

static VARS_ENG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENG_CHILDREN),
    value: None,
};

pub static VARS_ENG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lishise"),
        dictgen::InsensitiveStr::Ascii("lishises"),
        dictgen::InsensitiveStr::Ascii("lishize"),
        dictgen::InsensitiveStr::Ascii("lishizes"),
        dictgen::InsensitiveStr::Ascii("randise"),
        dictgen::InsensitiveStr::Ascii("randisement"),
        dictgen::InsensitiveStr::Ascii("randisements"),
        dictgen::InsensitiveStr::Ascii("randises"),
        dictgen::InsensitiveStr::Ascii("randize"),
        dictgen::InsensitiveStr::Ascii("randizement"),
        dictgen::InsensitiveStr::Ascii("randizements"),
        dictgen::InsensitiveStr::Ascii("randizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ENGLISHIZE_16572744168284665334)],
        &[(0b10010, &ENTRY_ENGLISHIZES_18263651365586401449)],
        &[(0b01001, &ENTRY_ENGLISHIZE_16572744168284665334)],
        &[(0b01001, &ENTRY_ENGLISHIZES_18263651365586401449)],
        &[(0b10010, &ENTRY_ENGRANDIZE_17642469822387491571)],
        &[(0b10010, &ENTRY_ENGRANDIZEMENT_6175391937433585069)],
        &[(0b10010, &ENTRY_ENGRANDIZEMENTS_4909257735302569491)],
        &[(0b10010, &ENTRY_ENGRANDIZES_5787971542005976862)],
        &[(0b01001, &ENTRY_ENGRANDIZE_17642469822387491571)],
        &[(0b01001, &ENTRY_ENGRANDIZEMENT_6175391937433585069)],
        &[(0b01001, &ENTRY_ENGRANDIZEMENTS_4909257735302569491)],
        &[(0b01001, &ENTRY_ENGRANDIZES_5787971542005976862)],
    ],
    range: 7..=12,
};

static VARS_ENE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENE_CHILDREN),
    value: None,
};

pub static VARS_ENE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("id"),
        dictgen::InsensitiveStr::Ascii("rgisation"),
        dictgen::InsensitiveStr::Ascii("rgise"),
        dictgen::InsensitiveStr::Ascii("rgised"),
        dictgen::InsensitiveStr::Ascii("rgiser"),
        dictgen::InsensitiveStr::Ascii("rgisers"),
        dictgen::InsensitiveStr::Ascii("rgises"),
        dictgen::InsensitiveStr::Ascii("rgising"),
        dictgen::InsensitiveStr::Ascii("rgization"),
        dictgen::InsensitiveStr::Ascii("rgize"),
        dictgen::InsensitiveStr::Ascii("rgized"),
        dictgen::InsensitiveStr::Ascii("rgizer"),
        dictgen::InsensitiveStr::Ascii("rgizers"),
        dictgen::InsensitiveStr::Ascii("rgizes"),
        dictgen::InsensitiveStr::Ascii("rgizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENEID_5242893003172218406)],
        &[(0b10010, &ENTRY_ENERGIZATION_8281923071042553435)],
        &[(0b10010, &ENTRY_ENERGIZE_9040021254285160273)],
        &[(0b10010, &ENTRY_ENERGIZED_10338769724136607063)],
        &[(0b10010, &ENTRY_ENERGIZER_449515490537378567)],
        &[(0b10010, &ENTRY_ENERGIZERS_10194438715562893992)],
        &[(0b10010, &ENTRY_ENERGIZES_6958626290038298541)],
        &[(0b10010, &ENTRY_ENERGIZING_17242100400597322517)],
        &[(0b01001, &ENTRY_ENERGIZATION_8281923071042553435)],
        &[(0b01001, &ENTRY_ENERGIZE_9040021254285160273)],
        &[(0b01001, &ENTRY_ENERGIZED_10338769724136607063)],
        &[(0b01001, &ENTRY_ENERGIZER_449515490537378567)],
        &[(0b01001, &ENTRY_ENERGIZERS_10194438715562893992)],
        &[(0b01001, &ENTRY_ENERGIZES_6958626290038298541)],
        &[(0b01001, &ENTRY_ENERGIZING_17242100400597322517)],
    ],
    range: 2..=9,
};

static VARS_END_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_END_CHILDREN),
    value: None,
};

pub static VARS_END_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ameba"),
        dictgen::InsensitiveStr::Ascii("amebae"),
        dictgen::InsensitiveStr::Ascii("amebas"),
        dictgen::InsensitiveStr::Ascii("amebiasis"),
        dictgen::InsensitiveStr::Ascii("amebic"),
        dictgen::InsensitiveStr::Ascii("amoeba"),
        dictgen::InsensitiveStr::Ascii("amoebae"),
        dictgen::InsensitiveStr::Ascii("amoebas"),
        dictgen::InsensitiveStr::Ascii("amoebiasis"),
        dictgen::InsensitiveStr::Ascii("amoebic"),
        dictgen::InsensitiveStr::Ascii("eavor"),
        dictgen::InsensitiveStr::Ascii("eavored"),
        dictgen::InsensitiveStr::Ascii("eavorer"),
        dictgen::InsensitiveStr::Ascii("eavorers"),
        dictgen::InsensitiveStr::Ascii("eavoring"),
        dictgen::InsensitiveStr::Ascii("eavors"),
        dictgen::InsensitiveStr::Ascii("eavour"),
        dictgen::InsensitiveStr::Ascii("eavoured"),
        dictgen::InsensitiveStr::Ascii("eavourer"),
        dictgen::InsensitiveStr::Ascii("eavourers"),
        dictgen::InsensitiveStr::Ascii("eavouring"),
        dictgen::InsensitiveStr::Ascii("eavours"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("res"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ENDAMEBA_3674996897057489972)],
        &[(0b00001, &ENTRY_ENDAMEBAE_7672591039700210017)],
        &[(0b00001, &ENTRY_ENDAMEBAS_3894595978421412160)],
        &[(0b00001, &ENTRY_ENDAMEBIASIS_10526584886624559903)],
        &[(0b00001, &ENTRY_ENDAMEBIC_7654343873984680949)],
        &[(0b11010, &ENTRY_ENDAMEBA_3674996897057489972)],
        &[(0b11010, &ENTRY_ENDAMEBAE_7672591039700210017)],
        &[(0b11010, &ENTRY_ENDAMEBAS_3894595978421412160)],
        &[(0b11010, &ENTRY_ENDAMEBIASIS_10526584886624559903)],
        &[(0b11010, &ENTRY_ENDAMEBIC_7654343873984680949)],
        &[(0b11001, &ENTRY_ENDEAVOR_1861674104846402447)],
        &[(0b11001, &ENTRY_ENDEAVORED_12576902359096148689)],
        &[(0b11001, &ENTRY_ENDEAVORER_10269034998374810670)],
        &[(0b11001, &ENTRY_ENDEAVORERS_4264835563429458461)],
        &[(0b11001, &ENTRY_ENDEAVORING_454178916350601958)],
        &[(0b11001, &ENTRY_ENDEAVORS_5789569016694167960)],
        &[(0b11010, &ENTRY_ENDEAVOR_1861674104846402447)],
        &[(0b11010, &ENTRY_ENDEAVORED_12576902359096148689)],
        &[(0b11010, &ENTRY_ENDEAVORER_10269034998374810670)],
        &[(0b11010, &ENTRY_ENDEAVORERS_4264835563429458461)],
        &[(0b11010, &ENTRY_ENDEAVORING_454178916350601958)],
        &[(0b11010, &ENTRY_ENDEAVORS_5789569016694167960)],
        &[(0b00001, &ENTRY_ENDERS_14681940842455541593)],
        &[(0b11010, &ENTRY_ENDERS_14681940842455541593)],
    ],
    range: 3..=10,
};

static VARS_ENC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENC_CHILDREN),
    value: None,
};

pub static VARS_ENC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arnalisation"),
        dictgen::InsensitiveStr::Ascii("arnalise"),
        dictgen::InsensitiveStr::Ascii("arnalised"),
        dictgen::InsensitiveStr::Ascii("arnalises"),
        dictgen::InsensitiveStr::Ascii("arnalising"),
        dictgen::InsensitiveStr::Ascii("arnalization"),
        dictgen::InsensitiveStr::Ascii("arnalize"),
        dictgen::InsensitiveStr::Ascii("arnalized"),
        dictgen::InsensitiveStr::Ascii("arnalizes"),
        dictgen::InsensitiveStr::Ascii("arnalizing"),
        dictgen::InsensitiveStr::Ascii("ephalocele"),
        dictgen::InsensitiveStr::Ascii("ephalocoele"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ENCARNALIZATION_13214089082920950546)],
        &[(0b10010, &ENTRY_ENCARNALIZE_10850144919400996674)],
        &[(0b10010, &ENTRY_ENCARNALIZED_13979095018139018531)],
        &[(0b10010, &ENTRY_ENCARNALIZES_11369013563329530888)],
        &[(0b10010, &ENTRY_ENCARNALIZING_15767167372584376951)],
        &[(0b01001, &ENTRY_ENCARNALIZATION_13214089082920950546)],
        &[(0b01001, &ENTRY_ENCARNALIZE_10850144919400996674)],
        &[(0b01001, &ENTRY_ENCARNALIZED_13979095018139018531)],
        &[(0b01001, &ENTRY_ENCARNALIZES_11369013563329530888)],
        &[(0b01001, &ENTRY_ENCARNALIZING_15767167372584376951)],
        &[(0b00001, &ENTRY_ENCEPHALOCELE_1084758429798248621)],
        &[(0b11010, &ENTRY_ENCEPHALOCELE_1084758429798248621)],
        &[(0b11001, &ENTRY_ENCOLOR_1492202587953686714)],
        &[(0b11001, &ENTRY_ENCOLORED_4939538076917014241)],
        &[(0b11001, &ENTRY_ENCOLORING_4183307079529327993)],
        &[(0b11001, &ENTRY_ENCOLORS_8551106713845336956)],
        &[(0b11010, &ENTRY_ENCOLOR_1492202587953686714)],
        &[(0b11010, &ENTRY_ENCOLORED_4939538076917014241)],
        &[(0b11010, &ENTRY_ENCOLORING_4183307079529327993)],
        &[(0b11010, &ENTRY_ENCOLORS_8551106713845336956)],
    ],
    range: 4..=12,
};

static VARS_ENA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ENA_CHILDREN),
    value: None,
};

pub static VARS_ENA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("meled"),
        dictgen::InsensitiveStr::Ascii("meler"),
        dictgen::InsensitiveStr::Ascii("melers"),
        dictgen::InsensitiveStr::Ascii("meling"),
        dictgen::InsensitiveStr::Ascii("melings"),
        dictgen::InsensitiveStr::Ascii("melist"),
        dictgen::InsensitiveStr::Ascii("melists"),
        dictgen::InsensitiveStr::Ascii("melled"),
        dictgen::InsensitiveStr::Ascii("meller"),
        dictgen::InsensitiveStr::Ascii("mellers"),
        dictgen::InsensitiveStr::Ascii("melling"),
        dictgen::InsensitiveStr::Ascii("mellings"),
        dictgen::InsensitiveStr::Ascii("mellist"),
        dictgen::InsensitiveStr::Ascii("mellists"),
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("moredness"),
        dictgen::InsensitiveStr::Ascii("morednesses"),
        dictgen::InsensitiveStr::Ascii("moreds"),
        dictgen::InsensitiveStr::Ascii("moring"),
        dictgen::InsensitiveStr::Ascii("morment"),
        dictgen::InsensitiveStr::Ascii("morments"),
        dictgen::InsensitiveStr::Ascii("mors"),
        dictgen::InsensitiveStr::Ascii("mour"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mouredness"),
        dictgen::InsensitiveStr::Ascii("mourednesses"),
        dictgen::InsensitiveStr::Ascii("moureds"),
        dictgen::InsensitiveStr::Ascii("mouring"),
        dictgen::InsensitiveStr::Ascii("mourment"),
        dictgen::InsensitiveStr::Ascii("mourments"),
        dictgen::InsensitiveStr::Ascii("mours"),
        dictgen::InsensitiveStr::Ascii("rbor"),
        dictgen::InsensitiveStr::Ascii("rbors"),
        dictgen::InsensitiveStr::Ascii("rbour"),
        dictgen::InsensitiveStr::Ascii("rbours"),
    ],
    values: &[
        &[(0b01001, &ENTRY_ENAMELED_989404607221066133)],
        &[(0b00001, &ENTRY_ENAMELER_14880476578662103007)],
        &[(0b00001, &ENTRY_ENAMELERS_7855006556277285142)],
        &[(0b01001, &ENTRY_ENAMELING_651499017740975299)],
        &[(0b01001, &ENTRY_ENAMELINGS_4169856245572563917)],
        &[(0b00001, &ENTRY_ENAMELIST_6556021724769945893)],
        &[(0b00001, &ENTRY_ENAMELISTS_3600110159132815371)],
        &[(0b11010, &ENTRY_ENAMELED_989404607221066133)],
        &[(0b11010, &ENTRY_ENAMELER_14880476578662103007)],
        &[(0b11010, &ENTRY_ENAMELERS_7855006556277285142)],
        &[(0b11010, &ENTRY_ENAMELING_651499017740975299)],
        &[(0b11010, &ENTRY_ENAMELINGS_4169856245572563917)],
        &[(0b11010, &ENTRY_ENAMELIST_6556021724769945893)],
        &[(0b11010, &ENTRY_ENAMELISTS_3600110159132815371)],
        &[(0b11001, &ENTRY_ENAMOR_2911879302324239036)],
        &[(0b11001, &ENTRY_ENAMORED_16186178270973267134)],
        &[(0b11001, &ENTRY_ENAMOREDNESS_10996665665818617331)],
        &[(0b11001, &ENTRY_ENAMOREDNESSES_1348249767052969587)],
        &[(0b11001, &ENTRY_ENAMOREDS_6301165412476267762)],
        &[(0b11001, &ENTRY_ENAMORING_17989678795134022497)],
        &[(0b11001, &ENTRY_ENAMORMENT_7471105087461120528)],
        &[(0b11001, &ENTRY_ENAMORMENTS_13370005761506802640)],
        &[(0b11001, &ENTRY_ENAMORS_9636937238080184741)],
        &[(0b11010, &ENTRY_ENAMOR_2911879302324239036)],
        &[(0b11010, &ENTRY_ENAMORED_16186178270973267134)],
        &[(0b11010, &ENTRY_ENAMOREDNESS_10996665665818617331)],
        &[(0b11010, &ENTRY_ENAMOREDNESSES_1348249767052969587)],
        &[(0b11010, &ENTRY_ENAMOREDS_6301165412476267762)],
        &[(0b11010, &ENTRY_ENAMORING_17989678795134022497)],
        &[(0b11010, &ENTRY_ENAMORMENT_7471105087461120528)],
        &[(0b11010, &ENTRY_ENAMORMENTS_13370005761506802640)],
        &[(0b11010, &ENTRY_ENAMORS_9636937238080184741)],
        &[(0b00001, &ENTRY_ENARBOR_15915857770564812751)],
        &[(0b00001, &ENTRY_ENARBORS_8145891299588576620)],
        &[(0b11010, &ENTRY_ENARBOR_15915857770564812751)],
        &[(0b11010, &ENTRY_ENARBORS_8145891299588576620)],
    ],
    range: 3..=12,
};

static VARS_EM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EM_CHILDREN),
    value: None,
};

static VARS_EM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_EMB_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_EMO_NODE),
    Some(&VARS_EMP_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_EMU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_EMU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EMU_CHILDREN),
    value: None,
};

pub static VARS_EMU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("les"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lsionise"),
        dictgen::InsensitiveStr::Ascii("lsionised"),
        dictgen::InsensitiveStr::Ascii("lsionises"),
        dictgen::InsensitiveStr::Ascii("lsionising"),
        dictgen::InsensitiveStr::Ascii("lsionize"),
        dictgen::InsensitiveStr::Ascii("lsionized"),
        dictgen::InsensitiveStr::Ascii("lsionizes"),
        dictgen::InsensitiveStr::Ascii("lsionizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_EMULE_1972234654623253784)],
        &[(0b00001, &ENTRY_EMULED_10357664319101512866)],
        &[(0b00001, &ENTRY_EMULES_6796003945794582963)],
        &[(0b00001, &ENTRY_EMULING_11304283679719960362)],
        &[(0b10010, &ENTRY_EMULSIONIZE_7053945529955407436)],
        &[(0b10010, &ENTRY_EMULSIONIZED_16825639760819643474)],
        &[(0b10010, &ENTRY_EMULSIONIZES_16895497312962998295)],
        &[(0b10010, &ENTRY_EMULSIONIZING_10164290780298735348)],
        &[(0b01001, &ENTRY_EMULSIONIZE_7053945529955407436)],
        &[(0b01001, &ENTRY_EMULSIONIZED_16825639760819643474)],
        &[(0b01001, &ENTRY_EMULSIONIZES_16895497312962998295)],
        &[(0b01001, &ENTRY_EMULSIONIZING_10164290780298735348)],
    ],
    range: 2..=10,
};

static VARS_EMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EMP_CHILDREN),
    value: None,
};

pub static VARS_EMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aestic"),
        dictgen::InsensitiveStr::Ascii("aneled"),
        dictgen::InsensitiveStr::Ascii("aneling"),
        dictgen::InsensitiveStr::Ascii("anelled"),
        dictgen::InsensitiveStr::Ascii("anelling"),
        dictgen::InsensitiveStr::Ascii("athise"),
        dictgen::InsensitiveStr::Ascii("athised"),
        dictgen::InsensitiveStr::Ascii("athises"),
        dictgen::InsensitiveStr::Ascii("athising"),
        dictgen::InsensitiveStr::Ascii("athize"),
        dictgen::InsensitiveStr::Ascii("athized"),
        dictgen::InsensitiveStr::Ascii("athizes"),
        dictgen::InsensitiveStr::Ascii("athizing"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("estic"),
        dictgen::InsensitiveStr::Ascii("hasise"),
        dictgen::InsensitiveStr::Ascii("hasised"),
        dictgen::InsensitiveStr::Ascii("hasiser"),
        dictgen::InsensitiveStr::Ascii("hasisers"),
        dictgen::InsensitiveStr::Ascii("hasises"),
        dictgen::InsensitiveStr::Ascii("hasising"),
        dictgen::InsensitiveStr::Ascii("hasize"),
        dictgen::InsensitiveStr::Ascii("hasized"),
        dictgen::InsensitiveStr::Ascii("hasizer"),
        dictgen::InsensitiveStr::Ascii("hasizers"),
        dictgen::InsensitiveStr::Ascii("hasizes"),
        dictgen::InsensitiveStr::Ascii("hasizing"),
        dictgen::InsensitiveStr::Ascii("loye"),
        dictgen::InsensitiveStr::Ascii("loyes"),
        dictgen::InsensitiveStr::Ascii("yreumatise"),
        dictgen::InsensitiveStr::Ascii("yreumatised"),
        dictgen::InsensitiveStr::Ascii("yreumatises"),
        dictgen::InsensitiveStr::Ascii("yreumatising"),
        dictgen::InsensitiveStr::Ascii("yreumatize"),
        dictgen::InsensitiveStr::Ascii("yreumatized"),
        dictgen::InsensitiveStr::Ascii("yreumatizes"),
        dictgen::InsensitiveStr::Ascii("yreumatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EMPESTIC_14588541811997276042)],
        &[(0b00001, &ENTRY_IMPANELED_1167928814655817587)],
        &[(0b00001, &ENTRY_IMPANELING_8436697861195228668)],
        &[(0b11010, &ENTRY_IMPANELED_1167928814655817587)],
        &[(0b11010, &ENTRY_IMPANELING_8436697861195228668)],
        &[(0b10010, &ENTRY_EMPATHIZE_1626505131224915017)],
        &[(0b10010, &ENTRY_EMPATHIZED_14314991802693364328)],
        &[(0b10010, &ENTRY_EMPATHIZES_3252518257724496702)],
        &[(0b10010, &ENTRY_EMPATHIZING_137602655573298152)],
        &[(0b01001, &ENTRY_EMPATHIZE_1626505131224915017)],
        &[(0b01001, &ENTRY_EMPATHIZED_14314991802693364328)],
        &[(0b01001, &ENTRY_EMPATHIZES_3252518257724496702)],
        &[(0b01001, &ENTRY_EMPATHIZING_137602655573298152)],
        &[(0b10010, &ENTRY_EMPERIZE_1384359766709835064)],
        &[(0b10010, &ENTRY_EMPERIZED_3609672014387585150)],
        &[(0b10010, &ENTRY_EMPERIZES_5086736676911735307)],
        &[(0b10010, &ENTRY_EMPERIZING_6110004448635217910)],
        &[(0b01001, &ENTRY_EMPERIZE_1384359766709835064)],
        &[(0b01001, &ENTRY_EMPERIZED_3609672014387585150)],
        &[(0b01001, &ENTRY_EMPERIZES_5086736676911735307)],
        &[(0b01001, &ENTRY_EMPERIZING_6110004448635217910)],
        &[(0b10001, &ENTRY_EMPESTIC_14588541811997276042)],
        &[(0b10010, &ENTRY_EMPHASIZE_15381357888908119930)],
        &[(0b10010, &ENTRY_EMPHASIZED_649083867029832853)],
        &[(0b10010, &ENTRY_EMPHASIZER_11403370446466675303)],
        &[(0b10010, &ENTRY_EMPHASIZERS_18309998515128705301)],
        &[(0b10010, &ENTRY_EMPHASIZES_5772436931297938243)],
        &[(0b10010, &ENTRY_EMPHASIZING_8877699404927600063)],
        &[(0b01001, &ENTRY_EMPHASIZE_15381357888908119930)],
        &[(0b01001, &ENTRY_EMPHASIZED_649083867029832853)],
        &[(0b01001, &ENTRY_EMPHASIZER_11403370446466675303)],
        &[(0b01001, &ENTRY_EMPHASIZERS_18309998515128705301)],
        &[(0b01001, &ENTRY_EMPHASIZES_5772436931297938243)],
        &[(0b01001, &ENTRY_EMPHASIZING_8877699404927600063)],
        &[(0b00001, &ENTRY_EMPLOYEE_11669968157991382973)],
        &[(0b00001, &ENTRY_EMPLOYEES_5068613761389447671)],
        &[(0b10010, &ENTRY_EMPYREUMATIZE_15069068830093340604)],
        &[(0b10010, &ENTRY_EMPYREUMATIZED_15637035447882020628)],
        &[(0b10010, &ENTRY_EMPYREUMATIZES_9068196112099455402)],
        &[(0b10010, &ENTRY_EMPYREUMATIZING_2341701252050540041)],
        &[(0b01001, &ENTRY_EMPYREUMATIZE_15069068830093340604)],
        &[(0b01001, &ENTRY_EMPYREUMATIZED_15637035447882020628)],
        &[(0b01001, &ENTRY_EMPYREUMATIZES_9068196112099455402)],
        &[(0b01001, &ENTRY_EMPYREUMATIZING_2341701252050540041)],
    ],
    range: 4..=12,
};

static VARS_EMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EMO_CHILDREN),
    value: None,
};

pub static VARS_EMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalisation"),
        dictgen::InsensitiveStr::Ascii("tionalisations"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalization"),
        dictgen::InsensitiveStr::Ascii("tionalizations"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("tionise"),
        dictgen::InsensitiveStr::Ascii("tionises"),
        dictgen::InsensitiveStr::Ascii("tionize"),
        dictgen::InsensitiveStr::Ascii("tionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EMOTIONALIZATION_8285067224344808560)],
        &[(0b10010, &ENTRY_EMOTIONALIZATIONS_8068177829901134213)],
        &[(0b10010, &ENTRY_EMOTIONALIZE_9595590056518240613)],
        &[(0b10010, &ENTRY_EMOTIONALIZED_10357036420236281327)],
        &[(0b10010, &ENTRY_EMOTIONALIZES_3570691650798864535)],
        &[(0b10010, &ENTRY_EMOTIONALIZING_18340248172153003025)],
        &[(0b01001, &ENTRY_EMOTIONALIZATION_8285067224344808560)],
        &[(0b01001, &ENTRY_EMOTIONALIZATIONS_8068177829901134213)],
        &[(0b01001, &ENTRY_EMOTIONALIZE_9595590056518240613)],
        &[(0b01001, &ENTRY_EMOTIONALIZED_10357036420236281327)],
        &[(0b01001, &ENTRY_EMOTIONALIZES_3570691650798864535)],
        &[(0b01001, &ENTRY_EMOTIONALIZING_18340248172153003025)],
        &[(0b10010, &ENTRY_EMOTIONIZE_15015605431088092781)],
        &[(0b10010, &ENTRY_EMOTIONIZES_4881347793120141643)],
        &[(0b01001, &ENTRY_EMOTIONIZE_15015605431088092781)],
        &[(0b01001, &ENTRY_EMOTIONIZES_4881347793120141643)],
    ],
    range: 7..=14,
};

static VARS_EMB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EMB_CHILDREN),
    value: None,
};

pub static VARS_EMB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lematicise"),
        dictgen::InsensitiveStr::Ascii("lematicises"),
        dictgen::InsensitiveStr::Ascii("lematicize"),
        dictgen::InsensitiveStr::Ascii("lematicizes"),
        dictgen::InsensitiveStr::Ascii("lematisation"),
        dictgen::InsensitiveStr::Ascii("lematise"),
        dictgen::InsensitiveStr::Ascii("lematised"),
        dictgen::InsensitiveStr::Ascii("lematises"),
        dictgen::InsensitiveStr::Ascii("lematising"),
        dictgen::InsensitiveStr::Ascii("lematization"),
        dictgen::InsensitiveStr::Ascii("lematize"),
        dictgen::InsensitiveStr::Ascii("lematized"),
        dictgen::InsensitiveStr::Ascii("lematizes"),
        dictgen::InsensitiveStr::Ascii("lematizing"),
        dictgen::InsensitiveStr::Ascii("lemise"),
        dictgen::InsensitiveStr::Ascii("lemised"),
        dictgen::InsensitiveStr::Ascii("lemises"),
        dictgen::InsensitiveStr::Ascii("lemising"),
        dictgen::InsensitiveStr::Ascii("lemize"),
        dictgen::InsensitiveStr::Ascii("lemized"),
        dictgen::InsensitiveStr::Ascii("lemizes"),
        dictgen::InsensitiveStr::Ascii("lemizing"),
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("oweled"),
        dictgen::InsensitiveStr::Ascii("oweling"),
        dictgen::InsensitiveStr::Ascii("owelled"),
        dictgen::InsensitiveStr::Ascii("owelling"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EMBLEMATICIZE_5365410222867877084)],
        &[(0b10010, &ENTRY_EMBLEMATICIZES_1712964621674583121)],
        &[(0b01001, &ENTRY_EMBLEMATICIZE_5365410222867877084)],
        &[(0b01001, &ENTRY_EMBLEMATICIZES_1712964621674583121)],
        &[(0b10010, &ENTRY_EMBLEMATIZATION_3037774664990291578)],
        &[(0b10010, &ENTRY_EMBLEMATIZE_12296991017617416245)],
        &[(0b10010, &ENTRY_EMBLEMATIZED_11833827530357489690)],
        &[(0b10010, &ENTRY_EMBLEMATIZES_2053946387275416277)],
        &[(0b10010, &ENTRY_EMBLEMATIZING_15961105666979470386)],
        &[(0b01001, &ENTRY_EMBLEMATIZATION_3037774664990291578)],
        &[(0b01001, &ENTRY_EMBLEMATIZE_12296991017617416245)],
        &[(0b01001, &ENTRY_EMBLEMATIZED_11833827530357489690)],
        &[(0b01001, &ENTRY_EMBLEMATIZES_2053946387275416277)],
        &[(0b01001, &ENTRY_EMBLEMATIZING_15961105666979470386)],
        &[(0b10010, &ENTRY_EMBLEMIZE_1401519711379921201)],
        &[(0b10010, &ENTRY_EMBLEMIZED_10594160594841460386)],
        &[(0b10010, &ENTRY_EMBLEMIZES_4063063334401141759)],
        &[(0b10010, &ENTRY_EMBLEMIZING_10846409341438865894)],
        &[(0b01001, &ENTRY_EMBLEMIZE_1401519711379921201)],
        &[(0b01001, &ENTRY_EMBLEMIZED_10594160594841460386)],
        &[(0b01001, &ENTRY_EMBLEMIZES_4063063334401141759)],
        &[(0b01001, &ENTRY_EMBLEMIZING_10846409341438865894)],
        &[(0b10010, &ENTRY_EMBOLIZATION_11273543037803448058)],
        &[(0b01001, &ENTRY_EMBOLIZATION_11273543037803448058)],
        &[(0b00001, &ENTRY_EMBOWELED_4570354825435090850)],
        &[(0b00001, &ENTRY_EMBOWELING_2941434533991212942)],
        &[(0b11010, &ENTRY_EMBOWELED_4570354825435090850)],
        &[(0b11010, &ENTRY_EMBOWELING_2941434533991212942)],
    ],
    range: 6..=12,
};

static VARS_EL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_EL_CHILDREN),
    value: None,
};

static VARS_EL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ELA_NODE),
    None,
    None,
    None,
    Some(&VARS_ELE_NODE),
    None,
    None,
    None,
    Some(&VARS_ELI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ELI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELI_CHILDREN),
    value: None,
};

pub static VARS_ELI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sabethville"),
        dictgen::InsensitiveStr::Ascii("zabethanise"),
        dictgen::InsensitiveStr::Ascii("zabethanises"),
        dictgen::InsensitiveStr::Ascii("zabethanize"),
        dictgen::InsensitiveStr::Ascii("zabethanizes"),
        dictgen::InsensitiveStr::Ascii("zabethville"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ELIZABETHVILLE_7585322377517108871)],
        &[(0b10010, &ENTRY_ELIZABETHANIZE_14863227819015951221)],
        &[(0b10010, &ENTRY_ELIZABETHANIZES_8429280681938858568)],
        &[(0b01001, &ENTRY_ELIZABETHANIZE_14863227819015951221)],
        &[(0b01001, &ENTRY_ELIZABETHANIZES_8429280681938858568)],
        &[(0b01001, &ENTRY_ELIZABETHVILLE_7585322377517108871)],
    ],
    range: 11..=12,
};

static VARS_ELE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ELE_CHILDREN),
    value: None,
};

static VARS_ELE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_ELEC_NODE),
    None,
    None,
    None,
    Some(&VARS_ELEG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ELEM_NODE),
    None,
    Some(&VARS_ELEO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ELEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELEO_CHILDREN),
    value: None,
};

pub static VARS_ELEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("blast"),
        dictgen::InsensitiveStr::Ascii("lite"),
        dictgen::InsensitiveStr::Ascii("margaric"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("ptene"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ELEOBLAST_8021023369296032808)],
        &[(0b00001, &ENTRY_ELEOLITE_8551744649156866087)],
        &[(0b00001, &ENTRY_ELEOMARGARIC_16571690257823782694)],
        &[(0b00001, &ENTRY_ELEOMETER_8406501550306573221)],
        &[(0b00001, &ENTRY_ELEOPTENE_189677587011952998)],
    ],
    range: 4..=8,
};

static VARS_ELEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELEM_CHILDREN),
    value: None,
};

pub static VARS_ELEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entalise"),
        dictgen::InsensitiveStr::Ascii("entalises"),
        dictgen::InsensitiveStr::Ascii("entalize"),
        dictgen::InsensitiveStr::Ascii("entalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ELEMENTALIZE_4802665164184536596)],
        &[(0b10010, &ENTRY_ELEMENTALIZES_2940727419159689038)],
        &[(0b01001, &ENTRY_ELEMENTALIZE_4802665164184536596)],
        &[(0b01001, &ENTRY_ELEMENTALIZES_2940727419159689038)],
    ],
    range: 8..=9,
};

static VARS_ELEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELEG_CHILDREN),
    value: None,
};

pub static VARS_ELEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ELEGIZE_7937759892215576690)],
        &[(0b10010, &ENTRY_ELEGIZED_234567674978394451)],
        &[(0b10010, &ENTRY_ELEGIZES_10107353784266158156)],
        &[(0b10010, &ENTRY_ELEGIZING_3259872614184614593)],
        &[(0b01001, &ENTRY_ELEGIZE_7937759892215576690)],
        &[(0b01001, &ENTRY_ELEGIZED_234567674978394451)],
        &[(0b01001, &ENTRY_ELEGIZES_10107353784266158156)],
        &[(0b01001, &ENTRY_ELEGIZING_3259872614184614593)],
    ],
    range: 3..=5,
};

static VARS_ELEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELEC_CHILDREN),
    value: None,
};

pub static VARS_ELEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tricalise"),
        dictgen::InsensitiveStr::Ascii("tricalises"),
        dictgen::InsensitiveStr::Ascii("tricalize"),
        dictgen::InsensitiveStr::Ascii("tricalizes"),
        dictgen::InsensitiveStr::Ascii("tricise"),
        dictgen::InsensitiveStr::Ascii("tricises"),
        dictgen::InsensitiveStr::Ascii("tricize"),
        dictgen::InsensitiveStr::Ascii("tricizes"),
        dictgen::InsensitiveStr::Ascii("trisation"),
        dictgen::InsensitiveStr::Ascii("trisations"),
        dictgen::InsensitiveStr::Ascii("trise"),
        dictgen::InsensitiveStr::Ascii("trised"),
        dictgen::InsensitiveStr::Ascii("trises"),
        dictgen::InsensitiveStr::Ascii("trising"),
        dictgen::InsensitiveStr::Ascii("trization"),
        dictgen::InsensitiveStr::Ascii("trizations"),
        dictgen::InsensitiveStr::Ascii("trize"),
        dictgen::InsensitiveStr::Ascii("trized"),
        dictgen::InsensitiveStr::Ascii("trizes"),
        dictgen::InsensitiveStr::Ascii("trizing"),
        dictgen::InsensitiveStr::Ascii("troanaesthesia"),
        dictgen::InsensitiveStr::Ascii("troanaesthesias"),
        dictgen::InsensitiveStr::Ascii("troanesthesia"),
        dictgen::InsensitiveStr::Ascii("troanesthesias"),
        dictgen::InsensitiveStr::Ascii("trocauterisation"),
        dictgen::InsensitiveStr::Ascii("trocauterisations"),
        dictgen::InsensitiveStr::Ascii("trocauterization"),
        dictgen::InsensitiveStr::Ascii("trocauterizations"),
        dictgen::InsensitiveStr::Ascii("trodialyse"),
        dictgen::InsensitiveStr::Ascii("trodialyser"),
        dictgen::InsensitiveStr::Ascii("trodialysers"),
        dictgen::InsensitiveStr::Ascii("trodialyses"),
        dictgen::InsensitiveStr::Ascii("trodialyze"),
        dictgen::InsensitiveStr::Ascii("trodialyzer"),
        dictgen::InsensitiveStr::Ascii("trodialyzers"),
        dictgen::InsensitiveStr::Ascii("trodialyzes"),
        dictgen::InsensitiveStr::Ascii("trogalvanise"),
        dictgen::InsensitiveStr::Ascii("trogalvanises"),
        dictgen::InsensitiveStr::Ascii("trogalvanize"),
        dictgen::InsensitiveStr::Ascii("trogalvanizes"),
        dictgen::InsensitiveStr::Ascii("trohomoeopathies"),
        dictgen::InsensitiveStr::Ascii("trohomoeopathy"),
        dictgen::InsensitiveStr::Ascii("trolysation"),
        dictgen::InsensitiveStr::Ascii("trolyse"),
        dictgen::InsensitiveStr::Ascii("trolysed"),
        dictgen::InsensitiveStr::Ascii("trolyser"),
        dictgen::InsensitiveStr::Ascii("trolyses"),
        dictgen::InsensitiveStr::Ascii("trolysing"),
        dictgen::InsensitiveStr::Ascii("trolyzation"),
        dictgen::InsensitiveStr::Ascii("trolyze"),
        dictgen::InsensitiveStr::Ascii("trolyzed"),
        dictgen::InsensitiveStr::Ascii("trolyzer"),
        dictgen::InsensitiveStr::Ascii("trolyzes"),
        dictgen::InsensitiveStr::Ascii("trolyzing"),
        dictgen::InsensitiveStr::Ascii("tromagnetisable"),
        dictgen::InsensitiveStr::Ascii("tromagnetizable"),
        dictgen::InsensitiveStr::Ascii("trotonise"),
        dictgen::InsensitiveStr::Ascii("trotonises"),
        dictgen::InsensitiveStr::Ascii("trotonize"),
        dictgen::InsensitiveStr::Ascii("trotonizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ELECTRICALIZE_12653348063928720225)],
        &[(0b10010, &ENTRY_ELECTRICALIZES_11839544262325067272)],
        &[(0b01001, &ENTRY_ELECTRICALIZE_12653348063928720225)],
        &[(0b01001, &ENTRY_ELECTRICALIZES_11839544262325067272)],
        &[(0b10010, &ENTRY_ELECTRICIZE_4911015515844771622)],
        &[(0b10010, &ENTRY_ELECTRICIZES_3929185044639312558)],
        &[(0b01001, &ENTRY_ELECTRICIZE_4911015515844771622)],
        &[(0b01001, &ENTRY_ELECTRICIZES_3929185044639312558)],
        &[(0b10010, &ENTRY_ELECTRIZATION_7597451149298731659)],
        &[(0b10010, &ENTRY_ELECTRIZATIONS_13976280743140547777)],
        &[(0b10010, &ENTRY_ELECTRIZE_7840311297044744924)],
        &[(0b10010, &ENTRY_ELECTRIZED_14788122243236354566)],
        &[(0b10010, &ENTRY_ELECTRIZES_8739623266390445152)],
        &[(0b10010, &ENTRY_ELECTRIZING_14822771639775450790)],
        &[(0b01001, &ENTRY_ELECTRIZATION_7597451149298731659)],
        &[(0b01001, &ENTRY_ELECTRIZATIONS_13976280743140547777)],
        &[(0b01001, &ENTRY_ELECTRIZE_7840311297044744924)],
        &[(0b01001, &ENTRY_ELECTRIZED_14788122243236354566)],
        &[(0b01001, &ENTRY_ELECTRIZES_8739623266390445152)],
        &[(0b01001, &ENTRY_ELECTRIZING_14822771639775450790)],
        &[(0b11010, &ENTRY_ELECTROANESTHESIA_6580395617178938362)],
        &[(0b11010, &ENTRY_ELECTROANESTHESIAS_6303108604980733618)],
        &[(0b00001, &ENTRY_ELECTROANESTHESIA_6580395617178938362)],
        &[(0b00001, &ENTRY_ELECTROANESTHESIAS_6303108604980733618)],
        &[(0b10010, &ENTRY_ELECTROCAUTERIZATION_16903094457115645430)],
        &[(0b10010, &ENTRY_ELECTROCAUTERIZATIONS_16892082350141619114)],
        &[(0b01001, &ENTRY_ELECTROCAUTERIZATION_16903094457115645430)],
        &[(0b01001, &ENTRY_ELECTROCAUTERIZATIONS_16892082350141619114)],
        &[(0b11010, &ENTRY_ELECTRODIALYZE_2544367951940511335)],
        &[(0b11010, &ENTRY_ELECTRODIALYZER_12002873361469261764)],
        &[(0b11010, &ENTRY_ELECTRODIALYZERS_1528101750662982617)],
        &[(0b11010, &ENTRY_ELECTRODIALYZES_3747563092652406931)],
        &[(0b00001, &ENTRY_ELECTRODIALYZE_2544367951940511335)],
        &[(0b00001, &ENTRY_ELECTRODIALYZER_12002873361469261764)],
        &[(0b00001, &ENTRY_ELECTRODIALYZERS_1528101750662982617)],
        &[(0b00001, &ENTRY_ELECTRODIALYZES_3747563092652406931)],
        &[(0b10010, &ENTRY_ELECTROGALVANIZE_10321474051524162337)],
        &[(0b10010, &ENTRY_ELECTROGALVANIZES_13557830902076339969)],
        &[(0b01001, &ENTRY_ELECTROGALVANIZE_10321474051524162337)],
        &[(0b01001, &ENTRY_ELECTROGALVANIZES_13557830902076339969)],
        &[(0b11010, &ENTRY_ELECTROHOMEOPATHIES_17935525580469832451)],
        &[(0b11010, &ENTRY_ELECTROHOMEOPATHY_13185050690123434514)],
        &[(0b10010, &ENTRY_ELECTROLYZATION_9992320209908525657)],
        &[(0b11010, &ENTRY_ELECTROLYZE_7508850835901837851)],
        &[(0b11010, &ENTRY_ELECTROLYZED_8924003047140896401)],
        &[(0b10010, &ENTRY_ELECTROLYZER_712384492117912586)],
        &[(0b11010, &ENTRY_ELECTROLYZES_11477690971732519647)],
        &[(0b11010, &ENTRY_ELECTROLYZING_9315861603300473848)],
        &[(0b01001, &ENTRY_ELECTROLYZATION_9992320209908525657)],
        &[(0b00001, &ENTRY_ELECTROLYZE_7508850835901837851)],
        &[(0b00001, &ENTRY_ELECTROLYZED_8924003047140896401)],
        &[(0b01001, &ENTRY_ELECTROLYZER_712384492117912586)],
        &[(0b00001, &ENTRY_ELECTROLYZES_11477690971732519647)],
        &[(0b00001, &ENTRY_ELECTROLYZING_9315861603300473848)],
        &[(0b10010, &ENTRY_ELECTROMAGNETIZABLE_9739565016268970696)],
        &[(0b01001, &ENTRY_ELECTROMAGNETIZABLE_9739565016268970696)],
        &[(0b10010, &ENTRY_ELECTROTONIZE_16993410664382051345)],
        &[(0b10010, &ENTRY_ELECTROTONIZES_9465124994125319681)],
        &[(0b01001, &ENTRY_ELECTROTONIZE_16993410664382051345)],
        &[(0b01001, &ENTRY_ELECTROTONIZES_9465124994125319681)],
    ],
    range: 5..=17,
};

static VARS_ELA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ELA_CHILDREN),
    value: None,
};

pub static VARS_ELA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eoblast"),
        dictgen::InsensitiveStr::Ascii("eolite"),
        dictgen::InsensitiveStr::Ascii("eomargaric"),
        dictgen::InsensitiveStr::Ascii("eometer"),
        dictgen::InsensitiveStr::Ascii("eoptene"),
        dictgen::InsensitiveStr::Ascii("sticisation"),
        dictgen::InsensitiveStr::Ascii("sticise"),
        dictgen::InsensitiveStr::Ascii("sticised"),
        dictgen::InsensitiveStr::Ascii("sticiser"),
        dictgen::InsensitiveStr::Ascii("sticisers"),
        dictgen::InsensitiveStr::Ascii("sticises"),
        dictgen::InsensitiveStr::Ascii("sticising"),
        dictgen::InsensitiveStr::Ascii("sticization"),
        dictgen::InsensitiveStr::Ascii("sticize"),
        dictgen::InsensitiveStr::Ascii("sticized"),
        dictgen::InsensitiveStr::Ascii("sticizer"),
        dictgen::InsensitiveStr::Ascii("sticizers"),
        dictgen::InsensitiveStr::Ascii("sticizes"),
        dictgen::InsensitiveStr::Ascii("sticizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ELEOBLAST_8021023369296032808)],
        &[(0b11010, &ENTRY_ELEOLITE_8551744649156866087)],
        &[(0b11010, &ENTRY_ELEOMARGARIC_16571690257823782694)],
        &[(0b11010, &ENTRY_ELEOMETER_8406501550306573221)],
        &[(0b11010, &ENTRY_ELEOPTENE_189677587011952998)],
        &[(0b10010, &ENTRY_ELASTICIZATION_15154020732606510926)],
        &[(0b10010, &ENTRY_ELASTICIZE_6142699365245709219)],
        &[(0b10010, &ENTRY_ELASTICIZED_17571893237729540044)],
        &[(0b10010, &ENTRY_ELASTICIZER_15500813180956764351)],
        &[(0b10010, &ENTRY_ELASTICIZERS_16095393649186847498)],
        &[(0b10010, &ENTRY_ELASTICIZES_15507458752832878092)],
        &[(0b10010, &ENTRY_ELASTICIZING_14323113355310943519)],
        &[(0b01001, &ENTRY_ELASTICIZATION_15154020732606510926)],
        &[(0b01001, &ENTRY_ELASTICIZE_6142699365245709219)],
        &[(0b01001, &ENTRY_ELASTICIZED_17571893237729540044)],
        &[(0b01001, &ENTRY_ELASTICIZER_15500813180956764351)],
        &[(0b01001, &ENTRY_ELASTICIZERS_16095393649186847498)],
        &[(0b01001, &ENTRY_ELASTICIZES_15507458752832878092)],
        &[(0b01001, &ENTRY_ELASTICIZING_14323113355310943519)],
    ],
    range: 6..=11,
};

static VARS_EG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EG_CHILDREN),
    value: None,
};

pub static VARS_EG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ilops"),
        dictgen::InsensitiveStr::Ascii("is"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("logue"),
        dictgen::InsensitiveStr::Ascii("oise"),
        dictgen::InsensitiveStr::Ascii("oiser"),
        dictgen::InsensitiveStr::Ascii("oisers"),
        dictgen::InsensitiveStr::Ascii("oises"),
        dictgen::InsensitiveStr::Ascii("oize"),
        dictgen::InsensitiveStr::Ascii("oizer"),
        dictgen::InsensitiveStr::Ascii("oizers"),
        dictgen::InsensitiveStr::Ascii("oizes"),
        dictgen::InsensitiveStr::Ascii("ophony"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("ritude"),
        dictgen::InsensitiveStr::Ascii("yptianisation"),
        dictgen::InsensitiveStr::Ascii("yptianisations"),
        dictgen::InsensitiveStr::Ascii("yptianise"),
        dictgen::InsensitiveStr::Ascii("yptianised"),
        dictgen::InsensitiveStr::Ascii("yptianises"),
        dictgen::InsensitiveStr::Ascii("yptianising"),
        dictgen::InsensitiveStr::Ascii("yptianization"),
        dictgen::InsensitiveStr::Ascii("yptianizations"),
        dictgen::InsensitiveStr::Ascii("yptianize"),
        dictgen::InsensitiveStr::Ascii("yptianized"),
        dictgen::InsensitiveStr::Ascii("yptianizes"),
        dictgen::InsensitiveStr::Ascii("yptianizing"),
        dictgen::InsensitiveStr::Ascii("yptise"),
        dictgen::InsensitiveStr::Ascii("yptises"),
        dictgen::InsensitiveStr::Ascii("yptize"),
        dictgen::InsensitiveStr::Ascii("yptizes"),
    ],
    values: &[
        &[
            (0b00001, &ENTRY_EGER_3267279819185100866),
            (0b00001, &ENTRY_EGER_370209078151771517),
        ],
        &[(0b00001, &ENTRY_EGILOPS_15304768767282746036)],
        &[(0b00001, &ENTRY_AEGIS_7746172769585303727)],
        &[(0b00001, &ENTRY_AEGISES_17452084053545629669)],
        &[(0b00001, &ENTRY_EGLOGUE_16104631981488511989)],
        &[(0b10010, &ENTRY_EGOIZE_848168811919938232)],
        &[(0b10010, &ENTRY_EGOIZER_6042847438515593386)],
        &[(0b10010, &ENTRY_EGOIZERS_16599062205549549591)],
        &[(0b10010, &ENTRY_EGOIZES_7296127181194814948)],
        &[(0b01001, &ENTRY_EGOIZE_848168811919938232)],
        &[(0b01001, &ENTRY_EGOIZER_6042847438515593386)],
        &[(0b01001, &ENTRY_EGOIZERS_16599062205549549591)],
        &[(0b01001, &ENTRY_EGOIZES_7296127181194814948)],
        &[(0b00001, &ENTRY_EGOPHONY_2012602110086773588)],
        &[(0b10010, &ENTRY_EGOTIZE_10473969129670528822)],
        &[(0b10010, &ENTRY_EGOTIZED_14948617827289949091)],
        &[(0b10010, &ENTRY_EGOTIZES_17356051654981309847)],
        &[(0b10010, &ENTRY_EGOTIZING_255552054661601129)],
        &[(0b01001, &ENTRY_EGOTIZE_10473969129670528822)],
        &[(0b01001, &ENTRY_EGOTIZED_14948617827289949091)],
        &[(0b01001, &ENTRY_EGOTIZES_17356051654981309847)],
        &[(0b01001, &ENTRY_EGOTIZING_255552054661601129)],
        &[(0b11010, &ENTRY_EGER_3267279819185100866)],
        &[(0b00001, &ENTRY_EGRITUDE_9946971293935803579)],
        &[(0b10010, &ENTRY_EGYPTIANIZATION_10487155187974848335)],
        &[(0b10010, &ENTRY_EGYPTIANIZATIONS_14876553018910189078)],
        &[(0b10010, &ENTRY_EGYPTIANIZE_3829453833375546559)],
        &[(0b10010, &ENTRY_EGYPTIANIZED_16285206324460702808)],
        &[(0b10010, &ENTRY_EGYPTIANIZES_8703144950337739653)],
        &[(0b10010, &ENTRY_EGYPTIANIZING_14447728275835277106)],
        &[(0b01001, &ENTRY_EGYPTIANIZATION_10487155187974848335)],
        &[(0b01001, &ENTRY_EGYPTIANIZATIONS_14876553018910189078)],
        &[(0b01001, &ENTRY_EGYPTIANIZE_3829453833375546559)],
        &[(0b01001, &ENTRY_EGYPTIANIZED_16285206324460702808)],
        &[(0b01001, &ENTRY_EGYPTIANIZES_8703144950337739653)],
        &[(0b01001, &ENTRY_EGYPTIANIZING_14447728275835277106)],
        &[(0b10010, &ENTRY_EGYPTIZE_7334581701121422605)],
        &[(0b10010, &ENTRY_EGYPTIZES_9609036163136479870)],
        &[(0b01001, &ENTRY_EGYPTIZE_7334581701121422605)],
        &[(0b01001, &ENTRY_EGYPTIZES_9609036163136479870)],
    ],
    range: 2..=14,
};

static VARS_EF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EF_CHILDREN),
    value: None,
};

pub static VARS_EF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fectualise"),
        dictgen::InsensitiveStr::Ascii("fectualises"),
        dictgen::InsensitiveStr::Ascii("fectualize"),
        dictgen::InsensitiveStr::Ascii("fectualizes"),
        dictgen::InsensitiveStr::Ascii("feminatise"),
        dictgen::InsensitiveStr::Ascii("feminatises"),
        dictgen::InsensitiveStr::Ascii("feminatize"),
        dictgen::InsensitiveStr::Ascii("feminatizes"),
        dictgen::InsensitiveStr::Ascii("feminisation"),
        dictgen::InsensitiveStr::Ascii("feminise"),
        dictgen::InsensitiveStr::Ascii("feminised"),
        dictgen::InsensitiveStr::Ascii("feminises"),
        dictgen::InsensitiveStr::Ascii("feminising"),
        dictgen::InsensitiveStr::Ascii("feminization"),
        dictgen::InsensitiveStr::Ascii("feminize"),
        dictgen::InsensitiveStr::Ascii("feminized"),
        dictgen::InsensitiveStr::Ascii("feminizes"),
        dictgen::InsensitiveStr::Ascii("feminizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EFFECTUALIZE_2854942339620949483)],
        &[(0b10010, &ENTRY_EFFECTUALIZES_5750997542764404732)],
        &[(0b01001, &ENTRY_EFFECTUALIZE_2854942339620949483)],
        &[(0b01001, &ENTRY_EFFECTUALIZES_5750997542764404732)],
        &[(0b10010, &ENTRY_EFFEMINATIZE_6301232153675654071)],
        &[(0b10010, &ENTRY_EFFEMINATIZES_10162259315067828496)],
        &[(0b01001, &ENTRY_EFFEMINATIZE_6301232153675654071)],
        &[(0b01001, &ENTRY_EFFEMINATIZES_10162259315067828496)],
        &[(0b10010, &ENTRY_EFFEMINIZATION_3469570906021333989)],
        &[(0b10010, &ENTRY_EFFEMINIZE_3367646221923186814)],
        &[(0b10010, &ENTRY_EFFEMINIZED_2488051553108619858)],
        &[(0b10010, &ENTRY_EFFEMINIZES_1751738554568598255)],
        &[(0b10010, &ENTRY_EFFEMINIZING_14300719326884303630)],
        &[(0b01001, &ENTRY_EFFEMINIZATION_3469570906021333989)],
        &[(0b01001, &ENTRY_EFFEMINIZE_3367646221923186814)],
        &[(0b01001, &ENTRY_EFFEMINIZED_2488051553108619858)],
        &[(0b01001, &ENTRY_EFFEMINIZES_1751738554568598255)],
        &[(0b01001, &ENTRY_EFFEMINIZING_14300719326884303630)],
    ],
    range: 8..=12,
};

static VARS_EE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EE_CHILDREN),
    value: None,
};

pub static VARS_EE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("tion")],
    values: &[&[(0b00001, &ENTRY_EETION_7506982938713093790)]],
    range: 4..=4,
};

static VARS_ED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ED_CHILDREN),
    value: None,
};

pub static VARS_ED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ema"),
        dictgen::InsensitiveStr::Ascii("emas"),
        dictgen::InsensitiveStr::Ascii("ematose"),
        dictgen::InsensitiveStr::Ascii("ematous"),
        dictgen::InsensitiveStr::Ascii("enisation"),
        dictgen::InsensitiveStr::Ascii("enisations"),
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enization"),
        dictgen::InsensitiveStr::Ascii("enizations"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("icule"),
        dictgen::InsensitiveStr::Ascii("ile"),
        dictgen::InsensitiveStr::Ascii("iles"),
        dictgen::InsensitiveStr::Ascii("ility"),
        dictgen::InsensitiveStr::Ascii("itorialisation"),
        dictgen::InsensitiveStr::Ascii("itorialisations"),
        dictgen::InsensitiveStr::Ascii("itorialise"),
        dictgen::InsensitiveStr::Ascii("itorialised"),
        dictgen::InsensitiveStr::Ascii("itorialiser"),
        dictgen::InsensitiveStr::Ascii("itorialises"),
        dictgen::InsensitiveStr::Ascii("itorialising"),
        dictgen::InsensitiveStr::Ascii("itorialization"),
        dictgen::InsensitiveStr::Ascii("itorializations"),
        dictgen::InsensitiveStr::Ascii("itorialize"),
        dictgen::InsensitiveStr::Ascii("itorialized"),
        dictgen::InsensitiveStr::Ascii("itorializer"),
        dictgen::InsensitiveStr::Ascii("itorializes"),
        dictgen::InsensitiveStr::Ascii("itorializing"),
    ],
    values: &[
        &[(0b11001, &ENTRY_EDEMA_6018744134424908364)],
        &[(0b11001, &ENTRY_EDEMAS_7742566514366737816)],
        &[(0b11001, &ENTRY_EDEMATOSE_16851378643586465230)],
        &[(0b11001, &ENTRY_EDEMATOUS_2501565917049629990)],
        &[(0b10010, &ENTRY_EDENIZATION_14877368160810371784)],
        &[(0b10010, &ENTRY_EDENIZATIONS_17717672445150358731)],
        &[(0b10010, &ENTRY_EDENIZE_4547310883249177007)],
        &[(0b10010, &ENTRY_EDENIZES_13029714813212856027)],
        &[(0b01001, &ENTRY_EDENIZATION_14877368160810371784)],
        &[(0b01001, &ENTRY_EDENIZATIONS_17717672445150358731)],
        &[(0b01001, &ENTRY_EDENIZE_4547310883249177007)],
        &[(0b01001, &ENTRY_EDENIZES_13029714813212856027)],
        &[(0b00001, &ENTRY_EDICULE_10918770642841249439)],
        &[(0b00001, &ENTRY_AEDILE_7817422603194149495)],
        &[(0b00001, &ENTRY_AEDILES_7017631595752864436)],
        &[(0b00001, &ENTRY_EDILITY_10658105135103528164)],
        &[(0b10010, &ENTRY_EDITORIALIZATION_16653146908113662887)],
        &[(0b10010, &ENTRY_EDITORIALIZATIONS_12319328368566597913)],
        &[(0b10010, &ENTRY_EDITORIALIZE_425925589943067801)],
        &[(0b10010, &ENTRY_EDITORIALIZED_9618808155032869338)],
        &[(0b10010, &ENTRY_EDITORIALIZER_907841174282390671)],
        &[(0b10010, &ENTRY_EDITORIALIZES_3002090244472118034)],
        &[(0b10010, &ENTRY_EDITORIALIZING_4056192079667477523)],
        &[(0b01001, &ENTRY_EDITORIALIZATION_16653146908113662887)],
        &[(0b01001, &ENTRY_EDITORIALIZATIONS_12319328368566597913)],
        &[(0b01001, &ENTRY_EDITORIALIZE_425925589943067801)],
        &[(0b01001, &ENTRY_EDITORIALIZED_9618808155032869338)],
        &[(0b01001, &ENTRY_EDITORIALIZER_907841174282390671)],
        &[(0b01001, &ENTRY_EDITORIALIZES_3002090244472118034)],
        &[(0b01001, &ENTRY_EDITORIALIZING_4056192079667477523)],
    ],
    range: 3..=15,
};

static VARS_EC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EC_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_EC_18369594411890017360)]),
};

pub static VARS_EC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("clesiasticise"),
        dictgen::InsensitiveStr::Ascii("clesiasticises"),
        dictgen::InsensitiveStr::Ascii("clesiasticize"),
        dictgen::InsensitiveStr::Ascii("clesiasticizes"),
        dictgen::InsensitiveStr::Ascii("hoise"),
        dictgen::InsensitiveStr::Ascii("hoised"),
        dictgen::InsensitiveStr::Ascii("hoises"),
        dictgen::InsensitiveStr::Ascii("hoising"),
        dictgen::InsensitiveStr::Ascii("hoize"),
        dictgen::InsensitiveStr::Ascii("hoized"),
        dictgen::InsensitiveStr::Ascii("hoizes"),
        dictgen::InsensitiveStr::Ascii("hoizing"),
        dictgen::InsensitiveStr::Ascii("lecticise"),
        dictgen::InsensitiveStr::Ascii("lecticises"),
        dictgen::InsensitiveStr::Ascii("lecticize"),
        dictgen::InsensitiveStr::Ascii("lecticizes"),
        dictgen::InsensitiveStr::Ascii("oid"),
        dictgen::InsensitiveStr::Ascii("onomisation"),
        dictgen::InsensitiveStr::Ascii("onomisations"),
        dictgen::InsensitiveStr::Ascii("onomise"),
        dictgen::InsensitiveStr::Ascii("onomised"),
        dictgen::InsensitiveStr::Ascii("onomiser"),
        dictgen::InsensitiveStr::Ascii("onomisers"),
        dictgen::InsensitiveStr::Ascii("onomises"),
        dictgen::InsensitiveStr::Ascii("onomising"),
        dictgen::InsensitiveStr::Ascii("onomization"),
        dictgen::InsensitiveStr::Ascii("onomizations"),
        dictgen::InsensitiveStr::Ascii("onomize"),
        dictgen::InsensitiveStr::Ascii("onomized"),
        dictgen::InsensitiveStr::Ascii("onomizer"),
        dictgen::InsensitiveStr::Ascii("onomizers"),
        dictgen::InsensitiveStr::Ascii("onomizes"),
        dictgen::InsensitiveStr::Ascii("onomizing"),
        dictgen::InsensitiveStr::Ascii("ophobia"),
        dictgen::InsensitiveStr::Ascii("stasise"),
        dictgen::InsensitiveStr::Ascii("stasised"),
        dictgen::InsensitiveStr::Ascii("stasises"),
        dictgen::InsensitiveStr::Ascii("stasising"),
        dictgen::InsensitiveStr::Ascii("stasize"),
        dictgen::InsensitiveStr::Ascii("stasized"),
        dictgen::InsensitiveStr::Ascii("stasizes"),
        dictgen::InsensitiveStr::Ascii("stasizing"),
        dictgen::InsensitiveStr::Ascii("staticise"),
        dictgen::InsensitiveStr::Ascii("staticises"),
        dictgen::InsensitiveStr::Ascii("staticize"),
        dictgen::InsensitiveStr::Ascii("staticizes"),
        dictgen::InsensitiveStr::Ascii("tethmoid"),
        dictgen::InsensitiveStr::Ascii("tocelic"),
        dictgen::InsensitiveStr::Ascii("tocoelic"),
        dictgen::InsensitiveStr::Ascii("toethmoid"),
        dictgen::InsensitiveStr::Ascii("us"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ECCLESIASTICIZE_5375790565507371661)],
        &[(0b10010, &ENTRY_ECCLESIASTICIZES_17947325437796182000)],
        &[(0b01001, &ENTRY_ECCLESIASTICIZE_5375790565507371661)],
        &[(0b01001, &ENTRY_ECCLESIASTICIZES_17947325437796182000)],
        &[(0b10010, &ENTRY_ECHOIZE_9793911410527060783)],
        &[(0b10010, &ENTRY_ECHOIZED_6584344175654222383)],
        &[(0b10010, &ENTRY_ECHOIZES_17651680927186205508)],
        &[(0b10010, &ENTRY_ECHOIZING_13817992796446083050)],
        &[(0b01001, &ENTRY_ECHOIZE_9793911410527060783)],
        &[(0b01001, &ENTRY_ECHOIZED_6584344175654222383)],
        &[(0b01001, &ENTRY_ECHOIZES_17651680927186205508)],
        &[(0b01001, &ENTRY_ECHOIZING_13817992796446083050)],
        &[(0b10010, &ENTRY_ECLECTICIZE_1537579377409875615)],
        &[(0b10010, &ENTRY_ECLECTICIZES_18162048424932631142)],
        &[(0b01001, &ENTRY_ECLECTICIZE_1537579377409875615)],
        &[(0b01001, &ENTRY_ECLECTICIZES_18162048424932631142)],
        &[(0b00001, &ENTRY_ECOID_15718380068289810443)],
        &[(0b10010, &ENTRY_ECONOMIZATION_17236921042856233623)],
        &[(0b10010, &ENTRY_ECONOMIZATIONS_13677505030173502975)],
        &[(0b10010, &ENTRY_ECONOMIZE_12358668986073235407)],
        &[(0b10010, &ENTRY_ECONOMIZED_18148417393969980009)],
        &[(0b10010, &ENTRY_ECONOMIZER_14737250670952641028)],
        &[(0b10010, &ENTRY_ECONOMIZERS_12502480689214202445)],
        &[(0b10010, &ENTRY_ECONOMIZES_12987737212565587737)],
        &[(0b10010, &ENTRY_ECONOMIZING_11359270378553989667)],
        &[(0b01001, &ENTRY_ECONOMIZATION_17236921042856233623)],
        &[(0b01001, &ENTRY_ECONOMIZATIONS_13677505030173502975)],
        &[(0b01001, &ENTRY_ECONOMIZE_12358668986073235407)],
        &[(0b01001, &ENTRY_ECONOMIZED_18148417393969980009)],
        &[(0b01001, &ENTRY_ECONOMIZER_14737250670952641028)],
        &[(0b01001, &ENTRY_ECONOMIZERS_12502480689214202445)],
        &[(0b01001, &ENTRY_ECONOMIZES_12987737212565587737)],
        &[(0b01001, &ENTRY_ECONOMIZING_11359270378553989667)],
        &[(0b00001, &ENTRY_ECOPHOBIA_3341542489768933704)],
        &[(0b10010, &ENTRY_ECSTASIZE_12478888629525898090)],
        &[(0b10010, &ENTRY_ECSTASIZED_14433048399656133421)],
        &[(0b10010, &ENTRY_ECSTASIZES_4161308607604786330)],
        &[(0b10010, &ENTRY_ECSTASIZING_2299211862700315587)],
        &[(0b01001, &ENTRY_ECSTASIZE_12478888629525898090)],
        &[(0b01001, &ENTRY_ECSTASIZED_14433048399656133421)],
        &[(0b01001, &ENTRY_ECSTASIZES_4161308607604786330)],
        &[(0b01001, &ENTRY_ECSTASIZING_2299211862700315587)],
        &[(0b10010, &ENTRY_ECSTATICIZE_10857806109758048478)],
        &[(0b10010, &ENTRY_ECSTATICIZES_12312353657798123304)],
        &[(0b01001, &ENTRY_ECSTATICIZE_10857806109758048478)],
        &[(0b01001, &ENTRY_ECSTATICIZES_12312353657798123304)],
        &[(0b00001, &ENTRY_ECTETHMOID_4932886455054265154)],
        &[(0b10001, &ENTRY_ECTOCELIC_15109589632064964048)],
        &[(0b11010, &ENTRY_ECTOCELIC_15109589632064964048)],
        &[(0b11010, &ENTRY_ECTETHMOID_4932886455054265154)],
        &[(0b00001, &ENTRY_ECUS_7337291910539278082)],
    ],
    range: 2..=14,
};

static VARS_EB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EB_CHILDREN),
    value: None,
};

pub static VARS_EB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ionise"),
        dictgen::InsensitiveStr::Ascii("ionised"),
        dictgen::InsensitiveStr::Ascii("ionises"),
        dictgen::InsensitiveStr::Ascii("ionising"),
        dictgen::InsensitiveStr::Ascii("ionize"),
        dictgen::InsensitiveStr::Ascii("ionized"),
        dictgen::InsensitiveStr::Ascii("ionizes"),
        dictgen::InsensitiveStr::Ascii("ionizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_EBIONIZE_14882150669745577807)],
        &[(0b10010, &ENTRY_EBIONIZED_607134243617959572)],
        &[(0b10010, &ENTRY_EBIONIZES_4728139485714479539)],
        &[(0b10010, &ENTRY_EBIONIZING_6877070461214793032)],
        &[(0b01001, &ENTRY_EBIONIZE_14882150669745577807)],
        &[(0b01001, &ENTRY_EBIONIZED_607134243617959572)],
        &[(0b01001, &ENTRY_EBIONIZES_4728139485714479539)],
        &[(0b01001, &ENTRY_EBIONIZING_6877070461214793032)],
        &[(0b10010, &ENTRY_EBONIZATION_5157733486316868335)],
        &[(0b10010, &ENTRY_EBONIZE_8171442481512187913)],
        &[(0b10010, &ENTRY_EBONIZED_3445883171941210725)],
        &[(0b10010, &ENTRY_EBONIZES_7098552992016802268)],
        &[(0b10010, &ENTRY_EBONIZING_1463384613006749087)],
        &[(0b01001, &ENTRY_EBONIZATION_5157733486316868335)],
        &[(0b01001, &ENTRY_EBONIZE_8171442481512187913)],
        &[(0b01001, &ENTRY_EBONIZED_3445883171941210725)],
        &[(0b01001, &ENTRY_EBONIZES_7098552992016802268)],
        &[(0b01001, &ENTRY_EBONIZING_1463384613006749087)],
    ],
    range: 5..=9,
};

static VARS_EA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_EA_CHILDREN),
    value: None,
};

pub static VARS_EA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etion"),
        dictgen::InsensitiveStr::Ascii("rlierise"),
        dictgen::InsensitiveStr::Ascii("rlierised"),
        dictgen::InsensitiveStr::Ascii("rlierises"),
        dictgen::InsensitiveStr::Ascii("rlierising"),
        dictgen::InsensitiveStr::Ascii("rlierize"),
        dictgen::InsensitiveStr::Ascii("rlierized"),
        dictgen::InsensitiveStr::Ascii("rlierizes"),
        dictgen::InsensitiveStr::Ascii("rlierizing"),
        dictgen::InsensitiveStr::Ascii("sternise"),
        dictgen::InsensitiveStr::Ascii("sternize"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EETION_7506982938713093790)],
        &[(0b10010, &ENTRY_EARLIERIZE_11997942640911832041)],
        &[(0b10010, &ENTRY_EARLIERIZED_5951041999526558231)],
        &[(0b10010, &ENTRY_EARLIERIZES_5592536878851474631)],
        &[(0b10010, &ENTRY_EARLIERIZING_8179681759986389983)],
        &[(0b01001, &ENTRY_EARLIERIZE_11997942640911832041)],
        &[(0b01001, &ENTRY_EARLIERIZED_5951041999526558231)],
        &[(0b01001, &ENTRY_EARLIERIZES_5592536878851474631)],
        &[(0b01001, &ENTRY_EARLIERIZING_8179681759986389983)],
        &[(0b10010, &ENTRY_EASTERNIZE_12013346158934132557)],
        &[(0b01001, &ENTRY_EASTERNIZE_12013346158934132557)],
    ],
    range: 5..=10,
};

static VARS_D_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_D_CHILDREN),
    value: None,
};

static VARS_D_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DA_NODE),
    None,
    None,
    None,
    Some(&VARS_DE_NODE),
    None,
    None,
    None,
    Some(&VARS_DI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DO_NODE),
    None,
    None,
    Some(&VARS_DR_NODE),
    None,
    None,
    Some(&VARS_DU_NODE),
    None,
    None,
    None,
    Some(&VARS_DY_NODE),
    None,
];

static VARS_DY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DY_CHILDREN),
    value: None,
};

pub static VARS_DY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("namise"),
        dictgen::InsensitiveStr::Ascii("namised"),
        dictgen::InsensitiveStr::Ascii("namises"),
        dictgen::InsensitiveStr::Ascii("namising"),
        dictgen::InsensitiveStr::Ascii("namize"),
        dictgen::InsensitiveStr::Ascii("namized"),
        dictgen::InsensitiveStr::Ascii("namizes"),
        dictgen::InsensitiveStr::Ascii("namizing"),
        dictgen::InsensitiveStr::Ascii("saesthesia"),
        dictgen::InsensitiveStr::Ascii("saesthetic"),
        dictgen::InsensitiveStr::Ascii("sesthesia"),
        dictgen::InsensitiveStr::Ascii("sesthetic"),
        dictgen::InsensitiveStr::Ascii("smenorrhea"),
        dictgen::InsensitiveStr::Ascii("smenorrheal"),
        dictgen::InsensitiveStr::Ascii("smenorrheas"),
        dictgen::InsensitiveStr::Ascii("smenorrheic"),
        dictgen::InsensitiveStr::Ascii("smenorrhoea"),
        dictgen::InsensitiveStr::Ascii("smenorrhoeal"),
        dictgen::InsensitiveStr::Ascii("smenorrhoeas"),
        dictgen::InsensitiveStr::Ascii("smenorrhoeic"),
        dictgen::InsensitiveStr::Ascii("spnea"),
        dictgen::InsensitiveStr::Ascii("spneal"),
        dictgen::InsensitiveStr::Ascii("spneas"),
        dictgen::InsensitiveStr::Ascii("spneic"),
        dictgen::InsensitiveStr::Ascii("spnoea"),
        dictgen::InsensitiveStr::Ascii("spnoeal"),
        dictgen::InsensitiveStr::Ascii("spnoeas"),
        dictgen::InsensitiveStr::Ascii("spnoeic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DYNAMIZE_16898679564021204348)],
        &[(0b10010, &ENTRY_DYNAMIZED_11851467384344631451)],
        &[(0b10010, &ENTRY_DYNAMIZES_8572022122021418990)],
        &[(0b10010, &ENTRY_DYNAMIZING_15204260139319478124)],
        &[(0b01001, &ENTRY_DYNAMIZE_16898679564021204348)],
        &[(0b01001, &ENTRY_DYNAMIZED_11851467384344631451)],
        &[(0b01001, &ENTRY_DYNAMIZES_8572022122021418990)],
        &[(0b01001, &ENTRY_DYNAMIZING_15204260139319478124)],
        &[(0b11010, &ENTRY_DYSESTHESIA_10145261120272617451)],
        &[(0b11010, &ENTRY_DYSESTHETIC_9985209311909479038)],
        &[(0b10001, &ENTRY_DYSESTHESIA_10145261120272617451)],
        &[(0b10001, &ENTRY_DYSESTHETIC_9985209311909479038)],
        &[(0b10001, &ENTRY_DYSMENORRHEA_666903672534201582)],
        &[(0b10001, &ENTRY_DYSMENORRHEAL_3211916475354947561)],
        &[(0b10001, &ENTRY_DYSMENORRHEAS_8092414813964160172)],
        &[(0b10001, &ENTRY_DYSMENORRHEIC_17754264387759129903)],
        &[(0b11010, &ENTRY_DYSMENORRHEA_666903672534201582)],
        &[(0b11010, &ENTRY_DYSMENORRHEAL_3211916475354947561)],
        &[(0b11010, &ENTRY_DYSMENORRHEAS_8092414813964160172)],
        &[(0b11010, &ENTRY_DYSMENORRHEIC_17754264387759129903)],
        &[(0b11001, &ENTRY_DYSPNEA_3275451076579387530)],
        &[(0b10001, &ENTRY_DYSPNEAL_4877333742970701237)],
        &[(0b11001, &ENTRY_DYSPNEAS_2665152845196591077)],
        &[(0b10001, &ENTRY_DYSPNEIC_8845859738600782802)],
        &[(0b10010, &ENTRY_DYSPNEA_3275451076579387530)],
        &[(0b11010, &ENTRY_DYSPNEAL_4877333742970701237)],
        &[(0b10010, &ENTRY_DYSPNEAS_2665152845196591077)],
        &[(0b11010, &ENTRY_DYSPNEIC_8845859738600782802)],
    ],
    range: 5..=12,
};

static VARS_DU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DU_CHILDREN),
    value: None,
};

pub static VARS_DU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("ctilise"),
        dictgen::InsensitiveStr::Ascii("ctilises"),
        dictgen::InsensitiveStr::Ascii("ctilize"),
        dictgen::InsensitiveStr::Ascii("ctilizes"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elist"),
        dictgen::InsensitiveStr::Ascii("elists"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
        dictgen::InsensitiveStr::Ascii("ellist"),
        dictgen::InsensitiveStr::Ascii("ellists"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DUALIZATION_297757979352720010)],
        &[(0b10010, &ENTRY_DUALIZATIONS_1769778750613840808)],
        &[(0b10010, &ENTRY_DUALIZE_14667812076587421504)],
        &[(0b10010, &ENTRY_DUALIZES_6580630624039637450)],
        &[(0b01001, &ENTRY_DUALIZATION_297757979352720010)],
        &[(0b01001, &ENTRY_DUALIZATIONS_1769778750613840808)],
        &[(0b01001, &ENTRY_DUALIZE_14667812076587421504)],
        &[(0b01001, &ENTRY_DUALIZES_6580630624039637450)],
        &[(0b10010, &ENTRY_DUCTILIZE_5117009823320979710)],
        &[(0b10010, &ENTRY_DUCTILIZES_8324019089066090944)],
        &[(0b01001, &ENTRY_DUCTILIZE_5117009823320979710)],
        &[(0b01001, &ENTRY_DUCTILIZES_8324019089066090944)],
        &[(0b00001, &ENTRY_DUELED_14139003527020650904)],
        &[(0b00001, &ENTRY_DUELER_17639225109776633494)],
        &[(0b00001, &ENTRY_DUELERS_885313812620534811)],
        &[(0b00001, &ENTRY_DUELING_5778547651645125895)],
        &[(0b00001, &ENTRY_DUELINGS_14759091337280437276)],
        &[(0b00001, &ENTRY_DUELIST_6970922052642565539)],
        &[(0b00001, &ENTRY_DUELISTS_18258331536218201176)],
        &[(0b11010, &ENTRY_DUELED_14139003527020650904)],
        &[(0b11010, &ENTRY_DUELER_17639225109776633494)],
        &[(0b11010, &ENTRY_DUELERS_885313812620534811)],
        &[(0b11010, &ENTRY_DUELING_5778547651645125895)],
        &[(0b11010, &ENTRY_DUELINGS_14759091337280437276)],
        &[(0b11010, &ENTRY_DUELIST_6970922052642565539)],
        &[(0b11010, &ENTRY_DUELISTS_18258331536218201176)],
        &[(0b00001, &ENTRY_DUER_2007337493238246122)],
        &[(0b11010, &ENTRY_DUER_2007337493238246122)],
    ],
    range: 2..=10,
};

static VARS_DR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DR_CHILDREN),
    value: None,
};

static VARS_DR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DRA_NODE),
    None,
    None,
    None,
    Some(&VARS_DRE_NODE),
    None,
    None,
    None,
    Some(&VARS_DRI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_DRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRI_CHILDREN),
    value: None,
};

pub static VARS_DRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("veled"),
        dictgen::InsensitiveStr::Ascii("veler"),
        dictgen::InsensitiveStr::Ascii("velers"),
        dictgen::InsensitiveStr::Ascii("veling"),
        dictgen::InsensitiveStr::Ascii("velled"),
        dictgen::InsensitiveStr::Ascii("veller"),
        dictgen::InsensitiveStr::Ascii("vellers"),
        dictgen::InsensitiveStr::Ascii("velling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DRIVELED_7030750316386626325)],
        &[(0b00001, &ENTRY_DRIVELER_13922515254126867061)],
        &[(0b00001, &ENTRY_DRIVELERS_719861811563082420)],
        &[(0b00001, &ENTRY_DRIVELING_8695688524206031945)],
        &[(0b11010, &ENTRY_DRIVELED_7030750316386626325)],
        &[(0b11010, &ENTRY_DRIVELER_13922515254126867061)],
        &[(0b11010, &ENTRY_DRIVELERS_719861811563082420)],
        &[(0b11010, &ENTRY_DRIVELING_8695688524206031945)],
    ],
    range: 5..=7,
};

static VARS_DRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRE_CHILDREN),
    value: None,
};

pub static VARS_DRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("amt"),
        dictgen::InsensitiveStr::Ascii("k"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DREAMED_693371865095129101)],
        &[(0b11010, &ENTRY_DERK_4716671464297446249)],
        &[(0b11010, &ENTRY_DERR_8497357744990730455)],
    ],
    range: 1..=3,
};

static VARS_DRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DRA_CHILDREN),
    value: None,
};

static VARS_DRA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_DRAC_NODE),
    None,
    None,
    Some(&VARS_DRAF_NODE),
    Some(&VARS_DRAG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DRAM_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DRAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DRAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAU_CHILDREN),
    value: None,
};

pub static VARS_DRAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ghted"),
        dictgen::InsensitiveStr::Ascii("ghtier"),
        dictgen::InsensitiveStr::Ascii("ghtiest"),
        dictgen::InsensitiveStr::Ascii("ghtilier"),
        dictgen::InsensitiveStr::Ascii("ghtiliest"),
        dictgen::InsensitiveStr::Ascii("ghtily"),
        dictgen::InsensitiveStr::Ascii("ghtiness"),
        dictgen::InsensitiveStr::Ascii("ghtinesses"),
        dictgen::InsensitiveStr::Ascii("ghting"),
        dictgen::InsensitiveStr::Ascii("ghtsmanship"),
        dictgen::InsensitiveStr::Ascii("ghtsmanships"),
        dictgen::InsensitiveStr::Ascii("ghtsperson"),
        dictgen::InsensitiveStr::Ascii("ghtswoman"),
        dictgen::InsensitiveStr::Ascii("ghtswomen"),
        dictgen::InsensitiveStr::Ascii("ghty"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DRAFTED_2613143638373081360)],
        &[(0b10010, &ENTRY_DRAFTIER_9222724357623798327)],
        &[(0b10010, &ENTRY_DRAFTIEST_5259543064524205513)],
        &[(0b10010, &ENTRY_DRAFTILIER_6263136181960657686)],
        &[(0b10010, &ENTRY_DRAFTILIEST_12111711614227754883)],
        &[(0b10010, &ENTRY_DRAFTILY_3404853207703525148)],
        &[(0b10010, &ENTRY_DRAFTINESS_5050558803290260054)],
        &[(0b10010, &ENTRY_DRAFTINESSES_2337311124395489337)],
        &[(0b10010, &ENTRY_DRAFTING_8913342336646949258)],
        &[(0b10010, &ENTRY_DRAFTSMANSHIP_14701669807878909941)],
        &[(0b10010, &ENTRY_DRAFTSMANSHIPS_3009875565957915648)],
        &[(0b10010, &ENTRY_DRAFTSPERSON_17252902994124085558)],
        &[(0b10010, &ENTRY_DRAFTSWOMAN_13749770471062736806)],
        &[(0b10010, &ENTRY_DRAFTSWOMEN_14692115605095290784)],
        &[(0b10010, &ENTRY_DRAFTY_11689082232746206984)],
    ],
    range: 4..=12,
};

static VARS_DRAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAM_CHILDREN),
    value: None,
};

pub static VARS_DRAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atisable"),
        dictgen::InsensitiveStr::Ascii("atisabler"),
        dictgen::InsensitiveStr::Ascii("atisables"),
        dictgen::InsensitiveStr::Ascii("atisablest"),
        dictgen::InsensitiveStr::Ascii("atisation"),
        dictgen::InsensitiveStr::Ascii("atisations"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atised"),
        dictgen::InsensitiveStr::Ascii("atiser"),
        dictgen::InsensitiveStr::Ascii("atisers"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atising"),
        dictgen::InsensitiveStr::Ascii("atizable"),
        dictgen::InsensitiveStr::Ascii("atizabler"),
        dictgen::InsensitiveStr::Ascii("atizables"),
        dictgen::InsensitiveStr::Ascii("atizablest"),
        dictgen::InsensitiveStr::Ascii("atization"),
        dictgen::InsensitiveStr::Ascii("atizations"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atized"),
        dictgen::InsensitiveStr::Ascii("atizer"),
        dictgen::InsensitiveStr::Ascii("atizers"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("atizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DRAMATIZABLE_114460072530125204)],
        &[(0b10010, &ENTRY_DRAMATIZABLER_14017923335901627289)],
        &[(0b10010, &ENTRY_DRAMATIZABLES_12929019439166166978)],
        &[(0b10010, &ENTRY_DRAMATIZABLEST_11908506320782789726)],
        &[(0b10010, &ENTRY_DRAMATIZATION_18352830060262048924)],
        &[(0b10010, &ENTRY_DRAMATIZATIONS_4872008295467161969)],
        &[(0b10010, &ENTRY_DRAMATIZE_11024442299136514965)],
        &[(0b10010, &ENTRY_DRAMATIZED_2372982752652968078)],
        &[(0b10010, &ENTRY_DRAMATIZER_12312020267573769761)],
        &[(0b10010, &ENTRY_DRAMATIZERS_17282413603035313323)],
        &[(0b10010, &ENTRY_DRAMATIZES_14716282266966184426)],
        &[(0b10010, &ENTRY_DRAMATIZING_14243240191823624849)],
        &[(0b01001, &ENTRY_DRAMATIZABLE_114460072530125204)],
        &[(0b01001, &ENTRY_DRAMATIZABLER_14017923335901627289)],
        &[(0b01001, &ENTRY_DRAMATIZABLES_12929019439166166978)],
        &[(0b01001, &ENTRY_DRAMATIZABLEST_11908506320782789726)],
        &[(0b01001, &ENTRY_DRAMATIZATION_18352830060262048924)],
        &[(0b01001, &ENTRY_DRAMATIZATIONS_4872008295467161969)],
        &[(0b01001, &ENTRY_DRAMATIZE_11024442299136514965)],
        &[(0b01001, &ENTRY_DRAMATIZED_2372982752652968078)],
        &[(0b01001, &ENTRY_DRAMATIZER_12312020267573769761)],
        &[(0b01001, &ENTRY_DRAMATIZERS_17282413603035313323)],
        &[(0b01001, &ENTRY_DRAMATIZES_14716282266966184426)],
        &[(0b01001, &ENTRY_DRAMATIZING_14243240191823624849)],
    ],
    range: 5..=10,
};

static VARS_DRAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAG_CHILDREN),
    value: None,
};

pub static VARS_DRAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DRAGONIZE_14160202049023947793)],
        &[(0b10010, &ENTRY_DRAGONIZED_13277720972691636848)],
        &[(0b10010, &ENTRY_DRAGONIZES_8370477046170548627)],
        &[(0b10010, &ENTRY_DRAGONIZING_15675970912123878416)],
        &[(0b01001, &ENTRY_DRAGONIZE_14160202049023947793)],
        &[(0b01001, &ENTRY_DRAGONIZED_13277720972691636848)],
        &[(0b01001, &ENTRY_DRAGONIZES_8370477046170548627)],
        &[(0b01001, &ENTRY_DRAGONIZING_15675970912123878416)],
    ],
    range: 5..=7,
};

static VARS_DRAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAF_CHILDREN),
    value: None,
};

pub static VARS_DRAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tboard"),
        dictgen::InsensitiveStr::Ascii("tboards"),
        dictgen::InsensitiveStr::Ascii("tier"),
        dictgen::InsensitiveStr::Ascii("tiest"),
        dictgen::InsensitiveStr::Ascii("tilier"),
        dictgen::InsensitiveStr::Ascii("tiliest"),
        dictgen::InsensitiveStr::Ascii("tily"),
        dictgen::InsensitiveStr::Ascii("tiness"),
        dictgen::InsensitiveStr::Ascii("tinesses"),
        dictgen::InsensitiveStr::Ascii("tsman"),
        dictgen::InsensitiveStr::Ascii("tsmanship"),
        dictgen::InsensitiveStr::Ascii("tsmanships"),
        dictgen::InsensitiveStr::Ascii("tsmen"),
        dictgen::InsensitiveStr::Ascii("tsperson"),
        dictgen::InsensitiveStr::Ascii("tswoman"),
        dictgen::InsensitiveStr::Ascii("tswomen"),
        dictgen::InsensitiveStr::Ascii("ty"),
    ],
    values: &[
        &[(0b01001, &ENTRY_DRAUGHTBOARD_17601710064627669528)],
        &[(0b01001, &ENTRY_DRAUGHTBOARDS_10338171604839828821)],
        &[(0b01001, &ENTRY_DRAFTIER_9222724357623798327)],
        &[(0b01001, &ENTRY_DRAFTIEST_5259543064524205513)],
        &[(0b01001, &ENTRY_DRAFTILIER_6263136181960657686)],
        &[(0b01001, &ENTRY_DRAFTILIEST_12111711614227754883)],
        &[(0b01001, &ENTRY_DRAFTILY_3404853207703525148)],
        &[(0b01001, &ENTRY_DRAFTINESS_5050558803290260054)],
        &[(0b01001, &ENTRY_DRAFTINESSES_2337311124395489337)],
        &[(0b01001, &ENTRY_DRAFTSMAN_2158426515502784003)],
        &[(0b01001, &ENTRY_DRAFTSMANSHIP_14701669807878909941)],
        &[(0b01001, &ENTRY_DRAFTSMANSHIPS_3009875565957915648)],
        &[(0b01001, &ENTRY_DRAFTSMEN_11969721402571410341)],
        &[(0b01001, &ENTRY_DRAFTSPERSON_17252902994124085558)],
        &[(0b01001, &ENTRY_DRAFTSWOMAN_13749770471062736806)],
        &[(0b01001, &ENTRY_DRAFTSWOMEN_14692115605095290784)],
        &[(0b01001, &ENTRY_DRAFTY_11689082232746206984)],
    ],
    range: 2..=10,
};

static VARS_DRAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DRAC_CHILDREN),
    value: None,
};

pub static VARS_DRAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aena"),
        dictgen::InsensitiveStr::Ascii("aenaceae"),
        dictgen::InsensitiveStr::Ascii("aenas"),
        dictgen::InsensitiveStr::Ascii("ena"),
        dictgen::InsensitiveStr::Ascii("enaceae"),
        dictgen::InsensitiveStr::Ascii("enas"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DRACENA_6118539877770808902)],
        &[(0b11010, &ENTRY_DRACENACEAE_16212683568672807360)],
        &[(0b11010, &ENTRY_DRACENAS_12510578936942457083)],
        &[(0b00001, &ENTRY_DRACENA_6118539877770808902)],
        &[(0b00001, &ENTRY_DRACENACEAE_16212683568672807360)],
        &[(0b00001, &ENTRY_DRACENAS_12510578936942457083)],
    ],
    range: 3..=8,
};

static VARS_DO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DO_CHILDREN),
    value: None,
};

static VARS_DO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_DOC_NODE),
    Some(&VARS_DOD_NODE),
    None,
    None,
    Some(&VARS_DOG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_DOL_NODE),
    Some(&VARS_DOM_NODE),
    Some(&VARS_DON_NODE),
    None,
    None,
    None,
    Some(&VARS_DOR_NODE),
    None,
    None,
    Some(&VARS_DOU_NODE),
    None,
    Some(&VARS_DOW_NODE),
    None,
    None,
    None,
];

static VARS_DOW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOW_CHILDREN),
    value: None,
};

pub static VARS_DOW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ndraft"),
        dictgen::InsensitiveStr::Ascii("ndraught"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DOWELED_3347505904680781852)],
        &[(0b00001, &ENTRY_DOWELER_14640077182615108914)],
        &[(0b00001, &ENTRY_DOWELING_18059799987098176192)],
        &[(0b11010, &ENTRY_DOWELED_3347505904680781852)],
        &[(0b11010, &ENTRY_DOWELER_14640077182615108914)],
        &[(0b11010, &ENTRY_DOWELING_18059799987098176192)],
        &[(0b01001, &ENTRY_DOWNDRAFT_9039488072887961853)],
        &[(0b10010, &ENTRY_DOWNDRAFT_9039488072887961853)],
    ],
    range: 4..=8,
};

static VARS_DOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOU_CHILDREN),
    value: None,
};

pub static VARS_DOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ra")],
    values: &[&[(0b11010, &ENTRY_DORA_16140085300068073244)]],
    range: 2..=2,
};

static VARS_DOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOR_CHILDREN),
    value: None,
};

pub static VARS_DOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("ylinae"),
        dictgen::InsensitiveStr::Ascii("yline"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DORA_16140085300068073244)],
        &[(0b10010, &ENTRY_DORICIZE_6423501943985007435)],
        &[(0b10010, &ENTRY_DORICIZES_6267531821171799546)],
        &[(0b01001, &ENTRY_DORICIZE_6423501943985007435)],
        &[(0b01001, &ENTRY_DORICIZES_6267531821171799546)],
        &[(0b10010, &ENTRY_DORIZE_5375683295399571559)],
        &[(0b10010, &ENTRY_DORIZED_15641017864552407948)],
        &[(0b10010, &ENTRY_DORIZES_2466661328762540129)],
        &[(0b10010, &ENTRY_DORIZING_8550740907826559833)],
        &[(0b01001, &ENTRY_DORIZE_5375683295399571559)],
        &[(0b01001, &ENTRY_DORIZED_15641017864552407948)],
        &[(0b01001, &ENTRY_DORIZES_2466661328762540129)],
        &[(0b01001, &ENTRY_DORIZING_8550740907826559833)],
        &[(0b11010, &ENTRY_DORYLINE_13007837504764606022)],
        &[(0b00001, &ENTRY_DORYLINE_13007837504764606022)],
    ],
    range: 1..=6,
};

static VARS_DON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DON_CHILDREN),
    value: None,
};

pub static VARS_DON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ut"),
        dictgen::InsensitiveStr::Ascii("uts"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DOUGHNUT_10730795230131641057)],
        &[(0b00001, &ENTRY_DOUGHNUTS_2863778322372164342)],
    ],
    range: 2..=3,
};

static VARS_DOM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOM_CHILDREN),
    value: None,
};

pub static VARS_DOM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esticise"),
        dictgen::InsensitiveStr::Ascii("esticised"),
        dictgen::InsensitiveStr::Ascii("esticises"),
        dictgen::InsensitiveStr::Ascii("esticising"),
        dictgen::InsensitiveStr::Ascii("esticize"),
        dictgen::InsensitiveStr::Ascii("esticized"),
        dictgen::InsensitiveStr::Ascii("esticizes"),
        dictgen::InsensitiveStr::Ascii("esticizing"),
        dictgen::InsensitiveStr::Ascii("inae"),
        dictgen::InsensitiveStr::Ascii("ine"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DOMESTICIZE_13328191379606735400)],
        &[(0b10010, &ENTRY_DOMESTICIZED_942799913724257410)],
        &[(0b10010, &ENTRY_DOMESTICIZES_10740490321221958206)],
        &[(0b10010, &ENTRY_DOMESTICIZING_14826454957919135861)],
        &[(0b01001, &ENTRY_DOMESTICIZE_13328191379606735400)],
        &[(0b01001, &ENTRY_DOMESTICIZED_942799913724257410)],
        &[(0b01001, &ENTRY_DOMESTICIZES_10740490321221958206)],
        &[(0b01001, &ENTRY_DOMESTICIZING_14826454957919135861)],
        &[(0b11010, &ENTRY_DOMINE_6107407794990069253)],
        &[(0b00001, &ENTRY_DOMINE_6107407794990069253)],
    ],
    range: 3..=10,
};

static VARS_DOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOL_CHILDREN),
    value: None,
};

pub static VARS_DOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("larisation"),
        dictgen::InsensitiveStr::Ascii("larisations"),
        dictgen::InsensitiveStr::Ascii("larization"),
        dictgen::InsensitiveStr::Ascii("larizations"),
        dictgen::InsensitiveStr::Ascii("omitisation"),
        dictgen::InsensitiveStr::Ascii("omitisations"),
        dictgen::InsensitiveStr::Ascii("omitise"),
        dictgen::InsensitiveStr::Ascii("omitised"),
        dictgen::InsensitiveStr::Ascii("omitises"),
        dictgen::InsensitiveStr::Ascii("omitising"),
        dictgen::InsensitiveStr::Ascii("omitization"),
        dictgen::InsensitiveStr::Ascii("omitizations"),
        dictgen::InsensitiveStr::Ascii("omitize"),
        dictgen::InsensitiveStr::Ascii("omitized"),
        dictgen::InsensitiveStr::Ascii("omitizes"),
        dictgen::InsensitiveStr::Ascii("omitizing"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DOLLARIZATION_17756157301501272744)],
        &[(0b10010, &ENTRY_DOLLARIZATIONS_17625833038744269977)],
        &[(0b01001, &ENTRY_DOLLARIZATION_17756157301501272744)],
        &[(0b01001, &ENTRY_DOLLARIZATIONS_17625833038744269977)],
        &[(0b10010, &ENTRY_DOLOMITIZATION_14933423504719929542)],
        &[(0b10010, &ENTRY_DOLOMITIZATIONS_14772713962775924448)],
        &[(0b10010, &ENTRY_DOLOMITIZE_11040063579570529637)],
        &[(0b10010, &ENTRY_DOLOMITIZED_11692953153623694619)],
        &[(0b10010, &ENTRY_DOLOMITIZES_14363893600761024796)],
        &[(0b10010, &ENTRY_DOLOMITIZING_438564637284719498)],
        &[(0b01001, &ENTRY_DOLOMITIZATION_14933423504719929542)],
        &[(0b01001, &ENTRY_DOLOMITIZATIONS_14772713962775924448)],
        &[(0b01001, &ENTRY_DOLOMITIZE_11040063579570529637)],
        &[(0b01001, &ENTRY_DOLOMITIZED_11692953153623694619)],
        &[(0b01001, &ENTRY_DOLOMITIZES_14363893600761024796)],
        &[(0b01001, &ENTRY_DOLOMITIZING_438564637284719498)],
        &[(0b11001, &ENTRY_DOLOR_13331739895797537426)],
        &[(0b11001, &ENTRY_DOLORS_14103590959031573361)],
        &[(0b11010, &ENTRY_DOLOR_13331739895797537426)],
        &[(0b11010, &ENTRY_DOLORS_14103590959031573361)],
    ],
    range: 2..=12,
};

static VARS_DOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOG_CHILDREN),
    value: None,
};

pub static VARS_DOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matisations"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matiser"),
        dictgen::InsensitiveStr::Ascii("matisers"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matizations"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizer"),
        dictgen::InsensitiveStr::Ascii("matizers"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
        dictgen::InsensitiveStr::Ascii("naped"),
        dictgen::InsensitiveStr::Ascii("naping"),
        dictgen::InsensitiveStr::Ascii("napped"),
        dictgen::InsensitiveStr::Ascii("napping"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DOGMATIZATION_9807437487276138631)],
        &[(0b10010, &ENTRY_DOGMATIZATIONS_16998792177218196465)],
        &[(0b10010, &ENTRY_DOGMATIZE_17787716068922105181)],
        &[(0b10010, &ENTRY_DOGMATIZED_16841797752844209570)],
        &[(0b10010, &ENTRY_DOGMATIZER_12352899563923207585)],
        &[(0b10010, &ENTRY_DOGMATIZERS_4399276900624905781)],
        &[(0b10010, &ENTRY_DOGMATIZES_5834123085035176852)],
        &[(0b10010, &ENTRY_DOGMATIZING_2447061813414873668)],
        &[(0b01001, &ENTRY_DOGMATIZATION_9807437487276138631)],
        &[(0b01001, &ENTRY_DOGMATIZATIONS_16998792177218196465)],
        &[(0b01001, &ENTRY_DOGMATIZE_17787716068922105181)],
        &[(0b01001, &ENTRY_DOGMATIZED_16841797752844209570)],
        &[(0b01001, &ENTRY_DOGMATIZER_12352899563923207585)],
        &[(0b01001, &ENTRY_DOGMATIZERS_4399276900624905781)],
        &[(0b01001, &ENTRY_DOGMATIZES_5834123085035176852)],
        &[(0b01001, &ENTRY_DOGMATIZING_2447061813414873668)],
        &[(0b00001, &ENTRY_DOGNAPED_11073408213279300229)],
        &[(0b00001, &ENTRY_DOGNAPING_18285041110852582538)],
        &[(0b11010, &ENTRY_DOGNAPED_11073408213279300229)],
        &[(0b11010, &ENTRY_DOGNAPING_18285041110852582538)],
    ],
    range: 5..=11,
};

static VARS_DOD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOD_CHILDREN),
    value: None,
};

pub static VARS_DOD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onaean"),
        dictgen::InsensitiveStr::Ascii("onean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DODONEAN_4865245390182893775)],
        &[(0b00001, &ENTRY_DODONEAN_4865245390182893775)],
    ],
    range: 5..=6,
};

static VARS_DOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DOC_CHILDREN),
    value: None,
};

pub static VARS_DOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etae"),
        dictgen::InsensitiveStr::Ascii("ete"),
        dictgen::InsensitiveStr::Ascii("kisation"),
        dictgen::InsensitiveStr::Ascii("kisations"),
        dictgen::InsensitiveStr::Ascii("kise"),
        dictgen::InsensitiveStr::Ascii("kised"),
        dictgen::InsensitiveStr::Ascii("kises"),
        dictgen::InsensitiveStr::Ascii("kising"),
        dictgen::InsensitiveStr::Ascii("kization"),
        dictgen::InsensitiveStr::Ascii("kizations"),
        dictgen::InsensitiveStr::Ascii("kize"),
        dictgen::InsensitiveStr::Ascii("kized"),
        dictgen::InsensitiveStr::Ascii("kizes"),
        dictgen::InsensitiveStr::Ascii("kizing"),
        dictgen::InsensitiveStr::Ascii("torisation"),
        dictgen::InsensitiveStr::Ascii("torisations"),
        dictgen::InsensitiveStr::Ascii("torise"),
        dictgen::InsensitiveStr::Ascii("torises"),
        dictgen::InsensitiveStr::Ascii("torization"),
        dictgen::InsensitiveStr::Ascii("torizations"),
        dictgen::InsensitiveStr::Ascii("torize"),
        dictgen::InsensitiveStr::Ascii("torizes"),
        dictgen::InsensitiveStr::Ascii("trinisation"),
        dictgen::InsensitiveStr::Ascii("trinisations"),
        dictgen::InsensitiveStr::Ascii("trinise"),
        dictgen::InsensitiveStr::Ascii("trinises"),
        dictgen::InsensitiveStr::Ascii("trinization"),
        dictgen::InsensitiveStr::Ascii("trinizations"),
        dictgen::InsensitiveStr::Ascii("trinize"),
        dictgen::InsensitiveStr::Ascii("trinizes"),
        dictgen::InsensitiveStr::Ascii("umentarisation"),
        dictgen::InsensitiveStr::Ascii("umentarisations"),
        dictgen::InsensitiveStr::Ascii("umentarise"),
        dictgen::InsensitiveStr::Ascii("umentarised"),
        dictgen::InsensitiveStr::Ascii("umentarises"),
        dictgen::InsensitiveStr::Ascii("umentarising"),
        dictgen::InsensitiveStr::Ascii("umentarization"),
        dictgen::InsensitiveStr::Ascii("umentarizations"),
        dictgen::InsensitiveStr::Ascii("umentarize"),
        dictgen::InsensitiveStr::Ascii("umentarized"),
        dictgen::InsensitiveStr::Ascii("umentarizes"),
        dictgen::InsensitiveStr::Ascii("umentarizing"),
        dictgen::InsensitiveStr::Ascii("umentise"),
        dictgen::InsensitiveStr::Ascii("umentises"),
        dictgen::InsensitiveStr::Ascii("umentize"),
        dictgen::InsensitiveStr::Ascii("umentizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DOCETE_9982236132390447888)],
        &[(0b00001, &ENTRY_DOCETE_9982236132390447888)],
        &[(0b10010, &ENTRY_DOCKIZATION_1535416910054929275)],
        &[(0b10010, &ENTRY_DOCKIZATIONS_11682590158800904305)],
        &[(0b10010, &ENTRY_DOCKIZE_7971946050616909881)],
        &[(0b10010, &ENTRY_DOCKIZED_11497882154286445931)],
        &[(0b10010, &ENTRY_DOCKIZES_18122194512183460168)],
        &[(0b10010, &ENTRY_DOCKIZING_3734828908908895957)],
        &[(0b01001, &ENTRY_DOCKIZATION_1535416910054929275)],
        &[(0b01001, &ENTRY_DOCKIZATIONS_11682590158800904305)],
        &[(0b01001, &ENTRY_DOCKIZE_7971946050616909881)],
        &[(0b01001, &ENTRY_DOCKIZED_11497882154286445931)],
        &[(0b01001, &ENTRY_DOCKIZES_18122194512183460168)],
        &[(0b01001, &ENTRY_DOCKIZING_3734828908908895957)],
        &[(0b10010, &ENTRY_DOCTORIZATION_16033729298032621232)],
        &[(0b10010, &ENTRY_DOCTORIZATIONS_16822908416090304265)],
        &[(0b10010, &ENTRY_DOCTORIZE_6755038590757730967)],
        &[(0b10010, &ENTRY_DOCTORIZES_5548640602945580448)],
        &[(0b01001, &ENTRY_DOCTORIZATION_16033729298032621232)],
        &[(0b01001, &ENTRY_DOCTORIZATIONS_16822908416090304265)],
        &[(0b01001, &ENTRY_DOCTORIZE_6755038590757730967)],
        &[(0b01001, &ENTRY_DOCTORIZES_5548640602945580448)],
        &[(0b10010, &ENTRY_DOCTRINIZATION_16019265374829905601)],
        &[(0b10010, &ENTRY_DOCTRINIZATIONS_15902219939645192582)],
        &[(0b10010, &ENTRY_DOCTRINIZE_6295108165555928163)],
        &[(0b10010, &ENTRY_DOCTRINIZES_5935013749533049591)],
        &[(0b01001, &ENTRY_DOCTRINIZATION_16019265374829905601)],
        &[(0b01001, &ENTRY_DOCTRINIZATIONS_15902219939645192582)],
        &[(0b01001, &ENTRY_DOCTRINIZE_6295108165555928163)],
        &[(0b01001, &ENTRY_DOCTRINIZES_5935013749533049591)],
        &[(0b10010, &ENTRY_DOCUMENTARIZATION_17974536989356012536)],
        &[(0b10010, &ENTRY_DOCUMENTARIZATIONS_10331155650038384543)],
        &[(0b10010, &ENTRY_DOCUMENTARIZE_4613182909392922028)],
        &[(0b10010, &ENTRY_DOCUMENTARIZED_17052922427938453018)],
        &[(0b10010, &ENTRY_DOCUMENTARIZES_12258340263601716780)],
        &[(0b10010, &ENTRY_DOCUMENTARIZING_617029537042756884)],
        &[(0b01001, &ENTRY_DOCUMENTARIZATION_17974536989356012536)],
        &[(0b01001, &ENTRY_DOCUMENTARIZATIONS_10331155650038384543)],
        &[(0b01001, &ENTRY_DOCUMENTARIZE_4613182909392922028)],
        &[(0b01001, &ENTRY_DOCUMENTARIZED_17052922427938453018)],
        &[(0b01001, &ENTRY_DOCUMENTARIZES_12258340263601716780)],
        &[(0b01001, &ENTRY_DOCUMENTARIZING_617029537042756884)],
        &[(0b10010, &ENTRY_DOCUMENTIZE_8987269843659123718)],
        &[(0b10010, &ENTRY_DOCUMENTIZES_16197448875654270526)],
        &[(0b01001, &ENTRY_DOCUMENTIZE_8987269843659123718)],
        &[(0b01001, &ENTRY_DOCUMENTIZES_16197448875654270526)],
    ],
    range: 3..=15,
};

static VARS_DI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DI_CHILDREN),
    value: None,
};

static VARS_DI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DIA_NODE),
    None,
    Some(&VARS_DIC_NODE),
    None,
    Some(&VARS_DIE_NODE),
    Some(&VARS_DIF_NODE),
    Some(&VARS_DIG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DIM_NODE),
    None,
    Some(&VARS_DIO_NODE),
    Some(&VARS_DIP_NODE),
    None,
    None,
    Some(&VARS_DIS_NODE),
    None,
    None,
    Some(&VARS_DIV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_DIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIV_CHILDREN),
    value: None,
};

pub static VARS_DIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ersicolored"),
        dictgen::InsensitiveStr::Ascii("ersicoloured"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inister"),
        dictgen::InsensitiveStr::Ascii("inistre"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
        dictgen::InsensitiveStr::Ascii("isionalisation"),
        dictgen::InsensitiveStr::Ascii("isionalisations"),
        dictgen::InsensitiveStr::Ascii("isionalization"),
        dictgen::InsensitiveStr::Ascii("isionalizations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DIVERSICOLORED_651357966110994775)],
        &[(0b11010, &ENTRY_DIVERSICOLORED_651357966110994775)],
        &[(0b10010, &ENTRY_DIVINIZATION_8790430811943080539)],
        &[(0b10010, &ENTRY_DIVINIZATIONS_4602312198214871584)],
        &[(0b10010, &ENTRY_DIVINIZE_15517841088563999430)],
        &[(0b10010, &ENTRY_DIVINIZED_7849256710429601444)],
        &[(0b10010, &ENTRY_DIVINIZES_2478647172593491088)],
        &[(0b10010, &ENTRY_DIVINIZING_3663245257392927615)],
        &[(0b00001, &ENTRY_DIVINISTER_6065276535238492048)],
        &[(0b11010, &ENTRY_DIVINISTER_6065276535238492048)],
        &[(0b01001, &ENTRY_DIVINIZATION_8790430811943080539)],
        &[(0b01001, &ENTRY_DIVINIZATIONS_4602312198214871584)],
        &[(0b01001, &ENTRY_DIVINIZE_15517841088563999430)],
        &[(0b01001, &ENTRY_DIVINIZED_7849256710429601444)],
        &[(0b01001, &ENTRY_DIVINIZES_2478647172593491088)],
        &[(0b01001, &ENTRY_DIVINIZING_3663245257392927615)],
        &[(0b10010, &ENTRY_DIVISIONALIZATION_12097639934213939942)],
        &[(0b10010, &ENTRY_DIVISIONALIZATIONS_5100962745240087520)],
        &[(0b01001, &ENTRY_DIVISIONALIZATION_12097639934213939942)],
        &[(0b01001, &ENTRY_DIVISIONALIZATIONS_5100962745240087520)],
    ],
    range: 5..=15,
};

static VARS_DIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DIS_CHILDREN),
    value: None,
};

static VARS_DIS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DISA_NODE),
    Some(&VARS_DISB_NODE),
    Some(&VARS_DISC_NODE),
    Some(&VARS_DISD_NODE),
    Some(&VARS_DISE_NODE),
    Some(&VARS_DISF_NODE),
    None,
    Some(&VARS_DISH_NODE),
    Some(&VARS_DISI_NODE),
    None,
    None,
    Some(&VARS_DISL_NODE),
    Some(&VARS_DISM_NODE),
    Some(&VARS_DISN_NODE),
    Some(&VARS_DISO_NODE),
    Some(&VARS_DISP_NODE),
    None,
    Some(&VARS_DISR_NODE),
    Some(&VARS_DISS_NODE),
    Some(&VARS_DIST_NODE),
    Some(&VARS_DISU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DISU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISU_CHILDREN),
    value: None,
};

pub static VARS_DISU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tilise"),
        dictgen::InsensitiveStr::Ascii("tilises"),
        dictgen::InsensitiveStr::Ascii("tilize"),
        dictgen::InsensitiveStr::Ascii("tilizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISUTILIZE_10973235722650343703)],
        &[(0b10010, &ENTRY_DISUTILIZES_8581123670870213073)],
        &[(0b01001, &ENTRY_DISUTILIZE_10973235722650343703)],
        &[(0b01001, &ENTRY_DISUTILIZES_8581123670870213073)],
    ],
    range: 6..=7,
};

static VARS_DIST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIST_CHILDREN),
    value: None,
};

pub static VARS_DIST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ill"),
        dictgen::InsensitiveStr::Ascii("ills"),
    ],
    values: &[
        &[(0b01001, &ENTRY_DISTILL_15657274320458397213)],
        &[(0b01001, &ENTRY_DISTILLS_2389426309220426558)],
    ],
    range: 3..=4,
};

static VARS_DISS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISS_CHILDREN),
    value: None,
};

pub static VARS_DISS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cepter"),
        dictgen::InsensitiveStr::Ascii("cepters"),
        dictgen::InsensitiveStr::Ascii("ceptre"),
        dictgen::InsensitiveStr::Ascii("ceptres"),
        dictgen::InsensitiveStr::Ascii("eise"),
        dictgen::InsensitiveStr::Ascii("eised"),
        dictgen::InsensitiveStr::Ascii("eisee"),
        dictgen::InsensitiveStr::Ascii("eises"),
        dictgen::InsensitiveStr::Ascii("eisin"),
        dictgen::InsensitiveStr::Ascii("eising"),
        dictgen::InsensitiveStr::Ascii("eisins"),
        dictgen::InsensitiveStr::Ascii("eisor"),
        dictgen::InsensitiveStr::Ascii("eisors"),
        dictgen::InsensitiveStr::Ascii("eize"),
        dictgen::InsensitiveStr::Ascii("eized"),
        dictgen::InsensitiveStr::Ascii("eizee"),
        dictgen::InsensitiveStr::Ascii("eizes"),
        dictgen::InsensitiveStr::Ascii("eizin"),
        dictgen::InsensitiveStr::Ascii("eizing"),
        dictgen::InsensitiveStr::Ascii("eizins"),
        dictgen::InsensitiveStr::Ascii("eizor"),
        dictgen::InsensitiveStr::Ascii("eizors"),
        dictgen::InsensitiveStr::Ascii("ensualise"),
        dictgen::InsensitiveStr::Ascii("ensualises"),
        dictgen::InsensitiveStr::Ascii("ensualize"),
        dictgen::InsensitiveStr::Ascii("ensualizes"),
        dictgen::InsensitiveStr::Ascii("ocialise"),
        dictgen::InsensitiveStr::Ascii("ocialised"),
        dictgen::InsensitiveStr::Ascii("ocialises"),
        dictgen::InsensitiveStr::Ascii("ocialising"),
        dictgen::InsensitiveStr::Ascii("ocialize"),
        dictgen::InsensitiveStr::Ascii("ocialized"),
        dictgen::InsensitiveStr::Ascii("ocializes"),
        dictgen::InsensitiveStr::Ascii("ocializing"),
        dictgen::InsensitiveStr::Ascii("yllabise"),
        dictgen::InsensitiveStr::Ascii("yllabised"),
        dictgen::InsensitiveStr::Ascii("yllabising"),
        dictgen::InsensitiveStr::Ascii("yllabize"),
        dictgen::InsensitiveStr::Ascii("yllabized"),
        dictgen::InsensitiveStr::Ascii("yllabizing"),
        dictgen::InsensitiveStr::Ascii("ympathise"),
        dictgen::InsensitiveStr::Ascii("ympathises"),
        dictgen::InsensitiveStr::Ascii("ympathize"),
        dictgen::InsensitiveStr::Ascii("ympathizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DISSCEPTER_9219896270222345750)],
        &[(0b00001, &ENTRY_DISSCEPTERS_8501541001325274567)],
        &[(0b11010, &ENTRY_DISSCEPTER_9219896270222345750)],
        &[(0b11010, &ENTRY_DISSCEPTERS_8501541001325274567)],
        &[(0b10010, &ENTRY_DISSEIZE_2220027749090213580)],
        &[(0b10010, &ENTRY_DISSEIZED_9143200265660844579)],
        &[(0b10010, &ENTRY_DISSEIZEE_10324450713845414018)],
        &[(0b10010, &ENTRY_DISSEIZES_2475038653439253891)],
        &[(0b11010, &ENTRY_DISSEIZIN_14782548980677684377)],
        &[(0b10010, &ENTRY_DISSEIZING_10817480248875018424)],
        &[(0b11010, &ENTRY_DISSEIZINS_9611939215700895786)],
        &[(0b11010, &ENTRY_DISSEIZOR_13887745959308891534)],
        &[(0b11010, &ENTRY_DISSEIZORS_6099442410087886972)],
        &[(0b01001, &ENTRY_DISSEIZE_2220027749090213580)],
        &[(0b01001, &ENTRY_DISSEIZED_9143200265660844579)],
        &[(0b01001, &ENTRY_DISSEIZEE_10324450713845414018)],
        &[(0b01001, &ENTRY_DISSEIZES_2475038653439253891)],
        &[(0b00001, &ENTRY_DISSEIZIN_14782548980677684377)],
        &[(0b01001, &ENTRY_DISSEIZING_10817480248875018424)],
        &[(0b00001, &ENTRY_DISSEIZINS_9611939215700895786)],
        &[(0b00001, &ENTRY_DISSEIZOR_13887745959308891534)],
        &[(0b00001, &ENTRY_DISSEIZORS_6099442410087886972)],
        &[(0b10010, &ENTRY_DISSENSUALIZE_6621544703464419271)],
        &[(0b10010, &ENTRY_DISSENSUALIZES_10730088086704898161)],
        &[(0b01001, &ENTRY_DISSENSUALIZE_6621544703464419271)],
        &[(0b01001, &ENTRY_DISSENSUALIZES_10730088086704898161)],
        &[(0b10010, &ENTRY_DISSOCIALIZE_15635530793606336711)],
        &[(0b10010, &ENTRY_DISSOCIALIZED_948976280000356279)],
        &[(0b10010, &ENTRY_DISSOCIALIZES_15997318284457012428)],
        &[(0b10010, &ENTRY_DISSOCIALIZING_6928297824228630438)],
        &[(0b01001, &ENTRY_DISSOCIALIZE_15635530793606336711)],
        &[(0b01001, &ENTRY_DISSOCIALIZED_948976280000356279)],
        &[(0b01001, &ENTRY_DISSOCIALIZES_15997318284457012428)],
        &[(0b01001, &ENTRY_DISSOCIALIZING_6928297824228630438)],
        &[(0b10010, &ENTRY_DISSYLLABIZE_10272862471065893703)],
        &[(0b10010, &ENTRY_DISSYLLABIZED_17425272029213608821)],
        &[(0b10010, &ENTRY_DISSYLLABIZING_7453400268342543405)],
        &[(0b01001, &ENTRY_DISSYLLABIZE_10272862471065893703)],
        &[(0b01001, &ENTRY_DISSYLLABIZED_17425272029213608821)],
        &[(0b01001, &ENTRY_DISSYLLABIZING_7453400268342543405)],
        &[(0b10010, &ENTRY_DISSYMPATHIZE_4993319775705622084)],
        &[(0b10010, &ENTRY_DISSYMPATHIZES_11030202988485089450)],
        &[(0b01001, &ENTRY_DISSYMPATHIZE_4993319775705622084)],
        &[(0b01001, &ENTRY_DISSYMPATHIZES_11030202988485089450)],
    ],
    range: 4..=10,
};

static VARS_DISR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISR_CHILDREN),
    value: None,
};

pub static VARS_DISR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ealise"),
        dictgen::InsensitiveStr::Ascii("ealises"),
        dictgen::InsensitiveStr::Ascii("ealize"),
        dictgen::InsensitiveStr::Ascii("ealizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISREALIZE_6886884802512895754)],
        &[(0b10010, &ENTRY_DISREALIZES_7034995371229494339)],
        &[(0b01001, &ENTRY_DISREALIZE_6886884802512895754)],
        &[(0b01001, &ENTRY_DISREALIZES_7034995371229494339)],
    ],
    range: 6..=7,
};

static VARS_DISP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISP_CHILDREN),
    value: None,
};

pub static VARS_DISP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("apalise"),
        dictgen::InsensitiveStr::Ascii("apalises"),
        dictgen::InsensitiveStr::Ascii("apalize"),
        dictgen::InsensitiveStr::Ascii("apalizes"),
        dictgen::InsensitiveStr::Ascii("auperise"),
        dictgen::InsensitiveStr::Ascii("auperised"),
        dictgen::InsensitiveStr::Ascii("auperises"),
        dictgen::InsensitiveStr::Ascii("auperising"),
        dictgen::InsensitiveStr::Ascii("auperize"),
        dictgen::InsensitiveStr::Ascii("auperized"),
        dictgen::InsensitiveStr::Ascii("auperizes"),
        dictgen::InsensitiveStr::Ascii("auperizing"),
        dictgen::InsensitiveStr::Ascii("ersonalise"),
        dictgen::InsensitiveStr::Ascii("ersonalises"),
        dictgen::InsensitiveStr::Ascii("ersonalize"),
        dictgen::InsensitiveStr::Ascii("ersonalizes"),
        dictgen::InsensitiveStr::Ascii("opularise"),
        dictgen::InsensitiveStr::Ascii("opularises"),
        dictgen::InsensitiveStr::Ascii("opularize"),
        dictgen::InsensitiveStr::Ascii("opularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISPAPALIZE_13165058594407425203)],
        &[(0b10010, &ENTRY_DISPAPALIZES_15889961525847775881)],
        &[(0b01001, &ENTRY_DISPAPALIZE_13165058594407425203)],
        &[(0b01001, &ENTRY_DISPAPALIZES_15889961525847775881)],
        &[(0b10010, &ENTRY_DISPAUPERIZE_4660569275468440176)],
        &[(0b10010, &ENTRY_DISPAUPERIZED_12650677804830175257)],
        &[(0b10010, &ENTRY_DISPAUPERIZES_12194191945308397437)],
        &[(0b10010, &ENTRY_DISPAUPERIZING_17043875401453982735)],
        &[(0b01001, &ENTRY_DISPAUPERIZE_4660569275468440176)],
        &[(0b01001, &ENTRY_DISPAUPERIZED_12650677804830175257)],
        &[(0b01001, &ENTRY_DISPAUPERIZES_12194191945308397437)],
        &[(0b01001, &ENTRY_DISPAUPERIZING_17043875401453982735)],
        &[(0b10010, &ENTRY_DISPERSONALIZE_6396828987917605190)],
        &[(0b10010, &ENTRY_DISPERSONALIZES_16334720714201751331)],
        &[(0b01001, &ENTRY_DISPERSONALIZE_6396828987917605190)],
        &[(0b01001, &ENTRY_DISPERSONALIZES_16334720714201751331)],
        &[(0b10010, &ENTRY_DISPOPULARIZE_6744315358378905582)],
        &[(0b10010, &ENTRY_DISPOPULARIZES_3346222683675559134)],
        &[(0b01001, &ENTRY_DISPOPULARIZE_6744315358378905582)],
        &[(0b01001, &ENTRY_DISPOPULARIZES_3346222683675559134)],
    ],
    range: 7..=11,
};

static VARS_DISO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISO_CHILDREN),
    value: None,
};

pub static VARS_DISO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rganisation"),
        dictgen::InsensitiveStr::Ascii("rganisations"),
        dictgen::InsensitiveStr::Ascii("rganise"),
        dictgen::InsensitiveStr::Ascii("rganised"),
        dictgen::InsensitiveStr::Ascii("rganiser"),
        dictgen::InsensitiveStr::Ascii("rganisers"),
        dictgen::InsensitiveStr::Ascii("rganises"),
        dictgen::InsensitiveStr::Ascii("rganising"),
        dictgen::InsensitiveStr::Ascii("rganization"),
        dictgen::InsensitiveStr::Ascii("rganizations"),
        dictgen::InsensitiveStr::Ascii("rganize"),
        dictgen::InsensitiveStr::Ascii("rganized"),
        dictgen::InsensitiveStr::Ascii("rganizer"),
        dictgen::InsensitiveStr::Ascii("rganizers"),
        dictgen::InsensitiveStr::Ascii("rganizes"),
        dictgen::InsensitiveStr::Ascii("rganizing"),
        dictgen::InsensitiveStr::Ascii("zonise"),
        dictgen::InsensitiveStr::Ascii("zonises"),
        dictgen::InsensitiveStr::Ascii("zonize"),
        dictgen::InsensitiveStr::Ascii("zonizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISORGANIZATION_16905278515917730708)],
        &[(0b10010, &ENTRY_DISORGANIZATIONS_14738569434179616840)],
        &[(0b10010, &ENTRY_DISORGANIZE_11143780718836315842)],
        &[(0b10010, &ENTRY_DISORGANIZED_16082182829150319317)],
        &[(0b10010, &ENTRY_DISORGANIZER_13968612653185254007)],
        &[(0b10010, &ENTRY_DISORGANIZERS_3700614044173779869)],
        &[(0b10010, &ENTRY_DISORGANIZES_3148142030701826514)],
        &[(0b10010, &ENTRY_DISORGANIZING_3512715266110397978)],
        &[(0b01001, &ENTRY_DISORGANIZATION_16905278515917730708)],
        &[(0b01001, &ENTRY_DISORGANIZATIONS_14738569434179616840)],
        &[(0b01001, &ENTRY_DISORGANIZE_11143780718836315842)],
        &[(0b01001, &ENTRY_DISORGANIZED_16082182829150319317)],
        &[(0b01001, &ENTRY_DISORGANIZER_13968612653185254007)],
        &[(0b01001, &ENTRY_DISORGANIZERS_3700614044173779869)],
        &[(0b01001, &ENTRY_DISORGANIZES_3148142030701826514)],
        &[(0b01001, &ENTRY_DISORGANIZING_3512715266110397978)],
        &[(0b10010, &ENTRY_DISOZONIZE_14151388182315461753)],
        &[(0b10010, &ENTRY_DISOZONIZES_12107113608008991830)],
        &[(0b01001, &ENTRY_DISOZONIZE_14151388182315461753)],
        &[(0b01001, &ENTRY_DISOZONIZES_12107113608008991830)],
    ],
    range: 6..=12,
};

static VARS_DISN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISN_CHILDREN),
    value: None,
};

pub static VARS_DISN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aturalisation"),
        dictgen::InsensitiveStr::Ascii("aturalisations"),
        dictgen::InsensitiveStr::Ascii("aturalise"),
        dictgen::InsensitiveStr::Ascii("aturalised"),
        dictgen::InsensitiveStr::Ascii("aturalises"),
        dictgen::InsensitiveStr::Ascii("aturalising"),
        dictgen::InsensitiveStr::Ascii("aturalization"),
        dictgen::InsensitiveStr::Ascii("aturalizations"),
        dictgen::InsensitiveStr::Ascii("aturalize"),
        dictgen::InsensitiveStr::Ascii("aturalized"),
        dictgen::InsensitiveStr::Ascii("aturalizes"),
        dictgen::InsensitiveStr::Ascii("aturalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISNATURALIZATION_11670344026850361488)],
        &[(0b10010, &ENTRY_DISNATURALIZATIONS_10342585743158502872)],
        &[(0b10010, &ENTRY_DISNATURALIZE_12307126110445937749)],
        &[(0b10010, &ENTRY_DISNATURALIZED_5916107255821231797)],
        &[(0b10010, &ENTRY_DISNATURALIZES_559626355389259758)],
        &[(0b10010, &ENTRY_DISNATURALIZING_797893369591768933)],
        &[(0b01001, &ENTRY_DISNATURALIZATION_11670344026850361488)],
        &[(0b01001, &ENTRY_DISNATURALIZATIONS_10342585743158502872)],
        &[(0b01001, &ENTRY_DISNATURALIZE_12307126110445937749)],
        &[(0b01001, &ENTRY_DISNATURALIZED_5916107255821231797)],
        &[(0b01001, &ENTRY_DISNATURALIZES_559626355389259758)],
        &[(0b01001, &ENTRY_DISNATURALIZING_797893369591768933)],
    ],
    range: 9..=14,
};

static VARS_DISM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISM_CHILDREN),
    value: None,
};

pub static VARS_DISM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISMALIZE_10250151666987366777)],
        &[(0b10010, &ENTRY_DISMALIZES_15353135750014042755)],
        &[(0b01001, &ENTRY_DISMALIZE_10250151666987366777)],
        &[(0b01001, &ENTRY_DISMALIZES_15353135750014042755)],
    ],
    range: 5..=6,
};

static VARS_DISL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISL_CHILDREN),
    value: None,
};

pub static VARS_DISL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uster"),
        dictgen::InsensitiveStr::Ascii("ustre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DISLUSTER_17318159058933817750)],
        &[(0b11010, &ENTRY_DISLUSTER_17318159058933817750)],
    ],
    range: 5..=5,
};

static VARS_DISI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISI_CHILDREN),
    value: None,
};

pub static VARS_DISI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("llusionise"),
        dictgen::InsensitiveStr::Ascii("llusionised"),
        dictgen::InsensitiveStr::Ascii("llusioniser"),
        dictgen::InsensitiveStr::Ascii("llusionisers"),
        dictgen::InsensitiveStr::Ascii("llusionises"),
        dictgen::InsensitiveStr::Ascii("llusionising"),
        dictgen::InsensitiveStr::Ascii("llusionize"),
        dictgen::InsensitiveStr::Ascii("llusionized"),
        dictgen::InsensitiveStr::Ascii("llusionizer"),
        dictgen::InsensitiveStr::Ascii("llusionizers"),
        dictgen::InsensitiveStr::Ascii("llusionizes"),
        dictgen::InsensitiveStr::Ascii("llusionizing"),
        dictgen::InsensitiveStr::Ascii("ndividualise"),
        dictgen::InsensitiveStr::Ascii("ndividualised"),
        dictgen::InsensitiveStr::Ascii("ndividualises"),
        dictgen::InsensitiveStr::Ascii("ndividualising"),
        dictgen::InsensitiveStr::Ascii("ndividualize"),
        dictgen::InsensitiveStr::Ascii("ndividualized"),
        dictgen::InsensitiveStr::Ascii("ndividualizes"),
        dictgen::InsensitiveStr::Ascii("ndividualizing"),
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialisations"),
        dictgen::InsensitiveStr::Ascii("ndustrialise"),
        dictgen::InsensitiveStr::Ascii("ndustrialised"),
        dictgen::InsensitiveStr::Ascii("ndustrialises"),
        dictgen::InsensitiveStr::Ascii("ndustrialising"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
        dictgen::InsensitiveStr::Ascii("ndustrializations"),
        dictgen::InsensitiveStr::Ascii("ndustrialize"),
        dictgen::InsensitiveStr::Ascii("ndustrialized"),
        dictgen::InsensitiveStr::Ascii("ndustrializes"),
        dictgen::InsensitiveStr::Ascii("ndustrializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISILLUSIONIZE_6725876315510879655)],
        &[(0b10010, &ENTRY_DISILLUSIONIZED_9985249129164082054)],
        &[(0b10010, &ENTRY_DISILLUSIONIZER_7747439668540485853)],
        &[(0b10010, &ENTRY_DISILLUSIONIZERS_3528478054985367590)],
        &[(0b10010, &ENTRY_DISILLUSIONIZES_12240679786185783886)],
        &[(0b10010, &ENTRY_DISILLUSIONIZING_7223559157676347916)],
        &[(0b01001, &ENTRY_DISILLUSIONIZE_6725876315510879655)],
        &[(0b01001, &ENTRY_DISILLUSIONIZED_9985249129164082054)],
        &[(0b01001, &ENTRY_DISILLUSIONIZER_7747439668540485853)],
        &[(0b01001, &ENTRY_DISILLUSIONIZERS_3528478054985367590)],
        &[(0b01001, &ENTRY_DISILLUSIONIZES_12240679786185783886)],
        &[(0b01001, &ENTRY_DISILLUSIONIZING_7223559157676347916)],
        &[(0b10010, &ENTRY_DISINDIVIDUALIZE_5618805340357401608)],
        &[(0b10010, &ENTRY_DISINDIVIDUALIZED_2490609976879253784)],
        &[(0b10010, &ENTRY_DISINDIVIDUALIZES_3078349844192054680)],
        &[(0b10010, &ENTRY_DISINDIVIDUALIZING_6461619562502650122)],
        &[(0b01001, &ENTRY_DISINDIVIDUALIZE_5618805340357401608)],
        &[(0b01001, &ENTRY_DISINDIVIDUALIZED_2490609976879253784)],
        &[(0b01001, &ENTRY_DISINDIVIDUALIZES_3078349844192054680)],
        &[(0b01001, &ENTRY_DISINDIVIDUALIZING_6461619562502650122)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZATION_11631925405929512766)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZATIONS_12474625419721941228)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZE_11677234080103658662)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZED_9116894414125815191)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZES_11775441929762490304)],
        &[(0b10010, &ENTRY_DISINDUSTRIALIZING_11227038092400551095)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZATION_11631925405929512766)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZATIONS_12474625419721941228)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZE_11677234080103658662)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZED_9116894414125815191)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZES_11775441929762490304)],
        &[(0b01001, &ENTRY_DISINDUSTRIALIZING_11227038092400551095)],
    ],
    range: 10..=17,
};

static VARS_DISH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISH_CHILDREN),
    value: None,
};

pub static VARS_DISH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("armonise"),
        dictgen::InsensitiveStr::Ascii("armonised"),
        dictgen::InsensitiveStr::Ascii("armonises"),
        dictgen::InsensitiveStr::Ascii("armonising"),
        dictgen::InsensitiveStr::Ascii("armonize"),
        dictgen::InsensitiveStr::Ascii("armonized"),
        dictgen::InsensitiveStr::Ascii("armonizes"),
        dictgen::InsensitiveStr::Ascii("armonizing"),
        dictgen::InsensitiveStr::Ascii("eveled"),
        dictgen::InsensitiveStr::Ascii("eveler"),
        dictgen::InsensitiveStr::Ascii("eveling"),
        dictgen::InsensitiveStr::Ascii("evelled"),
        dictgen::InsensitiveStr::Ascii("eveller"),
        dictgen::InsensitiveStr::Ascii("evelling"),
        dictgen::InsensitiveStr::Ascii("onor"),
        dictgen::InsensitiveStr::Ascii("onorable"),
        dictgen::InsensitiveStr::Ascii("onorableness"),
        dictgen::InsensitiveStr::Ascii("onorablenesses"),
        dictgen::InsensitiveStr::Ascii("onorabler"),
        dictgen::InsensitiveStr::Ascii("onorables"),
        dictgen::InsensitiveStr::Ascii("onorablest"),
        dictgen::InsensitiveStr::Ascii("onorablier"),
        dictgen::InsensitiveStr::Ascii("onorablies"),
        dictgen::InsensitiveStr::Ascii("onorabliest"),
        dictgen::InsensitiveStr::Ascii("onorably"),
        dictgen::InsensitiveStr::Ascii("onorary"),
        dictgen::InsensitiveStr::Ascii("onored"),
        dictgen::InsensitiveStr::Ascii("onorer"),
        dictgen::InsensitiveStr::Ascii("onorers"),
        dictgen::InsensitiveStr::Ascii("onoring"),
        dictgen::InsensitiveStr::Ascii("onors"),
        dictgen::InsensitiveStr::Ascii("onour"),
        dictgen::InsensitiveStr::Ascii("onourable"),
        dictgen::InsensitiveStr::Ascii("onourableness"),
        dictgen::InsensitiveStr::Ascii("onourablenesses"),
        dictgen::InsensitiveStr::Ascii("onourabler"),
        dictgen::InsensitiveStr::Ascii("onourables"),
        dictgen::InsensitiveStr::Ascii("onourablest"),
        dictgen::InsensitiveStr::Ascii("onourablier"),
        dictgen::InsensitiveStr::Ascii("onourablies"),
        dictgen::InsensitiveStr::Ascii("onourabliest"),
        dictgen::InsensitiveStr::Ascii("onourably"),
        dictgen::InsensitiveStr::Ascii("onourary"),
        dictgen::InsensitiveStr::Ascii("onoured"),
        dictgen::InsensitiveStr::Ascii("onourer"),
        dictgen::InsensitiveStr::Ascii("onourers"),
        dictgen::InsensitiveStr::Ascii("onouring"),
        dictgen::InsensitiveStr::Ascii("onours"),
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
        dictgen::InsensitiveStr::Ascii("umor"),
        dictgen::InsensitiveStr::Ascii("umored"),
        dictgen::InsensitiveStr::Ascii("umors"),
        dictgen::InsensitiveStr::Ascii("umour"),
        dictgen::InsensitiveStr::Ascii("umoured"),
        dictgen::InsensitiveStr::Ascii("umours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISHARMONIZE_14492960974540093828)],
        &[(0b10010, &ENTRY_DISHARMONIZED_4901310729391279975)],
        &[(0b10010, &ENTRY_DISHARMONIZES_6597311294304545400)],
        &[(0b10010, &ENTRY_DISHARMONIZING_15220607346038133749)],
        &[(0b01001, &ENTRY_DISHARMONIZE_14492960974540093828)],
        &[(0b01001, &ENTRY_DISHARMONIZED_4901310729391279975)],
        &[(0b01001, &ENTRY_DISHARMONIZES_6597311294304545400)],
        &[(0b01001, &ENTRY_DISHARMONIZING_15220607346038133749)],
        &[(0b00001, &ENTRY_DISHEVELED_4439055663190726624)],
        &[(0b00001, &ENTRY_DISHEVELER_8621924881071797327)],
        &[(0b00001, &ENTRY_DISHEVELING_10590618683250803788)],
        &[(0b11010, &ENTRY_DISHEVELED_4439055663190726624)],
        &[(0b11010, &ENTRY_DISHEVELER_8621924881071797327)],
        &[(0b11010, &ENTRY_DISHEVELING_10590618683250803788)],
        &[(0b11001, &ENTRY_DISHONOR_16058760573294695856)],
        &[(0b11001, &ENTRY_DISHONORABLE_6906558183452633549)],
        &[(0b11001, &ENTRY_DISHONORABLENESS_10647077411353658138)],
        &[(0b11001, &ENTRY_DISHONORABLENESSES_11979409559133838321)],
        &[(0b11001, &ENTRY_DISHONORABLER_3043788293690199279)],
        &[(0b11001, &ENTRY_DISHONORABLES_9899266461697606508)],
        &[(0b11001, &ENTRY_DISHONORABLEST_3928567236277526991)],
        &[(0b11001, &ENTRY_DISHONORABLIER_8450606157745671431)],
        &[(0b11001, &ENTRY_DISHONORABLIES_14942803523606691356)],
        &[(0b11001, &ENTRY_DISHONORABLIEST_12463634118581290321)],
        &[(0b11001, &ENTRY_DISHONORABLY_16389408757341415026)],
        &[(0b00001, &ENTRY_DISHONORARY_7185175374757498337)],
        &[(0b11001, &ENTRY_DISHONORED_1979408375344629609)],
        &[(0b11001, &ENTRY_DISHONORER_11600072711097852356)],
        &[(0b11001, &ENTRY_DISHONORERS_16218792927597703675)],
        &[(0b11001, &ENTRY_DISHONORING_16122094070164850675)],
        &[(0b11001, &ENTRY_DISHONORS_5828073138827677548)],
        &[(0b11010, &ENTRY_DISHONOR_16058760573294695856)],
        &[(0b11010, &ENTRY_DISHONORABLE_6906558183452633549)],
        &[(0b11010, &ENTRY_DISHONORABLENESS_10647077411353658138)],
        &[(0b11010, &ENTRY_DISHONORABLENESSES_11979409559133838321)],
        &[(0b11010, &ENTRY_DISHONORABLER_3043788293690199279)],
        &[(0b11010, &ENTRY_DISHONORABLES_9899266461697606508)],
        &[(0b11010, &ENTRY_DISHONORABLEST_3928567236277526991)],
        &[(0b11010, &ENTRY_DISHONORABLIER_8450606157745671431)],
        &[(0b11010, &ENTRY_DISHONORABLIES_14942803523606691356)],
        &[(0b11010, &ENTRY_DISHONORABLIEST_12463634118581290321)],
        &[(0b11010, &ENTRY_DISHONORABLY_16389408757341415026)],
        &[(0b11010, &ENTRY_DISHONORARY_7185175374757498337)],
        &[(0b11010, &ENTRY_DISHONORED_1979408375344629609)],
        &[(0b11010, &ENTRY_DISHONORER_11600072711097852356)],
        &[(0b11010, &ENTRY_DISHONORERS_16218792927597703675)],
        &[(0b11010, &ENTRY_DISHONORING_16122094070164850675)],
        &[(0b11010, &ENTRY_DISHONORS_5828073138827677548)],
        &[(0b10010, &ENTRY_DISHUMANIZE_2097256647850275480)],
        &[(0b10010, &ENTRY_DISHUMANIZES_11017789745964682172)],
        &[(0b01001, &ENTRY_DISHUMANIZE_2097256647850275480)],
        &[(0b01001, &ENTRY_DISHUMANIZES_11017789745964682172)],
        &[(0b11001, &ENTRY_DISHUMOR_17351796049135318401)],
        &[(0b11001, &ENTRY_DISHUMORED_2383879622247462959)],
        &[(0b11001, &ENTRY_DISHUMORS_4122248585102919920)],
        &[(0b11010, &ENTRY_DISHUMOR_17351796049135318401)],
        &[(0b11010, &ENTRY_DISHUMORED_2383879622247462959)],
        &[(0b11010, &ENTRY_DISHUMORS_4122248585102919920)],
    ],
    range: 4..=15,
};

static VARS_DISF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISF_CHILDREN),
    value: None,
};

pub static VARS_DISF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avored"),
        dictgen::InsensitiveStr::Ascii("avorer"),
        dictgen::InsensitiveStr::Ascii("avorers"),
        dictgen::InsensitiveStr::Ascii("avoring"),
        dictgen::InsensitiveStr::Ascii("avors"),
        dictgen::InsensitiveStr::Ascii("avour"),
        dictgen::InsensitiveStr::Ascii("avoured"),
        dictgen::InsensitiveStr::Ascii("avourer"),
        dictgen::InsensitiveStr::Ascii("avourers"),
        dictgen::InsensitiveStr::Ascii("avouring"),
        dictgen::InsensitiveStr::Ascii("avours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_DISFAVOR_10548525794143920697)],
        &[(0b11001, &ENTRY_DISFAVORED_4040006339995038210)],
        &[(0b11001, &ENTRY_DISFAVORER_10571638081997401701)],
        &[(0b11001, &ENTRY_DISFAVORERS_18430656322920499015)],
        &[(0b11001, &ENTRY_DISFAVORING_16851499602444812970)],
        &[(0b11001, &ENTRY_DISFAVORS_15834201467329633407)],
        &[(0b11010, &ENTRY_DISFAVOR_10548525794143920697)],
        &[(0b11010, &ENTRY_DISFAVORED_4040006339995038210)],
        &[(0b11010, &ENTRY_DISFAVORER_10571638081997401701)],
        &[(0b11010, &ENTRY_DISFAVORERS_18430656322920499015)],
        &[(0b11010, &ENTRY_DISFAVORING_16851499602444812970)],
        &[(0b11010, &ENTRY_DISFAVORS_15834201467329633407)],
    ],
    range: 4..=8,
};

static VARS_DISE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISE_CHILDREN),
    value: None,
};

pub static VARS_DISE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mboweled"),
        dictgen::InsensitiveStr::Ascii("mboweling"),
        dictgen::InsensitiveStr::Ascii("mbowelled"),
        dictgen::InsensitiveStr::Ascii("mbowelling"),
        dictgen::InsensitiveStr::Ascii("qualise"),
        dictgen::InsensitiveStr::Ascii("qualiser"),
        dictgen::InsensitiveStr::Ascii("qualisers"),
        dictgen::InsensitiveStr::Ascii("qualises"),
        dictgen::InsensitiveStr::Ascii("qualize"),
        dictgen::InsensitiveStr::Ascii("qualizer"),
        dictgen::InsensitiveStr::Ascii("qualizers"),
        dictgen::InsensitiveStr::Ascii("qualizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DISEMBOWELED_10970335018373428342)],
        &[(0b00001, &ENTRY_DISEMBOWELING_1397333253900455739)],
        &[(0b11010, &ENTRY_DISEMBOWELED_10970335018373428342)],
        &[(0b11010, &ENTRY_DISEMBOWELING_1397333253900455739)],
        &[(0b10010, &ENTRY_DISEQUALIZE_2351244429763172565)],
        &[(0b10010, &ENTRY_DISEQUALIZER_15153684888095615538)],
        &[(0b10010, &ENTRY_DISEQUALIZERS_17092206736491516096)],
        &[(0b10010, &ENTRY_DISEQUALIZES_7417403436798093715)],
        &[(0b01001, &ENTRY_DISEQUALIZE_2351244429763172565)],
        &[(0b01001, &ENTRY_DISEQUALIZER_15153684888095615538)],
        &[(0b01001, &ENTRY_DISEQUALIZERS_17092206736491516096)],
        &[(0b01001, &ENTRY_DISEQUALIZES_7417403436798093715)],
    ],
    range: 7..=10,
};

static VARS_DISD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISD_CHILDREN),
    value: None,
};

pub static VARS_DISD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enominationalise"),
        dictgen::InsensitiveStr::Ascii("enominationalises"),
        dictgen::InsensitiveStr::Ascii("enominationalize"),
        dictgen::InsensitiveStr::Ascii("enominationalizes"),
        dictgen::InsensitiveStr::Ascii("iplomatise"),
        dictgen::InsensitiveStr::Ascii("iplomatises"),
        dictgen::InsensitiveStr::Ascii("iplomatize"),
        dictgen::InsensitiveStr::Ascii("iplomatizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISDENOMINATIONALIZE_535012825291404497)],
        &[(0b10010, &ENTRY_DISDENOMINATIONALIZES_12397562771885821092)],
        &[(0b01001, &ENTRY_DISDENOMINATIONALIZE_535012825291404497)],
        &[(0b01001, &ENTRY_DISDENOMINATIONALIZES_12397562771885821092)],
        &[(0b10010, &ENTRY_DISDIPLOMATIZE_885764438051293853)],
        &[(0b10010, &ENTRY_DISDIPLOMATIZES_4891957747419116479)],
        &[(0b01001, &ENTRY_DISDIPLOMATIZE_885764438051293853)],
        &[(0b01001, &ENTRY_DISDIPLOMATIZES_4891957747419116479)],
    ],
    range: 10..=17,
};

static VARS_DISC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISC_CHILDREN),
    value: None,
};

pub static VARS_DISC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anonisation"),
        dictgen::InsensitiveStr::Ascii("anonisations"),
        dictgen::InsensitiveStr::Ascii("anonise"),
        dictgen::InsensitiveStr::Ascii("anonises"),
        dictgen::InsensitiveStr::Ascii("anonization"),
        dictgen::InsensitiveStr::Ascii("anonizations"),
        dictgen::InsensitiveStr::Ascii("anonize"),
        dictgen::InsensitiveStr::Ascii("anonizes"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olorate"),
        dictgen::InsensitiveStr::Ascii("olorated"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloredness"),
        dictgen::InsensitiveStr::Ascii("oloreds"),
        dictgen::InsensitiveStr::Ascii("oloring"),
        dictgen::InsensitiveStr::Ascii("olorization"),
        dictgen::InsensitiveStr::Ascii("olorizations"),
        dictgen::InsensitiveStr::Ascii("olorment"),
        dictgen::InsensitiveStr::Ascii("olorments"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olourate"),
        dictgen::InsensitiveStr::Ascii("olourated"),
        dictgen::InsensitiveStr::Ascii("olouration"),
        dictgen::InsensitiveStr::Ascii("olourations"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouredness"),
        dictgen::InsensitiveStr::Ascii("oloureds"),
        dictgen::InsensitiveStr::Ascii("olouring"),
        dictgen::InsensitiveStr::Ascii("olourisation"),
        dictgen::InsensitiveStr::Ascii("olourisations"),
        dictgen::InsensitiveStr::Ascii("olourization"),
        dictgen::InsensitiveStr::Ascii("olourizations"),
        dictgen::InsensitiveStr::Ascii("olourment"),
        dictgen::InsensitiveStr::Ascii("olourments"),
        dictgen::InsensitiveStr::Ascii("olours"),
        dictgen::InsensitiveStr::Ascii("retisation"),
        dictgen::InsensitiveStr::Ascii("retise"),
        dictgen::InsensitiveStr::Ascii("retization"),
        dictgen::InsensitiveStr::Ascii("retize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISCANONIZATION_9504497596950273772)],
        &[(0b10010, &ENTRY_DISCANONIZATIONS_714613792349570061)],
        &[(0b10010, &ENTRY_DISCANONIZE_10059279715015590378)],
        &[(0b10010, &ENTRY_DISCANONIZES_7404724245545428484)],
        &[(0b01001, &ENTRY_DISCANONIZATION_9504497596950273772)],
        &[(0b01001, &ENTRY_DISCANONIZATIONS_714613792349570061)],
        &[(0b01001, &ENTRY_DISCANONIZE_10059279715015590378)],
        &[(0b01001, &ENTRY_DISCANONIZES_7404724245545428484)],
        &[(0b01001, &ENTRY_DISCOLOR_5229997782497228003)],
        &[(0b00001, &ENTRY_DISCOLORATE_17525488967185123450)],
        &[(0b00001, &ENTRY_DISCOLORATED_9751918465389903770)],
        &[(0b01001, &ENTRY_DISCOLORED_11781061950619883476)],
        &[(0b00001, &ENTRY_DISCOLOREDNESS_6651369091187102535)],
        &[(0b01001, &ENTRY_DISCOLOREDS_2390131969640640898)],
        &[(0b01001, &ENTRY_DISCOLORING_2630857377151306278)],
        &[(0b00001, &ENTRY_DISCOLORIZATION_1561449986421291790)],
        &[(0b00001, &ENTRY_DISCOLORIZATIONS_14292400843926128979)],
        &[(0b00001, &ENTRY_DISCOLORMENT_14928622858833795102)],
        &[(0b00001, &ENTRY_DISCOLORMENTS_11818433310186389225)],
        &[(0b01001, &ENTRY_DISCOLORS_5612202091276496972)],
        &[(0b11010, &ENTRY_DISCOLOR_5229997782497228003)],
        &[(0b11010, &ENTRY_DISCOLORATE_17525488967185123450)],
        &[(0b11010, &ENTRY_DISCOLORATED_9751918465389903770)],
        &[(0b11010, &ENTRY_DISCOLORATION_14169998051189645771)],
        &[(0b11010, &ENTRY_DISCOLORATIONS_161368754086315692)],
        &[(0b11010, &ENTRY_DISCOLORED_11781061950619883476)],
        &[(0b11010, &ENTRY_DISCOLOREDNESS_6651369091187102535)],
        &[(0b11010, &ENTRY_DISCOLOREDS_2390131969640640898)],
        &[(0b11010, &ENTRY_DISCOLORING_2630857377151306278)],
        &[(0b10010, &ENTRY_DISCOLORIZATION_1561449986421291790)],
        &[(0b10010, &ENTRY_DISCOLORIZATIONS_14292400843926128979)],
        &[(0b01000, &ENTRY_DISCOLORIZATION_1561449986421291790)],
        &[(0b01000, &ENTRY_DISCOLORIZATIONS_14292400843926128979)],
        &[(0b11010, &ENTRY_DISCOLORMENT_14928622858833795102)],
        &[(0b11010, &ENTRY_DISCOLORMENTS_11818433310186389225)],
        &[(0b11010, &ENTRY_DISCOLORS_5612202091276496972)],
        &[(0b10010, &ENTRY_DISCRETIZATION_12744800183024300851)],
        &[(0b10010, &ENTRY_DISCRETIZE_5822871996560826075)],
        &[(0b01001, &ENTRY_DISCRETIZATION_12744800183024300851)],
        &[(0b01001, &ENTRY_DISCRETIZE_5822871996560826075)],
    ],
    range: 4..=13,
};

static VARS_DISB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISB_CHILDREN),
    value: None,
};

pub static VARS_DISB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oweled"),
        dictgen::InsensitiveStr::Ascii("oweling"),
        dictgen::InsensitiveStr::Ascii("owelled"),
        dictgen::InsensitiveStr::Ascii("owelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DISBOWELED_8124420063056832999)],
        &[(0b00001, &ENTRY_DISBOWELING_14146470427022244483)],
        &[(0b11010, &ENTRY_DISBOWELED_8124420063056832999)],
        &[(0b11010, &ENTRY_DISBOWELING_14146470427022244483)],
    ],
    range: 6..=8,
};

static VARS_DISA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DISA_CHILDREN),
    value: None,
};

pub static VARS_DISA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ngularise"),
        dictgen::InsensitiveStr::Ascii("ngularises"),
        dictgen::InsensitiveStr::Ascii("ngularize"),
        dictgen::InsensitiveStr::Ascii("ngularizes"),
        dictgen::InsensitiveStr::Ascii("uthorise"),
        dictgen::InsensitiveStr::Ascii("uthorised"),
        dictgen::InsensitiveStr::Ascii("uthorises"),
        dictgen::InsensitiveStr::Ascii("uthorising"),
        dictgen::InsensitiveStr::Ascii("uthorize"),
        dictgen::InsensitiveStr::Ascii("uthorized"),
        dictgen::InsensitiveStr::Ascii("uthorizes"),
        dictgen::InsensitiveStr::Ascii("uthorizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DISANGULARIZE_15234154485855761347)],
        &[(0b10010, &ENTRY_DISANGULARIZES_4645387961020197923)],
        &[(0b01001, &ENTRY_DISANGULARIZE_15234154485855761347)],
        &[(0b01001, &ENTRY_DISANGULARIZES_4645387961020197923)],
        &[(0b10010, &ENTRY_DISAUTHORIZE_9729193059512637993)],
        &[(0b10010, &ENTRY_DISAUTHORIZED_15149050577902575232)],
        &[(0b10010, &ENTRY_DISAUTHORIZES_16971580585403699509)],
        &[(0b10010, &ENTRY_DISAUTHORIZING_1506123926769301204)],
        &[(0b01001, &ENTRY_DISAUTHORIZE_9729193059512637993)],
        &[(0b01001, &ENTRY_DISAUTHORIZED_15149050577902575232)],
        &[(0b01001, &ENTRY_DISAUTHORIZES_16971580585403699509)],
        &[(0b01001, &ENTRY_DISAUTHORIZING_1506123926769301204)],
    ],
    range: 8..=10,
};

static VARS_DIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIP_CHILDREN),
    value: None,
};

pub static VARS_DIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hthongisation"),
        dictgen::InsensitiveStr::Ascii("hthongisations"),
        dictgen::InsensitiveStr::Ascii("hthongise"),
        dictgen::InsensitiveStr::Ascii("hthongised"),
        dictgen::InsensitiveStr::Ascii("hthongises"),
        dictgen::InsensitiveStr::Ascii("hthongising"),
        dictgen::InsensitiveStr::Ascii("hthongization"),
        dictgen::InsensitiveStr::Ascii("hthongizations"),
        dictgen::InsensitiveStr::Ascii("hthongize"),
        dictgen::InsensitiveStr::Ascii("hthongized"),
        dictgen::InsensitiveStr::Ascii("hthongizes"),
        dictgen::InsensitiveStr::Ascii("hthongizing"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("loae"),
        dictgen::InsensitiveStr::Ascii("loe"),
        dictgen::InsensitiveStr::Ascii("lomatise"),
        dictgen::InsensitiveStr::Ascii("lomatised"),
        dictgen::InsensitiveStr::Ascii("lomatises"),
        dictgen::InsensitiveStr::Ascii("lomatising"),
        dictgen::InsensitiveStr::Ascii("lomatize"),
        dictgen::InsensitiveStr::Ascii("lomatized"),
        dictgen::InsensitiveStr::Ascii("lomatizes"),
        dictgen::InsensitiveStr::Ascii("lomatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIPHTHONGIZATION_4888277953337569133)],
        &[(0b10010, &ENTRY_DIPHTHONGIZATIONS_3965346305488551771)],
        &[(0b10010, &ENTRY_DIPHTHONGIZE_12838588614712725416)],
        &[(0b10010, &ENTRY_DIPHTHONGIZED_7607687267591459487)],
        &[(0b10010, &ENTRY_DIPHTHONGIZES_9976473308769011757)],
        &[(0b10010, &ENTRY_DIPHTHONGIZING_9367101143579778156)],
        &[(0b01001, &ENTRY_DIPHTHONGIZATION_4888277953337569133)],
        &[(0b01001, &ENTRY_DIPHTHONGIZATIONS_3965346305488551771)],
        &[(0b01001, &ENTRY_DIPHTHONGIZE_12838588614712725416)],
        &[(0b01001, &ENTRY_DIPHTHONGIZED_7607687267591459487)],
        &[(0b01001, &ENTRY_DIPHTHONGIZES_9976473308769011757)],
        &[(0b01001, &ENTRY_DIPHTHONGIZING_9367101143579778156)],
        &[(0b00001, &ENTRY_DIPLE_3376459421960689495)],
        &[(0b11010, &ENTRY_DIPLOE_5571525081319448833)],
        &[
            (0b11010, &ENTRY_DIPLE_3376459421960689495),
            (0b00001, &ENTRY_DIPLOE_5571525081319448833),
        ],
        &[(0b10010, &ENTRY_DIPLOMATIZE_8810012624009252945)],
        &[(0b10010, &ENTRY_DIPLOMATIZED_18386252538878346892)],
        &[(0b10010, &ENTRY_DIPLOMATIZES_17976479831103709392)],
        &[(0b10010, &ENTRY_DIPLOMATIZING_10466832182528029316)],
        &[(0b01001, &ENTRY_DIPLOMATIZE_8810012624009252945)],
        &[(0b01001, &ENTRY_DIPLOMATIZED_18386252538878346892)],
        &[(0b01001, &ENTRY_DIPLOMATIZES_17976479831103709392)],
        &[(0b01001, &ENTRY_DIPLOMATIZING_10466832182528029316)],
    ],
    range: 2..=14,
};

static VARS_DIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIO_CHILDREN),
    value: None,
};

pub static VARS_DIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("estrous"),
        dictgen::InsensitiveStr::Ascii("estrual"),
        dictgen::InsensitiveStr::Ascii("estrum"),
        dictgen::InsensitiveStr::Ascii("estrus"),
        dictgen::InsensitiveStr::Ascii("estruses"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("pter"),
        dictgen::InsensitiveStr::Ascii("pters"),
        dictgen::InsensitiveStr::Ascii("ptre"),
        dictgen::InsensitiveStr::Ascii("ptres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DIESTROUS_2649092910168728128)],
        &[(0b11010, &ENTRY_DIESTRUAL_4297674653321861564)],
        &[(0b11010, &ENTRY_DIESTRUM_5374513461214013606)],
        &[(0b11010, &ENTRY_DIESTRUS_10065397832891326590)],
        &[(0b11010, &ENTRY_DIESTRUSES_551696630438157478)],
        &[(0b10010, &ENTRY_DIONIZE_5302013842773672496)],
        &[(0b01001, &ENTRY_DIONIZE_5302013842773672496)],
        &[(0b01001, &ENTRY_DIOPTER_10363011140557994074)],
        &[(0b01001, &ENTRY_DIOPTERS_516947549353623981)],
        &[(0b11010, &ENTRY_DIOPTER_10363011140557994074)],
        &[(0b11010, &ENTRY_DIOPTERS_516947549353623981)],
    ],
    range: 4..=8,
};

static VARS_DIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIM_CHILDREN),
    value: None,
};

pub static VARS_DIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensionalisation"),
        dictgen::InsensitiveStr::Ascii("ensionalise"),
        dictgen::InsensitiveStr::Ascii("ensionalised"),
        dictgen::InsensitiveStr::Ascii("ensionalises"),
        dictgen::InsensitiveStr::Ascii("ensionalising"),
        dictgen::InsensitiveStr::Ascii("ensionalization"),
        dictgen::InsensitiveStr::Ascii("ensionalize"),
        dictgen::InsensitiveStr::Ascii("ensionalized"),
        dictgen::InsensitiveStr::Ascii("ensionalizes"),
        dictgen::InsensitiveStr::Ascii("ensionalizing"),
        dictgen::InsensitiveStr::Ascii("erisation"),
        dictgen::InsensitiveStr::Ascii("erisations"),
        dictgen::InsensitiveStr::Ascii("erise"),
        dictgen::InsensitiveStr::Ascii("erised"),
        dictgen::InsensitiveStr::Ascii("erises"),
        dictgen::InsensitiveStr::Ascii("erising"),
        dictgen::InsensitiveStr::Ascii("erization"),
        dictgen::InsensitiveStr::Ascii("erizations"),
        dictgen::InsensitiveStr::Ascii("erize"),
        dictgen::InsensitiveStr::Ascii("erized"),
        dictgen::InsensitiveStr::Ascii("erizes"),
        dictgen::InsensitiveStr::Ascii("erizing"),
        dictgen::InsensitiveStr::Ascii("inutivise"),
        dictgen::InsensitiveStr::Ascii("inutivises"),
        dictgen::InsensitiveStr::Ascii("inutivize"),
        dictgen::InsensitiveStr::Ascii("inutivizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIMENSIONALIZATION_928272190267284990)],
        &[(0b10010, &ENTRY_DIMENSIONALIZE_17867138639749619838)],
        &[(0b10010, &ENTRY_DIMENSIONALIZED_7314101641422273330)],
        &[(0b10010, &ENTRY_DIMENSIONALIZES_8173757650577128994)],
        &[(0b10010, &ENTRY_DIMENSIONALIZING_5188710411327541644)],
        &[(0b01001, &ENTRY_DIMENSIONALIZATION_928272190267284990)],
        &[(0b01001, &ENTRY_DIMENSIONALIZE_17867138639749619838)],
        &[(0b01001, &ENTRY_DIMENSIONALIZED_7314101641422273330)],
        &[(0b01001, &ENTRY_DIMENSIONALIZES_8173757650577128994)],
        &[(0b01001, &ENTRY_DIMENSIONALIZING_5188710411327541644)],
        &[(0b10010, &ENTRY_DIMERIZATION_15302035121240997222)],
        &[(0b10010, &ENTRY_DIMERIZATIONS_14028175985445569270)],
        &[(0b10010, &ENTRY_DIMERIZE_16193073428737317522)],
        &[(0b10010, &ENTRY_DIMERIZED_15199320696227405238)],
        &[(0b10010, &ENTRY_DIMERIZES_1537628000711484411)],
        &[(0b10010, &ENTRY_DIMERIZING_14292842827296885678)],
        &[(0b01001, &ENTRY_DIMERIZATION_15302035121240997222)],
        &[(0b01001, &ENTRY_DIMERIZATIONS_14028175985445569270)],
        &[(0b01001, &ENTRY_DIMERIZE_16193073428737317522)],
        &[(0b01001, &ENTRY_DIMERIZED_15199320696227405238)],
        &[(0b01001, &ENTRY_DIMERIZES_1537628000711484411)],
        &[(0b01001, &ENTRY_DIMERIZING_14292842827296885678)],
        &[(0b10010, &ENTRY_DIMINUTIVIZE_8157805496969771537)],
        &[(0b10010, &ENTRY_DIMINUTIVIZES_340938279453222908)],
        &[(0b01001, &ENTRY_DIMINUTIVIZE_8157805496969771537)],
        &[(0b01001, &ENTRY_DIMINUTIVIZES_340938279453222908)],
    ],
    range: 5..=15,
};

static VARS_DIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIG_CHILDREN),
    value: None,
};

pub static VARS_DIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italisations"),
        dictgen::InsensitiveStr::Ascii("italise"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italises"),
        dictgen::InsensitiveStr::Ascii("italising"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italizations"),
        dictgen::InsensitiveStr::Ascii("italize"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizes"),
        dictgen::InsensitiveStr::Ascii("italizing"),
        dictgen::InsensitiveStr::Ascii("itisation"),
        dictgen::InsensitiveStr::Ascii("itisations"),
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itiser"),
        dictgen::InsensitiveStr::Ascii("itisers"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itization"),
        dictgen::InsensitiveStr::Ascii("itizations"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizer"),
        dictgen::InsensitiveStr::Ascii("itizers"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIGITALIZATION_5413639479952668184)],
        &[(0b10010, &ENTRY_DIGITALIZATIONS_7057163228044401005)],
        &[(0b10010, &ENTRY_DIGITALIZE_7792956770391756553)],
        &[(0b10010, &ENTRY_DIGITALIZED_10368572290482312188)],
        &[(0b10010, &ENTRY_DIGITALIZES_14236944342236594070)],
        &[(0b10010, &ENTRY_DIGITALIZING_5922141572600056524)],
        &[(0b01001, &ENTRY_DIGITALIZATION_5413639479952668184)],
        &[(0b01001, &ENTRY_DIGITALIZATIONS_7057163228044401005)],
        &[(0b01001, &ENTRY_DIGITALIZE_7792956770391756553)],
        &[(0b01001, &ENTRY_DIGITALIZED_10368572290482312188)],
        &[(0b01001, &ENTRY_DIGITALIZES_14236944342236594070)],
        &[(0b01001, &ENTRY_DIGITALIZING_5922141572600056524)],
        &[(0b10010, &ENTRY_DIGITIZATION_17548895183926914542)],
        &[(0b10010, &ENTRY_DIGITIZATIONS_16897900325023989676)],
        &[(0b10010, &ENTRY_DIGITIZE_9662348846686188302)],
        &[(0b10010, &ENTRY_DIGITIZED_18167407254586843848)],
        &[(0b10010, &ENTRY_DIGITIZER_10090672409246281037)],
        &[(0b10010, &ENTRY_DIGITIZERS_13411982289262402294)],
        &[(0b10010, &ENTRY_DIGITIZES_2690419763079826049)],
        &[(0b10010, &ENTRY_DIGITIZING_14141099429643492961)],
        &[(0b01001, &ENTRY_DIGITIZATION_17548895183926914542)],
        &[(0b01001, &ENTRY_DIGITIZATIONS_16897900325023989676)],
        &[(0b01001, &ENTRY_DIGITIZE_9662348846686188302)],
        &[(0b01001, &ENTRY_DIGITIZED_18167407254586843848)],
        &[(0b01001, &ENTRY_DIGITIZER_10090672409246281037)],
        &[(0b01001, &ENTRY_DIGITIZERS_13411982289262402294)],
        &[(0b01001, &ENTRY_DIGITIZES_2690419763079826049)],
        &[(0b01001, &ENTRY_DIGITIZING_14141099429643492961)],
    ],
    range: 5..=12,
};

static VARS_DIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIF_CHILDREN),
    value: None,
};

pub static VARS_DIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ferentialise"),
        dictgen::InsensitiveStr::Ascii("ferentialises"),
        dictgen::InsensitiveStr::Ascii("ferentialize"),
        dictgen::InsensitiveStr::Ascii("ferentializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIFFERENTIALIZE_16668562110152154633)],
        &[(0b10010, &ENTRY_DIFFERENTIALIZES_2900226538448132077)],
        &[(0b01001, &ENTRY_DIFFERENTIALIZE_16668562110152154633)],
        &[(0b01001, &ENTRY_DIFFERENTIALIZES_2900226538448132077)],
    ],
    range: 12..=13,
};

static VARS_DIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIE_CHILDREN),
    value: None,
};

pub static VARS_DIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("ciously"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("retic"),
        dictgen::InsensitiveStr::Ascii("selisation"),
        dictgen::InsensitiveStr::Ascii("selisations"),
        dictgen::InsensitiveStr::Ascii("selise"),
        dictgen::InsensitiveStr::Ascii("selised"),
        dictgen::InsensitiveStr::Ascii("selises"),
        dictgen::InsensitiveStr::Ascii("selising"),
        dictgen::InsensitiveStr::Ascii("selization"),
        dictgen::InsensitiveStr::Ascii("selizations"),
        dictgen::InsensitiveStr::Ascii("selize"),
        dictgen::InsensitiveStr::Ascii("selized"),
        dictgen::InsensitiveStr::Ascii("selizes"),
        dictgen::InsensitiveStr::Ascii("selizing"),
        dictgen::InsensitiveStr::Ascii("strous"),
        dictgen::InsensitiveStr::Ascii("strual"),
        dictgen::InsensitiveStr::Ascii("strum"),
        dictgen::InsensitiveStr::Ascii("strus"),
        dictgen::InsensitiveStr::Ascii("struses"),
        dictgen::InsensitiveStr::Ascii("thylstilbestrol"),
        dictgen::InsensitiveStr::Ascii("thylstilboestrol"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DIOECIOUS_421155846144149881)],
        &[(0b00001, &ENTRY_DIOECIOUSLY_10693807285796274184)],
        &[(0b00001, &ENTRY_DIENE_8393408286309594192)],
        &[(0b00001, &ENTRY_DIERETIC_13830183413584247379)],
        &[(0b10010, &ENTRY_DIESELIZATION_16989738541584421026)],
        &[(0b10010, &ENTRY_DIESELIZATIONS_14749287237278344971)],
        &[(0b10010, &ENTRY_DIESELIZE_14819412399240860707)],
        &[(0b10010, &ENTRY_DIESELIZED_1396909342953338000)],
        &[(0b10010, &ENTRY_DIESELIZES_13977733140626156483)],
        &[(0b10010, &ENTRY_DIESELIZING_17476118384961942350)],
        &[(0b01001, &ENTRY_DIESELIZATION_16989738541584421026)],
        &[(0b01001, &ENTRY_DIESELIZATIONS_14749287237278344971)],
        &[(0b01001, &ENTRY_DIESELIZE_14819412399240860707)],
        &[(0b01001, &ENTRY_DIESELIZED_1396909342953338000)],
        &[(0b01001, &ENTRY_DIESELIZES_13977733140626156483)],
        &[(0b01001, &ENTRY_DIESELIZING_17476118384961942350)],
        &[(0b10001, &ENTRY_DIESTROUS_2649092910168728128)],
        &[(0b10001, &ENTRY_DIESTRUAL_4297674653321861564)],
        &[(0b10001, &ENTRY_DIESTRUM_5374513461214013606)],
        &[(0b10001, &ENTRY_DIESTRUS_10065397832891326590)],
        &[(0b10001, &ENTRY_DIESTRUSES_551696630438157478)],
        &[(0b00001, &ENTRY_DIETHYLSTILBESTROL_1887150150156134254)],
        &[(0b11010, &ENTRY_DIETHYLSTILBESTROL_1887150150156134254)],
    ],
    range: 2..=16,
};

static VARS_DIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIC_CHILDREN),
    value: None,
};

pub static VARS_DIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hotomisation"),
        dictgen::InsensitiveStr::Ascii("hotomisations"),
        dictgen::InsensitiveStr::Ascii("hotomise"),
        dictgen::InsensitiveStr::Ascii("hotomised"),
        dictgen::InsensitiveStr::Ascii("hotomises"),
        dictgen::InsensitiveStr::Ascii("hotomising"),
        dictgen::InsensitiveStr::Ascii("hotomization"),
        dictgen::InsensitiveStr::Ascii("hotomizations"),
        dictgen::InsensitiveStr::Ascii("hotomize"),
        dictgen::InsensitiveStr::Ascii("hotomized"),
        dictgen::InsensitiveStr::Ascii("hotomizes"),
        dictgen::InsensitiveStr::Ascii("hotomizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DICHOTOMIZATION_14814468761822605666)],
        &[(0b10010, &ENTRY_DICHOTOMIZATIONS_11511794064634282366)],
        &[(0b10010, &ENTRY_DICHOTOMIZE_2536151466993014840)],
        &[(0b10010, &ENTRY_DICHOTOMIZED_11469969501387954088)],
        &[(0b10010, &ENTRY_DICHOTOMIZES_9486969443354667350)],
        &[(0b10010, &ENTRY_DICHOTOMIZING_6605468293502488075)],
        &[(0b01001, &ENTRY_DICHOTOMIZATION_14814468761822605666)],
        &[(0b01001, &ENTRY_DICHOTOMIZATIONS_11511794064634282366)],
        &[(0b01001, &ENTRY_DICHOTOMIZE_2536151466993014840)],
        &[(0b01001, &ENTRY_DICHOTOMIZED_11469969501387954088)],
        &[(0b01001, &ENTRY_DICHOTOMIZES_9486969443354667350)],
        &[(0b01001, &ENTRY_DICHOTOMIZING_6605468293502488075)],
    ],
    range: 8..=13,
};

static VARS_DIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DIA_CHILDREN),
    value: None,
};

static VARS_DIA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_DIAB_NODE),
    None,
    None,
    Some(&VARS_DIAE_NODE),
    None,
    Some(&VARS_DIAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_DIAL_NODE),
    Some(&VARS_DIAM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_DIAR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_DIAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAR_CHILDREN),
    value: None,
};

pub static VARS_DIAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
        dictgen::InsensitiveStr::Ascii("rhea"),
        dictgen::InsensitiveStr::Ascii("rheal"),
        dictgen::InsensitiveStr::Ascii("rhealer"),
        dictgen::InsensitiveStr::Ascii("rhealest"),
        dictgen::InsensitiveStr::Ascii("rheas"),
        dictgen::InsensitiveStr::Ascii("rheic"),
        dictgen::InsensitiveStr::Ascii("rheicer"),
        dictgen::InsensitiveStr::Ascii("rheicest"),
        dictgen::InsensitiveStr::Ascii("rhetic"),
        dictgen::InsensitiveStr::Ascii("rheticer"),
        dictgen::InsensitiveStr::Ascii("rheticest"),
        dictgen::InsensitiveStr::Ascii("rhoea"),
        dictgen::InsensitiveStr::Ascii("rhoeal"),
        dictgen::InsensitiveStr::Ascii("rhoealer"),
        dictgen::InsensitiveStr::Ascii("rhoealest"),
        dictgen::InsensitiveStr::Ascii("rhoeas"),
        dictgen::InsensitiveStr::Ascii("rhoeic"),
        dictgen::InsensitiveStr::Ascii("rhoeicer"),
        dictgen::InsensitiveStr::Ascii("rhoeicest"),
        dictgen::InsensitiveStr::Ascii("rhoetic"),
        dictgen::InsensitiveStr::Ascii("rhoeticer"),
        dictgen::InsensitiveStr::Ascii("rhoeticest"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIARIZE_7333441747497120999)],
        &[(0b10010, &ENTRY_DIARIZED_15375708985365837815)],
        &[(0b10010, &ENTRY_DIARIZES_6733157561570470769)],
        &[(0b10010, &ENTRY_DIARIZING_6033557535432094232)],
        &[(0b01001, &ENTRY_DIARIZE_7333441747497120999)],
        &[(0b01001, &ENTRY_DIARIZED_15375708985365837815)],
        &[(0b01001, &ENTRY_DIARIZES_6733157561570470769)],
        &[(0b01001, &ENTRY_DIARIZING_6033557535432094232)],
        &[(0b11001, &ENTRY_DIARRHEA_16651318537078726725)],
        &[(0b11001, &ENTRY_DIARRHEAL_13590773083958773898)],
        &[(0b11001, &ENTRY_DIARRHEALER_11350171176863314647)],
        &[(0b11001, &ENTRY_DIARRHEALEST_16171976767316321320)],
        &[(0b11001, &ENTRY_DIARRHEAS_11453476003683730830)],
        &[(0b10001, &ENTRY_DIARRHEIC_5406216762270560046)],
        &[(0b10001, &ENTRY_DIARRHEICER_15169580495143503922)],
        &[(0b10001, &ENTRY_DIARRHEICEST_14221151968572902300)],
        &[(0b10001, &ENTRY_DIARRHETIC_6608432625592653807)],
        &[(0b10001, &ENTRY_DIARRHETICER_8758731973889395817)],
        &[(0b10001, &ENTRY_DIARRHETICEST_7576238721431437280)],
        &[(0b10010, &ENTRY_DIARRHEA_16651318537078726725)],
        &[(0b10010, &ENTRY_DIARRHEAL_13590773083958773898)],
        &[(0b10010, &ENTRY_DIARRHEALER_11350171176863314647)],
        &[(0b10010, &ENTRY_DIARRHEALEST_16171976767316321320)],
        &[(0b10010, &ENTRY_DIARRHEAS_11453476003683730830)],
        &[(0b11010, &ENTRY_DIARRHEIC_5406216762270560046)],
        &[(0b11010, &ENTRY_DIARRHEICER_15169580495143503922)],
        &[(0b11010, &ENTRY_DIARRHEICEST_14221151968572902300)],
        &[(0b11010, &ENTRY_DIARRHETIC_6608432625592653807)],
        &[(0b11010, &ENTRY_DIARRHETICER_8758731973889395817)],
        &[(0b11010, &ENTRY_DIARRHETICEST_7576238721431437280)],
    ],
    range: 3..=10,
};

static VARS_DIAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAM_CHILDREN),
    value: None,
};

pub static VARS_DIAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ondise"),
        dictgen::InsensitiveStr::Ascii("ondises"),
        dictgen::InsensitiveStr::Ascii("ondize"),
        dictgen::InsensitiveStr::Ascii("ondizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIAMONDIZE_974653197096494091)],
        &[(0b10010, &ENTRY_DIAMONDIZES_11382117953228798781)],
        &[(0b01001, &ENTRY_DIAMONDIZE_974653197096494091)],
        &[(0b01001, &ENTRY_DIAMONDIZES_11382117953228798781)],
    ],
    range: 6..=7,
};

static VARS_DIAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAL_CHILDREN),
    value: None,
};

pub static VARS_DIAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecticise"),
        dictgen::InsensitiveStr::Ascii("ecticises"),
        dictgen::InsensitiveStr::Ascii("ecticize"),
        dictgen::InsensitiveStr::Ascii("ecticizes"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ings"),
        dictgen::InsensitiveStr::Ascii("ist"),
        dictgen::InsensitiveStr::Ascii("ists"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lings"),
        dictgen::InsensitiveStr::Ascii("list"),
        dictgen::InsensitiveStr::Ascii("lists"),
        dictgen::InsensitiveStr::Ascii("ogged"),
        dictgen::InsensitiveStr::Ascii("ogging"),
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ogs"),
        dictgen::InsensitiveStr::Ascii("ysabilities"),
        dictgen::InsensitiveStr::Ascii("ysability"),
        dictgen::InsensitiveStr::Ascii("ysable"),
        dictgen::InsensitiveStr::Ascii("ysabler"),
        dictgen::InsensitiveStr::Ascii("ysables"),
        dictgen::InsensitiveStr::Ascii("ysablest"),
        dictgen::InsensitiveStr::Ascii("ysate"),
        dictgen::InsensitiveStr::Ascii("ysates"),
        dictgen::InsensitiveStr::Ascii("ysation"),
        dictgen::InsensitiveStr::Ascii("yse"),
        dictgen::InsensitiveStr::Ascii("ysed"),
        dictgen::InsensitiveStr::Ascii("yser"),
        dictgen::InsensitiveStr::Ascii("ysers"),
        dictgen::InsensitiveStr::Ascii("ysing"),
        dictgen::InsensitiveStr::Ascii("yzabilities"),
        dictgen::InsensitiveStr::Ascii("yzability"),
        dictgen::InsensitiveStr::Ascii("yzable"),
        dictgen::InsensitiveStr::Ascii("yzabler"),
        dictgen::InsensitiveStr::Ascii("yzables"),
        dictgen::InsensitiveStr::Ascii("yzablest"),
        dictgen::InsensitiveStr::Ascii("yzate"),
        dictgen::InsensitiveStr::Ascii("yzates"),
        dictgen::InsensitiveStr::Ascii("yzation"),
        dictgen::InsensitiveStr::Ascii("yze"),
        dictgen::InsensitiveStr::Ascii("yzed"),
        dictgen::InsensitiveStr::Ascii("yzer"),
        dictgen::InsensitiveStr::Ascii("yzers"),
        dictgen::InsensitiveStr::Ascii("yzes"),
        dictgen::InsensitiveStr::Ascii("yzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIALECTICIZE_2204671560565196577)],
        &[(0b10010, &ENTRY_DIALECTICIZES_3201740277613515360)],
        &[(0b01001, &ENTRY_DIALECTICIZE_2204671560565196577)],
        &[(0b01001, &ENTRY_DIALECTICIZES_3201740277613515360)],
        &[(0b01001, &ENTRY_DIALED_12445554267564800284)],
        &[(0b00001, &ENTRY_DIALER_4550505305630586540)],
        &[(0b00001, &ENTRY_DIALERS_5602259152205050826)],
        &[(0b01001, &ENTRY_DIALING_15825922980741414813)],
        &[(0b01001, &ENTRY_DIALINGS_4797662219825576657)],
        &[(0b00001, &ENTRY_DIALIST_8678208478430149150)],
        &[(0b00001, &ENTRY_DIALISTS_17620866403243878741)],
        &[(0b11010, &ENTRY_DIALED_12445554267564800284)],
        &[(0b11010, &ENTRY_DIALER_4550505305630586540)],
        &[(0b11010, &ENTRY_DIALERS_5602259152205050826)],
        &[(0b11010, &ENTRY_DIALING_15825922980741414813)],
        &[(0b11010, &ENTRY_DIALINGS_4797662219825576657)],
        &[(0b11010, &ENTRY_DIALIST_8678208478430149150)],
        &[(0b11010, &ENTRY_DIALISTS_17620866403243878741)],
        &[(0b00001, &ENTRY_DIALOGUED_1860543501002215986)],
        &[(0b00001, &ENTRY_DIALOGUING_14221452045191699395)],
        &[(0b10010, &ENTRY_DIALOGIZE_3147664435711992783)],
        &[(0b10010, &ENTRY_DIALOGIZED_16517368637953000442)],
        &[(0b10010, &ENTRY_DIALOGIZES_10946689184118338197)],
        &[(0b10010, &ENTRY_DIALOGIZING_10876002085618537096)],
        &[(0b01001, &ENTRY_DIALOGIZE_3147664435711992783)],
        &[(0b01001, &ENTRY_DIALOGIZED_16517368637953000442)],
        &[(0b01001, &ENTRY_DIALOGIZES_10946689184118338197)],
        &[(0b01001, &ENTRY_DIALOGIZING_10876002085618537096)],
        &[(0b00001, &ENTRY_DIALOGUES_11157018411024684853)],
        &[(0b11010, &ENTRY_DIALYZABILITIES_16919452053444132964)],
        &[(0b11010, &ENTRY_DIALYZABILITY_2385882814800744278)],
        &[(0b11010, &ENTRY_DIALYZABLE_4481317071046410548)],
        &[(0b11010, &ENTRY_DIALYZABLER_2950437622828839578)],
        &[(0b11010, &ENTRY_DIALYZABLES_15000950498086971159)],
        &[(0b11010, &ENTRY_DIALYZABLEST_10251547193383432771)],
        &[(0b10010, &ENTRY_DIALYZATE_847425955284979672)],
        &[(0b10010, &ENTRY_DIALYZATES_16159553587347789538)],
        &[(0b10010, &ENTRY_DIALYZATION_14569182709416219304)],
        &[(0b10010, &ENTRY_DIALYZE_6329229259949071274)],
        &[(0b10010, &ENTRY_DIALYZED_1600178824809360907)],
        &[(0b10010, &ENTRY_DIALYZER_7774506769012694605)],
        &[(0b10010, &ENTRY_DIALYZERS_11623550947622716911)],
        &[(0b10010, &ENTRY_DIALYZING_4945836046675013341)],
        &[(0b00001, &ENTRY_DIALYZABILITIES_16919452053444132964)],
        &[(0b00001, &ENTRY_DIALYZABILITY_2385882814800744278)],
        &[(0b00001, &ENTRY_DIALYZABLE_4481317071046410548)],
        &[(0b00001, &ENTRY_DIALYZABLER_2950437622828839578)],
        &[(0b00001, &ENTRY_DIALYZABLES_15000950498086971159)],
        &[(0b00001, &ENTRY_DIALYZABLEST_10251547193383432771)],
        &[(0b01001, &ENTRY_DIALYZATE_847425955284979672)],
        &[(0b01001, &ENTRY_DIALYZATES_16159553587347789538)],
        &[(0b01001, &ENTRY_DIALYZATION_14569182709416219304)],
        &[(0b01001, &ENTRY_DIALYZE_6329229259949071274)],
        &[(0b01001, &ENTRY_DIALYZED_1600178824809360907)],
        &[(0b01001, &ENTRY_DIALYZER_7774506769012694605)],
        &[(0b01001, &ENTRY_DIALYZERS_11623550947622716911)],
        &[(0b01001, &ENTRY_DIALYZES_9413207522578141113)],
        &[(0b01001, &ENTRY_DIALYZING_4945836046675013341)],
    ],
    range: 2..=11,
};

static VARS_DIAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAG_CHILDREN),
    value: None,
};

pub static VARS_DIAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onalisable"),
        dictgen::InsensitiveStr::Ascii("onalisation"),
        dictgen::InsensitiveStr::Ascii("onalise"),
        dictgen::InsensitiveStr::Ascii("onalised"),
        dictgen::InsensitiveStr::Ascii("onalises"),
        dictgen::InsensitiveStr::Ascii("onalising"),
        dictgen::InsensitiveStr::Ascii("onalizable"),
        dictgen::InsensitiveStr::Ascii("onalization"),
        dictgen::InsensitiveStr::Ascii("onalize"),
        dictgen::InsensitiveStr::Ascii("onalized"),
        dictgen::InsensitiveStr::Ascii("onalizes"),
        dictgen::InsensitiveStr::Ascii("onalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIAGONALIZABLE_10977422841248602526)],
        &[(0b10010, &ENTRY_DIAGONALIZATION_17906612353739944122)],
        &[(0b10010, &ENTRY_DIAGONALIZE_17545470866818361268)],
        &[(0b10010, &ENTRY_DIAGONALIZED_16278489065750351065)],
        &[(0b10010, &ENTRY_DIAGONALIZES_15436394800752209539)],
        &[(0b10010, &ENTRY_DIAGONALIZING_14520835686620115538)],
        &[(0b01001, &ENTRY_DIAGONALIZABLE_10977422841248602526)],
        &[(0b01001, &ENTRY_DIAGONALIZATION_17906612353739944122)],
        &[(0b01001, &ENTRY_DIAGONALIZE_17545470866818361268)],
        &[(0b01001, &ENTRY_DIAGONALIZED_16278489065750351065)],
        &[(0b01001, &ENTRY_DIAGONALIZES_15436394800752209539)],
        &[(0b01001, &ENTRY_DIAGONALIZING_14520835686620115538)],
    ],
    range: 7..=11,
};

static VARS_DIAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAE_CHILDREN),
    value: None,
};

pub static VARS_DIAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("retic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DIENE_8393408286309594192)],
        &[(0b11010, &ENTRY_DIERETIC_13830183413584247379)],
    ],
    range: 2..=5,
};

static VARS_DIAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DIAB_CHILDREN),
    value: None,
};

pub static VARS_DIAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olisations"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olizations"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DIABOLIZATION_8147427661526738727)],
        &[(0b10010, &ENTRY_DIABOLIZATIONS_3822742467764077320)],
        &[(0b10010, &ENTRY_DIABOLIZE_13327939806411873396)],
        &[(0b10010, &ENTRY_DIABOLIZED_5121441305555041821)],
        &[(0b10010, &ENTRY_DIABOLIZES_6289744568368918053)],
        &[(0b10010, &ENTRY_DIABOLIZING_17353660640060220296)],
        &[(0b01001, &ENTRY_DIABOLIZATION_8147427661526738727)],
        &[(0b01001, &ENTRY_DIABOLIZATIONS_3822742467764077320)],
        &[(0b01001, &ENTRY_DIABOLIZE_13327939806411873396)],
        &[(0b01001, &ENTRY_DIABOLIZED_5121441305555041821)],
        &[(0b01001, &ENTRY_DIABOLIZES_6289744568368918053)],
        &[(0b01001, &ENTRY_DIABOLIZING_17353660640060220296)],
    ],
    range: 5..=10,
};

static VARS_DE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DE_CHILDREN),
    value: None,
};

static VARS_DE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DEA_NODE),
    None,
    Some(&VARS_DEC_NODE),
    Some(&VARS_DED_NODE),
    Some(&VARS_DEE_NODE),
    Some(&VARS_DEF_NODE),
    Some(&VARS_DEG_NODE),
    Some(&VARS_DEH_NODE),
    Some(&VARS_DEI_NODE),
    None,
    Some(&VARS_DEK_NODE),
    Some(&VARS_DEL_NODE),
    Some(&VARS_DEM_NODE),
    Some(&VARS_DEN_NODE),
    Some(&VARS_DEO_NODE),
    Some(&VARS_DEP_NODE),
    None,
    Some(&VARS_DER_NODE),
    Some(&VARS_DES_NODE),
    Some(&VARS_DET_NODE),
    None,
    Some(&VARS_DEV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_DEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEV_CHILDREN),
    value: None,
};

pub static VARS_DEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("alorisation"),
        dictgen::InsensitiveStr::Ascii("alorisations"),
        dictgen::InsensitiveStr::Ascii("alorise"),
        dictgen::InsensitiveStr::Ascii("alorised"),
        dictgen::InsensitiveStr::Ascii("alorises"),
        dictgen::InsensitiveStr::Ascii("alorising"),
        dictgen::InsensitiveStr::Ascii("alorization"),
        dictgen::InsensitiveStr::Ascii("alorizations"),
        dictgen::InsensitiveStr::Ascii("alorize"),
        dictgen::InsensitiveStr::Ascii("alorized"),
        dictgen::InsensitiveStr::Ascii("alorizes"),
        dictgen::InsensitiveStr::Ascii("alorizing"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("iled"),
        dictgen::InsensitiveStr::Ascii("iling"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("illed"),
        dictgen::InsensitiveStr::Ascii("illing"),
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italisations"),
        dictgen::InsensitiveStr::Ascii("italise"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italises"),
        dictgen::InsensitiveStr::Ascii("italising"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italizations"),
        dictgen::InsensitiveStr::Ascii("italize"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizes"),
        dictgen::InsensitiveStr::Ascii("italizing"),
        dictgen::InsensitiveStr::Ascii("ocalisation"),
        dictgen::InsensitiveStr::Ascii("ocalise"),
        dictgen::InsensitiveStr::Ascii("ocalised"),
        dictgen::InsensitiveStr::Ascii("ocalises"),
        dictgen::InsensitiveStr::Ascii("ocalising"),
        dictgen::InsensitiveStr::Ascii("ocalization"),
        dictgen::InsensitiveStr::Ascii("ocalize"),
        dictgen::InsensitiveStr::Ascii("ocalized"),
        dictgen::InsensitiveStr::Ascii("ocalizes"),
        dictgen::InsensitiveStr::Ascii("ocalizing"),
        dictgen::InsensitiveStr::Ascii("olatilisation"),
        dictgen::InsensitiveStr::Ascii("olatilisations"),
        dictgen::InsensitiveStr::Ascii("olatilise"),
        dictgen::InsensitiveStr::Ascii("olatilised"),
        dictgen::InsensitiveStr::Ascii("olatilises"),
        dictgen::InsensitiveStr::Ascii("olatilising"),
        dictgen::InsensitiveStr::Ascii("olatilization"),
        dictgen::InsensitiveStr::Ascii("olatilizations"),
        dictgen::InsensitiveStr::Ascii("olatilize"),
        dictgen::InsensitiveStr::Ascii("olatilized"),
        dictgen::InsensitiveStr::Ascii("olatilizes"),
        dictgen::InsensitiveStr::Ascii("olatilizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DEVA_18303315502243076060)],
        &[(0b10010, &ENTRY_DEVALORIZATION_15315014812840888413)],
        &[(0b10010, &ENTRY_DEVALORIZATIONS_12670639433164026734)],
        &[(0b10010, &ENTRY_DEVALORIZE_10794559313991782118)],
        &[(0b10010, &ENTRY_DEVALORIZED_10544100609075377554)],
        &[(0b10010, &ENTRY_DEVALORIZES_4580727997112987764)],
        &[(0b10010, &ENTRY_DEVALORIZING_745754966056062243)],
        &[(0b01001, &ENTRY_DEVALORIZATION_15315014812840888413)],
        &[(0b01001, &ENTRY_DEVALORIZATIONS_12670639433164026734)],
        &[(0b01001, &ENTRY_DEVALORIZE_10794559313991782118)],
        &[(0b01001, &ENTRY_DEVALORIZED_10544100609075377554)],
        &[(0b01001, &ENTRY_DEVALORIZES_4580727997112987764)],
        &[(0b01001, &ENTRY_DEVALORIZING_745754966056062243)],
        &[(0b00001, &ENTRY_DEVELED_13710518174394409286)],
        &[(0b00001, &ENTRY_DEVELING_8091139982686168573)],
        &[(0b11010, &ENTRY_DEVELED_13710518174394409286)],
        &[(0b11010, &ENTRY_DEVELING_8091139982686168573)],
        &[(0b00001, &ENTRY_DEVILED_13014517801589922329)],
        &[(0b00001, &ENTRY_DEVILING_6936097926436525993)],
        &[(0b10010, &ENTRY_DEVILIZE_9795464369905562385)],
        &[(0b10010, &ENTRY_DEVILIZES_17745578183045333673)],
        &[(0b01001, &ENTRY_DEVILIZE_9795464369905562385)],
        &[(0b01001, &ENTRY_DEVILIZES_17745578183045333673)],
        &[(0b11010, &ENTRY_DEVILED_13014517801589922329)],
        &[(0b11010, &ENTRY_DEVILING_6936097926436525993)],
        &[(0b10010, &ENTRY_DEVITALIZATION_2114332477720992030)],
        &[(0b10010, &ENTRY_DEVITALIZATIONS_13354425441260498778)],
        &[(0b10010, &ENTRY_DEVITALIZE_1043658353870554736)],
        &[(0b10010, &ENTRY_DEVITALIZED_8717395560461798050)],
        &[(0b10010, &ENTRY_DEVITALIZES_9074596952558116656)],
        &[(0b10010, &ENTRY_DEVITALIZING_14131643871253145067)],
        &[(0b01001, &ENTRY_DEVITALIZATION_2114332477720992030)],
        &[(0b01001, &ENTRY_DEVITALIZATIONS_13354425441260498778)],
        &[(0b01001, &ENTRY_DEVITALIZE_1043658353870554736)],
        &[(0b01001, &ENTRY_DEVITALIZED_8717395560461798050)],
        &[(0b01001, &ENTRY_DEVITALIZES_9074596952558116656)],
        &[(0b01001, &ENTRY_DEVITALIZING_14131643871253145067)],
        &[(0b10010, &ENTRY_DEVOCALIZATION_10444917076714233126)],
        &[(0b10010, &ENTRY_DEVOCALIZE_1529649237001829017)],
        &[(0b10010, &ENTRY_DEVOCALIZED_16555396131330717996)],
        &[(0b10010, &ENTRY_DEVOCALIZES_11452435934127095123)],
        &[(0b10010, &ENTRY_DEVOCALIZING_540893798000083473)],
        &[(0b01001, &ENTRY_DEVOCALIZATION_10444917076714233126)],
        &[(0b01001, &ENTRY_DEVOCALIZE_1529649237001829017)],
        &[(0b01001, &ENTRY_DEVOCALIZED_16555396131330717996)],
        &[(0b01001, &ENTRY_DEVOCALIZES_11452435934127095123)],
        &[(0b01001, &ENTRY_DEVOCALIZING_540893798000083473)],
        &[(0b10010, &ENTRY_DEVOLATILIZATION_4689429575223597286)],
        &[(0b10010, &ENTRY_DEVOLATILIZATIONS_4707574596121848991)],
        &[(0b10010, &ENTRY_DEVOLATILIZE_11441006506088892627)],
        &[(0b10010, &ENTRY_DEVOLATILIZED_507035959515124086)],
        &[(0b10010, &ENTRY_DEVOLATILIZES_8071137154044730701)],
        &[(0b10010, &ENTRY_DEVOLATILIZING_9726618714956110506)],
        &[(0b01001, &ENTRY_DEVOLATILIZATION_4689429575223597286)],
        &[(0b01001, &ENTRY_DEVOLATILIZATIONS_4707574596121848991)],
        &[(0b01001, &ENTRY_DEVOLATILIZE_11441006506088892627)],
        &[(0b01001, &ENTRY_DEVOLATILIZED_507035959515124086)],
        &[(0b01001, &ENTRY_DEVOLATILIZES_8071137154044730701)],
        &[(0b01001, &ENTRY_DEVOLATILIZING_9726618714956110506)],
    ],
    range: 1..=14,
};

static VARS_DET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DET_CHILDREN),
    value: None,
};

pub static VARS_DET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ribalisation"),
        dictgen::InsensitiveStr::Ascii("ribalisations"),
        dictgen::InsensitiveStr::Ascii("ribalise"),
        dictgen::InsensitiveStr::Ascii("ribalised"),
        dictgen::InsensitiveStr::Ascii("ribalises"),
        dictgen::InsensitiveStr::Ascii("ribalising"),
        dictgen::InsensitiveStr::Ascii("ribalization"),
        dictgen::InsensitiveStr::Ascii("ribalizations"),
        dictgen::InsensitiveStr::Ascii("ribalize"),
        dictgen::InsensitiveStr::Ascii("ribalized"),
        dictgen::InsensitiveStr::Ascii("ribalizes"),
        dictgen::InsensitiveStr::Ascii("ribalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DETRIBALIZATION_16952730237997981409)],
        &[(0b10010, &ENTRY_DETRIBALIZATIONS_11756828771994817312)],
        &[(0b10010, &ENTRY_DETRIBALIZE_15143242476306432587)],
        &[(0b10010, &ENTRY_DETRIBALIZED_7286047575373525196)],
        &[(0b10010, &ENTRY_DETRIBALIZES_17667503652444099945)],
        &[(0b10010, &ENTRY_DETRIBALIZING_12535699864595434298)],
        &[(0b01001, &ENTRY_DETRIBALIZATION_16952730237997981409)],
        &[(0b01001, &ENTRY_DETRIBALIZATIONS_11756828771994817312)],
        &[(0b01001, &ENTRY_DETRIBALIZE_15143242476306432587)],
        &[(0b01001, &ENTRY_DETRIBALIZED_7286047575373525196)],
        &[(0b01001, &ENTRY_DETRIBALIZES_17667503652444099945)],
        &[(0b01001, &ENTRY_DETRIBALIZING_12535699864595434298)],
    ],
    range: 8..=13,
};

static VARS_DES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DES_CHILDREN),
    value: None,
};

static VARS_DES_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DESA_NODE),
    None,
    Some(&VARS_DESC_NODE),
    None,
    Some(&VARS_DESE_NODE),
    None,
    None,
    None,
    Some(&VARS_DESI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DESP_NODE),
    None,
    None,
    None,
    Some(&VARS_DEST_NODE),
    Some(&VARS_DESU_NODE),
    None,
    None,
    None,
    Some(&VARS_DESY_NODE),
    None,
];

static VARS_DESY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESY_CHILDREN),
    value: None,
};

pub static VARS_DESY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nchronisation"),
        dictgen::InsensitiveStr::Ascii("nchronisations"),
        dictgen::InsensitiveStr::Ascii("nchronise"),
        dictgen::InsensitiveStr::Ascii("nchronised"),
        dictgen::InsensitiveStr::Ascii("nchronises"),
        dictgen::InsensitiveStr::Ascii("nchronising"),
        dictgen::InsensitiveStr::Ascii("nchronization"),
        dictgen::InsensitiveStr::Ascii("nchronizations"),
        dictgen::InsensitiveStr::Ascii("nchronize"),
        dictgen::InsensitiveStr::Ascii("nchronized"),
        dictgen::InsensitiveStr::Ascii("nchronizes"),
        dictgen::InsensitiveStr::Ascii("nchronizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESYNCHRONIZATION_15934272175464625660)],
        &[(0b10010, &ENTRY_DESYNCHRONIZATIONS_8142294090130517034)],
        &[(0b10010, &ENTRY_DESYNCHRONIZE_8943647682721253433)],
        &[(0b10010, &ENTRY_DESYNCHRONIZED_13365058336037754735)],
        &[(0b10010, &ENTRY_DESYNCHRONIZES_3997067564763019035)],
        &[(0b10010, &ENTRY_DESYNCHRONIZING_15189349053662354180)],
        &[(0b01001, &ENTRY_DESYNCHRONIZATION_15934272175464625660)],
        &[(0b01001, &ENTRY_DESYNCHRONIZATIONS_8142294090130517034)],
        &[(0b01001, &ENTRY_DESYNCHRONIZE_8943647682721253433)],
        &[(0b01001, &ENTRY_DESYNCHRONIZED_13365058336037754735)],
        &[(0b01001, &ENTRY_DESYNCHRONIZES_3997067564763019035)],
        &[(0b01001, &ENTRY_DESYNCHRONIZING_15189349053662354180)],
    ],
    range: 9..=14,
};

static VARS_DESU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESU_CHILDREN),
    value: None,
};

pub static VARS_DESU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lfuriser"),
        dictgen::InsensitiveStr::Ascii("lfurization"),
        dictgen::InsensitiveStr::Ascii("lfurizations"),
        dictgen::InsensitiveStr::Ascii("lfurize"),
        dictgen::InsensitiveStr::Ascii("lfurized"),
        dictgen::InsensitiveStr::Ascii("lfurizer"),
        dictgen::InsensitiveStr::Ascii("lfurizes"),
        dictgen::InsensitiveStr::Ascii("lfurizing"),
        dictgen::InsensitiveStr::Ascii("lphurisation"),
        dictgen::InsensitiveStr::Ascii("lphurisations"),
        dictgen::InsensitiveStr::Ascii("lphurise"),
        dictgen::InsensitiveStr::Ascii("lphurised"),
        dictgen::InsensitiveStr::Ascii("lphuriser"),
        dictgen::InsensitiveStr::Ascii("lphurisers"),
        dictgen::InsensitiveStr::Ascii("lphurises"),
        dictgen::InsensitiveStr::Ascii("lphurising"),
        dictgen::InsensitiveStr::Ascii("lphurization"),
        dictgen::InsensitiveStr::Ascii("lphurizations"),
        dictgen::InsensitiveStr::Ascii("lphurize"),
        dictgen::InsensitiveStr::Ascii("lphurized"),
        dictgen::InsensitiveStr::Ascii("lphurizer"),
        dictgen::InsensitiveStr::Ascii("lphurizers"),
        dictgen::InsensitiveStr::Ascii("lphurizes"),
        dictgen::InsensitiveStr::Ascii("lphurizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESULFURIZER_5734678686912127702)],
        &[(0b00001, &ENTRY_DESULFURIZATION_10145479217290079220)],
        &[(0b00001, &ENTRY_DESULFURIZATIONS_14861998503665123704)],
        &[(0b00001, &ENTRY_DESULFURIZE_12876573712862714533)],
        &[(0b00001, &ENTRY_DESULFURIZED_1535371682591396877)],
        &[(0b01001, &ENTRY_DESULFURIZER_5734678686912127702)],
        &[(0b00001, &ENTRY_DESULFURIZES_1197207125684665875)],
        &[(0b00001, &ENTRY_DESULFURIZING_7858975859555627847)],
        &[(0b10010, &ENTRY_DESULFURIZATION_10145479217290079220)],
        &[(0b10010, &ENTRY_DESULFURIZATIONS_14861998503665123704)],
        &[(0b10010, &ENTRY_DESULFURIZE_12876573712862714533)],
        &[(0b10010, &ENTRY_DESULFURIZED_1535371682591396877)],
        &[(0b10010, &ENTRY_DESULPHURIZER_10137789356803923951)],
        &[(0b10010, &ENTRY_DESULPHURIZERS_282853998000810658)],
        &[(0b10010, &ENTRY_DESULFURIZES_1197207125684665875)],
        &[(0b10010, &ENTRY_DESULFURIZING_7858975859555627847)],
        &[(0b01000, &ENTRY_DESULFURIZATION_10145479217290079220)],
        &[(0b01000, &ENTRY_DESULFURIZATIONS_14861998503665123704)],
        &[(0b01000, &ENTRY_DESULFURIZE_12876573712862714533)],
        &[(0b01000, &ENTRY_DESULFURIZED_1535371682591396877)],
        &[(0b01001, &ENTRY_DESULPHURIZER_10137789356803923951)],
        &[(0b01001, &ENTRY_DESULPHURIZERS_282853998000810658)],
        &[(0b01000, &ENTRY_DESULFURIZES_1197207125684665875)],
        &[(0b01000, &ENTRY_DESULFURIZING_7858975859555627847)],
    ],
    range: 7..=13,
};

static VARS_DEST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEST_CHILDREN),
    value: None,
};

pub static VARS_DEST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abilisation"),
        dictgen::InsensitiveStr::Ascii("abilise"),
        dictgen::InsensitiveStr::Ascii("abilised"),
        dictgen::InsensitiveStr::Ascii("abiliser"),
        dictgen::InsensitiveStr::Ascii("abilisers"),
        dictgen::InsensitiveStr::Ascii("abilises"),
        dictgen::InsensitiveStr::Ascii("abilising"),
        dictgen::InsensitiveStr::Ascii("abilization"),
        dictgen::InsensitiveStr::Ascii("abilize"),
        dictgen::InsensitiveStr::Ascii("abilized"),
        dictgen::InsensitiveStr::Ascii("abilizer"),
        dictgen::InsensitiveStr::Ascii("abilizers"),
        dictgen::InsensitiveStr::Ascii("abilizes"),
        dictgen::InsensitiveStr::Ascii("abilizing"),
        dictgen::InsensitiveStr::Ascii("alinise"),
        dictgen::InsensitiveStr::Ascii("alinised"),
        dictgen::InsensitiveStr::Ascii("alinises"),
        dictgen::InsensitiveStr::Ascii("alinising"),
        dictgen::InsensitiveStr::Ascii("alinize"),
        dictgen::InsensitiveStr::Ascii("alinized"),
        dictgen::InsensitiveStr::Ascii("alinizes"),
        dictgen::InsensitiveStr::Ascii("alinizing"),
        dictgen::InsensitiveStr::Ascii("erilise"),
        dictgen::InsensitiveStr::Ascii("erilize"),
        dictgen::InsensitiveStr::Ascii("igmatisation"),
        dictgen::InsensitiveStr::Ascii("igmatization"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESTABILIZATION_14326190546524052452)],
        &[(0b10010, &ENTRY_DESTABILIZE_5513808993828420574)],
        &[(0b10010, &ENTRY_DESTABILIZED_1777832444349565509)],
        &[(0b10010, &ENTRY_DESTABILIZER_5486156107617069595)],
        &[(0b10010, &ENTRY_DESTABILIZERS_6141576176215173386)],
        &[(0b10010, &ENTRY_DESTABILIZES_13491486327241590151)],
        &[(0b10010, &ENTRY_DESTABILIZING_10660910526175900618)],
        &[(0b01001, &ENTRY_DESTABILIZATION_14326190546524052452)],
        &[(0b01001, &ENTRY_DESTABILIZE_5513808993828420574)],
        &[(0b01001, &ENTRY_DESTABILIZED_1777832444349565509)],
        &[(0b01001, &ENTRY_DESTABILIZER_5486156107617069595)],
        &[(0b01001, &ENTRY_DESTABILIZERS_6141576176215173386)],
        &[(0b01001, &ENTRY_DESTABILIZES_13491486327241590151)],
        &[(0b01001, &ENTRY_DESTABILIZING_10660910526175900618)],
        &[(0b10010, &ENTRY_DESTALINIZE_9557464174451415418)],
        &[(0b10010, &ENTRY_DESTALINIZED_9729731297639277285)],
        &[(0b10010, &ENTRY_DESTALINIZES_5575846993066512172)],
        &[(0b10010, &ENTRY_DESTALINIZING_365060634953959661)],
        &[(0b01001, &ENTRY_DESTALINIZE_9557464174451415418)],
        &[(0b01001, &ENTRY_DESTALINIZED_9729731297639277285)],
        &[(0b01001, &ENTRY_DESTALINIZES_5575846993066512172)],
        &[(0b01001, &ENTRY_DESTALINIZING_365060634953959661)],
        &[(0b10010, &ENTRY_DESTERILIZE_10235095546341603640)],
        &[(0b01001, &ENTRY_DESTERILIZE_10235095546341603640)],
        &[(0b10010, &ENTRY_DESTIGMATIZATION_76784710048289446)],
        &[(0b01001, &ENTRY_DESTIGMATIZATION_76784710048289446)],
    ],
    range: 7..=12,
};

static VARS_DESP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESP_CHILDREN),
    value: None,
};

pub static VARS_DESP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atch"),
        dictgen::InsensitiveStr::Ascii("atched"),
        dictgen::InsensitiveStr::Ascii("atches"),
        dictgen::InsensitiveStr::Ascii("atching"),
        dictgen::InsensitiveStr::Ascii("iritualisation"),
        dictgen::InsensitiveStr::Ascii("iritualise"),
        dictgen::InsensitiveStr::Ascii("iritualization"),
        dictgen::InsensitiveStr::Ascii("iritualize"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otizes"),
    ],
    values: &[
        &[(0b10011, &ENTRY_DISPATCH_4830799078943953115)],
        &[(0b10011, &ENTRY_DISPATCHED_15382141028599285955)],
        &[(0b10011, &ENTRY_DISPATCHES_13572237410774142362)],
        &[(0b10011, &ENTRY_DISPATCHING_13590867743632657867)],
        &[(0b10010, &ENTRY_DESPIRITUALIZATION_9440879345640859842)],
        &[(0b10010, &ENTRY_DESPIRITUALIZE_18226118672475753223)],
        &[(0b01001, &ENTRY_DESPIRITUALIZATION_9440879345640859842)],
        &[(0b01001, &ENTRY_DESPIRITUALIZE_18226118672475753223)],
        &[(0b10010, &ENTRY_DESPOTIZE_7875765767418230550)],
        &[(0b10010, &ENTRY_DESPOTIZES_5251286731168770044)],
        &[(0b01001, &ENTRY_DESPOTIZE_7875765767418230550)],
        &[(0b01001, &ENTRY_DESPOTIZES_5251286731168770044)],
    ],
    range: 4..=14,
};

static VARS_DESI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESI_CHILDREN),
    value: None,
};

pub static VARS_DESI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lverisation"),
        dictgen::InsensitiveStr::Ascii("lverisations"),
        dictgen::InsensitiveStr::Ascii("lverise"),
        dictgen::InsensitiveStr::Ascii("lverised"),
        dictgen::InsensitiveStr::Ascii("lverises"),
        dictgen::InsensitiveStr::Ascii("lverising"),
        dictgen::InsensitiveStr::Ascii("lverization"),
        dictgen::InsensitiveStr::Ascii("lverizations"),
        dictgen::InsensitiveStr::Ascii("lverize"),
        dictgen::InsensitiveStr::Ascii("lverized"),
        dictgen::InsensitiveStr::Ascii("lverizes"),
        dictgen::InsensitiveStr::Ascii("lverizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESILVERIZATION_7083077588146441964)],
        &[(0b10010, &ENTRY_DESILVERIZATIONS_3476812538372816382)],
        &[(0b10010, &ENTRY_DESILVERIZE_6336096088586818504)],
        &[(0b10010, &ENTRY_DESILVERIZED_16070622223837559170)],
        &[(0b10010, &ENTRY_DESILVERIZES_557243620662112813)],
        &[(0b10010, &ENTRY_DESILVERIZING_13130813397466342155)],
        &[(0b01001, &ENTRY_DESILVERIZATION_7083077588146441964)],
        &[(0b01001, &ENTRY_DESILVERIZATIONS_3476812538372816382)],
        &[(0b01001, &ENTRY_DESILVERIZE_6336096088586818504)],
        &[(0b01001, &ENTRY_DESILVERIZED_16070622223837559170)],
        &[(0b01001, &ENTRY_DESILVERIZES_557243620662112813)],
        &[(0b01001, &ENTRY_DESILVERIZING_13130813397466342155)],
    ],
    range: 7..=12,
};

static VARS_DESE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESE_CHILDREN),
    value: None,
};

pub static VARS_DESE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nsitisation"),
        dictgen::InsensitiveStr::Ascii("nsitisations"),
        dictgen::InsensitiveStr::Ascii("nsitise"),
        dictgen::InsensitiveStr::Ascii("nsitised"),
        dictgen::InsensitiveStr::Ascii("nsitiser"),
        dictgen::InsensitiveStr::Ascii("nsitisers"),
        dictgen::InsensitiveStr::Ascii("nsitises"),
        dictgen::InsensitiveStr::Ascii("nsitising"),
        dictgen::InsensitiveStr::Ascii("nsitization"),
        dictgen::InsensitiveStr::Ascii("nsitizations"),
        dictgen::InsensitiveStr::Ascii("nsitize"),
        dictgen::InsensitiveStr::Ascii("nsitized"),
        dictgen::InsensitiveStr::Ascii("nsitizer"),
        dictgen::InsensitiveStr::Ascii("nsitizers"),
        dictgen::InsensitiveStr::Ascii("nsitizes"),
        dictgen::InsensitiveStr::Ascii("nsitizing"),
        dictgen::InsensitiveStr::Ascii("rtisation"),
        dictgen::InsensitiveStr::Ascii("rtisations"),
        dictgen::InsensitiveStr::Ascii("rtization"),
        dictgen::InsensitiveStr::Ascii("rtizations"),
        dictgen::InsensitiveStr::Ascii("xualisation"),
        dictgen::InsensitiveStr::Ascii("xualisations"),
        dictgen::InsensitiveStr::Ascii("xualise"),
        dictgen::InsensitiveStr::Ascii("xualised"),
        dictgen::InsensitiveStr::Ascii("xualises"),
        dictgen::InsensitiveStr::Ascii("xualising"),
        dictgen::InsensitiveStr::Ascii("xualization"),
        dictgen::InsensitiveStr::Ascii("xualizations"),
        dictgen::InsensitiveStr::Ascii("xualize"),
        dictgen::InsensitiveStr::Ascii("xualized"),
        dictgen::InsensitiveStr::Ascii("xualizes"),
        dictgen::InsensitiveStr::Ascii("xualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESENSITIZATION_12566365864470462238)],
        &[(0b10010, &ENTRY_DESENSITIZATIONS_8251374796564084894)],
        &[(0b10010, &ENTRY_DESENSITIZE_3550903971648567607)],
        &[(0b10010, &ENTRY_DESENSITIZED_16642593456085222259)],
        &[(0b10010, &ENTRY_DESENSITIZER_6020988563376810609)],
        &[(0b10010, &ENTRY_DESENSITIZERS_14718511209845696977)],
        &[(0b10010, &ENTRY_DESENSITIZES_7107240430399068707)],
        &[(0b10010, &ENTRY_DESENSITIZING_16627131864153604352)],
        &[(0b01001, &ENTRY_DESENSITIZATION_12566365864470462238)],
        &[(0b01001, &ENTRY_DESENSITIZATIONS_8251374796564084894)],
        &[(0b01001, &ENTRY_DESENSITIZE_3550903971648567607)],
        &[(0b01001, &ENTRY_DESENSITIZED_16642593456085222259)],
        &[(0b01001, &ENTRY_DESENSITIZER_6020988563376810609)],
        &[(0b01001, &ENTRY_DESENSITIZERS_14718511209845696977)],
        &[(0b01001, &ENTRY_DESENSITIZES_7107240430399068707)],
        &[(0b01001, &ENTRY_DESENSITIZING_16627131864153604352)],
        &[(0b10010, &ENTRY_DESERTIZATION_14992284590814327365)],
        &[(0b10010, &ENTRY_DESERTIZATIONS_9614321958416784718)],
        &[(0b01001, &ENTRY_DESERTIZATION_14992284590814327365)],
        &[(0b01001, &ENTRY_DESERTIZATIONS_9614321958416784718)],
        &[(0b10010, &ENTRY_DESEXUALIZATION_7051669726674300306)],
        &[(0b10010, &ENTRY_DESEXUALIZATIONS_317703425355638040)],
        &[(0b10010, &ENTRY_DESEXUALIZE_4949470699070422167)],
        &[(0b10010, &ENTRY_DESEXUALIZED_709042860780979441)],
        &[(0b10010, &ENTRY_DESEXUALIZES_12483266755535786660)],
        &[(0b10010, &ENTRY_DESEXUALIZING_9440019274877492043)],
        &[(0b01001, &ENTRY_DESEXUALIZATION_7051669726674300306)],
        &[(0b01001, &ENTRY_DESEXUALIZATIONS_317703425355638040)],
        &[(0b01001, &ENTRY_DESEXUALIZE_4949470699070422167)],
        &[(0b01001, &ENTRY_DESEXUALIZED_709042860780979441)],
        &[(0b01001, &ENTRY_DESEXUALIZES_12483266755535786660)],
        &[(0b01001, &ENTRY_DESEXUALIZING_9440019274877492043)],
    ],
    range: 7..=12,
};

static VARS_DESC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESC_CHILDREN),
    value: None,
};

pub static VARS_DESC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("endents")],
    values: &[&[(0b00001, &ENTRY_DESCENDANTS_13592723156308791185)]],
    range: 7..=7,
};

static VARS_DESA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DESA_CHILDREN),
    value: None,
};

pub static VARS_DESA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cralisation"),
        dictgen::InsensitiveStr::Ascii("cralisations"),
        dictgen::InsensitiveStr::Ascii("cralise"),
        dictgen::InsensitiveStr::Ascii("cralised"),
        dictgen::InsensitiveStr::Ascii("cralises"),
        dictgen::InsensitiveStr::Ascii("cralising"),
        dictgen::InsensitiveStr::Ascii("cralization"),
        dictgen::InsensitiveStr::Ascii("cralizations"),
        dictgen::InsensitiveStr::Ascii("cralize"),
        dictgen::InsensitiveStr::Ascii("cralized"),
        dictgen::InsensitiveStr::Ascii("cralizes"),
        dictgen::InsensitiveStr::Ascii("cralizing"),
        dictgen::InsensitiveStr::Ascii("linisation"),
        dictgen::InsensitiveStr::Ascii("linisations"),
        dictgen::InsensitiveStr::Ascii("linise"),
        dictgen::InsensitiveStr::Ascii("linised"),
        dictgen::InsensitiveStr::Ascii("linises"),
        dictgen::InsensitiveStr::Ascii("linising"),
        dictgen::InsensitiveStr::Ascii("linization"),
        dictgen::InsensitiveStr::Ascii("linizations"),
        dictgen::InsensitiveStr::Ascii("linize"),
        dictgen::InsensitiveStr::Ascii("linized"),
        dictgen::InsensitiveStr::Ascii("linizes"),
        dictgen::InsensitiveStr::Ascii("linizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DESACRALIZATION_8933482512308094840)],
        &[(0b10010, &ENTRY_DESACRALIZATIONS_3159008120594250545)],
        &[(0b10010, &ENTRY_DESACRALIZE_2904720596855309711)],
        &[(0b10010, &ENTRY_DESACRALIZED_5172113800600262057)],
        &[(0b10010, &ENTRY_DESACRALIZES_3129397141770379489)],
        &[(0b10010, &ENTRY_DESACRALIZING_1923812032604675331)],
        &[(0b01001, &ENTRY_DESACRALIZATION_8933482512308094840)],
        &[(0b01001, &ENTRY_DESACRALIZATIONS_3159008120594250545)],
        &[(0b01001, &ENTRY_DESACRALIZE_2904720596855309711)],
        &[(0b01001, &ENTRY_DESACRALIZED_5172113800600262057)],
        &[(0b01001, &ENTRY_DESACRALIZES_3129397141770379489)],
        &[(0b01001, &ENTRY_DESACRALIZING_1923812032604675331)],
        &[(0b10010, &ENTRY_DESALINIZATION_3112141684596769008)],
        &[(0b10010, &ENTRY_DESALINIZATIONS_6688266856012610087)],
        &[(0b10010, &ENTRY_DESALINIZE_14106924193733250969)],
        &[(0b10010, &ENTRY_DESALINIZED_15785822948480949641)],
        &[(0b10010, &ENTRY_DESALINIZES_9833000153222176974)],
        &[(0b10010, &ENTRY_DESALINIZING_375221854324330696)],
        &[(0b01001, &ENTRY_DESALINIZATION_3112141684596769008)],
        &[(0b01001, &ENTRY_DESALINIZATIONS_6688266856012610087)],
        &[(0b01001, &ENTRY_DESALINIZE_14106924193733250969)],
        &[(0b01001, &ENTRY_DESALINIZED_15785822948480949641)],
        &[(0b01001, &ENTRY_DESALINIZES_9833000153222176974)],
        &[(0b01001, &ENTRY_DESALINIZING_375221854324330696)],
    ],
    range: 6..=12,
};

static VARS_DER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DER_CHILDREN),
    value: None,
};

pub static VARS_DER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("acialise"),
        dictgen::InsensitiveStr::Ascii("acialised"),
        dictgen::InsensitiveStr::Ascii("acialises"),
        dictgen::InsensitiveStr::Ascii("acialising"),
        dictgen::InsensitiveStr::Ascii("acialize"),
        dictgen::InsensitiveStr::Ascii("acialized"),
        dictgen::InsensitiveStr::Ascii("acializes"),
        dictgen::InsensitiveStr::Ascii("acializing"),
        dictgen::InsensitiveStr::Ascii("ationalisation"),
        dictgen::InsensitiveStr::Ascii("ationalisations"),
        dictgen::InsensitiveStr::Ascii("ationalise"),
        dictgen::InsensitiveStr::Ascii("ationalises"),
        dictgen::InsensitiveStr::Ascii("ationalization"),
        dictgen::InsensitiveStr::Ascii("ationalizations"),
        dictgen::InsensitiveStr::Ascii("ationalize"),
        dictgen::InsensitiveStr::Ascii("ationalizes"),
        dictgen::InsensitiveStr::Ascii("atisation"),
        dictgen::InsensitiveStr::Ascii("atisations"),
        dictgen::InsensitiveStr::Ascii("atization"),
        dictgen::InsensitiveStr::Ascii("atizations"),
        dictgen::InsensitiveStr::Ascii("ealisation"),
        dictgen::InsensitiveStr::Ascii("ealization"),
        dictgen::InsensitiveStr::Ascii("ecognise"),
        dictgen::InsensitiveStr::Ascii("ecognised"),
        dictgen::InsensitiveStr::Ascii("ecognises"),
        dictgen::InsensitiveStr::Ascii("ecognising"),
        dictgen::InsensitiveStr::Ascii("ecognize"),
        dictgen::InsensitiveStr::Ascii("ecognized"),
        dictgen::InsensitiveStr::Ascii("ecognizes"),
        dictgen::InsensitiveStr::Ascii("ecognizing"),
        dictgen::InsensitiveStr::Ascii("egulationise"),
        dictgen::InsensitiveStr::Ascii("egulationises"),
        dictgen::InsensitiveStr::Ascii("egulationize"),
        dictgen::InsensitiveStr::Ascii("egulationizes"),
        dictgen::InsensitiveStr::Ascii("eligionise"),
        dictgen::InsensitiveStr::Ascii("eligionised"),
        dictgen::InsensitiveStr::Ascii("eligionises"),
        dictgen::InsensitiveStr::Ascii("eligionising"),
        dictgen::InsensitiveStr::Ascii("eligionize"),
        dictgen::InsensitiveStr::Ascii("eligionized"),
        dictgen::InsensitiveStr::Ascii("eligionizes"),
        dictgen::InsensitiveStr::Ascii("eligionizing"),
        dictgen::InsensitiveStr::Ascii("k"),
        dictgen::InsensitiveStr::Ascii("matorrhea"),
        dictgen::InsensitiveStr::Ascii("matorrhoea"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DERACIALIZE_16127533532397871488)],
        &[(0b10010, &ENTRY_DERACIALIZED_13925986860775238916)],
        &[(0b10010, &ENTRY_DERACIALIZES_3059282447110218733)],
        &[(0b10010, &ENTRY_DERACIALIZING_14275754837816585059)],
        &[(0b01001, &ENTRY_DERACIALIZE_16127533532397871488)],
        &[(0b01001, &ENTRY_DERACIALIZED_13925986860775238916)],
        &[(0b01001, &ENTRY_DERACIALIZES_3059282447110218733)],
        &[(0b01001, &ENTRY_DERACIALIZING_14275754837816585059)],
        &[(0b10010, &ENTRY_DERATIONALIZATION_10528830942768591126)],
        &[(0b10010, &ENTRY_DERATIONALIZATIONS_17119655431636120190)],
        &[(0b10010, &ENTRY_DERATIONALIZE_2313042250140882971)],
        &[(0b10010, &ENTRY_DERATIONALIZES_3693097460338270754)],
        &[(0b01001, &ENTRY_DERATIONALIZATION_10528830942768591126)],
        &[(0b01001, &ENTRY_DERATIONALIZATIONS_17119655431636120190)],
        &[(0b01001, &ENTRY_DERATIONALIZE_2313042250140882971)],
        &[(0b01001, &ENTRY_DERATIONALIZES_3693097460338270754)],
        &[(0b10010, &ENTRY_DERATIZATION_1556052931660067306)],
        &[(0b10010, &ENTRY_DERATIZATIONS_2987948756893457504)],
        &[(0b01001, &ENTRY_DERATIZATION_1556052931660067306)],
        &[(0b01001, &ENTRY_DERATIZATIONS_2987948756893457504)],
        &[(0b10010, &ENTRY_DEREALIZATION_4431015585806198367)],
        &[(0b01001, &ENTRY_DEREALIZATION_4431015585806198367)],
        &[(0b10010, &ENTRY_DERECOGNIZE_12966064062970832050)],
        &[(0b10010, &ENTRY_DERECOGNIZED_10133422456568606840)],
        &[(0b10010, &ENTRY_DERECOGNIZES_2898686597965431739)],
        &[(0b10010, &ENTRY_DERECOGNIZING_15630007461435589758)],
        &[(0b01001, &ENTRY_DERECOGNIZE_12966064062970832050)],
        &[(0b01001, &ENTRY_DERECOGNIZED_10133422456568606840)],
        &[(0b01001, &ENTRY_DERECOGNIZES_2898686597965431739)],
        &[(0b01001, &ENTRY_DERECOGNIZING_15630007461435589758)],
        &[(0b10010, &ENTRY_DEREGULATIONIZE_4270787265190494422)],
        &[(0b10010, &ENTRY_DEREGULATIONIZES_10669971165971717976)],
        &[(0b01001, &ENTRY_DEREGULATIONIZE_4270787265190494422)],
        &[(0b01001, &ENTRY_DEREGULATIONIZES_10669971165971717976)],
        &[(0b10010, &ENTRY_DERELIGIONIZE_2197762790814142315)],
        &[(0b10010, &ENTRY_DERELIGIONIZED_12703552936820666292)],
        &[(0b10010, &ENTRY_DERELIGIONIZES_15734216747597028796)],
        &[(0b10010, &ENTRY_DERELIGIONIZING_5815795344545989827)],
        &[(0b01001, &ENTRY_DERELIGIONIZE_2197762790814142315)],
        &[(0b01001, &ENTRY_DERELIGIONIZED_12703552936820666292)],
        &[(0b01001, &ENTRY_DERELIGIONIZES_15734216747597028796)],
        &[(0b01001, &ENTRY_DERELIGIONIZING_5815795344545989827)],
        &[(0b00001, &ENTRY_DERK_4716671464297446249)],
        &[(0b10001, &ENTRY_DERMATORRHEA_1805754234241080569)],
        &[(0b11010, &ENTRY_DERMATORRHEA_1805754234241080569)],
        &[(0b00001, &ENTRY_DERR_8497357744990730455)],
    ],
    range: 1..=15,
};

static VARS_DEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEP_CHILDREN),
    value: None,
};

static VARS_DEP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DEPA_NODE),
    None,
    None,
    None,
    Some(&VARS_DEPE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEPO_NODE),
    None,
    None,
    Some(&VARS_DEPR_NODE),
    None,
    None,
    Some(&VARS_DEPU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DEPU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPU_CHILDREN),
    value: None,
};

pub static VARS_DEPU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tationise"),
        dictgen::InsensitiveStr::Ascii("tationises"),
        dictgen::InsensitiveStr::Ascii("tationize"),
        dictgen::InsensitiveStr::Ascii("tationizes"),
        dictgen::InsensitiveStr::Ascii("tisation"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tization"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEPUTATIONIZE_6925287050174299860)],
        &[(0b10010, &ENTRY_DEPUTATIONIZES_6787325415938091394)],
        &[(0b01001, &ENTRY_DEPUTATIONIZE_6925287050174299860)],
        &[(0b01001, &ENTRY_DEPUTATIONIZES_6787325415938091394)],
        &[(0b10010, &ENTRY_DEPUTIZATION_1712123122893688078)],
        &[(0b10010, &ENTRY_DEPUTIZE_2146946330988443787)],
        &[(0b10010, &ENTRY_DEPUTIZED_7193789182724757168)],
        &[(0b10010, &ENTRY_DEPUTIZES_11101760392402320280)],
        &[(0b10010, &ENTRY_DEPUTIZING_7923968930248772327)],
        &[(0b01001, &ENTRY_DEPUTIZATION_1712123122893688078)],
        &[(0b01001, &ENTRY_DEPUTIZE_2146946330988443787)],
        &[(0b01001, &ENTRY_DEPUTIZED_7193789182724757168)],
        &[(0b01001, &ENTRY_DEPUTIZES_11101760392402320280)],
        &[(0b01001, &ENTRY_DEPUTIZING_7923968930248772327)],
    ],
    range: 4..=10,
};

static VARS_DEPR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPR_CHILDREN),
    value: None,
};

pub static VARS_DEPR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("essurisation"),
        dictgen::InsensitiveStr::Ascii("essurisations"),
        dictgen::InsensitiveStr::Ascii("essurise"),
        dictgen::InsensitiveStr::Ascii("essurised"),
        dictgen::InsensitiveStr::Ascii("essurises"),
        dictgen::InsensitiveStr::Ascii("essurising"),
        dictgen::InsensitiveStr::Ascii("essurization"),
        dictgen::InsensitiveStr::Ascii("essurizations"),
        dictgen::InsensitiveStr::Ascii("essurize"),
        dictgen::InsensitiveStr::Ascii("essurized"),
        dictgen::InsensitiveStr::Ascii("essurizes"),
        dictgen::InsensitiveStr::Ascii("essurizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEPRESSURIZATION_8699831289105571367)],
        &[(0b10010, &ENTRY_DEPRESSURIZATIONS_11557965491679491854)],
        &[(0b10010, &ENTRY_DEPRESSURIZE_2580273134181372193)],
        &[(0b10010, &ENTRY_DEPRESSURIZED_590523559314456395)],
        &[(0b10010, &ENTRY_DEPRESSURIZES_9794647774856679413)],
        &[(0b10010, &ENTRY_DEPRESSURIZING_13641347976969899739)],
        &[(0b01001, &ENTRY_DEPRESSURIZATION_8699831289105571367)],
        &[(0b01001, &ENTRY_DEPRESSURIZATIONS_11557965491679491854)],
        &[(0b01001, &ENTRY_DEPRESSURIZE_2580273134181372193)],
        &[(0b01001, &ENTRY_DEPRESSURIZED_590523559314456395)],
        &[(0b01001, &ENTRY_DEPRESSURIZES_9794647774856679413)],
        &[(0b01001, &ENTRY_DEPRESSURIZING_13641347976969899739)],
    ],
    range: 8..=13,
};

static VARS_DEPO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPO_CHILDREN),
    value: None,
};

pub static VARS_DEPO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("larisation"),
        dictgen::InsensitiveStr::Ascii("larisations"),
        dictgen::InsensitiveStr::Ascii("larise"),
        dictgen::InsensitiveStr::Ascii("larised"),
        dictgen::InsensitiveStr::Ascii("lariser"),
        dictgen::InsensitiveStr::Ascii("larisers"),
        dictgen::InsensitiveStr::Ascii("larises"),
        dictgen::InsensitiveStr::Ascii("larising"),
        dictgen::InsensitiveStr::Ascii("larization"),
        dictgen::InsensitiveStr::Ascii("larizations"),
        dictgen::InsensitiveStr::Ascii("larize"),
        dictgen::InsensitiveStr::Ascii("larized"),
        dictgen::InsensitiveStr::Ascii("larizer"),
        dictgen::InsensitiveStr::Ascii("larizers"),
        dictgen::InsensitiveStr::Ascii("larizes"),
        dictgen::InsensitiveStr::Ascii("larizing"),
        dictgen::InsensitiveStr::Ascii("liticisation"),
        dictgen::InsensitiveStr::Ascii("liticise"),
        dictgen::InsensitiveStr::Ascii("liticised"),
        dictgen::InsensitiveStr::Ascii("liticises"),
        dictgen::InsensitiveStr::Ascii("liticising"),
        dictgen::InsensitiveStr::Ascii("liticization"),
        dictgen::InsensitiveStr::Ascii("liticize"),
        dictgen::InsensitiveStr::Ascii("liticized"),
        dictgen::InsensitiveStr::Ascii("liticizes"),
        dictgen::InsensitiveStr::Ascii("liticizing"),
        dictgen::InsensitiveStr::Ascii("lymerisation"),
        dictgen::InsensitiveStr::Ascii("lymerisations"),
        dictgen::InsensitiveStr::Ascii("lymerise"),
        dictgen::InsensitiveStr::Ascii("lymerised"),
        dictgen::InsensitiveStr::Ascii("lymerises"),
        dictgen::InsensitiveStr::Ascii("lymerising"),
        dictgen::InsensitiveStr::Ascii("lymerization"),
        dictgen::InsensitiveStr::Ascii("lymerizations"),
        dictgen::InsensitiveStr::Ascii("lymerize"),
        dictgen::InsensitiveStr::Ascii("lymerized"),
        dictgen::InsensitiveStr::Ascii("lymerizes"),
        dictgen::InsensitiveStr::Ascii("lymerizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEPOLARIZATION_2742985217153412220)],
        &[(0b10010, &ENTRY_DEPOLARIZATIONS_6588998950476370531)],
        &[(0b10010, &ENTRY_DEPOLARIZE_13378765368414695477)],
        &[(0b10010, &ENTRY_DEPOLARIZED_13852987575688176985)],
        &[(0b10010, &ENTRY_DEPOLARIZER_13724559510199383868)],
        &[(0b10010, &ENTRY_DEPOLARIZERS_17405526508830397920)],
        &[(0b10010, &ENTRY_DEPOLARIZES_16555447378193023350)],
        &[(0b10010, &ENTRY_DEPOLARIZING_1326681409200466325)],
        &[(0b01001, &ENTRY_DEPOLARIZATION_2742985217153412220)],
        &[(0b01001, &ENTRY_DEPOLARIZATIONS_6588998950476370531)],
        &[(0b01001, &ENTRY_DEPOLARIZE_13378765368414695477)],
        &[(0b01001, &ENTRY_DEPOLARIZED_13852987575688176985)],
        &[(0b01001, &ENTRY_DEPOLARIZER_13724559510199383868)],
        &[(0b01001, &ENTRY_DEPOLARIZERS_17405526508830397920)],
        &[(0b01001, &ENTRY_DEPOLARIZES_16555447378193023350)],
        &[(0b01001, &ENTRY_DEPOLARIZING_1326681409200466325)],
        &[(0b10010, &ENTRY_DEPOLITICIZATION_14063377291726000588)],
        &[(0b10010, &ENTRY_DEPOLITICIZE_646707646854880895)],
        &[(0b10010, &ENTRY_DEPOLITICIZED_17863590655277271452)],
        &[(0b10010, &ENTRY_DEPOLITICIZES_17679110590239399087)],
        &[(0b10010, &ENTRY_DEPOLITICIZING_7335312451906636158)],
        &[(0b01001, &ENTRY_DEPOLITICIZATION_14063377291726000588)],
        &[(0b01001, &ENTRY_DEPOLITICIZE_646707646854880895)],
        &[(0b01001, &ENTRY_DEPOLITICIZED_17863590655277271452)],
        &[(0b01001, &ENTRY_DEPOLITICIZES_17679110590239399087)],
        &[(0b01001, &ENTRY_DEPOLITICIZING_7335312451906636158)],
        &[(0b10010, &ENTRY_DEPOLYMERIZATION_11553792676168407099)],
        &[(0b10010, &ENTRY_DEPOLYMERIZATIONS_10499384093097172145)],
        &[(0b10010, &ENTRY_DEPOLYMERIZE_332335072679713287)],
        &[(0b10010, &ENTRY_DEPOLYMERIZED_10301635163339565907)],
        &[(0b10010, &ENTRY_DEPOLYMERIZES_8621948432119164421)],
        &[(0b10010, &ENTRY_DEPOLYMERIZING_9371889196944478207)],
        &[(0b01001, &ENTRY_DEPOLYMERIZATION_11553792676168407099)],
        &[(0b01001, &ENTRY_DEPOLYMERIZATIONS_10499384093097172145)],
        &[(0b01001, &ENTRY_DEPOLYMERIZE_332335072679713287)],
        &[(0b01001, &ENTRY_DEPOLYMERIZED_10301635163339565907)],
        &[(0b01001, &ENTRY_DEPOLYMERIZES_8621948432119164421)],
        &[(0b01001, &ENTRY_DEPOLYMERIZING_9371889196944478207)],
    ],
    range: 6..=13,
};

static VARS_DEPE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPE_CHILDREN),
    value: None,
};

pub static VARS_DEPE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndance"),
        dictgen::InsensitiveStr::Ascii("ndances"),
        dictgen::InsensitiveStr::Ascii("ndant"),
        dictgen::InsensitiveStr::Ascii("ndants"),
        dictgen::InsensitiveStr::Ascii("rsonalisation"),
        dictgen::InsensitiveStr::Ascii("rsonalisations"),
        dictgen::InsensitiveStr::Ascii("rsonalise"),
        dictgen::InsensitiveStr::Ascii("rsonalised"),
        dictgen::InsensitiveStr::Ascii("rsonalises"),
        dictgen::InsensitiveStr::Ascii("rsonalising"),
        dictgen::InsensitiveStr::Ascii("rsonalization"),
        dictgen::InsensitiveStr::Ascii("rsonalizations"),
        dictgen::InsensitiveStr::Ascii("rsonalize"),
        dictgen::InsensitiveStr::Ascii("rsonalized"),
        dictgen::InsensitiveStr::Ascii("rsonalizes"),
        dictgen::InsensitiveStr::Ascii("rsonalizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DEPENDENCE_10489349889910496855)],
        &[(0b00001, &ENTRY_DEPENDENCES_3098774442639177584)],
        &[(0b11010, &ENTRY_DEPENDENT_14174944247872454288)],
        &[(0b11010, &ENTRY_DEPENDENTS_1571044403913138535)],
        &[(0b10010, &ENTRY_DEPERSONALIZATION_16899026211036624682)],
        &[(0b10010, &ENTRY_DEPERSONALIZATIONS_934260460324727269)],
        &[(0b10010, &ENTRY_DEPERSONALIZE_18024338536202331812)],
        &[(0b10010, &ENTRY_DEPERSONALIZED_6040306005149363450)],
        &[(0b10010, &ENTRY_DEPERSONALIZES_8248879637475981954)],
        &[(0b10010, &ENTRY_DEPERSONALIZING_9579967389250229168)],
        &[(0b01001, &ENTRY_DEPERSONALIZATION_16899026211036624682)],
        &[(0b01001, &ENTRY_DEPERSONALIZATIONS_934260460324727269)],
        &[(0b01001, &ENTRY_DEPERSONALIZE_18024338536202331812)],
        &[(0b01001, &ENTRY_DEPERSONALIZED_6040306005149363450)],
        &[(0b01001, &ENTRY_DEPERSONALIZES_8248879637475981954)],
        &[(0b01001, &ENTRY_DEPERSONALIZING_9579967389250229168)],
    ],
    range: 5..=14,
};

static VARS_DEPA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEPA_CHILDREN),
    value: None,
};

pub static VARS_DEPA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rtmentalisation"),
        dictgen::InsensitiveStr::Ascii("rtmentalisations"),
        dictgen::InsensitiveStr::Ascii("rtmentalise"),
        dictgen::InsensitiveStr::Ascii("rtmentalised"),
        dictgen::InsensitiveStr::Ascii("rtmentalises"),
        dictgen::InsensitiveStr::Ascii("rtmentalising"),
        dictgen::InsensitiveStr::Ascii("rtmentalization"),
        dictgen::InsensitiveStr::Ascii("rtmentalizations"),
        dictgen::InsensitiveStr::Ascii("rtmentalize"),
        dictgen::InsensitiveStr::Ascii("rtmentalized"),
        dictgen::InsensitiveStr::Ascii("rtmentalizes"),
        dictgen::InsensitiveStr::Ascii("rtmentalizing"),
        dictgen::InsensitiveStr::Ascii("rtmentisation"),
        dictgen::InsensitiveStr::Ascii("rtmentisations"),
        dictgen::InsensitiveStr::Ascii("rtmentise"),
        dictgen::InsensitiveStr::Ascii("rtmentises"),
        dictgen::InsensitiveStr::Ascii("rtmentization"),
        dictgen::InsensitiveStr::Ascii("rtmentizations"),
        dictgen::InsensitiveStr::Ascii("rtmentize"),
        dictgen::InsensitiveStr::Ascii("rtmentizes"),
        dictgen::InsensitiveStr::Ascii("uperisation"),
        dictgen::InsensitiveStr::Ascii("uperise"),
        dictgen::InsensitiveStr::Ascii("uperised"),
        dictgen::InsensitiveStr::Ascii("uperises"),
        dictgen::InsensitiveStr::Ascii("uperising"),
        dictgen::InsensitiveStr::Ascii("uperization"),
        dictgen::InsensitiveStr::Ascii("uperize"),
        dictgen::InsensitiveStr::Ascii("uperized"),
        dictgen::InsensitiveStr::Ascii("uperizes"),
        dictgen::InsensitiveStr::Ascii("uperizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEPARTMENTALIZATION_12611432409781436004)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZATIONS_13030339549069230554)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZE_14009690449414337770)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZED_7739211835934086119)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZES_2816661299052746212)],
        &[(0b10010, &ENTRY_DEPARTMENTALIZING_18236918120360172300)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZATION_12611432409781436004)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZATIONS_13030339549069230554)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZE_14009690449414337770)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZED_7739211835934086119)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZES_2816661299052746212)],
        &[(0b01001, &ENTRY_DEPARTMENTALIZING_18236918120360172300)],
        &[(0b10010, &ENTRY_DEPARTMENTIZATION_10520965656271033045)],
        &[(0b10010, &ENTRY_DEPARTMENTIZATIONS_3570201152511445119)],
        &[(0b10010, &ENTRY_DEPARTMENTIZE_14523218551427073465)],
        &[(0b10010, &ENTRY_DEPARTMENTIZES_7420843837381616897)],
        &[(0b01001, &ENTRY_DEPARTMENTIZATION_10520965656271033045)],
        &[(0b01001, &ENTRY_DEPARTMENTIZATIONS_3570201152511445119)],
        &[(0b01001, &ENTRY_DEPARTMENTIZE_14523218551427073465)],
        &[(0b01001, &ENTRY_DEPARTMENTIZES_7420843837381616897)],
        &[(0b10010, &ENTRY_DEPAUPERIZATION_12167006445811415084)],
        &[(0b10010, &ENTRY_DEPAUPERIZE_5573322689772847322)],
        &[(0b10010, &ENTRY_DEPAUPERIZED_18062942538181210641)],
        &[(0b10010, &ENTRY_DEPAUPERIZES_5838182964694454265)],
        &[(0b10010, &ENTRY_DEPAUPERIZING_17019784408353154824)],
        &[(0b01001, &ENTRY_DEPAUPERIZATION_12167006445811415084)],
        &[(0b01001, &ENTRY_DEPAUPERIZE_5573322689772847322)],
        &[(0b01001, &ENTRY_DEPAUPERIZED_18062942538181210641)],
        &[(0b01001, &ENTRY_DEPAUPERIZES_5838182964694454265)],
        &[(0b01001, &ENTRY_DEPAUPERIZING_17019784408353154824)],
    ],
    range: 7..=16,
};

static VARS_DEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEO_CHILDREN),
    value: None,
};

pub static VARS_DEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dorisation"),
        dictgen::InsensitiveStr::Ascii("dorisations"),
        dictgen::InsensitiveStr::Ascii("dorise"),
        dictgen::InsensitiveStr::Ascii("dorised"),
        dictgen::InsensitiveStr::Ascii("doriser"),
        dictgen::InsensitiveStr::Ascii("dorisers"),
        dictgen::InsensitiveStr::Ascii("dorises"),
        dictgen::InsensitiveStr::Ascii("dorising"),
        dictgen::InsensitiveStr::Ascii("dorization"),
        dictgen::InsensitiveStr::Ascii("dorizations"),
        dictgen::InsensitiveStr::Ascii("dorize"),
        dictgen::InsensitiveStr::Ascii("dorized"),
        dictgen::InsensitiveStr::Ascii("dorizer"),
        dictgen::InsensitiveStr::Ascii("dorizers"),
        dictgen::InsensitiveStr::Ascii("dorizes"),
        dictgen::InsensitiveStr::Ascii("dorizing"),
        dictgen::InsensitiveStr::Ascii("xidisation"),
        dictgen::InsensitiveStr::Ascii("xidisations"),
        dictgen::InsensitiveStr::Ascii("xidise"),
        dictgen::InsensitiveStr::Ascii("xidised"),
        dictgen::InsensitiveStr::Ascii("xidiser"),
        dictgen::InsensitiveStr::Ascii("xidisers"),
        dictgen::InsensitiveStr::Ascii("xidises"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidization"),
        dictgen::InsensitiveStr::Ascii("xidizations"),
        dictgen::InsensitiveStr::Ascii("xidize"),
        dictgen::InsensitiveStr::Ascii("xidized"),
        dictgen::InsensitiveStr::Ascii("xidizer"),
        dictgen::InsensitiveStr::Ascii("xidizers"),
        dictgen::InsensitiveStr::Ascii("xidizes"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
        dictgen::InsensitiveStr::Ascii("xygenise"),
        dictgen::InsensitiveStr::Ascii("xygenised"),
        dictgen::InsensitiveStr::Ascii("xygenises"),
        dictgen::InsensitiveStr::Ascii("xygenising"),
        dictgen::InsensitiveStr::Ascii("xygenize"),
        dictgen::InsensitiveStr::Ascii("xygenized"),
        dictgen::InsensitiveStr::Ascii("xygenizes"),
        dictgen::InsensitiveStr::Ascii("xygenizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEODORIZATION_15234202985364171925)],
        &[(0b10010, &ENTRY_DEODORIZATIONS_12657185289043189294)],
        &[(0b10010, &ENTRY_DEODORIZE_16215032566622833150)],
        &[(0b10010, &ENTRY_DEODORIZED_17559687252320728172)],
        &[(0b10010, &ENTRY_DEODORIZER_13797022735041696461)],
        &[(0b10010, &ENTRY_DEODORIZERS_7206686442131612842)],
        &[(0b10010, &ENTRY_DEODORIZES_4648778267610996306)],
        &[(0b10010, &ENTRY_DEODORIZING_12515361627952335019)],
        &[(0b01001, &ENTRY_DEODORIZATION_15234202985364171925)],
        &[(0b01001, &ENTRY_DEODORIZATIONS_12657185289043189294)],
        &[(0b01001, &ENTRY_DEODORIZE_16215032566622833150)],
        &[(0b01001, &ENTRY_DEODORIZED_17559687252320728172)],
        &[(0b01001, &ENTRY_DEODORIZER_13797022735041696461)],
        &[(0b01001, &ENTRY_DEODORIZERS_7206686442131612842)],
        &[(0b01001, &ENTRY_DEODORIZES_4648778267610996306)],
        &[(0b01001, &ENTRY_DEODORIZING_12515361627952335019)],
        &[(0b10010, &ENTRY_DEOXIDIZATION_7394934458510098573)],
        &[(0b10010, &ENTRY_DEOXIDIZATIONS_13683604498444194612)],
        &[(0b10010, &ENTRY_DEOXIDIZE_8564134429609100253)],
        &[(0b10010, &ENTRY_DEOXIDIZED_14617928271424988803)],
        &[(0b10010, &ENTRY_DEOXIDIZER_11973963213903362992)],
        &[(0b10010, &ENTRY_DEOXIDIZERS_10105977169121575310)],
        &[(0b10010, &ENTRY_DEOXIDIZES_4018740714548992165)],
        &[(0b10010, &ENTRY_DEOXIDIZING_17849539330093953654)],
        &[(0b01001, &ENTRY_DEOXIDIZATION_7394934458510098573)],
        &[(0b01001, &ENTRY_DEOXIDIZATIONS_13683604498444194612)],
        &[(0b01001, &ENTRY_DEOXIDIZE_8564134429609100253)],
        &[(0b01001, &ENTRY_DEOXIDIZED_14617928271424988803)],
        &[(0b01001, &ENTRY_DEOXIDIZER_11973963213903362992)],
        &[(0b01001, &ENTRY_DEOXIDIZERS_10105977169121575310)],
        &[(0b01001, &ENTRY_DEOXIDIZES_4018740714548992165)],
        &[(0b01001, &ENTRY_DEOXIDIZING_17849539330093953654)],
        &[(0b10010, &ENTRY_DEOXYGENIZE_7933890150357499237)],
        &[(0b10010, &ENTRY_DEOXYGENIZED_6360726218188064127)],
        &[(0b10010, &ENTRY_DEOXYGENIZES_17788466892741650049)],
        &[(0b10010, &ENTRY_DEOXYGENIZING_6445979304009334071)],
        &[(0b01001, &ENTRY_DEOXYGENIZE_7933890150357499237)],
        &[(0b01001, &ENTRY_DEOXYGENIZED_6360726218188064127)],
        &[(0b01001, &ENTRY_DEOXYGENIZES_17788466892741650049)],
        &[(0b01001, &ENTRY_DEOXYGENIZING_6445979304009334071)],
    ],
    range: 6..=11,
};

static VARS_DEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEN_CHILDREN),
    value: None,
};

static VARS_DEN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DENA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DENI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DENO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_DENT_NODE),
    Some(&VARS_DENU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DENU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENU_CHILDREN),
    value: None,
};

pub static VARS_DENU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("clearisation"),
        dictgen::InsensitiveStr::Ascii("clearisations"),
        dictgen::InsensitiveStr::Ascii("clearise"),
        dictgen::InsensitiveStr::Ascii("clearised"),
        dictgen::InsensitiveStr::Ascii("clearises"),
        dictgen::InsensitiveStr::Ascii("clearising"),
        dictgen::InsensitiveStr::Ascii("clearization"),
        dictgen::InsensitiveStr::Ascii("clearizations"),
        dictgen::InsensitiveStr::Ascii("clearize"),
        dictgen::InsensitiveStr::Ascii("clearized"),
        dictgen::InsensitiveStr::Ascii("clearizes"),
        dictgen::InsensitiveStr::Ascii("clearizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENUCLEARIZATION_6246945169000847057)],
        &[(0b10010, &ENTRY_DENUCLEARIZATIONS_7167298608770271904)],
        &[(0b10010, &ENTRY_DENUCLEARIZE_7871525726880557534)],
        &[(0b10010, &ENTRY_DENUCLEARIZED_14638949387306808248)],
        &[(0b10010, &ENTRY_DENUCLEARIZES_3857601007676937998)],
        &[(0b10010, &ENTRY_DENUCLEARIZING_6228420000189119754)],
        &[(0b01001, &ENTRY_DENUCLEARIZATION_6246945169000847057)],
        &[(0b01001, &ENTRY_DENUCLEARIZATIONS_7167298608770271904)],
        &[(0b01001, &ENTRY_DENUCLEARIZE_7871525726880557534)],
        &[(0b01001, &ENTRY_DENUCLEARIZED_14638949387306808248)],
        &[(0b01001, &ENTRY_DENUCLEARIZES_3857601007676937998)],
        &[(0b01001, &ENTRY_DENUCLEARIZING_6228420000189119754)],
    ],
    range: 8..=13,
};

static VARS_DENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENT_CHILDREN),
    value: None,
};

pub static VARS_DENT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("in"),
        dictgen::InsensitiveStr::Ascii("ins"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENTALIZATION_15022518066445577537)],
        &[(0b10010, &ENTRY_DENTALIZATIONS_1316043456675495124)],
        &[(0b10010, &ENTRY_DENTALIZE_13079577939938126746)],
        &[(0b10010, &ENTRY_DENTALIZED_2413837908707543437)],
        &[(0b10010, &ENTRY_DENTALIZES_6643609780500500774)],
        &[(0b10010, &ENTRY_DENTALIZING_324908095822959388)],
        &[(0b01001, &ENTRY_DENTALIZATION_15022518066445577537)],
        &[(0b01001, &ENTRY_DENTALIZATIONS_1316043456675495124)],
        &[(0b01001, &ENTRY_DENTALIZE_13079577939938126746)],
        &[(0b01001, &ENTRY_DENTALIZED_2413837908707543437)],
        &[(0b01001, &ENTRY_DENTALIZES_6643609780500500774)],
        &[(0b01001, &ENTRY_DENTALIZING_324908095822959388)],
        &[(0b00001, &ENTRY_DENTIN_8335953072295603807)],
        &[(0b00001, &ENTRY_DENTINS_8462696171012072981)],
    ],
    range: 2..=10,
};

static VARS_DENO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENO_CHILDREN),
    value: None,
};

pub static VARS_DENO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minationalise"),
        dictgen::InsensitiveStr::Ascii("minationalises"),
        dictgen::InsensitiveStr::Ascii("minationalize"),
        dictgen::InsensitiveStr::Ascii("minationalizes"),
        dictgen::InsensitiveStr::Ascii("rmalise"),
        dictgen::InsensitiveStr::Ascii("rmalize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENOMINATIONALIZE_11508794372277368265)],
        &[(0b10010, &ENTRY_DENOMINATIONALIZES_16912479616014894849)],
        &[(0b01001, &ENTRY_DENOMINATIONALIZE_11508794372277368265)],
        &[(0b01001, &ENTRY_DENOMINATIONALIZES_16912479616014894849)],
        &[(0b10010, &ENTRY_DENORMALIZE_14457389572229397553)],
        &[(0b01001, &ENTRY_DENORMALIZE_14457389572229397553)],
    ],
    range: 7..=14,
};

static VARS_DENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENI_CHILDREN),
    value: None,
};

pub static VARS_DENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cotinise"),
        dictgen::InsensitiveStr::Ascii("cotinize"),
        dictgen::InsensitiveStr::Ascii("zenise"),
        dictgen::InsensitiveStr::Ascii("zenises"),
        dictgen::InsensitiveStr::Ascii("zenize"),
        dictgen::InsensitiveStr::Ascii("zenizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENICOTINIZE_1657978267403261883)],
        &[(0b01001, &ENTRY_DENICOTINIZE_1657978267403261883)],
        &[(0b10010, &ENTRY_DENIZENIZE_15175171930010739812)],
        &[(0b10010, &ENTRY_DENIZENIZES_4532386499907231320)],
        &[(0b01001, &ENTRY_DENIZENIZE_15175171930010739812)],
        &[(0b01001, &ENTRY_DENIZENIZES_4532386499907231320)],
    ],
    range: 6..=8,
};

static VARS_DENA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DENA_CHILDREN),
    value: None,
};

pub static VARS_DENA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tionalisation"),
        dictgen::InsensitiveStr::Ascii("tionalisations"),
        dictgen::InsensitiveStr::Ascii("tionalise"),
        dictgen::InsensitiveStr::Ascii("tionalised"),
        dictgen::InsensitiveStr::Ascii("tionalises"),
        dictgen::InsensitiveStr::Ascii("tionalising"),
        dictgen::InsensitiveStr::Ascii("tionalization"),
        dictgen::InsensitiveStr::Ascii("tionalizations"),
        dictgen::InsensitiveStr::Ascii("tionalize"),
        dictgen::InsensitiveStr::Ascii("tionalized"),
        dictgen::InsensitiveStr::Ascii("tionalizes"),
        dictgen::InsensitiveStr::Ascii("tionalizing"),
        dictgen::InsensitiveStr::Ascii("turalisation"),
        dictgen::InsensitiveStr::Ascii("turalisations"),
        dictgen::InsensitiveStr::Ascii("turalise"),
        dictgen::InsensitiveStr::Ascii("turalised"),
        dictgen::InsensitiveStr::Ascii("turalises"),
        dictgen::InsensitiveStr::Ascii("turalising"),
        dictgen::InsensitiveStr::Ascii("turalization"),
        dictgen::InsensitiveStr::Ascii("turalizations"),
        dictgen::InsensitiveStr::Ascii("turalize"),
        dictgen::InsensitiveStr::Ascii("turalized"),
        dictgen::InsensitiveStr::Ascii("turalizes"),
        dictgen::InsensitiveStr::Ascii("turalizing"),
        dictgen::InsensitiveStr::Ascii("turisation"),
        dictgen::InsensitiveStr::Ascii("turisations"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turised"),
        dictgen::InsensitiveStr::Ascii("turiser"),
        dictgen::InsensitiveStr::Ascii("turisers"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turising"),
        dictgen::InsensitiveStr::Ascii("turization"),
        dictgen::InsensitiveStr::Ascii("turizations"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turized"),
        dictgen::InsensitiveStr::Ascii("turizer"),
        dictgen::InsensitiveStr::Ascii("turizers"),
        dictgen::InsensitiveStr::Ascii("turizes"),
        dictgen::InsensitiveStr::Ascii("turizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DENATIONALIZATION_16856781549152365477)],
        &[(0b10010, &ENTRY_DENATIONALIZATIONS_9164415981140694292)],
        &[(0b10010, &ENTRY_DENATIONALIZE_10800464833245961489)],
        &[(0b10010, &ENTRY_DENATIONALIZED_10472708594349713108)],
        &[(0b10010, &ENTRY_DENATIONALIZES_817254898726083409)],
        &[(0b10010, &ENTRY_DENATIONALIZING_8331022494929548611)],
        &[(0b01001, &ENTRY_DENATIONALIZATION_16856781549152365477)],
        &[(0b01001, &ENTRY_DENATIONALIZATIONS_9164415981140694292)],
        &[(0b01001, &ENTRY_DENATIONALIZE_10800464833245961489)],
        &[(0b01001, &ENTRY_DENATIONALIZED_10472708594349713108)],
        &[(0b01001, &ENTRY_DENATIONALIZES_817254898726083409)],
        &[(0b01001, &ENTRY_DENATIONALIZING_8331022494929548611)],
        &[(0b10010, &ENTRY_DENATURALIZATION_4147617871911149693)],
        &[(0b10010, &ENTRY_DENATURALIZATIONS_16570465894458392415)],
        &[(0b10010, &ENTRY_DENATURALIZE_12142869922927195304)],
        &[(0b10010, &ENTRY_DENATURALIZED_1338969835914266213)],
        &[(0b10010, &ENTRY_DENATURALIZES_12885068908916155509)],
        &[(0b10010, &ENTRY_DENATURALIZING_11035796773484399105)],
        &[(0b01001, &ENTRY_DENATURALIZATION_4147617871911149693)],
        &[(0b01001, &ENTRY_DENATURALIZATIONS_16570465894458392415)],
        &[(0b01001, &ENTRY_DENATURALIZE_12142869922927195304)],
        &[(0b01001, &ENTRY_DENATURALIZED_1338969835914266213)],
        &[(0b01001, &ENTRY_DENATURALIZES_12885068908916155509)],
        &[(0b01001, &ENTRY_DENATURALIZING_11035796773484399105)],
        &[(0b10010, &ENTRY_DENATURIZATION_2153844497547377154)],
        &[(0b10010, &ENTRY_DENATURIZATIONS_12481426158532842249)],
        &[(0b10010, &ENTRY_DENATURIZE_16665212717126083275)],
        &[(0b10010, &ENTRY_DENATURIZED_11293306666666002972)],
        &[(0b10010, &ENTRY_DENATURIZER_9311420005130802353)],
        &[(0b10010, &ENTRY_DENATURIZERS_7527212398694915324)],
        &[(0b10010, &ENTRY_DENATURIZES_2160785183565221398)],
        &[(0b10010, &ENTRY_DENATURIZING_7455919186731907769)],
        &[(0b01001, &ENTRY_DENATURIZATION_2153844497547377154)],
        &[(0b01001, &ENTRY_DENATURIZATIONS_12481426158532842249)],
        &[(0b01001, &ENTRY_DENATURIZE_16665212717126083275)],
        &[(0b01001, &ENTRY_DENATURIZED_11293306666666002972)],
        &[(0b01001, &ENTRY_DENATURIZER_9311420005130802353)],
        &[(0b01001, &ENTRY_DENATURIZERS_7527212398694915324)],
        &[(0b01001, &ENTRY_DENATURIZES_2160785183565221398)],
        &[(0b01001, &ENTRY_DENATURIZING_7455919186731907769)],
    ],
    range: 6..=14,
};

static VARS_DEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEM_CHILDREN),
    value: None,
};

static VARS_DEM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DEMA_NODE),
    None,
    None,
    None,
    Some(&VARS_DEME_NODE),
    None,
    None,
    None,
    Some(&VARS_DEMI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEMO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEMU_NODE),
    None,
    None,
    None,
    Some(&VARS_DEMY_NODE),
    None,
];

static VARS_DEMY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMY_CHILDREN),
    value: None,
};

pub static VARS_DEMY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thologisation"),
        dictgen::InsensitiveStr::Ascii("thologisations"),
        dictgen::InsensitiveStr::Ascii("thologise"),
        dictgen::InsensitiveStr::Ascii("thologised"),
        dictgen::InsensitiveStr::Ascii("thologiser"),
        dictgen::InsensitiveStr::Ascii("thologises"),
        dictgen::InsensitiveStr::Ascii("thologising"),
        dictgen::InsensitiveStr::Ascii("thologization"),
        dictgen::InsensitiveStr::Ascii("thologizations"),
        dictgen::InsensitiveStr::Ascii("thologize"),
        dictgen::InsensitiveStr::Ascii("thologized"),
        dictgen::InsensitiveStr::Ascii("thologizer"),
        dictgen::InsensitiveStr::Ascii("thologizes"),
        dictgen::InsensitiveStr::Ascii("thologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMYTHOLOGIZATION_10340600013226874649)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZATIONS_14134816474323970961)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZE_16862432836085218960)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZED_4313900331791829006)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZER_5237816041623179771)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZES_18185232184173660209)],
        &[(0b10010, &ENTRY_DEMYTHOLOGIZING_12409215121201891385)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZATION_10340600013226874649)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZATIONS_14134816474323970961)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZE_16862432836085218960)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZED_4313900331791829006)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZER_5237816041623179771)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZES_18185232184173660209)],
        &[(0b01001, &ENTRY_DEMYTHOLOGIZING_12409215121201891385)],
    ],
    range: 9..=14,
};

static VARS_DEMU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMU_CHILDREN),
    value: None,
};

pub static VARS_DEMU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tualisation"),
        dictgen::InsensitiveStr::Ascii("tualisations"),
        dictgen::InsensitiveStr::Ascii("tualise"),
        dictgen::InsensitiveStr::Ascii("tualised"),
        dictgen::InsensitiveStr::Ascii("tualises"),
        dictgen::InsensitiveStr::Ascii("tualising"),
        dictgen::InsensitiveStr::Ascii("tualization"),
        dictgen::InsensitiveStr::Ascii("tualizations"),
        dictgen::InsensitiveStr::Ascii("tualize"),
        dictgen::InsensitiveStr::Ascii("tualized"),
        dictgen::InsensitiveStr::Ascii("tualizes"),
        dictgen::InsensitiveStr::Ascii("tualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMUTUALIZATION_5558427623273214024)],
        &[(0b10010, &ENTRY_DEMUTUALIZATIONS_10275807852426892350)],
        &[(0b10010, &ENTRY_DEMUTUALIZE_2272296115716481128)],
        &[(0b10010, &ENTRY_DEMUTUALIZED_11852403011547269121)],
        &[(0b10010, &ENTRY_DEMUTUALIZES_11099575180973682407)],
        &[(0b10010, &ENTRY_DEMUTUALIZING_7987101933996172504)],
        &[(0b01001, &ENTRY_DEMUTUALIZATION_5558427623273214024)],
        &[(0b01001, &ENTRY_DEMUTUALIZATIONS_10275807852426892350)],
        &[(0b01001, &ENTRY_DEMUTUALIZE_2272296115716481128)],
        &[(0b01001, &ENTRY_DEMUTUALIZED_11852403011547269121)],
        &[(0b01001, &ENTRY_DEMUTUALIZES_11099575180973682407)],
        &[(0b01001, &ENTRY_DEMUTUALIZING_7987101933996172504)],
    ],
    range: 7..=12,
};

static VARS_DEMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEMO_CHILDREN),
    value: None,
};

static VARS_DEMO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_DEMOB_NODE),
    Some(&VARS_DEMOC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEMON_NODE),
    None,
    None,
    None,
    Some(&VARS_DEMOR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_DEMOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMOR_CHILDREN),
    value: None,
};

pub static VARS_DEMOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alisingly"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("alizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMORALIZATION_13446399219739683931)],
        &[(0b10010, &ENTRY_DEMORALIZATIONS_1875584783582242810)],
        &[(0b10010, &ENTRY_DEMORALIZE_5844727729581502857)],
        &[(0b10010, &ENTRY_DEMORALIZED_11996398655519385837)],
        &[(0b10010, &ENTRY_DEMORALIZER_9540636813033814633)],
        &[(0b10010, &ENTRY_DEMORALIZERS_600938080037133255)],
        &[(0b10010, &ENTRY_DEMORALIZES_6517352001271737987)],
        &[(0b10010, &ENTRY_DEMORALIZING_2653761035115515698)],
        &[(0b10010, &ENTRY_DEMORALIZINGLY_8510512214576425144)],
        &[(0b01001, &ENTRY_DEMORALIZATION_13446399219739683931)],
        &[(0b01001, &ENTRY_DEMORALIZATIONS_1875584783582242810)],
        &[(0b01001, &ENTRY_DEMORALIZE_5844727729581502857)],
        &[(0b01001, &ENTRY_DEMORALIZED_11996398655519385837)],
        &[(0b01001, &ENTRY_DEMORALIZER_9540636813033814633)],
        &[(0b01001, &ENTRY_DEMORALIZERS_600938080037133255)],
        &[(0b01001, &ENTRY_DEMORALIZES_6517352001271737987)],
        &[(0b01001, &ENTRY_DEMORALIZING_2653761035115515698)],
        &[(0b01001, &ENTRY_DEMORALIZINGLY_8510512214576425144)],
    ],
    range: 5..=10,
};

static VARS_DEMON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMON_CHILDREN),
    value: None,
};

pub static VARS_DEMON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etisation"),
        dictgen::InsensitiveStr::Ascii("etisations"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etization"),
        dictgen::InsensitiveStr::Ascii("etizations"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
        dictgen::InsensitiveStr::Ascii("ian"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMONETIZATION_10800150167569494235)],
        &[(0b10010, &ENTRY_DEMONETIZATIONS_255741605004235275)],
        &[(0b10010, &ENTRY_DEMONETIZE_9169780209388435319)],
        &[(0b10010, &ENTRY_DEMONETIZED_13800822593083516335)],
        &[(0b10010, &ENTRY_DEMONETIZES_7423921842471575397)],
        &[(0b10010, &ENTRY_DEMONETIZING_6533722070664012445)],
        &[(0b01001, &ENTRY_DEMONETIZATION_10800150167569494235)],
        &[(0b01001, &ENTRY_DEMONETIZATIONS_255741605004235275)],
        &[(0b01001, &ENTRY_DEMONETIZE_9169780209388435319)],
        &[(0b01001, &ENTRY_DEMONETIZED_13800822593083516335)],
        &[(0b01001, &ENTRY_DEMONETIZES_7423921842471575397)],
        &[(0b01001, &ENTRY_DEMONETIZING_6533722070664012445)],
        &[(0b10001, &ENTRY_DEMONIAN_17257435076983249346)],
        &[(0b10010, &ENTRY_DEMONIZATION_16933975817485552160)],
        &[(0b10010, &ENTRY_DEMONIZE_12145752355966993821)],
        &[(0b10010, &ENTRY_DEMONIZED_12813528693273757543)],
        &[(0b10010, &ENTRY_DEMONIZES_9920698644496788584)],
        &[(0b10010, &ENTRY_DEMONIZING_6566799728062813977)],
        &[(0b01001, &ENTRY_DEMONIZATION_16933975817485552160)],
        &[(0b01001, &ENTRY_DEMONIZE_12145752355966993821)],
        &[(0b01001, &ENTRY_DEMONIZED_12813528693273757543)],
        &[(0b01001, &ENTRY_DEMONIZES_9920698644496788584)],
        &[(0b01001, &ENTRY_DEMONIZING_6566799728062813977)],
    ],
    range: 3..=10,
};

static VARS_DEMOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMOC_CHILDREN),
    value: None,
};

pub static VARS_DEMOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ratisation"),
        dictgen::InsensitiveStr::Ascii("ratisations"),
        dictgen::InsensitiveStr::Ascii("ratise"),
        dictgen::InsensitiveStr::Ascii("ratised"),
        dictgen::InsensitiveStr::Ascii("ratiser"),
        dictgen::InsensitiveStr::Ascii("ratises"),
        dictgen::InsensitiveStr::Ascii("ratising"),
        dictgen::InsensitiveStr::Ascii("ratization"),
        dictgen::InsensitiveStr::Ascii("ratizations"),
        dictgen::InsensitiveStr::Ascii("ratize"),
        dictgen::InsensitiveStr::Ascii("ratized"),
        dictgen::InsensitiveStr::Ascii("ratizer"),
        dictgen::InsensitiveStr::Ascii("ratizes"),
        dictgen::InsensitiveStr::Ascii("ratizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMOCRATIZATION_17254764392338903283)],
        &[(0b10010, &ENTRY_DEMOCRATIZATIONS_4388695499854265807)],
        &[(0b10010, &ENTRY_DEMOCRATIZE_10194385791283666571)],
        &[(0b10010, &ENTRY_DEMOCRATIZED_18121735197237538789)],
        &[(0b10010, &ENTRY_DEMOCRATIZER_15492342920596234152)],
        &[(0b10010, &ENTRY_DEMOCRATIZES_11290287892884717824)],
        &[(0b10010, &ENTRY_DEMOCRATIZING_5756319688655505152)],
        &[(0b01001, &ENTRY_DEMOCRATIZATION_17254764392338903283)],
        &[(0b01001, &ENTRY_DEMOCRATIZATIONS_4388695499854265807)],
        &[(0b01001, &ENTRY_DEMOCRATIZE_10194385791283666571)],
        &[(0b01001, &ENTRY_DEMOCRATIZED_18121735197237538789)],
        &[(0b01001, &ENTRY_DEMOCRATIZER_15492342920596234152)],
        &[(0b01001, &ENTRY_DEMOCRATIZES_11290287892884717824)],
        &[(0b01001, &ENTRY_DEMOCRATIZING_5756319688655505152)],
    ],
    range: 6..=11,
};

static VARS_DEMOB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMOB_CHILDREN),
    value: None,
};

pub static VARS_DEMOB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMOBILIZATION_8427760600922715154)],
        &[(0b10010, &ENTRY_DEMOBILIZATIONS_6851457664741914489)],
        &[(0b10010, &ENTRY_DEMOBILIZE_7893368911880481234)],
        &[(0b10010, &ENTRY_DEMOBILIZED_9206102949665526961)],
        &[(0b10010, &ENTRY_DEMOBILIZES_9950566876349545979)],
        &[(0b10010, &ENTRY_DEMOBILIZING_2666589548621520076)],
        &[(0b01001, &ENTRY_DEMOBILIZATION_8427760600922715154)],
        &[(0b01001, &ENTRY_DEMOBILIZATIONS_6851457664741914489)],
        &[(0b01001, &ENTRY_DEMOBILIZE_7893368911880481234)],
        &[(0b01001, &ENTRY_DEMOBILIZED_9206102949665526961)],
        &[(0b01001, &ENTRY_DEMOBILIZES_9950566876349545979)],
        &[(0b01001, &ENTRY_DEMOBILIZING_2666589548621520076)],
    ],
    range: 5..=10,
};

static VARS_DEMI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMI_CHILDREN),
    value: None,
};

pub static VARS_DEMI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("litarisation"),
        dictgen::InsensitiveStr::Ascii("litarisations"),
        dictgen::InsensitiveStr::Ascii("litarise"),
        dictgen::InsensitiveStr::Ascii("litarised"),
        dictgen::InsensitiveStr::Ascii("litarises"),
        dictgen::InsensitiveStr::Ascii("litarising"),
        dictgen::InsensitiveStr::Ascii("litarization"),
        dictgen::InsensitiveStr::Ascii("litarizations"),
        dictgen::InsensitiveStr::Ascii("litarize"),
        dictgen::InsensitiveStr::Ascii("litarized"),
        dictgen::InsensitiveStr::Ascii("litarizes"),
        dictgen::InsensitiveStr::Ascii("litarizing"),
        dictgen::InsensitiveStr::Ascii("luster"),
        dictgen::InsensitiveStr::Ascii("lustre"),
        dictgen::InsensitiveStr::Ascii("neralisation"),
        dictgen::InsensitiveStr::Ascii("neralisations"),
        dictgen::InsensitiveStr::Ascii("neralise"),
        dictgen::InsensitiveStr::Ascii("neralised"),
        dictgen::InsensitiveStr::Ascii("neraliser"),
        dictgen::InsensitiveStr::Ascii("neralises"),
        dictgen::InsensitiveStr::Ascii("neralising"),
        dictgen::InsensitiveStr::Ascii("neralization"),
        dictgen::InsensitiveStr::Ascii("neralizations"),
        dictgen::InsensitiveStr::Ascii("neralize"),
        dictgen::InsensitiveStr::Ascii("neralized"),
        dictgen::InsensitiveStr::Ascii("neralizer"),
        dictgen::InsensitiveStr::Ascii("neralizes"),
        dictgen::InsensitiveStr::Ascii("neralizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMILITARIZATION_1830348363036337787)],
        &[(0b10010, &ENTRY_DEMILITARIZATIONS_12252664721077083328)],
        &[(0b10010, &ENTRY_DEMILITARIZE_16703679582695532386)],
        &[(0b10010, &ENTRY_DEMILITARIZED_7958961857075865134)],
        &[(0b10010, &ENTRY_DEMILITARIZES_17566131017554380497)],
        &[(0b10010, &ENTRY_DEMILITARIZING_5137023236614361970)],
        &[(0b01001, &ENTRY_DEMILITARIZATION_1830348363036337787)],
        &[(0b01001, &ENTRY_DEMILITARIZATIONS_12252664721077083328)],
        &[(0b01001, &ENTRY_DEMILITARIZE_16703679582695532386)],
        &[(0b01001, &ENTRY_DEMILITARIZED_7958961857075865134)],
        &[(0b01001, &ENTRY_DEMILITARIZES_17566131017554380497)],
        &[(0b01001, &ENTRY_DEMILITARIZING_5137023236614361970)],
        &[(0b00001, &ENTRY_DEMILUSTER_18156742814546492480)],
        &[(0b11010, &ENTRY_DEMILUSTER_18156742814546492480)],
        &[(0b10010, &ENTRY_DEMINERALIZATION_11860382402591403329)],
        &[(0b10010, &ENTRY_DEMINERALIZATIONS_9687527290224020253)],
        &[(0b10010, &ENTRY_DEMINERALIZE_2028750406115400134)],
        &[(0b10010, &ENTRY_DEMINERALIZED_417389536885991347)],
        &[(0b10010, &ENTRY_DEMINERALIZER_11839062214960881518)],
        &[(0b10010, &ENTRY_DEMINERALIZES_10853907656124140046)],
        &[(0b10010, &ENTRY_DEMINERALIZING_8656195446853674994)],
        &[(0b01001, &ENTRY_DEMINERALIZATION_11860382402591403329)],
        &[(0b01001, &ENTRY_DEMINERALIZATIONS_9687527290224020253)],
        &[(0b01001, &ENTRY_DEMINERALIZE_2028750406115400134)],
        &[(0b01001, &ENTRY_DEMINERALIZED_417389536885991347)],
        &[(0b01001, &ENTRY_DEMINERALIZER_11839062214960881518)],
        &[(0b01001, &ENTRY_DEMINERALIZES_10853907656124140046)],
        &[(0b01001, &ENTRY_DEMINERALIZING_8656195446853674994)],
    ],
    range: 6..=13,
};

static VARS_DEME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEME_CHILDREN),
    value: None,
};

pub static VARS_DEME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anor"),
        dictgen::InsensitiveStr::Ascii("anors"),
        dictgen::InsensitiveStr::Ascii("anour"),
        dictgen::InsensitiveStr::Ascii("anours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_DEMEANOR_13927976893530181065)],
        &[(0b11001, &ENTRY_DEMEANORS_15645246800979825016)],
        &[(0b11010, &ENTRY_DEMEANOR_13927976893530181065)],
        &[(0b11010, &ENTRY_DEMEANORS_15645246800979825016)],
    ],
    range: 4..=6,
};

static VARS_DEMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEMA_CHILDREN),
    value: None,
};

pub static VARS_DEMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gnetisable"),
        dictgen::InsensitiveStr::Ascii("gnetisabler"),
        dictgen::InsensitiveStr::Ascii("gnetisables"),
        dictgen::InsensitiveStr::Ascii("gnetisablest"),
        dictgen::InsensitiveStr::Ascii("gnetisation"),
        dictgen::InsensitiveStr::Ascii("gnetisations"),
        dictgen::InsensitiveStr::Ascii("gnetise"),
        dictgen::InsensitiveStr::Ascii("gnetised"),
        dictgen::InsensitiveStr::Ascii("gnetiser"),
        dictgen::InsensitiveStr::Ascii("gnetisers"),
        dictgen::InsensitiveStr::Ascii("gnetises"),
        dictgen::InsensitiveStr::Ascii("gnetising"),
        dictgen::InsensitiveStr::Ascii("gnetizable"),
        dictgen::InsensitiveStr::Ascii("gnetizabler"),
        dictgen::InsensitiveStr::Ascii("gnetizables"),
        dictgen::InsensitiveStr::Ascii("gnetizablest"),
        dictgen::InsensitiveStr::Ascii("gnetization"),
        dictgen::InsensitiveStr::Ascii("gnetizations"),
        dictgen::InsensitiveStr::Ascii("gnetize"),
        dictgen::InsensitiveStr::Ascii("gnetized"),
        dictgen::InsensitiveStr::Ascii("gnetizer"),
        dictgen::InsensitiveStr::Ascii("gnetizers"),
        dictgen::InsensitiveStr::Ascii("gnetizes"),
        dictgen::InsensitiveStr::Ascii("gnetizing"),
        dictgen::InsensitiveStr::Ascii("gog"),
        dictgen::InsensitiveStr::Ascii("goged"),
        dictgen::InsensitiveStr::Ascii("goging"),
        dictgen::InsensitiveStr::Ascii("gogry"),
        dictgen::InsensitiveStr::Ascii("gogs"),
        dictgen::InsensitiveStr::Ascii("sculinisation"),
        dictgen::InsensitiveStr::Ascii("sculinise"),
        dictgen::InsensitiveStr::Ascii("sculinised"),
        dictgen::InsensitiveStr::Ascii("sculinising"),
        dictgen::InsensitiveStr::Ascii("sculinization"),
        dictgen::InsensitiveStr::Ascii("sculinize"),
        dictgen::InsensitiveStr::Ascii("sculinized"),
        dictgen::InsensitiveStr::Ascii("sculinizing"),
        dictgen::InsensitiveStr::Ascii("terialisation"),
        dictgen::InsensitiveStr::Ascii("terialisations"),
        dictgen::InsensitiveStr::Ascii("terialise"),
        dictgen::InsensitiveStr::Ascii("terialised"),
        dictgen::InsensitiveStr::Ascii("terialises"),
        dictgen::InsensitiveStr::Ascii("terialising"),
        dictgen::InsensitiveStr::Ascii("terialization"),
        dictgen::InsensitiveStr::Ascii("terializations"),
        dictgen::InsensitiveStr::Ascii("terialize"),
        dictgen::InsensitiveStr::Ascii("terialized"),
        dictgen::InsensitiveStr::Ascii("terializes"),
        dictgen::InsensitiveStr::Ascii("terializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEMAGNETIZABLE_2829745576751479415)],
        &[(0b10010, &ENTRY_DEMAGNETIZABLER_14067236382470080700)],
        &[(0b10010, &ENTRY_DEMAGNETIZABLES_17349604975000267862)],
        &[(0b10010, &ENTRY_DEMAGNETIZABLEST_231408157539452152)],
        &[(0b10010, &ENTRY_DEMAGNETIZATION_10848943172388045538)],
        &[(0b10010, &ENTRY_DEMAGNETIZATIONS_17906684919392124321)],
        &[(0b10010, &ENTRY_DEMAGNETIZE_17682740839823545869)],
        &[(0b10010, &ENTRY_DEMAGNETIZED_429555390860227118)],
        &[(0b10010, &ENTRY_DEMAGNETIZER_7369266141467515452)],
        &[(0b10010, &ENTRY_DEMAGNETIZERS_3139106218193590904)],
        &[(0b10010, &ENTRY_DEMAGNETIZES_2351872097402777148)],
        &[(0b10010, &ENTRY_DEMAGNETIZING_14763681981656800434)],
        &[(0b01001, &ENTRY_DEMAGNETIZABLE_2829745576751479415)],
        &[(0b01001, &ENTRY_DEMAGNETIZABLER_14067236382470080700)],
        &[(0b01001, &ENTRY_DEMAGNETIZABLES_17349604975000267862)],
        &[(0b01001, &ENTRY_DEMAGNETIZABLEST_231408157539452152)],
        &[(0b01001, &ENTRY_DEMAGNETIZATION_10848943172388045538)],
        &[(0b01001, &ENTRY_DEMAGNETIZATIONS_17906684919392124321)],
        &[(0b01001, &ENTRY_DEMAGNETIZE_17682740839823545869)],
        &[(0b01001, &ENTRY_DEMAGNETIZED_429555390860227118)],
        &[(0b01001, &ENTRY_DEMAGNETIZER_7369266141467515452)],
        &[(0b01001, &ENTRY_DEMAGNETIZERS_3139106218193590904)],
        &[(0b01001, &ENTRY_DEMAGNETIZES_2351872097402777148)],
        &[(0b01001, &ENTRY_DEMAGNETIZING_14763681981656800434)],
        &[(0b00001, &ENTRY_DEMAGOGUE_5181969032657952767)],
        &[(0b00001, &ENTRY_DEMAGOGUED_8161585994268339914)],
        &[(0b00001, &ENTRY_DEMAGOGUING_1728340214383068433)],
        &[(0b00001, &ENTRY_DEMAGOGUERY_18141115406054203519)],
        &[(0b00001, &ENTRY_DEMAGOGUES_12777890380184860275)],
        &[(0b10010, &ENTRY_DEMASCULINIZATION_3144268104204565212)],
        &[(0b10010, &ENTRY_DEMASCULINIZE_10705941850922882000)],
        &[(0b10010, &ENTRY_DEMASCULINIZED_14641565565158279941)],
        &[(0b10010, &ENTRY_DEMASCULINIZING_2815690345809976595)],
        &[(0b01001, &ENTRY_DEMASCULINIZATION_3144268104204565212)],
        &[(0b01001, &ENTRY_DEMASCULINIZE_10705941850922882000)],
        &[(0b01001, &ENTRY_DEMASCULINIZED_14641565565158279941)],
        &[(0b01001, &ENTRY_DEMASCULINIZING_2815690345809976595)],
        &[(0b10010, &ENTRY_DEMATERIALIZATION_12365708154794235297)],
        &[(0b10010, &ENTRY_DEMATERIALIZATIONS_3461546780666068183)],
        &[(0b10010, &ENTRY_DEMATERIALIZE_204119081752940756)],
        &[(0b10010, &ENTRY_DEMATERIALIZED_7148599036847365626)],
        &[(0b10010, &ENTRY_DEMATERIALIZES_17865238971422686230)],
        &[(0b10010, &ENTRY_DEMATERIALIZING_10155714463244702927)],
        &[(0b01001, &ENTRY_DEMATERIALIZATION_12365708154794235297)],
        &[(0b01001, &ENTRY_DEMATERIALIZATIONS_3461546780666068183)],
        &[(0b01001, &ENTRY_DEMATERIALIZE_204119081752940756)],
        &[(0b01001, &ENTRY_DEMATERIALIZED_7148599036847365626)],
        &[(0b01001, &ENTRY_DEMATERIALIZES_17865238971422686230)],
        &[(0b01001, &ENTRY_DEMATERIALIZING_10155714463244702927)],
    ],
    range: 3..=14,
};

static VARS_DEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEL_CHILDREN),
    value: None,
};

pub static VARS_DEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("imitise"),
        dictgen::InsensitiveStr::Ascii("imitises"),
        dictgen::InsensitiveStr::Ascii("imitize"),
        dictgen::InsensitiveStr::Ascii("imitizes"),
        dictgen::InsensitiveStr::Ascii("ocalisation"),
        dictgen::InsensitiveStr::Ascii("ocalisations"),
        dictgen::InsensitiveStr::Ascii("ocalise"),
        dictgen::InsensitiveStr::Ascii("ocalised"),
        dictgen::InsensitiveStr::Ascii("ocalises"),
        dictgen::InsensitiveStr::Ascii("ocalising"),
        dictgen::InsensitiveStr::Ascii("ocalization"),
        dictgen::InsensitiveStr::Ascii("ocalizations"),
        dictgen::InsensitiveStr::Ascii("ocalize"),
        dictgen::InsensitiveStr::Ascii("ocalized"),
        dictgen::InsensitiveStr::Ascii("ocalizes"),
        dictgen::InsensitiveStr::Ascii("ocalizing"),
        dictgen::InsensitiveStr::Ascii("uster"),
        dictgen::InsensitiveStr::Ascii("ustre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DELIMITIZE_16541986644088610431)],
        &[(0b10010, &ENTRY_DELIMITIZES_8971276824870720345)],
        &[(0b01001, &ENTRY_DELIMITIZE_16541986644088610431)],
        &[(0b01001, &ENTRY_DELIMITIZES_8971276824870720345)],
        &[(0b10010, &ENTRY_DELOCALIZATION_4312310346451666001)],
        &[(0b10010, &ENTRY_DELOCALIZATIONS_460587193756388712)],
        &[(0b10010, &ENTRY_DELOCALIZE_142384639921788725)],
        &[(0b10010, &ENTRY_DELOCALIZED_6707490578440021648)],
        &[(0b10010, &ENTRY_DELOCALIZES_15812480500294999003)],
        &[(0b10010, &ENTRY_DELOCALIZING_11766970531294712613)],
        &[(0b01001, &ENTRY_DELOCALIZATION_4312310346451666001)],
        &[(0b01001, &ENTRY_DELOCALIZATIONS_460587193756388712)],
        &[(0b01001, &ENTRY_DELOCALIZE_142384639921788725)],
        &[(0b01001, &ENTRY_DELOCALIZED_6707490578440021648)],
        &[(0b01001, &ENTRY_DELOCALIZES_15812480500294999003)],
        &[(0b01001, &ENTRY_DELOCALIZING_11766970531294712613)],
        &[(0b00001, &ENTRY_DELUSTER_14098580558613886243)],
        &[(0b11010, &ENTRY_DELUSTER_14098580558613886243)],
    ],
    range: 5..=12,
};

static VARS_DEK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEK_CHILDREN),
    value: None,
};

pub static VARS_DEK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("agramme"),
        dictgen::InsensitiveStr::Ascii("agrammes"),
        dictgen::InsensitiveStr::Ascii("aliter"),
        dictgen::InsensitiveStr::Ascii("aliters"),
        dictgen::InsensitiveStr::Ascii("alitre"),
        dictgen::InsensitiveStr::Ascii("alitres"),
        dictgen::InsensitiveStr::Ascii("ameter"),
        dictgen::InsensitiveStr::Ascii("ameters"),
        dictgen::InsensitiveStr::Ascii("ametre"),
        dictgen::InsensitiveStr::Ascii("ametres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEKAGRAM_12670145940876311522)],
        &[(0b10010, &ENTRY_DEKAGRAMS_16794902135907120348)],
        &[(0b00001, &ENTRY_DEKALITER_3783941176090837116)],
        &[(0b00001, &ENTRY_DEKALITERS_8450766135929935128)],
        &[(0b11010, &ENTRY_DEKALITER_3783941176090837116)],
        &[(0b11010, &ENTRY_DEKALITERS_8450766135929935128)],
        &[(0b00001, &ENTRY_DEKAMETER_12894292200985003434)],
        &[(0b00001, &ENTRY_DEKAMETERS_17531050124125527369)],
        &[(0b11010, &ENTRY_DEKAMETER_12894292200985003434)],
        &[(0b11010, &ENTRY_DEKAMETERS_17531050124125527369)],
    ],
    range: 6..=8,
};

static VARS_DEI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEI_CHILDREN),
    value: None,
};

pub static VARS_DEI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndustrialisation"),
        dictgen::InsensitiveStr::Ascii("ndustrialisations"),
        dictgen::InsensitiveStr::Ascii("ndustrialise"),
        dictgen::InsensitiveStr::Ascii("ndustrialised"),
        dictgen::InsensitiveStr::Ascii("ndustrialises"),
        dictgen::InsensitiveStr::Ascii("ndustrialising"),
        dictgen::InsensitiveStr::Ascii("ndustrialization"),
        dictgen::InsensitiveStr::Ascii("ndustrializations"),
        dictgen::InsensitiveStr::Ascii("ndustrialize"),
        dictgen::InsensitiveStr::Ascii("ndustrialized"),
        dictgen::InsensitiveStr::Ascii("ndustrializes"),
        dictgen::InsensitiveStr::Ascii("ndustrializing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEINDUSTRIALIZATION_14471451768199148096)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZATIONS_15910460441488223406)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZE_15995862968967762494)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZED_1125754572889024423)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZES_13990996861462469130)],
        &[(0b10010, &ENTRY_DEINDUSTRIALIZING_3929932887349601221)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZATION_14471451768199148096)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZATIONS_15910460441488223406)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZE_15995862968967762494)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZED_1125754572889024423)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZES_13990996861462469130)],
        &[(0b01001, &ENTRY_DEINDUSTRIALIZING_3929932887349601221)],
        &[(0b10010, &ENTRY_DEIONIZATION_18037411003245501415)],
        &[(0b10010, &ENTRY_DEIONIZE_3742251118696055698)],
        &[(0b10010, &ENTRY_DEIONIZED_18147519954228604298)],
        &[(0b10010, &ENTRY_DEIONIZES_2511822428052345171)],
        &[(0b10010, &ENTRY_DEIONIZING_3409760745768493185)],
        &[(0b01001, &ENTRY_DEIONIZATION_18037411003245501415)],
        &[(0b01001, &ENTRY_DEIONIZE_3742251118696055698)],
        &[(0b01001, &ENTRY_DEIONIZED_18147519954228604298)],
        &[(0b01001, &ENTRY_DEIONIZES_2511822428052345171)],
        &[(0b01001, &ENTRY_DEIONIZING_3409760745768493185)],
    ],
    range: 5..=17,
};

static VARS_DEH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEH_CHILDREN),
    value: None,
};

pub static VARS_DEH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("umanisation"),
        dictgen::InsensitiveStr::Ascii("umanisations"),
        dictgen::InsensitiveStr::Ascii("umanise"),
        dictgen::InsensitiveStr::Ascii("umanised"),
        dictgen::InsensitiveStr::Ascii("umanises"),
        dictgen::InsensitiveStr::Ascii("umanising"),
        dictgen::InsensitiveStr::Ascii("umanization"),
        dictgen::InsensitiveStr::Ascii("umanizations"),
        dictgen::InsensitiveStr::Ascii("umanize"),
        dictgen::InsensitiveStr::Ascii("umanized"),
        dictgen::InsensitiveStr::Ascii("umanizes"),
        dictgen::InsensitiveStr::Ascii("umanizing"),
        dictgen::InsensitiveStr::Ascii("ydrogenisation"),
        dictgen::InsensitiveStr::Ascii("ydrogenise"),
        dictgen::InsensitiveStr::Ascii("ydrogenised"),
        dictgen::InsensitiveStr::Ascii("ydrogeniser"),
        dictgen::InsensitiveStr::Ascii("ydrogenising"),
        dictgen::InsensitiveStr::Ascii("ydrogenization"),
        dictgen::InsensitiveStr::Ascii("ydrogenize"),
        dictgen::InsensitiveStr::Ascii("ydrogenized"),
        dictgen::InsensitiveStr::Ascii("ydrogenizer"),
        dictgen::InsensitiveStr::Ascii("ydrogenizing"),
        dictgen::InsensitiveStr::Ascii("ypnotisation"),
        dictgen::InsensitiveStr::Ascii("ypnotisations"),
        dictgen::InsensitiveStr::Ascii("ypnotise"),
        dictgen::InsensitiveStr::Ascii("ypnotised"),
        dictgen::InsensitiveStr::Ascii("ypnotises"),
        dictgen::InsensitiveStr::Ascii("ypnotising"),
        dictgen::InsensitiveStr::Ascii("ypnotization"),
        dictgen::InsensitiveStr::Ascii("ypnotizations"),
        dictgen::InsensitiveStr::Ascii("ypnotize"),
        dictgen::InsensitiveStr::Ascii("ypnotized"),
        dictgen::InsensitiveStr::Ascii("ypnotizes"),
        dictgen::InsensitiveStr::Ascii("ypnotizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEHUMANIZATION_3572788173744551934)],
        &[(0b10010, &ENTRY_DEHUMANIZATIONS_6897797502184645692)],
        &[(0b10010, &ENTRY_DEHUMANIZE_2232272408872299361)],
        &[(0b10010, &ENTRY_DEHUMANIZED_2513733723938163946)],
        &[(0b10010, &ENTRY_DEHUMANIZES_79010027424209477)],
        &[(0b10010, &ENTRY_DEHUMANIZING_18121800466455281577)],
        &[(0b01001, &ENTRY_DEHUMANIZATION_3572788173744551934)],
        &[(0b01001, &ENTRY_DEHUMANIZATIONS_6897797502184645692)],
        &[(0b01001, &ENTRY_DEHUMANIZE_2232272408872299361)],
        &[(0b01001, &ENTRY_DEHUMANIZED_2513733723938163946)],
        &[(0b01001, &ENTRY_DEHUMANIZES_79010027424209477)],
        &[(0b01001, &ENTRY_DEHUMANIZING_18121800466455281577)],
        &[(0b10010, &ENTRY_DEHYDROGENIZATION_17529379708129741720)],
        &[(0b10010, &ENTRY_DEHYDROGENIZE_7036691670691764716)],
        &[(0b10010, &ENTRY_DEHYDROGENIZED_4042573802152435240)],
        &[(0b10010, &ENTRY_DEHYDROGENIZER_8525507183037678721)],
        &[(0b10010, &ENTRY_DEHYDROGENIZING_5974089619476922717)],
        &[(0b01001, &ENTRY_DEHYDROGENIZATION_17529379708129741720)],
        &[(0b01001, &ENTRY_DEHYDROGENIZE_7036691670691764716)],
        &[(0b01001, &ENTRY_DEHYDROGENIZED_4042573802152435240)],
        &[(0b01001, &ENTRY_DEHYDROGENIZER_8525507183037678721)],
        &[(0b01001, &ENTRY_DEHYDROGENIZING_5974089619476922717)],
        &[(0b10010, &ENTRY_DEHYPNOTIZATION_12210599348961381724)],
        &[(0b10010, &ENTRY_DEHYPNOTIZATIONS_4718849388849423582)],
        &[(0b10010, &ENTRY_DEHYPNOTIZE_10726010356831719725)],
        &[(0b10010, &ENTRY_DEHYPNOTIZED_6695632276418370962)],
        &[(0b10010, &ENTRY_DEHYPNOTIZES_6146772561847797201)],
        &[(0b10010, &ENTRY_DEHYPNOTIZING_12455661718180344756)],
        &[(0b01001, &ENTRY_DEHYPNOTIZATION_12210599348961381724)],
        &[(0b01001, &ENTRY_DEHYPNOTIZATIONS_4718849388849423582)],
        &[(0b01001, &ENTRY_DEHYPNOTIZE_10726010356831719725)],
        &[(0b01001, &ENTRY_DEHYPNOTIZED_6695632276418370962)],
        &[(0b01001, &ENTRY_DEHYPNOTIZES_6146772561847797201)],
        &[(0b01001, &ENTRY_DEHYPNOTIZING_12455661718180344756)],
    ],
    range: 7..=14,
};

static VARS_DEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEG_CHILDREN),
    value: None,
};

pub static VARS_DEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lycerolised"),
        dictgen::InsensitiveStr::Ascii("lycerolized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEGLYCEROLIZED_5620184830818473145)],
        &[(0b01001, &ENTRY_DEGLYCEROLIZED_5620184830818473145)],
    ],
    range: 11..=11,
};

static VARS_DEF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEF_CHILDREN),
    value: None,
};

static VARS_DEF_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_DEFE_NODE),
    None,
    None,
    None,
    Some(&VARS_DEFI_NODE),
    None,
    None,
    Some(&VARS_DEFL_NODE),
    None,
    None,
    Some(&VARS_DEFO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DEFU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_DEFU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFU_CHILDREN),
    value: None,
};

pub static VARS_DEFU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nctionalisation"),
        dictgen::InsensitiveStr::Ascii("nctionalisations"),
        dictgen::InsensitiveStr::Ascii("nctionalise"),
        dictgen::InsensitiveStr::Ascii("nctionalises"),
        dictgen::InsensitiveStr::Ascii("nctionalization"),
        dictgen::InsensitiveStr::Ascii("nctionalizations"),
        dictgen::InsensitiveStr::Ascii("nctionalize"),
        dictgen::InsensitiveStr::Ascii("nctionalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEFUNCTIONALIZATION_13807631024565298493)],
        &[(0b10010, &ENTRY_DEFUNCTIONALIZATIONS_13484968269526464929)],
        &[(0b10010, &ENTRY_DEFUNCTIONALIZE_3067764666659364877)],
        &[(0b10010, &ENTRY_DEFUNCTIONALIZES_2354126124027039718)],
        &[(0b01001, &ENTRY_DEFUNCTIONALIZATION_13807631024565298493)],
        &[(0b01001, &ENTRY_DEFUNCTIONALIZATIONS_13484968269526464929)],
        &[(0b01001, &ENTRY_DEFUNCTIONALIZE_3067764666659364877)],
        &[(0b01001, &ENTRY_DEFUNCTIONALIZES_2354126124027039718)],
    ],
    range: 11..=16,
};

static VARS_DEFO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFO_CHILDREN),
    value: None,
};

pub static VARS_DEFO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edation"),
        dictgen::InsensitiveStr::Ascii("rmalise"),
        dictgen::InsensitiveStr::Ascii("rmalize"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DEFEDATION_1250124429421953221)],
        &[(0b10010, &ENTRY_DEFORMALIZE_15907382900288731005)],
        &[(0b01001, &ENTRY_DEFORMALIZE_15907382900288731005)],
    ],
    range: 7..=7,
};

static VARS_DEFL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFL_CHILDREN),
    value: None,
};

pub static VARS_DEFL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ectionisation"),
        dictgen::InsensitiveStr::Ascii("ectionisations"),
        dictgen::InsensitiveStr::Ascii("ectionise"),
        dictgen::InsensitiveStr::Ascii("ectionises"),
        dictgen::InsensitiveStr::Ascii("ectionization"),
        dictgen::InsensitiveStr::Ascii("ectionizations"),
        dictgen::InsensitiveStr::Ascii("ectionize"),
        dictgen::InsensitiveStr::Ascii("ectionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEFLECTIONIZATION_11878097824098112217)],
        &[(0b10010, &ENTRY_DEFLECTIONIZATIONS_17851027536180674050)],
        &[(0b10010, &ENTRY_DEFLECTIONIZE_3095690419241116219)],
        &[(0b10010, &ENTRY_DEFLECTIONIZES_6073384244042155810)],
        &[(0b01001, &ENTRY_DEFLECTIONIZATION_11878097824098112217)],
        &[(0b01001, &ENTRY_DEFLECTIONIZATIONS_17851027536180674050)],
        &[(0b01001, &ENTRY_DEFLECTIONIZE_3095690419241116219)],
        &[(0b01001, &ENTRY_DEFLECTIONIZES_6073384244042155810)],
    ],
    range: 9..=14,
};

static VARS_DEFI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFI_CHILDREN),
    value: None,
};

pub static VARS_DEFI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("brinise"),
        dictgen::InsensitiveStr::Ascii("brinised"),
        dictgen::InsensitiveStr::Ascii("brinises"),
        dictgen::InsensitiveStr::Ascii("brinising"),
        dictgen::InsensitiveStr::Ascii("brinize"),
        dictgen::InsensitiveStr::Ascii("brinized"),
        dictgen::InsensitiveStr::Ascii("brinizes"),
        dictgen::InsensitiveStr::Ascii("brinizing"),
        dictgen::InsensitiveStr::Ascii("nitisation"),
        dictgen::InsensitiveStr::Ascii("nitisations"),
        dictgen::InsensitiveStr::Ascii("nitise"),
        dictgen::InsensitiveStr::Ascii("nitised"),
        dictgen::InsensitiveStr::Ascii("nitises"),
        dictgen::InsensitiveStr::Ascii("nitising"),
        dictgen::InsensitiveStr::Ascii("nitization"),
        dictgen::InsensitiveStr::Ascii("nitizations"),
        dictgen::InsensitiveStr::Ascii("nitize"),
        dictgen::InsensitiveStr::Ascii("nitized"),
        dictgen::InsensitiveStr::Ascii("nitizes"),
        dictgen::InsensitiveStr::Ascii("nitizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEFIBRINIZE_18283930865175559011)],
        &[(0b10010, &ENTRY_DEFIBRINIZED_142002320112068005)],
        &[(0b10010, &ENTRY_DEFIBRINIZES_7864712038065216074)],
        &[(0b10010, &ENTRY_DEFIBRINIZING_15126402992130628305)],
        &[(0b01001, &ENTRY_DEFIBRINIZE_18283930865175559011)],
        &[(0b01001, &ENTRY_DEFIBRINIZED_142002320112068005)],
        &[(0b01001, &ENTRY_DEFIBRINIZES_7864712038065216074)],
        &[(0b01001, &ENTRY_DEFIBRINIZING_15126402992130628305)],
        &[(0b10010, &ENTRY_DEFINITIZATION_7958601692772655221)],
        &[(0b10010, &ENTRY_DEFINITIZATIONS_2927011527962264879)],
        &[(0b10010, &ENTRY_DEFINITIZE_13578665782923325519)],
        &[(0b10010, &ENTRY_DEFINITIZED_9429215788712667143)],
        &[(0b10010, &ENTRY_DEFINITIZES_5808003072438523190)],
        &[(0b10010, &ENTRY_DEFINITIZING_17784497757438565701)],
        &[(0b01001, &ENTRY_DEFINITIZATION_7958601692772655221)],
        &[(0b01001, &ENTRY_DEFINITIZATIONS_2927011527962264879)],
        &[(0b01001, &ENTRY_DEFINITIZE_13578665782923325519)],
        &[(0b01001, &ENTRY_DEFINITIZED_9429215788712667143)],
        &[(0b01001, &ENTRY_DEFINITIZES_5808003072438523190)],
        &[(0b01001, &ENTRY_DEFINITIZING_17784497757438565701)],
    ],
    range: 6..=11,
};

static VARS_DEFE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEFE_CHILDREN),
    value: None,
};

pub static VARS_DEFE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dation"),
        dictgen::InsensitiveStr::Ascii("minisation"),
        dictgen::InsensitiveStr::Ascii("minise"),
        dictgen::InsensitiveStr::Ascii("minised"),
        dictgen::InsensitiveStr::Ascii("minises"),
        dictgen::InsensitiveStr::Ascii("minising"),
        dictgen::InsensitiveStr::Ascii("minization"),
        dictgen::InsensitiveStr::Ascii("minize"),
        dictgen::InsensitiveStr::Ascii("minized"),
        dictgen::InsensitiveStr::Ascii("minizes"),
        dictgen::InsensitiveStr::Ascii("minizing"),
        dictgen::InsensitiveStr::Ascii("nce"),
        dictgen::InsensitiveStr::Ascii("nced"),
        dictgen::InsensitiveStr::Ascii("nceless"),
        dictgen::InsensitiveStr::Ascii("ncelesser"),
        dictgen::InsensitiveStr::Ascii("ncelessest"),
        dictgen::InsensitiveStr::Ascii("ncelesslier"),
        dictgen::InsensitiveStr::Ascii("ncelessliest"),
        dictgen::InsensitiveStr::Ascii("ncelessly"),
        dictgen::InsensitiveStr::Ascii("ncelessness"),
        dictgen::InsensitiveStr::Ascii("ncelessnesses"),
        dictgen::InsensitiveStr::Ascii("nceman"),
        dictgen::InsensitiveStr::Ascii("ncemen"),
        dictgen::InsensitiveStr::Ascii("nces"),
        dictgen::InsensitiveStr::Ascii("ncing"),
        dictgen::InsensitiveStr::Ascii("nse"),
        dictgen::InsensitiveStr::Ascii("nsed"),
        dictgen::InsensitiveStr::Ascii("nseless"),
        dictgen::InsensitiveStr::Ascii("nselesser"),
        dictgen::InsensitiveStr::Ascii("nselessest"),
        dictgen::InsensitiveStr::Ascii("nselesslier"),
        dictgen::InsensitiveStr::Ascii("nselessliest"),
        dictgen::InsensitiveStr::Ascii("nselessly"),
        dictgen::InsensitiveStr::Ascii("nselessness"),
        dictgen::InsensitiveStr::Ascii("nselessnesses"),
        dictgen::InsensitiveStr::Ascii("nseman"),
        dictgen::InsensitiveStr::Ascii("nsemen"),
        dictgen::InsensitiveStr::Ascii("nses"),
        dictgen::InsensitiveStr::Ascii("nsing"),
        dictgen::InsensitiveStr::Ascii("udalise"),
        dictgen::InsensitiveStr::Ascii("udalised"),
        dictgen::InsensitiveStr::Ascii("udalises"),
        dictgen::InsensitiveStr::Ascii("udalising"),
        dictgen::InsensitiveStr::Ascii("udalize"),
        dictgen::InsensitiveStr::Ascii("udalized"),
        dictgen::InsensitiveStr::Ascii("udalizes"),
        dictgen::InsensitiveStr::Ascii("udalizing"),
    ],
    values: &[
        &[(0b10001, &ENTRY_DEFEDATION_1250124429421953221)],
        &[(0b10010, &ENTRY_DEFEMINIZATION_10970895057607673057)],
        &[(0b10010, &ENTRY_DEFEMINIZE_2460703809552770265)],
        &[(0b10010, &ENTRY_DEFEMINIZED_501903520845893607)],
        &[(0b10010, &ENTRY_DEFEMINIZES_13215201164940484905)],
        &[(0b10010, &ENTRY_DEFEMINIZING_2126786312766733725)],
        &[(0b01001, &ENTRY_DEFEMINIZATION_10970895057607673057)],
        &[(0b01001, &ENTRY_DEFEMINIZE_2460703809552770265)],
        &[(0b01001, &ENTRY_DEFEMINIZED_501903520845893607)],
        &[(0b01001, &ENTRY_DEFEMINIZES_13215201164940484905)],
        &[(0b01001, &ENTRY_DEFEMINIZING_2126786312766733725)],
        &[(0b11010, &ENTRY_DEFENSE_11018687793676709280)],
        &[(0b11010, &ENTRY_DEFENSED_4741744499926552984)],
        &[(0b11010, &ENTRY_DEFENSELESS_10794271276397387569)],
        &[(0b11010, &ENTRY_DEFENSELESSER_14429190642942612093)],
        &[(0b11010, &ENTRY_DEFENSELESSEST_2810886385008994530)],
        &[(0b11010, &ENTRY_DEFENSELESSLIER_16858376230646568189)],
        &[(0b11010, &ENTRY_DEFENSELESSLIEST_4063724903759190513)],
        &[(0b11010, &ENTRY_DEFENSELESSLY_14439715594919858663)],
        &[(0b11010, &ENTRY_DEFENSELESSNESS_12644024888445988945)],
        &[(0b11010, &ENTRY_DEFENSELESSNESSES_18348884860793393516)],
        &[(0b11010, &ENTRY_DEFENSEMAN_4178732654030128668)],
        &[(0b11010, &ENTRY_DEFENSEMEN_13356773840082441675)],
        &[(0b11010, &ENTRY_DEFENSES_17918359003970109622)],
        &[(0b11010, &ENTRY_DEFENSING_13872432362849183791)],
        &[(0b01001, &ENTRY_DEFENSE_11018687793676709280)],
        &[(0b01001, &ENTRY_DEFENSED_4741744499926552984)],
        &[(0b00001, &ENTRY_DEFENSELESS_10794271276397387569)],
        &[(0b00001, &ENTRY_DEFENSELESSER_14429190642942612093)],
        &[(0b00001, &ENTRY_DEFENSELESSEST_2810886385008994530)],
        &[(0b00001, &ENTRY_DEFENSELESSLIER_16858376230646568189)],
        &[(0b00001, &ENTRY_DEFENSELESSLIEST_4063724903759190513)],
        &[(0b00001, &ENTRY_DEFENSELESSLY_14439715594919858663)],
        &[(0b00001, &ENTRY_DEFENSELESSNESS_12644024888445988945)],
        &[(0b00001, &ENTRY_DEFENSELESSNESSES_18348884860793393516)],
        &[(0b00001, &ENTRY_DEFENSEMAN_4178732654030128668)],
        &[(0b00001, &ENTRY_DEFENSEMEN_13356773840082441675)],
        &[(0b01001, &ENTRY_DEFENSES_17918359003970109622)],
        &[(0b01001, &ENTRY_DEFENSING_13872432362849183791)],
        &[(0b10010, &ENTRY_DEFEUDALIZE_6153813523071316351)],
        &[(0b10010, &ENTRY_DEFEUDALIZED_10926320617236271428)],
        &[(0b10010, &ENTRY_DEFEUDALIZES_8548426077225192329)],
        &[(0b10010, &ENTRY_DEFEUDALIZING_6851219039661107804)],
        &[(0b01001, &ENTRY_DEFEUDALIZE_6153813523071316351)],
        &[(0b01001, &ENTRY_DEFEUDALIZED_10926320617236271428)],
        &[(0b01001, &ENTRY_DEFEUDALIZES_8548426077225192329)],
        &[(0b01001, &ENTRY_DEFEUDALIZING_6851219039661107804)],
    ],
    range: 3..=13,
};

static VARS_DEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEE_CHILDREN),
    value: None,
};

pub static VARS_DEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mphasisation"),
        dictgen::InsensitiveStr::Ascii("mphasise"),
        dictgen::InsensitiveStr::Ascii("mphasised"),
        dictgen::InsensitiveStr::Ascii("mphasiser"),
        dictgen::InsensitiveStr::Ascii("mphasisers"),
        dictgen::InsensitiveStr::Ascii("mphasises"),
        dictgen::InsensitiveStr::Ascii("mphasising"),
        dictgen::InsensitiveStr::Ascii("mphasization"),
        dictgen::InsensitiveStr::Ascii("mphasize"),
        dictgen::InsensitiveStr::Ascii("mphasized"),
        dictgen::InsensitiveStr::Ascii("mphasizer"),
        dictgen::InsensitiveStr::Ascii("mphasizers"),
        dictgen::InsensitiveStr::Ascii("mphasizes"),
        dictgen::InsensitiveStr::Ascii("mphasizing"),
        dictgen::InsensitiveStr::Ascii("nergise"),
        dictgen::InsensitiveStr::Ascii("nergised"),
        dictgen::InsensitiveStr::Ascii("nergiser"),
        dictgen::InsensitiveStr::Ascii("nergises"),
        dictgen::InsensitiveStr::Ascii("nergising"),
        dictgen::InsensitiveStr::Ascii("nergize"),
        dictgen::InsensitiveStr::Ascii("nergized"),
        dictgen::InsensitiveStr::Ascii("nergizer"),
        dictgen::InsensitiveStr::Ascii("nergizes"),
        dictgen::InsensitiveStr::Ascii("nergizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEEMPHASIZATION_17228655479618550538)],
        &[(0b10010, &ENTRY_DEEMPHASIZE_17692949100195205354)],
        &[(0b10010, &ENTRY_DEEMPHASIZED_14166971579948169339)],
        &[(0b10010, &ENTRY_DEEMPHASIZER_2232629022737279052)],
        &[(0b10010, &ENTRY_DEEMPHASIZERS_13733231012811038223)],
        &[(0b10010, &ENTRY_DEEMPHASIZES_13005114554703747835)],
        &[(0b10010, &ENTRY_DEEMPHASIZING_11093382399783111373)],
        &[(0b01001, &ENTRY_DEEMPHASIZATION_17228655479618550538)],
        &[(0b01001, &ENTRY_DEEMPHASIZE_17692949100195205354)],
        &[(0b01001, &ENTRY_DEEMPHASIZED_14166971579948169339)],
        &[(0b01001, &ENTRY_DEEMPHASIZER_2232629022737279052)],
        &[(0b01001, &ENTRY_DEEMPHASIZERS_13733231012811038223)],
        &[(0b01001, &ENTRY_DEEMPHASIZES_13005114554703747835)],
        &[(0b01001, &ENTRY_DEEMPHASIZING_11093382399783111373)],
        &[(0b10010, &ENTRY_DEENERGIZE_12832371231418785666)],
        &[(0b10010, &ENTRY_DEENERGIZED_11846795185389581725)],
        &[(0b10010, &ENTRY_DEENERGIZER_385500425712909906)],
        &[(0b10010, &ENTRY_DEENERGIZES_12119467381981965243)],
        &[(0b10010, &ENTRY_DEENERGIZING_5214336872196253860)],
        &[(0b01001, &ENTRY_DEENERGIZE_12832371231418785666)],
        &[(0b01001, &ENTRY_DEENERGIZED_11846795185389581725)],
        &[(0b01001, &ENTRY_DEENERGIZER_385500425712909906)],
        &[(0b01001, &ENTRY_DEENERGIZES_12119467381981965243)],
        &[(0b01001, &ENTRY_DEENERGIZING_5214336872196253860)],
    ],
    range: 7..=12,
};

static VARS_DED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DED_CHILDREN),
    value: None,
};

pub static VARS_DED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("alian"),
        dictgen::InsensitiveStr::Ascii("ramatise"),
        dictgen::InsensitiveStr::Ascii("ramatised"),
        dictgen::InsensitiveStr::Ascii("ramatises"),
        dictgen::InsensitiveStr::Ascii("ramatising"),
        dictgen::InsensitiveStr::Ascii("ramatize"),
        dictgen::InsensitiveStr::Ascii("ramatized"),
        dictgen::InsensitiveStr::Ascii("ramatizes"),
        dictgen::InsensitiveStr::Ascii("ramatizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DEDAL_3527172992604688330)],
        &[(0b00001, &ENTRY_DEDALIAN_1818689560079214410)],
        &[(0b10010, &ENTRY_DEDRAMATIZE_13453343698039522020)],
        &[(0b10010, &ENTRY_DEDRAMATIZED_322035020814147818)],
        &[(0b10010, &ENTRY_DEDRAMATIZES_17967690669487003147)],
        &[(0b10010, &ENTRY_DEDRAMATIZING_62928488875515887)],
        &[(0b01001, &ENTRY_DEDRAMATIZE_13453343698039522020)],
        &[(0b01001, &ENTRY_DEDRAMATIZED_322035020814147818)],
        &[(0b01001, &ENTRY_DEDRAMATIZES_17967690669487003147)],
        &[(0b01001, &ENTRY_DEDRAMATIZING_62928488875515887)],
    ],
    range: 2..=10,
};

static VARS_DEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_DEC_CHILDREN),
    value: None,
};

static VARS_DEC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_DECA_NODE),
    None,
    None,
    None,
    Some(&VARS_DECE_NODE),
    None,
    None,
    Some(&VARS_DECH_NODE),
    Some(&VARS_DECI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_DECO_NODE),
    None,
    None,
    Some(&VARS_DECR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_DECR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECR_CHILDREN),
    value: None,
};

pub static VARS_DECR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iminalisation"),
        dictgen::InsensitiveStr::Ascii("iminalisations"),
        dictgen::InsensitiveStr::Ascii("iminalise"),
        dictgen::InsensitiveStr::Ascii("iminalised"),
        dictgen::InsensitiveStr::Ascii("iminalises"),
        dictgen::InsensitiveStr::Ascii("iminalising"),
        dictgen::InsensitiveStr::Ascii("iminalization"),
        dictgen::InsensitiveStr::Ascii("iminalizations"),
        dictgen::InsensitiveStr::Ascii("iminalize"),
        dictgen::InsensitiveStr::Ascii("iminalized"),
        dictgen::InsensitiveStr::Ascii("iminalizes"),
        dictgen::InsensitiveStr::Ascii("iminalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DECRIMINALIZATION_11495835016656319471)],
        &[(0b10010, &ENTRY_DECRIMINALIZATIONS_8826141293763176549)],
        &[(0b10010, &ENTRY_DECRIMINALIZE_6091198611704708595)],
        &[(0b10010, &ENTRY_DECRIMINALIZED_14857350688716779167)],
        &[(0b10010, &ENTRY_DECRIMINALIZES_6368952306309816010)],
        &[(0b10010, &ENTRY_DECRIMINALIZING_16672118604268496422)],
        &[(0b01001, &ENTRY_DECRIMINALIZATION_11495835016656319471)],
        &[(0b01001, &ENTRY_DECRIMINALIZATIONS_8826141293763176549)],
        &[(0b01001, &ENTRY_DECRIMINALIZE_6091198611704708595)],
        &[(0b01001, &ENTRY_DECRIMINALIZED_14857350688716779167)],
        &[(0b01001, &ENTRY_DECRIMINALIZES_6368952306309816010)],
        &[(0b01001, &ENTRY_DECRIMINALIZING_16672118604268496422)],
    ],
    range: 9..=14,
};

static VARS_DECO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECO_CHILDREN),
    value: None,
};

pub static VARS_DECO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lonisation"),
        dictgen::InsensitiveStr::Ascii("lonisations"),
        dictgen::InsensitiveStr::Ascii("lonise"),
        dictgen::InsensitiveStr::Ascii("lonised"),
        dictgen::InsensitiveStr::Ascii("lonises"),
        dictgen::InsensitiveStr::Ascii("lonising"),
        dictgen::InsensitiveStr::Ascii("lonization"),
        dictgen::InsensitiveStr::Ascii("lonizations"),
        dictgen::InsensitiveStr::Ascii("lonize"),
        dictgen::InsensitiveStr::Ascii("lonized"),
        dictgen::InsensitiveStr::Ascii("lonizes"),
        dictgen::InsensitiveStr::Ascii("lonizing"),
        dictgen::InsensitiveStr::Ascii("lor"),
        dictgen::InsensitiveStr::Ascii("lorant"),
        dictgen::InsensitiveStr::Ascii("lorants"),
        dictgen::InsensitiveStr::Ascii("lorate"),
        dictgen::InsensitiveStr::Ascii("lorated"),
        dictgen::InsensitiveStr::Ascii("lorates"),
        dictgen::InsensitiveStr::Ascii("loration"),
        dictgen::InsensitiveStr::Ascii("lorations"),
        dictgen::InsensitiveStr::Ascii("lored"),
        dictgen::InsensitiveStr::Ascii("lorimeter"),
        dictgen::InsensitiveStr::Ascii("loring"),
        dictgen::InsensitiveStr::Ascii("lorization"),
        dictgen::InsensitiveStr::Ascii("lorizations"),
        dictgen::InsensitiveStr::Ascii("lorize"),
        dictgen::InsensitiveStr::Ascii("lorized"),
        dictgen::InsensitiveStr::Ascii("lorizer"),
        dictgen::InsensitiveStr::Ascii("lorizers"),
        dictgen::InsensitiveStr::Ascii("lorizes"),
        dictgen::InsensitiveStr::Ascii("lorizing"),
        dictgen::InsensitiveStr::Ascii("lors"),
        dictgen::InsensitiveStr::Ascii("lour"),
        dictgen::InsensitiveStr::Ascii("lourant"),
        dictgen::InsensitiveStr::Ascii("lourants"),
        dictgen::InsensitiveStr::Ascii("lourate"),
        dictgen::InsensitiveStr::Ascii("lourated"),
        dictgen::InsensitiveStr::Ascii("lourates"),
        dictgen::InsensitiveStr::Ascii("louration"),
        dictgen::InsensitiveStr::Ascii("lourations"),
        dictgen::InsensitiveStr::Ascii("loured"),
        dictgen::InsensitiveStr::Ascii("lourimeter"),
        dictgen::InsensitiveStr::Ascii("louring"),
        dictgen::InsensitiveStr::Ascii("lourisation"),
        dictgen::InsensitiveStr::Ascii("lourisations"),
        dictgen::InsensitiveStr::Ascii("lourise"),
        dictgen::InsensitiveStr::Ascii("lourised"),
        dictgen::InsensitiveStr::Ascii("louriser"),
        dictgen::InsensitiveStr::Ascii("lourisers"),
        dictgen::InsensitiveStr::Ascii("lourises"),
        dictgen::InsensitiveStr::Ascii("lourising"),
        dictgen::InsensitiveStr::Ascii("lourization"),
        dictgen::InsensitiveStr::Ascii("lourizations"),
        dictgen::InsensitiveStr::Ascii("lourize"),
        dictgen::InsensitiveStr::Ascii("lourized"),
        dictgen::InsensitiveStr::Ascii("lourizer"),
        dictgen::InsensitiveStr::Ascii("lourizers"),
        dictgen::InsensitiveStr::Ascii("lourizes"),
        dictgen::InsensitiveStr::Ascii("lourizing"),
        dictgen::InsensitiveStr::Ascii("lours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DECOLONIZATION_14844676044557344393)],
        &[(0b10010, &ENTRY_DECOLONIZATIONS_15473229397920826981)],
        &[(0b10010, &ENTRY_DECOLONIZE_8704444043034616664)],
        &[(0b10010, &ENTRY_DECOLONIZED_2468128191816289613)],
        &[(0b10010, &ENTRY_DECOLONIZES_17529571225109301692)],
        &[(0b10010, &ENTRY_DECOLONIZING_15890941705265622387)],
        &[(0b01001, &ENTRY_DECOLONIZATION_14844676044557344393)],
        &[(0b01001, &ENTRY_DECOLONIZATIONS_15473229397920826981)],
        &[(0b01001, &ENTRY_DECOLONIZE_8704444043034616664)],
        &[(0b01001, &ENTRY_DECOLONIZED_2468128191816289613)],
        &[(0b01001, &ENTRY_DECOLONIZES_17529571225109301692)],
        &[(0b01001, &ENTRY_DECOLONIZING_15890941705265622387)],
        &[(0b11001, &ENTRY_DECOLOR_5736949126416349048)],
        &[(0b11001, &ENTRY_DECOLORANT_5335359943030311716)],
        &[(0b11001, &ENTRY_DECOLORANTS_14395800598549575388)],
        &[(0b00001, &ENTRY_DECOLORATE_16171421314227384757)],
        &[(0b00001, &ENTRY_DECOLORATED_13361198090261586484)],
        &[(0b00001, &ENTRY_DECOLORATES_970217286770855278)],
        &[(0b00001, &ENTRY_DECOLORATION_687527831916147355)],
        &[(0b00001, &ENTRY_DECOLORATIONS_5937830887779716004)],
        &[(0b11001, &ENTRY_DECOLORED_12789961260525747964)],
        &[(0b00001, &ENTRY_DECOLORIMETER_9685638258569395132)],
        &[(0b11001, &ENTRY_DECOLORING_6691256159228887702)],
        &[(0b00001, &ENTRY_DECOLORIZATION_9440321833606051398)],
        &[(0b00001, &ENTRY_DECOLORIZATIONS_5583822483356878390)],
        &[(0b00001, &ENTRY_DECOLORIZE_10787926865254737924)],
        &[(0b00001, &ENTRY_DECOLORIZED_17864546395597600300)],
        &[(0b00001, &ENTRY_DECOLORIZER_1117085801636205705)],
        &[(0b00001, &ENTRY_DECOLORIZERS_2577270439983901494)],
        &[(0b00001, &ENTRY_DECOLORIZES_5066928271122015081)],
        &[(0b00001, &ENTRY_DECOLORIZING_16950423814877555244)],
        &[(0b11001, &ENTRY_DECOLORS_121898289642929190)],
        &[(0b11010, &ENTRY_DECOLOR_5736949126416349048)],
        &[(0b11010, &ENTRY_DECOLORANT_5335359943030311716)],
        &[(0b11010, &ENTRY_DECOLORANTS_14395800598549575388)],
        &[(0b11010, &ENTRY_DECOLORATE_16171421314227384757)],
        &[(0b11010, &ENTRY_DECOLORATED_13361198090261586484)],
        &[(0b11010, &ENTRY_DECOLORATES_970217286770855278)],
        &[(0b11010, &ENTRY_DECOLORATION_687527831916147355)],
        &[(0b11010, &ENTRY_DECOLORATIONS_5937830887779716004)],
        &[(0b11010, &ENTRY_DECOLORED_12789961260525747964)],
        &[(0b11010, &ENTRY_DECOLORIMETER_9685638258569395132)],
        &[(0b11010, &ENTRY_DECOLORING_6691256159228887702)],
        &[(0b10010, &ENTRY_DECOLORIZATION_9440321833606051398)],
        &[(0b10010, &ENTRY_DECOLORIZATIONS_5583822483356878390)],
        &[(0b10010, &ENTRY_DECOLORIZE_10787926865254737924)],
        &[(0b10010, &ENTRY_DECOLORIZED_17864546395597600300)],
        &[(0b10010, &ENTRY_DECOLORIZER_1117085801636205705)],
        &[(0b10010, &ENTRY_DECOLORIZERS_2577270439983901494)],
        &[(0b10010, &ENTRY_DECOLORIZES_5066928271122015081)],
        &[(0b10010, &ENTRY_DECOLORIZING_16950423814877555244)],
        &[(0b01000, &ENTRY_DECOLORIZATION_9440321833606051398)],
        &[(0b01000, &ENTRY_DECOLORIZATIONS_5583822483356878390)],
        &[(0b01000, &ENTRY_DECOLORIZE_10787926865254737924)],
        &[(0b01000, &ENTRY_DECOLORIZED_17864546395597600300)],
        &[(0b01000, &ENTRY_DECOLORIZER_1117085801636205705)],
        &[(0b01000, &ENTRY_DECOLORIZERS_2577270439983901494)],
        &[(0b01000, &ENTRY_DECOLORIZES_5066928271122015081)],
        &[(0b01000, &ENTRY_DECOLORIZING_16950423814877555244)],
        &[(0b11010, &ENTRY_DECOLORS_121898289642929190)],
    ],
    range: 3..=12,
};

static VARS_DECI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECI_CHILDREN),
    value: None,
};

pub static VARS_DECI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gramme"),
        dictgen::InsensitiveStr::Ascii("grammes"),
        dictgen::InsensitiveStr::Ascii("liter"),
        dictgen::InsensitiveStr::Ascii("liters"),
        dictgen::InsensitiveStr::Ascii("litre"),
        dictgen::InsensitiveStr::Ascii("litres"),
        dictgen::InsensitiveStr::Ascii("malisation"),
        dictgen::InsensitiveStr::Ascii("malisations"),
        dictgen::InsensitiveStr::Ascii("malise"),
        dictgen::InsensitiveStr::Ascii("malised"),
        dictgen::InsensitiveStr::Ascii("malises"),
        dictgen::InsensitiveStr::Ascii("malising"),
        dictgen::InsensitiveStr::Ascii("malization"),
        dictgen::InsensitiveStr::Ascii("malizations"),
        dictgen::InsensitiveStr::Ascii("malize"),
        dictgen::InsensitiveStr::Ascii("malized"),
        dictgen::InsensitiveStr::Ascii("malizes"),
        dictgen::InsensitiveStr::Ascii("malizing"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("meters"),
        dictgen::InsensitiveStr::Ascii("metre"),
        dictgen::InsensitiveStr::Ascii("metres"),
        dictgen::InsensitiveStr::Ascii("vilise"),
        dictgen::InsensitiveStr::Ascii("vilised"),
        dictgen::InsensitiveStr::Ascii("vilises"),
        dictgen::InsensitiveStr::Ascii("vilising"),
        dictgen::InsensitiveStr::Ascii("vilize"),
        dictgen::InsensitiveStr::Ascii("vilized"),
        dictgen::InsensitiveStr::Ascii("vilizes"),
        dictgen::InsensitiveStr::Ascii("vilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DECIGRAM_17589790411371966600)],
        &[(0b10010, &ENTRY_DECIGRAMS_7725289753257784879)],
        &[(0b00001, &ENTRY_DECILITER_16804458751438697102)],
        &[(0b00001, &ENTRY_DECILITERS_4643786240815277020)],
        &[(0b11010, &ENTRY_DECILITER_16804458751438697102)],
        &[(0b11010, &ENTRY_DECILITERS_4643786240815277020)],
        &[(0b10010, &ENTRY_DECIMALIZATION_6996195191656110298)],
        &[(0b10010, &ENTRY_DECIMALIZATIONS_7263991078898399657)],
        &[(0b10010, &ENTRY_DECIMALIZE_17840181587779229578)],
        &[(0b10010, &ENTRY_DECIMALIZED_11759803687347791070)],
        &[(0b10010, &ENTRY_DECIMALIZES_10277653931987829798)],
        &[(0b10010, &ENTRY_DECIMALIZING_6772930949596594022)],
        &[(0b01001, &ENTRY_DECIMALIZATION_6996195191656110298)],
        &[(0b01001, &ENTRY_DECIMALIZATIONS_7263991078898399657)],
        &[(0b01001, &ENTRY_DECIMALIZE_17840181587779229578)],
        &[(0b01001, &ENTRY_DECIMALIZED_11759803687347791070)],
        &[(0b01001, &ENTRY_DECIMALIZES_10277653931987829798)],
        &[(0b01001, &ENTRY_DECIMALIZING_6772930949596594022)],
        &[(0b00001, &ENTRY_DECIMETER_14067880338205453806)],
        &[(0b00001, &ENTRY_DECIMETERS_4158783169372669202)],
        &[(0b11010, &ENTRY_DECIMETER_14067880338205453806)],
        &[(0b11010, &ENTRY_DECIMETERS_4158783169372669202)],
        &[(0b10010, &ENTRY_DECIVILIZE_16580511735338840581)],
        &[(0b10010, &ENTRY_DECIVILIZED_5079080916308187134)],
        &[(0b10010, &ENTRY_DECIVILIZES_6813589689406092861)],
        &[(0b10010, &ENTRY_DECIVILIZING_4023615304630258958)],
        &[(0b01001, &ENTRY_DECIVILIZE_16580511735338840581)],
        &[(0b01001, &ENTRY_DECIVILIZED_5079080916308187134)],
        &[(0b01001, &ENTRY_DECIVILIZES_6813589689406092861)],
        &[(0b01001, &ENTRY_DECIVILIZING_4023615304630258958)],
    ],
    range: 5..=11,
};

static VARS_DECH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECH_CHILDREN),
    value: None,
};

pub static VARS_DECH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ristianisation"),
        dictgen::InsensitiveStr::Ascii("ristianisations"),
        dictgen::InsensitiveStr::Ascii("ristianise"),
        dictgen::InsensitiveStr::Ascii("ristianised"),
        dictgen::InsensitiveStr::Ascii("ristianises"),
        dictgen::InsensitiveStr::Ascii("ristianising"),
        dictgen::InsensitiveStr::Ascii("ristianization"),
        dictgen::InsensitiveStr::Ascii("ristianizations"),
        dictgen::InsensitiveStr::Ascii("ristianize"),
        dictgen::InsensitiveStr::Ascii("ristianized"),
        dictgen::InsensitiveStr::Ascii("ristianizes"),
        dictgen::InsensitiveStr::Ascii("ristianizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DECHRISTIANIZATION_11836465351921531501)],
        &[(0b10010, &ENTRY_DECHRISTIANIZATIONS_17028100591913749882)],
        &[(0b10010, &ENTRY_DECHRISTIANIZE_1708321262942279453)],
        &[(0b10010, &ENTRY_DECHRISTIANIZED_6964242037591866891)],
        &[(0b10010, &ENTRY_DECHRISTIANIZES_6387580170865898146)],
        &[(0b10010, &ENTRY_DECHRISTIANIZING_9955318127138092041)],
        &[(0b01001, &ENTRY_DECHRISTIANIZATION_11836465351921531501)],
        &[(0b01001, &ENTRY_DECHRISTIANIZATIONS_17028100591913749882)],
        &[(0b01001, &ENTRY_DECHRISTIANIZE_1708321262942279453)],
        &[(0b01001, &ENTRY_DECHRISTIANIZED_6964242037591866891)],
        &[(0b01001, &ENTRY_DECHRISTIANIZES_6387580170865898146)],
        &[(0b01001, &ENTRY_DECHRISTIANIZING_9955318127138092041)],
    ],
    range: 10..=15,
};

static VARS_DECE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECE_CHILDREN),
    value: None,
};

pub static VARS_DECE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nters"),
        dictgen::InsensitiveStr::Ascii("ntralisation"),
        dictgen::InsensitiveStr::Ascii("ntralisationist"),
        dictgen::InsensitiveStr::Ascii("ntralisations"),
        dictgen::InsensitiveStr::Ascii("ntralise"),
        dictgen::InsensitiveStr::Ascii("ntralised"),
        dictgen::InsensitiveStr::Ascii("ntralises"),
        dictgen::InsensitiveStr::Ascii("ntralising"),
        dictgen::InsensitiveStr::Ascii("ntralization"),
        dictgen::InsensitiveStr::Ascii("ntralizationist"),
        dictgen::InsensitiveStr::Ascii("ntralizations"),
        dictgen::InsensitiveStr::Ascii("ntralize"),
        dictgen::InsensitiveStr::Ascii("ntralized"),
        dictgen::InsensitiveStr::Ascii("ntralizes"),
        dictgen::InsensitiveStr::Ascii("ntralizing"),
        dictgen::InsensitiveStr::Ascii("ntres"),
        dictgen::InsensitiveStr::Ascii("rebrise"),
        dictgen::InsensitiveStr::Ascii("rebrised"),
        dictgen::InsensitiveStr::Ascii("rebrises"),
        dictgen::InsensitiveStr::Ascii("rebrising"),
        dictgen::InsensitiveStr::Ascii("rebrize"),
        dictgen::InsensitiveStr::Ascii("rebrized"),
        dictgen::InsensitiveStr::Ascii("rebrizes"),
        dictgen::InsensitiveStr::Ascii("rebrizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DECENTERS_782900641405037424)],
        &[(0b10010, &ENTRY_DECENTRALIZATION_1145039421821383347)],
        &[(0b10010, &ENTRY_DECENTRALIZATIONIST_15242187117214090536)],
        &[(0b10010, &ENTRY_DECENTRALIZATIONS_17002754818902434488)],
        &[(0b10010, &ENTRY_DECENTRALIZE_1723656843408900394)],
        &[(0b10010, &ENTRY_DECENTRALIZED_17904951634508172483)],
        &[(0b10010, &ENTRY_DECENTRALIZES_4819976769659557164)],
        &[(0b10010, &ENTRY_DECENTRALIZING_1061628518546631855)],
        &[(0b01001, &ENTRY_DECENTRALIZATION_1145039421821383347)],
        &[(0b01001, &ENTRY_DECENTRALIZATIONIST_15242187117214090536)],
        &[(0b01001, &ENTRY_DECENTRALIZATIONS_17002754818902434488)],
        &[(0b01001, &ENTRY_DECENTRALIZE_1723656843408900394)],
        &[(0b01001, &ENTRY_DECENTRALIZED_17904951634508172483)],
        &[(0b01001, &ENTRY_DECENTRALIZES_4819976769659557164)],
        &[(0b01001, &ENTRY_DECENTRALIZING_1061628518546631855)],
        &[(0b11010, &ENTRY_DECENTERS_782900641405037424)],
        &[(0b10010, &ENTRY_DECEREBRIZE_5169026104609683255)],
        &[(0b10010, &ENTRY_DECEREBRIZED_14339403834612181570)],
        &[(0b10010, &ENTRY_DECEREBRIZES_7217503420848291830)],
        &[(0b10010, &ENTRY_DECEREBRIZING_6341477046577811325)],
        &[(0b01001, &ENTRY_DECEREBRIZE_5169026104609683255)],
        &[(0b01001, &ENTRY_DECEREBRIZED_14339403834612181570)],
        &[(0b01001, &ENTRY_DECEREBRIZES_7217503420848291830)],
        &[(0b01001, &ENTRY_DECEREBRIZING_6341477046577811325)],
    ],
    range: 5..=15,
};

static VARS_DECA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DECA_CHILDREN),
    value: None,
};

pub static VARS_DECA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("liter"),
        dictgen::InsensitiveStr::Ascii("liters"),
        dictgen::InsensitiveStr::Ascii("litre"),
        dictgen::InsensitiveStr::Ascii("litres"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("meters"),
        dictgen::InsensitiveStr::Ascii("metre"),
        dictgen::InsensitiveStr::Ascii("metres"),
        dictgen::InsensitiveStr::Ascii("pitalisation"),
        dictgen::InsensitiveStr::Ascii("pitalisations"),
        dictgen::InsensitiveStr::Ascii("pitalise"),
        dictgen::InsensitiveStr::Ascii("pitalised"),
        dictgen::InsensitiveStr::Ascii("pitalises"),
        dictgen::InsensitiveStr::Ascii("pitalising"),
        dictgen::InsensitiveStr::Ascii("pitalization"),
        dictgen::InsensitiveStr::Ascii("pitalizations"),
        dictgen::InsensitiveStr::Ascii("pitalize"),
        dictgen::InsensitiveStr::Ascii("pitalized"),
        dictgen::InsensitiveStr::Ascii("pitalizes"),
        dictgen::InsensitiveStr::Ascii("pitalizing"),
        dictgen::InsensitiveStr::Ascii("rbonisation"),
        dictgen::InsensitiveStr::Ascii("rbonisations"),
        dictgen::InsensitiveStr::Ascii("rbonise"),
        dictgen::InsensitiveStr::Ascii("rbonised"),
        dictgen::InsensitiveStr::Ascii("rboniser"),
        dictgen::InsensitiveStr::Ascii("rbonisers"),
        dictgen::InsensitiveStr::Ascii("rbonises"),
        dictgen::InsensitiveStr::Ascii("rbonising"),
        dictgen::InsensitiveStr::Ascii("rbonization"),
        dictgen::InsensitiveStr::Ascii("rbonizations"),
        dictgen::InsensitiveStr::Ascii("rbonize"),
        dictgen::InsensitiveStr::Ascii("rbonized"),
        dictgen::InsensitiveStr::Ascii("rbonizer"),
        dictgen::InsensitiveStr::Ascii("rbonizers"),
        dictgen::InsensitiveStr::Ascii("rbonizes"),
        dictgen::InsensitiveStr::Ascii("rbonizing"),
        dictgen::InsensitiveStr::Ascii("rburisation"),
        dictgen::InsensitiveStr::Ascii("rburisations"),
        dictgen::InsensitiveStr::Ascii("rburise"),
        dictgen::InsensitiveStr::Ascii("rburised"),
        dictgen::InsensitiveStr::Ascii("rburises"),
        dictgen::InsensitiveStr::Ascii("rburising"),
        dictgen::InsensitiveStr::Ascii("rburization"),
        dictgen::InsensitiveStr::Ascii("rburizations"),
        dictgen::InsensitiveStr::Ascii("rburize"),
        dictgen::InsensitiveStr::Ascii("rburized"),
        dictgen::InsensitiveStr::Ascii("rburizes"),
        dictgen::InsensitiveStr::Ascii("rburizing"),
        dictgen::InsensitiveStr::Ascii("sualisation"),
        dictgen::InsensitiveStr::Ascii("sualisations"),
        dictgen::InsensitiveStr::Ascii("sualise"),
        dictgen::InsensitiveStr::Ascii("sualised"),
        dictgen::InsensitiveStr::Ascii("sualising"),
        dictgen::InsensitiveStr::Ascii("sualization"),
        dictgen::InsensitiveStr::Ascii("sualizations"),
        dictgen::InsensitiveStr::Ascii("sualize"),
        dictgen::InsensitiveStr::Ascii("sualized"),
        dictgen::InsensitiveStr::Ascii("sualizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_DECALITER_4375398060796975724)],
        &[(0b00001, &ENTRY_DECALITERS_3685909594822331600)],
        &[(0b11010, &ENTRY_DECALITER_4375398060796975724)],
        &[(0b11010, &ENTRY_DECALITERS_3685909594822331600)],
        &[(0b00001, &ENTRY_DECAMETER_14656314621987784949)],
        &[(0b00001, &ENTRY_DECAMETERS_12345413372720956347)],
        &[(0b11010, &ENTRY_DECAMETER_14656314621987784949)],
        &[(0b11010, &ENTRY_DECAMETERS_12345413372720956347)],
        &[(0b10010, &ENTRY_DECAPITALIZATION_10013185676274515636)],
        &[(0b10010, &ENTRY_DECAPITALIZATIONS_4946483081288861635)],
        &[(0b10010, &ENTRY_DECAPITALIZE_16025876451254005657)],
        &[(0b10010, &ENTRY_DECAPITALIZED_11861526144439577453)],
        &[(0b10010, &ENTRY_DECAPITALIZES_3757956433811423536)],
        &[(0b10010, &ENTRY_DECAPITALIZING_9239457887018733519)],
        &[(0b01001, &ENTRY_DECAPITALIZATION_10013185676274515636)],
        &[(0b01001, &ENTRY_DECAPITALIZATIONS_4946483081288861635)],
        &[(0b01001, &ENTRY_DECAPITALIZE_16025876451254005657)],
        &[(0b01001, &ENTRY_DECAPITALIZED_11861526144439577453)],
        &[(0b01001, &ENTRY_DECAPITALIZES_3757956433811423536)],
        &[(0b01001, &ENTRY_DECAPITALIZING_9239457887018733519)],
        &[(0b10010, &ENTRY_DECARBONIZATION_8874762898635047514)],
        &[(0b10010, &ENTRY_DECARBONIZATIONS_12243161232853744724)],
        &[(0b10010, &ENTRY_DECARBONIZE_14547194689917209691)],
        &[(0b10010, &ENTRY_DECARBONIZED_831670285440777483)],
        &[(0b10010, &ENTRY_DECARBONIZER_7249394058399586099)],
        &[(0b10010, &ENTRY_DECARBONIZERS_11181600971431230502)],
        &[(0b10010, &ENTRY_DECARBONIZES_16627154206935494807)],
        &[(0b10010, &ENTRY_DECARBONIZING_17299516323553280568)],
        &[(0b01001, &ENTRY_DECARBONIZATION_8874762898635047514)],
        &[(0b01001, &ENTRY_DECARBONIZATIONS_12243161232853744724)],
        &[(0b01001, &ENTRY_DECARBONIZE_14547194689917209691)],
        &[(0b01001, &ENTRY_DECARBONIZED_831670285440777483)],
        &[(0b01001, &ENTRY_DECARBONIZER_7249394058399586099)],
        &[(0b01001, &ENTRY_DECARBONIZERS_11181600971431230502)],
        &[(0b01001, &ENTRY_DECARBONIZES_16627154206935494807)],
        &[(0b01001, &ENTRY_DECARBONIZING_17299516323553280568)],
        &[(0b10010, &ENTRY_DECARBURIZATION_9039500434838585200)],
        &[(0b10010, &ENTRY_DECARBURIZATIONS_2176112887354481552)],
        &[(0b10010, &ENTRY_DECARBURIZE_9459391841384624626)],
        &[(0b10010, &ENTRY_DECARBURIZED_2477575653270598611)],
        &[(0b10010, &ENTRY_DECARBURIZES_4783060351348035100)],
        &[(0b10010, &ENTRY_DECARBURIZING_6487494577812793164)],
        &[(0b01001, &ENTRY_DECARBURIZATION_9039500434838585200)],
        &[(0b01001, &ENTRY_DECARBURIZATIONS_2176112887354481552)],
        &[(0b01001, &ENTRY_DECARBURIZE_9459391841384624626)],
        &[(0b01001, &ENTRY_DECARBURIZED_2477575653270598611)],
        &[(0b01001, &ENTRY_DECARBURIZES_4783060351348035100)],
        &[(0b01001, &ENTRY_DECARBURIZING_6487494577812793164)],
        &[(0b10010, &ENTRY_DECASUALIZATION_10274253385824132479)],
        &[(0b10010, &ENTRY_DECASUALIZATIONS_3864825352222685439)],
        &[(0b10010, &ENTRY_DECASUALIZE_17572605258851322561)],
        &[(0b10010, &ENTRY_DECASUALIZED_1520306088891108700)],
        &[(0b10010, &ENTRY_DECASUALIZING_18325301279691614544)],
        &[(0b01001, &ENTRY_DECASUALIZATION_10274253385824132479)],
        &[(0b01001, &ENTRY_DECASUALIZATIONS_3864825352222685439)],
        &[(0b01001, &ENTRY_DECASUALIZE_17572605258851322561)],
        &[(0b01001, &ENTRY_DECASUALIZED_1520306088891108700)],
        &[(0b01001, &ENTRY_DECASUALIZING_18325301279691614544)],
    ],
    range: 5..=13,
};

static VARS_DEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DEA_CHILDREN),
    value: None,
};

pub static VARS_DEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("conise"),
        dictgen::InsensitiveStr::Ascii("conises"),
        dictgen::InsensitiveStr::Ascii("conize"),
        dictgen::InsensitiveStr::Ascii("conizes"),
        dictgen::InsensitiveStr::Ascii("drise"),
        dictgen::InsensitiveStr::Ascii("drize"),
        dictgen::InsensitiveStr::Ascii("lcoholise"),
        dictgen::InsensitiveStr::Ascii("lcoholised"),
        dictgen::InsensitiveStr::Ascii("lcoholises"),
        dictgen::InsensitiveStr::Ascii("lcoholising"),
        dictgen::InsensitiveStr::Ascii("lcoholize"),
        dictgen::InsensitiveStr::Ascii("lcoholized"),
        dictgen::InsensitiveStr::Ascii("lcoholizes"),
        dictgen::InsensitiveStr::Ascii("lcoholizing"),
        dictgen::InsensitiveStr::Ascii("minise"),
        dictgen::InsensitiveStr::Ascii("minize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_DEACONIZE_18248452212031779732)],
        &[(0b10010, &ENTRY_DEACONIZES_10922795038830896546)],
        &[(0b01001, &ENTRY_DEACONIZE_18248452212031779732)],
        &[(0b01001, &ENTRY_DEACONIZES_10922795038830896546)],
        &[(0b10010, &ENTRY_DEADRIZE_16948183351591896893)],
        &[(0b01001, &ENTRY_DEADRIZE_16948183351591896893)],
        &[(0b10010, &ENTRY_DEALCOHOLIZE_17481590891108727711)],
        &[(0b10010, &ENTRY_DEALCOHOLIZED_4879647847969574400)],
        &[(0b10010, &ENTRY_DEALCOHOLIZES_8191413688823277724)],
        &[(0b10010, &ENTRY_DEALCOHOLIZING_9291655249306543942)],
        &[(0b01001, &ENTRY_DEALCOHOLIZE_17481590891108727711)],
        &[(0b01001, &ENTRY_DEALCOHOLIZED_4879647847969574400)],
        &[(0b01001, &ENTRY_DEALCOHOLIZES_8191413688823277724)],
        &[(0b01001, &ENTRY_DEALCOHOLIZING_9291655249306543942)],
        &[(0b10010, &ENTRY_DEAMINIZE_18302767805033719686)],
        &[(0b01001, &ENTRY_DEAMINIZE_18302767805033719686)],
    ],
    range: 5..=11,
};

static VARS_DA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_DA_CHILDREN),
    value: None,
};

pub static VARS_DA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edal"),
        dictgen::InsensitiveStr::Ascii("edalian"),
        dictgen::InsensitiveStr::Ascii("emonian"),
        dictgen::InsensitiveStr::Ascii("eva"),
        dictgen::InsensitiveStr::Ascii("nae"),
        dictgen::InsensitiveStr::Ascii("naidae"),
        dictgen::InsensitiveStr::Ascii("naide"),
        dictgen::InsensitiveStr::Ascii("ndisette"),
        dictgen::InsensitiveStr::Ascii("ndizette"),
        dictgen::InsensitiveStr::Ascii("ndyise"),
        dictgen::InsensitiveStr::Ascii("ndyises"),
        dictgen::InsensitiveStr::Ascii("ndyize"),
        dictgen::InsensitiveStr::Ascii("ndyizes"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("rwinise"),
        dictgen::InsensitiveStr::Ascii("rwinises"),
        dictgen::InsensitiveStr::Ascii("rwinize"),
        dictgen::InsensitiveStr::Ascii("rwinizes"),
        dictgen::InsensitiveStr::Ascii("stardise"),
        dictgen::InsensitiveStr::Ascii("stardises"),
        dictgen::InsensitiveStr::Ascii("stardize"),
        dictgen::InsensitiveStr::Ascii("stardizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_DEDAL_3527172992604688330)],
        &[(0b11010, &ENTRY_DEDALIAN_1818689560079214410)],
        &[(0b11010, &ENTRY_DEMONIAN_17257435076983249346)],
        &[(0b11010, &ENTRY_DEVA_18303315502243076060)],
        &[(0b11010, &ENTRY_DANE_3862192600118407294)],
        &[(0b11010, &ENTRY_DANAIDE_9364396268060723081)],
        &[(0b00001, &ENTRY_DANAIDE_9364396268060723081)],
        &[(0b10010, &ENTRY_DANDIZETTE_7715971230906134138)],
        &[(0b01001, &ENTRY_DANDIZETTE_7715971230906134138)],
        &[(0b10010, &ENTRY_DANDYIZE_10327123579855543927)],
        &[(0b10010, &ENTRY_DANDYIZES_5178148648982336582)],
        &[(0b01001, &ENTRY_DANDYIZE_10327123579855543927)],
        &[(0b01001, &ENTRY_DANDYIZES_5178148648982336582)],
        &[(0b00001, &ENTRY_DANE_3862192600118407294)],
        &[(0b10010, &ENTRY_DANIZATION_4527343444630609033)],
        &[(0b10010, &ENTRY_DANIZATIONS_586018653689790602)],
        &[(0b10010, &ENTRY_DANIZE_7643162790699672050)],
        &[(0b10010, &ENTRY_DANIZES_982119247166854426)],
        &[(0b01001, &ENTRY_DANIZATION_4527343444630609033)],
        &[(0b01001, &ENTRY_DANIZATIONS_586018653689790602)],
        &[(0b01001, &ENTRY_DANIZE_7643162790699672050)],
        &[(0b01001, &ENTRY_DANIZES_982119247166854426)],
        &[(0b10010, &ENTRY_DARWINIZE_17708644917698913001)],
        &[(0b10010, &ENTRY_DARWINIZES_4276823588989949702)],
        &[(0b01001, &ENTRY_DARWINIZE_17708644917698913001)],
        &[(0b01001, &ENTRY_DARWINIZES_4276823588989949702)],
        &[(0b10010, &ENTRY_DASTARDIZE_9137258977351501392)],
        &[(0b10010, &ENTRY_DASTARDIZES_14814359505750971454)],
        &[(0b01001, &ENTRY_DASTARDIZE_9137258977351501392)],
        &[(0b01001, &ENTRY_DASTARDIZES_14814359505750971454)],
    ],
    range: 2..=9,
};

static VARS_C_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_C_CHILDREN),
    value: None,
};

static VARS_C_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CA_NODE),
    None,
    None,
    None,
    Some(&VARS_CE_NODE),
    None,
    None,
    Some(&VARS_CH_NODE),
    Some(&VARS_CI_NODE),
    None,
    None,
    Some(&VARS_CL_NODE),
    None,
    None,
    Some(&VARS_CO_NODE),
    None,
    None,
    Some(&VARS_CR_NODE),
    None,
    None,
    Some(&VARS_CU_NODE),
    None,
    None,
    None,
    Some(&VARS_CY_NODE),
    Some(&VARS_CZ_NODE),
];

static VARS_CZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CZ_CHILDREN),
    value: None,
};

pub static VARS_CZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("echisation"),
        dictgen::InsensitiveStr::Ascii("echisations"),
        dictgen::InsensitiveStr::Ascii("echization"),
        dictgen::InsensitiveStr::Ascii("echizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CZECHIZATION_14599848904820315137)],
        &[(0b10010, &ENTRY_CZECHIZATIONS_406710155217652709)],
        &[(0b01001, &ENTRY_CZECHIZATION_14599848904820315137)],
        &[(0b01001, &ENTRY_CZECHIZATIONS_406710155217652709)],
    ],
    range: 10..=11,
};

static VARS_CY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CY_CHILDREN),
    value: None,
};

pub static VARS_CY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aneae"),
        dictgen::InsensitiveStr::Ascii("anee"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("anomethaemoglobin"),
        dictgen::InsensitiveStr::Ascii("anomethemoglobin"),
        dictgen::InsensitiveStr::Ascii("clisation"),
        dictgen::InsensitiveStr::Ascii("clisations"),
        dictgen::InsensitiveStr::Ascii("clise"),
        dictgen::InsensitiveStr::Ascii("clised"),
        dictgen::InsensitiveStr::Ascii("clises"),
        dictgen::InsensitiveStr::Ascii("clising"),
        dictgen::InsensitiveStr::Ascii("clization"),
        dictgen::InsensitiveStr::Ascii("clizations"),
        dictgen::InsensitiveStr::Ascii("clize"),
        dictgen::InsensitiveStr::Ascii("clized"),
        dictgen::InsensitiveStr::Ascii("clizes"),
        dictgen::InsensitiveStr::Ascii("clizing"),
        dictgen::InsensitiveStr::Ascii("mae"),
        dictgen::InsensitiveStr::Ascii("me"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CYANEE_11375348371881906566)],
        &[(0b00001, &ENTRY_CYANEE_11375348371881906566)],
        &[(0b10010, &ENTRY_CYANIZE_16155583626941063831)],
        &[(0b10010, &ENTRY_CYANIZED_17361255917873352647)],
        &[(0b10010, &ENTRY_CYANIZES_5685851010869963468)],
        &[(0b10010, &ENTRY_CYANIZING_13714646055406888213)],
        &[(0b01001, &ENTRY_CYANIZE_16155583626941063831)],
        &[(0b01001, &ENTRY_CYANIZED_17361255917873352647)],
        &[(0b01001, &ENTRY_CYANIZES_5685851010869963468)],
        &[(0b01001, &ENTRY_CYANIZING_13714646055406888213)],
        &[(0b11010, &ENTRY_CYANOMETHEMOGLOBIN_17992938767240588113)],
        &[(0b10001, &ENTRY_CYANOMETHEMOGLOBIN_17992938767240588113)],
        &[(0b10010, &ENTRY_CYCLIZATION_18360017396052282635)],
        &[(0b10010, &ENTRY_CYCLIZATIONS_3981106857955296675)],
        &[(0b10010, &ENTRY_CYCLIZE_11964539384894004110)],
        &[(0b10010, &ENTRY_CYCLIZED_9753759946426964794)],
        &[(0b10010, &ENTRY_CYCLIZES_5515758818050542691)],
        &[(0b10010, &ENTRY_CYCLIZING_8867677036457804725)],
        &[(0b01001, &ENTRY_CYCLIZATION_18360017396052282635)],
        &[(0b01001, &ENTRY_CYCLIZATIONS_3981106857955296675)],
        &[(0b01001, &ENTRY_CYCLIZE_11964539384894004110)],
        &[(0b01001, &ENTRY_CYCLIZED_9753759946426964794)],
        &[(0b01001, &ENTRY_CYCLIZES_5515758818050542691)],
        &[(0b01001, &ENTRY_CYCLIZING_8867677036457804725)],
        &[(0b11010, &ENTRY_CYME_3841905397007660900)],
        &[(0b00001, &ENTRY_CYME_3841905397007660900)],
    ],
    range: 2..=17,
};

static VARS_CU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CU_CHILDREN),
    value: None,
};

static VARS_CU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_CUB_NODE),
    Some(&VARS_CUC_NODE),
    Some(&VARS_CUD_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CUL_NODE),
    None,
    None,
    None,
    Some(&VARS_CUP_NODE),
    None,
    Some(&VARS_CUR_NODE),
    Some(&VARS_CUS_NODE),
    Some(&VARS_CUT_NODE),
    None,
    Some(&VARS_CUV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_CUV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUV_CHILDREN),
    value: None,
};

pub static VARS_CUV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ae"),
        dictgen::InsensitiveStr::Ascii("e"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CUVE_11772864420884703925)],
        &[(0b00001, &ENTRY_CUVE_11772864420884703925)],
    ],
    range: 1..=2,
};

static VARS_CUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUT_CHILDREN),
    value: None,
};

pub static VARS_CUT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icolor"),
        dictgen::InsensitiveStr::Ascii("icolour"),
        dictgen::InsensitiveStr::Ascii("inisation"),
        dictgen::InsensitiveStr::Ascii("inisations"),
        dictgen::InsensitiveStr::Ascii("inise"),
        dictgen::InsensitiveStr::Ascii("inised"),
        dictgen::InsensitiveStr::Ascii("inises"),
        dictgen::InsensitiveStr::Ascii("inising"),
        dictgen::InsensitiveStr::Ascii("inization"),
        dictgen::InsensitiveStr::Ascii("inizations"),
        dictgen::InsensitiveStr::Ascii("inize"),
        dictgen::InsensitiveStr::Ascii("inized"),
        dictgen::InsensitiveStr::Ascii("inizes"),
        dictgen::InsensitiveStr::Ascii("inizing"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izations"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CUTICOLOR_17641383408080176141)],
        &[(0b11010, &ENTRY_CUTICOLOR_17641383408080176141)],
        &[(0b10010, &ENTRY_CUTINIZATION_7081285991404911992)],
        &[(0b10010, &ENTRY_CUTINIZATIONS_17168596603659079378)],
        &[(0b10010, &ENTRY_CUTINIZE_17770128684096533482)],
        &[(0b10010, &ENTRY_CUTINIZED_8304546337057011168)],
        &[(0b10010, &ENTRY_CUTINIZES_7397928291454568665)],
        &[(0b10010, &ENTRY_CUTINIZING_17947614786569489277)],
        &[(0b01001, &ENTRY_CUTINIZATION_7081285991404911992)],
        &[(0b01001, &ENTRY_CUTINIZATIONS_17168596603659079378)],
        &[(0b01001, &ENTRY_CUTINIZE_17770128684096533482)],
        &[(0b01001, &ENTRY_CUTINIZED_8304546337057011168)],
        &[(0b01001, &ENTRY_CUTINIZES_7397928291454568665)],
        &[(0b01001, &ENTRY_CUTINIZING_17947614786569489277)],
        &[(0b10010, &ENTRY_CUTIZATION_8177626209182721273)],
        &[(0b10010, &ENTRY_CUTIZATIONS_12588515800323296191)],
        &[(0b01001, &ENTRY_CUTIZATION_8177626209182721273)],
        &[(0b01001, &ENTRY_CUTIZATIONS_12588515800323296191)],
    ],
    range: 5..=10,
};

static VARS_CUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUS_CHILDREN),
    value: None,
};

pub static VARS_CUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tomisable"),
        dictgen::InsensitiveStr::Ascii("tomisation"),
        dictgen::InsensitiveStr::Ascii("tomisations"),
        dictgen::InsensitiveStr::Ascii("tomise"),
        dictgen::InsensitiveStr::Ascii("tomised"),
        dictgen::InsensitiveStr::Ascii("tomiser"),
        dictgen::InsensitiveStr::Ascii("tomisers"),
        dictgen::InsensitiveStr::Ascii("tomises"),
        dictgen::InsensitiveStr::Ascii("tomising"),
        dictgen::InsensitiveStr::Ascii("tomizable"),
        dictgen::InsensitiveStr::Ascii("tomization"),
        dictgen::InsensitiveStr::Ascii("tomizations"),
        dictgen::InsensitiveStr::Ascii("tomize"),
        dictgen::InsensitiveStr::Ascii("tomized"),
        dictgen::InsensitiveStr::Ascii("tomizer"),
        dictgen::InsensitiveStr::Ascii("tomizers"),
        dictgen::InsensitiveStr::Ascii("tomizes"),
        dictgen::InsensitiveStr::Ascii("tomizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CUSTOMIZABLE_4188832830695107920)],
        &[(0b10010, &ENTRY_CUSTOMIZATION_453875871734424262)],
        &[(0b10010, &ENTRY_CUSTOMIZATIONS_5506803585454620316)],
        &[(0b10010, &ENTRY_CUSTOMIZE_17506619842499670481)],
        &[(0b10010, &ENTRY_CUSTOMIZED_13934442474650970923)],
        &[(0b10010, &ENTRY_CUSTOMIZER_10903429132081239237)],
        &[(0b10010, &ENTRY_CUSTOMIZERS_7343425341470389472)],
        &[(0b10010, &ENTRY_CUSTOMIZES_7573381294777108850)],
        &[(0b10010, &ENTRY_CUSTOMIZING_12981538261584263761)],
        &[(0b01001, &ENTRY_CUSTOMIZABLE_4188832830695107920)],
        &[(0b01001, &ENTRY_CUSTOMIZATION_453875871734424262)],
        &[(0b01001, &ENTRY_CUSTOMIZATIONS_5506803585454620316)],
        &[(0b01001, &ENTRY_CUSTOMIZE_17506619842499670481)],
        &[(0b01001, &ENTRY_CUSTOMIZED_13934442474650970923)],
        &[(0b01001, &ENTRY_CUSTOMIZER_10903429132081239237)],
        &[(0b01001, &ENTRY_CUSTOMIZERS_7343425341470389472)],
        &[(0b01001, &ENTRY_CUSTOMIZES_7573381294777108850)],
        &[(0b01001, &ENTRY_CUSTOMIZING_12981538261584263761)],
    ],
    range: 6..=11,
};

static VARS_CUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUR_CHILDREN),
    value: None,
};

pub static VARS_CUR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("atise"),
        dictgen::InsensitiveStr::Ascii("atises"),
        dictgen::InsensitiveStr::Ascii("atize"),
        dictgen::InsensitiveStr::Ascii("atizes"),
        dictgen::InsensitiveStr::Ascii("ricularisation"),
        dictgen::InsensitiveStr::Ascii("ricularisations"),
        dictgen::InsensitiveStr::Ascii("ricularise"),
        dictgen::InsensitiveStr::Ascii("ricularises"),
        dictgen::InsensitiveStr::Ascii("ricularization"),
        dictgen::InsensitiveStr::Ascii("ricularizations"),
        dictgen::InsensitiveStr::Ascii("ricularize"),
        dictgen::InsensitiveStr::Ascii("ricularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CURARIZE_9480914079622972520)],
        &[(0b10010, &ENTRY_CURARIZED_16380507751440201850)],
        &[(0b10010, &ENTRY_CURARIZES_11507088447457007709)],
        &[(0b10010, &ENTRY_CURARIZING_17039072217967273189)],
        &[(0b01001, &ENTRY_CURARIZE_9480914079622972520)],
        &[(0b01001, &ENTRY_CURARIZED_16380507751440201850)],
        &[(0b01001, &ENTRY_CURARIZES_11507088447457007709)],
        &[(0b01001, &ENTRY_CURARIZING_17039072217967273189)],
        &[(0b10010, &ENTRY_CURATIZE_12754148319229450576)],
        &[(0b10010, &ENTRY_CURATIZES_4333181687986321191)],
        &[(0b01001, &ENTRY_CURATIZE_12754148319229450576)],
        &[(0b01001, &ENTRY_CURATIZES_4333181687986321191)],
        &[(0b10010, &ENTRY_CURRICULARIZATION_17949948352689251703)],
        &[(0b10010, &ENTRY_CURRICULARIZATIONS_8190097899978040825)],
        &[(0b10010, &ENTRY_CURRICULARIZE_16163595528229474912)],
        &[(0b10010, &ENTRY_CURRICULARIZES_15886142937581991191)],
        &[(0b01001, &ENTRY_CURRICULARIZATION_17949948352689251703)],
        &[(0b01001, &ENTRY_CURRICULARIZATIONS_8190097899978040825)],
        &[(0b01001, &ENTRY_CURRICULARIZE_16163595528229474912)],
        &[(0b01001, &ENTRY_CURRICULARIZES_15886142937581991191)],
    ],
    range: 5..=15,
};

static VARS_CUP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUP_CHILDREN),
    value: None,
};

pub static VARS_CUP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elation"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("ellation"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ulae"),
        dictgen::InsensitiveStr::Ascii("ule"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CUPELATION_14255540896200543840)],
        &[(0b00001, &ENTRY_CUPELED_8946630193695466634)],
        &[(0b00001, &ENTRY_CUPELER_7377946170413406251)],
        &[(0b00001, &ENTRY_CUPELERS_5725217363507193203)],
        &[(0b00001, &ENTRY_CUPELING_4033682037469028100)],
        &[(0b11010, &ENTRY_CUPELATION_14255540896200543840)],
        &[(0b11010, &ENTRY_CUPELED_8946630193695466634)],
        &[(0b11010, &ENTRY_CUPELER_7377946170413406251)],
        &[(0b11010, &ENTRY_CUPELERS_5725217363507193203)],
        &[(0b11010, &ENTRY_CUPELING_4033682037469028100)],
        &[(0b11010, &ENTRY_CUPULE_4300809885306855718)],
        &[(0b00001, &ENTRY_CUPULE_4300809885306855718)],
    ],
    range: 3..=8,
};

static VARS_CUL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUL_CHILDREN),
    value: None,
};

pub static VARS_CUL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icidae"),
        dictgen::InsensitiveStr::Ascii("icide"),
        dictgen::InsensitiveStr::Ascii("turisation"),
        dictgen::InsensitiveStr::Ascii("turisations"),
        dictgen::InsensitiveStr::Ascii("turise"),
        dictgen::InsensitiveStr::Ascii("turises"),
        dictgen::InsensitiveStr::Ascii("turization"),
        dictgen::InsensitiveStr::Ascii("turizations"),
        dictgen::InsensitiveStr::Ascii("turize"),
        dictgen::InsensitiveStr::Ascii("turizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CULICIDE_539049738338426871)],
        &[(0b00001, &ENTRY_CULICIDE_539049738338426871)],
        &[(0b10010, &ENTRY_CULTURIZATION_8113112597865327363)],
        &[(0b10010, &ENTRY_CULTURIZATIONS_433804245511281258)],
        &[(0b10010, &ENTRY_CULTURIZE_9663475963702798186)],
        &[(0b10010, &ENTRY_CULTURIZES_8371845703179033846)],
        &[(0b01001, &ENTRY_CULTURIZATION_8113112597865327363)],
        &[(0b01001, &ENTRY_CULTURIZATIONS_433804245511281258)],
        &[(0b01001, &ENTRY_CULTURIZE_9663475963702798186)],
        &[(0b01001, &ENTRY_CULTURIZES_8371845703179033846)],
    ],
    range: 5..=11,
};

static VARS_CUD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUD_CHILDREN),
    value: None,
};

pub static VARS_CUD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("geled"),
        dictgen::InsensitiveStr::Ascii("geler"),
        dictgen::InsensitiveStr::Ascii("gelers"),
        dictgen::InsensitiveStr::Ascii("geling"),
        dictgen::InsensitiveStr::Ascii("gelings"),
        dictgen::InsensitiveStr::Ascii("gelled"),
        dictgen::InsensitiveStr::Ascii("geller"),
        dictgen::InsensitiveStr::Ascii("gellers"),
        dictgen::InsensitiveStr::Ascii("gelling"),
        dictgen::InsensitiveStr::Ascii("gellings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CUDGELED_5228795318766271839)],
        &[(0b00001, &ENTRY_CUDGELER_14634684249116397869)],
        &[(0b00001, &ENTRY_CUDGELERS_17674302985237395736)],
        &[(0b00001, &ENTRY_CUDGELING_10321409265487926568)],
        &[(0b00001, &ENTRY_CUDGELINGS_2528963097802037407)],
        &[(0b11010, &ENTRY_CUDGELED_5228795318766271839)],
        &[(0b11010, &ENTRY_CUDGELER_14634684249116397869)],
        &[(0b11010, &ENTRY_CUDGELERS_17674302985237395736)],
        &[(0b11010, &ENTRY_CUDGELING_10321409265487926568)],
        &[(0b11010, &ENTRY_CUDGELINGS_2528963097802037407)],
    ],
    range: 5..=8,
};

static VARS_CUC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUC_CHILDREN),
    value: None,
};

pub static VARS_CUC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("koldise"),
        dictgen::InsensitiveStr::Ascii("koldised"),
        dictgen::InsensitiveStr::Ascii("koldises"),
        dictgen::InsensitiveStr::Ascii("koldising"),
        dictgen::InsensitiveStr::Ascii("koldize"),
        dictgen::InsensitiveStr::Ascii("koldized"),
        dictgen::InsensitiveStr::Ascii("koldizes"),
        dictgen::InsensitiveStr::Ascii("koldizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CUCKOLDIZE_15621372017035539958)],
        &[(0b10010, &ENTRY_CUCKOLDIZED_8063124355706017628)],
        &[(0b10010, &ENTRY_CUCKOLDIZES_12399951352713548106)],
        &[(0b10010, &ENTRY_CUCKOLDIZING_7372514622681800766)],
        &[(0b01001, &ENTRY_CUCKOLDIZE_15621372017035539958)],
        &[(0b01001, &ENTRY_CUCKOLDIZED_8063124355706017628)],
        &[(0b01001, &ENTRY_CUCKOLDIZES_12399951352713548106)],
        &[(0b01001, &ENTRY_CUCKOLDIZING_7372514622681800766)],
    ],
    range: 7..=9,
};

static VARS_CUB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CUB_CHILDREN),
    value: None,
};

pub static VARS_CUB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CUBANIZE_5406869394071964531)],
        &[(0b10010, &ENTRY_CUBANIZES_11947476283611479479)],
        &[(0b01001, &ENTRY_CUBANIZE_5406869394071964531)],
        &[(0b01001, &ENTRY_CUBANIZES_11947476283611479479)],
    ],
    range: 5..=6,
};

static VARS_CR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CR_CHILDREN),
    value: None,
};

static VARS_CR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CRA_NODE),
    None,
    None,
    None,
    Some(&VARS_CRE_NODE),
    None,
    None,
    None,
    Some(&VARS_CRI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CRO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CRU_NODE),
    None,
    None,
    None,
    Some(&VARS_CRY_NODE),
    None,
];

static VARS_CRY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRY_CHILDREN),
    value: None,
};

pub static VARS_CRY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("oanaesthesia"),
        dictgen::InsensitiveStr::Ascii("oanesthesia"),
        dictgen::InsensitiveStr::Ascii("ptaesthesia"),
        dictgen::InsensitiveStr::Ascii("ptaesthesias"),
        dictgen::InsensitiveStr::Ascii("ptaesthetic"),
        dictgen::InsensitiveStr::Ascii("ptanalyses"),
        dictgen::InsensitiveStr::Ascii("ptanalyzes"),
        dictgen::InsensitiveStr::Ascii("ptesthesia"),
        dictgen::InsensitiveStr::Ascii("ptesthesias"),
        dictgen::InsensitiveStr::Ascii("ptesthetic"),
        dictgen::InsensitiveStr::Ascii("stalize"),
        dictgen::InsensitiveStr::Ascii("stalized"),
        dictgen::InsensitiveStr::Ascii("stalizes"),
        dictgen::InsensitiveStr::Ascii("stalizing"),
        dictgen::InsensitiveStr::Ascii("stallisabilities"),
        dictgen::InsensitiveStr::Ascii("stallisability"),
        dictgen::InsensitiveStr::Ascii("stallisable"),
        dictgen::InsensitiveStr::Ascii("stallisabler"),
        dictgen::InsensitiveStr::Ascii("stallisables"),
        dictgen::InsensitiveStr::Ascii("stallisablest"),
        dictgen::InsensitiveStr::Ascii("stallisation"),
        dictgen::InsensitiveStr::Ascii("stallisations"),
        dictgen::InsensitiveStr::Ascii("stallise"),
        dictgen::InsensitiveStr::Ascii("stallised"),
        dictgen::InsensitiveStr::Ascii("stalliser"),
        dictgen::InsensitiveStr::Ascii("stallisers"),
        dictgen::InsensitiveStr::Ascii("stallises"),
        dictgen::InsensitiveStr::Ascii("stallising"),
        dictgen::InsensitiveStr::Ascii("stallizabilities"),
        dictgen::InsensitiveStr::Ascii("stallizability"),
        dictgen::InsensitiveStr::Ascii("stallizable"),
        dictgen::InsensitiveStr::Ascii("stallizabler"),
        dictgen::InsensitiveStr::Ascii("stallizables"),
        dictgen::InsensitiveStr::Ascii("stallizablest"),
        dictgen::InsensitiveStr::Ascii("stallization"),
        dictgen::InsensitiveStr::Ascii("stallizations"),
        dictgen::InsensitiveStr::Ascii("stallize"),
        dictgen::InsensitiveStr::Ascii("stallized"),
        dictgen::InsensitiveStr::Ascii("stallizer"),
        dictgen::InsensitiveStr::Ascii("stallizers"),
        dictgen::InsensitiveStr::Ascii("stallizes"),
        dictgen::InsensitiveStr::Ascii("stallizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CRYESTHESIA_5758775181330161574)],
        &[(0b10001, &ENTRY_CRYESTHESIA_5758775181330161574)],
        &[(0b11010, &ENTRY_CRYOANESTHESIA_5659435164723717323)],
        &[(0b10001, &ENTRY_CRYOANESTHESIA_5659435164723717323)],
        &[(0b11010, &ENTRY_CRYPTESTHESIA_11957770407798142447)],
        &[(0b11010, &ENTRY_CRYPTESTHESIAS_13878578396343060203)],
        &[(0b11010, &ENTRY_CRYPTESTHETIC_6202935653821971765)],
        &[(0b10010, &ENTRY_CRYPTANALYZES_8578659007864632505)],
        &[(0b01001, &ENTRY_CRYPTANALYZES_8578659007864632505)],
        &[(0b10001, &ENTRY_CRYPTESTHESIA_11957770407798142447)],
        &[(0b10001, &ENTRY_CRYPTESTHESIAS_13878578396343060203)],
        &[(0b10001, &ENTRY_CRYPTESTHETIC_6202935653821971765)],
        &[(0b00001, &ENTRY_CRYSTALLIZE_16085680612819973763)],
        &[(0b00001, &ENTRY_CRYSTALLIZED_1190597515180481232)],
        &[(0b00001, &ENTRY_CRYSTALLIZES_4917509722520652987)],
        &[(0b00001, &ENTRY_CRYSTALLIZING_1947916141166292087)],
        &[(0b10010, &ENTRY_CRYSTALLIZABILITIES_3954684427565379393)],
        &[(0b10010, &ENTRY_CRYSTALLIZABILITY_417676650172898499)],
        &[(0b10010, &ENTRY_CRYSTALLIZABLE_5487202742125994763)],
        &[(0b10010, &ENTRY_CRYSTALLIZABLER_14422860421659122029)],
        &[(0b10010, &ENTRY_CRYSTALLIZABLES_13105784762937285967)],
        &[(0b10010, &ENTRY_CRYSTALLIZABLEST_11639541143335039276)],
        &[(0b10010, &ENTRY_CRYSTALLIZATION_11917761263858890133)],
        &[(0b10010, &ENTRY_CRYSTALLIZATIONS_8117698772064969073)],
        &[(0b10010, &ENTRY_CRYSTALLIZE_16085680612819973763)],
        &[(0b10010, &ENTRY_CRYSTALLIZED_1190597515180481232)],
        &[(0b10010, &ENTRY_CRYSTALLIZER_9934670519220100357)],
        &[(0b10010, &ENTRY_CRYSTALLIZERS_541454243380461975)],
        &[(0b10010, &ENTRY_CRYSTALLIZES_4917509722520652987)],
        &[(0b10010, &ENTRY_CRYSTALLIZING_1947916141166292087)],
        &[(0b01001, &ENTRY_CRYSTALLIZABILITIES_3954684427565379393)],
        &[(0b01001, &ENTRY_CRYSTALLIZABILITY_417676650172898499)],
        &[(0b01001, &ENTRY_CRYSTALLIZABLE_5487202742125994763)],
        &[(0b01001, &ENTRY_CRYSTALLIZABLER_14422860421659122029)],
        &[(0b01001, &ENTRY_CRYSTALLIZABLES_13105784762937285967)],
        &[(0b01001, &ENTRY_CRYSTALLIZABLEST_11639541143335039276)],
        &[(0b01001, &ENTRY_CRYSTALLIZATION_11917761263858890133)],
        &[(0b01001, &ENTRY_CRYSTALLIZATIONS_8117698772064969073)],
        &[(0b01001, &ENTRY_CRYSTALLIZE_16085680612819973763)],
        &[(0b01001, &ENTRY_CRYSTALLIZED_1190597515180481232)],
        &[(0b01001, &ENTRY_CRYSTALLIZER_9934670519220100357)],
        &[(0b01001, &ENTRY_CRYSTALLIZERS_541454243380461975)],
        &[(0b01001, &ENTRY_CRYSTALLIZES_4917509722520652987)],
        &[(0b01001, &ENTRY_CRYSTALLIZING_1947916141166292087)],
    ],
    range: 7..=16,
};

static VARS_CRU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRU_CHILDREN),
    value: None,
};

pub static VARS_CRU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elest"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellest"),
    ],
    values: &[
        &[(0b01001, &ENTRY_CRUELER_8850779393447007974)],
        &[(0b01001, &ENTRY_CRUELEST_9704800828794339180)],
        &[(0b10010, &ENTRY_CRUELIZE_1812841929360609104)],
        &[(0b10010, &ENTRY_CRUELIZES_5359533254509589966)],
        &[(0b01001, &ENTRY_CRUELIZE_1812841929360609104)],
        &[(0b01001, &ENTRY_CRUELIZES_5359533254509589966)],
        &[(0b11010, &ENTRY_CRUELER_8850779393447007974)],
        &[(0b11010, &ENTRY_CRUELEST_9704800828794339180)],
    ],
    range: 4..=6,
};

static VARS_CRO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRO_CHILDREN),
    value: None,
};

pub static VARS_CRO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fterisation"),
        dictgen::InsensitiveStr::Ascii("fterisations"),
        dictgen::InsensitiveStr::Ascii("fterise"),
        dictgen::InsensitiveStr::Ascii("fterises"),
        dictgen::InsensitiveStr::Ascii("fterization"),
        dictgen::InsensitiveStr::Ascii("fterizations"),
        dictgen::InsensitiveStr::Ascii("fterize"),
        dictgen::InsensitiveStr::Ascii("fterizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CROFTERIZATION_5035727674537403320)],
        &[(0b10010, &ENTRY_CROFTERIZATIONS_16334682363476700656)],
        &[(0b10010, &ENTRY_CROFTERIZE_16982662599909303513)],
        &[(0b10010, &ENTRY_CROFTERIZES_11462100976556470416)],
        &[(0b01001, &ENTRY_CROFTERIZATION_5035727674537403320)],
        &[(0b01001, &ENTRY_CROFTERIZATIONS_16334682363476700656)],
        &[(0b01001, &ENTRY_CROFTERIZE_16982662599909303513)],
        &[(0b01001, &ENTRY_CROFTERIZES_11462100976556470416)],
    ],
    range: 7..=12,
};

static VARS_CRI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRI_CHILDREN),
    value: None,
};

pub static VARS_CRI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minalisation"),
        dictgen::InsensitiveStr::Ascii("minalisations"),
        dictgen::InsensitiveStr::Ascii("minalise"),
        dictgen::InsensitiveStr::Ascii("minalised"),
        dictgen::InsensitiveStr::Ascii("minalises"),
        dictgen::InsensitiveStr::Ascii("minalising"),
        dictgen::InsensitiveStr::Ascii("minalization"),
        dictgen::InsensitiveStr::Ascii("minalizations"),
        dictgen::InsensitiveStr::Ascii("minalize"),
        dictgen::InsensitiveStr::Ascii("minalized"),
        dictgen::InsensitiveStr::Ascii("minalizes"),
        dictgen::InsensitiveStr::Ascii("minalizing"),
        dictgen::InsensitiveStr::Ascii("ticisable"),
        dictgen::InsensitiveStr::Ascii("ticisabler"),
        dictgen::InsensitiveStr::Ascii("ticisables"),
        dictgen::InsensitiveStr::Ascii("ticisablest"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticised"),
        dictgen::InsensitiveStr::Ascii("ticiser"),
        dictgen::InsensitiveStr::Ascii("ticisers"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticising"),
        dictgen::InsensitiveStr::Ascii("ticisinglier"),
        dictgen::InsensitiveStr::Ascii("ticisinglies"),
        dictgen::InsensitiveStr::Ascii("ticisingliest"),
        dictgen::InsensitiveStr::Ascii("ticisingly"),
        dictgen::InsensitiveStr::Ascii("ticizable"),
        dictgen::InsensitiveStr::Ascii("ticizabler"),
        dictgen::InsensitiveStr::Ascii("ticizables"),
        dictgen::InsensitiveStr::Ascii("ticizablest"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticized"),
        dictgen::InsensitiveStr::Ascii("ticizer"),
        dictgen::InsensitiveStr::Ascii("ticizers"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("ticizing"),
        dictgen::InsensitiveStr::Ascii("ticizinglier"),
        dictgen::InsensitiveStr::Ascii("ticizinglies"),
        dictgen::InsensitiveStr::Ascii("ticizingliest"),
        dictgen::InsensitiveStr::Ascii("ticizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CRIMINALIZATION_3737684511061545754)],
        &[(0b10010, &ENTRY_CRIMINALIZATIONS_7033644149025759517)],
        &[(0b10010, &ENTRY_CRIMINALIZE_11153638088565284591)],
        &[(0b10010, &ENTRY_CRIMINALIZED_11203535063879460381)],
        &[(0b10010, &ENTRY_CRIMINALIZES_3410670484073252306)],
        &[(0b10010, &ENTRY_CRIMINALIZING_910154589421830415)],
        &[(0b01001, &ENTRY_CRIMINALIZATION_3737684511061545754)],
        &[(0b01001, &ENTRY_CRIMINALIZATIONS_7033644149025759517)],
        &[(0b01001, &ENTRY_CRIMINALIZE_11153638088565284591)],
        &[(0b01001, &ENTRY_CRIMINALIZED_11203535063879460381)],
        &[(0b01001, &ENTRY_CRIMINALIZES_3410670484073252306)],
        &[(0b01001, &ENTRY_CRIMINALIZING_910154589421830415)],
        &[(0b10010, &ENTRY_CRITICIZABLE_11161073204477833540)],
        &[(0b10010, &ENTRY_CRITICIZABLER_15788598655348442927)],
        &[(0b10010, &ENTRY_CRITICIZABLES_15336014985309704799)],
        &[(0b10010, &ENTRY_CRITICIZABLEST_16577651845714565882)],
        &[(0b10010, &ENTRY_CRITICIZE_6068870801343218661)],
        &[(0b10010, &ENTRY_CRITICIZED_11062690254551858674)],
        &[(0b10010, &ENTRY_CRITICIZER_1957848661038883017)],
        &[(0b10010, &ENTRY_CRITICIZERS_1569351139366706310)],
        &[(0b10010, &ENTRY_CRITICIZES_17213534894187218607)],
        &[(0b10010, &ENTRY_CRITICIZING_721139847503188555)],
        &[(0b10010, &ENTRY_CRITICIZINGLIER_5644837899795371316)],
        &[(0b10010, &ENTRY_CRITICIZINGLIES_10873838484352102652)],
        &[(0b10010, &ENTRY_CRITICIZINGLIEST_16754553627614394252)],
        &[(0b10010, &ENTRY_CRITICIZINGLY_17073704302947432967)],
        &[(0b01001, &ENTRY_CRITICIZABLE_11161073204477833540)],
        &[(0b01001, &ENTRY_CRITICIZABLER_15788598655348442927)],
        &[(0b01001, &ENTRY_CRITICIZABLES_15336014985309704799)],
        &[(0b01001, &ENTRY_CRITICIZABLEST_16577651845714565882)],
        &[(0b01001, &ENTRY_CRITICIZE_6068870801343218661)],
        &[(0b01001, &ENTRY_CRITICIZED_11062690254551858674)],
        &[(0b01001, &ENTRY_CRITICIZER_1957848661038883017)],
        &[(0b01001, &ENTRY_CRITICIZERS_1569351139366706310)],
        &[(0b01001, &ENTRY_CRITICIZES_17213534894187218607)],
        &[(0b01001, &ENTRY_CRITICIZING_721139847503188555)],
        &[(0b01001, &ENTRY_CRITICIZINGLIER_5644837899795371316)],
        &[(0b01001, &ENTRY_CRITICIZINGLIES_10873838484352102652)],
        &[(0b01001, &ENTRY_CRITICIZINGLIEST_16754553627614394252)],
        &[(0b01001, &ENTRY_CRITICIZINGLY_17073704302947432967)],
    ],
    range: 6..=13,
};

static VARS_CRE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRE_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_CER_16898181025911443964)]),
};

pub static VARS_CRE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("at"),
        dictgen::InsensitiveStr::Ascii("atin"),
        dictgen::InsensitiveStr::Ascii("atins"),
        dictgen::InsensitiveStr::Ascii("aturise"),
        dictgen::InsensitiveStr::Ascii("aturises"),
        dictgen::InsensitiveStr::Ascii("aturize"),
        dictgen::InsensitiveStr::Ascii("aturizes"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("nellate"),
        dictgen::InsensitiveStr::Ascii("nellated"),
        dictgen::InsensitiveStr::Ascii("nellater"),
        dictgen::InsensitiveStr::Ascii("nellates"),
        dictgen::InsensitiveStr::Ascii("nellatest"),
        dictgen::InsensitiveStr::Ascii("nellating"),
        dictgen::InsensitiveStr::Ascii("nellation"),
        dictgen::InsensitiveStr::Ascii("nellations"),
        dictgen::InsensitiveStr::Ascii("nelled"),
        dictgen::InsensitiveStr::Ascii("nelling"),
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olisations"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olite"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olizations"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
        dictgen::InsensitiveStr::Ascii("tinisation"),
        dictgen::InsensitiveStr::Ascii("tinisations"),
        dictgen::InsensitiveStr::Ascii("tinise"),
        dictgen::InsensitiveStr::Ascii("tinised"),
        dictgen::InsensitiveStr::Ascii("tinises"),
        dictgen::InsensitiveStr::Ascii("tinising"),
        dictgen::InsensitiveStr::Ascii("tinization"),
        dictgen::InsensitiveStr::Ascii("tinizations"),
        dictgen::InsensitiveStr::Ascii("tinize"),
        dictgen::InsensitiveStr::Ascii("tinized"),
        dictgen::InsensitiveStr::Ascii("tinizes"),
        dictgen::InsensitiveStr::Ascii("tinizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CERA_7059694773303335761)],
        &[(0b11010, &ENTRY_CERAT_1886332108569610985)],
        &[(0b11010, &ENTRY_CERATIN_7844527544181435388)],
        &[(0b11010, &ENTRY_CERATINS_7956220450419624429)],
        &[(0b10010, &ENTRY_CREATURIZE_11671782863777774169)],
        &[(0b10010, &ENTRY_CREATURIZES_11072091990116315598)],
        &[(0b01001, &ENTRY_CREATURIZE_11671782863777774169)],
        &[(0b01001, &ENTRY_CREATURIZES_11072091990116315598)],
        &[(0b11010, &ENTRY_CERE_9821157149992437937)],
        &[(0b11010, &ENTRY_CERES_4278379745962029428)],
        &[(0b11010, &ENTRY_CRENELATE_4846628544233188866)],
        &[(0b11010, &ENTRY_CRENELATED_4747089085581062744)],
        &[(0b11010, &ENTRY_CRENELATER_17949792491463033916)],
        &[(0b11010, &ENTRY_CRENELATES_1558161520210179871)],
        &[(0b11010, &ENTRY_CRENELATEST_4139190496016465578)],
        &[(0b11010, &ENTRY_CRENELATING_3475200518815041064)],
        &[(0b11010, &ENTRY_CRENELATION_1079785305940612588)],
        &[(0b11010, &ENTRY_CRENELATIONS_13269172105110545010)],
        &[(0b11010, &ENTRY_CRENELED_12587802714564552958)],
        &[(0b11010, &ENTRY_CRENELING_15994472673064843243)],
        &[(0b10010, &ENTRY_CREOLIZATION_2399026028067198251)],
        &[(0b10010, &ENTRY_CREOLIZATIONS_18438815551943447952)],
        &[(0b10010, &ENTRY_CREOLIZE_5145685228179089111)],
        &[(0b10010, &ENTRY_CREOLIZED_7643361883981250764)],
        &[(0b10010, &ENTRY_CREOLIZES_3089367645000699437)],
        &[(0b10010, &ENTRY_CREOLIZING_12140091392528441353)],
        &[(0b11010, &ENTRY_CEROLITE_7632841335460717740)],
        &[(0b01001, &ENTRY_CREOLIZATION_2399026028067198251)],
        &[(0b01001, &ENTRY_CREOLIZATIONS_18438815551943447952)],
        &[(0b01001, &ENTRY_CREOLIZE_5145685228179089111)],
        &[(0b01001, &ENTRY_CREOLIZED_7643361883981250764)],
        &[(0b01001, &ENTRY_CREOLIZES_3089367645000699437)],
        &[(0b01001, &ENTRY_CREOLIZING_12140091392528441353)],
        &[(0b10010, &ENTRY_CRETINIZATION_9976126052462780936)],
        &[(0b10010, &ENTRY_CRETINIZATIONS_8550950897045447908)],
        &[(0b10010, &ENTRY_CRETINIZE_567737549892855222)],
        &[(0b10010, &ENTRY_CRETINIZED_970325680379971482)],
        &[(0b10010, &ENTRY_CRETINIZES_15606980122166252360)],
        &[(0b10010, &ENTRY_CRETINIZING_10538665090855146969)],
        &[(0b01001, &ENTRY_CRETINIZATION_9976126052462780936)],
        &[(0b01001, &ENTRY_CRETINIZATIONS_8550950897045447908)],
        &[(0b01001, &ENTRY_CRETINIZE_567737549892855222)],
        &[(0b01001, &ENTRY_CRETINIZED_970325680379971482)],
        &[(0b01001, &ENTRY_CRETINIZES_15606980122166252360)],
        &[(0b01001, &ENTRY_CRETINIZING_10538665090855146969)],
    ],
    range: 1..=11,
};

static VARS_CRA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CRA_CHILDREN),
    value: None,
};

pub static VARS_CRA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isey"),
        dictgen::InsensitiveStr::Ascii("izey"),
        dictgen::InsensitiveStr::Ascii("mbes"),
        dictgen::InsensitiveStr::Ascii("mboes"),
        dictgen::InsensitiveStr::Ascii("wlerise"),
        dictgen::InsensitiveStr::Ascii("wlerises"),
        dictgen::InsensitiveStr::Ascii("wlerize"),
        dictgen::InsensitiveStr::Ascii("wlerizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CRAIZEY_11207510142316496553)],
        &[(0b01001, &ENTRY_CRAIZEY_11207510142316496553)],
        &[(0b00001, &ENTRY_CRAMBES_5154618776124525704)],
        &[(0b11010, &ENTRY_CRAMBES_5154618776124525704)],
        &[(0b10010, &ENTRY_CRAWLERIZE_812960636373413412)],
        &[(0b10010, &ENTRY_CRAWLERIZES_13469653902313454380)],
        &[(0b01001, &ENTRY_CRAWLERIZE_812960636373413412)],
        &[(0b01001, &ENTRY_CRAWLERIZES_13469653902313454380)],
    ],
    range: 4..=8,
};

static VARS_CO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CO_CHILDREN),
    value: None,
};

static VARS_CO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_COA_NODE),
    None,
    Some(&VARS_COC_NODE),
    None,
    Some(&VARS_COE_NODE),
    None,
    Some(&VARS_COG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_COL_NODE),
    Some(&VARS_COM_NODE),
    Some(&VARS_CON_NODE),
    Some(&VARS_COO_NODE),
    Some(&VARS_COP_NODE),
    None,
    Some(&VARS_COR_NODE),
    Some(&VARS_COS_NODE),
    Some(&VARS_COT_NODE),
    Some(&VARS_COU_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_COZ_NODE),
];

static VARS_COZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COZ_CHILDREN),
    value: None,
};

pub static VARS_COZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ied"),
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("ies"),
        dictgen::InsensitiveStr::Ascii("iest"),
        dictgen::InsensitiveStr::Ascii("ily"),
        dictgen::InsensitiveStr::Ascii("iness"),
        dictgen::InsensitiveStr::Ascii("y"),
        dictgen::InsensitiveStr::Ascii("ying"),
    ],
    values: &[
        &[(0b01001, &ENTRY_COZIED_892102520341074320)],
        &[(0b01001, &ENTRY_COZIER_16664560812994447871)],
        &[(0b01001, &ENTRY_COZIES_14939999790619704585)],
        &[(0b01001, &ENTRY_COZIEST_2405878050968803482)],
        &[(0b01001, &ENTRY_COZILY_12652080440015563463)],
        &[(0b01001, &ENTRY_COZINESS_4340402800488732549)],
        &[(0b01001, &ENTRY_COZY_16771377950900395846)],
        &[(0b01001, &ENTRY_COZYING_8737786447759601632)],
    ],
    range: 1..=5,
};

static VARS_COU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COU_CHILDREN),
    value: None,
};

pub static VARS_COU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ncillor"),
        dictgen::InsensitiveStr::Ascii("ncillors"),
        dictgen::InsensitiveStr::Ascii("ncillorship"),
        dictgen::InsensitiveStr::Ascii("ncillorships"),
        dictgen::InsensitiveStr::Ascii("ncilor"),
        dictgen::InsensitiveStr::Ascii("ncilors"),
        dictgen::InsensitiveStr::Ascii("ncilorship"),
        dictgen::InsensitiveStr::Ascii("ncilorships"),
        dictgen::InsensitiveStr::Ascii("nseled"),
        dictgen::InsensitiveStr::Ascii("nselee"),
        dictgen::InsensitiveStr::Ascii("nseling"),
        dictgen::InsensitiveStr::Ascii("nselled"),
        dictgen::InsensitiveStr::Ascii("nsellee"),
        dictgen::InsensitiveStr::Ascii("nselling"),
        dictgen::InsensitiveStr::Ascii("nsellor"),
        dictgen::InsensitiveStr::Ascii("nsellors"),
        dictgen::InsensitiveStr::Ascii("nsellorship"),
        dictgen::InsensitiveStr::Ascii("nsellorships"),
        dictgen::InsensitiveStr::Ascii("nselor"),
        dictgen::InsensitiveStr::Ascii("nselors"),
        dictgen::InsensitiveStr::Ascii("nselorship"),
        dictgen::InsensitiveStr::Ascii("nselorships"),
        dictgen::InsensitiveStr::Ascii("ntercolored"),
        dictgen::InsensitiveStr::Ascii("ntercoloured"),
        dictgen::InsensitiveStr::Ascii("ntor"),
        dictgen::InsensitiveStr::Ascii("ntour"),
        dictgen::InsensitiveStr::Ascii("ranto"),
        dictgen::InsensitiveStr::Ascii("rantoes"),
        dictgen::InsensitiveStr::Ascii("rantos"),
        dictgen::InsensitiveStr::Ascii("rbe"),
        dictgen::InsensitiveStr::Ascii("rbed"),
        dictgen::InsensitiveStr::Ascii("rge"),
        dictgen::InsensitiveStr::Ascii("rsy"),
        dictgen::InsensitiveStr::Ascii("rtage"),
        dictgen::InsensitiveStr::Ascii("rtin"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COUNCILOR_9008971708424749691)],
        &[(0b11010, &ENTRY_COUNCILORS_10740681458284876699)],
        &[(0b11010, &ENTRY_COUNCILORSHIP_11271914097682866054)],
        &[(0b11010, &ENTRY_COUNCILORSHIPS_4030354772794301642)],
        &[(0b00001, &ENTRY_COUNCILOR_9008971708424749691)],
        &[(0b00001, &ENTRY_COUNCILORS_10740681458284876699)],
        &[(0b00001, &ENTRY_COUNCILORSHIP_11271914097682866054)],
        &[(0b00001, &ENTRY_COUNCILORSHIPS_4030354772794301642)],
        &[(0b00001, &ENTRY_COUNSELED_16528360610427400796)],
        &[(0b00001, &ENTRY_COUNSELEE_5928413848108470968)],
        &[(0b00001, &ENTRY_COUNSELING_801410554831071578)],
        &[(0b11010, &ENTRY_COUNSELED_16528360610427400796)],
        &[(0b11010, &ENTRY_COUNSELEE_5928413848108470968)],
        &[(0b11010, &ENTRY_COUNSELING_801410554831071578)],
        &[(0b11010, &ENTRY_COUNSELOR_10543167328253513516)],
        &[(0b11010, &ENTRY_COUNSELORS_13992003748073450387)],
        &[(0b11010, &ENTRY_COUNSELORSHIP_5288062081367197198)],
        &[(0b11010, &ENTRY_COUNSELORSHIPS_7582354069010921169)],
        &[(0b01001, &ENTRY_COUNSELOR_10543167328253513516)],
        &[(0b01001, &ENTRY_COUNSELORS_13992003748073450387)],
        &[(0b00001, &ENTRY_COUNSELORSHIP_5288062081367197198)],
        &[(0b00001, &ENTRY_COUNSELORSHIPS_7582354069010921169)],
        &[(0b10001, &ENTRY_COUNTERCOLORED_4458254746746370067)],
        &[(0b11010, &ENTRY_COUNTERCOLORED_4458254746746370067)],
        &[(0b00001, &ENTRY_COUNTOR_3612808841271391195)],
        &[(0b11010, &ENTRY_COUNTOR_3612808841271391195)],
        &[(0b11010, &ENTRY_CORANTO_4279134034163662809)],
        &[(0b11010, &ENTRY_CORANTOES_3187574316281975902)],
        &[(0b11010, &ENTRY_CORANTOS_4303750137767317450)],
        &[(0b11010, &ENTRY_CORBE_17730991887414349664)],
        &[(0b11010, &ENTRY_CORBED_3736423820408057899)],
        &[(0b11010, &ENTRY_CORGE_17139623337126675741)],
        &[(0b11010, &ENTRY_CORSY_8397709613851582338)],
        &[(0b11010, &ENTRY_CORTAGE_11582769904852791421)],
        &[(0b11010, &ENTRY_CORTIN_6028563342284786375)],
    ],
    range: 3..=12,
};

static VARS_COT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COT_CHILDREN),
    value: None,
};

pub static VARS_COT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tonisation"),
        dictgen::InsensitiveStr::Ascii("tonisations"),
        dictgen::InsensitiveStr::Ascii("tonise"),
        dictgen::InsensitiveStr::Ascii("tonises"),
        dictgen::InsensitiveStr::Ascii("tonization"),
        dictgen::InsensitiveStr::Ascii("tonizations"),
        dictgen::InsensitiveStr::Ascii("tonize"),
        dictgen::InsensitiveStr::Ascii("tonizes"),
        dictgen::InsensitiveStr::Ascii("ylae"),
        dictgen::InsensitiveStr::Ascii("yle"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COTTE_13644830532086634992)],
        &[(0b00001, &ENTRY_COTTE_13644830532086634992)],
        &[(0b10010, &ENTRY_COTTONIZATION_3551122105294457662)],
        &[(0b10010, &ENTRY_COTTONIZATIONS_17749803100676719261)],
        &[(0b10010, &ENTRY_COTTONIZE_937005096342491386)],
        &[(0b10010, &ENTRY_COTTONIZES_9008427680743356385)],
        &[(0b01001, &ENTRY_COTTONIZATION_3551122105294457662)],
        &[(0b01001, &ENTRY_COTTONIZATIONS_17749803100676719261)],
        &[(0b01001, &ENTRY_COTTONIZE_937005096342491386)],
        &[(0b01001, &ENTRY_COTTONIZES_9008427680743356385)],
        &[(0b11010, &ENTRY_COTYLE_942493646255101754)],
        &[(0b00001, &ENTRY_COTYLE_942493646255101754)],
    ],
    range: 2..=11,
};

static VARS_COS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COS_CHILDREN),
    value: None,
};

pub static VARS_COS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ied"),
        dictgen::InsensitiveStr::Ascii("ier"),
        dictgen::InsensitiveStr::Ascii("ies"),
        dictgen::InsensitiveStr::Ascii("iest"),
        dictgen::InsensitiveStr::Ascii("ily"),
        dictgen::InsensitiveStr::Ascii("iness"),
        dictgen::InsensitiveStr::Ascii("meticise"),
        dictgen::InsensitiveStr::Ascii("meticised"),
        dictgen::InsensitiveStr::Ascii("meticises"),
        dictgen::InsensitiveStr::Ascii("meticising"),
        dictgen::InsensitiveStr::Ascii("meticize"),
        dictgen::InsensitiveStr::Ascii("meticized"),
        dictgen::InsensitiveStr::Ascii("meticizes"),
        dictgen::InsensitiveStr::Ascii("meticizing"),
        dictgen::InsensitiveStr::Ascii("mopolitanisation"),
        dictgen::InsensitiveStr::Ascii("mopolitanisations"),
        dictgen::InsensitiveStr::Ascii("mopolitanise"),
        dictgen::InsensitiveStr::Ascii("mopolitanised"),
        dictgen::InsensitiveStr::Ascii("mopolitanises"),
        dictgen::InsensitiveStr::Ascii("mopolitanising"),
        dictgen::InsensitiveStr::Ascii("mopolitanization"),
        dictgen::InsensitiveStr::Ascii("mopolitanizations"),
        dictgen::InsensitiveStr::Ascii("mopolitanize"),
        dictgen::InsensitiveStr::Ascii("mopolitanized"),
        dictgen::InsensitiveStr::Ascii("mopolitanizes"),
        dictgen::InsensitiveStr::Ascii("mopolitanizing"),
        dictgen::InsensitiveStr::Ascii("plendor"),
        dictgen::InsensitiveStr::Ascii("plendour"),
        dictgen::InsensitiveStr::Ascii("tae"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tumier"),
        dictgen::InsensitiveStr::Ascii("tumire"),
        dictgen::InsensitiveStr::Ascii("y"),
        dictgen::InsensitiveStr::Ascii("ying"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COZIED_892102520341074320)],
        &[(0b11010, &ENTRY_COZIER_16664560812994447871)],
        &[(0b11010, &ENTRY_COZIES_14939999790619704585)],
        &[(0b11010, &ENTRY_COZIEST_2405878050968803482)],
        &[(0b10010, &ENTRY_COZILY_12652080440015563463)],
        &[(0b10010, &ENTRY_COZINESS_4340402800488732549)],
        &[(0b10010, &ENTRY_COSMETICIZE_4510163316750805851)],
        &[(0b10010, &ENTRY_COSMETICIZED_13397803251483774269)],
        &[(0b10010, &ENTRY_COSMETICIZES_5573800526141905092)],
        &[(0b10010, &ENTRY_COSMETICIZING_4611837122081199790)],
        &[(0b01001, &ENTRY_COSMETICIZE_4510163316750805851)],
        &[(0b01001, &ENTRY_COSMETICIZED_13397803251483774269)],
        &[(0b01001, &ENTRY_COSMETICIZES_5573800526141905092)],
        &[(0b01001, &ENTRY_COSMETICIZING_4611837122081199790)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZATION_13712421328153787188)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZATIONS_17982550395466641141)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZE_11591269984956762481)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZED_15042192345530983967)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZES_57296618879818157)],
        &[(0b10010, &ENTRY_COSMOPOLITANIZING_11804948920948531162)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZATION_13712421328153787188)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZATIONS_17982550395466641141)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZE_11591269984956762481)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZED_15042192345530983967)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZES_57296618879818157)],
        &[(0b01001, &ENTRY_COSMOPOLITANIZING_11804948920948531162)],
        &[(0b10001, &ENTRY_COSPLENDOR_14307850165475070048)],
        &[(0b11010, &ENTRY_COSPLENDOR_14307850165475070048)],
        &[(0b11010, &ENTRY_COSTE_1360786639006955600)],
        &[(0b00001, &ENTRY_COSTE_1360786639006955600)],
        &[(0b00001, &ENTRY_COSTUMIER_4823477100121806221)],
        &[(0b11010, &ENTRY_COSTUMIER_4823477100121806221)],
        &[(0b11010, &ENTRY_COZY_16771377950900395846)],
        &[(0b11010, &ENTRY_COZYING_8737786447759601632)],
    ],
    range: 1..=17,
};

static VARS_COR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COR_CHILDREN),
    value: None,
};

pub static VARS_COR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aled"),
        dictgen::InsensitiveStr::Ascii("alled"),
        dictgen::InsensitiveStr::Ascii("anto"),
        dictgen::InsensitiveStr::Ascii("antoes"),
        dictgen::InsensitiveStr::Ascii("antos"),
        dictgen::InsensitiveStr::Ascii("be"),
        dictgen::InsensitiveStr::Ascii("bed"),
        dictgen::InsensitiveStr::Ascii("beled"),
        dictgen::InsensitiveStr::Ascii("beling"),
        dictgen::InsensitiveStr::Ascii("belings"),
        dictgen::InsensitiveStr::Ascii("belled"),
        dictgen::InsensitiveStr::Ascii("belling"),
        dictgen::InsensitiveStr::Ascii("bellings"),
        dictgen::InsensitiveStr::Ascii("dialise"),
        dictgen::InsensitiveStr::Ascii("dialised"),
        dictgen::InsensitiveStr::Ascii("dialises"),
        dictgen::InsensitiveStr::Ascii("dialising"),
        dictgen::InsensitiveStr::Ascii("dialize"),
        dictgen::InsensitiveStr::Ascii("dialized"),
        dictgen::InsensitiveStr::Ascii("dializes"),
        dictgen::InsensitiveStr::Ascii("dializing"),
        dictgen::InsensitiveStr::Ascii("ge"),
        dictgen::InsensitiveStr::Ascii("inthianise"),
        dictgen::InsensitiveStr::Ascii("inthianised"),
        dictgen::InsensitiveStr::Ascii("inthianises"),
        dictgen::InsensitiveStr::Ascii("inthianising"),
        dictgen::InsensitiveStr::Ascii("inthianize"),
        dictgen::InsensitiveStr::Ascii("inthianized"),
        dictgen::InsensitiveStr::Ascii("inthianizes"),
        dictgen::InsensitiveStr::Ascii("inthianizing"),
        dictgen::InsensitiveStr::Ascii("porealisation"),
        dictgen::InsensitiveStr::Ascii("porealisations"),
        dictgen::InsensitiveStr::Ascii("porealise"),
        dictgen::InsensitiveStr::Ascii("porealised"),
        dictgen::InsensitiveStr::Ascii("porealises"),
        dictgen::InsensitiveStr::Ascii("porealising"),
        dictgen::InsensitiveStr::Ascii("porealization"),
        dictgen::InsensitiveStr::Ascii("porealizations"),
        dictgen::InsensitiveStr::Ascii("porealize"),
        dictgen::InsensitiveStr::Ascii("porealized"),
        dictgen::InsensitiveStr::Ascii("porealizes"),
        dictgen::InsensitiveStr::Ascii("porealizing"),
        dictgen::InsensitiveStr::Ascii("sy"),
        dictgen::InsensitiveStr::Ascii("tage"),
        dictgen::InsensitiveStr::Ascii("tin"),
        dictgen::InsensitiveStr::Ascii("tinae"),
        dictgen::InsensitiveStr::Ascii("tine"),
        dictgen::InsensitiveStr::Ascii("vae"),
        dictgen::InsensitiveStr::Ascii("ve"),
        dictgen::InsensitiveStr::Ascii("yphae"),
        dictgen::InsensitiveStr::Ascii("yphaes"),
        dictgen::InsensitiveStr::Ascii("yphe"),
        dictgen::InsensitiveStr::Ascii("yphes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CORALED_17029032369203888932)],
        &[(0b11010, &ENTRY_CORALED_17029032369203888932)],
        &[(0b00001, &ENTRY_CORANTO_4279134034163662809)],
        &[(0b00001, &ENTRY_CORANTOES_3187574316281975902)],
        &[(0b00001, &ENTRY_CORANTOS_4303750137767317450)],
        &[(0b00001, &ENTRY_CORBE_17730991887414349664)],
        &[(0b00001, &ENTRY_CORBED_3736423820408057899)],
        &[(0b00001, &ENTRY_CORBELED_6042612068469726728)],
        &[(0b00001, &ENTRY_CORBELING_17424209206512192853)],
        &[(0b00001, &ENTRY_CORBELINGS_3564173093504722553)],
        &[(0b11010, &ENTRY_CORBELED_6042612068469726728)],
        &[(0b11010, &ENTRY_CORBELING_17424209206512192853)],
        &[(0b11010, &ENTRY_CORBELINGS_3564173093504722553)],
        &[(0b10010, &ENTRY_CORDIALIZE_18283820928702090126)],
        &[(0b10010, &ENTRY_CORDIALIZED_17060566600018841931)],
        &[(0b10010, &ENTRY_CORDIALIZES_15225222580021745806)],
        &[(0b10010, &ENTRY_CORDIALIZING_16322807405354472673)],
        &[(0b01001, &ENTRY_CORDIALIZE_18283820928702090126)],
        &[(0b01001, &ENTRY_CORDIALIZED_17060566600018841931)],
        &[(0b01001, &ENTRY_CORDIALIZES_15225222580021745806)],
        &[(0b01001, &ENTRY_CORDIALIZING_16322807405354472673)],
        &[(0b00001, &ENTRY_CORGE_17139623337126675741)],
        &[(0b10010, &ENTRY_CORINTHIANIZE_15193202304262813823)],
        &[(0b10010, &ENTRY_CORINTHIANIZED_3878556826042603473)],
        &[(0b10010, &ENTRY_CORINTHIANIZES_15960209016441005021)],
        &[(0b10010, &ENTRY_CORINTHIANIZING_5628303096329418476)],
        &[(0b01001, &ENTRY_CORINTHIANIZE_15193202304262813823)],
        &[(0b01001, &ENTRY_CORINTHIANIZED_3878556826042603473)],
        &[(0b01001, &ENTRY_CORINTHIANIZES_15960209016441005021)],
        &[(0b01001, &ENTRY_CORINTHIANIZING_5628303096329418476)],
        &[(0b10010, &ENTRY_CORPOREALIZATION_13444603137664491535)],
        &[(0b10010, &ENTRY_CORPOREALIZATIONS_13406569937168049681)],
        &[(0b10010, &ENTRY_CORPOREALIZE_15369417358773446090)],
        &[(0b10010, &ENTRY_CORPOREALIZED_12082854418069448893)],
        &[(0b10010, &ENTRY_CORPOREALIZES_13055328418208419278)],
        &[(0b10010, &ENTRY_CORPOREALIZING_3901751814264969100)],
        &[(0b01001, &ENTRY_CORPOREALIZATION_13444603137664491535)],
        &[(0b01001, &ENTRY_CORPOREALIZATIONS_13406569937168049681)],
        &[(0b01001, &ENTRY_CORPOREALIZE_15369417358773446090)],
        &[(0b01001, &ENTRY_CORPOREALIZED_12082854418069448893)],
        &[(0b01001, &ENTRY_CORPOREALIZES_13055328418208419278)],
        &[(0b01001, &ENTRY_CORPOREALIZING_3901751814264969100)],
        &[(0b00001, &ENTRY_CORSY_8397709613851582338)],
        &[(0b00001, &ENTRY_CORTAGE_11582769904852791421)],
        &[(0b00001, &ENTRY_CORTIN_6028563342284786375)],
        &[(0b11010, &ENTRY_CORTINE_13597620914405629291)],
        &[(0b00001, &ENTRY_CORTINE_13597620914405629291)],
        &[(0b11010, &ENTRY_CORVE_15600376709730904093)],
        &[(0b00001, &ENTRY_CORVE_15600376709730904093)],
        &[(0b11010, &ENTRY_CORYPHE_5310787045413936233)],
        &[(0b11010, &ENTRY_CORYPHES_13646996028278890092)],
        &[(0b00001, &ENTRY_CORYPHE_5310787045413936233)],
        &[(0b00001, &ENTRY_CORYPHES_13646996028278890092)],
    ],
    range: 2..=14,
};

static VARS_COP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COP_CHILDREN),
    value: None,
};

pub static VARS_COP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olymerisation"),
        dictgen::InsensitiveStr::Ascii("olymerisations"),
        dictgen::InsensitiveStr::Ascii("olymerise"),
        dictgen::InsensitiveStr::Ascii("olymerised"),
        dictgen::InsensitiveStr::Ascii("olymerises"),
        dictgen::InsensitiveStr::Ascii("olymerising"),
        dictgen::InsensitiveStr::Ascii("olymerization"),
        dictgen::InsensitiveStr::Ascii("olymerizations"),
        dictgen::InsensitiveStr::Ascii("olymerize"),
        dictgen::InsensitiveStr::Ascii("olymerized"),
        dictgen::InsensitiveStr::Ascii("olymerizes"),
        dictgen::InsensitiveStr::Ascii("olymerizing"),
        dictgen::InsensitiveStr::Ascii("perisation"),
        dictgen::InsensitiveStr::Ascii("perisations"),
        dictgen::InsensitiveStr::Ascii("perise"),
        dictgen::InsensitiveStr::Ascii("perises"),
        dictgen::InsensitiveStr::Ascii("perization"),
        dictgen::InsensitiveStr::Ascii("perizations"),
        dictgen::InsensitiveStr::Ascii("perize"),
        dictgen::InsensitiveStr::Ascii("perizes"),
        dictgen::InsensitiveStr::Ascii("raemia"),
        dictgen::InsensitiveStr::Ascii("raemic"),
        dictgen::InsensitiveStr::Ascii("remia"),
        dictgen::InsensitiveStr::Ascii("remic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COPOLYMERIZATION_3565686431310114577)],
        &[(0b10010, &ENTRY_COPOLYMERIZATIONS_5973914645684635)],
        &[(0b10010, &ENTRY_COPOLYMERIZE_4215053249879524882)],
        &[(0b10010, &ENTRY_COPOLYMERIZED_17760814634904159372)],
        &[(0b10010, &ENTRY_COPOLYMERIZES_13350833418414627371)],
        &[(0b10010, &ENTRY_COPOLYMERIZING_322624390484211449)],
        &[(0b01001, &ENTRY_COPOLYMERIZATION_3565686431310114577)],
        &[(0b01001, &ENTRY_COPOLYMERIZATIONS_5973914645684635)],
        &[(0b01001, &ENTRY_COPOLYMERIZE_4215053249879524882)],
        &[(0b01001, &ENTRY_COPOLYMERIZED_17760814634904159372)],
        &[(0b01001, &ENTRY_COPOLYMERIZES_13350833418414627371)],
        &[(0b01001, &ENTRY_COPOLYMERIZING_322624390484211449)],
        &[(0b10010, &ENTRY_COPPERIZATION_964826321420421086)],
        &[(0b10010, &ENTRY_COPPERIZATIONS_6621746123672599508)],
        &[(0b10010, &ENTRY_COPPERIZE_8585777073067773483)],
        &[(0b10010, &ENTRY_COPPERIZES_11565506510531680556)],
        &[(0b01001, &ENTRY_COPPERIZATION_964826321420421086)],
        &[(0b01001, &ENTRY_COPPERIZATIONS_6621746123672599508)],
        &[(0b01001, &ENTRY_COPPERIZE_8585777073067773483)],
        &[(0b01001, &ENTRY_COPPERIZES_11565506510531680556)],
        &[(0b11010, &ENTRY_COPREMIA_15716946293536237967)],
        &[(0b11010, &ENTRY_COPREMIC_330320805830628274)],
        &[(0b10001, &ENTRY_COPREMIA_15716946293536237967)],
        &[(0b10001, &ENTRY_COPREMIC_330320805830628274)],
    ],
    range: 5..=14,
};

static VARS_COO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COO_CHILDREN),
    value: None,
};

pub static VARS_COO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ky"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COE_10755603025154058571)],
        &[(0b00001, &ENTRY_COOKIE_7907860379600479031)],
    ],
    range: 1..=2,
};

static VARS_CON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CON_CHILDREN),
    value: None,
};

static VARS_CON_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CONC_NODE),
    Some(&VARS_COND_NODE),
    None,
    Some(&VARS_CONF_NODE),
    Some(&VARS_CONG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CONN_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CONS_NODE),
    Some(&VARS_CONT_NODE),
    Some(&VARS_CONU_NODE),
    Some(&VARS_CONV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_CONV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONV_CHILDREN),
    value: None,
};

pub static VARS_CONV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("entionalisation"),
        dictgen::InsensitiveStr::Ascii("entionalisations"),
        dictgen::InsensitiveStr::Ascii("entionalise"),
        dictgen::InsensitiveStr::Ascii("entionalised"),
        dictgen::InsensitiveStr::Ascii("entionalises"),
        dictgen::InsensitiveStr::Ascii("entionalising"),
        dictgen::InsensitiveStr::Ascii("entionalization"),
        dictgen::InsensitiveStr::Ascii("entionalizations"),
        dictgen::InsensitiveStr::Ascii("entionalize"),
        dictgen::InsensitiveStr::Ascii("entionalized"),
        dictgen::InsensitiveStr::Ascii("entionalizes"),
        dictgen::InsensitiveStr::Ascii("entionalizing"),
        dictgen::InsensitiveStr::Ascii("entionise"),
        dictgen::InsensitiveStr::Ascii("entionises"),
        dictgen::InsensitiveStr::Ascii("entionize"),
        dictgen::InsensitiveStr::Ascii("entionizes"),
        dictgen::InsensitiveStr::Ascii("ersationise"),
        dictgen::InsensitiveStr::Ascii("ersationises"),
        dictgen::InsensitiveStr::Ascii("ersationize"),
        dictgen::InsensitiveStr::Ascii("ersationizes"),
        dictgen::InsensitiveStr::Ascii("ertor"),
        dictgen::InsensitiveStr::Ascii("ertors"),
        dictgen::InsensitiveStr::Ascii("eyorise"),
        dictgen::InsensitiveStr::Ascii("eyorised"),
        dictgen::InsensitiveStr::Ascii("eyorises"),
        dictgen::InsensitiveStr::Ascii("eyorising"),
        dictgen::InsensitiveStr::Ascii("eyorize"),
        dictgen::InsensitiveStr::Ascii("eyorized"),
        dictgen::InsensitiveStr::Ascii("eyorizes"),
        dictgen::InsensitiveStr::Ascii("eyorizing"),
        dictgen::InsensitiveStr::Ascii("ivialise"),
        dictgen::InsensitiveStr::Ascii("ivialises"),
        dictgen::InsensitiveStr::Ascii("ivialize"),
        dictgen::InsensitiveStr::Ascii("ivializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONVENTIONALIZATION_13028625690092222465)],
        &[(0b10010, &ENTRY_CONVENTIONALIZATIONS_16276682879105179823)],
        &[(0b10010, &ENTRY_CONVENTIONALIZE_5523697518996561640)],
        &[(0b10010, &ENTRY_CONVENTIONALIZED_12965553780389351275)],
        &[(0b10010, &ENTRY_CONVENTIONALIZES_9272151990564007911)],
        &[(0b10010, &ENTRY_CONVENTIONALIZING_8403911928878303814)],
        &[(0b01001, &ENTRY_CONVENTIONALIZATION_13028625690092222465)],
        &[(0b01001, &ENTRY_CONVENTIONALIZATIONS_16276682879105179823)],
        &[(0b01001, &ENTRY_CONVENTIONALIZE_5523697518996561640)],
        &[(0b01001, &ENTRY_CONVENTIONALIZED_12965553780389351275)],
        &[(0b01001, &ENTRY_CONVENTIONALIZES_9272151990564007911)],
        &[(0b01001, &ENTRY_CONVENTIONALIZING_8403911928878303814)],
        &[(0b10010, &ENTRY_CONVENTIONIZE_10105849898246202377)],
        &[(0b10010, &ENTRY_CONVENTIONIZES_5985365324069048956)],
        &[(0b01001, &ENTRY_CONVENTIONIZE_10105849898246202377)],
        &[(0b01001, &ENTRY_CONVENTIONIZES_5985365324069048956)],
        &[(0b10010, &ENTRY_CONVERSATIONIZE_5100069228660462527)],
        &[(0b10010, &ENTRY_CONVERSATIONIZES_17870350526921946834)],
        &[(0b01001, &ENTRY_CONVERSATIONIZE_5100069228660462527)],
        &[(0b01001, &ENTRY_CONVERSATIONIZES_17870350526921946834)],
        &[
            (0b10010, &ENTRY_CONVERTER_1832376138567767596),
            (0b10011, &ENTRY_CONVERTER_5031978836001352470),
        ],
        &[
            (0b10010, &ENTRY_CONVERTERS_3839419135582169647),
            (0b10011, &ENTRY_CONVERTERS_5331070164538082909),
        ],
        &[(0b10010, &ENTRY_CONVEYORIZE_13627331458498794547)],
        &[(0b10010, &ENTRY_CONVEYORIZED_1550738673068217452)],
        &[(0b10010, &ENTRY_CONVEYORIZES_5699299181152546893)],
        &[(0b10010, &ENTRY_CONVEYORIZING_12428816853490274627)],
        &[(0b01001, &ENTRY_CONVEYORIZE_13627331458498794547)],
        &[(0b01001, &ENTRY_CONVEYORIZED_1550738673068217452)],
        &[(0b01001, &ENTRY_CONVEYORIZES_5699299181152546893)],
        &[(0b01001, &ENTRY_CONVEYORIZING_12428816853490274627)],
        &[(0b10010, &ENTRY_CONVIVIALIZE_12861322270762809887)],
        &[(0b10010, &ENTRY_CONVIVIALIZES_14081286682414244239)],
        &[(0b01001, &ENTRY_CONVIVIALIZE_12861322270762809887)],
        &[(0b01001, &ENTRY_CONVIVIALIZES_14081286682414244239)],
    ],
    range: 5..=16,
};

static VARS_CONU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONU_CHILDREN),
    value: None,
};

pub static VARS_CONU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ndrumise"),
        dictgen::InsensitiveStr::Ascii("ndrumises"),
        dictgen::InsensitiveStr::Ascii("ndrumize"),
        dictgen::InsensitiveStr::Ascii("ndrumizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONUNDRUMIZE_12213997648480363330)],
        &[(0b10010, &ENTRY_CONUNDRUMIZES_7982003424972698355)],
        &[(0b01001, &ENTRY_CONUNDRUMIZE_12213997648480363330)],
        &[(0b01001, &ENTRY_CONUNDRUMIZES_7982003424972698355)],
    ],
    range: 8..=9,
};

static VARS_CONT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONT_CHILDREN),
    value: None,
};

pub static VARS_CONT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ainerisation"),
        dictgen::InsensitiveStr::Ascii("ainerisations"),
        dictgen::InsensitiveStr::Ascii("ainerise"),
        dictgen::InsensitiveStr::Ascii("ainerised"),
        dictgen::InsensitiveStr::Ascii("ainerises"),
        dictgen::InsensitiveStr::Ascii("ainerising"),
        dictgen::InsensitiveStr::Ascii("ainerization"),
        dictgen::InsensitiveStr::Ascii("ainerizations"),
        dictgen::InsensitiveStr::Ascii("ainerize"),
        dictgen::InsensitiveStr::Ascii("ainerized"),
        dictgen::InsensitiveStr::Ascii("ainerizes"),
        dictgen::InsensitiveStr::Ascii("ainerizing"),
        dictgen::InsensitiveStr::Ascii("emporisation"),
        dictgen::InsensitiveStr::Ascii("emporise"),
        dictgen::InsensitiveStr::Ascii("emporised"),
        dictgen::InsensitiveStr::Ascii("emporises"),
        dictgen::InsensitiveStr::Ascii("emporising"),
        dictgen::InsensitiveStr::Ascii("emporization"),
        dictgen::InsensitiveStr::Ascii("emporize"),
        dictgen::InsensitiveStr::Ascii("emporized"),
        dictgen::InsensitiveStr::Ascii("emporizes"),
        dictgen::InsensitiveStr::Ascii("emporizing"),
        dictgen::InsensitiveStr::Ascii("extualisation"),
        dictgen::InsensitiveStr::Ascii("extualisations"),
        dictgen::InsensitiveStr::Ascii("extualise"),
        dictgen::InsensitiveStr::Ascii("extualised"),
        dictgen::InsensitiveStr::Ascii("extualises"),
        dictgen::InsensitiveStr::Ascii("extualising"),
        dictgen::InsensitiveStr::Ascii("extualization"),
        dictgen::InsensitiveStr::Ascii("extualizations"),
        dictgen::InsensitiveStr::Ascii("extualize"),
        dictgen::InsensitiveStr::Ascii("extualized"),
        dictgen::InsensitiveStr::Ascii("extualizes"),
        dictgen::InsensitiveStr::Ascii("extualizing"),
        dictgen::InsensitiveStr::Ascii("inentalise"),
        dictgen::InsensitiveStr::Ascii("inentalises"),
        dictgen::InsensitiveStr::Ascii("inentalize"),
        dictgen::InsensitiveStr::Ascii("inentalizes"),
        dictgen::InsensitiveStr::Ascii("roversialise"),
        dictgen::InsensitiveStr::Ascii("roversialises"),
        dictgen::InsensitiveStr::Ascii("roversialize"),
        dictgen::InsensitiveStr::Ascii("roversializes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONTAINERIZATION_5740732325462062174)],
        &[(0b10010, &ENTRY_CONTAINERIZATIONS_4036516080513202324)],
        &[(0b10010, &ENTRY_CONTAINERIZE_17609445608339490283)],
        &[(0b10010, &ENTRY_CONTAINERIZED_11029791807154416517)],
        &[(0b10010, &ENTRY_CONTAINERIZES_5244588712773306715)],
        &[(0b10010, &ENTRY_CONTAINERIZING_9054115922997640811)],
        &[(0b01001, &ENTRY_CONTAINERIZATION_5740732325462062174)],
        &[(0b01001, &ENTRY_CONTAINERIZATIONS_4036516080513202324)],
        &[(0b01001, &ENTRY_CONTAINERIZE_17609445608339490283)],
        &[(0b01001, &ENTRY_CONTAINERIZED_11029791807154416517)],
        &[(0b01001, &ENTRY_CONTAINERIZES_5244588712773306715)],
        &[(0b01001, &ENTRY_CONTAINERIZING_9054115922997640811)],
        &[(0b10010, &ENTRY_CONTEMPORIZATION_16780108593197095593)],
        &[(0b10010, &ENTRY_CONTEMPORIZE_5008428677635696983)],
        &[(0b10010, &ENTRY_CONTEMPORIZED_3426415243352581168)],
        &[(0b10010, &ENTRY_CONTEMPORIZES_2967807069359802216)],
        &[(0b10010, &ENTRY_CONTEMPORIZING_6045892075236219913)],
        &[(0b01001, &ENTRY_CONTEMPORIZATION_16780108593197095593)],
        &[(0b01001, &ENTRY_CONTEMPORIZE_5008428677635696983)],
        &[(0b01001, &ENTRY_CONTEMPORIZED_3426415243352581168)],
        &[(0b01001, &ENTRY_CONTEMPORIZES_2967807069359802216)],
        &[(0b01001, &ENTRY_CONTEMPORIZING_6045892075236219913)],
        &[(0b10010, &ENTRY_CONTEXTUALIZATION_6940693679263259371)],
        &[(0b10010, &ENTRY_CONTEXTUALIZATIONS_18105932896496599445)],
        &[(0b10010, &ENTRY_CONTEXTUALIZE_4584369818380473712)],
        &[(0b10010, &ENTRY_CONTEXTUALIZED_6300908248792062084)],
        &[(0b10010, &ENTRY_CONTEXTUALIZES_12529336508087690726)],
        &[(0b10010, &ENTRY_CONTEXTUALIZING_7461111452640045211)],
        &[(0b01001, &ENTRY_CONTEXTUALIZATION_6940693679263259371)],
        &[(0b01001, &ENTRY_CONTEXTUALIZATIONS_18105932896496599445)],
        &[(0b01001, &ENTRY_CONTEXTUALIZE_4584369818380473712)],
        &[(0b01001, &ENTRY_CONTEXTUALIZED_6300908248792062084)],
        &[(0b01001, &ENTRY_CONTEXTUALIZES_12529336508087690726)],
        &[(0b01001, &ENTRY_CONTEXTUALIZING_7461111452640045211)],
        &[(0b10010, &ENTRY_CONTINENTALIZE_15476635658600406518)],
        &[(0b10010, &ENTRY_CONTINENTALIZES_6196002065058300897)],
        &[(0b01001, &ENTRY_CONTINENTALIZE_15476635658600406518)],
        &[(0b01001, &ENTRY_CONTINENTALIZES_6196002065058300897)],
        &[(0b10010, &ENTRY_CONTROVERSIALIZE_3063821365593875585)],
        &[(0b10010, &ENTRY_CONTROVERSIALIZES_7981611622332565361)],
        &[(0b01001, &ENTRY_CONTROVERSIALIZE_3063821365593875585)],
        &[(0b01001, &ENTRY_CONTROVERSIALIZES_7981611622332565361)],
    ],
    range: 8..=14,
};

static VARS_CONS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONS_CHILDREN),
    value: None,
};

pub static VARS_CONS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ervatise"),
        dictgen::InsensitiveStr::Ascii("ervatised"),
        dictgen::InsensitiveStr::Ascii("ervatises"),
        dictgen::InsensitiveStr::Ascii("ervatising"),
        dictgen::InsensitiveStr::Ascii("ervatize"),
        dictgen::InsensitiveStr::Ascii("ervatized"),
        dictgen::InsensitiveStr::Ascii("ervatizes"),
        dictgen::InsensitiveStr::Ascii("ervatizing"),
        dictgen::InsensitiveStr::Ascii("onantise"),
        dictgen::InsensitiveStr::Ascii("onantised"),
        dictgen::InsensitiveStr::Ascii("onantises"),
        dictgen::InsensitiveStr::Ascii("onantising"),
        dictgen::InsensitiveStr::Ascii("onantize"),
        dictgen::InsensitiveStr::Ascii("onantized"),
        dictgen::InsensitiveStr::Ascii("onantizes"),
        dictgen::InsensitiveStr::Ascii("onantizing"),
        dictgen::InsensitiveStr::Ascii("titutionalisation"),
        dictgen::InsensitiveStr::Ascii("titutionalisations"),
        dictgen::InsensitiveStr::Ascii("titutionalise"),
        dictgen::InsensitiveStr::Ascii("titutionalised"),
        dictgen::InsensitiveStr::Ascii("titutionalises"),
        dictgen::InsensitiveStr::Ascii("titutionalising"),
        dictgen::InsensitiveStr::Ascii("titutionalization"),
        dictgen::InsensitiveStr::Ascii("titutionalizations"),
        dictgen::InsensitiveStr::Ascii("titutionalize"),
        dictgen::InsensitiveStr::Ascii("titutionalized"),
        dictgen::InsensitiveStr::Ascii("titutionalizes"),
        dictgen::InsensitiveStr::Ascii("titutionalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONSERVATIZE_2070475109159374656)],
        &[(0b10010, &ENTRY_CONSERVATIZED_8955764860788295695)],
        &[(0b10010, &ENTRY_CONSERVATIZES_6230909821260907845)],
        &[(0b10010, &ENTRY_CONSERVATIZING_3183413058245669100)],
        &[(0b01001, &ENTRY_CONSERVATIZE_2070475109159374656)],
        &[(0b01001, &ENTRY_CONSERVATIZED_8955764860788295695)],
        &[(0b01001, &ENTRY_CONSERVATIZES_6230909821260907845)],
        &[(0b01001, &ENTRY_CONSERVATIZING_3183413058245669100)],
        &[(0b10010, &ENTRY_CONSONANTIZE_7643805442006694940)],
        &[(0b10010, &ENTRY_CONSONANTIZED_17873071838789420092)],
        &[(0b10010, &ENTRY_CONSONANTIZES_1574898332026499098)],
        &[(0b10010, &ENTRY_CONSONANTIZING_13097410576135380735)],
        &[(0b01001, &ENTRY_CONSONANTIZE_7643805442006694940)],
        &[(0b01001, &ENTRY_CONSONANTIZED_17873071838789420092)],
        &[(0b01001, &ENTRY_CONSONANTIZES_1574898332026499098)],
        &[(0b01001, &ENTRY_CONSONANTIZING_13097410576135380735)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZATION_15784223903500663882)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZATIONS_3173298060249661811)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZE_4750305806592443640)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZED_9394750460084858253)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZES_6011502541057503677)],
        &[(0b10010, &ENTRY_CONSTITUTIONALIZING_15920645894132149057)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZATION_15784223903500663882)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZATIONS_3173298060249661811)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZE_4750305806592443640)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZED_9394750460084858253)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZES_6011502541057503677)],
        &[(0b01001, &ENTRY_CONSTITUTIONALIZING_15920645894132149057)],
    ],
    range: 8..=18,
};

static VARS_CONN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONN_CHILDREN),
    value: None,
};

pub static VARS_CONN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecter"),
        dictgen::InsensitiveStr::Ascii("ecters"),
        dictgen::InsensitiveStr::Ascii("ectible"),
        dictgen::InsensitiveStr::Ascii("exion"),
        dictgen::InsensitiveStr::Ascii("exions"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CONNECTOR_16799434896865993625)],
        &[(0b00001, &ENTRY_CONNECTORS_2322332520801589759)],
        &[(0b00001, &ENTRY_CONNECTABLE_4141190038522560448)],
        &[(0b10010, &ENTRY_CONNECTION_3596008768342696520)],
        &[(0b10010, &ENTRY_CONNECTIONS_4180526765108060503)],
    ],
    range: 5..=7,
};

static VARS_CONG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONG_CHILDREN),
    value: None,
};

pub static VARS_CONG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enialise"),
        dictgen::InsensitiveStr::Ascii("enialises"),
        dictgen::InsensitiveStr::Ascii("enialize"),
        dictgen::InsensitiveStr::Ascii("enializes"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("oes"),
        dictgen::InsensitiveStr::Ascii("regationalise"),
        dictgen::InsensitiveStr::Ascii("regationalises"),
        dictgen::InsensitiveStr::Ascii("regationalize"),
        dictgen::InsensitiveStr::Ascii("regationalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONGENIALIZE_1800526471228574085)],
        &[(0b10010, &ENTRY_CONGENIALIZES_1415068390337769577)],
        &[(0b01001, &ENTRY_CONGENIALIZE_1800526471228574085)],
        &[(0b01001, &ENTRY_CONGENIALIZES_1415068390337769577)],
        &[(0b00001, &ENTRY_CONGES_13755371658333708467)],
        &[(0b11010, &ENTRY_CONGES_13755371658333708467)],
        &[(0b10010, &ENTRY_CONGREGATIONALIZE_9819463413052527180)],
        &[(0b10010, &ENTRY_CONGREGATIONALIZES_3694181040722978196)],
        &[(0b01001, &ENTRY_CONGREGATIONALIZE_9819463413052527180)],
        &[(0b01001, &ENTRY_CONGREGATIONALIZES_3694181040722978196)],
    ],
    range: 2..=14,
};

static VARS_CONF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONF_CHILDREN),
    value: None,
};

pub static VARS_CONF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ederatise"),
        dictgen::InsensitiveStr::Ascii("ederatises"),
        dictgen::InsensitiveStr::Ascii("ederatize"),
        dictgen::InsensitiveStr::Ascii("ederatizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONFEDERATIZE_6554466446788291559)],
        &[(0b10010, &ENTRY_CONFEDERATIZES_13632434106090755943)],
        &[(0b01001, &ENTRY_CONFEDERATIZE_6554466446788291559)],
        &[(0b01001, &ENTRY_CONFEDERATIZES_13632434106090755943)],
    ],
    range: 9..=10,
};

static VARS_COND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COND_CHILDREN),
    value: None,
};

pub static VARS_COND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itionalise"),
        dictgen::InsensitiveStr::Ascii("itionalises"),
        dictgen::InsensitiveStr::Ascii("itionalize"),
        dictgen::InsensitiveStr::Ascii("itionalizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CONDITIONALIZE_17072508968306397240)],
        &[(0b10010, &ENTRY_CONDITIONALIZES_15570057258703829423)],
        &[(0b01001, &ENTRY_CONDITIONALIZE_17072508968306397240)],
        &[(0b01001, &ENTRY_CONDITIONALIZES_15570057258703829423)],
    ],
    range: 10..=11,
};

static VARS_CONC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CONC_CHILDREN),
    value: None,
};

pub static VARS_CONC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("entered"),
        dictgen::InsensitiveStr::Ascii("entering"),
        dictgen::InsensitiveStr::Ascii("enters"),
        dictgen::InsensitiveStr::Ascii("entre"),
        dictgen::InsensitiveStr::Ascii("entred"),
        dictgen::InsensitiveStr::Ascii("entres"),
        dictgen::InsensitiveStr::Ascii("entring"),
        dictgen::InsensitiveStr::Ascii("eptualisation"),
        dictgen::InsensitiveStr::Ascii("eptualisations"),
        dictgen::InsensitiveStr::Ascii("eptualise"),
        dictgen::InsensitiveStr::Ascii("eptualised"),
        dictgen::InsensitiveStr::Ascii("eptualiser"),
        dictgen::InsensitiveStr::Ascii("eptualises"),
        dictgen::InsensitiveStr::Ascii("eptualising"),
        dictgen::InsensitiveStr::Ascii("eptualization"),
        dictgen::InsensitiveStr::Ascii("eptualizations"),
        dictgen::InsensitiveStr::Ascii("eptualize"),
        dictgen::InsensitiveStr::Ascii("eptualized"),
        dictgen::InsensitiveStr::Ascii("eptualizer"),
        dictgen::InsensitiveStr::Ascii("eptualizes"),
        dictgen::InsensitiveStr::Ascii("eptualizing"),
        dictgen::InsensitiveStr::Ascii("ertise"),
        dictgen::InsensitiveStr::Ascii("ertised"),
        dictgen::InsensitiveStr::Ascii("ertiser"),
        dictgen::InsensitiveStr::Ascii("ertisers"),
        dictgen::InsensitiveStr::Ascii("ertises"),
        dictgen::InsensitiveStr::Ascii("ertising"),
        dictgen::InsensitiveStr::Ascii("ertist"),
        dictgen::InsensitiveStr::Ascii("ertize"),
        dictgen::InsensitiveStr::Ascii("ertized"),
        dictgen::InsensitiveStr::Ascii("ertizer"),
        dictgen::InsensitiveStr::Ascii("ertizers"),
        dictgen::InsensitiveStr::Ascii("ertizes"),
        dictgen::InsensitiveStr::Ascii("ertizing"),
        dictgen::InsensitiveStr::Ascii("hae"),
        dictgen::InsensitiveStr::Ascii("he"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olorous"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("olourous"),
        dictgen::InsensitiveStr::Ascii("retisation"),
        dictgen::InsensitiveStr::Ascii("retisations"),
        dictgen::InsensitiveStr::Ascii("retise"),
        dictgen::InsensitiveStr::Ascii("retised"),
        dictgen::InsensitiveStr::Ascii("retises"),
        dictgen::InsensitiveStr::Ascii("retising"),
        dictgen::InsensitiveStr::Ascii("retist"),
        dictgen::InsensitiveStr::Ascii("retization"),
        dictgen::InsensitiveStr::Ascii("retizations"),
        dictgen::InsensitiveStr::Ascii("retize"),
        dictgen::InsensitiveStr::Ascii("retized"),
        dictgen::InsensitiveStr::Ascii("retizes"),
        dictgen::InsensitiveStr::Ascii("retizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CONCENTER_12599613659019972198)],
        &[(0b00001, &ENTRY_CONCENTERED_5661172717823289893)],
        &[(0b00001, &ENTRY_CONCENTERING_8029206760572244740)],
        &[(0b00001, &ENTRY_CONCENTERS_15190503554801426852)],
        &[(0b11010, &ENTRY_CONCENTER_12599613659019972198)],
        &[(0b11010, &ENTRY_CONCENTERED_5661172717823289893)],
        &[(0b11010, &ENTRY_CONCENTERS_15190503554801426852)],
        &[(0b11010, &ENTRY_CONCENTERING_8029206760572244740)],
        &[(0b10010, &ENTRY_CONCEPTUALIZATION_5738356471049765058)],
        &[(0b10010, &ENTRY_CONCEPTUALIZATIONS_11238993640785943456)],
        &[(0b10010, &ENTRY_CONCEPTUALIZE_13986310691359872680)],
        &[(0b10010, &ENTRY_CONCEPTUALIZED_6046228406726865910)],
        &[(0b10010, &ENTRY_CONCEPTUALIZER_9902569432824476207)],
        &[(0b10010, &ENTRY_CONCEPTUALIZES_17221094629974506736)],
        &[(0b10010, &ENTRY_CONCEPTUALIZING_540854313698733535)],
        &[(0b01001, &ENTRY_CONCEPTUALIZATION_5738356471049765058)],
        &[(0b01001, &ENTRY_CONCEPTUALIZATIONS_11238993640785943456)],
        &[(0b01001, &ENTRY_CONCEPTUALIZE_13986310691359872680)],
        &[(0b01001, &ENTRY_CONCEPTUALIZED_6046228406726865910)],
        &[(0b01001, &ENTRY_CONCEPTUALIZER_9902569432824476207)],
        &[(0b01001, &ENTRY_CONCEPTUALIZES_17221094629974506736)],
        &[(0b01001, &ENTRY_CONCEPTUALIZING_540854313698733535)],
        &[(0b10010, &ENTRY_CONCERTIZE_12949550082462386391)],
        &[(0b10010, &ENTRY_CONCERTIZED_13322827190564875313)],
        &[(0b10010, &ENTRY_CONCERTIZER_1607241334899378280)],
        &[(0b10010, &ENTRY_CONCERTIZERS_18408860231574633709)],
        &[(0b10010, &ENTRY_CONCERTIZES_11707521685205330713)],
        &[(0b10010, &ENTRY_CONCERTIZING_823694797397139539)],
        &[(0b00001, &ENTRY_CONCERTIST_12966623456893238257)],
        &[(0b01001, &ENTRY_CONCERTIZE_12949550082462386391)],
        &[(0b01001, &ENTRY_CONCERTIZED_13322827190564875313)],
        &[(0b01001, &ENTRY_CONCERTIZER_1607241334899378280)],
        &[(0b01001, &ENTRY_CONCERTIZERS_18408860231574633709)],
        &[(0b01001, &ENTRY_CONCERTIZES_11707521685205330713)],
        &[(0b01001, &ENTRY_CONCERTIZING_823694797397139539)],
        &[(0b11010, &ENTRY_CONCHE_198313554269271817)],
        &[(0b00001, &ENTRY_CONCHE_198313554269271817)],
        &[(0b00001, &ENTRY_CONCOLOR_17454478296536964945)],
        &[(0b00001, &ENTRY_CONCOLOROUS_3163909145039836280)],
        &[(0b11010, &ENTRY_CONCOLOR_17454478296536964945)],
        &[(0b11010, &ENTRY_CONCOLOROUS_3163909145039836280)],
        &[(0b10010, &ENTRY_CONCRETIZATION_9902216531217228458)],
        &[(0b10010, &ENTRY_CONCRETIZATIONS_14806205502602655468)],
        &[(0b10010, &ENTRY_CONCRETIZE_5573134973876025446)],
        &[(0b10010, &ENTRY_CONCRETIZED_4880170111921035163)],
        &[(0b10010, &ENTRY_CONCRETIZES_14141471054162706394)],
        &[(0b10010, &ENTRY_CONCRETIZING_3165984632825616589)],
        &[(0b11010, &ENTRY_CONCERTIST_12966623456893238257)],
        &[(0b01001, &ENTRY_CONCRETIZATION_9902216531217228458)],
        &[(0b01001, &ENTRY_CONCRETIZATIONS_14806205502602655468)],
        &[(0b01001, &ENTRY_CONCRETIZE_5573134973876025446)],
        &[(0b01001, &ENTRY_CONCRETIZED_4880170111921035163)],
        &[(0b01001, &ENTRY_CONCRETIZES_14141471054162706394)],
        &[(0b01001, &ENTRY_CONCRETIZING_3165984632825616589)],
    ],
    range: 2..=14,
};

static VARS_COM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COM_CHILDREN),
    value: None,
};

static VARS_COM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_COME_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COMM_NODE),
    None,
    Some(&VARS_COMO_NODE),
    Some(&VARS_COMP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_COMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COMP_CHILDREN),
    value: None,
};

pub static VARS_COMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anionise"),
        dictgen::InsensitiveStr::Ascii("anionises"),
        dictgen::InsensitiveStr::Ascii("anionize"),
        dictgen::InsensitiveStr::Ascii("anionizes"),
        dictgen::InsensitiveStr::Ascii("artmentalisation"),
        dictgen::InsensitiveStr::Ascii("artmentalisations"),
        dictgen::InsensitiveStr::Ascii("artmentalise"),
        dictgen::InsensitiveStr::Ascii("artmentalised"),
        dictgen::InsensitiveStr::Ascii("artmentalises"),
        dictgen::InsensitiveStr::Ascii("artmentalising"),
        dictgen::InsensitiveStr::Ascii("artmentalization"),
        dictgen::InsensitiveStr::Ascii("artmentalizations"),
        dictgen::InsensitiveStr::Ascii("artmentalize"),
        dictgen::InsensitiveStr::Ascii("artmentalized"),
        dictgen::InsensitiveStr::Ascii("artmentalizes"),
        dictgen::InsensitiveStr::Ascii("artmentalizing"),
        dictgen::InsensitiveStr::Ascii("artmentise"),
        dictgen::InsensitiveStr::Ascii("artmentises"),
        dictgen::InsensitiveStr::Ascii("artmentize"),
        dictgen::InsensitiveStr::Ascii("artmentizes"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("lementiser"),
        dictgen::InsensitiveStr::Ascii("lementizer"),
        dictgen::InsensitiveStr::Ascii("oer"),
        dictgen::InsensitiveStr::Ascii("ositae"),
        dictgen::InsensitiveStr::Ascii("osite"),
        dictgen::InsensitiveStr::Ascii("rehensivisation"),
        dictgen::InsensitiveStr::Ascii("rehensivisations"),
        dictgen::InsensitiveStr::Ascii("rehensivise"),
        dictgen::InsensitiveStr::Ascii("rehensivised"),
        dictgen::InsensitiveStr::Ascii("rehensivises"),
        dictgen::InsensitiveStr::Ascii("rehensivising"),
        dictgen::InsensitiveStr::Ascii("rehensivization"),
        dictgen::InsensitiveStr::Ascii("rehensivizations"),
        dictgen::InsensitiveStr::Ascii("rehensivize"),
        dictgen::InsensitiveStr::Ascii("rehensivized"),
        dictgen::InsensitiveStr::Ascii("rehensivizes"),
        dictgen::InsensitiveStr::Ascii("rehensivizing"),
        dictgen::InsensitiveStr::Ascii("risable"),
        dictgen::InsensitiveStr::Ascii("risal"),
        dictgen::InsensitiveStr::Ascii("rizable"),
        dictgen::InsensitiveStr::Ascii("rizal"),
        dictgen::InsensitiveStr::Ascii("uterisable"),
        dictgen::InsensitiveStr::Ascii("uterisation"),
        dictgen::InsensitiveStr::Ascii("uterisations"),
        dictgen::InsensitiveStr::Ascii("uterise"),
        dictgen::InsensitiveStr::Ascii("uterised"),
        dictgen::InsensitiveStr::Ascii("uterises"),
        dictgen::InsensitiveStr::Ascii("uterising"),
        dictgen::InsensitiveStr::Ascii("uterizable"),
        dictgen::InsensitiveStr::Ascii("uterization"),
        dictgen::InsensitiveStr::Ascii("uterizations"),
        dictgen::InsensitiveStr::Ascii("uterize"),
        dictgen::InsensitiveStr::Ascii("uterized"),
        dictgen::InsensitiveStr::Ascii("uterizes"),
        dictgen::InsensitiveStr::Ascii("uterizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COMPANIONIZE_17295459993069832105)],
        &[(0b10010, &ENTRY_COMPANIONIZES_159175304294701734)],
        &[(0b01001, &ENTRY_COMPANIONIZE_17295459993069832105)],
        &[(0b01001, &ENTRY_COMPANIONIZES_159175304294701734)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZATION_18240462251141060220)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZATIONS_2073690646158683595)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZE_6316599424281105903)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZED_2091042337396016604)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZES_1429778905943784124)],
        &[(0b10010, &ENTRY_COMPARTMENTALIZING_14853138630531540565)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZATION_18240462251141060220)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZATIONS_2073690646158683595)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZE_6316599424281105903)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZED_2091042337396016604)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZES_1429778905943784124)],
        &[(0b01001, &ENTRY_COMPARTMENTALIZING_14853138630531540565)],
        &[(0b10010, &ENTRY_COMPARTMENTIZE_4090554704802645617)],
        &[(0b10010, &ENTRY_COMPARTMENTIZES_12901335302225578235)],
        &[(0b01001, &ENTRY_COMPARTMENTIZE_4090554704802645617)],
        &[(0b01001, &ENTRY_COMPARTMENTIZES_12901335302225578235)],
        &[(0b00001, &ENTRY_COMPER_13800353684688405016)],
        &[(0b10010, &ENTRY_COMPLEMENTIZER_6562757288101998612)],
        &[(0b01001, &ENTRY_COMPLEMENTIZER_6562757288101998612)],
        &[(0b11010, &ENTRY_COMPER_13800353684688405016)],
        &[(0b11010, &ENTRY_COMPOSITE_2834997305530089174)],
        &[(0b00001, &ENTRY_COMPOSITE_2834997305530089174)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZATION_15958998661265330414)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZATIONS_1893003905937999548)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZE_12410257886709581767)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZED_2933839517192572218)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZES_7584059223344239212)],
        &[(0b10010, &ENTRY_COMPREHENSIVIZING_2953121830198164292)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZATION_15958998661265330414)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZATIONS_1893003905937999548)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZE_12410257886709581767)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZED_2933839517192572218)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZES_7584059223344239212)],
        &[(0b01001, &ENTRY_COMPREHENSIVIZING_2953121830198164292)],
        &[(0b10010, &ENTRY_COMPRIZABLE_4826744105914478701)],
        &[(0b10010, &ENTRY_COMPRIZAL_9931805136956588535)],
        &[(0b01001, &ENTRY_COMPRIZABLE_4826744105914478701)],
        &[(0b01001, &ENTRY_COMPRIZAL_9931805136956588535)],
        &[(0b10010, &ENTRY_COMPUTERIZABLE_11675963878159642483)],
        &[(0b10010, &ENTRY_COMPUTERIZATION_14289958571575590804)],
        &[(0b10010, &ENTRY_COMPUTERIZATIONS_5765686861831125257)],
        &[(0b10010, &ENTRY_COMPUTERIZE_15545915378374926111)],
        &[(0b10010, &ENTRY_COMPUTERIZED_15101489353463973212)],
        &[(0b10010, &ENTRY_COMPUTERIZES_14986241207867566402)],
        &[(0b10010, &ENTRY_COMPUTERIZING_12865766678094814563)],
        &[(0b01001, &ENTRY_COMPUTERIZABLE_11675963878159642483)],
        &[(0b01001, &ENTRY_COMPUTERIZATION_14289958571575590804)],
        &[(0b01001, &ENTRY_COMPUTERIZATIONS_5765686861831125257)],
        &[(0b01001, &ENTRY_COMPUTERIZE_15545915378374926111)],
        &[(0b01001, &ENTRY_COMPUTERIZED_15101489353463973212)],
        &[(0b01001, &ENTRY_COMPUTERIZES_14986241207867566402)],
        &[(0b01001, &ENTRY_COMPUTERIZING_12865766678094814563)],
    ],
    range: 2..=17,
};

static VARS_COMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COMO_CHILDREN),
    value: None,
};

pub static VARS_COMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("edia")],
    values: &[&[(0b11010, &ENTRY_COMEDIA_5856845506973447538)]],
    range: 4..=4,
};

static VARS_COMM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COMM_CHILDREN),
    value: None,
};

pub static VARS_COMM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ercialisation"),
        dictgen::InsensitiveStr::Ascii("ercialisations"),
        dictgen::InsensitiveStr::Ascii("ercialise"),
        dictgen::InsensitiveStr::Ascii("ercialised"),
        dictgen::InsensitiveStr::Ascii("ercialises"),
        dictgen::InsensitiveStr::Ascii("ercialising"),
        dictgen::InsensitiveStr::Ascii("ercialization"),
        dictgen::InsensitiveStr::Ascii("ercializations"),
        dictgen::InsensitiveStr::Ascii("ercialize"),
        dictgen::InsensitiveStr::Ascii("ercialized"),
        dictgen::InsensitiveStr::Ascii("ercializes"),
        dictgen::InsensitiveStr::Ascii("ercializing"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("unalisation"),
        dictgen::InsensitiveStr::Ascii("unalisations"),
        dictgen::InsensitiveStr::Ascii("unalise"),
        dictgen::InsensitiveStr::Ascii("unalised"),
        dictgen::InsensitiveStr::Ascii("unaliser"),
        dictgen::InsensitiveStr::Ascii("unalisers"),
        dictgen::InsensitiveStr::Ascii("unalises"),
        dictgen::InsensitiveStr::Ascii("unalising"),
        dictgen::InsensitiveStr::Ascii("unalization"),
        dictgen::InsensitiveStr::Ascii("unalizations"),
        dictgen::InsensitiveStr::Ascii("unalize"),
        dictgen::InsensitiveStr::Ascii("unalized"),
        dictgen::InsensitiveStr::Ascii("unalizer"),
        dictgen::InsensitiveStr::Ascii("unalizers"),
        dictgen::InsensitiveStr::Ascii("unalizes"),
        dictgen::InsensitiveStr::Ascii("unalizing"),
        dictgen::InsensitiveStr::Ascii("unisation"),
        dictgen::InsensitiveStr::Ascii("unisations"),
        dictgen::InsensitiveStr::Ascii("unise"),
        dictgen::InsensitiveStr::Ascii("unised"),
        dictgen::InsensitiveStr::Ascii("unises"),
        dictgen::InsensitiveStr::Ascii("unising"),
        dictgen::InsensitiveStr::Ascii("unization"),
        dictgen::InsensitiveStr::Ascii("unizations"),
        dictgen::InsensitiveStr::Ascii("unize"),
        dictgen::InsensitiveStr::Ascii("unized"),
        dictgen::InsensitiveStr::Ascii("unizes"),
        dictgen::InsensitiveStr::Ascii("unizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COMMERCIALIZATION_1643106928830782978)],
        &[(0b10010, &ENTRY_COMMERCIALIZATIONS_17012404820436874389)],
        &[(0b10010, &ENTRY_COMMERCIALIZE_16888630425257885338)],
        &[(0b10010, &ENTRY_COMMERCIALIZED_13681505620366419859)],
        &[(0b10010, &ENTRY_COMMERCIALIZES_7923464025673338308)],
        &[(0b10010, &ENTRY_COMMERCIALIZING_10714170346661677285)],
        &[(0b01001, &ENTRY_COMMERCIALIZATION_1643106928830782978)],
        &[(0b01001, &ENTRY_COMMERCIALIZATIONS_17012404820436874389)],
        &[(0b01001, &ENTRY_COMMERCIALIZE_16888630425257885338)],
        &[(0b01001, &ENTRY_COMMERCIALIZED_13681505620366419859)],
        &[(0b01001, &ENTRY_COMMERCIALIZES_7923464025673338308)],
        &[(0b01001, &ENTRY_COMMERCIALIZING_10714170346661677285)],
        &[(0b10010, &ENTRY_COMMONIZE_3127845796652963145)],
        &[(0b10010, &ENTRY_COMMONIZES_1050237353426943643)],
        &[(0b01001, &ENTRY_COMMONIZE_3127845796652963145)],
        &[(0b01001, &ENTRY_COMMONIZES_1050237353426943643)],
        &[(0b10010, &ENTRY_COMMUNALIZATION_1354902119947113774)],
        &[(0b10010, &ENTRY_COMMUNALIZATIONS_10004190720704121461)],
        &[(0b10010, &ENTRY_COMMUNALIZE_16978210201059417779)],
        &[(0b10010, &ENTRY_COMMUNALIZED_8414107067770377657)],
        &[(0b10010, &ENTRY_COMMUNALIZER_9067480767105491194)],
        &[(0b10010, &ENTRY_COMMUNALIZERS_1419522334270734921)],
        &[(0b10010, &ENTRY_COMMUNALIZES_12395688431331928966)],
        &[(0b10010, &ENTRY_COMMUNALIZING_8021518098437504841)],
        &[(0b01001, &ENTRY_COMMUNALIZATION_1354902119947113774)],
        &[(0b01001, &ENTRY_COMMUNALIZATIONS_10004190720704121461)],
        &[(0b01001, &ENTRY_COMMUNALIZE_16978210201059417779)],
        &[(0b01001, &ENTRY_COMMUNALIZED_8414107067770377657)],
        &[(0b01001, &ENTRY_COMMUNALIZER_9067480767105491194)],
        &[(0b01001, &ENTRY_COMMUNALIZERS_1419522334270734921)],
        &[(0b01001, &ENTRY_COMMUNALIZES_12395688431331928966)],
        &[(0b01001, &ENTRY_COMMUNALIZING_8021518098437504841)],
        &[(0b10010, &ENTRY_COMMUNIZATION_847361005287031401)],
        &[(0b10010, &ENTRY_COMMUNIZATIONS_9900325170167101461)],
        &[(0b10010, &ENTRY_COMMUNIZE_13614074380950312902)],
        &[(0b10010, &ENTRY_COMMUNIZED_15644498154290457954)],
        &[(0b10010, &ENTRY_COMMUNIZES_16239995256080535914)],
        &[(0b10010, &ENTRY_COMMUNIZING_4187287385336521999)],
        &[(0b01001, &ENTRY_COMMUNIZATION_847361005287031401)],
        &[(0b01001, &ENTRY_COMMUNIZATIONS_9900325170167101461)],
        &[(0b01001, &ENTRY_COMMUNIZE_13614074380950312902)],
        &[(0b01001, &ENTRY_COMMUNIZED_15644498154290457954)],
        &[(0b01001, &ENTRY_COMMUNIZES_16239995256080535914)],
        &[(0b01001, &ENTRY_COMMUNIZING_4187287385336521999)],
    ],
    range: 5..=14,
};

static VARS_COME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COME_CHILDREN),
    value: None,
};

pub static VARS_COME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("dia")],
    values: &[&[(0b00001, &ENTRY_COMEDIA_5856845506973447538)]],
    range: 3..=3,
};

static VARS_COL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COL_CHILDREN),
    value: None,
};

static VARS_COL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COLL_NODE),
    None,
    None,
    Some(&VARS_COLO_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COLU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_COLU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLU_CHILDREN),
    value: None,
};

pub static VARS_COLU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mnisation"),
        dictgen::InsensitiveStr::Ascii("mnisations"),
        dictgen::InsensitiveStr::Ascii("mnise"),
        dictgen::InsensitiveStr::Ascii("mnised"),
        dictgen::InsensitiveStr::Ascii("mnises"),
        dictgen::InsensitiveStr::Ascii("mnising"),
        dictgen::InsensitiveStr::Ascii("mnization"),
        dictgen::InsensitiveStr::Ascii("mnizations"),
        dictgen::InsensitiveStr::Ascii("mnize"),
        dictgen::InsensitiveStr::Ascii("mnized"),
        dictgen::InsensitiveStr::Ascii("mnizes"),
        dictgen::InsensitiveStr::Ascii("mnizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COLUMNIZATION_11878276873729118026)],
        &[(0b10010, &ENTRY_COLUMNIZATIONS_12733006362612848403)],
        &[(0b10010, &ENTRY_COLUMNIZE_7550365049509673455)],
        &[(0b10010, &ENTRY_COLUMNIZED_12525419582000651703)],
        &[(0b10010, &ENTRY_COLUMNIZES_920618881458905076)],
        &[(0b10010, &ENTRY_COLUMNIZING_11760357087944386265)],
        &[(0b01001, &ENTRY_COLUMNIZATION_11878276873729118026)],
        &[(0b01001, &ENTRY_COLUMNIZATIONS_12733006362612848403)],
        &[(0b01001, &ENTRY_COLUMNIZE_7550365049509673455)],
        &[(0b01001, &ENTRY_COLUMNIZED_12525419582000651703)],
        &[(0b01001, &ENTRY_COLUMNIZES_920618881458905076)],
        &[(0b01001, &ENTRY_COLUMNIZING_11760357087944386265)],
    ],
    range: 5..=10,
};

static VARS_COLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COLO_CHILDREN),
    value: None,
};

static VARS_COLO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COLON_NODE),
    None,
    None,
    None,
    Some(&VARS_COLOR_NODE),
    None,
    None,
    Some(&VARS_COLOU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_COLOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COLOU_CHILDREN),
    value: None,
};

static VARS_COLOU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_COLOUR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_COLOUR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COLOUR_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_COLOR_17720358635329736641)]),
};

static VARS_COLOUR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_COLOURA_NODE),
    Some(&VARS_COLOURB_NODE),
    Some(&VARS_COLOURC_NODE),
    None,
    Some(&VARS_COLOURE_NODE),
    Some(&VARS_COLOURF_NODE),
    None,
    None,
    Some(&VARS_COLOURI_NODE),
    None,
    None,
    Some(&VARS_COLOURL_NODE),
    Some(&VARS_COLOURM_NODE),
    None,
    Some(&VARS_COLOURO_NODE),
    Some(&VARS_COLOURP_NODE),
    None,
    Some(&VARS_COLOURR_NODE),
    Some(&VARS_COLOURS_NODE),
    Some(&VARS_COLOURT_NODE),
    None,
    None,
    Some(&VARS_COLOURW_NODE),
    None,
    Some(&VARS_COLOURY_NODE),
    None,
];

static VARS_COLOURY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURY_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_COLORY_3235234236420467456)]),
};

pub static VARS_COLOURY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_COLOURW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURW_CHILDREN),
    value: None,
};

pub static VARS_COLOURW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ay"),
        dictgen::InsensitiveStr::Ascii("ays"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORWAY_14654249147936693420)],
        &[(0b11010, &ENTRY_COLORWAYS_6062463807369877282)],
    ],
    range: 2..=3,
};

static VARS_COLOURT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURT_CHILDREN),
    value: None,
};

pub static VARS_COLOURT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ype")],
    values: &[&[(0b11010, &ENTRY_COLORTYPE_14680038702599961625)]],
    range: 3..=3,
};

static VARS_COLOURS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURS_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_COLORS_13018845474144214729)]),
};

pub static VARS_COLOURS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_COLOURR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURR_CHILDREN),
    value: None,
};

pub static VARS_COLOURR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("haphy")],
    values: &[&[(0b11010, &ENTRY_COLORRHAPHY_13136665400257945176)]],
    range: 5..=5,
};

static VARS_COLOURP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURP_CHILDREN),
    value: None,
};

pub static VARS_COLOURP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oint"),
        dictgen::InsensitiveStr::Ascii("oints"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORPOINT_12353596064079181917)],
        &[(0b11010, &ENTRY_COLORPOINTS_13015689836998141845)],
    ],
    range: 4..=5,
};

static VARS_COLOURO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURO_CHILDREN),
    value: None,
};

pub static VARS_COLOURO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("to")],
    values: &[&[(0b11010, &ENTRY_COLOROTO_5869254994177780978)]],
    range: 2..=2,
};

static VARS_COLOURM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURM_CHILDREN),
    value: None,
};

pub static VARS_COLOURM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aker"),
        dictgen::InsensitiveStr::Ascii("aking"),
        dictgen::InsensitiveStr::Ascii("an"),
        dictgen::InsensitiveStr::Ascii("ap"),
        dictgen::InsensitiveStr::Ascii("aps"),
        dictgen::InsensitiveStr::Ascii("en"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORMAKER_13048991323713933641)],
        &[(0b11010, &ENTRY_COLORMAKING_3298385465563328410)],
        &[(0b11010, &ENTRY_COLORMAN_9192316057645589430)],
        &[(0b11010, &ENTRY_COLORMAP_18024738796464819872)],
        &[(0b11010, &ENTRY_COLORMAPS_11406342514432472514)],
        &[(0b11010, &ENTRY_COLORMEN_1963797128559420405)],
    ],
    range: 2..=5,
};

static VARS_COLOURL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURL_CHILDREN),
    value: None,
};

pub static VARS_COLOURL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ess"),
        dictgen::InsensitiveStr::Ascii("esser"),
        dictgen::InsensitiveStr::Ascii("essest"),
        dictgen::InsensitiveStr::Ascii("esslier"),
        dictgen::InsensitiveStr::Ascii("essliest"),
        dictgen::InsensitiveStr::Ascii("essly"),
        dictgen::InsensitiveStr::Ascii("essness"),
        dictgen::InsensitiveStr::Ascii("essnesses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORLESS_15335426167000546767)],
        &[(0b11010, &ENTRY_COLORLESSER_9795559032347620897)],
        &[(0b11010, &ENTRY_COLORLESSEST_2853202552785506979)],
        &[(0b11010, &ENTRY_COLORLESSLIER_15143289294047728460)],
        &[(0b11010, &ENTRY_COLORLESSLIEST_12819557587409285660)],
        &[(0b11010, &ENTRY_COLORLESSLY_15719317170801627859)],
        &[(0b11010, &ENTRY_COLORLESSNESS_3911470984873699039)],
        &[(0b11010, &ENTRY_COLORLESSNESSES_17325232283084205852)],
    ],
    range: 3..=9,
};

static VARS_COLOURI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURI_CHILDREN),
    value: None,
};

pub static VARS_COLOURI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fic"),
        dictgen::InsensitiveStr::Ascii("fics"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("meters"),
        dictgen::InsensitiveStr::Ascii("metric"),
        dictgen::InsensitiveStr::Ascii("metrical"),
        dictgen::InsensitiveStr::Ascii("metrically"),
        dictgen::InsensitiveStr::Ascii("metrics"),
        dictgen::InsensitiveStr::Ascii("metries"),
        dictgen::InsensitiveStr::Ascii("metrist"),
        dictgen::InsensitiveStr::Ascii("metry"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("ng"),
        dictgen::InsensitiveStr::Ascii("ngs"),
        dictgen::InsensitiveStr::Ascii("sation"),
        dictgen::InsensitiveStr::Ascii("sations"),
        dictgen::InsensitiveStr::Ascii("se"),
        dictgen::InsensitiveStr::Ascii("sed"),
        dictgen::InsensitiveStr::Ascii("ses"),
        dictgen::InsensitiveStr::Ascii("sing"),
        dictgen::InsensitiveStr::Ascii("sm"),
        dictgen::InsensitiveStr::Ascii("sms"),
        dictgen::InsensitiveStr::Ascii("st"),
        dictgen::InsensitiveStr::Ascii("stic"),
        dictgen::InsensitiveStr::Ascii("stically"),
        dictgen::InsensitiveStr::Ascii("sticer"),
        dictgen::InsensitiveStr::Ascii("sticest"),
        dictgen::InsensitiveStr::Ascii("stics"),
        dictgen::InsensitiveStr::Ascii("sts"),
        dictgen::InsensitiveStr::Ascii("zation"),
        dictgen::InsensitiveStr::Ascii("zations"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zed"),
        dictgen::InsensitiveStr::Ascii("zes"),
        dictgen::InsensitiveStr::Ascii("zing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORIFIC_17453281363599547611)],
        &[(0b11010, &ENTRY_COLORIFICS_7493178994191350405)],
        &[(0b11010, &ENTRY_COLORIMETER_5995992236279956204)],
        &[(0b11010, &ENTRY_COLORIMETERS_16988328923257615588)],
        &[(0b11010, &ENTRY_COLORIMETRIC_2752387257901137840)],
        &[(0b11010, &ENTRY_COLORIMETRICAL_14932230836831976255)],
        &[(0b11010, &ENTRY_COLORIMETRICALLY_5243289402205557910)],
        &[(0b11010, &ENTRY_COLORIMETRICS_8847586357101611180)],
        &[(0b11010, &ENTRY_COLORIMETRIES_16352633730423789473)],
        &[(0b11010, &ENTRY_COLORIMETRIST_16103668754911113058)],
        &[(0b11010, &ENTRY_COLORIMETRY_1096025596659311412)],
        &[(0b11010, &ENTRY_COLORIN_7364447797547189461)],
        &[(0b11010, &ENTRY_COLORING_3210137591351035939)],
        &[(0b11010, &ENTRY_COLORINGS_3076825598771260084)],
        &[(0b10010, &ENTRY_COLORIZATION_8112190634064658436)],
        &[(0b10010, &ENTRY_COLORIZATIONS_4267572307963209982)],
        &[(0b10010, &ENTRY_COLORIZE_378813947509810224)],
        &[(0b10010, &ENTRY_COLORIZED_1927556635004418734)],
        &[(0b10010, &ENTRY_COLORIZES_12579061677034347790)],
        &[(0b10010, &ENTRY_COLORIZING_2623120429929129787)],
        &[(0b11010, &ENTRY_COLORISM_11451642000509277550)],
        &[(0b11010, &ENTRY_COLORISMS_9834615672957808489)],
        &[(0b11010, &ENTRY_COLORIST_3170137357114879751)],
        &[(0b11010, &ENTRY_COLORISTIC_4901807440455152786)],
        &[(0b11010, &ENTRY_COLORISTICALLY_4826074029409437505)],
        &[(0b11010, &ENTRY_COLORISTICER_8710817088617352267)],
        &[(0b11010, &ENTRY_COLORISTICEST_2991259503195608639)],
        &[(0b11010, &ENTRY_COLORISTICS_10161388239807067112)],
        &[(0b11010, &ENTRY_COLORISTS_205210891187993391)],
        &[(0b01000, &ENTRY_COLORIZATION_8112190634064658436)],
        &[(0b01000, &ENTRY_COLORIZATIONS_4267572307963209982)],
        &[(0b01000, &ENTRY_COLORIZE_378813947509810224)],
        &[(0b01000, &ENTRY_COLORIZED_1927556635004418734)],
        &[(0b01000, &ENTRY_COLORIZES_12579061677034347790)],
        &[(0b01000, &ENTRY_COLORIZING_2623120429929129787)],
    ],
    range: 1..=10,
};

static VARS_COLOURF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURF_CHILDREN),
    value: None,
};

pub static VARS_COLOURF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ast"),
        dictgen::InsensitiveStr::Ascii("astness"),
        dictgen::InsensitiveStr::Ascii("astnesses"),
        dictgen::InsensitiveStr::Ascii("ul"),
        dictgen::InsensitiveStr::Ascii("uler"),
        dictgen::InsensitiveStr::Ascii("ulest"),
        dictgen::InsensitiveStr::Ascii("ullier"),
        dictgen::InsensitiveStr::Ascii("ulliest"),
        dictgen::InsensitiveStr::Ascii("ully"),
        dictgen::InsensitiveStr::Ascii("ulness"),
        dictgen::InsensitiveStr::Ascii("ulnesses"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORFAST_16696822485914404702)],
        &[(0b11010, &ENTRY_COLORFASTNESS_3258841464722986607)],
        &[(0b11010, &ENTRY_COLORFASTNESSES_14995112700652023509)],
        &[(0b11010, &ENTRY_COLORFUL_16225861255487751804)],
        &[(0b11010, &ENTRY_COLORFULER_10294924989983822582)],
        &[(0b11010, &ENTRY_COLORFULEST_202572902882532719)],
        &[(0b11010, &ENTRY_COLORFULLIER_3454480613316383412)],
        &[(0b11010, &ENTRY_COLORFULLIEST_14019017521674302328)],
        &[(0b11010, &ENTRY_COLORFULLY_7749800674951458575)],
        &[(0b11010, &ENTRY_COLORFULNESS_8831709788792250227)],
        &[(0b11010, &ENTRY_COLORFULNESSES_11724036744178299544)],
    ],
    range: 2..=9,
};

static VARS_COLOURE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURE_CHILDREN),
    value: None,
};

pub static VARS_COLOURE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctal"),
        dictgen::InsensitiveStr::Ascii("ctitis"),
        dictgen::InsensitiveStr::Ascii("ctostomy"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ds"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("st"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORECTAL_9394771582914199855)],
        &[(0b11010, &ENTRY_COLORECTITIS_11920759655606208881)],
        &[(0b11010, &ENTRY_COLORECTOSTOMY_809184159134628418)],
        &[(0b11010, &ENTRY_COLORED_809367823820397764)],
        &[(0b11010, &ENTRY_COLOREDS_5638105898846322523)],
        &[(0b11010, &ENTRY_COLORER_6377883908421217617)],
        &[(0b11010, &ENTRY_COLORERS_5523036624009318320)],
        &[(0b11010, &ENTRY_COLORREST_6777192705388068909)],
    ],
    range: 1..=8,
};

static VARS_COLOURC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURC_CHILDREN),
    value: None,
};

pub static VARS_COLOURC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ast"),
        dictgen::InsensitiveStr::Ascii("asted"),
        dictgen::InsensitiveStr::Ascii("aster"),
        dictgen::InsensitiveStr::Ascii("asters"),
        dictgen::InsensitiveStr::Ascii("asting"),
        dictgen::InsensitiveStr::Ascii("asts"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORCAST_16740960231179575917)],
        &[(0b11010, &ENTRY_COLORCASTED_10398645425299808234)],
        &[(0b11010, &ENTRY_COLORCASTER_8192206561724383576)],
        &[(0b11010, &ENTRY_COLORCASTERS_9885877195250711665)],
        &[(0b11010, &ENTRY_COLORCASTING_9616298919649932012)],
        &[(0b11010, &ENTRY_COLORCASTS_17581853229444769235)],
    ],
    range: 3..=6,
};

static VARS_COLOURB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURB_CHILDREN),
    value: None,
};

pub static VARS_COLOURB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("earer"),
        dictgen::InsensitiveStr::Ascii("lind"),
        dictgen::InsensitiveStr::Ascii("lindness"),
        dictgen::InsensitiveStr::Ascii("lindnesses"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("reed"),
        dictgen::InsensitiveStr::Ascii("reeding"),
        dictgen::InsensitiveStr::Ascii("reeds"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORBEARER_9903060614478418481)],
        &[(0b11010, &ENTRY_COLORBLIND_6088870633188592041)],
        &[(0b11010, &ENTRY_COLORBLINDNESS_15137443200927238655)],
        &[(0b11010, &ENTRY_COLORBLINDNESSES_12714928556099515868)],
        &[(0b11010, &ENTRY_COLORBRED_17391526765371994938)],
        &[(0b11010, &ENTRY_COLORBREED_988623603127049866)],
        &[(0b11010, &ENTRY_COLORBREEDING_14262752611756151320)],
        &[(0b11010, &ENTRY_COLORBREEDS_5534022895414416287)],
    ],
    range: 3..=10,
};

static VARS_COLOURA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLOURA_CHILDREN),
    value: None,
};

pub static VARS_COLOURA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilities"),
        dictgen::InsensitiveStr::Ascii("bility"),
        dictgen::InsensitiveStr::Ascii("ble"),
        dictgen::InsensitiveStr::Ascii("bleness"),
        dictgen::InsensitiveStr::Ascii("blenesses"),
        dictgen::InsensitiveStr::Ascii("bler"),
        dictgen::InsensitiveStr::Ascii("bles"),
        dictgen::InsensitiveStr::Ascii("blest"),
        dictgen::InsensitiveStr::Ascii("blier"),
        dictgen::InsensitiveStr::Ascii("blies"),
        dictgen::InsensitiveStr::Ascii("bliest"),
        dictgen::InsensitiveStr::Ascii("bly"),
        dictgen::InsensitiveStr::Ascii("dan"),
        dictgen::InsensitiveStr::Ascii("dans"),
        dictgen::InsensitiveStr::Ascii("do"),
        dictgen::InsensitiveStr::Ascii("doite"),
        dictgen::InsensitiveStr::Ascii("ma"),
        dictgen::InsensitiveStr::Ascii("nt"),
        dictgen::InsensitiveStr::Ascii("nts"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tion"),
        dictgen::InsensitiveStr::Ascii("tional"),
        dictgen::InsensitiveStr::Ascii("tionaler"),
        dictgen::InsensitiveStr::Ascii("tionalest"),
        dictgen::InsensitiveStr::Ascii("tionallier"),
        dictgen::InsensitiveStr::Ascii("tionalliest"),
        dictgen::InsensitiveStr::Ascii("tionally"),
        dictgen::InsensitiveStr::Ascii("tions"),
        dictgen::InsensitiveStr::Ascii("tive"),
    ],
    values: &[
        &[(0b11010, &ENTRY_COLORABILITIES_17934830495879279238)],
        &[(0b11010, &ENTRY_COLORABILITY_3833618249244001959)],
        &[(0b11010, &ENTRY_COLORABLE_9126609110540102083)],
        &[(0b11010, &ENTRY_COLORABLENESS_1061796348140451347)],
        &[(0b11010, &ENTRY_COLORABLENESSES_10749946314548598617)],
        &[(0b11010, &ENTRY_COLORABLER_1063847220352847404)],
        &[(0b11010, &ENTRY_COLORABLES_10854398030589164189)],
        &[(0b11010, &ENTRY_COLORABLEST_3683085641889155962)],
        &[(0b11010, &ENTRY_COLORABLIER_5968483988144955864)],
        &[(0b11010, &ENTRY_COLORABLIES_16005107918816262896)],
        &[(0b11010, &ENTRY_COLORABLIEST_5199306118528597149)],
        &[(0b11010, &ENTRY_COLORABLY_13475999889111967538)],
        &[(0b11010, &ENTRY_COLORADAN_1710087118093866996)],
        &[(0b11010, &ENTRY_COLORADANS_1537230991364273395)],
        &[(0b11010, &ENTRY_COLORADO_672786360083421122)],
        &[(0b11010, &ENTRY_COLORADOITE_10437671738809934244)],
        &[(0b11010, &ENTRY_COLORAMA_10946100748903023597)],
        &[(0b11010, &ENTRY_COLORANT_105918244627467133)],
        &[(0b11010, &ENTRY_COLORANTS_7537794752295559574)],
        &[(0b11010, &ENTRY_COLORATE_7568881222694249579)],
        &[(0b11010, &ENTRY_COLORATION_8662739203385742912)],
        &[(0b11010, &ENTRY_COLORATIONAL_7644580988989747664)],
        &[(0b11010, &ENTRY_COLORATIONALER_18110955114460055798)],
        &[(0b11010, &ENTRY_COLORATIONALEST_16549871838474883279)],
        &[(0b11010, &ENTRY_COLORATIONALLIER_11632159047499104121)],
        &[(0b11010, &ENTRY_COLORATIONALLIEST_15869239691609448176)],
        &[(0b11010, &ENTRY_COLORATIONALLY_6635974304993009997)],
        &[(0b11010, &ENTRY_COLORATIONS_1952756960960680507)],
        &[(0b11010, &ENTRY_COLORATIVE_17851173748347347190)],
    ],
    range: 2..=11,
};

static VARS_COLOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_COLOR_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_COLOR_17720358635329736641)]),
};

static VARS_COLOR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_COLORA_NODE),
    Some(&VARS_COLORB_NODE),
    Some(&VARS_COLORC_NODE),
    None,
    Some(&VARS_COLORE_NODE),
    Some(&VARS_COLORF_NODE),
    None,
    None,
    Some(&VARS_COLORI_NODE),
    None,
    None,
    Some(&VARS_COLORL_NODE),
    Some(&VARS_COLORM_NODE),
    None,
    Some(&VARS_COLORO_NODE),
    Some(&VARS_COLORP_NODE),
    None,
    Some(&VARS_COLORR_NODE),
    Some(&VARS_COLORS_NODE),
    Some(&VARS_COLORT_NODE),
    None,
    None,
    Some(&VARS_COLORW_NODE),
    None,
    Some(&VARS_COLORY_NODE),
    None,
];

static VARS_COLORY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORY_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_COLORY_3235234236420467456)]),
};

pub static VARS_COLORY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_COLORW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORW_CHILDREN),
    value: None,
};

pub static VARS_COLORW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ay"),
        dictgen::InsensitiveStr::Ascii("ays"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORWAY_14654249147936693420)],
        &[(0b11001, &ENTRY_COLORWAYS_6062463807369877282)],
    ],
    range: 2..=3,
};

static VARS_COLORT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORT_CHILDREN),
    value: None,
};

pub static VARS_COLORT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ype")],
    values: &[&[(0b11001, &ENTRY_COLORTYPE_14680038702599961625)]],
    range: 3..=3,
};

static VARS_COLORS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORS_CHILDREN),
    value: Some(&[(0b11001, &ENTRY_COLORS_13018845474144214729)]),
};

pub static VARS_COLORS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_COLORR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORR_CHILDREN),
    value: None,
};

pub static VARS_COLORR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("est"),
        dictgen::InsensitiveStr::Ascii("haphy"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORREST_6777192705388068909)],
        &[(0b00001, &ENTRY_COLORRHAPHY_13136665400257945176)],
    ],
    range: 3..=5,
};

static VARS_COLORP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORP_CHILDREN),
    value: None,
};

pub static VARS_COLORP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oint"),
        dictgen::InsensitiveStr::Ascii("oints"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORPOINT_12353596064079181917)],
        &[(0b11001, &ENTRY_COLORPOINTS_13015689836998141845)],
    ],
    range: 4..=5,
};

static VARS_COLORO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORO_CHILDREN),
    value: None,
};

pub static VARS_COLORO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("to")],
    values: &[&[(0b00001, &ENTRY_COLOROTO_5869254994177780978)]],
    range: 2..=2,
};

static VARS_COLORM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORM_CHILDREN),
    value: None,
};

pub static VARS_COLORM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aker"),
        dictgen::InsensitiveStr::Ascii("aking"),
        dictgen::InsensitiveStr::Ascii("an"),
        dictgen::InsensitiveStr::Ascii("ap"),
        dictgen::InsensitiveStr::Ascii("aps"),
        dictgen::InsensitiveStr::Ascii("en"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORMAKER_13048991323713933641)],
        &[(0b11001, &ENTRY_COLORMAKING_3298385465563328410)],
        &[(0b11001, &ENTRY_COLORMAN_9192316057645589430)],
        &[(0b11001, &ENTRY_COLORMAP_18024738796464819872)],
        &[(0b11001, &ENTRY_COLORMAPS_11406342514432472514)],
        &[(0b11001, &ENTRY_COLORMEN_1963797128559420405)],
    ],
    range: 2..=5,
};

static VARS_COLORL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORL_CHILDREN),
    value: None,
};

pub static VARS_COLORL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ess"),
        dictgen::InsensitiveStr::Ascii("esser"),
        dictgen::InsensitiveStr::Ascii("essest"),
        dictgen::InsensitiveStr::Ascii("esslier"),
        dictgen::InsensitiveStr::Ascii("essliest"),
        dictgen::InsensitiveStr::Ascii("essly"),
        dictgen::InsensitiveStr::Ascii("essness"),
        dictgen::InsensitiveStr::Ascii("essnesses"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORLESS_15335426167000546767)],
        &[(0b11001, &ENTRY_COLORLESSER_9795559032347620897)],
        &[(0b11001, &ENTRY_COLORLESSEST_2853202552785506979)],
        &[(0b11001, &ENTRY_COLORLESSLIER_15143289294047728460)],
        &[(0b11001, &ENTRY_COLORLESSLIEST_12819557587409285660)],
        &[(0b11001, &ENTRY_COLORLESSLY_15719317170801627859)],
        &[(0b11001, &ENTRY_COLORLESSNESS_3911470984873699039)],
        &[(0b11001, &ENTRY_COLORLESSNESSES_17325232283084205852)],
    ],
    range: 3..=9,
};

static VARS_COLORI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORI_CHILDREN),
    value: None,
};

pub static VARS_COLORI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fic"),
        dictgen::InsensitiveStr::Ascii("fics"),
        dictgen::InsensitiveStr::Ascii("metrical"),
        dictgen::InsensitiveStr::Ascii("metrically"),
        dictgen::InsensitiveStr::Ascii("metrist"),
        dictgen::InsensitiveStr::Ascii("n"),
        dictgen::InsensitiveStr::Ascii("ng"),
        dictgen::InsensitiveStr::Ascii("ngs"),
        dictgen::InsensitiveStr::Ascii("sm"),
        dictgen::InsensitiveStr::Ascii("sms"),
        dictgen::InsensitiveStr::Ascii("st"),
        dictgen::InsensitiveStr::Ascii("stic"),
        dictgen::InsensitiveStr::Ascii("stically"),
        dictgen::InsensitiveStr::Ascii("sticer"),
        dictgen::InsensitiveStr::Ascii("sticest"),
        dictgen::InsensitiveStr::Ascii("stics"),
        dictgen::InsensitiveStr::Ascii("sts"),
        dictgen::InsensitiveStr::Ascii("zation"),
        dictgen::InsensitiveStr::Ascii("zations"),
        dictgen::InsensitiveStr::Ascii("ze"),
        dictgen::InsensitiveStr::Ascii("zed"),
        dictgen::InsensitiveStr::Ascii("zes"),
        dictgen::InsensitiveStr::Ascii("zing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_COLORIFIC_17453281363599547611)],
        &[(0b00001, &ENTRY_COLORIFICS_7493178994191350405)],
        &[(0b00001, &ENTRY_COLORIMETRICAL_14932230836831976255)],
        &[(0b00001, &ENTRY_COLORIMETRICALLY_5243289402205557910)],
        &[(0b00001, &ENTRY_COLORIMETRIST_16103668754911113058)],
        &[(0b00001, &ENTRY_COLORIN_7364447797547189461)],
        &[(0b11001, &ENTRY_COLORING_3210137591351035939)],
        &[(0b11001, &ENTRY_COLORINGS_3076825598771260084)],
        &[(0b00001, &ENTRY_COLORISM_11451642000509277550)],
        &[(0b00001, &ENTRY_COLORISMS_9834615672957808489)],
        &[(0b01001, &ENTRY_COLORIST_3170137357114879751)],
        &[(0b00001, &ENTRY_COLORISTIC_4901807440455152786)],
        &[(0b00001, &ENTRY_COLORISTICALLY_4826074029409437505)],
        &[(0b00001, &ENTRY_COLORISTICER_8710817088617352267)],
        &[(0b00001, &ENTRY_COLORISTICEST_2991259503195608639)],
        &[(0b00001, &ENTRY_COLORISTICS_10161388239807067112)],
        &[(0b01001, &ENTRY_COLORISTS_205210891187993391)],
        &[(0b00001, &ENTRY_COLORIZATION_8112190634064658436)],
        &[(0b00001, &ENTRY_COLORIZATIONS_4267572307963209982)],
        &[(0b00001, &ENTRY_COLORIZE_378813947509810224)],
        &[(0b00001, &ENTRY_COLORIZED_1927556635004418734)],
        &[(0b00001, &ENTRY_COLORIZES_12579061677034347790)],
        &[(0b00001, &ENTRY_COLORIZING_2623120429929129787)],
    ],
    range: 1..=10,
};

static VARS_COLORF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORF_CHILDREN),
    value: None,
};

pub static VARS_COLORF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ast"),
        dictgen::InsensitiveStr::Ascii("astness"),
        dictgen::InsensitiveStr::Ascii("astnesses"),
        dictgen::InsensitiveStr::Ascii("ul"),
        dictgen::InsensitiveStr::Ascii("uler"),
        dictgen::InsensitiveStr::Ascii("ulest"),
        dictgen::InsensitiveStr::Ascii("ullier"),
        dictgen::InsensitiveStr::Ascii("ulliest"),
        dictgen::InsensitiveStr::Ascii("ully"),
        dictgen::InsensitiveStr::Ascii("ulness"),
        dictgen::InsensitiveStr::Ascii("ulnesses"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORFAST_16696822485914404702)],
        &[(0b11001, &ENTRY_COLORFASTNESS_3258841464722986607)],
        &[(0b11001, &ENTRY_COLORFASTNESSES_14995112700652023509)],
        &[(0b11001, &ENTRY_COLORFUL_16225861255487751804)],
        &[(0b11001, &ENTRY_COLORFULER_10294924989983822582)],
        &[(0b11001, &ENTRY_COLORFULEST_202572902882532719)],
        &[(0b11001, &ENTRY_COLORFULLIER_3454480613316383412)],
        &[(0b11001, &ENTRY_COLORFULLIEST_14019017521674302328)],
        &[(0b11001, &ENTRY_COLORFULLY_7749800674951458575)],
        &[(0b11001, &ENTRY_COLORFULNESS_8831709788792250227)],
        &[(0b11001, &ENTRY_COLORFULNESSES_11724036744178299544)],
    ],
    range: 2..=9,
};

static VARS_COLORE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORE_CHILDREN),
    value: None,
};

pub static VARS_COLORE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ctal"),
        dictgen::InsensitiveStr::Ascii("ctitis"),
        dictgen::InsensitiveStr::Ascii("ctostomy"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ds"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rs"),
    ],
    values: &[
        &[(0b00001, &ENTRY_COLORECTAL_9394771582914199855)],
        &[(0b00001, &ENTRY_COLORECTITIS_11920759655606208881)],
        &[(0b00001, &ENTRY_COLORECTOSTOMY_809184159134628418)],
        &[(0b11001, &ENTRY_COLORED_809367823820397764)],
        &[(0b11001, &ENTRY_COLOREDS_5638105898846322523)],
        &[(0b11001, &ENTRY_COLORER_6377883908421217617)],
        &[(0b11001, &ENTRY_COLORERS_5523036624009318320)],
    ],
    range: 1..=8,
};

static VARS_COLORC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORC_CHILDREN),
    value: None,
};

pub static VARS_COLORC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ast"),
        dictgen::InsensitiveStr::Ascii("asted"),
        dictgen::InsensitiveStr::Ascii("aster"),
        dictgen::InsensitiveStr::Ascii("asters"),
        dictgen::InsensitiveStr::Ascii("asting"),
        dictgen::InsensitiveStr::Ascii("asts"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORCAST_16740960231179575917)],
        &[(0b11001, &ENTRY_COLORCASTED_10398645425299808234)],
        &[(0b11001, &ENTRY_COLORCASTER_8192206561724383576)],
        &[(0b11001, &ENTRY_COLORCASTERS_9885877195250711665)],
        &[(0b11001, &ENTRY_COLORCASTING_9616298919649932012)],
        &[(0b11001, &ENTRY_COLORCASTS_17581853229444769235)],
    ],
    range: 3..=6,
};

static VARS_COLORB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORB_CHILDREN),
    value: None,
};

pub static VARS_COLORB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("earer"),
        dictgen::InsensitiveStr::Ascii("lind"),
        dictgen::InsensitiveStr::Ascii("lindness"),
        dictgen::InsensitiveStr::Ascii("lindnesses"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("reed"),
        dictgen::InsensitiveStr::Ascii("reeding"),
        dictgen::InsensitiveStr::Ascii("reeds"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORBEARER_9903060614478418481)],
        &[(0b11001, &ENTRY_COLORBLIND_6088870633188592041)],
        &[(0b11001, &ENTRY_COLORBLINDNESS_15137443200927238655)],
        &[(0b11001, &ENTRY_COLORBLINDNESSES_12714928556099515868)],
        &[(0b11001, &ENTRY_COLORBRED_17391526765371994938)],
        &[(0b11001, &ENTRY_COLORBREED_988623603127049866)],
        &[(0b11001, &ENTRY_COLORBREEDING_14262752611756151320)],
        &[(0b11001, &ENTRY_COLORBREEDS_5534022895414416287)],
    ],
    range: 3..=10,
};

static VARS_COLORA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLORA_CHILDREN),
    value: None,
};

pub static VARS_COLORA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bilities"),
        dictgen::InsensitiveStr::Ascii("bility"),
        dictgen::InsensitiveStr::Ascii("ble"),
        dictgen::InsensitiveStr::Ascii("bleness"),
        dictgen::InsensitiveStr::Ascii("blenesses"),
        dictgen::InsensitiveStr::Ascii("bler"),
        dictgen::InsensitiveStr::Ascii("bles"),
        dictgen::InsensitiveStr::Ascii("blest"),
        dictgen::InsensitiveStr::Ascii("blier"),
        dictgen::InsensitiveStr::Ascii("blies"),
        dictgen::InsensitiveStr::Ascii("bliest"),
        dictgen::InsensitiveStr::Ascii("bly"),
        dictgen::InsensitiveStr::Ascii("dan"),
        dictgen::InsensitiveStr::Ascii("dans"),
        dictgen::InsensitiveStr::Ascii("do"),
        dictgen::InsensitiveStr::Ascii("doite"),
        dictgen::InsensitiveStr::Ascii("ma"),
        dictgen::InsensitiveStr::Ascii("nt"),
        dictgen::InsensitiveStr::Ascii("nts"),
        dictgen::InsensitiveStr::Ascii("te"),
        dictgen::InsensitiveStr::Ascii("tive"),
    ],
    values: &[
        &[(0b11001, &ENTRY_COLORABILITIES_17934830495879279238)],
        &[(0b11001, &ENTRY_COLORABILITY_3833618249244001959)],
        &[(0b11001, &ENTRY_COLORABLE_9126609110540102083)],
        &[(0b11001, &ENTRY_COLORABLENESS_1061796348140451347)],
        &[(0b11001, &ENTRY_COLORABLENESSES_10749946314548598617)],
        &[(0b11001, &ENTRY_COLORABLER_1063847220352847404)],
        &[(0b11001, &ENTRY_COLORABLES_10854398030589164189)],
        &[(0b11001, &ENTRY_COLORABLEST_3683085641889155962)],
        &[(0b11001, &ENTRY_COLORABLIER_5968483988144955864)],
        &[(0b11001, &ENTRY_COLORABLIES_16005107918816262896)],
        &[(0b11001, &ENTRY_COLORABLIEST_5199306118528597149)],
        &[(0b11001, &ENTRY_COLORABLY_13475999889111967538)],
        &[(0b00001, &ENTRY_COLORADAN_1710087118093866996)],
        &[(0b00001, &ENTRY_COLORADANS_1537230991364273395)],
        &[(0b00001, &ENTRY_COLORADO_672786360083421122)],
        &[(0b00001, &ENTRY_COLORADOITE_10437671738809934244)],
        &[(0b00001, &ENTRY_COLORAMA_10946100748903023597)],
        &[(0b11001, &ENTRY_COLORANT_105918244627467133)],
        &[(0b11001, &ENTRY_COLORANTS_7537794752295559574)],
        &[(0b00001, &ENTRY_COLORATE_7568881222694249579)],
        &[(0b00001, &ENTRY_COLORATIVE_17851173748347347190)],
    ],
    range: 2..=9,
};

static VARS_COLON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLON_CHILDREN),
    value: None,
};

pub static VARS_COLON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialise"),
        dictgen::InsensitiveStr::Ascii("ialised"),
        dictgen::InsensitiveStr::Ascii("ialises"),
        dictgen::InsensitiveStr::Ascii("ialising"),
        dictgen::InsensitiveStr::Ascii("ialize"),
        dictgen::InsensitiveStr::Ascii("ialized"),
        dictgen::InsensitiveStr::Ascii("ializes"),
        dictgen::InsensitiveStr::Ascii("ializing"),
        dictgen::InsensitiveStr::Ascii("isabilities"),
        dictgen::InsensitiveStr::Ascii("isability"),
        dictgen::InsensitiveStr::Ascii("isable"),
        dictgen::InsensitiveStr::Ascii("isabler"),
        dictgen::InsensitiveStr::Ascii("isables"),
        dictgen::InsensitiveStr::Ascii("isablest"),
        dictgen::InsensitiveStr::Ascii("isation"),
        dictgen::InsensitiveStr::Ascii("isationist"),
        dictgen::InsensitiveStr::Ascii("isationists"),
        dictgen::InsensitiveStr::Ascii("isations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("iser"),
        dictgen::InsensitiveStr::Ascii("isers"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("izabilities"),
        dictgen::InsensitiveStr::Ascii("izability"),
        dictgen::InsensitiveStr::Ascii("izable"),
        dictgen::InsensitiveStr::Ascii("izabler"),
        dictgen::InsensitiveStr::Ascii("izables"),
        dictgen::InsensitiveStr::Ascii("izablest"),
        dictgen::InsensitiveStr::Ascii("ization"),
        dictgen::InsensitiveStr::Ascii("izationist"),
        dictgen::InsensitiveStr::Ascii("izationists"),
        dictgen::InsensitiveStr::Ascii("izations"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izer"),
        dictgen::InsensitiveStr::Ascii("izers"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COLONIALIZE_17015664660619402146)],
        &[(0b10010, &ENTRY_COLONIALIZED_13876149610938201725)],
        &[(0b10010, &ENTRY_COLONIALIZES_14570746695121826765)],
        &[(0b10010, &ENTRY_COLONIALIZING_16068571893089538400)],
        &[(0b01001, &ENTRY_COLONIALIZE_17015664660619402146)],
        &[(0b01001, &ENTRY_COLONIALIZED_13876149610938201725)],
        &[(0b01001, &ENTRY_COLONIALIZES_14570746695121826765)],
        &[(0b01001, &ENTRY_COLONIALIZING_16068571893089538400)],
        &[(0b10010, &ENTRY_COLONIZABILITIES_12944259693371296365)],
        &[(0b10010, &ENTRY_COLONIZABILITY_11573587685077716438)],
        &[(0b10010, &ENTRY_COLONIZABLE_1551399607404148929)],
        &[(0b10010, &ENTRY_COLONIZABLER_7503793641425675771)],
        &[(0b10010, &ENTRY_COLONIZABLES_7468307704661763383)],
        &[(0b10010, &ENTRY_COLONIZABLEST_13287343767333590772)],
        &[(0b10010, &ENTRY_COLONIZATION_8572095881455583344)],
        &[(0b10010, &ENTRY_COLONIZATIONIST_176926856555957139)],
        &[(0b10010, &ENTRY_COLONIZATIONISTS_16863993202249434726)],
        &[(0b10010, &ENTRY_COLONIZATIONS_12298250811536901685)],
        &[(0b10010, &ENTRY_COLONIZE_15302728430964322592)],
        &[(0b10010, &ENTRY_COLONIZED_12903152841060558253)],
        &[(0b10010, &ENTRY_COLONIZER_5320596989867894996)],
        &[(0b10010, &ENTRY_COLONIZERS_11110896653251592981)],
        &[(0b10010, &ENTRY_COLONIZES_5176087008588077388)],
        &[(0b10010, &ENTRY_COLONIZING_17297511401074881747)],
        &[(0b01001, &ENTRY_COLONIZABILITIES_12944259693371296365)],
        &[(0b01001, &ENTRY_COLONIZABILITY_11573587685077716438)],
        &[(0b01001, &ENTRY_COLONIZABLE_1551399607404148929)],
        &[(0b01001, &ENTRY_COLONIZABLER_7503793641425675771)],
        &[(0b01001, &ENTRY_COLONIZABLES_7468307704661763383)],
        &[(0b01001, &ENTRY_COLONIZABLEST_13287343767333590772)],
        &[(0b01001, &ENTRY_COLONIZATION_8572095881455583344)],
        &[(0b01001, &ENTRY_COLONIZATIONIST_176926856555957139)],
        &[(0b01001, &ENTRY_COLONIZATIONISTS_16863993202249434726)],
        &[(0b01001, &ENTRY_COLONIZATIONS_12298250811536901685)],
        &[(0b01001, &ENTRY_COLONIZE_15302728430964322592)],
        &[(0b01001, &ENTRY_COLONIZED_12903152841060558253)],
        &[(0b01001, &ENTRY_COLONIZER_5320596989867894996)],
        &[(0b01001, &ENTRY_COLONIZERS_11110896653251592981)],
        &[(0b01001, &ENTRY_COLONIZES_5176087008588077388)],
        &[(0b01001, &ENTRY_COLONIZING_17297511401074881747)],
    ],
    range: 3..=11,
};

static VARS_COLL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COLL_CHILDREN),
    value: None,
};

pub static VARS_COLL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ateralise"),
        dictgen::InsensitiveStr::Ascii("ateralize"),
        dictgen::InsensitiveStr::Ascii("ectable"),
        dictgen::InsensitiveStr::Ascii("ectables"),
        dictgen::InsensitiveStr::Ascii("ectivisation"),
        dictgen::InsensitiveStr::Ascii("ectivisations"),
        dictgen::InsensitiveStr::Ascii("ectivise"),
        dictgen::InsensitiveStr::Ascii("ectivised"),
        dictgen::InsensitiveStr::Ascii("ectivises"),
        dictgen::InsensitiveStr::Ascii("ectivising"),
        dictgen::InsensitiveStr::Ascii("ectivization"),
        dictgen::InsensitiveStr::Ascii("ectivizations"),
        dictgen::InsensitiveStr::Ascii("ectivize"),
        dictgen::InsensitiveStr::Ascii("ectivized"),
        dictgen::InsensitiveStr::Ascii("ectivizes"),
        dictgen::InsensitiveStr::Ascii("ectivizing"),
        dictgen::InsensitiveStr::Ascii("oquialise"),
        dictgen::InsensitiveStr::Ascii("oquialises"),
        dictgen::InsensitiveStr::Ascii("oquialize"),
        dictgen::InsensitiveStr::Ascii("oquializes"),
        dictgen::InsensitiveStr::Ascii("oquise"),
        dictgen::InsensitiveStr::Ascii("oquised"),
        dictgen::InsensitiveStr::Ascii("oquises"),
        dictgen::InsensitiveStr::Ascii("oquising"),
        dictgen::InsensitiveStr::Ascii("oquize"),
        dictgen::InsensitiveStr::Ascii("oquized"),
        dictgen::InsensitiveStr::Ascii("oquizes"),
        dictgen::InsensitiveStr::Ascii("oquizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COLLATERALIZE_4809202625356484324)],
        &[(0b01001, &ENTRY_COLLATERALIZE_4809202625356484324)],
        &[(0b10011, &ENTRY_COLLECTIBLE_16675394473838043634)],
        &[(0b10011, &ENTRY_COLLECTIBLES_1426649794037748395)],
        &[(0b10010, &ENTRY_COLLECTIVIZATION_10577206395052359405)],
        &[(0b10010, &ENTRY_COLLECTIVIZATIONS_6853316050939234055)],
        &[(0b10010, &ENTRY_COLLECTIVIZE_18197662740300515669)],
        &[(0b10010, &ENTRY_COLLECTIVIZED_14370760959187496202)],
        &[(0b10010, &ENTRY_COLLECTIVIZES_15340840028673940577)],
        &[(0b10010, &ENTRY_COLLECTIVIZING_6177450980824602558)],
        &[(0b01001, &ENTRY_COLLECTIVIZATION_10577206395052359405)],
        &[(0b01001, &ENTRY_COLLECTIVIZATIONS_6853316050939234055)],
        &[(0b01001, &ENTRY_COLLECTIVIZE_18197662740300515669)],
        &[(0b01001, &ENTRY_COLLECTIVIZED_14370760959187496202)],
        &[(0b01001, &ENTRY_COLLECTIVIZES_15340840028673940577)],
        &[(0b01001, &ENTRY_COLLECTIVIZING_6177450980824602558)],
        &[(0b10010, &ENTRY_COLLOQUIALIZE_400572582640316358)],
        &[(0b10010, &ENTRY_COLLOQUIALIZES_11772046900035477346)],
        &[(0b01001, &ENTRY_COLLOQUIALIZE_400572582640316358)],
        &[(0b01001, &ENTRY_COLLOQUIALIZES_11772046900035477346)],
        &[(0b10010, &ENTRY_COLLOQUIZE_3542999561179306173)],
        &[(0b10010, &ENTRY_COLLOQUIZED_2987662592391153464)],
        &[(0b10010, &ENTRY_COLLOQUIZES_3694957155887273629)],
        &[(0b10010, &ENTRY_COLLOQUIZING_12005217252377921527)],
        &[(0b01001, &ENTRY_COLLOQUIZE_3542999561179306173)],
        &[(0b01001, &ENTRY_COLLOQUIZED_2987662592391153464)],
        &[(0b01001, &ENTRY_COLLOQUIZES_3694957155887273629)],
        &[(0b01001, &ENTRY_COLLOQUIZING_12005217252377921527)],
    ],
    range: 6..=13,
};

static VARS_COG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COG_CHILDREN),
    value: None,
};

pub static VARS_COG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nisability"),
        dictgen::InsensitiveStr::Ascii("nisable"),
        dictgen::InsensitiveStr::Ascii("nisableness"),
        dictgen::InsensitiveStr::Ascii("nisabler"),
        dictgen::InsensitiveStr::Ascii("nisablest"),
        dictgen::InsensitiveStr::Ascii("nisablier"),
        dictgen::InsensitiveStr::Ascii("nisabliest"),
        dictgen::InsensitiveStr::Ascii("nisably"),
        dictgen::InsensitiveStr::Ascii("nisance"),
        dictgen::InsensitiveStr::Ascii("nisances"),
        dictgen::InsensitiveStr::Ascii("nisant"),
        dictgen::InsensitiveStr::Ascii("nisanter"),
        dictgen::InsensitiveStr::Ascii("nisantest"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nizability"),
        dictgen::InsensitiveStr::Ascii("nizable"),
        dictgen::InsensitiveStr::Ascii("nizableness"),
        dictgen::InsensitiveStr::Ascii("nizabler"),
        dictgen::InsensitiveStr::Ascii("nizablest"),
        dictgen::InsensitiveStr::Ascii("nizablier"),
        dictgen::InsensitiveStr::Ascii("nizabliest"),
        dictgen::InsensitiveStr::Ascii("nizably"),
        dictgen::InsensitiveStr::Ascii("nizance"),
        dictgen::InsensitiveStr::Ascii("nizances"),
        dictgen::InsensitiveStr::Ascii("nizant"),
        dictgen::InsensitiveStr::Ascii("nizanter"),
        dictgen::InsensitiveStr::Ascii("nizantest"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COGNIZABILITY_660527253976403780)],
        &[(0b10010, &ENTRY_COGNIZABLE_13131115414619000772)],
        &[(0b10010, &ENTRY_COGNIZABLENESS_16476592524827512160)],
        &[(0b10010, &ENTRY_COGNIZABLER_12070099101883833731)],
        &[(0b10010, &ENTRY_COGNIZABLEST_13955023369005527923)],
        &[(0b10010, &ENTRY_COGNIZABLIER_1964601888045213766)],
        &[(0b10010, &ENTRY_COGNIZABLIEST_13701693542862328478)],
        &[(0b10010, &ENTRY_COGNIZABLY_17839926776700915805)],
        &[(0b10010, &ENTRY_COGNIZANCE_14359512853615918641)],
        &[(0b10010, &ENTRY_COGNIZANCES_183948325192833313)],
        &[(0b10010, &ENTRY_COGNIZANT_2557847978553579663)],
        &[(0b10010, &ENTRY_COGNIZANTER_9274314327914715355)],
        &[(0b10010, &ENTRY_COGNIZANTEST_9952434271050939774)],
        &[(0b10010, &ENTRY_COGNIZE_7253118900028580039)],
        &[(0b10010, &ENTRY_COGNIZED_17562230997464673899)],
        &[(0b10010, &ENTRY_COGNIZER_17235063272659781689)],
        &[(0b10010, &ENTRY_COGNIZERS_16818874771090495789)],
        &[(0b10010, &ENTRY_COGNIZES_313141652357958777)],
        &[(0b10010, &ENTRY_COGNIZING_14291458489887284299)],
        &[(0b01001, &ENTRY_COGNIZABILITY_660527253976403780)],
        &[(0b01001, &ENTRY_COGNIZABLE_13131115414619000772)],
        &[(0b01001, &ENTRY_COGNIZABLENESS_16476592524827512160)],
        &[(0b01001, &ENTRY_COGNIZABLER_12070099101883833731)],
        &[(0b01001, &ENTRY_COGNIZABLEST_13955023369005527923)],
        &[(0b01001, &ENTRY_COGNIZABLIER_1964601888045213766)],
        &[(0b01001, &ENTRY_COGNIZABLIEST_13701693542862328478)],
        &[(0b01001, &ENTRY_COGNIZABLY_17839926776700915805)],
        &[(0b01001, &ENTRY_COGNIZANCE_14359512853615918641)],
        &[(0b01001, &ENTRY_COGNIZANCES_183948325192833313)],
        &[(0b01001, &ENTRY_COGNIZANT_2557847978553579663)],
        &[(0b01001, &ENTRY_COGNIZANTER_9274314327914715355)],
        &[(0b01001, &ENTRY_COGNIZANTEST_9952434271050939774)],
        &[(0b01001, &ENTRY_COGNIZE_7253118900028580039)],
        &[(0b01001, &ENTRY_COGNIZED_17562230997464673899)],
        &[(0b01001, &ENTRY_COGNIZER_17235063272659781689)],
        &[(0b01001, &ENTRY_COGNIZERS_16818874771090495789)],
        &[(0b01001, &ENTRY_COGNIZES_313141652357958777)],
        &[(0b01001, &ENTRY_COGNIZING_14291458489887284299)],
    ],
    range: 4..=11,
};

static VARS_COE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COE_CHILDREN),
    value: Some(&[
        (0b11010, &ENTRY_CE_254143254853835550),
        (0b00001, &ENTRY_COE_10755603025154058571),
    ]),
};

pub static VARS_COE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ducationalise"),
        dictgen::InsensitiveStr::Ascii("ducationalises"),
        dictgen::InsensitiveStr::Ascii("ducationalize"),
        dictgen::InsensitiveStr::Ascii("ducationalizes"),
        dictgen::InsensitiveStr::Ascii("lastraceae"),
        dictgen::InsensitiveStr::Ascii("lastraceous"),
        dictgen::InsensitiveStr::Ascii("lestine"),
        dictgen::InsensitiveStr::Ascii("liac"),
        dictgen::InsensitiveStr::Ascii("liacs"),
        dictgen::InsensitiveStr::Ascii("lialgia"),
        dictgen::InsensitiveStr::Ascii("liomyalgia"),
        dictgen::InsensitiveStr::Ascii("liorrhea"),
        dictgen::InsensitiveStr::Ascii("lioscopy"),
        dictgen::InsensitiveStr::Ascii("liotomy"),
        dictgen::InsensitiveStr::Ascii("lom"),
        dictgen::InsensitiveStr::Ascii("loma"),
        dictgen::InsensitiveStr::Ascii("lomata"),
        dictgen::InsensitiveStr::Ascii("loms"),
        dictgen::InsensitiveStr::Ascii("loscope"),
        dictgen::InsensitiveStr::Ascii("nacle"),
        dictgen::InsensitiveStr::Ascii("naculum"),
        dictgen::InsensitiveStr::Ascii("namor"),
        dictgen::InsensitiveStr::Ascii("namored"),
        dictgen::InsensitiveStr::Ascii("namoring"),
        dictgen::InsensitiveStr::Ascii("namorment"),
        dictgen::InsensitiveStr::Ascii("namors"),
        dictgen::InsensitiveStr::Ascii("namour"),
        dictgen::InsensitiveStr::Ascii("namoured"),
        dictgen::InsensitiveStr::Ascii("namouring"),
        dictgen::InsensitiveStr::Ascii("namourment"),
        dictgen::InsensitiveStr::Ascii("namours"),
        dictgen::InsensitiveStr::Ascii("nesthesia"),
        dictgen::InsensitiveStr::Ascii("nesthesias"),
        dictgen::InsensitiveStr::Ascii("nesthesis"),
        dictgen::InsensitiveStr::Ascii("nobe"),
        dictgen::InsensitiveStr::Ascii("nobite"),
        dictgen::InsensitiveStr::Ascii("nobites"),
        dictgen::InsensitiveStr::Ascii("nobitic"),
        dictgen::InsensitiveStr::Ascii("nobitical"),
        dictgen::InsensitiveStr::Ascii("nobitism"),
        dictgen::InsensitiveStr::Ascii("nobium"),
        dictgen::InsensitiveStr::Ascii("noby"),
        dictgen::InsensitiveStr::Ascii("nogenetic"),
        dictgen::InsensitiveStr::Ascii("nosite"),
        dictgen::InsensitiveStr::Ascii("nospecies"),
        dictgen::InsensitiveStr::Ascii("nospecific"),
        dictgen::InsensitiveStr::Ascii("nospecifically"),
        dictgen::InsensitiveStr::Ascii("qualise"),
        dictgen::InsensitiveStr::Ascii("qualises"),
        dictgen::InsensitiveStr::Ascii("qualize"),
        dictgen::InsensitiveStr::Ascii("qualizes"),
        dictgen::InsensitiveStr::Ascii("ruleolactite"),
        dictgen::InsensitiveStr::Ascii("tus"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COEDUCATIONALIZE_1494210807334794701)],
        &[(0b10010, &ENTRY_COEDUCATIONALIZES_6378010748334869944)],
        &[(0b01001, &ENTRY_COEDUCATIONALIZE_1494210807334794701)],
        &[(0b01001, &ENTRY_COEDUCATIONALIZES_6378010748334869944)],
        &[(0b11010, &ENTRY_CELASTRACEAE_17324005888177982048)],
        &[(0b11010, &ENTRY_CELASTRACEOUS_18174723794622646878)],
        &[(0b11010, &ENTRY_CELESTINE_11011528250519125092)],
        &[(0b11010, &ENTRY_CELIAC_10249133411124257957)],
        &[(0b11010, &ENTRY_CELIACS_10248347099141877177)],
        &[(0b11010, &ENTRY_CELIALGIA_4569927604389576150)],
        &[(0b11010, &ENTRY_CELIOMYALGIA_14548383766443531737)],
        &[(0b11010, &ENTRY_CELIORRHEA_5614182174276153091)],
        &[(0b11010, &ENTRY_CELIOSCOPY_17821312237861674807)],
        &[(0b11010, &ENTRY_CELIOTOMY_9141657999599968712)],
        &[(0b11010, &ENTRY_CELOM_581114569279805851)],
        &[(0b11010, &ENTRY_CELOMA_8394900856159450271)],
        &[
            (0b11010, &ENTRY_CELOMATA_5399894536275260385),
            (0b00010, &ENTRY_CELOMS_16869648723221026513),
        ],
        &[(0b11010, &ENTRY_CELOMS_16869648723221026513)],
        &[(0b11010, &ENTRY_CELOSCOPE_13733285893205563827)],
        &[(0b11010, &ENTRY_CENACLE_4902172834128420652)],
        &[(0b11010, &ENTRY_CENACULUM_14642801640862790402)],
        &[(0b10001, &ENTRY_COENAMOR_8473204005333691620)],
        &[(0b10001, &ENTRY_COENAMORED_9568490962748517648)],
        &[(0b10001, &ENTRY_COENAMORING_951487569841068233)],
        &[(0b10001, &ENTRY_COENAMORMENT_10116172708022357030)],
        &[(0b10001, &ENTRY_COENAMORS_8428808930600945906)],
        &[(0b11010, &ENTRY_COENAMOR_8473204005333691620)],
        &[(0b11010, &ENTRY_COENAMORED_9568490962748517648)],
        &[(0b11010, &ENTRY_COENAMORING_951487569841068233)],
        &[(0b11010, &ENTRY_COENAMORMENT_10116172708022357030)],
        &[(0b11010, &ENTRY_COENAMORS_8428808930600945906)],
        &[(0b11010, &ENTRY_CENESTHESIA_3973419130660988894)],
        &[(0b11010, &ENTRY_CENESTHESIAS_17650055632548316730)],
        &[(0b11010, &ENTRY_CENESTHESIS_2981771230300833707)],
        &[(0b11010, &ENTRY_CENOBE_17025760197236238291)],
        &[(0b11010, &ENTRY_CENOBITE_15084617731417587224)],
        &[(0b11010, &ENTRY_CENOBITES_12070792697281985215)],
        &[(0b11010, &ENTRY_CENOBITIC_861253358414117823)],
        &[(0b11010, &ENTRY_CENOBITICAL_3907716283980683620)],
        &[(0b11010, &ENTRY_CENOBITISM_5016689208030165500)],
        &[(0b11010, &ENTRY_CENOBIUM_6656148321160010108)],
        &[(0b11010, &ENTRY_CENOBY_6246310194380860627)],
        &[(0b11010, &ENTRY_CENOGENETIC_14752824343681490356)],
        &[(0b11010, &ENTRY_CENOSITE_6962695398695523616)],
        &[(0b11010, &ENTRY_CENOSPECIES_18129881350317785306)],
        &[(0b11010, &ENTRY_CENOSPECIFIC_10710765180299401749)],
        &[(0b11010, &ENTRY_CENOSPECIFICALLY_5111318916340201830)],
        &[(0b10010, &ENTRY_COEQUALIZE_15105464134551790946)],
        &[(0b10010, &ENTRY_COEQUALIZES_1651368880238979086)],
        &[(0b01001, &ENTRY_COEQUALIZE_15105464134551790946)],
        &[(0b01001, &ENTRY_COEQUALIZES_1651368880238979086)],
        &[(0b11010, &ENTRY_CERULEOLACTITE_1277200430318336008)],
        &[(0b11010, &ENTRY_CETUS_11617299917311809086)],
    ],
    range: 3..=14,
};

static VARS_COC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COC_CHILDREN),
    value: None,
};

pub static VARS_COC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ainisation"),
        dictgen::InsensitiveStr::Ascii("ainisations"),
        dictgen::InsensitiveStr::Ascii("ainise"),
        dictgen::InsensitiveStr::Ascii("ainised"),
        dictgen::InsensitiveStr::Ascii("ainises"),
        dictgen::InsensitiveStr::Ascii("ainising"),
        dictgen::InsensitiveStr::Ascii("ainization"),
        dictgen::InsensitiveStr::Ascii("ainizations"),
        dictgen::InsensitiveStr::Ascii("ainize"),
        dictgen::InsensitiveStr::Ascii("ainized"),
        dictgen::InsensitiveStr::Ascii("ainizes"),
        dictgen::InsensitiveStr::Ascii("ainizing"),
        dictgen::InsensitiveStr::Ascii("uisa"),
        dictgen::InsensitiveStr::Ascii("uiza"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COCAINIZATION_18270228789956323677)],
        &[(0b10010, &ENTRY_COCAINIZATIONS_3037752219365718178)],
        &[(0b10010, &ENTRY_COCAINIZE_5959521297540551059)],
        &[(0b10010, &ENTRY_COCAINIZED_11738928114927355282)],
        &[(0b10010, &ENTRY_COCAINIZES_4491426404312671844)],
        &[(0b10010, &ENTRY_COCAINIZING_3962782652468626350)],
        &[(0b01001, &ENTRY_COCAINIZATION_18270228789956323677)],
        &[(0b01001, &ENTRY_COCAINIZATIONS_3037752219365718178)],
        &[(0b01001, &ENTRY_COCAINIZE_5959521297540551059)],
        &[(0b01001, &ENTRY_COCAINIZED_11738928114927355282)],
        &[(0b01001, &ENTRY_COCAINIZES_4491426404312671844)],
        &[(0b01001, &ENTRY_COCAINIZING_3962782652468626350)],
        &[(0b10010, &ENTRY_COCUIZA_6504886933052210304)],
        &[(0b01001, &ENTRY_COCUIZA_6504886933052210304)],
    ],
    range: 4..=11,
};

static VARS_COA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_COA_CHILDREN),
    value: None,
};

pub static VARS_COA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("liser"),
        dictgen::InsensitiveStr::Ascii("lisers"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizer"),
        dictgen::InsensitiveStr::Ascii("lizers"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_COALIZE_1093705182941742482)],
        &[(0b10010, &ENTRY_COALIZED_1331392537006305584)],
        &[(0b10010, &ENTRY_COALIZER_8326324895948995645)],
        &[(0b10010, &ENTRY_COALIZERS_8541541270360324668)],
        &[(0b10010, &ENTRY_COALIZES_12556076575141372172)],
        &[(0b10010, &ENTRY_COALIZING_8107852365569207830)],
        &[(0b01001, &ENTRY_COALIZE_1093705182941742482)],
        &[(0b01001, &ENTRY_COALIZED_1331392537006305584)],
        &[(0b01001, &ENTRY_COALIZER_8326324895948995645)],
        &[(0b01001, &ENTRY_COALIZERS_8541541270360324668)],
        &[(0b01001, &ENTRY_COALIZES_12556076575141372172)],
        &[(0b01001, &ENTRY_COALIZING_8107852365569207830)],
    ],
    range: 4..=6,
};

static VARS_CL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CL_CHILDREN),
    value: None,
};

static VARS_CL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CLA_NODE),
    None,
    None,
    None,
    Some(&VARS_CLE_NODE),
    None,
    None,
    None,
    Some(&VARS_CLI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CLO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CLY_NODE),
    None,
];

static VARS_CLY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLY_CHILDREN),
    value: None,
};

pub static VARS_CLY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tiae"),
        dictgen::InsensitiveStr::Ascii("tie"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CLYTIE_11851522067983621366)],
        &[(0b00001, &ENTRY_CLYTIE_11851522067983621366)],
    ],
    range: 3..=4,
};

static VARS_CLO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLO_CHILDREN),
    value: None,
};

pub static VARS_CLO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ete"),
        dictgen::InsensitiveStr::Ascii("wer"),
        dictgen::InsensitiveStr::Ascii("wre"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CLETE_1876197067502328027)],
        &[(0b00001, &ENTRY_CLOWER_9225698487842396572)],
        &[(0b11010, &ENTRY_CLOWER_9225698487842396572)],
    ],
    range: 3..=3,
};

static VARS_CLI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLI_CHILDREN),
    value: None,
};

pub static VARS_CLI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CLIMATIZE_3452063415630301254)],
        &[(0b10010, &ENTRY_CLIMATIZED_124773700894549172)],
        &[(0b10010, &ENTRY_CLIMATIZES_13429047652583201954)],
        &[(0b10010, &ENTRY_CLIMATIZING_4457168972427899649)],
        &[(0b01001, &ENTRY_CLIMATIZE_3452063415630301254)],
        &[(0b01001, &ENTRY_CLIMATIZED_124773700894549172)],
        &[(0b01001, &ENTRY_CLIMATIZES_13429047652583201954)],
        &[(0b01001, &ENTRY_CLIMATIZING_4457168972427899649)],
    ],
    range: 6..=8,
};

static VARS_CLE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLE_CHILDREN),
    value: None,
};

pub static VARS_CLE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ricalise"),
        dictgen::InsensitiveStr::Ascii("ricalises"),
        dictgen::InsensitiveStr::Ascii("ricalize"),
        dictgen::InsensitiveStr::Ascii("ricalizes"),
        dictgen::InsensitiveStr::Ascii("te"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CLERICALIZE_1865718535677694450)],
        &[(0b10010, &ENTRY_CLERICALIZES_8269477549000417569)],
        &[(0b01001, &ENTRY_CLERICALIZE_1865718535677694450)],
        &[(0b01001, &ENTRY_CLERICALIZES_8269477549000417569)],
        &[(0b00001, &ENTRY_CLETE_1876197067502328027)],
    ],
    range: 2..=9,
};

static VARS_CLA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CLA_CHILDREN),
    value: None,
};

pub static VARS_CLA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("mor"),
        dictgen::InsensitiveStr::Ascii("mored"),
        dictgen::InsensitiveStr::Ascii("morer"),
        dictgen::InsensitiveStr::Ascii("morers"),
        dictgen::InsensitiveStr::Ascii("moring"),
        dictgen::InsensitiveStr::Ascii("morist"),
        dictgen::InsensitiveStr::Ascii("mors"),
        dictgen::InsensitiveStr::Ascii("morsome"),
        dictgen::InsensitiveStr::Ascii("mour"),
        dictgen::InsensitiveStr::Ascii("moured"),
        dictgen::InsensitiveStr::Ascii("mourer"),
        dictgen::InsensitiveStr::Ascii("mourers"),
        dictgen::InsensitiveStr::Ascii("mouring"),
        dictgen::InsensitiveStr::Ascii("mourist"),
        dictgen::InsensitiveStr::Ascii("mours"),
        dictgen::InsensitiveStr::Ascii("moursome"),
        dictgen::InsensitiveStr::Ascii("ngor"),
        dictgen::InsensitiveStr::Ascii("ngored"),
        dictgen::InsensitiveStr::Ascii("ngoring"),
        dictgen::InsensitiveStr::Ascii("ngors"),
        dictgen::InsensitiveStr::Ascii("ngour"),
        dictgen::InsensitiveStr::Ascii("ngoured"),
        dictgen::InsensitiveStr::Ascii("ngouring"),
        dictgen::InsensitiveStr::Ascii("ngours"),
        dictgen::InsensitiveStr::Ascii("res"),
        dictgen::InsensitiveStr::Ascii("rinetist"),
        dictgen::InsensitiveStr::Ascii("rinetists"),
        dictgen::InsensitiveStr::Ascii("rinettist"),
        dictgen::InsensitiveStr::Ascii("rinettists"),
        dictgen::InsensitiveStr::Ascii("roes"),
        dictgen::InsensitiveStr::Ascii("ssicalise"),
        dictgen::InsensitiveStr::Ascii("ssicalises"),
        dictgen::InsensitiveStr::Ascii("ssicalize"),
        dictgen::InsensitiveStr::Ascii("ssicalizes"),
        dictgen::InsensitiveStr::Ascii("ssicisation"),
        dictgen::InsensitiveStr::Ascii("ssicise"),
        dictgen::InsensitiveStr::Ascii("ssicised"),
        dictgen::InsensitiveStr::Ascii("ssicises"),
        dictgen::InsensitiveStr::Ascii("ssicising"),
        dictgen::InsensitiveStr::Ascii("ssicization"),
        dictgen::InsensitiveStr::Ascii("ssicize"),
        dictgen::InsensitiveStr::Ascii("ssicized"),
        dictgen::InsensitiveStr::Ascii("ssicizes"),
        dictgen::InsensitiveStr::Ascii("ssicizing"),
        dictgen::InsensitiveStr::Ascii("usulae"),
        dictgen::InsensitiveStr::Ascii("usule"),
    ],
    values: &[
        &[(0b11001, &ENTRY_CLAMOR_11722915000424769718)],
        &[(0b11001, &ENTRY_CLAMORED_4631300413281563513)],
        &[(0b11001, &ENTRY_CLAMORER_17883337748457044767)],
        &[(0b11001, &ENTRY_CLAMORERS_15362052334359174240)],
        &[(0b11001, &ENTRY_CLAMORING_5415785372025381455)],
        &[(0b00001, &ENTRY_CLAMORIST_16325759197501191896)],
        &[(0b11001, &ENTRY_CLAMORS_2773887349084725873)],
        &[(0b11001, &ENTRY_CLAMORSOME_7681677003017063573)],
        &[(0b11010, &ENTRY_CLAMOR_11722915000424769718)],
        &[(0b11010, &ENTRY_CLAMORED_4631300413281563513)],
        &[(0b11010, &ENTRY_CLAMORER_17883337748457044767)],
        &[(0b11010, &ENTRY_CLAMORERS_15362052334359174240)],
        &[(0b11010, &ENTRY_CLAMORING_5415785372025381455)],
        &[(0b11010, &ENTRY_CLAMORIST_16325759197501191896)],
        &[(0b11010, &ENTRY_CLAMORS_2773887349084725873)],
        &[(0b11010, &ENTRY_CLAMORSOME_7681677003017063573)],
        &[(0b11001, &ENTRY_CLANGOR_11515055037441300100)],
        &[(0b11001, &ENTRY_CLANGORED_15084752842311792542)],
        &[(0b11001, &ENTRY_CLANGORING_14458664811220315605)],
        &[(0b11001, &ENTRY_CLANGORS_14016497850837852764)],
        &[(0b11010, &ENTRY_CLANGOR_11515055037441300100)],
        &[(0b11010, &ENTRY_CLANGORED_15084752842311792542)],
        &[(0b11010, &ENTRY_CLANGORING_14458664811220315605)],
        &[(0b11010, &ENTRY_CLANGORS_14016497850837852764)],
        &[(0b00001, &ENTRY_CLARES_1731306513503085955)],
        &[(0b01001, &ENTRY_CLARINETIST_8834681667523453854)],
        &[(0b01001, &ENTRY_CLARINETISTS_8097106053649523838)],
        &[(0b10011, &ENTRY_CLARINETIST_8834681667523453854)],
        &[(0b10011, &ENTRY_CLARINETISTS_8097106053649523838)],
        &[(0b11010, &ENTRY_CLARES_1731306513503085955)],
        &[(0b10010, &ENTRY_CLASSICALIZE_7168633238933548715)],
        &[(0b10010, &ENTRY_CLASSICALIZES_2442176202643132547)],
        &[(0b01001, &ENTRY_CLASSICALIZE_7168633238933548715)],
        &[(0b01001, &ENTRY_CLASSICALIZES_2442176202643132547)],
        &[(0b10010, &ENTRY_CLASSICIZATION_4974218833361429454)],
        &[(0b10010, &ENTRY_CLASSICIZE_6847726068049490278)],
        &[(0b10010, &ENTRY_CLASSICIZED_11040640355679759136)],
        &[(0b10010, &ENTRY_CLASSICIZES_7627137652355384645)],
        &[(0b10010, &ENTRY_CLASSICIZING_13143908142359497861)],
        &[(0b01001, &ENTRY_CLASSICIZATION_4974218833361429454)],
        &[(0b01001, &ENTRY_CLASSICIZE_6847726068049490278)],
        &[(0b01001, &ENTRY_CLASSICIZED_11040640355679759136)],
        &[(0b01001, &ENTRY_CLASSICIZES_7627137652355384645)],
        &[(0b01001, &ENTRY_CLASSICIZING_13143908142359497861)],
        &[(0b11010, &ENTRY_CLAUSULE_67200534337080796)],
        &[(0b00001, &ENTRY_CLAUSULE_67200534337080796)],
    ],
    range: 3..=11,
};

static VARS_CI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CI_CHILDREN),
    value: None,
};

static VARS_CI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CIC_NODE),
    None,
    None,
    None,
    Some(&VARS_CIG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CIM_NODE),
    Some(&VARS_CIN_NODE),
    None,
    None,
    None,
    Some(&VARS_CIR_NODE),
    Some(&VARS_CIS_NODE),
    Some(&VARS_CIT_NODE),
    None,
    Some(&VARS_CIV_NODE),
    None,
    None,
    None,
    Some(&VARS_CIZ_NODE),
];

static VARS_CIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIZ_CHILDREN),
    value: None,
};

pub static VARS_CIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b01001, &ENTRY_CIZE_6818406889408576007)]],
    range: 1..=1,
};

static VARS_CIV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIV_CHILDREN),
    value: None,
};

pub static VARS_CIV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ilianisation"),
        dictgen::InsensitiveStr::Ascii("ilianisations"),
        dictgen::InsensitiveStr::Ascii("ilianise"),
        dictgen::InsensitiveStr::Ascii("ilianised"),
        dictgen::InsensitiveStr::Ascii("ilianises"),
        dictgen::InsensitiveStr::Ascii("ilianising"),
        dictgen::InsensitiveStr::Ascii("ilianization"),
        dictgen::InsensitiveStr::Ascii("ilianizations"),
        dictgen::InsensitiveStr::Ascii("ilianize"),
        dictgen::InsensitiveStr::Ascii("ilianized"),
        dictgen::InsensitiveStr::Ascii("ilianizes"),
        dictgen::InsensitiveStr::Ascii("ilianizing"),
        dictgen::InsensitiveStr::Ascii("ilisable"),
        dictgen::InsensitiveStr::Ascii("ilisabler"),
        dictgen::InsensitiveStr::Ascii("ilisables"),
        dictgen::InsensitiveStr::Ascii("ilisablest"),
        dictgen::InsensitiveStr::Ascii("ilisation"),
        dictgen::InsensitiveStr::Ascii("ilisational"),
        dictgen::InsensitiveStr::Ascii("ilisationaler"),
        dictgen::InsensitiveStr::Ascii("ilisationalest"),
        dictgen::InsensitiveStr::Ascii("ilisationals"),
        dictgen::InsensitiveStr::Ascii("ilisations"),
        dictgen::InsensitiveStr::Ascii("ilisatory"),
        dictgen::InsensitiveStr::Ascii("ilise"),
        dictgen::InsensitiveStr::Ascii("ilised"),
        dictgen::InsensitiveStr::Ascii("ilisedness"),
        dictgen::InsensitiveStr::Ascii("ilisednesses"),
        dictgen::InsensitiveStr::Ascii("iliser"),
        dictgen::InsensitiveStr::Ascii("ilisers"),
        dictgen::InsensitiveStr::Ascii("ilises"),
        dictgen::InsensitiveStr::Ascii("ilising"),
        dictgen::InsensitiveStr::Ascii("ilizable"),
        dictgen::InsensitiveStr::Ascii("ilizabler"),
        dictgen::InsensitiveStr::Ascii("ilizables"),
        dictgen::InsensitiveStr::Ascii("ilizablest"),
        dictgen::InsensitiveStr::Ascii("ilization"),
        dictgen::InsensitiveStr::Ascii("ilizational"),
        dictgen::InsensitiveStr::Ascii("ilizationaler"),
        dictgen::InsensitiveStr::Ascii("ilizationalest"),
        dictgen::InsensitiveStr::Ascii("ilizationals"),
        dictgen::InsensitiveStr::Ascii("ilizations"),
        dictgen::InsensitiveStr::Ascii("ilizatory"),
        dictgen::InsensitiveStr::Ascii("ilize"),
        dictgen::InsensitiveStr::Ascii("ilized"),
        dictgen::InsensitiveStr::Ascii("ilizedness"),
        dictgen::InsensitiveStr::Ascii("ilizednesses"),
        dictgen::InsensitiveStr::Ascii("ilizer"),
        dictgen::InsensitiveStr::Ascii("ilizers"),
        dictgen::InsensitiveStr::Ascii("ilizes"),
        dictgen::InsensitiveStr::Ascii("ilizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CIVILIANIZATION_17575505866978524289)],
        &[(0b10010, &ENTRY_CIVILIANIZATIONS_17045136972884179633)],
        &[(0b10010, &ENTRY_CIVILIANIZE_4503116173799461974)],
        &[(0b10010, &ENTRY_CIVILIANIZED_15443763184741606790)],
        &[(0b10010, &ENTRY_CIVILIANIZES_1873437655700489131)],
        &[(0b10010, &ENTRY_CIVILIANIZING_10886647865038667032)],
        &[(0b01001, &ENTRY_CIVILIANIZATION_17575505866978524289)],
        &[(0b01001, &ENTRY_CIVILIANIZATIONS_17045136972884179633)],
        &[(0b01001, &ENTRY_CIVILIANIZE_4503116173799461974)],
        &[(0b01001, &ENTRY_CIVILIANIZED_15443763184741606790)],
        &[(0b01001, &ENTRY_CIVILIANIZES_1873437655700489131)],
        &[(0b01001, &ENTRY_CIVILIANIZING_10886647865038667032)],
        &[(0b10010, &ENTRY_CIVILIZABLE_12250954830034270586)],
        &[(0b10010, &ENTRY_CIVILIZABLER_1009443025003033054)],
        &[(0b10010, &ENTRY_CIVILIZABLES_6992110506684451627)],
        &[(0b10010, &ENTRY_CIVILIZABLEST_10363624488321164576)],
        &[(0b10010, &ENTRY_CIVILIZATION_15013403646640920675)],
        &[(0b10010, &ENTRY_CIVILIZATIONAL_6714937636315886610)],
        &[(0b10010, &ENTRY_CIVILIZATIONALER_2223864160765042134)],
        &[(0b10010, &ENTRY_CIVILIZATIONALEST_8468211002452117483)],
        &[(0b10010, &ENTRY_CIVILIZATIONALS_16890543284368506921)],
        &[(0b10010, &ENTRY_CIVILIZATIONS_10559611739235699948)],
        &[(0b10010, &ENTRY_CIVILIZATORY_1986047737625317948)],
        &[(0b10010, &ENTRY_CIVILIZE_11305300708024681316)],
        &[(0b10010, &ENTRY_CIVILIZED_12545974517817432534)],
        &[(0b10010, &ENTRY_CIVILIZEDNESS_8991979933830574813)],
        &[(0b10010, &ENTRY_CIVILIZEDNESSES_12980539923790842297)],
        &[(0b10010, &ENTRY_CIVILIZER_6543816336610065762)],
        &[(0b10010, &ENTRY_CIVILIZERS_15636793990348820949)],
        &[(0b10010, &ENTRY_CIVILIZES_10418281941070358506)],
        &[(0b10010, &ENTRY_CIVILIZING_14404215502589538333)],
        &[(0b01001, &ENTRY_CIVILIZABLE_12250954830034270586)],
        &[(0b01001, &ENTRY_CIVILIZABLER_1009443025003033054)],
        &[(0b01001, &ENTRY_CIVILIZABLES_6992110506684451627)],
        &[(0b01001, &ENTRY_CIVILIZABLEST_10363624488321164576)],
        &[(0b01001, &ENTRY_CIVILIZATION_15013403646640920675)],
        &[(0b01001, &ENTRY_CIVILIZATIONAL_6714937636315886610)],
        &[(0b01001, &ENTRY_CIVILIZATIONALER_2223864160765042134)],
        &[(0b01001, &ENTRY_CIVILIZATIONALEST_8468211002452117483)],
        &[(0b01001, &ENTRY_CIVILIZATIONALS_16890543284368506921)],
        &[(0b01001, &ENTRY_CIVILIZATIONS_10559611739235699948)],
        &[(0b01001, &ENTRY_CIVILIZATORY_1986047737625317948)],
        &[(0b01001, &ENTRY_CIVILIZE_11305300708024681316)],
        &[(0b01001, &ENTRY_CIVILIZED_12545974517817432534)],
        &[(0b01001, &ENTRY_CIVILIZEDNESS_8991979933830574813)],
        &[(0b01001, &ENTRY_CIVILIZEDNESSES_12980539923790842297)],
        &[(0b01001, &ENTRY_CIVILIZER_6543816336610065762)],
        &[(0b01001, &ENTRY_CIVILIZERS_15636793990348820949)],
        &[(0b01001, &ENTRY_CIVILIZES_10418281941070358506)],
        &[(0b01001, &ENTRY_CIVILIZING_14404215502589538333)],
    ],
    range: 5..=14,
};

static VARS_CIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIT_CHILDREN),
    value: None,
};

pub static VARS_CIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hern"),
        dictgen::InsensitiveStr::Ascii("herns"),
        dictgen::InsensitiveStr::Ascii("hren"),
        dictgen::InsensitiveStr::Ascii("hrens"),
        dictgen::InsensitiveStr::Ascii("izenise"),
        dictgen::InsensitiveStr::Ascii("izenised"),
        dictgen::InsensitiveStr::Ascii("izenises"),
        dictgen::InsensitiveStr::Ascii("izenising"),
        dictgen::InsensitiveStr::Ascii("izenize"),
        dictgen::InsensitiveStr::Ascii("izenized"),
        dictgen::InsensitiveStr::Ascii("izenizes"),
        dictgen::InsensitiveStr::Ascii("izenizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CITHERN_6627389279929637643)],
        &[(0b00001, &ENTRY_CITHERNS_14301574885087358999)],
        &[(0b11010, &ENTRY_CITHERN_6627389279929637643)],
        &[(0b11010, &ENTRY_CITHERNS_14301574885087358999)],
        &[(0b10010, &ENTRY_CITIZENIZE_14957512849570966194)],
        &[(0b10010, &ENTRY_CITIZENIZED_1264772045676693507)],
        &[(0b10010, &ENTRY_CITIZENIZES_18430750407999070293)],
        &[(0b10010, &ENTRY_CITIZENIZING_4863665565831279155)],
        &[(0b01001, &ENTRY_CITIZENIZE_14957512849570966194)],
        &[(0b01001, &ENTRY_CITIZENIZED_1264772045676693507)],
        &[(0b01001, &ENTRY_CITIZENIZES_18430750407999070293)],
        &[(0b01001, &ENTRY_CITIZENIZING_4863665565831279155)],
    ],
    range: 4..=9,
};

static VARS_CIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIS_CHILDREN),
    value: None,
};

pub static VARS_CIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("e")],
    values: &[&[(0b10010, &ENTRY_CIZE_6818406889408576007)]],
    range: 1..=1,
};

static VARS_CIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIR_CHILDREN),
    value: None,
};

pub static VARS_CIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("caean"),
        dictgen::InsensitiveStr::Ascii("cean"),
        dictgen::InsensitiveStr::Ascii("cularisation"),
        dictgen::InsensitiveStr::Ascii("cularisations"),
        dictgen::InsensitiveStr::Ascii("cularise"),
        dictgen::InsensitiveStr::Ascii("cularised"),
        dictgen::InsensitiveStr::Ascii("culariser"),
        dictgen::InsensitiveStr::Ascii("cularisers"),
        dictgen::InsensitiveStr::Ascii("cularises"),
        dictgen::InsensitiveStr::Ascii("cularising"),
        dictgen::InsensitiveStr::Ascii("cularization"),
        dictgen::InsensitiveStr::Ascii("cularizations"),
        dictgen::InsensitiveStr::Ascii("cularize"),
        dictgen::InsensitiveStr::Ascii("cularized"),
        dictgen::InsensitiveStr::Ascii("cularizer"),
        dictgen::InsensitiveStr::Ascii("cularizers"),
        dictgen::InsensitiveStr::Ascii("cularizes"),
        dictgen::InsensitiveStr::Ascii("cularizing"),
        dictgen::InsensitiveStr::Ascii("cumcenter"),
        dictgen::InsensitiveStr::Ascii("cumcenters"),
        dictgen::InsensitiveStr::Ascii("cumcentre"),
        dictgen::InsensitiveStr::Ascii("cumcentres"),
        dictgen::InsensitiveStr::Ascii("cumesophagal"),
        dictgen::InsensitiveStr::Ascii("cumoesophagal"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CIRCEAN_2837826078225645071)],
        &[(0b00001, &ENTRY_CIRCEAN_2837826078225645071)],
        &[(0b10010, &ENTRY_CIRCULARIZATION_17838622241027218582)],
        &[(0b10010, &ENTRY_CIRCULARIZATIONS_1984387235149986914)],
        &[(0b10010, &ENTRY_CIRCULARIZE_168549599908464304)],
        &[(0b10010, &ENTRY_CIRCULARIZED_17077855093521846327)],
        &[(0b10010, &ENTRY_CIRCULARIZER_10781935971896485951)],
        &[(0b10010, &ENTRY_CIRCULARIZERS_9484517890337368712)],
        &[(0b10010, &ENTRY_CIRCULARIZES_5373385699289469463)],
        &[(0b10010, &ENTRY_CIRCULARIZING_13000180152805667363)],
        &[(0b01001, &ENTRY_CIRCULARIZATION_17838622241027218582)],
        &[(0b01001, &ENTRY_CIRCULARIZATIONS_1984387235149986914)],
        &[(0b01001, &ENTRY_CIRCULARIZE_168549599908464304)],
        &[(0b01001, &ENTRY_CIRCULARIZED_17077855093521846327)],
        &[(0b01001, &ENTRY_CIRCULARIZER_10781935971896485951)],
        &[(0b01001, &ENTRY_CIRCULARIZERS_9484517890337368712)],
        &[(0b01001, &ENTRY_CIRCULARIZES_5373385699289469463)],
        &[(0b01001, &ENTRY_CIRCULARIZING_13000180152805667363)],
        &[(0b00001, &ENTRY_CIRCUMCENTER_207116320690761995)],
        &[(0b00001, &ENTRY_CIRCUMCENTERS_3631459482063575085)],
        &[(0b11010, &ENTRY_CIRCUMCENTER_207116320690761995)],
        &[(0b11010, &ENTRY_CIRCUMCENTERS_3631459482063575085)],
        &[(0b00001, &ENTRY_CIRCUMESOPHAGAL_14446114158922149948)],
        &[(0b11010, &ENTRY_CIRCUMESOPHAGAL_14446114158922149948)],
    ],
    range: 4..=13,
};

static VARS_CIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIN_CHILDREN),
    value: None,
};

pub static VARS_CIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chonisation"),
        dictgen::InsensitiveStr::Ascii("chonisations"),
        dictgen::InsensitiveStr::Ascii("chonise"),
        dictgen::InsensitiveStr::Ascii("chonised"),
        dictgen::InsensitiveStr::Ascii("chonises"),
        dictgen::InsensitiveStr::Ascii("chonising"),
        dictgen::InsensitiveStr::Ascii("chonization"),
        dictgen::InsensitiveStr::Ascii("chonizations"),
        dictgen::InsensitiveStr::Ascii("chonize"),
        dictgen::InsensitiveStr::Ascii("chonized"),
        dictgen::InsensitiveStr::Ascii("chonizes"),
        dictgen::InsensitiveStr::Ascii("chonizing"),
        dictgen::InsensitiveStr::Ascii("ematise"),
        dictgen::InsensitiveStr::Ascii("ematize"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CINCHONIZATION_10888105560110104460)],
        &[(0b10010, &ENTRY_CINCHONIZATIONS_6677879833142170709)],
        &[(0b10010, &ENTRY_CINCHONIZE_14048235966165265995)],
        &[(0b10010, &ENTRY_CINCHONIZED_1697201765172263780)],
        &[(0b10010, &ENTRY_CINCHONIZES_1522582946661651319)],
        &[(0b10010, &ENTRY_CINCHONIZING_12181226423066017076)],
        &[(0b01001, &ENTRY_CINCHONIZATION_10888105560110104460)],
        &[(0b01001, &ENTRY_CINCHONIZATIONS_6677879833142170709)],
        &[(0b01001, &ENTRY_CINCHONIZE_14048235966165265995)],
        &[(0b01001, &ENTRY_CINCHONIZED_1697201765172263780)],
        &[(0b01001, &ENTRY_CINCHONIZES_1522582946661651319)],
        &[(0b01001, &ENTRY_CINCHONIZING_12181226423066017076)],
        &[(0b10010, &ENTRY_CINEMATIZE_14141234202546792174)],
        &[(0b01001, &ENTRY_CINEMATIZE_14141234202546792174)],
        &[(0b00001, &ENTRY_CINTER_5255881384560882873)],
        &[(0b11010, &ENTRY_CINTER_5255881384560882873)],
    ],
    range: 3..=12,
};

static VARS_CIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIM_CHILDREN),
    value: None,
};

pub static VARS_CIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icidae"),
        dictgen::InsensitiveStr::Ascii("icide"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CIMICIDE_252691567770959002)],
        &[(0b00001, &ENTRY_CIMICIDE_252691567770959002)],
    ],
    range: 5..=6,
};

static VARS_CIG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIG_CHILDREN),
    value: None,
};

pub static VARS_CIG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aret"),
        dictgen::InsensitiveStr::Ascii("arets"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CIGARETTE_3240954964785468511)],
        &[(0b00001, &ENTRY_CIGARETTES_2896249679667819882)],
    ],
    range: 4..=5,
};

static VARS_CIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CIC_CHILDREN),
    value: None,
};

pub static VARS_CIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atriculae"),
        dictgen::InsensitiveStr::Ascii("atricule"),
        dictgen::InsensitiveStr::Ascii("atrisant"),
        dictgen::InsensitiveStr::Ascii("atrisate"),
        dictgen::InsensitiveStr::Ascii("atrisation"),
        dictgen::InsensitiveStr::Ascii("atrisations"),
        dictgen::InsensitiveStr::Ascii("atrise"),
        dictgen::InsensitiveStr::Ascii("atrised"),
        dictgen::InsensitiveStr::Ascii("atriser"),
        dictgen::InsensitiveStr::Ascii("atrises"),
        dictgen::InsensitiveStr::Ascii("atrising"),
        dictgen::InsensitiveStr::Ascii("atrixes"),
        dictgen::InsensitiveStr::Ascii("atrizant"),
        dictgen::InsensitiveStr::Ascii("atrizate"),
        dictgen::InsensitiveStr::Ascii("atrization"),
        dictgen::InsensitiveStr::Ascii("atrizations"),
        dictgen::InsensitiveStr::Ascii("atrize"),
        dictgen::InsensitiveStr::Ascii("atrized"),
        dictgen::InsensitiveStr::Ascii("atrizer"),
        dictgen::InsensitiveStr::Ascii("atrizes"),
        dictgen::InsensitiveStr::Ascii("atrizing"),
        dictgen::InsensitiveStr::Ascii("eronianise"),
        dictgen::InsensitiveStr::Ascii("eronianises"),
        dictgen::InsensitiveStr::Ascii("eronianize"),
        dictgen::InsensitiveStr::Ascii("eronianizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CICATRICULE_5186934031307821263)],
        &[(0b00001, &ENTRY_CICATRICULE_5186934031307821263)],
        &[(0b10010, &ENTRY_CICATRIZANT_12486636820913979450)],
        &[(0b10010, &ENTRY_CICATRIZATE_4590503640777088427)],
        &[(0b10010, &ENTRY_CICATRIZATION_12095729010218257569)],
        &[(0b10010, &ENTRY_CICATRIZATIONS_18248179778439022462)],
        &[(0b10010, &ENTRY_CICATRIZE_17449239625442097002)],
        &[(0b10010, &ENTRY_CICATRIZED_1926551778073289264)],
        &[(0b10010, &ENTRY_CICATRIZER_13415710374354046728)],
        &[(0b10010, &ENTRY_CICATRIZES_18063560548351573209)],
        &[(0b10010, &ENTRY_CICATRIZING_13257780105810264437)],
        &[(0b00001, &ENTRY_CICATRICES_6326588841275377818)],
        &[(0b01001, &ENTRY_CICATRIZANT_12486636820913979450)],
        &[(0b01001, &ENTRY_CICATRIZATE_4590503640777088427)],
        &[(0b01001, &ENTRY_CICATRIZATION_12095729010218257569)],
        &[(0b01001, &ENTRY_CICATRIZATIONS_18248179778439022462)],
        &[(0b01001, &ENTRY_CICATRIZE_17449239625442097002)],
        &[(0b01001, &ENTRY_CICATRIZED_1926551778073289264)],
        &[(0b01001, &ENTRY_CICATRIZER_13415710374354046728)],
        &[(0b01001, &ENTRY_CICATRIZES_18063560548351573209)],
        &[(0b01001, &ENTRY_CICATRIZING_13257780105810264437)],
        &[(0b10010, &ENTRY_CICERONIANIZE_15017821268740384544)],
        &[(0b10010, &ENTRY_CICERONIANIZES_12944202395538543019)],
        &[(0b01001, &ENTRY_CICERONIANIZE_15017821268740384544)],
        &[(0b01001, &ENTRY_CICERONIANIZES_12944202395538543019)],
    ],
    range: 6..=11,
};

static VARS_CH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CH_CHILDREN),
    value: None,
};

static VARS_CH_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CHA_NODE),
    None,
    None,
    None,
    Some(&VARS_CHE_NODE),
    None,
    None,
    None,
    Some(&VARS_CHI_NODE),
    None,
    None,
    Some(&VARS_CHL_NODE),
    None,
    None,
    Some(&VARS_CHO_NODE),
    None,
    None,
    Some(&VARS_CHR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CHR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHR_CHILDREN),
    value: None,
};

pub static VARS_CHR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("istianisation"),
        dictgen::InsensitiveStr::Ascii("istianisations"),
        dictgen::InsensitiveStr::Ascii("istianise"),
        dictgen::InsensitiveStr::Ascii("istianised"),
        dictgen::InsensitiveStr::Ascii("istianiser"),
        dictgen::InsensitiveStr::Ascii("istianisers"),
        dictgen::InsensitiveStr::Ascii("istianises"),
        dictgen::InsensitiveStr::Ascii("istianising"),
        dictgen::InsensitiveStr::Ascii("istianization"),
        dictgen::InsensitiveStr::Ascii("istianizations"),
        dictgen::InsensitiveStr::Ascii("istianize"),
        dictgen::InsensitiveStr::Ascii("istianized"),
        dictgen::InsensitiveStr::Ascii("istianizer"),
        dictgen::InsensitiveStr::Ascii("istianizers"),
        dictgen::InsensitiveStr::Ascii("istianizes"),
        dictgen::InsensitiveStr::Ascii("istianizing"),
        dictgen::InsensitiveStr::Ascii("omaesthesia"),
        dictgen::InsensitiveStr::Ascii("omatise"),
        dictgen::InsensitiveStr::Ascii("omatises"),
        dictgen::InsensitiveStr::Ascii("omatize"),
        dictgen::InsensitiveStr::Ascii("omatizes"),
        dictgen::InsensitiveStr::Ascii("omesthesia"),
        dictgen::InsensitiveStr::Ascii("omicise"),
        dictgen::InsensitiveStr::Ascii("omicises"),
        dictgen::InsensitiveStr::Ascii("omicize"),
        dictgen::InsensitiveStr::Ascii("omicizes"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("omizing"),
        dictgen::InsensitiveStr::Ascii("onologise"),
        dictgen::InsensitiveStr::Ascii("onologised"),
        dictgen::InsensitiveStr::Ascii("onologises"),
        dictgen::InsensitiveStr::Ascii("onologising"),
        dictgen::InsensitiveStr::Ascii("onologize"),
        dictgen::InsensitiveStr::Ascii("onologized"),
        dictgen::InsensitiveStr::Ascii("onologizes"),
        dictgen::InsensitiveStr::Ascii("onologizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHRISTIANIZATION_18360975039569708955)],
        &[(0b10010, &ENTRY_CHRISTIANIZATIONS_939157464750574119)],
        &[(0b10010, &ENTRY_CHRISTIANIZE_17043173566737823874)],
        &[(0b10010, &ENTRY_CHRISTIANIZED_2305498091852997860)],
        &[(0b10010, &ENTRY_CHRISTIANIZER_12661100042100507791)],
        &[(0b10010, &ENTRY_CHRISTIANIZERS_2108724649580713236)],
        &[(0b10010, &ENTRY_CHRISTIANIZES_14805680753012611713)],
        &[(0b10010, &ENTRY_CHRISTIANIZING_3955473617595650674)],
        &[(0b01001, &ENTRY_CHRISTIANIZATION_18360975039569708955)],
        &[(0b01001, &ENTRY_CHRISTIANIZATIONS_939157464750574119)],
        &[(0b01001, &ENTRY_CHRISTIANIZE_17043173566737823874)],
        &[(0b01001, &ENTRY_CHRISTIANIZED_2305498091852997860)],
        &[(0b01001, &ENTRY_CHRISTIANIZER_12661100042100507791)],
        &[(0b01001, &ENTRY_CHRISTIANIZERS_2108724649580713236)],
        &[(0b01001, &ENTRY_CHRISTIANIZES_14805680753012611713)],
        &[(0b01001, &ENTRY_CHRISTIANIZING_3955473617595650674)],
        &[(0b11010, &ENTRY_CHROMESTHESIA_3768057935676918572)],
        &[(0b10010, &ENTRY_CHROMATIZE_11372633214051605374)],
        &[(0b10010, &ENTRY_CHROMATIZES_8188945171625541176)],
        &[(0b01001, &ENTRY_CHROMATIZE_11372633214051605374)],
        &[(0b01001, &ENTRY_CHROMATIZES_8188945171625541176)],
        &[(0b00001, &ENTRY_CHROMESTHESIA_3768057935676918572)],
        &[(0b10010, &ENTRY_CHROMICIZE_2411849466836240319)],
        &[(0b10010, &ENTRY_CHROMICIZES_17571169233071174152)],
        &[(0b01001, &ENTRY_CHROMICIZE_2411849466836240319)],
        &[(0b01001, &ENTRY_CHROMICIZES_17571169233071174152)],
        &[(0b10010, &ENTRY_CHROMIZE_5262872595657112785)],
        &[(0b10010, &ENTRY_CHROMIZED_10186147401749465104)],
        &[(0b10010, &ENTRY_CHROMIZES_15865986984042622696)],
        &[(0b10010, &ENTRY_CHROMIZING_1826459851914480574)],
        &[(0b01001, &ENTRY_CHROMIZE_5262872595657112785)],
        &[(0b01001, &ENTRY_CHROMIZED_10186147401749465104)],
        &[(0b01001, &ENTRY_CHROMIZES_15865986984042622696)],
        &[(0b01001, &ENTRY_CHROMIZING_1826459851914480574)],
        &[(0b10010, &ENTRY_CHRONOLOGIZE_12846965199938511954)],
        &[(0b10010, &ENTRY_CHRONOLOGIZED_5845452320056255894)],
        &[(0b10010, &ENTRY_CHRONOLOGIZES_11841064468767540761)],
        &[(0b10010, &ENTRY_CHRONOLOGIZING_3430096775276619170)],
        &[(0b01001, &ENTRY_CHRONOLOGIZE_12846965199938511954)],
        &[(0b01001, &ENTRY_CHRONOLOGIZED_5845452320056255894)],
        &[(0b01001, &ENTRY_CHRONOLOGIZES_11841064468767540761)],
        &[(0b01001, &ENTRY_CHRONOLOGIZING_3430096775276619170)],
    ],
    range: 5..=14,
};

static VARS_CHO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHO_CHILDREN),
    value: None,
};

pub static VARS_CHO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aephori"),
        dictgen::InsensitiveStr::Ascii("enix"),
        dictgen::InsensitiveStr::Ascii("enixes"),
        dictgen::InsensitiveStr::Ascii("ephori"),
        dictgen::InsensitiveStr::Ascii("laemia"),
        dictgen::InsensitiveStr::Ascii("laemias"),
        dictgen::InsensitiveStr::Ascii("lemia"),
        dictgen::InsensitiveStr::Ascii("lemias"),
        dictgen::InsensitiveStr::Ascii("lophaein"),
        dictgen::InsensitiveStr::Ascii("lophein"),
        dictgen::InsensitiveStr::Ascii("risation"),
        dictgen::InsensitiveStr::Ascii("risations"),
        dictgen::InsensitiveStr::Ascii("rization"),
        dictgen::InsensitiveStr::Ascii("rizations"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CHOEPHORI_13897909648270625076)],
        &[(0b11010, &ENTRY_CHENIX_6890496202644655006)],
        &[(0b11010, &ENTRY_CHENIXES_18140842653808609264)],
        &[(0b00001, &ENTRY_CHOEPHORI_13897909648270625076)],
        &[(0b11010, &ENTRY_CHOLEMIA_10472935038101851986)],
        &[(0b11010, &ENTRY_CHOLEMIAS_1320999302245492995)],
        &[(0b00001, &ENTRY_CHOLEMIA_10472935038101851986)],
        &[(0b00001, &ENTRY_CHOLEMIAS_1320999302245492995)],
        &[(0b11010, &ENTRY_CHOLOPHEIN_3609148772555478472)],
        &[(0b00001, &ENTRY_CHOLOPHEIN_3609148772555478472)],
        &[(0b10010, &ENTRY_CHORIZATION_2744114980681106174)],
        &[(0b10010, &ENTRY_CHORIZATIONS_15797795758878758614)],
        &[(0b01001, &ENTRY_CHORIZATION_2744114980681106174)],
        &[(0b01001, &ENTRY_CHORIZATIONS_15797795758878758614)],
    ],
    range: 4..=9,
};

static VARS_CHL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHL_CHILDREN),
    value: None,
};

pub static VARS_CHL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oraemia"),
        dictgen::InsensitiveStr::Ascii("oranaemia"),
        dictgen::InsensitiveStr::Ascii("oranemia"),
        dictgen::InsensitiveStr::Ascii("oremia"),
        dictgen::InsensitiveStr::Ascii("oridise"),
        dictgen::InsensitiveStr::Ascii("oridised"),
        dictgen::InsensitiveStr::Ascii("oridises"),
        dictgen::InsensitiveStr::Ascii("oridising"),
        dictgen::InsensitiveStr::Ascii("oridize"),
        dictgen::InsensitiveStr::Ascii("oridized"),
        dictgen::InsensitiveStr::Ascii("oridizes"),
        dictgen::InsensitiveStr::Ascii("oridizing"),
        dictgen::InsensitiveStr::Ascii("orinise"),
        dictgen::InsensitiveStr::Ascii("orinised"),
        dictgen::InsensitiveStr::Ascii("orinises"),
        dictgen::InsensitiveStr::Ascii("orinising"),
        dictgen::InsensitiveStr::Ascii("orinize"),
        dictgen::InsensitiveStr::Ascii("orinized"),
        dictgen::InsensitiveStr::Ascii("orinizes"),
        dictgen::InsensitiveStr::Ascii("orinizing"),
        dictgen::InsensitiveStr::Ascii("oritisation"),
        dictgen::InsensitiveStr::Ascii("oritisations"),
        dictgen::InsensitiveStr::Ascii("oritization"),
        dictgen::InsensitiveStr::Ascii("oritizations"),
        dictgen::InsensitiveStr::Ascii("oroanaemia"),
        dictgen::InsensitiveStr::Ascii("oroanemia"),
        dictgen::InsensitiveStr::Ascii("oroformisation"),
        dictgen::InsensitiveStr::Ascii("oroformisations"),
        dictgen::InsensitiveStr::Ascii("oroformise"),
        dictgen::InsensitiveStr::Ascii("oroformises"),
        dictgen::InsensitiveStr::Ascii("oroformization"),
        dictgen::InsensitiveStr::Ascii("oroformizations"),
        dictgen::InsensitiveStr::Ascii("oroformize"),
        dictgen::InsensitiveStr::Ascii("oroformizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CHLOREMIA_11927970491263400748)],
        &[(0b11010, &ENTRY_CHLORANEMIA_14943573677886171490)],
        &[(0b10001, &ENTRY_CHLORANEMIA_14943573677886171490)],
        &[(0b10001, &ENTRY_CHLOREMIA_11927970491263400748)],
        &[(0b10010, &ENTRY_CHLORIDIZE_15852197382856458938)],
        &[(0b10010, &ENTRY_CHLORIDIZED_12549087814443170120)],
        &[(0b10010, &ENTRY_CHLORIDIZES_10968236782051706807)],
        &[(0b10010, &ENTRY_CHLORIDIZING_13412386735842532684)],
        &[(0b01001, &ENTRY_CHLORIDIZE_15852197382856458938)],
        &[(0b01001, &ENTRY_CHLORIDIZED_12549087814443170120)],
        &[(0b01001, &ENTRY_CHLORIDIZES_10968236782051706807)],
        &[(0b01001, &ENTRY_CHLORIDIZING_13412386735842532684)],
        &[(0b10010, &ENTRY_CHLORINIZE_4322542416170463875)],
        &[(0b10010, &ENTRY_CHLORINIZED_17584986266499508813)],
        &[(0b10010, &ENTRY_CHLORINIZES_6611213572390335959)],
        &[(0b10010, &ENTRY_CHLORINIZING_11381892907334769846)],
        &[(0b01001, &ENTRY_CHLORINIZE_4322542416170463875)],
        &[(0b01001, &ENTRY_CHLORINIZED_17584986266499508813)],
        &[(0b01001, &ENTRY_CHLORINIZES_6611213572390335959)],
        &[(0b01001, &ENTRY_CHLORINIZING_11381892907334769846)],
        &[(0b10010, &ENTRY_CHLORITIZATION_6329588467839471117)],
        &[(0b10010, &ENTRY_CHLORITIZATIONS_14114607753454173066)],
        &[(0b01001, &ENTRY_CHLORITIZATION_6329588467839471117)],
        &[(0b01001, &ENTRY_CHLORITIZATIONS_14114607753454173066)],
        &[(0b11010, &ENTRY_CHLOROANEMIA_6563825885243058247)],
        &[(0b10001, &ENTRY_CHLOROANEMIA_6563825885243058247)],
        &[(0b10010, &ENTRY_CHLOROFORMIZATION_18266136341140668534)],
        &[(0b10010, &ENTRY_CHLOROFORMIZATIONS_10258939630473669855)],
        &[(0b10010, &ENTRY_CHLOROFORMIZE_4267369403631594202)],
        &[(0b10010, &ENTRY_CHLOROFORMIZES_15872749603216002935)],
        &[(0b01001, &ENTRY_CHLOROFORMIZATION_18266136341140668534)],
        &[(0b01001, &ENTRY_CHLOROFORMIZATIONS_10258939630473669855)],
        &[(0b01001, &ENTRY_CHLOROFORMIZE_4267369403631594202)],
        &[(0b01001, &ENTRY_CHLOROFORMIZES_15872749603216002935)],
    ],
    range: 6..=15,
};

static VARS_CHI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHI_CHILDREN),
    value: None,
};

pub static VARS_CHI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ffer"),
        dictgen::InsensitiveStr::Ascii("ffre"),
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("ldre"),
        dictgen::InsensitiveStr::Ascii("le"),
        dictgen::InsensitiveStr::Ascii("les"),
        dictgen::InsensitiveStr::Ascii("li"),
        dictgen::InsensitiveStr::Ascii("lies"),
        dictgen::InsensitiveStr::Ascii("lis"),
        dictgen::InsensitiveStr::Ascii("lli"),
        dictgen::InsensitiveStr::Ascii("llies"),
        dictgen::InsensitiveStr::Ascii("maerid"),
        dictgen::InsensitiveStr::Ascii("maerids"),
        dictgen::InsensitiveStr::Ascii("maerism"),
        dictgen::InsensitiveStr::Ascii("maerisms"),
        dictgen::InsensitiveStr::Ascii("merid"),
        dictgen::InsensitiveStr::Ascii("merids"),
        dictgen::InsensitiveStr::Ascii("merism"),
        dictgen::InsensitiveStr::Ascii("merisms"),
        dictgen::InsensitiveStr::Ascii("seled"),
        dictgen::InsensitiveStr::Ascii("seler"),
        dictgen::InsensitiveStr::Ascii("selers"),
        dictgen::InsensitiveStr::Ascii("seling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CHIFFER_15730952033932406541)],
        &[(0b11010, &ENTRY_CHIFFER_15730952033932406541)],
        &[(0b00001, &ENTRY_CHILDER_1838168120264181115)],
        &[(0b11010, &ENTRY_CHILDER_1838168120264181115)],
        &[(0b01001, &ENTRY_CHILI_17288123216260222064)],
        &[(0b01001, &ENTRY_CHILIES_2805435102646559217)],
        &[(0b01001, &ENTRY_CHILI_17288123216260222064)],
        &[(0b01001, &ENTRY_CHILIES_2805435102646559217)],
        &[(0b00001, &ENTRY_CHILIES_2805435102646559217)],
        &[(0b10011, &ENTRY_CHILI_17288123216260222064)],
        &[(0b10011, &ENTRY_CHILIES_2805435102646559217)],
        &[(0b11010, &ENTRY_CHIMERID_12786529903260126440)],
        &[(0b11010, &ENTRY_CHIMERIDS_5877455725309387123)],
        &[(0b11010, &ENTRY_CHIMERISM_7571951058816157382)],
        &[(0b11010, &ENTRY_CHIMERISMS_7406463563173008857)],
        &[(0b00001, &ENTRY_CHIMERID_12786529903260126440)],
        &[(0b00001, &ENTRY_CHIMERIDS_5877455725309387123)],
        &[(0b00001, &ENTRY_CHIMERISM_7571951058816157382)],
        &[(0b00001, &ENTRY_CHIMERISMS_7406463563173008857)],
        &[(0b00001, &ENTRY_CHISELED_4085439916793683323)],
        &[(0b00001, &ENTRY_CHISELER_5457396429234167127)],
        &[(0b00001, &ENTRY_CHISELERS_2484752867150137049)],
        &[(0b00001, &ENTRY_CHISELING_10949176651834943898)],
    ],
    range: 2..=8,
};

static VARS_CHE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHE_CHILDREN),
    value: None,
};

pub static VARS_CHE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ckbook"),
        dictgen::InsensitiveStr::Ascii("ckbooks"),
        dictgen::InsensitiveStr::Ascii("ckerboard"),
        dictgen::InsensitiveStr::Ascii("ckerboards"),
        dictgen::InsensitiveStr::Ascii("ckered"),
        dictgen::InsensitiveStr::Ascii("ckering"),
        dictgen::InsensitiveStr::Ascii("erfulise"),
        dictgen::InsensitiveStr::Ascii("erfulises"),
        dictgen::InsensitiveStr::Ascii("erfulize"),
        dictgen::InsensitiveStr::Ascii("erfulizes"),
        dictgen::InsensitiveStr::Ascii("erly"),
        dictgen::InsensitiveStr::Ascii("licerae"),
        dictgen::InsensitiveStr::Ascii("licere"),
        dictgen::InsensitiveStr::Ascii("micalisation"),
        dictgen::InsensitiveStr::Ascii("micalisations"),
        dictgen::InsensitiveStr::Ascii("micalise"),
        dictgen::InsensitiveStr::Ascii("micalises"),
        dictgen::InsensitiveStr::Ascii("micalization"),
        dictgen::InsensitiveStr::Ascii("micalizations"),
        dictgen::InsensitiveStr::Ascii("micalize"),
        dictgen::InsensitiveStr::Ascii("micalizes"),
        dictgen::InsensitiveStr::Ascii("nix"),
        dictgen::InsensitiveStr::Ascii("nixes"),
        dictgen::InsensitiveStr::Ascii("que"),
        dictgen::InsensitiveStr::Ascii("quebook"),
        dictgen::InsensitiveStr::Ascii("quebooks"),
        dictgen::InsensitiveStr::Ascii("qued"),
        dictgen::InsensitiveStr::Ascii("quer"),
        dictgen::InsensitiveStr::Ascii("querboard"),
        dictgen::InsensitiveStr::Ascii("querboards"),
        dictgen::InsensitiveStr::Ascii("quered"),
        dictgen::InsensitiveStr::Ascii("quering"),
        dictgen::InsensitiveStr::Ascii("quers"),
        dictgen::InsensitiveStr::Ascii("ques"),
        dictgen::InsensitiveStr::Ascii("quing"),
        dictgen::InsensitiveStr::Ascii("rely"),
        dictgen::InsensitiveStr::Ascii("topod"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CHECKBOOK_9009854196001512796)],
        &[(0b00001, &ENTRY_CHECKBOOKS_17794340270798521929)],
        &[(0b00001, &ENTRY_CHECKERBOARD_8549731976664485147)],
        &[(0b00001, &ENTRY_CHECKERBOARDS_18064653792576628856)],
        &[(0b01001, &ENTRY_CHECKERED_6058427683271064427)],
        &[(0b01001, &ENTRY_CHECKERING_13657948767544155739)],
        &[(0b10010, &ENTRY_CHEERFULIZE_762771897588790882)],
        &[(0b10010, &ENTRY_CHEERFULIZES_14800232417183976396)],
        &[(0b01001, &ENTRY_CHEERFULIZE_762771897588790882)],
        &[(0b01001, &ENTRY_CHEERFULIZES_14800232417183976396)],
        &[(0b00001, &ENTRY_CHEERLY_11367263964946583096)],
        &[(0b11010, &ENTRY_CHELICERE_10130398757296091498)],
        &[(0b00001, &ENTRY_CHELICERE_10130398757296091498)],
        &[(0b10010, &ENTRY_CHEMICALIZATION_14523349755381906432)],
        &[(0b10010, &ENTRY_CHEMICALIZATIONS_17250488376229572482)],
        &[(0b10010, &ENTRY_CHEMICALIZE_2429770358300165469)],
        &[(0b10010, &ENTRY_CHEMICALIZES_17947429043522126420)],
        &[(0b01001, &ENTRY_CHEMICALIZATION_14523349755381906432)],
        &[(0b01001, &ENTRY_CHEMICALIZATIONS_17250488376229572482)],
        &[(0b01001, &ENTRY_CHEMICALIZE_2429770358300165469)],
        &[(0b01001, &ENTRY_CHEMICALIZES_17947429043522126420)],
        &[(0b10001, &ENTRY_CHENIX_6890496202644655006)],
        &[(0b10001, &ENTRY_CHENIXES_18140842653808609264)],
        &[(0b11010, &ENTRY_CHECK_17773922188155612180)],
        &[(0b11010, &ENTRY_CHECKBOOK_9009854196001512796)],
        &[(0b11010, &ENTRY_CHECKBOOKS_17794340270798521929)],
        &[(0b11010, &ENTRY_CHECKED_864493317061472521)],
        &[(0b11010, &ENTRY_CHECKER_9431957816562634502)],
        &[(0b11010, &ENTRY_CHECKERBOARD_8549731976664485147)],
        &[(0b11010, &ENTRY_CHECKERBOARDS_18064653792576628856)],
        &[(0b11010, &ENTRY_CHECKERED_6058427683271064427)],
        &[(0b11010, &ENTRY_CHECKERING_13657948767544155739)],
        &[(0b11010, &ENTRY_CHECKERS_4651898690896940599)],
        &[(0b11010, &ENTRY_CHECKS_5429237539074196507)],
        &[(0b11010, &ENTRY_CHECKING_12030083975828633786)],
        &[(0b11010, &ENTRY_CHEERLY_11367263964946583096)],
        &[(0b00001, &ENTRY_CHETOPOD_16990284463679767109)],
    ],
    range: 3..=13,
};

static VARS_CHA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CHA_CHILDREN),
    value: None,
};

static VARS_CHA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CHAC_NODE),
    None,
    Some(&VARS_CHAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CHAL_NODE),
    Some(&VARS_CHAM_NODE),
    Some(&VARS_CHAN_NODE),
    None,
    Some(&VARS_CHAP_NODE),
    None,
    Some(&VARS_CHAR_NODE),
    None,
    Some(&VARS_CHAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CHAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAT_CHILDREN),
    value: None,
};

pub static VARS_CHAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("telisation"),
        dictgen::InsensitiveStr::Ascii("telisations"),
        dictgen::InsensitiveStr::Ascii("telise"),
        dictgen::InsensitiveStr::Ascii("telises"),
        dictgen::InsensitiveStr::Ascii("telization"),
        dictgen::InsensitiveStr::Ascii("telizations"),
        dictgen::InsensitiveStr::Ascii("telize"),
        dictgen::InsensitiveStr::Ascii("telizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHATTELIZATION_7363246458991523337)],
        &[(0b10010, &ENTRY_CHATTELIZATIONS_14825459471315247028)],
        &[(0b10010, &ENTRY_CHATTELIZE_6140490582785528527)],
        &[(0b10010, &ENTRY_CHATTELIZES_8748236808052543965)],
        &[(0b01001, &ENTRY_CHATTELIZATION_7363246458991523337)],
        &[(0b01001, &ENTRY_CHATTELIZATIONS_14825459471315247028)],
        &[(0b01001, &ENTRY_CHATTELIZE_6140490582785528527)],
        &[(0b01001, &ENTRY_CHATTELIZES_8748236808052543965)],
    ],
    range: 6..=11,
};

static VARS_CHAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAR_CHILDREN),
    value: None,
};

pub static VARS_CHAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("acterisable"),
        dictgen::InsensitiveStr::Ascii("acterisabler"),
        dictgen::InsensitiveStr::Ascii("acterisables"),
        dictgen::InsensitiveStr::Ascii("acterisablest"),
        dictgen::InsensitiveStr::Ascii("acterisation"),
        dictgen::InsensitiveStr::Ascii("acterisations"),
        dictgen::InsensitiveStr::Ascii("acterise"),
        dictgen::InsensitiveStr::Ascii("acterised"),
        dictgen::InsensitiveStr::Ascii("acteriser"),
        dictgen::InsensitiveStr::Ascii("acterisers"),
        dictgen::InsensitiveStr::Ascii("acterises"),
        dictgen::InsensitiveStr::Ascii("acterising"),
        dictgen::InsensitiveStr::Ascii("acterizable"),
        dictgen::InsensitiveStr::Ascii("acterizabler"),
        dictgen::InsensitiveStr::Ascii("acterizables"),
        dictgen::InsensitiveStr::Ascii("acterizablest"),
        dictgen::InsensitiveStr::Ascii("acterization"),
        dictgen::InsensitiveStr::Ascii("acterizations"),
        dictgen::InsensitiveStr::Ascii("acterize"),
        dictgen::InsensitiveStr::Ascii("acterized"),
        dictgen::InsensitiveStr::Ascii("acterizer"),
        dictgen::InsensitiveStr::Ascii("acterizers"),
        dictgen::InsensitiveStr::Ascii("acterizes"),
        dictgen::InsensitiveStr::Ascii("acterizing"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHARACTERIZABLE_5496268454277897612)],
        &[(0b10010, &ENTRY_CHARACTERIZABLER_3425015125508980850)],
        &[(0b10010, &ENTRY_CHARACTERIZABLES_15907805406605774252)],
        &[(0b10010, &ENTRY_CHARACTERIZABLEST_13029951397962650520)],
        &[(0b10010, &ENTRY_CHARACTERIZATION_14570061393281069506)],
        &[(0b10010, &ENTRY_CHARACTERIZATIONS_9619550519705951475)],
        &[(0b10010, &ENTRY_CHARACTERIZE_7158652718387618717)],
        &[(0b10010, &ENTRY_CHARACTERIZED_3099918736243105904)],
        &[(0b10010, &ENTRY_CHARACTERIZER_14416082234464511775)],
        &[(0b10010, &ENTRY_CHARACTERIZERS_11394110184099705360)],
        &[(0b10010, &ENTRY_CHARACTERIZES_10537774223087357590)],
        &[(0b10010, &ENTRY_CHARACTERIZING_3950440594591682040)],
        &[(0b01001, &ENTRY_CHARACTERIZABLE_5496268454277897612)],
        &[(0b01001, &ENTRY_CHARACTERIZABLER_3425015125508980850)],
        &[(0b01001, &ENTRY_CHARACTERIZABLES_15907805406605774252)],
        &[(0b01001, &ENTRY_CHARACTERIZABLEST_13029951397962650520)],
        &[(0b01001, &ENTRY_CHARACTERIZATION_14570061393281069506)],
        &[(0b01001, &ENTRY_CHARACTERIZATIONS_9619550519705951475)],
        &[(0b01001, &ENTRY_CHARACTERIZE_7158652718387618717)],
        &[(0b01001, &ENTRY_CHARACTERIZED_3099918736243105904)],
        &[(0b01001, &ENTRY_CHARACTERIZER_14416082234464511775)],
        &[(0b01001, &ENTRY_CHARACTERIZERS_11394110184099705360)],
        &[(0b01001, &ENTRY_CHARACTERIZES_10537774223087357590)],
        &[(0b01001, &ENTRY_CHARACTERIZING_3950440594591682040)],
        &[(0b00001, &ENTRY_CHARER_7967793744452777217)],
        &[(0b11010, &ENTRY_CHARER_7967793744452777217)],
    ],
    range: 2..=13,
};

static VARS_CHAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAP_CHILDREN),
    value: None,
};

pub static VARS_CHAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("talisation"),
        dictgen::InsensitiveStr::Ascii("talisations"),
        dictgen::InsensitiveStr::Ascii("talise"),
        dictgen::InsensitiveStr::Ascii("talised"),
        dictgen::InsensitiveStr::Ascii("talises"),
        dictgen::InsensitiveStr::Ascii("talising"),
        dictgen::InsensitiveStr::Ascii("talization"),
        dictgen::InsensitiveStr::Ascii("talizations"),
        dictgen::InsensitiveStr::Ascii("talize"),
        dictgen::InsensitiveStr::Ascii("talized"),
        dictgen::InsensitiveStr::Ascii("talizes"),
        dictgen::InsensitiveStr::Ascii("talizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHAPTALIZATION_6705837795677885132)],
        &[(0b10010, &ENTRY_CHAPTALIZATIONS_11954144109418771855)],
        &[(0b10010, &ENTRY_CHAPTALIZE_3805623131812885010)],
        &[(0b10010, &ENTRY_CHAPTALIZED_15614458859451523347)],
        &[(0b10010, &ENTRY_CHAPTALIZES_12293081829441947782)],
        &[(0b10010, &ENTRY_CHAPTALIZING_3323047688472626072)],
        &[(0b01001, &ENTRY_CHAPTALIZATION_6705837795677885132)],
        &[(0b01001, &ENTRY_CHAPTALIZATIONS_11954144109418771855)],
        &[(0b01001, &ENTRY_CHAPTALIZE_3805623131812885010)],
        &[(0b01001, &ENTRY_CHAPTALIZED_15614458859451523347)],
        &[(0b01001, &ENTRY_CHAPTALIZES_12293081829441947782)],
        &[(0b01001, &ENTRY_CHAPTALIZING_3323047688472626072)],
    ],
    range: 6..=11,
};

static VARS_CHAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAN_CHILDREN),
    value: None,
};

pub static VARS_CHAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("neled"),
        dictgen::InsensitiveStr::Ascii("neler"),
        dictgen::InsensitiveStr::Ascii("nelers"),
        dictgen::InsensitiveStr::Ascii("neling"),
        dictgen::InsensitiveStr::Ascii("nelisation"),
        dictgen::InsensitiveStr::Ascii("nelisations"),
        dictgen::InsensitiveStr::Ascii("nelise"),
        dictgen::InsensitiveStr::Ascii("nelised"),
        dictgen::InsensitiveStr::Ascii("nelises"),
        dictgen::InsensitiveStr::Ascii("nelising"),
        dictgen::InsensitiveStr::Ascii("nelization"),
        dictgen::InsensitiveStr::Ascii("nelizations"),
        dictgen::InsensitiveStr::Ascii("nelize"),
        dictgen::InsensitiveStr::Ascii("nelized"),
        dictgen::InsensitiveStr::Ascii("nelizes"),
        dictgen::InsensitiveStr::Ascii("nelizing"),
        dictgen::InsensitiveStr::Ascii("nelled"),
        dictgen::InsensitiveStr::Ascii("neller"),
        dictgen::InsensitiveStr::Ascii("nellers"),
        dictgen::InsensitiveStr::Ascii("nelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CHANNELED_13645294606351550471)],
        &[(0b00001, &ENTRY_CHANNELER_15902006922249091823)],
        &[(0b00001, &ENTRY_CHANNELERS_15986650866937147094)],
        &[(0b00001, &ENTRY_CHANNELING_9266544299775335589)],
        &[(0b10010, &ENTRY_CHANNELIZATION_8051143060294686401)],
        &[(0b10010, &ENTRY_CHANNELIZATIONS_17088609630173428942)],
        &[(0b10010, &ENTRY_CHANNELIZE_12428404691676585341)],
        &[(0b10010, &ENTRY_CHANNELIZED_5009658046976798401)],
        &[(0b10010, &ENTRY_CHANNELIZES_12481680265741921670)],
        &[(0b10010, &ENTRY_CHANNELIZING_3206328004957832674)],
        &[(0b01001, &ENTRY_CHANNELIZATION_8051143060294686401)],
        &[(0b01001, &ENTRY_CHANNELIZATIONS_17088609630173428942)],
        &[(0b01001, &ENTRY_CHANNELIZE_12428404691676585341)],
        &[(0b01001, &ENTRY_CHANNELIZED_5009658046976798401)],
        &[(0b01001, &ENTRY_CHANNELIZES_12481680265741921670)],
        &[(0b01001, &ENTRY_CHANNELIZING_3206328004957832674)],
        &[(0b11010, &ENTRY_CHANNELED_13645294606351550471)],
        &[(0b11010, &ENTRY_CHANNELER_15902006922249091823)],
        &[(0b11010, &ENTRY_CHANNELERS_15986650866937147094)],
        &[(0b11010, &ENTRY_CHANNELING_9266544299775335589)],
    ],
    range: 5..=11,
};

static VARS_CHAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAM_CHILDREN),
    value: None,
};

pub static VARS_CHAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eleonise"),
        dictgen::InsensitiveStr::Ascii("eleonises"),
        dictgen::InsensitiveStr::Ascii("eleonize"),
        dictgen::InsensitiveStr::Ascii("eleonizes"),
        dictgen::InsensitiveStr::Ascii("isal"),
        dictgen::InsensitiveStr::Ascii("izal"),
        dictgen::InsensitiveStr::Ascii("pionise"),
        dictgen::InsensitiveStr::Ascii("pionises"),
        dictgen::InsensitiveStr::Ascii("pionize"),
        dictgen::InsensitiveStr::Ascii("pionizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CHAMELEONIZE_6719282861796065512)],
        &[(0b10010, &ENTRY_CHAMELEONIZES_16228445024684788006)],
        &[(0b01001, &ENTRY_CHAMELEONIZE_6719282861796065512)],
        &[(0b01001, &ENTRY_CHAMELEONIZES_16228445024684788006)],
        &[(0b10010, &ENTRY_CHAMIZAL_15395913577609401131)],
        &[(0b01001, &ENTRY_CHAMIZAL_15395913577609401131)],
        &[(0b10010, &ENTRY_CHAMPIONIZE_6246420755652451774)],
        &[(0b10010, &ENTRY_CHAMPIONIZES_1300772143294053091)],
        &[(0b01001, &ENTRY_CHAMPIONIZE_6246420755652451774)],
        &[(0b01001, &ENTRY_CHAMPIONIZES_1300772143294053091)],
    ],
    range: 4..=9,
};

static VARS_CHAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAL_CHILDREN),
    value: None,
};

pub static VARS_CHAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("azae"),
        dictgen::InsensitiveStr::Ascii("aze"),
        dictgen::InsensitiveStr::Ascii("daeans"),
        dictgen::InsensitiveStr::Ascii("deans"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CHALAZE_4744907345488198318)],
        &[(0b00001, &ENTRY_CHALAZE_4744907345488198318)],
        &[(0b11010, &ENTRY_CHALDEANS_13473385401733030342)],
        &[(0b00001, &ENTRY_CHALDEANS_13473385401733030342)],
    ],
    range: 3..=6,
};

static VARS_CHAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAE_CHILDREN),
    value: None,
};

pub static VARS_CHAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("topod")],
    values: &[&[(0b11010, &ENTRY_CHETOPOD_16990284463679767109)]],
    range: 5..=5,
};

static VARS_CHAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CHAC_CHILDREN),
    value: None,
};

pub static VARS_CHAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("oes"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CHACES_10965505579181904844)],
        &[(0b11010, &ENTRY_CHACES_10965505579181904844)],
    ],
    range: 2..=3,
};

static VARS_CE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CE_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_CE_254143254853835550)]),
};

static VARS_CE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CEC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CEL_NODE),
    None,
    Some(&VARS_CEN_NODE),
    None,
    Some(&VARS_CEP_NODE),
    None,
    Some(&VARS_CER_NODE),
    Some(&VARS_CES_NODE),
    Some(&VARS_CET_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CET_CHILDREN),
    value: None,
};

pub static VARS_CET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("us")],
    values: &[&[(0b10001, &ENTRY_CETUS_11617299917311809086)]],
    range: 2..=2,
};

static VARS_CES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CES_CHILDREN),
    value: None,
};

pub static VARS_CES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ar"),
        dictgen::InsensitiveStr::Ascii("aria"),
        dictgen::InsensitiveStr::Ascii("ious"),
        dictgen::InsensitiveStr::Ascii("ium"),
        dictgen::InsensitiveStr::Ascii("iums"),
        dictgen::InsensitiveStr::Ascii("pitose"),
        dictgen::InsensitiveStr::Ascii("pitosely"),
        dictgen::InsensitiveStr::Ascii("tus"),
        dictgen::InsensitiveStr::Ascii("tuses"),
        dictgen::InsensitiveStr::Ascii("ural"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CESAR_6074944643525905095)],
        &[(0b00001, &ENTRY_CESARIA_7497611325269733598)],
        &[(0b00001, &ENTRY_CESIOUS_10445245552084517023)],
        &[(0b11001, &ENTRY_CESIUM_17343129911628596363)],
        &[(0b11001, &ENTRY_CESIUMS_4513476447764778250)],
        &[(0b10001, &ENTRY_CESPITOSE_2511412164776933409)],
        &[(0b10001, &ENTRY_CESPITOSELY_7196666758904903124)],
        &[(0b10001, &ENTRY_CESTUS_2264271345052468556)],
        &[(0b10001, &ENTRY_CESTUSES_17262448748104314423)],
        &[(0b10001, &ENTRY_CESURAL_2827531996476826616)],
    ],
    range: 2..=8,
};

static VARS_CER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CER_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_CER_16898181025911443964)]),
};

pub static VARS_CER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("a"),
        dictgen::InsensitiveStr::Ascii("at"),
        dictgen::InsensitiveStr::Ascii("atin"),
        dictgen::InsensitiveStr::Ascii("atins"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ebralisation"),
        dictgen::InsensitiveStr::Ascii("ebralisations"),
        dictgen::InsensitiveStr::Ascii("ebralise"),
        dictgen::InsensitiveStr::Ascii("ebralises"),
        dictgen::InsensitiveStr::Ascii("ebralization"),
        dictgen::InsensitiveStr::Ascii("ebralizations"),
        dictgen::InsensitiveStr::Ascii("ebralize"),
        dictgen::InsensitiveStr::Ascii("ebralizes"),
        dictgen::InsensitiveStr::Ascii("emonialise"),
        dictgen::InsensitiveStr::Ascii("emonialises"),
        dictgen::InsensitiveStr::Ascii("emonialize"),
        dictgen::InsensitiveStr::Ascii("emonializes"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("olite"),
        dictgen::InsensitiveStr::Ascii("ule"),
        dictgen::InsensitiveStr::Ascii("uleolactite"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CERA_7059694773303335761)],
        &[(0b00001, &ENTRY_CERAT_1886332108569610985)],
        &[(0b00001, &ENTRY_CERATIN_7844527544181435388)],
        &[(0b00001, &ENTRY_CERATINS_7956220450419624429)],
        &[(0b00001, &ENTRY_CERE_9821157149992437937)],
        &[(0b10010, &ENTRY_CEREBRALIZATION_639759174762081390)],
        &[(0b10010, &ENTRY_CEREBRALIZATIONS_10944353801184109081)],
        &[(0b10010, &ENTRY_CEREBRALIZE_4644072502748774455)],
        &[(0b10010, &ENTRY_CEREBRALIZES_14811698873620229158)],
        &[(0b01001, &ENTRY_CEREBRALIZATION_639759174762081390)],
        &[(0b01001, &ENTRY_CEREBRALIZATIONS_10944353801184109081)],
        &[(0b01001, &ENTRY_CEREBRALIZE_4644072502748774455)],
        &[(0b01001, &ENTRY_CEREBRALIZES_14811698873620229158)],
        &[(0b10010, &ENTRY_CEREMONIALIZE_8839368071947058377)],
        &[(0b10010, &ENTRY_CEREMONIALIZES_13518074193055353148)],
        &[(0b01001, &ENTRY_CEREMONIALIZE_8839368071947058377)],
        &[(0b01001, &ENTRY_CEREMONIALIZES_13518074193055353148)],
        &[(0b00001, &ENTRY_CERES_4278379745962029428)],
        &[(0b00001, &ENTRY_CEROLITE_7632841335460717740)],
        &[(0b00001, &ENTRY_CERULE_1141707642753807571)],
        &[(0b00001, &ENTRY_CERULEOLACTITE_1277200430318336008)],
    ],
    range: 1..=13,
};

static VARS_CEP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CEP_CHILDREN),
    value: None,
};

pub static VARS_CEP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("halisation"),
        dictgen::InsensitiveStr::Ascii("halisations"),
        dictgen::InsensitiveStr::Ascii("halization"),
        dictgen::InsensitiveStr::Ascii("halizations"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CEPHALIZATION_1313416802058839208)],
        &[(0b10010, &ENTRY_CEPHALIZATIONS_11274159904518065511)],
        &[(0b01001, &ENTRY_CEPHALIZATION_1313416802058839208)],
        &[(0b01001, &ENTRY_CEPHALIZATIONS_11274159904518065511)],
    ],
    range: 10..=11,
};

static VARS_CEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CEN_CHILDREN),
    value: None,
};

static VARS_CEN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CENA_NODE),
    None,
    None,
    None,
    Some(&VARS_CENE_NODE),
    None,
    None,
    None,
    Some(&VARS_CENI_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CENO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CENT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CENT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CENT_CHILDREN),
    value: None,
};

static VARS_CENT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_CENTE_NODE),
    None,
    None,
    None,
    Some(&VARS_CENTI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CENTR_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CENTR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENTR_CHILDREN),
    value: None,
};

pub static VARS_CENTR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alisers"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizers"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("eable"),
        dictgen::InsensitiveStr::Ascii("eables"),
        dictgen::InsensitiveStr::Ascii("eboard"),
        dictgen::InsensitiveStr::Ascii("eboards"),
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("efold"),
        dictgen::InsensitiveStr::Ascii("efolds"),
        dictgen::InsensitiveStr::Ascii("eless"),
        dictgen::InsensitiveStr::Ascii("elesser"),
        dictgen::InsensitiveStr::Ascii("elessest"),
        dictgen::InsensitiveStr::Ascii("eline"),
        dictgen::InsensitiveStr::Ascii("elines"),
        dictgen::InsensitiveStr::Ascii("emost"),
        dictgen::InsensitiveStr::Ascii("epiece"),
        dictgen::InsensitiveStr::Ascii("epieces"),
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ers"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("eville"),
        dictgen::InsensitiveStr::Ascii("ifugalisation"),
        dictgen::InsensitiveStr::Ascii("ifugalisations"),
        dictgen::InsensitiveStr::Ascii("ifugalise"),
        dictgen::InsensitiveStr::Ascii("ifugalised"),
        dictgen::InsensitiveStr::Ascii("ifugalises"),
        dictgen::InsensitiveStr::Ascii("ifugalising"),
        dictgen::InsensitiveStr::Ascii("ifugalization"),
        dictgen::InsensitiveStr::Ascii("ifugalizations"),
        dictgen::InsensitiveStr::Ascii("ifugalize"),
        dictgen::InsensitiveStr::Ascii("ifugalized"),
        dictgen::InsensitiveStr::Ascii("ifugalizes"),
        dictgen::InsensitiveStr::Ascii("ifugalizing"),
        dictgen::InsensitiveStr::Ascii("ing"),
        dictgen::InsensitiveStr::Ascii("ings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CENTRALIZATION_1234582649982497784)],
        &[(0b10010, &ENTRY_CENTRALIZATIONS_16044732569453119370)],
        &[(0b10010, &ENTRY_CENTRALIZE_15017664864759648047)],
        &[(0b10010, &ENTRY_CENTRALIZED_70126610329667809)],
        &[(0b10010, &ENTRY_CENTRALIZER_12959940147090220134)],
        &[(0b10010, &ENTRY_CENTRALIZERS_15668441115014907887)],
        &[(0b10010, &ENTRY_CENTRALIZES_13145361766427986184)],
        &[(0b10010, &ENTRY_CENTRALIZING_11205811887699159106)],
        &[(0b01001, &ENTRY_CENTRALIZATION_1234582649982497784)],
        &[(0b01001, &ENTRY_CENTRALIZATIONS_16044732569453119370)],
        &[(0b01001, &ENTRY_CENTRALIZE_15017664864759648047)],
        &[(0b01001, &ENTRY_CENTRALIZED_70126610329667809)],
        &[(0b01001, &ENTRY_CENTRALIZER_12959940147090220134)],
        &[(0b01001, &ENTRY_CENTRALIZERS_15668441115014907887)],
        &[(0b01001, &ENTRY_CENTRALIZES_13145361766427986184)],
        &[(0b01001, &ENTRY_CENTRALIZING_11205811887699159106)],
        &[(0b11010, &ENTRY_CENTER_5116273194089119472)],
        &[(0b11010, &ENTRY_CENTERABLE_7850484022405363699)],
        &[(0b11010, &ENTRY_CENTERABLES_284130752204252297)],
        &[(0b11010, &ENTRY_CENTERBOARD_6663399917522410894)],
        &[(0b11010, &ENTRY_CENTERBOARDS_6194272976717122092)],
        &[(0b11010, &ENTRY_CENTERED_7034434783664313969)],
        &[(0b11010, &ENTRY_CENTERFOLD_8184640290263929626)],
        &[(0b11010, &ENTRY_CENTERFOLDS_3764205251661654267)],
        &[(0b11010, &ENTRY_CENTERLESS_16010100430566689787)],
        &[(0b11010, &ENTRY_CENTERLESSER_4828594898766209427)],
        &[(0b11010, &ENTRY_CENTERLESSEST_15729458226381131123)],
        &[(0b11010, &ENTRY_CENTERLINE_4175184067421726158)],
        &[(0b11010, &ENTRY_CENTERLINES_17943791483589954179)],
        &[(0b11010, &ENTRY_CENTERMOST_14667266636773107736)],
        &[(0b11010, &ENTRY_CENTERPIECE_9404304832569952961)],
        &[(0b11010, &ENTRY_CENTERPIECES_2175158136644578025)],
        &[(0b11010, &ENTRY_CENTERER_1283754348315229141)],
        &[(0b11010, &ENTRY_CENTERERS_8988197150993437622)],
        &[(0b11010, &ENTRY_CENTERS_8512068248537945159)],
        &[(0b11010, &ENTRY_CENTERVILLE_8888927316062312202)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZATION_10319359115375445805)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZATIONS_16355479198686645900)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZE_12152362034063070075)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZED_16399570134709120738)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZES_17016153988543053118)],
        &[(0b10010, &ENTRY_CENTRIFUGALIZING_7217121477743759122)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZATION_10319359115375445805)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZATIONS_16355479198686645900)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZE_12152362034063070075)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZED_16399570134709120738)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZES_17016153988543053118)],
        &[(0b01001, &ENTRY_CENTRIFUGALIZING_7217121477743759122)],
        &[(0b11010, &ENTRY_CENTERING_2288436236637604266)],
        &[(0b11010, &ENTRY_CENTERINGS_3934315661544059303)],
    ],
    range: 1..=14,
};

static VARS_CENTI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENTI_CHILDREN),
    value: None,
};

pub static VARS_CENTI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gramme"),
        dictgen::InsensitiveStr::Ascii("grammes"),
        dictgen::InsensitiveStr::Ascii("liter"),
        dictgen::InsensitiveStr::Ascii("liters"),
        dictgen::InsensitiveStr::Ascii("litre"),
        dictgen::InsensitiveStr::Ascii("litres"),
        dictgen::InsensitiveStr::Ascii("meter"),
        dictgen::InsensitiveStr::Ascii("meters"),
        dictgen::InsensitiveStr::Ascii("metre"),
        dictgen::InsensitiveStr::Ascii("metres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CENTIGRAM_6661702624209880115)],
        &[(0b10010, &ENTRY_CENTIGRAMS_13488008474576662923)],
        &[(0b00001, &ENTRY_CENTILITER_16190905673789101195)],
        &[(0b00001, &ENTRY_CENTILITERS_15644223244315246330)],
        &[(0b11010, &ENTRY_CENTILITER_16190905673789101195)],
        &[(0b11010, &ENTRY_CENTILITERS_15644223244315246330)],
        &[(0b00001, &ENTRY_CENTIMETER_7893665458627405085)],
        &[(0b00001, &ENTRY_CENTIMETERS_13218717043789536591)],
        &[(0b11010, &ENTRY_CENTIMETER_7893665458627405085)],
        &[(0b11010, &ENTRY_CENTIMETERS_13218717043789536591)],
    ],
    range: 5..=7,
};

static VARS_CENTE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENTE_CHILDREN),
    value: None,
};

pub static VARS_CENTE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rable"),
        dictgen::InsensitiveStr::Ascii("rables"),
        dictgen::InsensitiveStr::Ascii("rboard"),
        dictgen::InsensitiveStr::Ascii("rboards"),
        dictgen::InsensitiveStr::Ascii("red"),
        dictgen::InsensitiveStr::Ascii("rer"),
        dictgen::InsensitiveStr::Ascii("rers"),
        dictgen::InsensitiveStr::Ascii("rfold"),
        dictgen::InsensitiveStr::Ascii("rfolds"),
        dictgen::InsensitiveStr::Ascii("ring"),
        dictgen::InsensitiveStr::Ascii("rings"),
        dictgen::InsensitiveStr::Ascii("rless"),
        dictgen::InsensitiveStr::Ascii("rlesser"),
        dictgen::InsensitiveStr::Ascii("rlessest"),
        dictgen::InsensitiveStr::Ascii("rline"),
        dictgen::InsensitiveStr::Ascii("rlines"),
        dictgen::InsensitiveStr::Ascii("rmost"),
        dictgen::InsensitiveStr::Ascii("rpiece"),
        dictgen::InsensitiveStr::Ascii("rpieces"),
        dictgen::InsensitiveStr::Ascii("rs"),
        dictgen::InsensitiveStr::Ascii("rville"),
    ],
    values: &[
        &[(0b01001, &ENTRY_CENTER_5116273194089119472)],
        &[(0b00001, &ENTRY_CENTERABLE_7850484022405363699)],
        &[(0b00001, &ENTRY_CENTERABLES_284130752204252297)],
        &[(0b00001, &ENTRY_CENTERBOARD_6663399917522410894)],
        &[(0b00001, &ENTRY_CENTERBOARDS_6194272976717122092)],
        &[(0b01001, &ENTRY_CENTERED_7034434783664313969)],
        &[(0b00001, &ENTRY_CENTERER_1283754348315229141)],
        &[(0b00001, &ENTRY_CENTERERS_8988197150993437622)],
        &[(0b00001, &ENTRY_CENTERFOLD_8184640290263929626)],
        &[(0b00001, &ENTRY_CENTERFOLDS_3764205251661654267)],
        &[(0b01001, &ENTRY_CENTERING_2288436236637604266)],
        &[(0b01001, &ENTRY_CENTERINGS_3934315661544059303)],
        &[(0b00001, &ENTRY_CENTERLESS_16010100430566689787)],
        &[(0b00001, &ENTRY_CENTERLESSER_4828594898766209427)],
        &[(0b00001, &ENTRY_CENTERLESSEST_15729458226381131123)],
        &[(0b00001, &ENTRY_CENTERLINE_4175184067421726158)],
        &[(0b00001, &ENTRY_CENTERLINES_17943791483589954179)],
        &[(0b00001, &ENTRY_CENTERMOST_14667266636773107736)],
        &[(0b00001, &ENTRY_CENTERPIECE_9404304832569952961)],
        &[(0b00001, &ENTRY_CENTERPIECES_2175158136644578025)],
        &[(0b01001, &ENTRY_CENTERS_8512068248537945159)],
        &[(0b00001, &ENTRY_CENTERVILLE_8888927316062312202)],
    ],
    range: 1..=8,
};

static VARS_CENO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENO_CHILDREN),
    value: None,
};

pub static VARS_CENO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("be"),
        dictgen::InsensitiveStr::Ascii("bitism"),
        dictgen::InsensitiveStr::Ascii("bium"),
        dictgen::InsensitiveStr::Ascii("by"),
        dictgen::InsensitiveStr::Ascii("genetic"),
        dictgen::InsensitiveStr::Ascii("genetically"),
        dictgen::InsensitiveStr::Ascii("site"),
        dictgen::InsensitiveStr::Ascii("species"),
        dictgen::InsensitiveStr::Ascii("specific"),
        dictgen::InsensitiveStr::Ascii("specifically"),
        dictgen::InsensitiveStr::Ascii("zoic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CENOBE_17025760197236238291)],
        &[(0b10001, &ENTRY_CENOBITISM_5016689208030165500)],
        &[(0b10001, &ENTRY_CENOBIUM_6656148321160010108)],
        &[(0b10001, &ENTRY_CENOBY_6246310194380860627)],
        &[
            (0b10001, &ENTRY_CENOGENETIC_14752824343681490356),
            (0b10001, &ENTRY_CENOGENETIC_4645405785928938913),
        ],
        &[(0b10001, &ENTRY_CENOGENETICALLY_14614059803186390481)],
        &[(0b10001, &ENTRY_CENOSITE_6962695398695523616)],
        &[(0b10001, &ENTRY_CENOSPECIES_18129881350317785306)],
        &[(0b10001, &ENTRY_CENOSPECIFIC_10710765180299401749)],
        &[(0b10001, &ENTRY_CENOSPECIFICALLY_5111318916340201830)],
        &[(0b10001, &ENTRY_CENOZOIC_2810735566450048802)],
    ],
    range: 2..=12,
};

static VARS_CENI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENI_CHILDREN),
    value: None,
};

pub static VARS_CENI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("s")],
    values: &[&[(0b10001, &ENTRY_CENIS_1991031411311203268)]],
    range: 1..=1,
};

static VARS_CENE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENE_CHILDREN),
    value: None,
};

pub static VARS_CENE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthesis"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CENESTHESIA_3973419130660988894)],
        &[(0b10001, &ENTRY_CENESTHESIAS_17650055632548316730)],
        &[(0b10001, &ENTRY_CENESTHESIS_2981771230300833707)],
    ],
    range: 7..=8,
};

static VARS_CENA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CENA_CHILDREN),
    value: None,
};

pub static VARS_CENA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cle"),
        dictgen::InsensitiveStr::Ascii("culum"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CENACLE_4902172834128420652)],
        &[(0b10001, &ENTRY_CENACULUM_14642801640862790402)],
    ],
    range: 3..=5,
};

static VARS_CEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CEL_CHILDREN),
    value: None,
};

pub static VARS_CEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("astraceae"),
        dictgen::InsensitiveStr::Ascii("astraceous"),
        dictgen::InsensitiveStr::Ascii("estialise"),
        dictgen::InsensitiveStr::Ascii("estialises"),
        dictgen::InsensitiveStr::Ascii("estialize"),
        dictgen::InsensitiveStr::Ascii("estializes"),
        dictgen::InsensitiveStr::Ascii("estine"),
        dictgen::InsensitiveStr::Ascii("iac"),
        dictgen::InsensitiveStr::Ascii("iacs"),
        dictgen::InsensitiveStr::Ascii("ialgia"),
        dictgen::InsensitiveStr::Ascii("iomyalgia"),
        dictgen::InsensitiveStr::Ascii("iorrhea"),
        dictgen::InsensitiveStr::Ascii("ioscopy"),
        dictgen::InsensitiveStr::Ascii("iotomy"),
        dictgen::InsensitiveStr::Ascii("om"),
        dictgen::InsensitiveStr::Ascii("oma"),
        dictgen::InsensitiveStr::Ascii("omata"),
        dictgen::InsensitiveStr::Ascii("oms"),
        dictgen::InsensitiveStr::Ascii("oscope"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CELASTRACEAE_17324005888177982048)],
        &[(0b00001, &ENTRY_CELASTRACEOUS_18174723794622646878)],
        &[(0b10010, &ENTRY_CELESTIALIZE_2289649302276111708)],
        &[(0b10010, &ENTRY_CELESTIALIZES_10058751039284937485)],
        &[(0b01001, &ENTRY_CELESTIALIZE_2289649302276111708)],
        &[(0b01001, &ENTRY_CELESTIALIZES_10058751039284937485)],
        &[(0b00001, &ENTRY_CELESTINE_11011528250519125092)],
        &[(0b10001, &ENTRY_CELIAC_10249133411124257957)],
        &[(0b10001, &ENTRY_CELIACS_10248347099141877177)],
        &[(0b10001, &ENTRY_CELIALGIA_4569927604389576150)],
        &[(0b10001, &ENTRY_CELIOMYALGIA_14548383766443531737)],
        &[(0b10001, &ENTRY_CELIORRHEA_5614182174276153091)],
        &[(0b10001, &ENTRY_CELIOSCOPY_17821312237861674807)],
        &[(0b10001, &ENTRY_CELIOTOMY_9141657999599968712)],
        &[(0b11001, &ENTRY_CELOM_581114569279805851)],
        &[(0b10001, &ENTRY_CELOMA_8394900856159450271)],
        &[(0b10001, &ENTRY_CELOMATA_5399894536275260385)],
        &[(0b11001, &ENTRY_CELOMS_16869648723221026513)],
        &[(0b10001, &ENTRY_CELOSCOPE_13733285893205563827)],
        &[(0b10010, &ENTRY_CELTICIZE_15359124010454967826)],
        &[(0b10010, &ENTRY_CELTICIZES_13468713960478569237)],
        &[(0b01001, &ENTRY_CELTICIZE_15359124010454967826)],
        &[(0b01001, &ENTRY_CELTICIZES_13468713960478569237)],
    ],
    range: 2..=10,
};

static VARS_CEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CEC_CHILDREN),
    value: None,
};

pub static VARS_CEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ally"),
        dictgen::InsensitiveStr::Ascii("itis"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("ity"),
        dictgen::InsensitiveStr::Ascii("ostomy"),
        dictgen::InsensitiveStr::Ascii("otomy"),
    ],
    values: &[
        &[(0b10001, &ENTRY_CECALLY_12720796600011784892)],
        &[(0b10001, &ENTRY_CECITIS_18034763690253072964)],
        &[(0b10001, &ENTRY_CECITISES_10355938704850723051)],
        &[(0b10001, &ENTRY_CECITY_9865259183091102407)],
        &[(0b10001, &ENTRY_CECOSTOMY_3475802463529305333)],
        &[(0b10001, &ENTRY_CECOTOMY_3978768287054362751)],
    ],
    range: 3..=6,
};

static VARS_CA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CA_CHILDREN),
    value: None,
};

static VARS_CA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_CAC_NODE),
    Some(&VARS_CAD_NODE),
    Some(&VARS_CAE_NODE),
    Some(&VARS_CAF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CAL_NODE),
    Some(&VARS_CAM_NODE),
    Some(&VARS_CAN_NODE),
    None,
    Some(&VARS_CAP_NODE),
    None,
    Some(&VARS_CAR_NODE),
    Some(&VARS_CAS_NODE),
    Some(&VARS_CAT_NODE),
    Some(&VARS_CAU_NODE),
    Some(&VARS_CAV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_CAV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAV_CHILDREN),
    value: None,
};

pub static VARS_CAV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iare"),
        dictgen::InsensitiveStr::Ascii("iares"),
        dictgen::InsensitiveStr::Ascii("ilation"),
        dictgen::InsensitiveStr::Ascii("iled"),
        dictgen::InsensitiveStr::Ascii("iler"),
        dictgen::InsensitiveStr::Ascii("ilers"),
        dictgen::InsensitiveStr::Ascii("iling"),
        dictgen::InsensitiveStr::Ascii("ilings"),
        dictgen::InsensitiveStr::Ascii("illation"),
        dictgen::InsensitiveStr::Ascii("illed"),
        dictgen::InsensitiveStr::Ascii("iller"),
        dictgen::InsensitiveStr::Ascii("illers"),
        dictgen::InsensitiveStr::Ascii("illing"),
        dictgen::InsensitiveStr::Ascii("illings"),
    ],
    values: &[
        &[(0b10011, &ENTRY_CAVIAR_7938491403168755546)],
        &[(0b10011, &ENTRY_CAVIARS_3052109653380368873)],
        &[(0b00001, &ENTRY_CAVILATION_6485561782401683356)],
        &[(0b01001, &ENTRY_CAVILED_13259789881942666788)],
        &[(0b00001, &ENTRY_CAVILER_18221555292854240655)],
        &[(0b00001, &ENTRY_CAVILERS_17995770150287304299)],
        &[(0b01001, &ENTRY_CAVILING_3938684952444630623)],
        &[(0b01001, &ENTRY_CAVILINGS_3979930879616230447)],
        &[(0b11010, &ENTRY_CAVILATION_6485561782401683356)],
        &[(0b11010, &ENTRY_CAVILED_13259789881942666788)],
        &[(0b11010, &ENTRY_CAVILER_18221555292854240655)],
        &[(0b11010, &ENTRY_CAVILERS_17995770150287304299)],
        &[(0b11010, &ENTRY_CAVILING_3938684952444630623)],
        &[(0b11010, &ENTRY_CAVILINGS_3979930879616230447)],
    ],
    range: 4..=8,
};

static VARS_CAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAU_CHILDREN),
    value: None,
};

pub static VARS_CAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sticisation"),
        dictgen::InsensitiveStr::Ascii("sticisations"),
        dictgen::InsensitiveStr::Ascii("sticise"),
        dictgen::InsensitiveStr::Ascii("sticiser"),
        dictgen::InsensitiveStr::Ascii("sticisers"),
        dictgen::InsensitiveStr::Ascii("sticises"),
        dictgen::InsensitiveStr::Ascii("sticization"),
        dictgen::InsensitiveStr::Ascii("sticizations"),
        dictgen::InsensitiveStr::Ascii("sticize"),
        dictgen::InsensitiveStr::Ascii("sticizer"),
        dictgen::InsensitiveStr::Ascii("sticizers"),
        dictgen::InsensitiveStr::Ascii("sticizes"),
        dictgen::InsensitiveStr::Ascii("terisation"),
        dictgen::InsensitiveStr::Ascii("terisations"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terised"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terising"),
        dictgen::InsensitiveStr::Ascii("terization"),
        dictgen::InsensitiveStr::Ascii("terizations"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terized"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("terizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CAUSTICIZATION_14179900306302530284)],
        &[(0b10010, &ENTRY_CAUSTICIZATIONS_3386787494158775873)],
        &[(0b10010, &ENTRY_CAUSTICIZE_8749392950417620936)],
        &[(0b10010, &ENTRY_CAUSTICIZER_11653296088268450856)],
        &[(0b10010, &ENTRY_CAUSTICIZERS_3776323281922224631)],
        &[(0b10010, &ENTRY_CAUSTICIZES_9636663018478092014)],
        &[(0b01001, &ENTRY_CAUSTICIZATION_14179900306302530284)],
        &[(0b01001, &ENTRY_CAUSTICIZATIONS_3386787494158775873)],
        &[(0b01001, &ENTRY_CAUSTICIZE_8749392950417620936)],
        &[(0b01001, &ENTRY_CAUSTICIZER_11653296088268450856)],
        &[(0b01001, &ENTRY_CAUSTICIZERS_3776323281922224631)],
        &[(0b01001, &ENTRY_CAUSTICIZES_9636663018478092014)],
        &[(0b10010, &ENTRY_CAUTERIZATION_13195615037701165081)],
        &[(0b10010, &ENTRY_CAUTERIZATIONS_6182254960121790836)],
        &[(0b10010, &ENTRY_CAUTERIZE_3418770242947142090)],
        &[(0b10010, &ENTRY_CAUTERIZED_14634034015720450176)],
        &[(0b10010, &ENTRY_CAUTERIZES_10593916877351446728)],
        &[(0b10010, &ENTRY_CAUTERIZING_13207260063277352862)],
        &[(0b01001, &ENTRY_CAUTERIZATION_13195615037701165081)],
        &[(0b01001, &ENTRY_CAUTERIZATIONS_6182254960121790836)],
        &[(0b01001, &ENTRY_CAUTERIZE_3418770242947142090)],
        &[(0b01001, &ENTRY_CAUTERIZED_14634034015720450176)],
        &[(0b01001, &ENTRY_CAUTERIZES_10593916877351446728)],
        &[(0b01001, &ENTRY_CAUTERIZING_13207260063277352862)],
    ],
    range: 6..=12,
};

static VARS_CAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CAT_CHILDREN),
    value: None,
};

static VARS_CAT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CATA_NODE),
    None,
    None,
    None,
    Some(&VARS_CATE_NODE),
    None,
    None,
    Some(&VARS_CATH_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CATH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CATH_CHILDREN),
    value: None,
};

pub static VARS_CATH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arise"),
        dictgen::InsensitiveStr::Ascii("arised"),
        dictgen::InsensitiveStr::Ascii("arises"),
        dictgen::InsensitiveStr::Ascii("arising"),
        dictgen::InsensitiveStr::Ascii("arize"),
        dictgen::InsensitiveStr::Ascii("arized"),
        dictgen::InsensitiveStr::Ascii("arizes"),
        dictgen::InsensitiveStr::Ascii("arizing"),
        dictgen::InsensitiveStr::Ascii("eterisation"),
        dictgen::InsensitiveStr::Ascii("eterisations"),
        dictgen::InsensitiveStr::Ascii("eterise"),
        dictgen::InsensitiveStr::Ascii("eterised"),
        dictgen::InsensitiveStr::Ascii("eterises"),
        dictgen::InsensitiveStr::Ascii("eterising"),
        dictgen::InsensitiveStr::Ascii("eterization"),
        dictgen::InsensitiveStr::Ascii("eterizations"),
        dictgen::InsensitiveStr::Ascii("eterize"),
        dictgen::InsensitiveStr::Ascii("eterized"),
        dictgen::InsensitiveStr::Ascii("eterizes"),
        dictgen::InsensitiveStr::Ascii("eterizing"),
        dictgen::InsensitiveStr::Ascii("olicisation"),
        dictgen::InsensitiveStr::Ascii("olicisations"),
        dictgen::InsensitiveStr::Ascii("olicise"),
        dictgen::InsensitiveStr::Ascii("olicised"),
        dictgen::InsensitiveStr::Ascii("oliciser"),
        dictgen::InsensitiveStr::Ascii("olicisers"),
        dictgen::InsensitiveStr::Ascii("olicises"),
        dictgen::InsensitiveStr::Ascii("olicising"),
        dictgen::InsensitiveStr::Ascii("olicization"),
        dictgen::InsensitiveStr::Ascii("olicizations"),
        dictgen::InsensitiveStr::Ascii("olicize"),
        dictgen::InsensitiveStr::Ascii("olicized"),
        dictgen::InsensitiveStr::Ascii("olicizer"),
        dictgen::InsensitiveStr::Ascii("olicizers"),
        dictgen::InsensitiveStr::Ascii("olicizes"),
        dictgen::InsensitiveStr::Ascii("olicizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CATHARIZE_13562362241692832662)],
        &[(0b10010, &ENTRY_CATHARIZED_5807291134697395135)],
        &[(0b10010, &ENTRY_CATHARIZES_15482284310469218680)],
        &[(0b10010, &ENTRY_CATHARIZING_1602215100886763291)],
        &[(0b01001, &ENTRY_CATHARIZE_13562362241692832662)],
        &[(0b01001, &ENTRY_CATHARIZED_5807291134697395135)],
        &[(0b01001, &ENTRY_CATHARIZES_15482284310469218680)],
        &[(0b01001, &ENTRY_CATHARIZING_1602215100886763291)],
        &[(0b10010, &ENTRY_CATHETERIZATION_11439863909552030833)],
        &[(0b10010, &ENTRY_CATHETERIZATIONS_13120993350154324986)],
        &[(0b10010, &ENTRY_CATHETERIZE_6492718106386820661)],
        &[(0b10010, &ENTRY_CATHETERIZED_5620836466321605366)],
        &[(0b10010, &ENTRY_CATHETERIZES_11247243473913332794)],
        &[(0b10010, &ENTRY_CATHETERIZING_17180903138518299050)],
        &[(0b01001, &ENTRY_CATHETERIZATION_11439863909552030833)],
        &[(0b01001, &ENTRY_CATHETERIZATIONS_13120993350154324986)],
        &[(0b01001, &ENTRY_CATHETERIZE_6492718106386820661)],
        &[(0b01001, &ENTRY_CATHETERIZED_5620836466321605366)],
        &[(0b01001, &ENTRY_CATHETERIZES_11247243473913332794)],
        &[(0b01001, &ENTRY_CATHETERIZING_17180903138518299050)],
        &[(0b10010, &ENTRY_CATHOLICIZATION_1039966536643797028)],
        &[(0b10010, &ENTRY_CATHOLICIZATIONS_8828933916874627488)],
        &[(0b10010, &ENTRY_CATHOLICIZE_4285061554275370513)],
        &[(0b10010, &ENTRY_CATHOLICIZED_14250990289821303382)],
        &[(0b10010, &ENTRY_CATHOLICIZER_17454867137057099076)],
        &[(0b10010, &ENTRY_CATHOLICIZERS_11183927485796882872)],
        &[(0b10010, &ENTRY_CATHOLICIZES_893481801065117743)],
        &[(0b10010, &ENTRY_CATHOLICIZING_483590190526039504)],
        &[(0b01001, &ENTRY_CATHOLICIZATION_1039966536643797028)],
        &[(0b01001, &ENTRY_CATHOLICIZATIONS_8828933916874627488)],
        &[(0b01001, &ENTRY_CATHOLICIZE_4285061554275370513)],
        &[(0b01001, &ENTRY_CATHOLICIZED_14250990289821303382)],
        &[(0b01001, &ENTRY_CATHOLICIZER_17454867137057099076)],
        &[(0b01001, &ENTRY_CATHOLICIZERS_11183927485796882872)],
        &[(0b01001, &ENTRY_CATHOLICIZES_893481801065117743)],
        &[(0b01001, &ENTRY_CATHOLICIZING_483590190526039504)],
    ],
    range: 5..=12,
};

static VARS_CATE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CATE_CHILDREN),
    value: None,
};

pub static VARS_CATE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chisable"),
        dictgen::InsensitiveStr::Ascii("chisabler"),
        dictgen::InsensitiveStr::Ascii("chisables"),
        dictgen::InsensitiveStr::Ascii("chisablest"),
        dictgen::InsensitiveStr::Ascii("chisation"),
        dictgen::InsensitiveStr::Ascii("chisations"),
        dictgen::InsensitiveStr::Ascii("chise"),
        dictgen::InsensitiveStr::Ascii("chised"),
        dictgen::InsensitiveStr::Ascii("chiser"),
        dictgen::InsensitiveStr::Ascii("chisers"),
        dictgen::InsensitiveStr::Ascii("chises"),
        dictgen::InsensitiveStr::Ascii("chising"),
        dictgen::InsensitiveStr::Ascii("chisings"),
        dictgen::InsensitiveStr::Ascii("chizable"),
        dictgen::InsensitiveStr::Ascii("chizabler"),
        dictgen::InsensitiveStr::Ascii("chizables"),
        dictgen::InsensitiveStr::Ascii("chizablest"),
        dictgen::InsensitiveStr::Ascii("chization"),
        dictgen::InsensitiveStr::Ascii("chizations"),
        dictgen::InsensitiveStr::Ascii("chize"),
        dictgen::InsensitiveStr::Ascii("chized"),
        dictgen::InsensitiveStr::Ascii("chizer"),
        dictgen::InsensitiveStr::Ascii("chizers"),
        dictgen::InsensitiveStr::Ascii("chizes"),
        dictgen::InsensitiveStr::Ascii("chizing"),
        dictgen::InsensitiveStr::Ascii("chizings"),
        dictgen::InsensitiveStr::Ascii("gorisation"),
        dictgen::InsensitiveStr::Ascii("gorisations"),
        dictgen::InsensitiveStr::Ascii("gorise"),
        dictgen::InsensitiveStr::Ascii("gorised"),
        dictgen::InsensitiveStr::Ascii("goriser"),
        dictgen::InsensitiveStr::Ascii("gorisers"),
        dictgen::InsensitiveStr::Ascii("gorises"),
        dictgen::InsensitiveStr::Ascii("gorising"),
        dictgen::InsensitiveStr::Ascii("gorization"),
        dictgen::InsensitiveStr::Ascii("gorizations"),
        dictgen::InsensitiveStr::Ascii("gorize"),
        dictgen::InsensitiveStr::Ascii("gorized"),
        dictgen::InsensitiveStr::Ascii("gorizer"),
        dictgen::InsensitiveStr::Ascii("gorizers"),
        dictgen::InsensitiveStr::Ascii("gorizes"),
        dictgen::InsensitiveStr::Ascii("gorizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CATECHIZABLE_8282651021901386912)],
        &[(0b10010, &ENTRY_CATECHIZABLER_5689981000220656601)],
        &[(0b10010, &ENTRY_CATECHIZABLES_10992088782460228856)],
        &[(0b10010, &ENTRY_CATECHIZABLEST_7714292286287558770)],
        &[(0b10010, &ENTRY_CATECHIZATION_12810249719668086283)],
        &[(0b10010, &ENTRY_CATECHIZATIONS_7241271747980004634)],
        &[(0b10010, &ENTRY_CATECHIZE_4522606049079804123)],
        &[(0b10010, &ENTRY_CATECHIZED_8126030264531245281)],
        &[(0b10010, &ENTRY_CATECHIZER_8253596747885095438)],
        &[(0b10010, &ENTRY_CATECHIZERS_10089039414007893489)],
        &[(0b10010, &ENTRY_CATECHIZES_9034465079743774482)],
        &[(0b10010, &ENTRY_CATECHIZING_12487941153933575504)],
        &[(0b10010, &ENTRY_CATECHIZINGS_5519486100889374813)],
        &[(0b01001, &ENTRY_CATECHIZABLE_8282651021901386912)],
        &[(0b01001, &ENTRY_CATECHIZABLER_5689981000220656601)],
        &[(0b01001, &ENTRY_CATECHIZABLES_10992088782460228856)],
        &[(0b01001, &ENTRY_CATECHIZABLEST_7714292286287558770)],
        &[(0b01001, &ENTRY_CATECHIZATION_12810249719668086283)],
        &[(0b01001, &ENTRY_CATECHIZATIONS_7241271747980004634)],
        &[(0b01001, &ENTRY_CATECHIZE_4522606049079804123)],
        &[(0b01001, &ENTRY_CATECHIZED_8126030264531245281)],
        &[(0b01001, &ENTRY_CATECHIZER_8253596747885095438)],
        &[(0b01001, &ENTRY_CATECHIZERS_10089039414007893489)],
        &[(0b01001, &ENTRY_CATECHIZES_9034465079743774482)],
        &[(0b01001, &ENTRY_CATECHIZING_12487941153933575504)],
        &[(0b01001, &ENTRY_CATECHIZINGS_5519486100889374813)],
        &[(0b10010, &ENTRY_CATEGORIZATION_8749709687767811950)],
        &[(0b10010, &ENTRY_CATEGORIZATIONS_16612628821035244612)],
        &[(0b10010, &ENTRY_CATEGORIZE_12360966269850201965)],
        &[(0b10010, &ENTRY_CATEGORIZED_4533542698041220795)],
        &[(0b10010, &ENTRY_CATEGORIZER_7305291735145100306)],
        &[(0b10010, &ENTRY_CATEGORIZERS_7439137280162913189)],
        &[(0b10010, &ENTRY_CATEGORIZES_3536341508655848694)],
        &[(0b10010, &ENTRY_CATEGORIZING_961096799238536775)],
        &[(0b01001, &ENTRY_CATEGORIZATION_8749709687767811950)],
        &[(0b01001, &ENTRY_CATEGORIZATIONS_16612628821035244612)],
        &[(0b01001, &ENTRY_CATEGORIZE_12360966269850201965)],
        &[(0b01001, &ENTRY_CATEGORIZED_4533542698041220795)],
        &[(0b01001, &ENTRY_CATEGORIZER_7305291735145100306)],
        &[(0b01001, &ENTRY_CATEGORIZERS_7439137280162913189)],
        &[(0b01001, &ENTRY_CATEGORIZES_3536341508655848694)],
        &[(0b01001, &ENTRY_CATEGORIZING_961096799238536775)],
    ],
    range: 5..=11,
};

static VARS_CATA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CATA_CHILDREN),
    value: None,
};

pub static VARS_CATA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bolise"),
        dictgen::InsensitiveStr::Ascii("bolize"),
        dictgen::InsensitiveStr::Ascii("log"),
        dictgen::InsensitiveStr::Ascii("loged"),
        dictgen::InsensitiveStr::Ascii("loger"),
        dictgen::InsensitiveStr::Ascii("logers"),
        dictgen::InsensitiveStr::Ascii("loging"),
        dictgen::InsensitiveStr::Ascii("logs"),
        dictgen::InsensitiveStr::Ascii("loguer"),
        dictgen::InsensitiveStr::Ascii("loguers"),
        dictgen::InsensitiveStr::Ascii("loguise"),
        dictgen::InsensitiveStr::Ascii("loguised"),
        dictgen::InsensitiveStr::Ascii("loguises"),
        dictgen::InsensitiveStr::Ascii("loguising"),
        dictgen::InsensitiveStr::Ascii("loguize"),
        dictgen::InsensitiveStr::Ascii("loguized"),
        dictgen::InsensitiveStr::Ascii("loguizes"),
        dictgen::InsensitiveStr::Ascii("loguizing"),
        dictgen::InsensitiveStr::Ascii("lyse"),
        dictgen::InsensitiveStr::Ascii("lysed"),
        dictgen::InsensitiveStr::Ascii("lyser"),
        dictgen::InsensitiveStr::Ascii("lysers"),
        dictgen::InsensitiveStr::Ascii("lysing"),
        dictgen::InsensitiveStr::Ascii("lyze"),
        dictgen::InsensitiveStr::Ascii("lyzed"),
        dictgen::InsensitiveStr::Ascii("lyzer"),
        dictgen::InsensitiveStr::Ascii("lyzers"),
        dictgen::InsensitiveStr::Ascii("lyzes"),
        dictgen::InsensitiveStr::Ascii("lyzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CATABOLIZE_1177290851351235880)],
        &[(0b01001, &ENTRY_CATABOLIZE_1177290851351235880)],
        &[(0b00001, &ENTRY_CATALOG_6854298310343011085)],
        &[(0b00001, &ENTRY_CATALOGED_17338507726872594232)],
        &[(0b00001, &ENTRY_CATALOGER_1036462752165445499)],
        &[(0b00001, &ENTRY_CATALOGERS_18141804906921168384)],
        &[(0b00001, &ENTRY_CATALOGING_8506877421439024861)],
        &[(0b00001, &ENTRY_CATALOGS_8518416776176012476)],
        &[(0b11010, &ENTRY_CATALOGER_1036462752165445499)],
        &[(0b11010, &ENTRY_CATALOGERS_18141804906921168384)],
        &[(0b10010, &ENTRY_CATALOGUIZE_1271806317788507924)],
        &[(0b10010, &ENTRY_CATALOGUIZED_4476989929563164358)],
        &[(0b10010, &ENTRY_CATALOGUIZES_3655562417907187515)],
        &[(0b10010, &ENTRY_CATALOGUIZING_15932890814645999252)],
        &[(0b01001, &ENTRY_CATALOGUIZE_1271806317788507924)],
        &[(0b01001, &ENTRY_CATALOGUIZED_4476989929563164358)],
        &[(0b01001, &ENTRY_CATALOGUIZES_3655562417907187515)],
        &[(0b01001, &ENTRY_CATALOGUIZING_15932890814645999252)],
        &[(0b11010, &ENTRY_CATALYZE_2004345719426635958)],
        &[(0b11010, &ENTRY_CATALYZED_14626193667566838732)],
        &[(0b11010, &ENTRY_CATALYZER_13103775222379027346)],
        &[(0b11010, &ENTRY_CATALYZERS_14386582083420565337)],
        &[(0b11010, &ENTRY_CATALYZING_5940201018784400445)],
        &[(0b01001, &ENTRY_CATALYZE_2004345719426635958)],
        &[(0b01001, &ENTRY_CATALYZED_14626193667566838732)],
        &[(0b00001, &ENTRY_CATALYZER_13103775222379027346)],
        &[(0b00001, &ENTRY_CATALYZERS_14386582083420565337)],
        &[(0b01001, &ENTRY_CATALYZES_14856767428712676497)],
        &[(0b01001, &ENTRY_CATALYZING_5940201018784400445)],
    ],
    range: 3..=9,
};

static VARS_CAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAS_CHILDREN),
    value: None,
};

pub static VARS_CAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("torised"),
        dictgen::InsensitiveStr::Ascii("toriseds"),
        dictgen::InsensitiveStr::Ascii("torized"),
        dictgen::InsensitiveStr::Ascii("torizeds"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CASTORIZED_17799018914377706815)],
        &[(0b10010, &ENTRY_CASTORIZEDS_7380053523540664448)],
        &[(0b01001, &ENTRY_CASTORIZED_17799018914377706815)],
        &[(0b01001, &ENTRY_CASTORIZEDS_7380053523540664448)],
        &[(0b10010, &ENTRY_CASUALIZATION_12871483932151068766)],
        &[(0b10010, &ENTRY_CASUALIZATIONS_4776592355861975796)],
        &[(0b10010, &ENTRY_CASUALIZE_10803983540374652623)],
        &[(0b10010, &ENTRY_CASUALIZED_3173806408429929886)],
        &[(0b10010, &ENTRY_CASUALIZES_2357569365432878510)],
        &[(0b10010, &ENTRY_CASUALIZING_16345100801087952198)],
        &[(0b01001, &ENTRY_CASUALIZATION_12871483932151068766)],
        &[(0b01001, &ENTRY_CASUALIZATIONS_4776592355861975796)],
        &[(0b01001, &ENTRY_CASUALIZE_10803983540374652623)],
        &[(0b01001, &ENTRY_CASUALIZED_3173806408429929886)],
        &[(0b01001, &ENTRY_CASUALIZES_2357569365432878510)],
        &[(0b01001, &ENTRY_CASUALIZING_16345100801087952198)],
    ],
    range: 6..=11,
};

static VARS_CAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CAR_CHILDREN),
    value: None,
};

static VARS_CAR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CARA_NODE),
    Some(&VARS_CARB_NODE),
    None,
    Some(&VARS_CARD_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_CARN_NODE),
    Some(&VARS_CARO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CART_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CART_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CART_CHILDREN),
    value: None,
};

pub static VARS_CART_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elisations"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elizations"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("elizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CARTELIZATION_1802711991797389087)],
        &[(0b10010, &ENTRY_CARTELIZATIONS_15852914117827138645)],
        &[(0b10010, &ENTRY_CARTELIZE_7454101035459734890)],
        &[(0b10010, &ENTRY_CARTELIZED_9927132532859356643)],
        &[(0b10010, &ENTRY_CARTELIZES_14469260606626523795)],
        &[(0b10010, &ENTRY_CARTELIZING_16082986042795613861)],
        &[(0b01001, &ENTRY_CARTELIZATION_1802711991797389087)],
        &[(0b01001, &ENTRY_CARTELIZATIONS_15852914117827138645)],
        &[(0b01001, &ENTRY_CARTELIZE_7454101035459734890)],
        &[(0b01001, &ENTRY_CARTELIZED_9927132532859356643)],
        &[(0b01001, &ENTRY_CARTELIZES_14469260606626523795)],
        &[(0b01001, &ENTRY_CARTELIZING_16082986042795613861)],
    ],
    range: 5..=10,
};

static VARS_CARO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARO_CHILDREN),
    value: None,
};

pub static VARS_CARO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("tinaemia"),
        dictgen::InsensitiveStr::Ascii("tinemia"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CAROLED_10588023811542781156)],
        &[(0b00001, &ENTRY_CAROLER_7480138065296781672)],
        &[(0b00001, &ENTRY_CAROLERS_10675807177319949622)],
        &[(0b00001, &ENTRY_CAROLING_1021261814376249053)],
        &[(0b11010, &ENTRY_CAROLED_10588023811542781156)],
        &[(0b11010, &ENTRY_CAROLER_7480138065296781672)],
        &[(0b11010, &ENTRY_CAROLERS_10675807177319949622)],
        &[(0b11010, &ENTRY_CAROLING_1021261814376249053)],
        &[(0b11010, &ENTRY_CAROTINEMIA_10522117710609229159)],
        &[(0b10001, &ENTRY_CAROTINEMIA_10522117710609229159)],
    ],
    range: 3..=8,
};

static VARS_CARN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARN_CHILDREN),
    value: None,
};

pub static VARS_CARN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CARNALIZE_5475208533929563421)],
        &[(0b10010, &ENTRY_CARNALIZED_7768933264922371251)],
        &[(0b10010, &ENTRY_CARNALIZES_5581084477739167595)],
        &[(0b10010, &ENTRY_CARNALIZING_6431076956231586367)],
        &[(0b01001, &ENTRY_CARNALIZE_5475208533929563421)],
        &[(0b01001, &ENTRY_CARNALIZED_7768933264922371251)],
        &[(0b01001, &ENTRY_CARNALIZES_5581084477739167595)],
        &[(0b01001, &ENTRY_CARNALIZING_6431076956231586367)],
    ],
    range: 5..=7,
};

static VARS_CARD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARD_CHILDREN),
    value: None,
};

pub static VARS_CARD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iae"),
        dictgen::InsensitiveStr::Ascii("ie"),
        dictgen::InsensitiveStr::Ascii("uelinae"),
        dictgen::InsensitiveStr::Ascii("ueline"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CARDIE_2205350999715185435)],
        &[(0b00001, &ENTRY_CARDIE_2205350999715185435)],
        &[(0b11010, &ENTRY_CARDUELINE_17268913123311282389)],
        &[(0b00001, &ENTRY_CARDUELINE_17268913123311282389)],
    ],
    range: 2..=7,
};

static VARS_CARB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARB_CHILDREN),
    value: None,
};

pub static VARS_CARB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olisation"),
        dictgen::InsensitiveStr::Ascii("olise"),
        dictgen::InsensitiveStr::Ascii("olised"),
        dictgen::InsensitiveStr::Ascii("olises"),
        dictgen::InsensitiveStr::Ascii("olising"),
        dictgen::InsensitiveStr::Ascii("olization"),
        dictgen::InsensitiveStr::Ascii("olize"),
        dictgen::InsensitiveStr::Ascii("olized"),
        dictgen::InsensitiveStr::Ascii("olizes"),
        dictgen::InsensitiveStr::Ascii("olizing"),
        dictgen::InsensitiveStr::Ascii("onades"),
        dictgen::InsensitiveStr::Ascii("onadoes"),
        dictgen::InsensitiveStr::Ascii("onatisation"),
        dictgen::InsensitiveStr::Ascii("onatisations"),
        dictgen::InsensitiveStr::Ascii("onatization"),
        dictgen::InsensitiveStr::Ascii("onatizations"),
        dictgen::InsensitiveStr::Ascii("onisable"),
        dictgen::InsensitiveStr::Ascii("onisabler"),
        dictgen::InsensitiveStr::Ascii("onisables"),
        dictgen::InsensitiveStr::Ascii("onisablest"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onisers"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onizable"),
        dictgen::InsensitiveStr::Ascii("onizabler"),
        dictgen::InsensitiveStr::Ascii("onizables"),
        dictgen::InsensitiveStr::Ascii("onizablest"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizers"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("uretor"),
        dictgen::InsensitiveStr::Ascii("uretors"),
        dictgen::InsensitiveStr::Ascii("uretter"),
        dictgen::InsensitiveStr::Ascii("uretters"),
        dictgen::InsensitiveStr::Ascii("urettor"),
        dictgen::InsensitiveStr::Ascii("urettors"),
        dictgen::InsensitiveStr::Ascii("urisation"),
        dictgen::InsensitiveStr::Ascii("urisations"),
        dictgen::InsensitiveStr::Ascii("urise"),
        dictgen::InsensitiveStr::Ascii("urised"),
        dictgen::InsensitiveStr::Ascii("uriser"),
        dictgen::InsensitiveStr::Ascii("urises"),
        dictgen::InsensitiveStr::Ascii("urising"),
        dictgen::InsensitiveStr::Ascii("urization"),
        dictgen::InsensitiveStr::Ascii("urizations"),
        dictgen::InsensitiveStr::Ascii("urize"),
        dictgen::InsensitiveStr::Ascii("urized"),
        dictgen::InsensitiveStr::Ascii("urizer"),
        dictgen::InsensitiveStr::Ascii("urizes"),
        dictgen::InsensitiveStr::Ascii("urizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CARBOLIZATION_16908167377588079008)],
        &[(0b10010, &ENTRY_CARBOLIZE_10498092873125902774)],
        &[(0b10010, &ENTRY_CARBOLIZED_3610204407073437611)],
        &[(0b10010, &ENTRY_CARBOLIZES_16280869006659938468)],
        &[(0b10010, &ENTRY_CARBOLIZING_10944405222501443697)],
        &[(0b01001, &ENTRY_CARBOLIZATION_16908167377588079008)],
        &[(0b01001, &ENTRY_CARBOLIZE_10498092873125902774)],
        &[(0b01001, &ENTRY_CARBOLIZED_3610204407073437611)],
        &[(0b01001, &ENTRY_CARBOLIZES_16280869006659938468)],
        &[(0b01001, &ENTRY_CARBOLIZING_10944405222501443697)],
        &[(0b00001, &ENTRY_CARBONADES_5678712770354789721)],
        &[(0b11010, &ENTRY_CARBONADES_5678712770354789721)],
        &[(0b10010, &ENTRY_CARBONATIZATION_5251252289578036221)],
        &[(0b10010, &ENTRY_CARBONATIZATIONS_10498315283198909416)],
        &[(0b01001, &ENTRY_CARBONATIZATION_5251252289578036221)],
        &[(0b01001, &ENTRY_CARBONATIZATIONS_10498315283198909416)],
        &[(0b10010, &ENTRY_CARBONIZABLE_7275477916888704155)],
        &[(0b10010, &ENTRY_CARBONIZABLER_11011547734927627020)],
        &[(0b10010, &ENTRY_CARBONIZABLES_4143576460831039714)],
        &[(0b10010, &ENTRY_CARBONIZABLEST_112885352202057431)],
        &[(0b10010, &ENTRY_CARBONIZATION_11122364629547796220)],
        &[(0b10010, &ENTRY_CARBONIZATIONS_6111370292147685550)],
        &[(0b10010, &ENTRY_CARBONIZE_16235242288107272785)],
        &[(0b10010, &ENTRY_CARBONIZED_14795079813785129130)],
        &[(0b10010, &ENTRY_CARBONIZER_12348552524098629169)],
        &[(0b10010, &ENTRY_CARBONIZERS_13712244721486829214)],
        &[(0b10010, &ENTRY_CARBONIZES_14523315792081641044)],
        &[(0b10010, &ENTRY_CARBONIZING_6968560222274215193)],
        &[(0b01001, &ENTRY_CARBONIZABLE_7275477916888704155)],
        &[(0b01001, &ENTRY_CARBONIZABLER_11011547734927627020)],
        &[(0b01001, &ENTRY_CARBONIZABLES_4143576460831039714)],
        &[(0b01001, &ENTRY_CARBONIZABLEST_112885352202057431)],
        &[(0b01001, &ENTRY_CARBONIZATION_11122364629547796220)],
        &[(0b01001, &ENTRY_CARBONIZATIONS_6111370292147685550)],
        &[(0b01001, &ENTRY_CARBONIZE_16235242288107272785)],
        &[(0b01001, &ENTRY_CARBONIZED_14795079813785129130)],
        &[(0b01001, &ENTRY_CARBONIZER_12348552524098629169)],
        &[(0b01001, &ENTRY_CARBONIZERS_13712244721486829214)],
        &[(0b01001, &ENTRY_CARBONIZES_14523315792081641044)],
        &[(0b01001, &ENTRY_CARBONIZING_6968560222274215193)],
        &[(0b00001, &ENTRY_CARBURETOR_3718140921594640872)],
        &[(0b00001, &ENTRY_CARBURETORS_16992407598754998108)],
        &[(0b11010, &ENTRY_CARBURETOR_3718140921594640872)],
        &[(0b11010, &ENTRY_CARBURETORS_16992407598754998108)],
        &[(0b11010, &ENTRY_CARBURETOR_3718140921594640872)],
        &[(0b11010, &ENTRY_CARBURETORS_16992407598754998108)],
        &[(0b10010, &ENTRY_CARBURIZATION_14186154773415871277)],
        &[(0b10010, &ENTRY_CARBURIZATIONS_4288822688136593112)],
        &[(0b10010, &ENTRY_CARBURIZE_886066375006540244)],
        &[(0b10010, &ENTRY_CARBURIZED_2653066621032127976)],
        &[(0b10010, &ENTRY_CARBURIZER_1120017158252509510)],
        &[(0b10010, &ENTRY_CARBURIZES_2604386355014205446)],
        &[(0b10010, &ENTRY_CARBURIZING_14362267205170352071)],
        &[(0b01001, &ENTRY_CARBURIZATION_14186154773415871277)],
        &[(0b01001, &ENTRY_CARBURIZATIONS_4288822688136593112)],
        &[(0b01001, &ENTRY_CARBURIZE_886066375006540244)],
        &[(0b01001, &ENTRY_CARBURIZED_2653066621032127976)],
        &[(0b01001, &ENTRY_CARBURIZER_1120017158252509510)],
        &[(0b01001, &ENTRY_CARBURIZES_2604386355014205446)],
        &[(0b01001, &ENTRY_CARBURIZING_14362267205170352071)],
    ],
    range: 5..=12,
};

static VARS_CARA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CARA_CHILDREN),
    value: None,
};

pub static VARS_CARA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("coled"),
        dictgen::InsensitiveStr::Ascii("coling"),
        dictgen::InsensitiveStr::Ascii("colled"),
        dictgen::InsensitiveStr::Ascii("colling"),
        dictgen::InsensitiveStr::Ascii("melisation"),
        dictgen::InsensitiveStr::Ascii("melisations"),
        dictgen::InsensitiveStr::Ascii("melise"),
        dictgen::InsensitiveStr::Ascii("melised"),
        dictgen::InsensitiveStr::Ascii("melises"),
        dictgen::InsensitiveStr::Ascii("melising"),
        dictgen::InsensitiveStr::Ascii("melization"),
        dictgen::InsensitiveStr::Ascii("melizations"),
        dictgen::InsensitiveStr::Ascii("melize"),
        dictgen::InsensitiveStr::Ascii("melized"),
        dictgen::InsensitiveStr::Ascii("melizes"),
        dictgen::InsensitiveStr::Ascii("melizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CARACOLED_8083634779350238799)],
        &[(0b00001, &ENTRY_CARACOLING_4913840131879532625)],
        &[(0b11010, &ENTRY_CARACOLED_8083634779350238799)],
        &[(0b11010, &ENTRY_CARACOLING_4913840131879532625)],
        &[(0b10010, &ENTRY_CARAMELIZATION_12261843451362374441)],
        &[(0b10010, &ENTRY_CARAMELIZATIONS_16073975104161787099)],
        &[(0b10010, &ENTRY_CARAMELIZE_15122592141568398862)],
        &[(0b10010, &ENTRY_CARAMELIZED_3143066068548786354)],
        &[(0b10010, &ENTRY_CARAMELIZES_12354251654432497813)],
        &[(0b10010, &ENTRY_CARAMELIZING_10890268661953323278)],
        &[(0b01001, &ENTRY_CARAMELIZATION_12261843451362374441)],
        &[(0b01001, &ENTRY_CARAMELIZATIONS_16073975104161787099)],
        &[(0b01001, &ENTRY_CARAMELIZE_15122592141568398862)],
        &[(0b01001, &ENTRY_CARAMELIZED_3143066068548786354)],
        &[(0b01001, &ENTRY_CARAMELIZES_12354251654432497813)],
        &[(0b01001, &ENTRY_CARAMELIZING_10890268661953323278)],
    ],
    range: 5..=11,
};

static VARS_CAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAP_CHILDREN),
    value: None,
};

pub static VARS_CAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("italisable"),
        dictgen::InsensitiveStr::Ascii("italisabler"),
        dictgen::InsensitiveStr::Ascii("italisables"),
        dictgen::InsensitiveStr::Ascii("italisablest"),
        dictgen::InsensitiveStr::Ascii("italisation"),
        dictgen::InsensitiveStr::Ascii("italisations"),
        dictgen::InsensitiveStr::Ascii("italise"),
        dictgen::InsensitiveStr::Ascii("italised"),
        dictgen::InsensitiveStr::Ascii("italiser"),
        dictgen::InsensitiveStr::Ascii("italisers"),
        dictgen::InsensitiveStr::Ascii("italises"),
        dictgen::InsensitiveStr::Ascii("italising"),
        dictgen::InsensitiveStr::Ascii("italizable"),
        dictgen::InsensitiveStr::Ascii("italizabler"),
        dictgen::InsensitiveStr::Ascii("italizables"),
        dictgen::InsensitiveStr::Ascii("italizablest"),
        dictgen::InsensitiveStr::Ascii("italization"),
        dictgen::InsensitiveStr::Ascii("italizations"),
        dictgen::InsensitiveStr::Ascii("italize"),
        dictgen::InsensitiveStr::Ascii("italized"),
        dictgen::InsensitiveStr::Ascii("italizer"),
        dictgen::InsensitiveStr::Ascii("italizers"),
        dictgen::InsensitiveStr::Ascii("italizes"),
        dictgen::InsensitiveStr::Ascii("italizing"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("oniser"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizer"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("sulisation"),
        dictgen::InsensitiveStr::Ascii("sulise"),
        dictgen::InsensitiveStr::Ascii("sulised"),
        dictgen::InsensitiveStr::Ascii("sulises"),
        dictgen::InsensitiveStr::Ascii("sulising"),
        dictgen::InsensitiveStr::Ascii("sulization"),
        dictgen::InsensitiveStr::Ascii("sulize"),
        dictgen::InsensitiveStr::Ascii("sulized"),
        dictgen::InsensitiveStr::Ascii("sulizes"),
        dictgen::InsensitiveStr::Ascii("sulizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CAPITALIZABLE_1765975557696773459)],
        &[(0b10010, &ENTRY_CAPITALIZABLER_17031718845693435382)],
        &[(0b10010, &ENTRY_CAPITALIZABLES_12918035538804552826)],
        &[(0b10010, &ENTRY_CAPITALIZABLEST_6136542042922432603)],
        &[(0b10010, &ENTRY_CAPITALIZATION_12627331264579480739)],
        &[(0b10010, &ENTRY_CAPITALIZATIONS_4554225755737415935)],
        &[(0b10010, &ENTRY_CAPITALIZE_8725562284183074279)],
        &[(0b10010, &ENTRY_CAPITALIZED_15025949045206025922)],
        &[(0b10010, &ENTRY_CAPITALIZER_15938335196315218634)],
        &[(0b10010, &ENTRY_CAPITALIZERS_10517751249028432560)],
        &[(0b10010, &ENTRY_CAPITALIZES_16323417076992732600)],
        &[(0b10010, &ENTRY_CAPITALIZING_2512967533316213598)],
        &[(0b01001, &ENTRY_CAPITALIZABLE_1765975557696773459)],
        &[(0b01001, &ENTRY_CAPITALIZABLER_17031718845693435382)],
        &[(0b01001, &ENTRY_CAPITALIZABLES_12918035538804552826)],
        &[(0b01001, &ENTRY_CAPITALIZABLEST_6136542042922432603)],
        &[(0b01001, &ENTRY_CAPITALIZATION_12627331264579480739)],
        &[(0b01001, &ENTRY_CAPITALIZATIONS_4554225755737415935)],
        &[(0b01001, &ENTRY_CAPITALIZE_8725562284183074279)],
        &[(0b01001, &ENTRY_CAPITALIZED_15025949045206025922)],
        &[(0b01001, &ENTRY_CAPITALIZER_15938335196315218634)],
        &[(0b01001, &ENTRY_CAPITALIZERS_10517751249028432560)],
        &[(0b01001, &ENTRY_CAPITALIZES_16323417076992732600)],
        &[(0b01001, &ENTRY_CAPITALIZING_2512967533316213598)],
        &[(0b10010, &ENTRY_CAPONIZATION_1938263787545597969)],
        &[(0b10010, &ENTRY_CAPONIZE_17964447872816434047)],
        &[(0b10010, &ENTRY_CAPONIZED_14836958589299432160)],
        &[(0b10010, &ENTRY_CAPONIZER_5653304916609979245)],
        &[(0b10010, &ENTRY_CAPONIZES_8415080645445299415)],
        &[(0b10010, &ENTRY_CAPONIZING_12126070973152497349)],
        &[(0b01001, &ENTRY_CAPONIZATION_1938263787545597969)],
        &[(0b01001, &ENTRY_CAPONIZE_17964447872816434047)],
        &[(0b01001, &ENTRY_CAPONIZED_14836958589299432160)],
        &[(0b01001, &ENTRY_CAPONIZER_5653304916609979245)],
        &[(0b01001, &ENTRY_CAPONIZES_8415080645445299415)],
        &[(0b01001, &ENTRY_CAPONIZING_12126070973152497349)],
        &[(0b10010, &ENTRY_CAPSULIZATION_1378111058341821834)],
        &[(0b10010, &ENTRY_CAPSULIZE_7935266522075201942)],
        &[(0b10010, &ENTRY_CAPSULIZED_14587057948214962939)],
        &[(0b10010, &ENTRY_CAPSULIZES_12567539512302131751)],
        &[(0b10010, &ENTRY_CAPSULIZING_7016335058787637735)],
        &[(0b01001, &ENTRY_CAPSULIZATION_1378111058341821834)],
        &[(0b01001, &ENTRY_CAPSULIZE_7935266522075201942)],
        &[(0b01001, &ENTRY_CAPSULIZED_14587057948214962939)],
        &[(0b01001, &ENTRY_CAPSULIZES_12567539512302131751)],
        &[(0b01001, &ENTRY_CAPSULIZING_7016335058787637735)],
    ],
    range: 5..=12,
};

static VARS_CAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_CAN_CHILDREN),
    value: None,
};

static VARS_CAN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_CANA_NODE),
    None,
    Some(&VARS_CANC_NODE),
    Some(&VARS_CAND_NODE),
    Some(&VARS_CANE_NODE),
    None,
    None,
    None,
    Some(&VARS_CANI_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CANN_NODE),
    Some(&VARS_CANO_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_CANT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_CANT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANT_CHILDREN),
    value: None,
};

pub static VARS_CANT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aloup"),
        dictgen::InsensitiveStr::Ascii("aloups"),
        dictgen::InsensitiveStr::Ascii("onisation"),
        dictgen::InsensitiveStr::Ascii("onisations"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onization"),
        dictgen::InsensitiveStr::Ascii("onizations"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
    ],
    values: &[
        &[(0b01001, &ENTRY_CANTALOUPE_7760362447914940621)],
        &[(0b01001, &ENTRY_CANTALOUPES_10789009086995967817)],
        &[(0b10010, &ENTRY_CANTONIZATION_6677109296433610186)],
        &[(0b10010, &ENTRY_CANTONIZATIONS_17246812416090811840)],
        &[(0b10010, &ENTRY_CANTONIZE_1640483783874964493)],
        &[(0b10010, &ENTRY_CANTONIZED_759359507372098389)],
        &[(0b10010, &ENTRY_CANTONIZES_10832472956122974528)],
        &[(0b10010, &ENTRY_CANTONIZING_12871143996405253104)],
        &[(0b01001, &ENTRY_CANTONIZATION_6677109296433610186)],
        &[(0b01001, &ENTRY_CANTONIZATIONS_17246812416090811840)],
        &[(0b01001, &ENTRY_CANTONIZE_1640483783874964493)],
        &[(0b01001, &ENTRY_CANTONIZED_759359507372098389)],
        &[(0b01001, &ENTRY_CANTONIZES_10832472956122974528)],
        &[(0b01001, &ENTRY_CANTONIZING_12871143996405253104)],
    ],
    range: 5..=10,
};

static VARS_CANO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANO_CHILDREN),
    value: None,
};

pub static VARS_CANO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nicalisation"),
        dictgen::InsensitiveStr::Ascii("nicalise"),
        dictgen::InsensitiveStr::Ascii("nicalised"),
        dictgen::InsensitiveStr::Ascii("nicalises"),
        dictgen::InsensitiveStr::Ascii("nicalising"),
        dictgen::InsensitiveStr::Ascii("nicalization"),
        dictgen::InsensitiveStr::Ascii("nicalize"),
        dictgen::InsensitiveStr::Ascii("nicalized"),
        dictgen::InsensitiveStr::Ascii("nicalizes"),
        dictgen::InsensitiveStr::Ascii("nicalizing"),
        dictgen::InsensitiveStr::Ascii("nisation"),
        dictgen::InsensitiveStr::Ascii("nisations"),
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nization"),
        dictgen::InsensitiveStr::Ascii("nizations"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CANONICALIZATION_7999615851945801309)],
        &[(0b10010, &ENTRY_CANONICALIZE_2632431567177056192)],
        &[(0b10010, &ENTRY_CANONICALIZED_11250167296463797072)],
        &[(0b10010, &ENTRY_CANONICALIZES_18227657368670160690)],
        &[(0b10010, &ENTRY_CANONICALIZING_1431614031305230237)],
        &[(0b01001, &ENTRY_CANONICALIZATION_7999615851945801309)],
        &[(0b01001, &ENTRY_CANONICALIZE_2632431567177056192)],
        &[(0b01001, &ENTRY_CANONICALIZED_11250167296463797072)],
        &[(0b01001, &ENTRY_CANONICALIZES_18227657368670160690)],
        &[(0b01001, &ENTRY_CANONICALIZING_1431614031305230237)],
        &[(0b10010, &ENTRY_CANONIZATION_5080602976142523102)],
        &[(0b10010, &ENTRY_CANONIZATIONS_15946456967388997441)],
        &[(0b10010, &ENTRY_CANONIZE_7683068140953197405)],
        &[(0b10010, &ENTRY_CANONIZED_4794312694447620033)],
        &[(0b10010, &ENTRY_CANONIZER_17140136837292538642)],
        &[(0b10010, &ENTRY_CANONIZERS_1059373452134645246)],
        &[(0b10010, &ENTRY_CANONIZES_17683915838157001675)],
        &[(0b10010, &ENTRY_CANONIZING_8668155521149668521)],
        &[(0b01001, &ENTRY_CANONIZATION_5080602976142523102)],
        &[(0b01001, &ENTRY_CANONIZATIONS_15946456967388997441)],
        &[(0b01001, &ENTRY_CANONIZE_7683068140953197405)],
        &[(0b01001, &ENTRY_CANONIZED_4794312694447620033)],
        &[(0b01001, &ENTRY_CANONIZER_17140136837292538642)],
        &[(0b01001, &ENTRY_CANONIZERS_1059373452134645246)],
        &[(0b01001, &ENTRY_CANONIZES_17683915838157001675)],
        &[(0b01001, &ENTRY_CANONIZING_8668155521149668521)],
    ],
    range: 4..=12,
};

static VARS_CANN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANN_CHILDREN),
    value: None,
};

pub static VARS_CANN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ibalisation"),
        dictgen::InsensitiveStr::Ascii("ibalisations"),
        dictgen::InsensitiveStr::Ascii("ibalise"),
        dictgen::InsensitiveStr::Ascii("ibalised"),
        dictgen::InsensitiveStr::Ascii("ibalises"),
        dictgen::InsensitiveStr::Ascii("ibalising"),
        dictgen::InsensitiveStr::Ascii("ibalization"),
        dictgen::InsensitiveStr::Ascii("ibalizations"),
        dictgen::InsensitiveStr::Ascii("ibalize"),
        dictgen::InsensitiveStr::Ascii("ibalized"),
        dictgen::InsensitiveStr::Ascii("ibalizes"),
        dictgen::InsensitiveStr::Ascii("ibalizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CANNIBALIZATION_7240357016697451118)],
        &[(0b10010, &ENTRY_CANNIBALIZATIONS_14659207523926251323)],
        &[(0b10010, &ENTRY_CANNIBALIZE_6390598440678018772)],
        &[(0b10010, &ENTRY_CANNIBALIZED_8169504218362659851)],
        &[(0b10010, &ENTRY_CANNIBALIZES_7622852839420143979)],
        &[(0b10010, &ENTRY_CANNIBALIZING_12609939168668624233)],
        &[(0b01001, &ENTRY_CANNIBALIZATION_7240357016697451118)],
        &[(0b01001, &ENTRY_CANNIBALIZATIONS_14659207523926251323)],
        &[(0b01001, &ENTRY_CANNIBALIZE_6390598440678018772)],
        &[(0b01001, &ENTRY_CANNIBALIZED_8169504218362659851)],
        &[(0b01001, &ENTRY_CANNIBALIZES_7622852839420143979)],
        &[(0b01001, &ENTRY_CANNIBALIZING_12609939168668624233)],
    ],
    range: 7..=12,
};

static VARS_CANI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANI_CHILDREN),
    value: None,
};

pub static VARS_CANI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sterisation"),
        dictgen::InsensitiveStr::Ascii("sterisations"),
        dictgen::InsensitiveStr::Ascii("sterise"),
        dictgen::InsensitiveStr::Ascii("sterised"),
        dictgen::InsensitiveStr::Ascii("sterises"),
        dictgen::InsensitiveStr::Ascii("sterising"),
        dictgen::InsensitiveStr::Ascii("sterization"),
        dictgen::InsensitiveStr::Ascii("sterizations"),
        dictgen::InsensitiveStr::Ascii("sterize"),
        dictgen::InsensitiveStr::Ascii("sterized"),
        dictgen::InsensitiveStr::Ascii("sterizes"),
        dictgen::InsensitiveStr::Ascii("sterizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CANISTERIZATION_9994917120138811095)],
        &[(0b10010, &ENTRY_CANISTERIZATIONS_16175257743062965718)],
        &[(0b10010, &ENTRY_CANISTERIZE_3823751102053887281)],
        &[(0b10010, &ENTRY_CANISTERIZED_11516075806659176774)],
        &[(0b10010, &ENTRY_CANISTERIZES_8707191536977720595)],
        &[(0b10010, &ENTRY_CANISTERIZING_3833251549971264383)],
        &[(0b01001, &ENTRY_CANISTERIZATION_9994917120138811095)],
        &[(0b01001, &ENTRY_CANISTERIZATIONS_16175257743062965718)],
        &[(0b01001, &ENTRY_CANISTERIZE_3823751102053887281)],
        &[(0b01001, &ENTRY_CANISTERIZED_11516075806659176774)],
        &[(0b01001, &ENTRY_CANISTERIZES_8707191536977720595)],
        &[(0b01001, &ENTRY_CANISTERIZING_3833251549971264383)],
    ],
    range: 7..=12,
};

static VARS_CANE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANE_CHILDREN),
    value: None,
};

pub static VARS_CANE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("phorae"),
        dictgen::InsensitiveStr::Ascii("phore"),
        dictgen::InsensitiveStr::Ascii("phoroe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CANEPHORE_6434692370350146164)],
        &[
            (0b00001, &ENTRY_CANEPHORE_10522331887025347806),
            (0b00001, &ENTRY_CANEPHORE_6434692370350146164),
        ],
        &[(0b11010, &ENTRY_CANEPHORE_10522331887025347806)],
    ],
    range: 5..=6,
};

static VARS_CAND_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAND_CHILDREN),
    value: None,
};

pub static VARS_CAND_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_CANDOR_14808094384111961913)],
        &[(0b11001, &ENTRY_CANDORS_352105524503647274)],
        &[(0b11010, &ENTRY_CANDOR_14808094384111961913)],
        &[(0b11010, &ENTRY_CANDORS_352105524503647274)],
    ],
    range: 2..=4,
};

static VARS_CANC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANC_CHILDREN),
    value: None,
};

pub static VARS_CANC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elable"),
        dictgen::InsensitiveStr::Ascii("elate"),
        dictgen::InsensitiveStr::Ascii("elated"),
        dictgen::InsensitiveStr::Ascii("elation"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("ellous"),
        dictgen::InsensitiveStr::Ascii("elous"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CANCELABLE_3744022220960108237)],
        &[(0b00001, &ENTRY_CANCELATE_11514029187019320804)],
        &[(0b00001, &ENTRY_CANCELATED_14737160893696822649)],
        &[(0b00001, &ENTRY_CANCELLATION_16186923162114662177)],
        &[(0b00001, &ENTRY_CANCELED_8509071628121806534)],
        &[(0b00001, &ENTRY_CANCELER_11336704721008790101)],
        &[(0b00001, &ENTRY_CANCELERS_843956304444885828)],
        &[(0b00001, &ENTRY_CANCELING_2043317365185195331)],
        &[(0b11010, &ENTRY_CANCELER_11336704721008790101)],
        &[(0b11010, &ENTRY_CANCELERS_843956304444885828)],
        &[(0b11010, &ENTRY_CANCELOUS_13432632612523726300)],
        &[(0b00001, &ENTRY_CANCELOUS_13432632612523726300)],
    ],
    range: 4..=7,
};

static VARS_CANA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CANA_CHILDREN),
    value: None,
};

pub static VARS_CANA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dianisation"),
        dictgen::InsensitiveStr::Ascii("dianisations"),
        dictgen::InsensitiveStr::Ascii("dianise"),
        dictgen::InsensitiveStr::Ascii("dianises"),
        dictgen::InsensitiveStr::Ascii("dianization"),
        dictgen::InsensitiveStr::Ascii("dianizations"),
        dictgen::InsensitiveStr::Ascii("dianize"),
        dictgen::InsensitiveStr::Ascii("dianizes"),
        dictgen::InsensitiveStr::Ascii("led"),
        dictgen::InsensitiveStr::Ascii("ler"),
        dictgen::InsensitiveStr::Ascii("lers"),
        dictgen::InsensitiveStr::Ascii("ling"),
        dictgen::InsensitiveStr::Ascii("lisation"),
        dictgen::InsensitiveStr::Ascii("lisations"),
        dictgen::InsensitiveStr::Ascii("lise"),
        dictgen::InsensitiveStr::Ascii("lised"),
        dictgen::InsensitiveStr::Ascii("lises"),
        dictgen::InsensitiveStr::Ascii("lising"),
        dictgen::InsensitiveStr::Ascii("lization"),
        dictgen::InsensitiveStr::Ascii("lizations"),
        dictgen::InsensitiveStr::Ascii("lize"),
        dictgen::InsensitiveStr::Ascii("lized"),
        dictgen::InsensitiveStr::Ascii("lizes"),
        dictgen::InsensitiveStr::Ascii("lizing"),
        dictgen::InsensitiveStr::Ascii("lled"),
        dictgen::InsensitiveStr::Ascii("ller"),
        dictgen::InsensitiveStr::Ascii("llers"),
        dictgen::InsensitiveStr::Ascii("lling"),
        dictgen::InsensitiveStr::Ascii("naean"),
        dictgen::InsensitiveStr::Ascii("nean"),
    ],
    values: &[
        &[(0b10010, &ENTRY_CANADIANIZATION_11574644012372626466)],
        &[(0b10010, &ENTRY_CANADIANIZATIONS_406463589942768872)],
        &[(0b10010, &ENTRY_CANADIANIZE_16890380569827973630)],
        &[(0b10010, &ENTRY_CANADIANIZES_962660416621258364)],
        &[(0b01001, &ENTRY_CANADIANIZATION_11574644012372626466)],
        &[(0b01001, &ENTRY_CANADIANIZATIONS_406463589942768872)],
        &[(0b01001, &ENTRY_CANADIANIZE_16890380569827973630)],
        &[(0b01001, &ENTRY_CANADIANIZES_962660416621258364)],
        &[(0b00001, &ENTRY_CANALED_1837439099016219610)],
        &[(0b00001, &ENTRY_CANALER_18198043193093593287)],
        &[(0b00001, &ENTRY_CANALERS_7689806565376794966)],
        &[(0b00001, &ENTRY_CANALING_8814927178454078271)],
        &[(0b10010, &ENTRY_CANALIZATION_9901281941769542241)],
        &[(0b10010, &ENTRY_CANALIZATIONS_2935456196223694503)],
        &[(0b10010, &ENTRY_CANALIZE_911721963215339223)],
        &[(0b10010, &ENTRY_CANALIZED_5067325481202256530)],
        &[(0b10010, &ENTRY_CANALIZES_14989578106312573774)],
        &[(0b10010, &ENTRY_CANALIZING_4812741747649871906)],
        &[(0b01001, &ENTRY_CANALIZATION_9901281941769542241)],
        &[(0b01001, &ENTRY_CANALIZATIONS_2935456196223694503)],
        &[(0b01001, &ENTRY_CANALIZE_911721963215339223)],
        &[(0b01001, &ENTRY_CANALIZED_5067325481202256530)],
        &[(0b01001, &ENTRY_CANALIZES_14989578106312573774)],
        &[(0b01001, &ENTRY_CANALIZING_4812741747649871906)],
        &[(0b11010, &ENTRY_CANALED_1837439099016219610)],
        &[(0b11010, &ENTRY_CANALER_18198043193093593287)],
        &[(0b11010, &ENTRY_CANALERS_7689806565376794966)],
        &[(0b11010, &ENTRY_CANALING_8814927178454078271)],
        &[(0b11010, &ENTRY_CANANEAN_5897518141290055149)],
        &[(0b00001, &ENTRY_CANANEAN_5897518141290055149)],
    ],
    range: 3..=12,
};

static VARS_CAM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAM_CHILDREN),
    value: None,
};

pub static VARS_CAM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("isades"),
        dictgen::InsensitiveStr::Ascii("isadoes"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ize"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CAMISADES_11807808624178252595)],
        &[(0b11010, &ENTRY_CAMISADES_11807808624178252595)],
        &[(0b10010, &ENTRY_CAMIZE_10411458476841511707)],
        &[(0b01001, &ENTRY_CAMIZE_10411458476841511707)],
    ],
    range: 3..=7,
};

static VARS_CAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAL_CHILDREN),
    value: None,
};

pub static VARS_CAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ander"),
        dictgen::InsensitiveStr::Ascii("andre"),
        dictgen::InsensitiveStr::Ascii("caemia"),
        dictgen::InsensitiveStr::Ascii("cemia"),
        dictgen::InsensitiveStr::Ascii("dron"),
        dictgen::InsensitiveStr::Ascii("drons"),
        dictgen::InsensitiveStr::Ascii("endarisation"),
        dictgen::InsensitiveStr::Ascii("endarisations"),
        dictgen::InsensitiveStr::Ascii("endarise"),
        dictgen::InsensitiveStr::Ascii("endarised"),
        dictgen::InsensitiveStr::Ascii("endarises"),
        dictgen::InsensitiveStr::Ascii("endarising"),
        dictgen::InsensitiveStr::Ascii("endarization"),
        dictgen::InsensitiveStr::Ascii("endarizations"),
        dictgen::InsensitiveStr::Ascii("endarize"),
        dictgen::InsensitiveStr::Ascii("endarized"),
        dictgen::InsensitiveStr::Ascii("endarizes"),
        dictgen::InsensitiveStr::Ascii("endarizing"),
        dictgen::InsensitiveStr::Ascii("ender"),
        dictgen::InsensitiveStr::Ascii("endre"),
        dictgen::InsensitiveStr::Ascii("iber"),
        dictgen::InsensitiveStr::Ascii("ibers"),
        dictgen::InsensitiveStr::Ascii("ibre"),
        dictgen::InsensitiveStr::Ascii("ibres"),
        dictgen::InsensitiveStr::Ascii("isthenics"),
        dictgen::InsensitiveStr::Ascii("k"),
        dictgen::InsensitiveStr::Ascii("ked"),
        dictgen::InsensitiveStr::Ascii("king"),
        dictgen::InsensitiveStr::Ascii("kings"),
        dictgen::InsensitiveStr::Ascii("ks"),
        dictgen::InsensitiveStr::Ascii("liper"),
        dictgen::InsensitiveStr::Ascii("lipered"),
        dictgen::InsensitiveStr::Ascii("lipering"),
        dictgen::InsensitiveStr::Ascii("lipers"),
        dictgen::InsensitiveStr::Ascii("lirrhoae"),
        dictgen::InsensitiveStr::Ascii("lirrhoe"),
        dictgen::InsensitiveStr::Ascii("listhenics"),
        dictgen::InsensitiveStr::Ascii("odaemon"),
        dictgen::InsensitiveStr::Ascii("odemon"),
        dictgen::InsensitiveStr::Ascii("vinise"),
        dictgen::InsensitiveStr::Ascii("vinises"),
        dictgen::InsensitiveStr::Ascii("vinize"),
        dictgen::InsensitiveStr::Ascii("vinizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CALANDER_1319585864060436502)],
        &[(0b11010, &ENTRY_CALANDER_1319585864060436502)],
        &[(0b11010, &ENTRY_CALCEMIA_1283576588856942148)],
        &[(0b10001, &ENTRY_CALCEMIA_1283576588856942148)],
        &[(0b10011, &ENTRY_CAULDRON_2025597715474043203)],
        &[(0b10011, &ENTRY_CAULDRONS_1493548229478431121)],
        &[(0b10010, &ENTRY_CALENDARIZATION_11275927263521422623)],
        &[(0b10010, &ENTRY_CALENDARIZATIONS_4887826632899373259)],
        &[(0b10010, &ENTRY_CALENDARIZE_14479923013676531010)],
        &[(0b10010, &ENTRY_CALENDARIZED_16767057265330067481)],
        &[(0b10010, &ENTRY_CALENDARIZES_9729766993143146526)],
        &[(0b10010, &ENTRY_CALENDARIZING_12252223763201845409)],
        &[(0b01001, &ENTRY_CALENDARIZATION_11275927263521422623)],
        &[(0b01001, &ENTRY_CALENDARIZATIONS_4887826632899373259)],
        &[(0b01001, &ENTRY_CALENDARIZE_14479923013676531010)],
        &[(0b01001, &ENTRY_CALENDARIZED_16767057265330067481)],
        &[(0b01001, &ENTRY_CALENDARIZES_9729766993143146526)],
        &[(0b01001, &ENTRY_CALENDARIZING_12252223763201845409)],
        &[(0b00001, &ENTRY_CALENDER_4820301279587696859)],
        &[(0b11010, &ENTRY_CALENDER_4820301279587696859)],
        &[(0b00001, &ENTRY_CALIBER_6088618581414349459)],
        &[(0b00001, &ENTRY_CALIBERS_1430668361820786824)],
        &[(0b11010, &ENTRY_CALIBER_6088618581414349459)],
        &[(0b11010, &ENTRY_CALIBERS_1430668361820786824)],
        &[(0b01001, &ENTRY_CALISTHENICS_3364072204597622667)],
        &[
            (0b00001, &ENTRY_CALK_12575257056050776341),
            (0b00001, &ENTRY_CAULK_17535979702514416347),
            (0b00001, &ENTRY_CAULK_18401647289797844299),
        ],
        &[
            (0b00001, &ENTRY_CALKED_9181583761946600913),
            (0b00001, &ENTRY_CAULKED_16471647952977568672),
        ],
        &[
            (0b00001, &ENTRY_CALKING_11924577664112241546),
            (0b00001, &ENTRY_CAULKING_9579808018830977690),
            (0b00001, &ENTRY_CAULK_17535979702514416347),
        ],
        &[(0b00001, &ENTRY_CAULKS_14651084141226031502)],
        &[
            (0b00001, &ENTRY_CALKS_16035962776808869627),
            (0b00001, &ENTRY_CAULKS_14651084141226031502),
            (0b00001, &ENTRY_CAULKS_9108482765718739748),
        ],
        &[(0b11010, &ENTRY_CALIPER_1634512857873448114)],
        &[(0b11010, &ENTRY_CALIPERED_235483477506157991)],
        &[(0b11010, &ENTRY_CALIPERING_10891416031331783411)],
        &[(0b11010, &ENTRY_CALIPERS_7817536690880904969)],
        &[(0b11010, &ENTRY_CALLIRRHOE_14861380595191797356)],
        &[(0b00001, &ENTRY_CALLIRRHOE_14861380595191797356)],
        &[(0b11010, &ENTRY_CALISTHENICS_3364072204597622667)],
        &[(0b11010, &ENTRY_CALODEMON_13354165079519258551)],
        &[(0b00001, &ENTRY_CALODEMON_13354165079519258551)],
        &[(0b10010, &ENTRY_CALVINIZE_13816648771193752029)],
        &[(0b10010, &ENTRY_CALVINIZES_5436345566017846080)],
        &[(0b01001, &ENTRY_CALVINIZE_13816648771193752029)],
        &[(0b01001, &ENTRY_CALVINIZES_5436345566017846080)],
    ],
    range: 1..=13,
};

static VARS_CAF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAF_CHILDREN),
    value: None,
};

pub static VARS_CAF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("fer"),
        dictgen::InsensitiveStr::Ascii("fre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CAFFER_7853146588750420256)],
        &[(0b11010, &ENTRY_CAFFER_7853146588750420256)],
    ],
    range: 3..=3,
};

static VARS_CAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAE_CHILDREN),
    value: None,
};

pub static VARS_CAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cally"),
        dictgen::InsensitiveStr::Ascii("citis"),
        dictgen::InsensitiveStr::Ascii("citises"),
        dictgen::InsensitiveStr::Ascii("city"),
        dictgen::InsensitiveStr::Ascii("costomy"),
        dictgen::InsensitiveStr::Ascii("cotomy"),
        dictgen::InsensitiveStr::Ascii("nis"),
        dictgen::InsensitiveStr::Ascii("nogenetic"),
        dictgen::InsensitiveStr::Ascii("nogenetically"),
        dictgen::InsensitiveStr::Ascii("nozoic"),
        dictgen::InsensitiveStr::Ascii("rule"),
        dictgen::InsensitiveStr::Ascii("sar"),
        dictgen::InsensitiveStr::Ascii("saria"),
        dictgen::InsensitiveStr::Ascii("sarise"),
        dictgen::InsensitiveStr::Ascii("sarises"),
        dictgen::InsensitiveStr::Ascii("sarize"),
        dictgen::InsensitiveStr::Ascii("sarizes"),
        dictgen::InsensitiveStr::Ascii("sious"),
        dictgen::InsensitiveStr::Ascii("sium"),
        dictgen::InsensitiveStr::Ascii("siums"),
        dictgen::InsensitiveStr::Ascii("spitose"),
        dictgen::InsensitiveStr::Ascii("spitosely"),
        dictgen::InsensitiveStr::Ascii("stus"),
        dictgen::InsensitiveStr::Ascii("stuses"),
        dictgen::InsensitiveStr::Ascii("sural"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CECALLY_12720796600011784892)],
        &[(0b11010, &ENTRY_CECITIS_18034763690253072964)],
        &[(0b11010, &ENTRY_CECITISES_10355938704850723051)],
        &[(0b11010, &ENTRY_CECITY_9865259183091102407)],
        &[(0b11010, &ENTRY_CECOSTOMY_3475802463529305333)],
        &[(0b11010, &ENTRY_CECOTOMY_3978768287054362751)],
        &[(0b11010, &ENTRY_CENIS_1991031411311203268)],
        &[(0b11010, &ENTRY_CENOGENETIC_4645405785928938913)],
        &[(0b11010, &ENTRY_CENOGENETICALLY_14614059803186390481)],
        &[(0b11010, &ENTRY_CENOZOIC_2810735566450048802)],
        &[(0b11010, &ENTRY_CERULE_1141707642753807571)],
        &[(0b11010, &ENTRY_CESAR_6074944643525905095)],
        &[(0b11010, &ENTRY_CESARIA_7497611325269733598)],
        &[(0b10010, &ENTRY_CAESARIZE_5575641651919740489)],
        &[(0b10010, &ENTRY_CAESARIZES_16957983591444579370)],
        &[(0b01001, &ENTRY_CAESARIZE_5575641651919740489)],
        &[(0b01001, &ENTRY_CAESARIZES_16957983591444579370)],
        &[(0b11010, &ENTRY_CESIOUS_10445245552084517023)],
        &[(0b11010, &ENTRY_CESIUM_17343129911628596363)],
        &[(0b11010, &ENTRY_CESIUMS_4513476447764778250)],
        &[(0b11010, &ENTRY_CESPITOSE_2511412164776933409)],
        &[(0b11010, &ENTRY_CESPITOSELY_7196666758904903124)],
        &[(0b11010, &ENTRY_CESTUS_2264271345052468556)],
        &[(0b11010, &ENTRY_CESTUSES_17262448748104314423)],
        &[(0b11010, &ENTRY_CESURAL_2827531996476826616)],
    ],
    range: 3..=13,
};

static VARS_CAD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAD_CHILDREN),
    value: None,
};

pub static VARS_CAD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aster"),
        dictgen::InsensitiveStr::Ascii("asters"),
        dictgen::InsensitiveStr::Ascii("astre"),
        dictgen::InsensitiveStr::Ascii("astres"),
        dictgen::InsensitiveStr::Ascii("averise"),
        dictgen::InsensitiveStr::Ascii("averises"),
        dictgen::InsensitiveStr::Ascii("averize"),
        dictgen::InsensitiveStr::Ascii("averizes"),
        dictgen::InsensitiveStr::Ascii("miumise"),
        dictgen::InsensitiveStr::Ascii("miumises"),
        dictgen::InsensitiveStr::Ascii("miumize"),
        dictgen::InsensitiveStr::Ascii("miumizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_CADASTER_600878410341713165)],
        &[(0b00001, &ENTRY_CADASTERS_582180790478148418)],
        &[(0b11010, &ENTRY_CADASTER_600878410341713165)],
        &[(0b11010, &ENTRY_CADASTERS_582180790478148418)],
        &[(0b10010, &ENTRY_CADAVERIZE_7507726269443380406)],
        &[(0b10010, &ENTRY_CADAVERIZES_5212133003303242117)],
        &[(0b01001, &ENTRY_CADAVERIZE_7507726269443380406)],
        &[(0b01001, &ENTRY_CADAVERIZES_5212133003303242117)],
        &[(0b10010, &ENTRY_CADMIUMIZE_6211453858315644291)],
        &[(0b10010, &ENTRY_CADMIUMIZES_784331431098990189)],
        &[(0b01001, &ENTRY_CADMIUMIZE_6211453858315644291)],
        &[(0b01001, &ENTRY_CADMIUMIZES_784331431098990189)],
    ],
    range: 5..=8,
};

static VARS_CAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_CAC_CHILDREN),
    value: None,
};

pub static VARS_CAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("haemia"),
        dictgen::InsensitiveStr::Ascii("haemic"),
        dictgen::InsensitiveStr::Ascii("hemia"),
        dictgen::InsensitiveStr::Ascii("hemic"),
        dictgen::InsensitiveStr::Ascii("oaethes"),
        dictgen::InsensitiveStr::Ascii("odaemon"),
        dictgen::InsensitiveStr::Ascii("odaemoniac"),
        dictgen::InsensitiveStr::Ascii("odaemonial"),
        dictgen::InsensitiveStr::Ascii("odaemonic"),
        dictgen::InsensitiveStr::Ascii("odaemons"),
        dictgen::InsensitiveStr::Ascii("odemon"),
        dictgen::InsensitiveStr::Ascii("odemoniac"),
        dictgen::InsensitiveStr::Ascii("odemonial"),
        dictgen::InsensitiveStr::Ascii("odemonic"),
        dictgen::InsensitiveStr::Ascii("odemons"),
        dictgen::InsensitiveStr::Ascii("oethes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_CACESTHESIA_3355744088099232950)],
        &[(0b10001, &ENTRY_CACESTHESIA_3355744088099232950)],
        &[(0b11010, &ENTRY_CACHEMIA_7087156802078224155)],
        &[(0b11010, &ENTRY_CACHEMIC_8607330359013703184)],
        &[(0b10001, &ENTRY_CACHEMIA_7087156802078224155)],
        &[(0b10001, &ENTRY_CACHEMIC_8607330359013703184)],
        &[(0b11010, &ENTRY_CACOETHES_16920803313087394954)],
        &[(0b11010, &ENTRY_CACODEMON_14159660385143717967)],
        &[(0b11010, &ENTRY_CACODEMONIAC_1398909674946225762)],
        &[(0b11010, &ENTRY_CACODEMONIAL_4666484075733322158)],
        &[(0b11010, &ENTRY_CACODEMONIC_13766389188311207544)],
        &[(0b11010, &ENTRY_CACODEMONS_4825079147053974709)],
        &[(0b10001, &ENTRY_CACODEMON_14159660385143717967)],
        &[(0b10001, &ENTRY_CACODEMONIAC_1398909674946225762)],
        &[(0b10001, &ENTRY_CACODEMONIAL_4666484075733322158)],
        &[(0b10001, &ENTRY_CACODEMONIC_13766389188311207544)],
        &[(0b10001, &ENTRY_CACODEMONS_4825079147053974709)],
        &[(0b10001, &ENTRY_CACOETHES_16920803313087394954)],
    ],
    range: 5..=10,
};

static VARS_B_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_B_CHILDREN),
    value: None,
};

static VARS_B_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_BA_NODE),
    None,
    None,
    None,
    Some(&VARS_BE_NODE),
    None,
    None,
    None,
    Some(&VARS_BI_NODE),
    None,
    None,
    Some(&VARS_BL_NODE),
    None,
    None,
    Some(&VARS_BO_NODE),
    None,
    None,
    Some(&VARS_BR_NODE),
    None,
    None,
    Some(&VARS_BU_NODE),
    None,
    None,
    None,
    Some(&VARS_BY_NODE),
    None,
];

static VARS_BY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BY_CHILDREN),
    value: None,
};

pub static VARS_BY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ronise"),
        dictgen::InsensitiveStr::Ascii("ronises"),
        dictgen::InsensitiveStr::Ascii("ronize"),
        dictgen::InsensitiveStr::Ascii("ronizes"),
        dictgen::InsensitiveStr::Ascii("zantinise"),
        dictgen::InsensitiveStr::Ascii("zantinises"),
        dictgen::InsensitiveStr::Ascii("zantinize"),
        dictgen::InsensitiveStr::Ascii("zantinizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BYRONIZE_12114867653355624724)],
        &[(0b10010, &ENTRY_BYRONIZES_17917324563061221571)],
        &[(0b01001, &ENTRY_BYRONIZE_12114867653355624724)],
        &[(0b01001, &ENTRY_BYRONIZES_17917324563061221571)],
        &[(0b10010, &ENTRY_BYZANTINIZE_8123759068349438218)],
        &[(0b10010, &ENTRY_BYZANTINIZES_7526286864523963129)],
        &[(0b01001, &ENTRY_BYZANTINIZE_8123759068349438218)],
        &[(0b01001, &ENTRY_BYZANTINIZES_7526286864523963129)],
    ],
    range: 6..=10,
};

static VARS_BU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BU_CHILDREN),
    value: None,
};

pub static VARS_BU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daenny"),
        dictgen::InsensitiveStr::Ascii("denny"),
        dictgen::InsensitiveStr::Ascii("reaucratisation"),
        dictgen::InsensitiveStr::Ascii("reaucratisations"),
        dictgen::InsensitiveStr::Ascii("reaucratise"),
        dictgen::InsensitiveStr::Ascii("reaucratised"),
        dictgen::InsensitiveStr::Ascii("reaucratises"),
        dictgen::InsensitiveStr::Ascii("reaucratising"),
        dictgen::InsensitiveStr::Ascii("reaucratization"),
        dictgen::InsensitiveStr::Ascii("reaucratizations"),
        dictgen::InsensitiveStr::Ascii("reaucratize"),
        dictgen::InsensitiveStr::Ascii("reaucratized"),
        dictgen::InsensitiveStr::Ascii("reaucratizes"),
        dictgen::InsensitiveStr::Ascii("reaucratizing"),
        dictgen::InsensitiveStr::Ascii("rglarise"),
        dictgen::InsensitiveStr::Ascii("rglarised"),
        dictgen::InsensitiveStr::Ascii("rglarises"),
        dictgen::InsensitiveStr::Ascii("rglarising"),
        dictgen::InsensitiveStr::Ascii("rglarize"),
        dictgen::InsensitiveStr::Ascii("rglarized"),
        dictgen::InsensitiveStr::Ascii("rglarizes"),
        dictgen::InsensitiveStr::Ascii("rglarizing"),
        dictgen::InsensitiveStr::Ascii("rkha"),
        dictgen::InsensitiveStr::Ascii("rkhas"),
        dictgen::InsensitiveStr::Ascii("rnettise"),
        dictgen::InsensitiveStr::Ascii("rnettised"),
        dictgen::InsensitiveStr::Ascii("rnettises"),
        dictgen::InsensitiveStr::Ascii("rnettising"),
        dictgen::InsensitiveStr::Ascii("rnettize"),
        dictgen::InsensitiveStr::Ascii("rnettized"),
        dictgen::InsensitiveStr::Ascii("rnettizes"),
        dictgen::InsensitiveStr::Ascii("rnettizing"),
        dictgen::InsensitiveStr::Ascii("rqa"),
        dictgen::InsensitiveStr::Ascii("rqas"),
        dictgen::InsensitiveStr::Ascii("sheled"),
        dictgen::InsensitiveStr::Ascii("sheler"),
        dictgen::InsensitiveStr::Ascii("shelers"),
        dictgen::InsensitiveStr::Ascii("sheling"),
        dictgen::InsensitiveStr::Ascii("shelings"),
        dictgen::InsensitiveStr::Ascii("shelled"),
        dictgen::InsensitiveStr::Ascii("sheller"),
        dictgen::InsensitiveStr::Ascii("shellers"),
        dictgen::InsensitiveStr::Ascii("shelling"),
        dictgen::InsensitiveStr::Ascii("shellings"),
        dictgen::InsensitiveStr::Ascii("ssed"),
        dictgen::InsensitiveStr::Ascii("ssing"),
        dictgen::InsensitiveStr::Ascii("ssings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_BUDENNY_11099115713729619046)],
        &[(0b00001, &ENTRY_BUDENNY_11099115713729619046)],
        &[(0b10010, &ENTRY_BUREAUCRATIZATION_16556810164478202459)],
        &[(0b10010, &ENTRY_BUREAUCRATIZATIONS_4497039635998929992)],
        &[(0b10010, &ENTRY_BUREAUCRATIZE_16395985087531018238)],
        &[(0b10010, &ENTRY_BUREAUCRATIZED_15775450558155547918)],
        &[(0b10010, &ENTRY_BUREAUCRATIZES_961794786572965629)],
        &[(0b10010, &ENTRY_BUREAUCRATIZING_11662006117549455029)],
        &[(0b01001, &ENTRY_BUREAUCRATIZATION_16556810164478202459)],
        &[(0b01001, &ENTRY_BUREAUCRATIZATIONS_4497039635998929992)],
        &[(0b01001, &ENTRY_BUREAUCRATIZE_16395985087531018238)],
        &[(0b01001, &ENTRY_BUREAUCRATIZED_15775450558155547918)],
        &[(0b01001, &ENTRY_BUREAUCRATIZES_961794786572965629)],
        &[(0b01001, &ENTRY_BUREAUCRATIZING_11662006117549455029)],
        &[(0b10010, &ENTRY_BURGLARIZE_3702042591254065955)],
        &[(0b10010, &ENTRY_BURGLARIZED_12847959995142931775)],
        &[(0b10010, &ENTRY_BURGLARIZES_9695092733654355865)],
        &[(0b10010, &ENTRY_BURGLARIZING_8183010640223344875)],
        &[(0b01001, &ENTRY_BURGLARIZE_3702042591254065955)],
        &[(0b01001, &ENTRY_BURGLARIZED_12847959995142931775)],
        &[(0b01001, &ENTRY_BURGLARIZES_9695092733654355865)],
        &[(0b01001, &ENTRY_BURGLARIZING_8183010640223344875)],
        &[(0b01010, &ENTRY_BURKA_1159530484671088481)],
        &[(0b01010, &ENTRY_BURKAS_17648103133414783175)],
        &[(0b10010, &ENTRY_BURNETTIZE_2544477078181246197)],
        &[(0b10010, &ENTRY_BURNETTIZED_4236600316315443722)],
        &[(0b10010, &ENTRY_BURNETTIZES_11084091521976824076)],
        &[(0b10010, &ENTRY_BURNETTIZING_7002913660791249279)],
        &[(0b01001, &ENTRY_BURNETTIZE_2544477078181246197)],
        &[(0b01001, &ENTRY_BURNETTIZED_4236600316315443722)],
        &[(0b01001, &ENTRY_BURNETTIZES_11084091521976824076)],
        &[(0b01001, &ENTRY_BURNETTIZING_7002913660791249279)],
        &[(0b11010, &ENTRY_BURKA_1159530484671088481)],
        &[(0b11010, &ENTRY_BURKAS_17648103133414783175)],
        &[(0b00001, &ENTRY_BUSHELED_1118763777829214027)],
        &[(0b00001, &ENTRY_BUSHELER_17954630284099342763)],
        &[(0b00001, &ENTRY_BUSHELERS_15210446479419969885)],
        &[(0b00001, &ENTRY_BUSHELING_12570417250242863334)],
        &[(0b00001, &ENTRY_BUSHELINGS_985942199985401750)],
        &[(0b11010, &ENTRY_BUSHELED_1118763777829214027)],
        &[(0b11010, &ENTRY_BUSHELER_17954630284099342763)],
        &[(0b11010, &ENTRY_BUSHELERS_15210446479419969885)],
        &[(0b11010, &ENTRY_BUSHELING_12570417250242863334)],
        &[(0b11010, &ENTRY_BUSHELINGS_985942199985401750)],
        &[(0b10011, &ENTRY_BUSED_11356679774879450486)],
        &[(0b10011, &ENTRY_BUSING_14976108434828724214)],
        &[(0b10011, &ENTRY_BUSINGS_5189350881089292254)],
    ],
    range: 3..=16,
};

static VARS_BR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BR_CHILDREN),
    value: None,
};

pub static VARS_BR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("adypnea"),
        dictgen::InsensitiveStr::Ascii("adypnoea"),
        dictgen::InsensitiveStr::Ascii("eathalyse"),
        dictgen::InsensitiveStr::Ascii("eathalysed"),
        dictgen::InsensitiveStr::Ascii("eathalyser"),
        dictgen::InsensitiveStr::Ascii("eathalysers"),
        dictgen::InsensitiveStr::Ascii("eathalyses"),
        dictgen::InsensitiveStr::Ascii("eathalysing"),
        dictgen::InsensitiveStr::Ascii("eathalyze"),
        dictgen::InsensitiveStr::Ascii("eathalyzed"),
        dictgen::InsensitiveStr::Ascii("eathalyzers"),
        dictgen::InsensitiveStr::Ascii("eathalyzes"),
        dictgen::InsensitiveStr::Ascii("eathalyzing"),
        dictgen::InsensitiveStr::Ascii("eloque"),
        dictgen::InsensitiveStr::Ascii("eme"),
        dictgen::InsensitiveStr::Ascii("en"),
        dictgen::InsensitiveStr::Ascii("isa"),
        dictgen::InsensitiveStr::Ascii("iza"),
        dictgen::InsensitiveStr::Ascii("omethylene"),
        dictgen::InsensitiveStr::Ascii("ominise"),
        dictgen::InsensitiveStr::Ascii("ominises"),
        dictgen::InsensitiveStr::Ascii("ominize"),
        dictgen::InsensitiveStr::Ascii("ominizes"),
        dictgen::InsensitiveStr::Ascii("omisation"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omization"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizing"),
        dictgen::InsensitiveStr::Ascii("omoethylene"),
        dictgen::InsensitiveStr::Ascii("utalisation"),
        dictgen::InsensitiveStr::Ascii("utalisations"),
        dictgen::InsensitiveStr::Ascii("utalise"),
        dictgen::InsensitiveStr::Ascii("utalised"),
        dictgen::InsensitiveStr::Ascii("utalises"),
        dictgen::InsensitiveStr::Ascii("utalising"),
        dictgen::InsensitiveStr::Ascii("utalization"),
        dictgen::InsensitiveStr::Ascii("utalizations"),
        dictgen::InsensitiveStr::Ascii("utalize"),
        dictgen::InsensitiveStr::Ascii("utalized"),
        dictgen::InsensitiveStr::Ascii("utalizes"),
        dictgen::InsensitiveStr::Ascii("utalizing"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BRADYPNEA_14990069084802510573)],
        &[(0b11010, &ENTRY_BRADYPNEA_14990069084802510573)],
        &[(0b11010, &ENTRY_BREATHALYZE_10553810929293173557)],
        &[(0b11010, &ENTRY_BREATHALYZED_10540875853111278249)],
        &[(0b11010, &ENTRY_BREATHALYZER_15434122011452224968)],
        &[(0b11010, &ENTRY_BREATHALYZERS_7686418927650730063)],
        &[(0b11010, &ENTRY_BREATHALYZES_15395076049944664352)],
        &[(0b11010, &ENTRY_BREATHALYZING_9538292620264111634)],
        &[(0b01001, &ENTRY_BREATHALYZE_10553810929293173557)],
        &[(0b01001, &ENTRY_BREATHALYZED_10540875853111278249)],
        &[(0b00001, &ENTRY_BREATHALYZERS_7686418927650730063)],
        &[(0b01001, &ENTRY_BREATHALYZES_15395076049944664352)],
        &[(0b01001, &ENTRY_BREATHALYZING_9538292620264111634)],
        &[(0b11010, &ENTRY_BERLOQUE_16973140256876933299)],
        &[(0b11010, &ENTRY_BERME_13467983052397932132)],
        &[(0b11010, &ENTRY_BERN_9411483658541257171)],
        &[(0b10010, &ENTRY_BRIZA_6020459019937063540)],
        &[(0b01001, &ENTRY_BRIZA_6020459019937063540)],
        &[(0b00001, &ENTRY_BROMETHYLENE_12089993515876146438)],
        &[(0b10010, &ENTRY_BROMINIZE_17329310617302550026)],
        &[(0b10010, &ENTRY_BROMINIZES_11166943960094705541)],
        &[(0b01001, &ENTRY_BROMINIZE_17329310617302550026)],
        &[(0b01001, &ENTRY_BROMINIZES_11166943960094705541)],
        &[(0b10010, &ENTRY_BROMIZATION_2640938302052484551)],
        &[(0b10010, &ENTRY_BROMIZE_9408768460954085967)],
        &[(0b10010, &ENTRY_BROMIZED_1262409682973727998)],
        &[(0b10010, &ENTRY_BROMIZING_11142091927559534073)],
        &[(0b01001, &ENTRY_BROMIZATION_2640938302052484551)],
        &[(0b01001, &ENTRY_BROMIZE_9408768460954085967)],
        &[(0b01001, &ENTRY_BROMIZED_1262409682973727998)],
        &[(0b01001, &ENTRY_BROMIZING_11142091927559534073)],
        &[(0b11010, &ENTRY_BROMETHYLENE_12089993515876146438)],
        &[(0b10010, &ENTRY_BRUTALIZATION_5823277448598256026)],
        &[(0b10010, &ENTRY_BRUTALIZATIONS_14502881577076747180)],
        &[(0b10010, &ENTRY_BRUTALIZE_15445890938697612049)],
        &[(0b10010, &ENTRY_BRUTALIZED_12350992663397007437)],
        &[(0b10010, &ENTRY_BRUTALIZES_14319976079482108516)],
        &[(0b10010, &ENTRY_BRUTALIZING_17352191512105797054)],
        &[(0b01001, &ENTRY_BRUTALIZATION_5823277448598256026)],
        &[(0b01001, &ENTRY_BRUTALIZATIONS_14502881577076747180)],
        &[(0b01001, &ENTRY_BRUTALIZE_15445890938697612049)],
        &[(0b01001, &ENTRY_BRUTALIZED_12350992663397007437)],
        &[(0b01001, &ENTRY_BRUTALIZES_14319976079482108516)],
        &[(0b01001, &ENTRY_BRUTALIZING_17352191512105797054)],
    ],
    range: 2..=12,
};

static VARS_BO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_BO_CHILDREN),
    value: None,
};

static VARS_BO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_BOA_NODE),
    None,
    None,
    None,
    Some(&VARS_BOE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_BOL_NODE),
    None,
    Some(&VARS_BON_NODE),
    None,
    None,
    None,
    Some(&VARS_BOR_NODE),
    Some(&VARS_BOS_NODE),
    Some(&VARS_BOT_NODE),
    Some(&VARS_BOU_NODE),
    None,
    Some(&VARS_BOW_NODE),
    None,
    None,
    None,
];

static VARS_BOW_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOW_CHILDREN),
    value: None,
};

pub static VARS_BOW_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dlerisation"),
        dictgen::InsensitiveStr::Ascii("dlerisations"),
        dictgen::InsensitiveStr::Ascii("dlerise"),
        dictgen::InsensitiveStr::Ascii("dlerised"),
        dictgen::InsensitiveStr::Ascii("dleriser"),
        dictgen::InsensitiveStr::Ascii("dlerisers"),
        dictgen::InsensitiveStr::Ascii("dlerises"),
        dictgen::InsensitiveStr::Ascii("dlerising"),
        dictgen::InsensitiveStr::Ascii("dlerization"),
        dictgen::InsensitiveStr::Ascii("dlerizations"),
        dictgen::InsensitiveStr::Ascii("dlerize"),
        dictgen::InsensitiveStr::Ascii("dlerized"),
        dictgen::InsensitiveStr::Ascii("dlerizer"),
        dictgen::InsensitiveStr::Ascii("dlerizers"),
        dictgen::InsensitiveStr::Ascii("dlerizes"),
        dictgen::InsensitiveStr::Ascii("dlerizing"),
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("lder"),
        dictgen::InsensitiveStr::Ascii("lders"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BOWDLERIZATION_15003666665570033944)],
        &[(0b10010, &ENTRY_BOWDLERIZATIONS_4765159417978820500)],
        &[(0b10010, &ENTRY_BOWDLERIZE_3564223313490479365)],
        &[(0b10010, &ENTRY_BOWDLERIZED_11555956899762270807)],
        &[(0b10010, &ENTRY_BOWDLERIZER_9391658950288862007)],
        &[(0b10010, &ENTRY_BOWDLERIZERS_3135273670642498247)],
        &[(0b10010, &ENTRY_BOWDLERIZES_996948036211004202)],
        &[(0b10010, &ENTRY_BOWDLERIZING_8658675993569127303)],
        &[(0b01001, &ENTRY_BOWDLERIZATION_15003666665570033944)],
        &[(0b01001, &ENTRY_BOWDLERIZATIONS_4765159417978820500)],
        &[(0b01001, &ENTRY_BOWDLERIZE_3564223313490479365)],
        &[(0b01001, &ENTRY_BOWDLERIZED_11555956899762270807)],
        &[(0b01001, &ENTRY_BOWDLERIZER_9391658950288862007)],
        &[(0b01001, &ENTRY_BOWDLERIZERS_3135273670642498247)],
        &[(0b01001, &ENTRY_BOWDLERIZES_996948036211004202)],
        &[(0b01001, &ENTRY_BOWDLERIZING_8658675993569127303)],
        &[(0b00001, &ENTRY_BOWELED_17573142053252288008)],
        &[(0b00001, &ENTRY_BOWELING_12067574292037953398)],
        &[(0b11010, &ENTRY_BOWELED_17573142053252288008)],
        &[(0b11010, &ENTRY_BOWELING_12067574292037953398)],
        &[(0b00001, &ENTRY_BOULDER_12516261271833260895)],
        &[(0b00001, &ENTRY_BOULDERS_3864700166179251654)],
    ],
    range: 4..=12,
};

static VARS_BOU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOU_CHILDREN),
    value: None,
};

pub static VARS_BOU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("levardise"),
        dictgen::InsensitiveStr::Ascii("levardises"),
        dictgen::InsensitiveStr::Ascii("levardize"),
        dictgen::InsensitiveStr::Ascii("levardizes"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("rage"),
        dictgen::InsensitiveStr::Ascii("rasque"),
        dictgen::InsensitiveStr::Ascii("rbonise"),
        dictgen::InsensitiveStr::Ascii("rbonises"),
        dictgen::InsensitiveStr::Ascii("rbonize"),
        dictgen::InsensitiveStr::Ascii("rbonizes"),
        dictgen::InsensitiveStr::Ascii("rd"),
        dictgen::InsensitiveStr::Ascii("rds"),
        dictgen::InsensitiveStr::Ascii("rg"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BOULEVARDIZE_8185506525213597267)],
        &[(0b10010, &ENTRY_BOULEVARDIZES_9859087317378411554)],
        &[(0b01001, &ENTRY_BOULEVARDIZE_8185506525213597267)],
        &[(0b01001, &ENTRY_BOULEVARDIZES_9859087317378411554)],
        &[(0b11010, &ENTRY_BOR_15726996487969007319)],
        &[(0b11010, &ENTRY_BORAGE_11906407082412349878)],
        &[(0b11010, &ENTRY_BORASQUE_12463950773551631809)],
        &[(0b10010, &ENTRY_BOURBONIZE_1178395603606873081)],
        &[(0b10010, &ENTRY_BOURBONIZES_14462412263603486786)],
        &[(0b01001, &ENTRY_BOURBONIZE_1178395603606873081)],
        &[(0b01001, &ENTRY_BOURBONIZES_14462412263603486786)],
        &[(0b11010, &ENTRY_BORD_18164452795863545372)],
        &[(0b11010, &ENTRY_BORDS_7324219903916101004)],
        &[(0b11010, &ENTRY_BORG_5368387535636175671)],
    ],
    range: 1..=10,
};

static VARS_BOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOT_CHILDREN),
    value: None,
};

pub static VARS_BOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("aniser"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizer"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BOTANIZE_7551170961793070479)],
        &[(0b10010, &ENTRY_BOTANIZED_6978246195480656091)],
        &[(0b10010, &ENTRY_BOTANIZER_10688902380199603159)],
        &[(0b10010, &ENTRY_BOTANIZES_4460206956631925576)],
        &[(0b10010, &ENTRY_BOTANIZING_15845930378851783636)],
        &[(0b01001, &ENTRY_BOTANIZE_7551170961793070479)],
        &[(0b01001, &ENTRY_BOTANIZED_6978246195480656091)],
        &[(0b01001, &ENTRY_BOTANIZER_10688902380199603159)],
        &[(0b01001, &ENTRY_BOTANIZES_4460206956631925576)],
        &[(0b01001, &ENTRY_BOTANIZING_15845930378851783636)],
    ],
    range: 5..=7,
};

static VARS_BOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOS_CHILDREN),
    value: None,
};

pub static VARS_BOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("wellise"),
        dictgen::InsensitiveStr::Ascii("wellised"),
        dictgen::InsensitiveStr::Ascii("wellises"),
        dictgen::InsensitiveStr::Ascii("wellising"),
        dictgen::InsensitiveStr::Ascii("wellize"),
        dictgen::InsensitiveStr::Ascii("wellized"),
        dictgen::InsensitiveStr::Ascii("wellizes"),
        dictgen::InsensitiveStr::Ascii("wellizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BOSWELLIZE_3698602768600626065)],
        &[(0b10010, &ENTRY_BOSWELLIZED_8124331813443724374)],
        &[(0b10010, &ENTRY_BOSWELLIZES_11578704107127902682)],
        &[(0b10010, &ENTRY_BOSWELLIZING_5812126249996086388)],
        &[(0b01001, &ENTRY_BOSWELLIZE_3698602768600626065)],
        &[(0b01001, &ENTRY_BOSWELLIZED_8124331813443724374)],
        &[(0b01001, &ENTRY_BOSWELLIZES_11578704107127902682)],
        &[(0b01001, &ENTRY_BOSWELLIZING_5812126249996086388)],
    ],
    range: 7..=9,
};

static VARS_BOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOR_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_BOR_15726996487969007319)]),
};

pub static VARS_BOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("age"),
        dictgen::InsensitiveStr::Ascii("asque"),
        dictgen::InsensitiveStr::Ascii("d"),
        dictgen::InsensitiveStr::Ascii("ds"),
        dictgen::InsensitiveStr::Ascii("g"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BORAGE_11906407082412349878)],
        &[(0b00001, &ENTRY_BORASQUE_12463950773551631809)],
        &[(0b00001, &ENTRY_BORD_18164452795863545372)],
        &[(0b00001, &ENTRY_BORDS_7324219903916101004)],
        &[(0b00001, &ENTRY_BORG_5368387535636175671)],
        &[(0b10010, &ENTRY_BORIZE_10330616917016533656)],
        &[(0b10010, &ENTRY_BORIZES_16866165125304621719)],
        &[(0b01001, &ENTRY_BORIZE_10330616917016533656)],
        &[(0b01001, &ENTRY_BORIZES_16866165125304621719)],
    ],
    range: 1..=5,
};

static VARS_BON_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BON_CHILDREN),
    value: None,
};

pub static VARS_BON_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("derise"),
        dictgen::InsensitiveStr::Ascii("derize"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BONDERIZE_7272076124653249026)],
        &[(0b01001, &ENTRY_BONDERIZE_7272076124653249026)],
    ],
    range: 6..=6,
};

static VARS_BOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOL_CHILDREN),
    value: None,
};

pub static VARS_BOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ed"),
        dictgen::InsensitiveStr::Ascii("oed"),
        dictgen::InsensitiveStr::Ascii("shevise"),
        dictgen::InsensitiveStr::Ascii("shevised"),
        dictgen::InsensitiveStr::Ascii("shevises"),
        dictgen::InsensitiveStr::Ascii("shevising"),
        dictgen::InsensitiveStr::Ascii("shevize"),
        dictgen::InsensitiveStr::Ascii("shevized"),
        dictgen::InsensitiveStr::Ascii("shevizes"),
        dictgen::InsensitiveStr::Ascii("shevizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BOLED_14696249241634637180)],
        &[(0b11010, &ENTRY_BOLED_14696249241634637180)],
        &[(0b10010, &ENTRY_BOLSHEVIZE_9295222616139275092)],
        &[(0b10010, &ENTRY_BOLSHEVIZED_12985511351822149082)],
        &[(0b10010, &ENTRY_BOLSHEVIZES_2750006029755985666)],
        &[(0b10010, &ENTRY_BOLSHEVIZING_2242830870498003369)],
        &[(0b01001, &ENTRY_BOLSHEVIZE_9295222616139275092)],
        &[(0b01001, &ENTRY_BOLSHEVIZED_12985511351822149082)],
        &[(0b01001, &ENTRY_BOLSHEVIZES_2750006029755985666)],
        &[(0b01001, &ENTRY_BOLSHEVIZING_2242830870498003369)],
    ],
    range: 2..=9,
};

static VARS_BOE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOE_CHILDREN),
    value: None,
};

pub static VARS_BOE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("dromius"),
        dictgen::InsensitiveStr::Ascii("hmenism"),
        dictgen::InsensitiveStr::Ascii("hmenist"),
        dictgen::InsensitiveStr::Ascii("hmenite"),
        dictgen::InsensitiveStr::Ascii("lter"),
        dictgen::InsensitiveStr::Ascii("lus"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BOEDROMIUS_10140569261433699587)],
        &[(0b11010, &ENTRY_BEHMENISM_16450421455239972566)],
        &[(0b11010, &ENTRY_BEHMENIST_12053790631810257124)],
        &[(0b11010, &ENTRY_BEHMENITE_3335321400081704671)],
        &[(0b11010, &ENTRY_BELTER_6595324842513246324)],
        &[(0b11010, &ENTRY_BELUS_10707973760047908555)],
    ],
    range: 3..=7,
};

static VARS_BOA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BOA_CHILDREN),
    value: None,
};

pub static VARS_BOA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("edromius")],
    values: &[&[(0b11010, &ENTRY_BOEDROMIUS_10140569261433699587)]],
    range: 8..=8,
};

static VARS_BL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BL_CHILDREN),
    value: None,
};

pub static VARS_BL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aise"),
        dictgen::InsensitiveStr::Ascii("aize"),
        dictgen::InsensitiveStr::Ascii("amable"),
        dictgen::InsensitiveStr::Ascii("astocele"),
        dictgen::InsensitiveStr::Ascii("astocoele"),
        dictgen::InsensitiveStr::Ascii("astulae"),
        dictgen::InsensitiveStr::Ascii("astule"),
        dictgen::InsensitiveStr::Ascii("ennemesis"),
        dictgen::InsensitiveStr::Ascii("ennoemesis"),
        dictgen::InsensitiveStr::Ascii("ennorrhea"),
        dictgen::InsensitiveStr::Ascii("ennorrhoea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BLAIZE_1220632059692388861)],
        &[(0b01001, &ENTRY_BLAIZE_1220632059692388861)],
        &[(0b01001, &ENTRY_BLAMABLE_7328528693620793783)],
        &[(0b00001, &ENTRY_BLASTOCELE_18161446415449857731)],
        &[(0b11010, &ENTRY_BLASTOCELE_18161446415449857731)],
        &[(0b11010, &ENTRY_BLASTULE_6565332400736377843)],
        &[(0b00001, &ENTRY_BLASTULE_6565332400736377843)],
        &[(0b00001, &ENTRY_BLENNEMESIS_12408003891077842527)],
        &[(0b11010, &ENTRY_BLENNEMESIS_12408003891077842527)],
        &[(0b10001, &ENTRY_BLENNORRHEA_2218782057410422271)],
        &[(0b11010, &ENTRY_BLENNORRHEA_2218782057410422271)],
    ],
    range: 4..=10,
};

static VARS_BI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_BI_CHILDREN),
    value: None,
};

static VARS_BI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_BIA_NODE),
    None,
    Some(&VARS_BIC_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_BIM_NODE),
    Some(&VARS_BIN_NODE),
    Some(&VARS_BIO_NODE),
    Some(&VARS_BIP_NODE),
    None,
    Some(&VARS_BIR_NODE),
    Some(&VARS_BIS_NODE),
    Some(&VARS_BIT_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_BIZ_NODE),
];

static VARS_BIZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIZ_CHILDREN),
    value: None,
};

pub static VARS_BIZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("et"),
    ],
    values: &[
        &[(0b01001, &ENTRY_BIZE_12936627068566021826)],
        &[(0b01001, &ENTRY_BIZET_4586471071545262019)],
    ],
    range: 1..=2,
};

static VARS_BIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIT_CHILDREN),
    value: None,
};

pub static VARS_BIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tor"),
        dictgen::InsensitiveStr::Ascii("tors"),
        dictgen::InsensitiveStr::Ascii("tour"),
        dictgen::InsensitiveStr::Ascii("tours"),
        dictgen::InsensitiveStr::Ascii("uminisation"),
        dictgen::InsensitiveStr::Ascii("uminisations"),
        dictgen::InsensitiveStr::Ascii("uminise"),
        dictgen::InsensitiveStr::Ascii("uminised"),
        dictgen::InsensitiveStr::Ascii("uminises"),
        dictgen::InsensitiveStr::Ascii("uminising"),
        dictgen::InsensitiveStr::Ascii("uminization"),
        dictgen::InsensitiveStr::Ascii("uminizations"),
        dictgen::InsensitiveStr::Ascii("uminize"),
        dictgen::InsensitiveStr::Ascii("uminized"),
        dictgen::InsensitiveStr::Ascii("uminizes"),
        dictgen::InsensitiveStr::Ascii("uminizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BITTOR_17121981854551948147)],
        &[(0b00001, &ENTRY_BITTORS_11286171863858275118)],
        &[(0b11010, &ENTRY_BITTOR_17121981854551948147)],
        &[(0b11010, &ENTRY_BITTORS_11286171863858275118)],
        &[(0b10010, &ENTRY_BITUMINIZATION_17454899386160960184)],
        &[(0b10010, &ENTRY_BITUMINIZATIONS_4430255676913937183)],
        &[(0b10010, &ENTRY_BITUMINIZE_18416379614821284335)],
        &[(0b10010, &ENTRY_BITUMINIZED_3973700773638176633)],
        &[(0b10010, &ENTRY_BITUMINIZES_15984764105434279145)],
        &[(0b10010, &ENTRY_BITUMINIZING_14018683945005443597)],
        &[(0b01001, &ENTRY_BITUMINIZATION_17454899386160960184)],
        &[(0b01001, &ENTRY_BITUMINIZATIONS_4430255676913937183)],
        &[(0b01001, &ENTRY_BITUMINIZE_18416379614821284335)],
        &[(0b01001, &ENTRY_BITUMINIZED_3973700773638176633)],
        &[(0b01001, &ENTRY_BITUMINIZES_15984764105434279145)],
        &[(0b01001, &ENTRY_BITUMINIZING_14018683945005443597)],
    ],
    range: 3..=12,
};

static VARS_BIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIS_CHILDREN),
    value: None,
};

pub static VARS_BIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("et"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tered"),
        dictgen::InsensitiveStr::Ascii("teredder"),
        dictgen::InsensitiveStr::Ascii("tereddest"),
        dictgen::InsensitiveStr::Ascii("ters"),
        dictgen::InsensitiveStr::Ascii("tre"),
        dictgen::InsensitiveStr::Ascii("tred"),
        dictgen::InsensitiveStr::Ascii("tredder"),
        dictgen::InsensitiveStr::Ascii("treddest"),
        dictgen::InsensitiveStr::Ascii("tres"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BIZE_12936627068566021826)],
        &[(0b10010, &ENTRY_BIZET_4586471071545262019)],
        &[(0b01001, &ENTRY_BISTER_12243394786223476364)],
        &[(0b00001, &ENTRY_BISTERED_12594354785868849372)],
        &[(0b00001, &ENTRY_BISTEREDDER_4919702072233220862)],
        &[(0b00001, &ENTRY_BISTEREDDEST_8076651195429169182)],
        &[(0b01001, &ENTRY_BISTERS_2497112586905993305)],
        &[(0b11010, &ENTRY_BISTER_12243394786223476364)],
        &[(0b11010, &ENTRY_BISTERED_12594354785868849372)],
        &[(0b11010, &ENTRY_BISTEREDDER_4919702072233220862)],
        &[(0b11010, &ENTRY_BISTEREDDEST_8076651195429169182)],
        &[(0b11010, &ENTRY_BISTERS_2497112586905993305)],
    ],
    range: 1..=9,
};

static VARS_BIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIR_CHILDREN),
    value: None,
};

pub static VARS_BIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minghamise"),
        dictgen::InsensitiveStr::Ascii("minghamises"),
        dictgen::InsensitiveStr::Ascii("minghamize"),
        dictgen::InsensitiveStr::Ascii("minghamizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BIRMINGHAMIZE_8569250108140387650)],
        &[(0b10010, &ENTRY_BIRMINGHAMIZES_18070978989186779877)],
        &[(0b01001, &ENTRY_BIRMINGHAMIZE_8569250108140387650)],
        &[(0b01001, &ENTRY_BIRMINGHAMIZES_18070978989186779877)],
    ],
    range: 10..=11,
};

static VARS_BIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIP_CHILDREN),
    value: None,
};

pub static VARS_BIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olarisation"),
        dictgen::InsensitiveStr::Ascii("olarise"),
        dictgen::InsensitiveStr::Ascii("olarises"),
        dictgen::InsensitiveStr::Ascii("olarization"),
        dictgen::InsensitiveStr::Ascii("olarize"),
        dictgen::InsensitiveStr::Ascii("olarizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BIPOLARIZATION_8043840355082199256)],
        &[(0b10010, &ENTRY_BIPOLARIZE_7871964341365869167)],
        &[(0b10010, &ENTRY_BIPOLARIZES_9309819257597037093)],
        &[(0b01001, &ENTRY_BIPOLARIZATION_8043840355082199256)],
        &[(0b01001, &ENTRY_BIPOLARIZE_7871964341365869167)],
        &[(0b01001, &ENTRY_BIPOLARIZES_9309819257597037093)],
    ],
    range: 7..=11,
};

static VARS_BIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIO_CHILDREN),
    value: None,
};

pub static VARS_BIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cenology"),
        dictgen::InsensitiveStr::Ascii("cenose"),
        dictgen::InsensitiveStr::Ascii("cenoses"),
        dictgen::InsensitiveStr::Ascii("cenosis"),
        dictgen::InsensitiveStr::Ascii("cenotic"),
        dictgen::InsensitiveStr::Ascii("coenology"),
        dictgen::InsensitiveStr::Ascii("coenose"),
        dictgen::InsensitiveStr::Ascii("coenoses"),
        dictgen::InsensitiveStr::Ascii("coenosis"),
        dictgen::InsensitiveStr::Ascii("coenotic"),
        dictgen::InsensitiveStr::Ascii("graphise"),
        dictgen::InsensitiveStr::Ascii("graphises"),
        dictgen::InsensitiveStr::Ascii("graphize"),
        dictgen::InsensitiveStr::Ascii("graphizes"),
        dictgen::InsensitiveStr::Ascii("logise"),
        dictgen::InsensitiveStr::Ascii("logises"),
        dictgen::InsensitiveStr::Ascii("logize"),
        dictgen::InsensitiveStr::Ascii("logizes"),
        dictgen::InsensitiveStr::Ascii("synthesised"),
        dictgen::InsensitiveStr::Ascii("synthesized"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BIOCENOLOGY_14689209691235014054)],
        &[(0b10001, &ENTRY_BIOCENOSE_3138770096544861410)],
        &[(0b10001, &ENTRY_BIOCENOSES_13501584028527836531)],
        &[(0b10001, &ENTRY_BIOCENOSIS_8916166807214256078)],
        &[(0b10001, &ENTRY_BIOCENOTIC_8654469384514575281)],
        &[(0b11010, &ENTRY_BIOCENOLOGY_14689209691235014054)],
        &[(0b11010, &ENTRY_BIOCENOSE_3138770096544861410)],
        &[(0b11010, &ENTRY_BIOCENOSES_13501584028527836531)],
        &[(0b11010, &ENTRY_BIOCENOSIS_8916166807214256078)],
        &[(0b11010, &ENTRY_BIOCENOTIC_8654469384514575281)],
        &[(0b10010, &ENTRY_BIOGRAPHIZE_3101270671578058317)],
        &[(0b10010, &ENTRY_BIOGRAPHIZES_9794450292227006800)],
        &[(0b01001, &ENTRY_BIOGRAPHIZE_3101270671578058317)],
        &[(0b01001, &ENTRY_BIOGRAPHIZES_9794450292227006800)],
        &[(0b10010, &ENTRY_BIOLOGIZE_7350607900569346229)],
        &[(0b10010, &ENTRY_BIOLOGIZES_3124510342898949248)],
        &[(0b01001, &ENTRY_BIOLOGIZE_7350607900569346229)],
        &[(0b01001, &ENTRY_BIOLOGIZES_3124510342898949248)],
        &[(0b10010, &ENTRY_BIOSYNTHESIZED_13192699560463879497)],
        &[(0b01001, &ENTRY_BIOSYNTHESIZED_13192699560463879497)],
    ],
    range: 6..=11,
};

static VARS_BIN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIN_CHILDREN),
    value: None,
};

pub static VARS_BIN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ging")],
    values: &[&[(0b00001, &ENTRY_BINGEING_14277432149077039485)]],
    range: 4..=4,
};

static VARS_BIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIM_CHILDREN),
    value: None,
};

pub static VARS_BIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etalist"),
        dictgen::InsensitiveStr::Ascii("etalistic"),
        dictgen::InsensitiveStr::Ascii("etallist"),
        dictgen::InsensitiveStr::Ascii("etallistic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BIMETALIST_7071235615867580313)],
        &[(0b00001, &ENTRY_BIMETALISTIC_10704026739410878685)],
        &[(0b11010, &ENTRY_BIMETALIST_7071235615867580313)],
        &[(0b11010, &ENTRY_BIMETALISTIC_10704026739410878685)],
    ],
    range: 7..=10,
};

static VARS_BIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIC_CHILDREN),
    value: None,
};

pub static VARS_BIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hromatise"),
        dictgen::InsensitiveStr::Ascii("hromatises"),
        dictgen::InsensitiveStr::Ascii("hromatize"),
        dictgen::InsensitiveStr::Ascii("hromatizes"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olored"),
        dictgen::InsensitiveStr::Ascii("oloredder"),
        dictgen::InsensitiveStr::Ascii("oloreddest"),
        dictgen::InsensitiveStr::Ascii("olorous"),
        dictgen::InsensitiveStr::Ascii("olorrer"),
        dictgen::InsensitiveStr::Ascii("olorrest"),
        dictgen::InsensitiveStr::Ascii("olors"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("oloured"),
        dictgen::InsensitiveStr::Ascii("olouredder"),
        dictgen::InsensitiveStr::Ascii("oloureddest"),
        dictgen::InsensitiveStr::Ascii("olourer"),
        dictgen::InsensitiveStr::Ascii("olourest"),
        dictgen::InsensitiveStr::Ascii("olourous"),
        dictgen::InsensitiveStr::Ascii("olours"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BICHROMATIZE_6575837359582309819)],
        &[(0b10010, &ENTRY_BICHROMATIZES_11938767258104126504)],
        &[(0b01001, &ENTRY_BICHROMATIZE_6575837359582309819)],
        &[(0b01001, &ENTRY_BICHROMATIZES_11938767258104126504)],
        &[(0b10001, &ENTRY_BICOLOR_10164358994113091705)],
        &[(0b10001, &ENTRY_BICOLORED_434708862208065723)],
        &[(0b10001, &ENTRY_BICOLOREDDER_8362361841051385390)],
        &[(0b10001, &ENTRY_BICOLOREDDEST_8676331588438394982)],
        &[(0b00001, &ENTRY_BICOLOROUS_9012574496998947343)],
        &[(0b10001, &ENTRY_BICOLORRER_5653522831142191999)],
        &[(0b10001, &ENTRY_BICOLORREST_693010655310508411)],
        &[(0b10001, &ENTRY_BICOLORS_9368006477019357638)],
        &[(0b11010, &ENTRY_BICOLOR_10164358994113091705)],
        &[(0b11010, &ENTRY_BICOLORED_434708862208065723)],
        &[(0b11010, &ENTRY_BICOLOREDDER_8362361841051385390)],
        &[(0b11010, &ENTRY_BICOLOREDDEST_8676331588438394982)],
        &[(0b11010, &ENTRY_BICOLORRER_5653522831142191999)],
        &[(0b11010, &ENTRY_BICOLORREST_693010655310508411)],
        &[(0b11010, &ENTRY_BICOLOROUS_9012574496998947343)],
        &[(0b11010, &ENTRY_BICOLORS_9368006477019357638)],
    ],
    range: 4..=11,
};

static VARS_BIA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BIA_CHILDREN),
    value: None,
};

pub static VARS_BIA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ssed"),
        dictgen::InsensitiveStr::Ascii("ssing"),
    ],
    values: &[
        &[(0b10011, &ENTRY_BIASED_1791974261124589682)],
        &[(0b10011, &ENTRY_BIASING_6997021477668826126)],
    ],
    range: 4..=5,
};

static VARS_BE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_BE_CHILDREN),
    value: None,
};

static VARS_BE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_BEA_NODE),
    None,
    Some(&VARS_BEC_NODE),
    Some(&VARS_BED_NODE),
    Some(&VARS_BEE_NODE),
    Some(&VARS_BEF_NODE),
    Some(&VARS_BEG_NODE),
    Some(&VARS_BEH_NODE),
    None,
    Some(&VARS_BEJ_NODE),
    None,
    Some(&VARS_BEL_NODE),
    Some(&VARS_BEM_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_BER_NODE),
    Some(&VARS_BES_NODE),
    None,
    None,
    Some(&VARS_BEV_NODE),
    None,
    None,
    Some(&VARS_BEY_NODE),
    None,
];

static VARS_BEY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEY_CHILDREN),
    value: None,
};

pub static VARS_BEY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("er")],
    values: &[&[(0b00001, &ENTRY_BEYER_14898169439752870815)]],
    range: 2..=2,
};

static VARS_BEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEV_CHILDREN),
    value: None,
};

pub static VARS_BEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eled"),
        dictgen::InsensitiveStr::Ascii("eler"),
        dictgen::InsensitiveStr::Ascii("elers"),
        dictgen::InsensitiveStr::Ascii("eling"),
        dictgen::InsensitiveStr::Ascii("elings"),
        dictgen::InsensitiveStr::Ascii("elled"),
        dictgen::InsensitiveStr::Ascii("eller"),
        dictgen::InsensitiveStr::Ascii("ellers"),
        dictgen::InsensitiveStr::Ascii("elling"),
        dictgen::InsensitiveStr::Ascii("ellings"),
    ],
    values: &[
        &[(0b01001, &ENTRY_BEVELED_464364200154775119)],
        &[(0b01001, &ENTRY_BEVELER_2560516573011394819)],
        &[(0b01001, &ENTRY_BEVELERS_9232933359348996649)],
        &[(0b01001, &ENTRY_BEVELING_10855109562149223001)],
        &[(0b01001, &ENTRY_BEVELINGS_2452856377064833303)],
        &[(0b11010, &ENTRY_BEVELED_464364200154775119)],
        &[(0b11010, &ENTRY_BEVELER_2560516573011394819)],
        &[(0b11010, &ENTRY_BEVELERS_9232933359348996649)],
        &[(0b11010, &ENTRY_BEVELING_10855109562149223001)],
        &[(0b11010, &ENTRY_BEVELINGS_2452856377064833303)],
    ],
    range: 4..=7,
};

static VARS_BES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BES_CHILDREN),
    value: None,
};

pub static VARS_BES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("semerise"),
        dictgen::InsensitiveStr::Ascii("semerises"),
        dictgen::InsensitiveStr::Ascii("semerize"),
        dictgen::InsensitiveStr::Ascii("semerizes"),
        dictgen::InsensitiveStr::Ascii("tialise"),
        dictgen::InsensitiveStr::Ascii("tialised"),
        dictgen::InsensitiveStr::Ascii("tialises"),
        dictgen::InsensitiveStr::Ascii("tialising"),
        dictgen::InsensitiveStr::Ascii("tialize"),
        dictgen::InsensitiveStr::Ascii("tialized"),
        dictgen::InsensitiveStr::Ascii("tializes"),
        dictgen::InsensitiveStr::Ascii("tializing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BESSEMERIZE_14474112216075710864)],
        &[(0b10010, &ENTRY_BESSEMERIZES_6207831075537789134)],
        &[(0b01001, &ENTRY_BESSEMERIZE_14474112216075710864)],
        &[(0b01001, &ENTRY_BESSEMERIZES_6207831075537789134)],
        &[(0b10010, &ENTRY_BESTIALIZE_3056063670726597576)],
        &[(0b10010, &ENTRY_BESTIALIZED_9547393233273320821)],
        &[(0b10010, &ENTRY_BESTIALIZES_1393652725255993657)],
        &[(0b10010, &ENTRY_BESTIALIZING_3683935903600606612)],
        &[(0b01001, &ENTRY_BESTIALIZE_3056063670726597576)],
        &[(0b01001, &ENTRY_BESTIALIZED_9547393233273320821)],
        &[(0b01001, &ENTRY_BESTIALIZES_1393652725255993657)],
        &[(0b01001, &ENTRY_BESTIALIZING_3683935903600606612)],
    ],
    range: 7..=9,
};

static VARS_BER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BER_CHILDREN),
    value: None,
};

pub static VARS_BER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("ia"),
        dictgen::InsensitiveStr::Ascii("l"),
        dictgen::InsensitiveStr::Ascii("linise"),
        dictgen::InsensitiveStr::Ascii("linises"),
        dictgen::InsensitiveStr::Ascii("linize"),
        dictgen::InsensitiveStr::Ascii("linizes"),
        dictgen::InsensitiveStr::Ascii("loque"),
        dictgen::InsensitiveStr::Ascii("me"),
        dictgen::InsensitiveStr::Ascii("n"),
    ],
    values: &[
        &[(0b11010, &ENTRY_BEERA_6010693163623887132)],
        &[(0b00001, &ENTRY_BERIA_6249864324866743848)],
        &[(0b00001, &ENTRY_BERL_1185444321092270619)],
        &[(0b10010, &ENTRY_BERLINIZE_15633104344359694284)],
        &[(0b10010, &ENTRY_BERLINIZES_5780526359977067580)],
        &[(0b01001, &ENTRY_BERLINIZE_15633104344359694284)],
        &[(0b01001, &ENTRY_BERLINIZES_5780526359977067580)],
        &[(0b00001, &ENTRY_BERLOQUE_16973140256876933299)],
        &[(0b00001, &ENTRY_BERME_13467983052397932132)],
        &[(0b00001, &ENTRY_BERN_9411483658541257171)],
    ],
    range: 1..=7,
};

static VARS_BEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEM_CHILDREN),
    value: None,
};

pub static VARS_BEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edaled"),
        dictgen::InsensitiveStr::Ascii("edalled"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BEMEDALED_11565185958895431981)],
        &[(0b11010, &ENTRY_BEMEDALED_11565185958895431981)],
    ],
    range: 6..=7,
};

static VARS_BEL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEL_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_BEL_14468840991245400678)]),
};

pub static VARS_BEL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abored"),
        dictgen::InsensitiveStr::Ascii("aboring"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("aboured"),
        dictgen::InsensitiveStr::Ascii("abouring"),
        dictgen::InsensitiveStr::Ascii("abours"),
        dictgen::InsensitiveStr::Ascii("s"),
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("us"),
    ],
    values: &[
        &[(0b11001, &ENTRY_BELABOR_9577593579762971199)],
        &[(0b11001, &ENTRY_BELABORED_2071671744170951559)],
        &[(0b11001, &ENTRY_BELABORING_1181160254749158200)],
        &[(0b11001, &ENTRY_BELABORS_6186916057783206938)],
        &[(0b11010, &ENTRY_BELABOR_9577593579762971199)],
        &[(0b11010, &ENTRY_BELABORED_2071671744170951559)],
        &[(0b11010, &ENTRY_BELABORING_1181160254749158200)],
        &[(0b11010, &ENTRY_BELABORS_6186916057783206938)],
        &[(0b00001, &ENTRY_BELS_17074483974516039729)],
        &[(0b00001, &ENTRY_BELTER_6595324842513246324)],
        &[(0b00001, &ENTRY_BELUS_10707973760047908555)],
    ],
    range: 1..=8,
};

static VARS_BEJ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEJ_CHILDREN),
    value: None,
};

pub static VARS_BEJ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eweled"),
        dictgen::InsensitiveStr::Ascii("eweling"),
        dictgen::InsensitiveStr::Ascii("ewelled"),
        dictgen::InsensitiveStr::Ascii("ewelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BEJEWELED_4984569160882024545)],
        &[(0b00001, &ENTRY_BEJEWELING_6307871362607074541)],
        &[(0b11010, &ENTRY_BEJEWELED_4984569160882024545)],
        &[(0b11010, &ENTRY_BEJEWELING_6307871362607074541)],
    ],
    range: 6..=8,
};

static VARS_BEH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEH_CHILDREN),
    value: None,
};

pub static VARS_BEH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avior"),
        dictgen::InsensitiveStr::Ascii("avioral"),
        dictgen::InsensitiveStr::Ascii("avioraler"),
        dictgen::InsensitiveStr::Ascii("avioralest"),
        dictgen::InsensitiveStr::Ascii("aviorally"),
        dictgen::InsensitiveStr::Ascii("aviored"),
        dictgen::InsensitiveStr::Ascii("aviorism"),
        dictgen::InsensitiveStr::Ascii("aviorisms"),
        dictgen::InsensitiveStr::Ascii("aviorist"),
        dictgen::InsensitiveStr::Ascii("avioristic"),
        dictgen::InsensitiveStr::Ascii("avioristicer"),
        dictgen::InsensitiveStr::Ascii("avioristicest"),
        dictgen::InsensitiveStr::Ascii("avioristics"),
        dictgen::InsensitiveStr::Ascii("aviorists"),
        dictgen::InsensitiveStr::Ascii("aviors"),
        dictgen::InsensitiveStr::Ascii("aviour"),
        dictgen::InsensitiveStr::Ascii("avioural"),
        dictgen::InsensitiveStr::Ascii("aviouraler"),
        dictgen::InsensitiveStr::Ascii("aviouralest"),
        dictgen::InsensitiveStr::Ascii("aviourally"),
        dictgen::InsensitiveStr::Ascii("avioured"),
        dictgen::InsensitiveStr::Ascii("aviourism"),
        dictgen::InsensitiveStr::Ascii("aviourisms"),
        dictgen::InsensitiveStr::Ascii("aviourist"),
        dictgen::InsensitiveStr::Ascii("aviouristic"),
        dictgen::InsensitiveStr::Ascii("aviouristicer"),
        dictgen::InsensitiveStr::Ascii("aviouristicest"),
        dictgen::InsensitiveStr::Ascii("aviouristics"),
        dictgen::InsensitiveStr::Ascii("aviourists"),
        dictgen::InsensitiveStr::Ascii("aviours"),
        dictgen::InsensitiveStr::Ascii("menism"),
        dictgen::InsensitiveStr::Ascii("menist"),
        dictgen::InsensitiveStr::Ascii("menite"),
        dictgen::InsensitiveStr::Ascii("oove"),
        dictgen::InsensitiveStr::Ascii("ooved"),
        dictgen::InsensitiveStr::Ascii("ooves"),
        dictgen::InsensitiveStr::Ascii("ooving"),
        dictgen::InsensitiveStr::Ascii("oovingly"),
        dictgen::InsensitiveStr::Ascii("oovings"),
        dictgen::InsensitiveStr::Ascii("ove"),
        dictgen::InsensitiveStr::Ascii("oved"),
        dictgen::InsensitiveStr::Ascii("oves"),
        dictgen::InsensitiveStr::Ascii("oving"),
        dictgen::InsensitiveStr::Ascii("ovingly"),
        dictgen::InsensitiveStr::Ascii("ovings"),
    ],
    values: &[
        &[(0b11001, &ENTRY_BEHAVIOR_14651200144504457213)],
        &[(0b11001, &ENTRY_BEHAVIORAL_16431863374575357094)],
        &[(0b11001, &ENTRY_BEHAVIORALER_6184370577289856922)],
        &[(0b11001, &ENTRY_BEHAVIORALEST_3631208384433367206)],
        &[(0b11001, &ENTRY_BEHAVIORALLY_3392730520394326300)],
        &[(0b11001, &ENTRY_BEHAVIORED_496799855263187779)],
        &[(0b11001, &ENTRY_BEHAVIORISM_4176615940346575759)],
        &[(0b11001, &ENTRY_BEHAVIORISMS_1554586755841111618)],
        &[(0b11001, &ENTRY_BEHAVIORIST_5628596059711288582)],
        &[(0b11001, &ENTRY_BEHAVIORISTIC_2362575912476199312)],
        &[(0b11001, &ENTRY_BEHAVIORISTICER_3955710407140770528)],
        &[(0b11001, &ENTRY_BEHAVIORISTICEST_9606870366866079149)],
        &[(0b11001, &ENTRY_BEHAVIORISTICS_18376773413500646501)],
        &[(0b11001, &ENTRY_BEHAVIORISTS_16129454263271072388)],
        &[(0b11001, &ENTRY_BEHAVIORS_3758424170765605620)],
        &[(0b11010, &ENTRY_BEHAVIOR_14651200144504457213)],
        &[(0b11010, &ENTRY_BEHAVIORAL_16431863374575357094)],
        &[(0b11010, &ENTRY_BEHAVIORALER_6184370577289856922)],
        &[(0b11010, &ENTRY_BEHAVIORALEST_3631208384433367206)],
        &[(0b11010, &ENTRY_BEHAVIORALLY_3392730520394326300)],
        &[(0b11010, &ENTRY_BEHAVIORED_496799855263187779)],
        &[(0b11010, &ENTRY_BEHAVIORISM_4176615940346575759)],
        &[(0b11010, &ENTRY_BEHAVIORISMS_1554586755841111618)],
        &[(0b11010, &ENTRY_BEHAVIORIST_5628596059711288582)],
        &[(0b11010, &ENTRY_BEHAVIORISTIC_2362575912476199312)],
        &[(0b11010, &ENTRY_BEHAVIORISTICER_3955710407140770528)],
        &[(0b11010, &ENTRY_BEHAVIORISTICEST_9606870366866079149)],
        &[(0b11010, &ENTRY_BEHAVIORISTICS_18376773413500646501)],
        &[(0b11010, &ENTRY_BEHAVIORISTS_16129454263271072388)],
        &[(0b11010, &ENTRY_BEHAVIORS_3758424170765605620)],
        &[(0b00001, &ENTRY_BEHMENISM_16450421455239972566)],
        &[(0b00001, &ENTRY_BEHMENIST_12053790631810257124)],
        &[(0b00001, &ENTRY_BEHMENITE_3335321400081704671)],
        &[(0b01001, &ENTRY_BEHOOVE_6147219241654589987)],
        &[(0b01001, &ENTRY_BEHOOVED_1655251573785223409)],
        &[(0b01001, &ENTRY_BEHOOVES_3868425672448610419)],
        &[(0b01001, &ENTRY_BEHOOVING_8088190138647815853)],
        &[(0b00001, &ENTRY_BEHOOVINGLY_4751705039419506689)],
        &[(0b01001, &ENTRY_BEHOOVINGS_8205659410382773823)],
        &[(0b10010, &ENTRY_BEHOOVE_6147219241654589987)],
        &[(0b10010, &ENTRY_BEHOOVED_1655251573785223409)],
        &[(0b10010, &ENTRY_BEHOOVES_3868425672448610419)],
        &[(0b10010, &ENTRY_BEHOOVING_8088190138647815853)],
        &[(0b11010, &ENTRY_BEHOOVINGLY_4751705039419506689)],
        &[(0b10010, &ENTRY_BEHOOVINGS_8205659410382773823)],
    ],
    range: 3..=14,
};

static VARS_BEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEG_CHILDREN),
    value: None,
};

pub static VARS_BEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lamor"),
        dictgen::InsensitiveStr::Ascii("lamored"),
        dictgen::InsensitiveStr::Ascii("lamoring"),
        dictgen::InsensitiveStr::Ascii("lamors"),
        dictgen::InsensitiveStr::Ascii("lamour"),
        dictgen::InsensitiveStr::Ascii("lamoured"),
        dictgen::InsensitiveStr::Ascii("lamouring"),
        dictgen::InsensitiveStr::Ascii("lamours"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BEGLAMOR_13712112495668100470)],
        &[(0b10001, &ENTRY_BEGLAMORED_17236768717735314854)],
        &[(0b10001, &ENTRY_BEGLAMORING_16675826950855681606)],
        &[(0b10001, &ENTRY_BEGLAMORS_12605296861327651664)],
        &[(0b11010, &ENTRY_BEGLAMOR_13712112495668100470)],
        &[(0b11010, &ENTRY_BEGLAMORED_17236768717735314854)],
        &[(0b11010, &ENTRY_BEGLAMORING_16675826950855681606)],
        &[(0b11010, &ENTRY_BEGLAMORS_12605296861327651664)],
    ],
    range: 5..=9,
};

static VARS_BEF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEF_CHILDREN),
    value: None,
};

pub static VARS_BEF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("avor"),
        dictgen::InsensitiveStr::Ascii("avour"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BEFAVOR_4929864496662345763)],
        &[(0b11010, &ENTRY_BEFAVOR_4929864496662345763)],
    ],
    range: 4..=5,
};

static VARS_BEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEE_CHILDREN),
    value: None,
};

pub static VARS_BEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("ra")],
    values: &[&[(0b00001, &ENTRY_BEERA_6010693163623887132)]],
    range: 2..=2,
};

static VARS_BED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BED_CHILDREN),
    value: None,
};

pub static VARS_BED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eviled"),
        dictgen::InsensitiveStr::Ascii("eviling"),
        dictgen::InsensitiveStr::Ascii("evilled"),
        dictgen::InsensitiveStr::Ascii("evilling"),
        dictgen::InsensitiveStr::Ascii("lamise"),
        dictgen::InsensitiveStr::Ascii("lamised"),
        dictgen::InsensitiveStr::Ascii("lamises"),
        dictgen::InsensitiveStr::Ascii("lamising"),
        dictgen::InsensitiveStr::Ascii("lamize"),
        dictgen::InsensitiveStr::Ascii("lamized"),
        dictgen::InsensitiveStr::Ascii("lamizes"),
        dictgen::InsensitiveStr::Ascii("lamizing"),
        dictgen::InsensitiveStr::Ascii("riveled"),
        dictgen::InsensitiveStr::Ascii("riveling"),
        dictgen::InsensitiveStr::Ascii("rivelled"),
        dictgen::InsensitiveStr::Ascii("rivelling"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BEDEVILED_14137634025943909745)],
        &[(0b00001, &ENTRY_BEDEVILING_3264516468398917500)],
        &[(0b11010, &ENTRY_BEDEVILED_14137634025943909745)],
        &[(0b11010, &ENTRY_BEDEVILING_3264516468398917500)],
        &[(0b10010, &ENTRY_BEDLAMIZE_8032432031457666621)],
        &[(0b10010, &ENTRY_BEDLAMIZED_8070235127373715475)],
        &[(0b10010, &ENTRY_BEDLAMIZES_2905803091441936414)],
        &[(0b10010, &ENTRY_BEDLAMIZING_5249207699535847866)],
        &[(0b01001, &ENTRY_BEDLAMIZE_8032432031457666621)],
        &[(0b01001, &ENTRY_BEDLAMIZED_8070235127373715475)],
        &[(0b01001, &ENTRY_BEDLAMIZES_2905803091441936414)],
        &[(0b01001, &ENTRY_BEDLAMIZING_5249207699535847866)],
        &[(0b00001, &ENTRY_BEDRIVELED_16825680695984036015)],
        &[(0b00001, &ENTRY_BEDRIVELING_12159930547505129231)],
        &[(0b11010, &ENTRY_BEDRIVELED_16825680695984036015)],
        &[(0b11010, &ENTRY_BEDRIVELING_12159930547505129231)],
    ],
    range: 6..=9,
};

static VARS_BEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEC_CHILDREN),
    value: None,
};

pub static VARS_BEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lamor"),
        dictgen::InsensitiveStr::Ascii("lamored"),
        dictgen::InsensitiveStr::Ascii("lamoring"),
        dictgen::InsensitiveStr::Ascii("lamors"),
        dictgen::InsensitiveStr::Ascii("lamour"),
        dictgen::InsensitiveStr::Ascii("lamoured"),
        dictgen::InsensitiveStr::Ascii("lamouring"),
        dictgen::InsensitiveStr::Ascii("lamours"),
        dictgen::InsensitiveStr::Ascii("olor"),
        dictgen::InsensitiveStr::Ascii("olour"),
        dictgen::InsensitiveStr::Ascii("udgeled"),
        dictgen::InsensitiveStr::Ascii("udgeling"),
        dictgen::InsensitiveStr::Ascii("udgelled"),
        dictgen::InsensitiveStr::Ascii("udgelling"),
    ],
    values: &[
        &[(0b10001, &ENTRY_BECLAMOR_15010060560531866056)],
        &[(0b10001, &ENTRY_BECLAMORED_11429770894371708638)],
        &[(0b10001, &ENTRY_BECLAMORING_9503333775494226894)],
        &[(0b10001, &ENTRY_BECLAMORS_13615720098742172165)],
        &[(0b11010, &ENTRY_BECLAMOR_15010060560531866056)],
        &[(0b11010, &ENTRY_BECLAMORED_11429770894371708638)],
        &[(0b11010, &ENTRY_BECLAMORING_9503333775494226894)],
        &[(0b11010, &ENTRY_BECLAMORS_13615720098742172165)],
        &[(0b10001, &ENTRY_BECOLOR_1820125413532981726)],
        &[(0b11010, &ENTRY_BECOLOR_1820125413532981726)],
        &[(0b00001, &ENTRY_BECUDGELED_10688892400774535279)],
        &[(0b00001, &ENTRY_BECUDGELING_2856359572329458860)],
        &[(0b11010, &ENTRY_BECUDGELED_10688892400774535279)],
        &[(0b11010, &ENTRY_BECUDGELING_2856359572329458860)],
    ],
    range: 4..=9,
};

static VARS_BEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BEA_CHILDREN),
    value: None,
};

pub static VARS_BEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("verise"),
        dictgen::InsensitiveStr::Ascii("verises"),
        dictgen::InsensitiveStr::Ascii("verize"),
        dictgen::InsensitiveStr::Ascii("verizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BEAVERIZE_17666585249999378311)],
        &[(0b10010, &ENTRY_BEAVERIZES_3003655027714564574)],
        &[(0b01001, &ENTRY_BEAVERIZE_17666585249999378311)],
        &[(0b01001, &ENTRY_BEAVERIZES_3003655027714564574)],
    ],
    range: 6..=7,
};

static VARS_BA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_BA_CHILDREN),
    value: None,
};

static VARS_BA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_BAB_NODE),
    Some(&VARS_BAC_NODE),
    None,
    Some(&VARS_BAE_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_BAL_NODE),
    None,
    Some(&VARS_BAN_NODE),
    None,
    Some(&VARS_BAP_NODE),
    None,
    Some(&VARS_BAR_NODE),
    Some(&VARS_BAS_NODE),
    Some(&VARS_BAT_NODE),
    Some(&VARS_BAU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_BAU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAU_CHILDREN),
    value: None,
};

pub static VARS_BAU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lk"),
        dictgen::InsensitiveStr::Ascii("lked"),
        dictgen::InsensitiveStr::Ascii("lking"),
        dictgen::InsensitiveStr::Ascii("lks"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BALK_16157341829373855465)],
        &[(0b10010, &ENTRY_BALKED_13168474275010509248)],
        &[(0b10010, &ENTRY_BALKING_4782897688469985529)],
        &[(0b10010, &ENTRY_BALKS_15300503195053466242)],
    ],
    range: 2..=5,
};

static VARS_BAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAT_CHILDREN),
    value: None,
};

pub static VARS_BAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tleax"),
        dictgen::InsensitiveStr::Ascii("tologise"),
        dictgen::InsensitiveStr::Ascii("tologised"),
        dictgen::InsensitiveStr::Ascii("tologising"),
        dictgen::InsensitiveStr::Ascii("tologize"),
        dictgen::InsensitiveStr::Ascii("tologized"),
        dictgen::InsensitiveStr::Ascii("tologizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_BATTLEAXE_15052343884109974687)],
        &[(0b10010, &ENTRY_BATTOLOGIZE_12105586747261105341)],
        &[(0b10010, &ENTRY_BATTOLOGIZED_12783274211026027611)],
        &[(0b10010, &ENTRY_BATTOLOGIZING_6018370845171871626)],
        &[(0b01001, &ENTRY_BATTOLOGIZE_12105586747261105341)],
        &[(0b01001, &ENTRY_BATTOLOGIZED_12783274211026027611)],
        &[(0b01001, &ENTRY_BATTOLOGIZING_6018370845171871626)],
    ],
    range: 5..=10,
};

static VARS_BAS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAS_CHILDREN),
    value: None,
};

pub static VARS_BAS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tardisation"),
        dictgen::InsensitiveStr::Ascii("tardisations"),
        dictgen::InsensitiveStr::Ascii("tardise"),
        dictgen::InsensitiveStr::Ascii("tardised"),
        dictgen::InsensitiveStr::Ascii("tardises"),
        dictgen::InsensitiveStr::Ascii("tardising"),
        dictgen::InsensitiveStr::Ascii("tardization"),
        dictgen::InsensitiveStr::Ascii("tardizations"),
        dictgen::InsensitiveStr::Ascii("tardize"),
        dictgen::InsensitiveStr::Ascii("tardized"),
        dictgen::InsensitiveStr::Ascii("tardizes"),
        dictgen::InsensitiveStr::Ascii("tardizing"),
        dictgen::InsensitiveStr::Ascii("tinaded"),
        dictgen::InsensitiveStr::Ascii("tinades"),
        dictgen::InsensitiveStr::Ascii("tinadoed"),
        dictgen::InsensitiveStr::Ascii("tinadoes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BASTARDIZATION_15150400898607735555)],
        &[(0b10010, &ENTRY_BASTARDIZATIONS_13505445987148951791)],
        &[(0b10010, &ENTRY_BASTARDIZE_17168607737816618553)],
        &[(0b10010, &ENTRY_BASTARDIZED_15327063659865539383)],
        &[(0b10010, &ENTRY_BASTARDIZES_1734137171535573217)],
        &[(0b10010, &ENTRY_BASTARDIZING_4525888023760792804)],
        &[(0b01001, &ENTRY_BASTARDIZATION_15150400898607735555)],
        &[(0b01001, &ENTRY_BASTARDIZATIONS_13505445987148951791)],
        &[(0b01001, &ENTRY_BASTARDIZE_17168607737816618553)],
        &[(0b01001, &ENTRY_BASTARDIZED_15327063659865539383)],
        &[(0b01001, &ENTRY_BASTARDIZES_1734137171535573217)],
        &[(0b01001, &ENTRY_BASTARDIZING_4525888023760792804)],
        &[(0b00001, &ENTRY_BASTINADED_10916132116078316936)],
        &[(0b00001, &ENTRY_BASTINADES_16941290810871621543)],
        &[(0b11010, &ENTRY_BASTINADED_10916132116078316936)],
        &[(0b11010, &ENTRY_BASTINADES_16941290810871621543)],
    ],
    range: 7..=12,
};

static VARS_BAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAR_CHILDREN),
    value: None,
};

pub static VARS_BAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("barianise"),
        dictgen::InsensitiveStr::Ascii("barianises"),
        dictgen::InsensitiveStr::Ascii("barianize"),
        dictgen::InsensitiveStr::Ascii("barianizes"),
        dictgen::InsensitiveStr::Ascii("barisation"),
        dictgen::InsensitiveStr::Ascii("barisations"),
        dictgen::InsensitiveStr::Ascii("barise"),
        dictgen::InsensitiveStr::Ascii("barised"),
        dictgen::InsensitiveStr::Ascii("barises"),
        dictgen::InsensitiveStr::Ascii("barising"),
        dictgen::InsensitiveStr::Ascii("barization"),
        dictgen::InsensitiveStr::Ascii("barizations"),
        dictgen::InsensitiveStr::Ascii("barize"),
        dictgen::InsensitiveStr::Ascii("barized"),
        dictgen::InsensitiveStr::Ascii("barizes"),
        dictgen::InsensitiveStr::Ascii("barizing"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("onetise"),
        dictgen::InsensitiveStr::Ascii("onetised"),
        dictgen::InsensitiveStr::Ascii("onetising"),
        dictgen::InsensitiveStr::Ascii("onetize"),
        dictgen::InsensitiveStr::Ascii("onetized"),
        dictgen::InsensitiveStr::Ascii("onetizing"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("reled"),
        dictgen::InsensitiveStr::Ascii("reling"),
        dictgen::InsensitiveStr::Ascii("tisan"),
        dictgen::InsensitiveStr::Ascii("tisaned"),
        dictgen::InsensitiveStr::Ascii("tisans"),
        dictgen::InsensitiveStr::Ascii("tizan"),
        dictgen::InsensitiveStr::Ascii("tizaned"),
        dictgen::InsensitiveStr::Ascii("tizans"),
        dictgen::InsensitiveStr::Ascii("ycenter"),
        dictgen::InsensitiveStr::Ascii("ycentre"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BARBARIANIZE_15261658705914178060)],
        &[(0b10010, &ENTRY_BARBARIANIZES_11395565352922752182)],
        &[(0b01001, &ENTRY_BARBARIANIZE_15261658705914178060)],
        &[(0b01001, &ENTRY_BARBARIANIZES_11395565352922752182)],
        &[(0b10010, &ENTRY_BARBARIZATION_637634415456611000)],
        &[(0b10010, &ENTRY_BARBARIZATIONS_6457370917232767902)],
        &[(0b10010, &ENTRY_BARBARIZE_3245642365916369243)],
        &[(0b10010, &ENTRY_BARBARIZED_408182624919762132)],
        &[(0b10010, &ENTRY_BARBARIZES_7081317051698057651)],
        &[(0b10010, &ENTRY_BARBARIZING_9364260930235464394)],
        &[(0b01001, &ENTRY_BARBARIZATION_637634415456611000)],
        &[(0b01001, &ENTRY_BARBARIZATIONS_6457370917232767902)],
        &[(0b01001, &ENTRY_BARBARIZE_3245642365916369243)],
        &[(0b01001, &ENTRY_BARBARIZED_408182624919762132)],
        &[(0b01001, &ENTRY_BARBARIZES_7081317051698057651)],
        &[(0b01001, &ENTRY_BARBARIZING_9364260930235464394)],
        &[(0b11010, &ENTRY_BAER_14581860992483818503)],
        &[(0b10010, &ENTRY_BARONETIZE_816321287514212290)],
        &[(0b10010, &ENTRY_BARONETIZED_15717984216308695709)],
        &[(0b10010, &ENTRY_BARONETIZING_3724487241546723880)],
        &[(0b01001, &ENTRY_BARONETIZE_816321287514212290)],
        &[(0b01001, &ENTRY_BARONETIZED_15717984216308695709)],
        &[(0b01001, &ENTRY_BARONETIZING_3724487241546723880)],
        &[(0b10010, &ENTRY_BARONIZE_14549807395279592595)],
        &[(0b10010, &ENTRY_BARONIZES_2387447146173200401)],
        &[(0b01001, &ENTRY_BARONIZE_14549807395279592595)],
        &[(0b01001, &ENTRY_BARONIZES_2387447146173200401)],
        &[(0b00001, &ENTRY_BARRELED_771246087900113850)],
        &[(0b00001, &ENTRY_BARRELING_14371038101917122463)],
        &[(0b10010, &ENTRY_BARTIZAN_3091667005685807749)],
        &[(0b10010, &ENTRY_BARTIZANED_11308940237767481814)],
        &[(0b10010, &ENTRY_BARTIZANS_12739620651264432470)],
        &[(0b01001, &ENTRY_BARTIZAN_3091667005685807749)],
        &[(0b01001, &ENTRY_BARTIZANED_11308940237767481814)],
        &[(0b01001, &ENTRY_BARTIZANS_12739620651264432470)],
        &[(0b00001, &ENTRY_BARYCENTER_18352620831248386358)],
        &[(0b11010, &ENTRY_BARYCENTER_18352620831248386358)],
    ],
    range: 1..=11,
};

static VARS_BAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAP_CHILDREN),
    value: None,
};

pub static VARS_BAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tisable"),
        dictgen::InsensitiveStr::Ascii("tisables"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tised"),
        dictgen::InsensitiveStr::Ascii("tisement"),
        dictgen::InsensitiveStr::Ascii("tisements"),
        dictgen::InsensitiveStr::Ascii("tiser"),
        dictgen::InsensitiveStr::Ascii("tisers"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tising"),
        dictgen::InsensitiveStr::Ascii("tizable"),
        dictgen::InsensitiveStr::Ascii("tizables"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tized"),
        dictgen::InsensitiveStr::Ascii("tizement"),
        dictgen::InsensitiveStr::Ascii("tizements"),
        dictgen::InsensitiveStr::Ascii("tizer"),
        dictgen::InsensitiveStr::Ascii("tizers"),
        dictgen::InsensitiveStr::Ascii("tizes"),
        dictgen::InsensitiveStr::Ascii("tizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BAPTIZABLE_16415989175028506130)],
        &[(0b10010, &ENTRY_BAPTIZABLES_14971615946689154480)],
        &[(0b10010, &ENTRY_BAPTIZE_1514931118124683391)],
        &[(0b10010, &ENTRY_BAPTIZED_13515788660771621839)],
        &[(0b10010, &ENTRY_BAPTIZEMENT_738422419453567978)],
        &[(0b10010, &ENTRY_BAPTIZEMENTS_11049026893818752213)],
        &[(0b10010, &ENTRY_BAPTIZER_9063381427387950458)],
        &[(0b10010, &ENTRY_BAPTIZERS_10757448844252252817)],
        &[(0b10010, &ENTRY_BAPTIZES_6929806982786773033)],
        &[(0b10010, &ENTRY_BAPTIZING_13695168305550097810)],
        &[(0b01001, &ENTRY_BAPTIZABLE_16415989175028506130)],
        &[(0b01001, &ENTRY_BAPTIZABLES_14971615946689154480)],
        &[(0b01001, &ENTRY_BAPTIZE_1514931118124683391)],
        &[(0b01001, &ENTRY_BAPTIZED_13515788660771621839)],
        &[(0b01001, &ENTRY_BAPTIZEMENT_738422419453567978)],
        &[(0b01001, &ENTRY_BAPTIZEMENTS_11049026893818752213)],
        &[(0b01001, &ENTRY_BAPTIZER_9063381427387950458)],
        &[(0b01001, &ENTRY_BAPTIZERS_10757448844252252817)],
        &[(0b01001, &ENTRY_BAPTIZES_6929806982786773033)],
        &[(0b01001, &ENTRY_BAPTIZING_13695168305550097810)],
    ],
    range: 4..=9,
};

static VARS_BAN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAN_CHILDREN),
    value: None,
};

pub static VARS_BAN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("tamise"),
        dictgen::InsensitiveStr::Ascii("tamises"),
        dictgen::InsensitiveStr::Ascii("tamize"),
        dictgen::InsensitiveStr::Ascii("tamizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BANALIZATION_11638029989791824412)],
        &[(0b10010, &ENTRY_BANALIZATIONS_13442258248647777583)],
        &[(0b10010, &ENTRY_BANALIZE_3555517535598908983)],
        &[(0b10010, &ENTRY_BANALIZED_7402767891348368303)],
        &[(0b10010, &ENTRY_BANALIZES_18046806542989340297)],
        &[(0b10010, &ENTRY_BANALIZING_4703954921087288770)],
        &[(0b01001, &ENTRY_BANALIZATION_11638029989791824412)],
        &[(0b01001, &ENTRY_BANALIZATIONS_13442258248647777583)],
        &[(0b01001, &ENTRY_BANALIZE_3555517535598908983)],
        &[(0b01001, &ENTRY_BANALIZED_7402767891348368303)],
        &[(0b01001, &ENTRY_BANALIZES_18046806542989340297)],
        &[(0b01001, &ENTRY_BANALIZING_4703954921087288770)],
        &[(0b10010, &ENTRY_BANTAMIZE_16291863723097401467)],
        &[(0b10010, &ENTRY_BANTAMIZES_12701524523935305027)],
        &[(0b01001, &ENTRY_BANTAMIZE_16291863723097401467)],
        &[(0b01001, &ENTRY_BANTAMIZES_12701524523935305027)],
    ],
    range: 5..=10,
};

static VARS_BAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAL_CHILDREN),
    value: None,
};

pub static VARS_BAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("kanisation"),
        dictgen::InsensitiveStr::Ascii("kanisations"),
        dictgen::InsensitiveStr::Ascii("kanise"),
        dictgen::InsensitiveStr::Ascii("kanised"),
        dictgen::InsensitiveStr::Ascii("kanises"),
        dictgen::InsensitiveStr::Ascii("kanising"),
        dictgen::InsensitiveStr::Ascii("kanization"),
        dictgen::InsensitiveStr::Ascii("kanizations"),
        dictgen::InsensitiveStr::Ascii("kanize"),
        dictgen::InsensitiveStr::Ascii("kanized"),
        dictgen::InsensitiveStr::Ascii("kanizes"),
        dictgen::InsensitiveStr::Ascii("kanizing"),
        dictgen::InsensitiveStr::Ascii("ladise"),
        dictgen::InsensitiveStr::Ascii("ladised"),
        dictgen::InsensitiveStr::Ascii("ladises"),
        dictgen::InsensitiveStr::Ascii("ladising"),
        dictgen::InsensitiveStr::Ascii("ladize"),
        dictgen::InsensitiveStr::Ascii("ladized"),
        dictgen::InsensitiveStr::Ascii("ladizes"),
        dictgen::InsensitiveStr::Ascii("ladizing"),
        dictgen::InsensitiveStr::Ascii("samise"),
        dictgen::InsensitiveStr::Ascii("samises"),
        dictgen::InsensitiveStr::Ascii("samize"),
        dictgen::InsensitiveStr::Ascii("samizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BALKANIZATION_7162843825151431114)],
        &[(0b10010, &ENTRY_BALKANIZATIONS_1102575160899563311)],
        &[(0b10010, &ENTRY_BALKANIZE_626464622875805915)],
        &[(0b10010, &ENTRY_BALKANIZED_7283200167845869640)],
        &[(0b10010, &ENTRY_BALKANIZES_15710898030250571993)],
        &[(0b10010, &ENTRY_BALKANIZING_2444358339203572953)],
        &[(0b01001, &ENTRY_BALKANIZATION_7162843825151431114)],
        &[(0b01001, &ENTRY_BALKANIZATIONS_1102575160899563311)],
        &[(0b01001, &ENTRY_BALKANIZE_626464622875805915)],
        &[(0b01001, &ENTRY_BALKANIZED_7283200167845869640)],
        &[(0b01001, &ENTRY_BALKANIZES_15710898030250571993)],
        &[(0b01001, &ENTRY_BALKANIZING_2444358339203572953)],
        &[(0b10010, &ENTRY_BALLADIZE_15696239668228025324)],
        &[(0b10010, &ENTRY_BALLADIZED_2167734885988214874)],
        &[(0b10010, &ENTRY_BALLADIZES_6866475825533925100)],
        &[(0b10010, &ENTRY_BALLADIZING_3534870542470368404)],
        &[(0b01001, &ENTRY_BALLADIZE_15696239668228025324)],
        &[(0b01001, &ENTRY_BALLADIZED_2167734885988214874)],
        &[(0b01001, &ENTRY_BALLADIZES_6866475825533925100)],
        &[(0b01001, &ENTRY_BALLADIZING_3534870542470368404)],
        &[(0b10010, &ENTRY_BALSAMIZE_1201263166025813215)],
        &[(0b10010, &ENTRY_BALSAMIZES_9137778879856125866)],
        &[(0b01001, &ENTRY_BALSAMIZE_1201263166025813215)],
        &[(0b01001, &ENTRY_BALSAMIZES_9137778879856125866)],
    ],
    range: 6..=11,
};

static VARS_BAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAE_CHILDREN),
    value: None,
};

pub static VARS_BAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("l"),
        dictgen::InsensitiveStr::Ascii("ls"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("ria"),
        dictgen::InsensitiveStr::Ascii("rl"),
        dictgen::InsensitiveStr::Ascii("yer"),
    ],
    values: &[
        &[(0b11010, &ENTRY_BEL_14468840991245400678)],
        &[(0b11010, &ENTRY_BELS_17074483974516039729)],
        &[(0b00001, &ENTRY_BAER_14581860992483818503)],
        &[(0b11010, &ENTRY_BERIA_6249864324866743848)],
        &[(0b11010, &ENTRY_BERL_1185444321092270619)],
        &[(0b11010, &ENTRY_BEYER_14898169439752870815)],
    ],
    range: 1..=3,
};

static VARS_BAC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAC_CHILDREN),
    value: None,
};

pub static VARS_BAC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("helorise"),
        dictgen::InsensitiveStr::Ascii("helorises"),
        dictgen::InsensitiveStr::Ascii("helorize"),
        dictgen::InsensitiveStr::Ascii("helorizes"),
        dictgen::InsensitiveStr::Ascii("illaemia"),
        dictgen::InsensitiveStr::Ascii("illaemias"),
        dictgen::InsensitiveStr::Ascii("illemia"),
        dictgen::InsensitiveStr::Ascii("illemias"),
        dictgen::InsensitiveStr::Ascii("kpedaled"),
        dictgen::InsensitiveStr::Ascii("kpedaling"),
        dictgen::InsensitiveStr::Ascii("kpedalled"),
        dictgen::InsensitiveStr::Ascii("kpedalling"),
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("teraemia"),
        dictgen::InsensitiveStr::Ascii("teraemias"),
        dictgen::InsensitiveStr::Ascii("teremia"),
        dictgen::InsensitiveStr::Ascii("teremias"),
        dictgen::InsensitiveStr::Ascii("teriaemia"),
        dictgen::InsensitiveStr::Ascii("terias"),
        dictgen::InsensitiveStr::Ascii("teriemia"),
        dictgen::InsensitiveStr::Ascii("terise"),
        dictgen::InsensitiveStr::Ascii("terised"),
        dictgen::InsensitiveStr::Ascii("terises"),
        dictgen::InsensitiveStr::Ascii("terising"),
        dictgen::InsensitiveStr::Ascii("terize"),
        dictgen::InsensitiveStr::Ascii("terized"),
        dictgen::InsensitiveStr::Ascii("terizes"),
        dictgen::InsensitiveStr::Ascii("terizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BACHELORIZE_16140957144715523023)],
        &[(0b10010, &ENTRY_BACHELORIZES_18287548054552021920)],
        &[(0b01001, &ENTRY_BACHELORIZE_16140957144715523023)],
        &[(0b01001, &ENTRY_BACHELORIZES_18287548054552021920)],
        &[(0b11010, &ENTRY_BACILLEMIA_6966726555392631595)],
        &[(0b11010, &ENTRY_BACILLEMIAS_5457140517144338455)],
        &[(0b10001, &ENTRY_BACILLEMIA_6966726555392631595)],
        &[(0b10001, &ENTRY_BACILLEMIAS_5457140517144338455)],
        &[(0b00001, &ENTRY_BACKPEDALED_15080995488497192935)],
        &[(0b00001, &ENTRY_BACKPEDALING_16889760085914099362)],
        &[(0b11010, &ENTRY_BACKPEDALED_15080995488497192935)],
        &[(0b11010, &ENTRY_BACKPEDALING_16889760085914099362)],
        &[(0b10010, &ENTRY_BACONIZE_13936618010843734949)],
        &[(0b10010, &ENTRY_BACONIZES_15492280776277479142)],
        &[(0b01001, &ENTRY_BACONIZE_13936618010843734949)],
        &[(0b01001, &ENTRY_BACONIZES_15492280776277479142)],
        &[(0b11010, &ENTRY_BACTEREMIA_7447506279056258270)],
        &[(0b11010, &ENTRY_BACTEREMIAS_3485923405679674442)],
        &[(0b10001, &ENTRY_BACTEREMIA_7447506279056258270)],
        &[(0b10001, &ENTRY_BACTEREMIAS_3485923405679674442)],
        &[(0b11010, &ENTRY_BACTERIEMIA_1013683590812100357)],
        &[(0b00001, &ENTRY_BACTERIA_932829979244663072)],
        &[(0b00001, &ENTRY_BACTERIEMIA_1013683590812100357)],
        &[(0b10010, &ENTRY_BACTERIZE_18408113064097816790)],
        &[(0b10010, &ENTRY_BACTERIZED_2369187923965453166)],
        &[(0b10010, &ENTRY_BACTERIZES_16999732192120374065)],
        &[(0b10010, &ENTRY_BACTERIZING_3356633906290065053)],
        &[(0b01001, &ENTRY_BACTERIZE_18408113064097816790)],
        &[(0b01001, &ENTRY_BACTERIZED_2369187923965453166)],
        &[(0b01001, &ENTRY_BACTERIZES_16999732192120374065)],
        &[(0b01001, &ENTRY_BACTERIZING_3356633906290065053)],
    ],
    range: 5..=10,
};

static VARS_BAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_BAB_CHILDREN),
    value: None,
};

pub static VARS_BAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elisation"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elised"),
        dictgen::InsensitiveStr::Ascii("elising"),
        dictgen::InsensitiveStr::Ascii("elization"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elized"),
        dictgen::InsensitiveStr::Ascii("elizing"),
        dictgen::InsensitiveStr::Ascii("ylonise"),
        dictgen::InsensitiveStr::Ascii("ylonises"),
        dictgen::InsensitiveStr::Ascii("ylonize"),
        dictgen::InsensitiveStr::Ascii("ylonizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_BABELIZATION_6227505335585113751)],
        &[(0b10010, &ENTRY_BABELIZE_14685836478937353557)],
        &[(0b10010, &ENTRY_BABELIZED_9260063960247770923)],
        &[(0b10010, &ENTRY_BABELIZING_3570390515053010427)],
        &[(0b01001, &ENTRY_BABELIZATION_6227505335585113751)],
        &[(0b01001, &ENTRY_BABELIZE_14685836478937353557)],
        &[(0b01001, &ENTRY_BABELIZED_9260063960247770923)],
        &[(0b01001, &ENTRY_BABELIZING_3570390515053010427)],
        &[(0b10010, &ENTRY_BABYLONIZE_11002600115818594610)],
        &[(0b10010, &ENTRY_BABYLONIZES_15691990922940613274)],
        &[(0b01001, &ENTRY_BABYLONIZE_11002600115818594610)],
        &[(0b01001, &ENTRY_BABYLONIZES_15691990922940613274)],
    ],
    range: 5..=9,
};

static VARS_A_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_A_CHILDREN),
    value: None,
};

static VARS_A_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_AA_NODE),
    Some(&VARS_AB_NODE),
    Some(&VARS_AC_NODE),
    Some(&VARS_AD_NODE),
    Some(&VARS_AE_NODE),
    Some(&VARS_AF_NODE),
    Some(&VARS_AG_NODE),
    None,
    Some(&VARS_AI_NODE),
    None,
    Some(&VARS_AK_NODE),
    Some(&VARS_AL_NODE),
    Some(&VARS_AM_NODE),
    Some(&VARS_AN_NODE),
    None,
    Some(&VARS_AP_NODE),
    None,
    Some(&VARS_AR_NODE),
    Some(&VARS_AS_NODE),
    Some(&VARS_AT_NODE),
    Some(&VARS_AU_NODE),
    Some(&VARS_AV_NODE),
    None,
    Some(&VARS_AX_NODE),
    None,
    Some(&VARS_AZ_NODE),
];

static VARS_AZ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AZ_CHILDREN),
    value: None,
};

pub static VARS_AZ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("otaemia"),
        dictgen::InsensitiveStr::Ascii("otemia"),
        dictgen::InsensitiveStr::Ascii("otisation"),
        dictgen::InsensitiveStr::Ascii("otise"),
        dictgen::InsensitiveStr::Ascii("otised"),
        dictgen::InsensitiveStr::Ascii("otises"),
        dictgen::InsensitiveStr::Ascii("otising"),
        dictgen::InsensitiveStr::Ascii("otization"),
        dictgen::InsensitiveStr::Ascii("otize"),
        dictgen::InsensitiveStr::Ascii("otized"),
        dictgen::InsensitiveStr::Ascii("otizes"),
        dictgen::InsensitiveStr::Ascii("otizing"),
        dictgen::InsensitiveStr::Ascii("otorrhea"),
        dictgen::InsensitiveStr::Ascii("otorrhoea"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AZOTEMIA_11026435551695672571)],
        &[(0b00001, &ENTRY_AZOTEMIA_11026435551695672571)],
        &[(0b10010, &ENTRY_AZOTIZATION_16963563287305367427)],
        &[(0b10010, &ENTRY_AZOTIZE_2287686933818550495)],
        &[(0b10010, &ENTRY_AZOTIZED_5442413055636672930)],
        &[(0b10010, &ENTRY_AZOTIZES_11787523905240626686)],
        &[(0b10010, &ENTRY_AZOTIZING_14086470722290046366)],
        &[(0b01001, &ENTRY_AZOTIZATION_16963563287305367427)],
        &[(0b01001, &ENTRY_AZOTIZE_2287686933818550495)],
        &[(0b01001, &ENTRY_AZOTIZED_5442413055636672930)],
        &[(0b01001, &ENTRY_AZOTIZES_11787523905240626686)],
        &[(0b01001, &ENTRY_AZOTIZING_14086470722290046366)],
        &[(0b00001, &ENTRY_AZOTORRHEA_15953136960912190838)],
        &[(0b11010, &ENTRY_AZOTORRHEA_15953136960912190838)],
    ],
    range: 5..=9,
};

static VARS_AX_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AX_CHILDREN),
    value: Some(&[(0b00001, &ENTRY_AX_1575519092942394335)]),
};

pub static VARS_AX_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("iomatisation"),
        dictgen::InsensitiveStr::Ascii("iomatisations"),
        dictgen::InsensitiveStr::Ascii("iomatise"),
        dictgen::InsensitiveStr::Ascii("iomatised"),
        dictgen::InsensitiveStr::Ascii("iomatises"),
        dictgen::InsensitiveStr::Ascii("iomatising"),
        dictgen::InsensitiveStr::Ascii("iomatization"),
        dictgen::InsensitiveStr::Ascii("iomatizations"),
        dictgen::InsensitiveStr::Ascii("iomatize"),
        dictgen::InsensitiveStr::Ascii("iomatized"),
        dictgen::InsensitiveStr::Ascii("iomatizes"),
        dictgen::InsensitiveStr::Ascii("iomatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AX_1575519092942394335)],
        &[(0b10010, &ENTRY_AXIOMATIZATION_2512913160865628279)],
        &[(0b10010, &ENTRY_AXIOMATIZATIONS_4377624432478694059)],
        &[(0b10010, &ENTRY_AXIOMATIZE_10684888507156394817)],
        &[(0b10010, &ENTRY_AXIOMATIZED_13606089758225327424)],
        &[(0b10010, &ENTRY_AXIOMATIZES_8178035167309590431)],
        &[(0b10010, &ENTRY_AXIOMATIZING_1265140579235398858)],
        &[(0b01001, &ENTRY_AXIOMATIZATION_2512913160865628279)],
        &[(0b01001, &ENTRY_AXIOMATIZATIONS_4377624432478694059)],
        &[(0b01001, &ENTRY_AXIOMATIZE_10684888507156394817)],
        &[(0b01001, &ENTRY_AXIOMATIZED_13606089758225327424)],
        &[(0b01001, &ENTRY_AXIOMATIZES_8178035167309590431)],
        &[(0b01001, &ENTRY_AXIOMATIZING_1265140579235398858)],
    ],
    range: 1..=13,
};

static VARS_AV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AV_CHILDREN),
    value: None,
};

pub static VARS_AV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ianise"),
        dictgen::InsensitiveStr::Ascii("ianised"),
        dictgen::InsensitiveStr::Ascii("ianises"),
        dictgen::InsensitiveStr::Ascii("ianising"),
        dictgen::InsensitiveStr::Ascii("ianize"),
        dictgen::InsensitiveStr::Ascii("ianized"),
        dictgen::InsensitiveStr::Ascii("ianizes"),
        dictgen::InsensitiveStr::Ascii("ianizing"),
        dictgen::InsensitiveStr::Ascii("isandum"),
        dictgen::InsensitiveStr::Ascii("isandums"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("izandum"),
        dictgen::InsensitiveStr::Ascii("izandums"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AVIANIZE_10110854240867535999)],
        &[(0b10010, &ENTRY_AVIANIZED_3624907102508634438)],
        &[(0b10010, &ENTRY_AVIANIZES_6407105568503397650)],
        &[(0b10010, &ENTRY_AVIANIZING_14608259848585895347)],
        &[(0b01001, &ENTRY_AVIANIZE_10110854240867535999)],
        &[(0b01001, &ENTRY_AVIANIZED_3624907102508634438)],
        &[(0b01001, &ENTRY_AVIANIZES_6407105568503397650)],
        &[(0b01001, &ENTRY_AVIANIZING_14608259848585895347)],
        &[(0b10010, &ENTRY_AVIZANDUM_15832266843653276586)],
        &[(0b10010, &ENTRY_AVIZANDUMS_10365146430390683692)],
        &[(0b10010, &ENTRY_AVIZE_558609699481267671)],
        &[(0b10010, &ENTRY_AVIZED_374462512849482817)],
        &[(0b10010, &ENTRY_AVIZES_4714530384314138108)],
        &[(0b10010, &ENTRY_AVIZING_3841969763676440589)],
        &[(0b01001, &ENTRY_AVIZANDUM_15832266843653276586)],
        &[(0b01001, &ENTRY_AVIZANDUMS_10365146430390683692)],
        &[(0b01001, &ENTRY_AVIZE_558609699481267671)],
        &[(0b01001, &ENTRY_AVIZED_374462512849482817)],
        &[(0b01001, &ENTRY_AVIZES_4714530384314138108)],
        &[(0b01001, &ENTRY_AVIZING_3841969763676440589)],
    ],
    range: 3..=8,
};

static VARS_AU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AU_CHILDREN),
    value: None,
};

static VARS_AU_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AUN_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_AUS_NODE),
    Some(&VARS_AUT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_AUT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AUT_CHILDREN),
    value: None,
};

static VARS_AUT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    Some(&VARS_AUTE_NODE),
    None,
    None,
    Some(&VARS_AUTH_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AUTO_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_AUTO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUTO_CHILDREN),
    value: None,
};

pub static VARS_AUTO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("catalyse"),
        dictgen::InsensitiveStr::Ascii("catalysed"),
        dictgen::InsensitiveStr::Ascii("catalyses"),
        dictgen::InsensitiveStr::Ascii("catalysing"),
        dictgen::InsensitiveStr::Ascii("catalyze"),
        dictgen::InsensitiveStr::Ascii("catalyzed"),
        dictgen::InsensitiveStr::Ascii("catalyzes"),
        dictgen::InsensitiveStr::Ascii("catalyzing"),
        dictgen::InsensitiveStr::Ascii("dialer"),
        dictgen::InsensitiveStr::Ascii("dialler"),
        dictgen::InsensitiveStr::Ascii("ecious"),
        dictgen::InsensitiveStr::Ascii("eciously"),
        dictgen::InsensitiveStr::Ascii("eciousness"),
        dictgen::InsensitiveStr::Ascii("ecism"),
        dictgen::InsensitiveStr::Ascii("ecisms"),
        dictgen::InsensitiveStr::Ascii("ecy"),
        dictgen::InsensitiveStr::Ascii("immunisation"),
        dictgen::InsensitiveStr::Ascii("immunization"),
        dictgen::InsensitiveStr::Ascii("ionisation"),
        dictgen::InsensitiveStr::Ascii("ionization"),
        dictgen::InsensitiveStr::Ascii("lysate"),
        dictgen::InsensitiveStr::Ascii("lysates"),
        dictgen::InsensitiveStr::Ascii("lyse"),
        dictgen::InsensitiveStr::Ascii("lysed"),
        dictgen::InsensitiveStr::Ascii("lyses"),
        dictgen::InsensitiveStr::Ascii("lysing"),
        dictgen::InsensitiveStr::Ascii("lyzate"),
        dictgen::InsensitiveStr::Ascii("lyzates"),
        dictgen::InsensitiveStr::Ascii("lyze"),
        dictgen::InsensitiveStr::Ascii("lyzed"),
        dictgen::InsensitiveStr::Ascii("lyzes"),
        dictgen::InsensitiveStr::Ascii("lyzing"),
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matisations"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matizations"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
        dictgen::InsensitiveStr::Ascii("noae"),
        dictgen::InsensitiveStr::Ascii("noe"),
        dictgen::InsensitiveStr::Ascii("tomise"),
        dictgen::InsensitiveStr::Ascii("tomised"),
        dictgen::InsensitiveStr::Ascii("tomises"),
        dictgen::InsensitiveStr::Ascii("tomising"),
        dictgen::InsensitiveStr::Ascii("tomize"),
        dictgen::InsensitiveStr::Ascii("tomized"),
        dictgen::InsensitiveStr::Ascii("tomizes"),
        dictgen::InsensitiveStr::Ascii("tomizing"),
        dictgen::InsensitiveStr::Ascii("toxaemia"),
        dictgen::InsensitiveStr::Ascii("toxaemias"),
        dictgen::InsensitiveStr::Ascii("toxemia"),
        dictgen::InsensitiveStr::Ascii("toxemias"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AUTOCATALYZE_11377656786611519467)],
        &[(0b10010, &ENTRY_AUTOCATALYZED_11100710334159127743)],
        &[(0b10010, &ENTRY_AUTOCATALYZES_5725738045167769178)],
        &[(0b10010, &ENTRY_AUTOCATALYZING_5159779918854952475)],
        &[(0b01001, &ENTRY_AUTOCATALYZE_11377656786611519467)],
        &[(0b01001, &ENTRY_AUTOCATALYZED_11100710334159127743)],
        &[(0b01001, &ENTRY_AUTOCATALYZES_5725738045167769178)],
        &[(0b01001, &ENTRY_AUTOCATALYZING_5159779918854952475)],
        &[(0b00001, &ENTRY_AUTODIALER_1134450050813174093)],
        &[(0b11010, &ENTRY_AUTODIALER_1134450050813174093)],
        &[(0b11010, &ENTRY_AUTECIOUS_13333061310808681838)],
        &[(0b11010, &ENTRY_AUTECIOUSLY_14502261960323316507)],
        &[(0b11010, &ENTRY_AUTECIOUSNESS_11976285547644733901)],
        &[(0b11010, &ENTRY_AUTECISM_1715619165077149465)],
        &[(0b11010, &ENTRY_AUTECISMS_2180607123628399675)],
        &[(0b11010, &ENTRY_AUTECY_13719576853502314463)],
        &[(0b10010, &ENTRY_AUTOIMMUNIZATION_9708656153855152039)],
        &[(0b01001, &ENTRY_AUTOIMMUNIZATION_9708656153855152039)],
        &[(0b10010, &ENTRY_AUTOIONIZATION_6978369082999863184)],
        &[(0b01001, &ENTRY_AUTOIONIZATION_6978369082999863184)],
        &[(0b10010, &ENTRY_AUTOLYZATE_13897976732846843186)],
        &[(0b10010, &ENTRY_AUTOLYZATES_1225100042828836123)],
        &[(0b10010, &ENTRY_AUTOLYZE_11473855583949653238)],
        &[(0b10010, &ENTRY_AUTOLYZED_17033910730696642695)],
        &[(0b10010, &ENTRY_AUTOLYZES_15600692012613351200)],
        &[(0b10010, &ENTRY_AUTOLYZING_489296052443611874)],
        &[(0b01001, &ENTRY_AUTOLYZATE_13897976732846843186)],
        &[(0b01001, &ENTRY_AUTOLYZATES_1225100042828836123)],
        &[(0b01001, &ENTRY_AUTOLYZE_11473855583949653238)],
        &[(0b01001, &ENTRY_AUTOLYZED_17033910730696642695)],
        &[(0b01001, &ENTRY_AUTOLYZES_15600692012613351200)],
        &[(0b01001, &ENTRY_AUTOLYZING_489296052443611874)],
        &[(0b10010, &ENTRY_AUTOMATIZATION_1620858880780330964)],
        &[(0b10010, &ENTRY_AUTOMATIZATIONS_619849714390905963)],
        &[(0b10010, &ENTRY_AUTOMATIZE_7880401560635519882)],
        &[(0b10010, &ENTRY_AUTOMATIZED_9571719111299962204)],
        &[(0b10010, &ENTRY_AUTOMATIZES_9261149387605266072)],
        &[(0b10010, &ENTRY_AUTOMATIZING_11897346773175064542)],
        &[(0b01001, &ENTRY_AUTOMATIZATION_1620858880780330964)],
        &[(0b01001, &ENTRY_AUTOMATIZATIONS_619849714390905963)],
        &[(0b01001, &ENTRY_AUTOMATIZE_7880401560635519882)],
        &[(0b01001, &ENTRY_AUTOMATIZED_9571719111299962204)],
        &[(0b01001, &ENTRY_AUTOMATIZES_9261149387605266072)],
        &[(0b01001, &ENTRY_AUTOMATIZING_11897346773175064542)],
        &[(0b11010, &ENTRY_AUTONOE_11409143792101174133)],
        &[(0b00001, &ENTRY_AUTONOE_11409143792101174133)],
        &[(0b10010, &ENTRY_AUTOTOMIZE_10870376480991549462)],
        &[(0b10010, &ENTRY_AUTOTOMIZED_7590157601515171803)],
        &[(0b10010, &ENTRY_AUTOTOMIZES_9909588375372995524)],
        &[(0b10010, &ENTRY_AUTOTOMIZING_18376066296486340252)],
        &[(0b01001, &ENTRY_AUTOTOMIZE_10870376480991549462)],
        &[(0b01001, &ENTRY_AUTOTOMIZED_7590157601515171803)],
        &[(0b01001, &ENTRY_AUTOTOMIZES_9909588375372995524)],
        &[(0b01001, &ENTRY_AUTOTOMIZING_18376066296486340252)],
        &[(0b11010, &ENTRY_AUTOTOXEMIA_18366267511576797743)],
        &[(0b11010, &ENTRY_AUTOTOXEMIAS_3350713876222978889)],
        &[(0b00001, &ENTRY_AUTOTOXEMIA_18366267511576797743)],
        &[(0b00001, &ENTRY_AUTOTOXEMIAS_3350713876222978889)],
    ],
    range: 3..=12,
};

static VARS_AUTH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUTH_CHILDREN),
    value: None,
};

pub static VARS_AUTH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("orisable"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("oriser"),
        dictgen::InsensitiveStr::Ascii("orisers"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orizable"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizer"),
        dictgen::InsensitiveStr::Ascii("orizers"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AUTHORIZABLE_5231844717756889861)],
        &[(0b10010, &ENTRY_AUTHORIZATION_395843400641738718)],
        &[(0b10010, &ENTRY_AUTHORIZATIONS_3134679260837487294)],
        &[(0b10010, &ENTRY_AUTHORIZE_12314763752837557145)],
        &[(0b10010, &ENTRY_AUTHORIZED_2551432787313490355)],
        &[(0b10010, &ENTRY_AUTHORIZER_4327258003305487952)],
        &[(0b10010, &ENTRY_AUTHORIZERS_8627630439372760014)],
        &[(0b10010, &ENTRY_AUTHORIZES_17496628475906077057)],
        &[(0b10010, &ENTRY_AUTHORIZING_6195944790124186706)],
        &[(0b01001, &ENTRY_AUTHORIZABLE_5231844717756889861)],
        &[(0b01001, &ENTRY_AUTHORIZATION_395843400641738718)],
        &[(0b01001, &ENTRY_AUTHORIZATIONS_3134679260837487294)],
        &[(0b01001, &ENTRY_AUTHORIZE_12314763752837557145)],
        &[(0b01001, &ENTRY_AUTHORIZED_2551432787313490355)],
        &[(0b01001, &ENTRY_AUTHORIZER_4327258003305487952)],
        &[(0b01001, &ENTRY_AUTHORIZERS_8627630439372760014)],
        &[(0b01001, &ENTRY_AUTHORIZES_17496628475906077057)],
        &[(0b01001, &ENTRY_AUTHORIZING_6195944790124186706)],
    ],
    range: 5..=10,
};

static VARS_AUTE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUTE_CHILDREN),
    value: None,
};

pub static VARS_AUTE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("cious"),
        dictgen::InsensitiveStr::Ascii("ciously"),
        dictgen::InsensitiveStr::Ascii("ciousness"),
        dictgen::InsensitiveStr::Ascii("cism"),
        dictgen::InsensitiveStr::Ascii("cisms"),
        dictgen::InsensitiveStr::Ascii("cy"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AUTECIOUS_13333061310808681838)],
        &[(0b00001, &ENTRY_AUTECIOUSLY_14502261960323316507)],
        &[(0b00001, &ENTRY_AUTECIOUSNESS_11976285547644733901)],
        &[(0b00001, &ENTRY_AUTECISM_1715619165077149465)],
        &[(0b00001, &ENTRY_AUTECISMS_2180607123628399675)],
        &[(0b00001, &ENTRY_AUTECY_13719576853502314463)],
    ],
    range: 2..=9,
};

static VARS_AUS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUS_CHILDREN),
    value: None,
};

pub static VARS_AUS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tralianise"),
        dictgen::InsensitiveStr::Ascii("tralianises"),
        dictgen::InsensitiveStr::Ascii("tralianize"),
        dictgen::InsensitiveStr::Ascii("tralianizes"),
        dictgen::InsensitiveStr::Ascii("tralopithecinae"),
        dictgen::InsensitiveStr::Ascii("tralopithecine"),
        dictgen::InsensitiveStr::Ascii("trianise"),
        dictgen::InsensitiveStr::Ascii("trianises"),
        dictgen::InsensitiveStr::Ascii("trianize"),
        dictgen::InsensitiveStr::Ascii("trianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AUSTRALIANIZE_15680337575086561646)],
        &[(0b10010, &ENTRY_AUSTRALIANIZES_15628526718481795434)],
        &[(0b01001, &ENTRY_AUSTRALIANIZE_15680337575086561646)],
        &[(0b01001, &ENTRY_AUSTRALIANIZES_15628526718481795434)],
        &[(0b11010, &ENTRY_AUSTRALOPITHECINE_461885205668956581)],
        &[(0b00001, &ENTRY_AUSTRALOPITHECINE_461885205668956581)],
        &[(0b10010, &ENTRY_AUSTRIANIZE_13889494210532044520)],
        &[(0b10010, &ENTRY_AUSTRIANIZES_15942538329526351866)],
        &[(0b01001, &ENTRY_AUSTRIANIZE_13889494210532044520)],
        &[(0b01001, &ENTRY_AUSTRIANIZES_15942538329526351866)],
    ],
    range: 8..=15,
};

static VARS_AUN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AUN_CHILDREN),
    value: None,
};

pub static VARS_AUN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ter"),
        dictgen::InsensitiveStr::Ascii("tre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AUNTER_3984069006526724037)],
        &[(0b11010, &ENTRY_AUNTER_3984069006526724037)],
    ],
    range: 3..=3,
};

static VARS_AT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AT_CHILDREN),
    value: None,
};

static VARS_AT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ATH_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ATM_NODE),
    None,
    Some(&VARS_ATO_NODE),
    None,
    None,
    Some(&VARS_ATR_NODE),
    None,
    Some(&VARS_ATT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ATT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATT_CHILDREN),
    value: None,
};

pub static VARS_ATT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emper"),
        dictgen::InsensitiveStr::Ascii("empre"),
        dictgen::InsensitiveStr::Ascii("icise"),
        dictgen::InsensitiveStr::Ascii("icised"),
        dictgen::InsensitiveStr::Ascii("icises"),
        dictgen::InsensitiveStr::Ascii("icising"),
        dictgen::InsensitiveStr::Ascii("icize"),
        dictgen::InsensitiveStr::Ascii("icized"),
        dictgen::InsensitiveStr::Ascii("icizes"),
        dictgen::InsensitiveStr::Ascii("icizing"),
        dictgen::InsensitiveStr::Ascii("itudinisation"),
        dictgen::InsensitiveStr::Ascii("itudinise"),
        dictgen::InsensitiveStr::Ascii("itudinised"),
        dictgen::InsensitiveStr::Ascii("itudiniser"),
        dictgen::InsensitiveStr::Ascii("itudinisers"),
        dictgen::InsensitiveStr::Ascii("itudinises"),
        dictgen::InsensitiveStr::Ascii("itudinising"),
        dictgen::InsensitiveStr::Ascii("itudinisings"),
        dictgen::InsensitiveStr::Ascii("itudinization"),
        dictgen::InsensitiveStr::Ascii("itudinize"),
        dictgen::InsensitiveStr::Ascii("itudinized"),
        dictgen::InsensitiveStr::Ascii("itudinizer"),
        dictgen::InsensitiveStr::Ascii("itudinizers"),
        dictgen::InsensitiveStr::Ascii("itudinizes"),
        dictgen::InsensitiveStr::Ascii("itudinizing"),
        dictgen::InsensitiveStr::Ascii("itudinizings"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ATTEMPER_10321595750792114646)],
        &[(0b11010, &ENTRY_ATTEMPER_10321595750792114646)],
        &[(0b10010, &ENTRY_ATTICIZE_10540291067079331794)],
        &[(0b10010, &ENTRY_ATTICIZED_17898369434810945049)],
        &[(0b10010, &ENTRY_ATTICIZES_7824093798291526926)],
        &[(0b10010, &ENTRY_ATTICIZING_12115148616495024690)],
        &[(0b01001, &ENTRY_ATTICIZE_10540291067079331794)],
        &[(0b01001, &ENTRY_ATTICIZED_17898369434810945049)],
        &[(0b01001, &ENTRY_ATTICIZES_7824093798291526926)],
        &[(0b01001, &ENTRY_ATTICIZING_12115148616495024690)],
        &[(0b10010, &ENTRY_ATTITUDINIZATION_17706899523030773650)],
        &[(0b10010, &ENTRY_ATTITUDINIZE_4708014689700982410)],
        &[(0b10010, &ENTRY_ATTITUDINIZED_5404939483170560810)],
        &[(0b10010, &ENTRY_ATTITUDINIZER_2282587564825240743)],
        &[(0b10010, &ENTRY_ATTITUDINIZERS_11505676119055064972)],
        &[(0b10010, &ENTRY_ATTITUDINIZES_4849080985867035260)],
        &[(0b10010, &ENTRY_ATTITUDINIZING_3722680743543175700)],
        &[(0b10010, &ENTRY_ATTITUDINIZINGS_1081765832368849783)],
        &[(0b01001, &ENTRY_ATTITUDINIZATION_17706899523030773650)],
        &[(0b01001, &ENTRY_ATTITUDINIZE_4708014689700982410)],
        &[(0b01001, &ENTRY_ATTITUDINIZED_5404939483170560810)],
        &[(0b01001, &ENTRY_ATTITUDINIZER_2282587564825240743)],
        &[(0b01001, &ENTRY_ATTITUDINIZERS_11505676119055064972)],
        &[(0b01001, &ENTRY_ATTITUDINIZES_4849080985867035260)],
        &[(0b01001, &ENTRY_ATTITUDINIZING_3722680743543175700)],
        &[(0b01001, &ENTRY_ATTITUDINIZINGS_1081765832368849783)],
    ],
    range: 5..=13,
};

static VARS_ATR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATR_CHILDREN),
    value: None,
};

pub static VARS_ATR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("oceruleus"),
        dictgen::InsensitiveStr::Ascii("ocoeruleus"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ATROCERULEUS_7452134384217065626)],
        &[(0b11010, &ENTRY_ATROCERULEUS_7452134384217065626)],
    ],
    range: 9..=10,
};

static VARS_ATO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATO_CHILDREN),
    value: None,
};

pub static VARS_ATO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("misability"),
        dictgen::InsensitiveStr::Ascii("misable"),
        dictgen::InsensitiveStr::Ascii("misation"),
        dictgen::InsensitiveStr::Ascii("misations"),
        dictgen::InsensitiveStr::Ascii("mise"),
        dictgen::InsensitiveStr::Ascii("mised"),
        dictgen::InsensitiveStr::Ascii("miser"),
        dictgen::InsensitiveStr::Ascii("misers"),
        dictgen::InsensitiveStr::Ascii("mises"),
        dictgen::InsensitiveStr::Ascii("mising"),
        dictgen::InsensitiveStr::Ascii("mizability"),
        dictgen::InsensitiveStr::Ascii("mizable"),
        dictgen::InsensitiveStr::Ascii("mization"),
        dictgen::InsensitiveStr::Ascii("mizations"),
        dictgen::InsensitiveStr::Ascii("mize"),
        dictgen::InsensitiveStr::Ascii("mized"),
        dictgen::InsensitiveStr::Ascii("mizer"),
        dictgen::InsensitiveStr::Ascii("mizers"),
        dictgen::InsensitiveStr::Ascii("mizes"),
        dictgen::InsensitiveStr::Ascii("mizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ATOMIZABILITY_3662844297231153629)],
        &[(0b10010, &ENTRY_ATOMIZABLE_9006232702939622749)],
        &[(0b10010, &ENTRY_ATOMIZATION_17590563802310665738)],
        &[(0b10010, &ENTRY_ATOMIZATIONS_15654929944891871906)],
        &[(0b10010, &ENTRY_ATOMIZE_2064605152651050847)],
        &[(0b10010, &ENTRY_ATOMIZED_8537277580871094585)],
        &[(0b10010, &ENTRY_ATOMIZER_10420576678406032842)],
        &[(0b10010, &ENTRY_ATOMIZERS_14449646570970952892)],
        &[(0b10010, &ENTRY_ATOMIZES_963643916071531136)],
        &[(0b10010, &ENTRY_ATOMIZING_14986115038272633138)],
        &[(0b01001, &ENTRY_ATOMIZABILITY_3662844297231153629)],
        &[(0b01001, &ENTRY_ATOMIZABLE_9006232702939622749)],
        &[(0b01001, &ENTRY_ATOMIZATION_17590563802310665738)],
        &[(0b01001, &ENTRY_ATOMIZATIONS_15654929944891871906)],
        &[(0b01001, &ENTRY_ATOMIZE_2064605152651050847)],
        &[(0b01001, &ENTRY_ATOMIZED_8537277580871094585)],
        &[(0b01001, &ENTRY_ATOMIZER_10420576678406032842)],
        &[(0b01001, &ENTRY_ATOMIZERS_14449646570970952892)],
        &[(0b01001, &ENTRY_ATOMIZES_963643916071531136)],
        &[(0b01001, &ENTRY_ATOMIZING_14986115038272633138)],
    ],
    range: 4..=10,
};

static VARS_ATM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATM_CHILDREN),
    value: None,
};

pub static VARS_ATM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("olyse"),
        dictgen::InsensitiveStr::Ascii("olysed"),
        dictgen::InsensitiveStr::Ascii("olyses"),
        dictgen::InsensitiveStr::Ascii("olysing"),
        dictgen::InsensitiveStr::Ascii("olyze"),
        dictgen::InsensitiveStr::Ascii("olyzed"),
        dictgen::InsensitiveStr::Ascii("olyzes"),
        dictgen::InsensitiveStr::Ascii("olyzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ATMOLYZE_6907417165654906772)],
        &[(0b10010, &ENTRY_ATMOLYZED_12772305670820601939)],
        &[(0b10010, &ENTRY_ATMOLYZES_14417513048999254193)],
        &[(0b10010, &ENTRY_ATMOLYZING_12067305970424863391)],
        &[(0b01001, &ENTRY_ATMOLYZE_6907417165654906772)],
        &[(0b01001, &ENTRY_ATMOLYZED_12772305670820601939)],
        &[(0b01001, &ENTRY_ATMOLYZES_14417513048999254193)],
        &[(0b01001, &ENTRY_ATMOLYZING_12067305970424863391)],
    ],
    range: 5..=7,
};

static VARS_ATH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ATH_CHILDREN),
    value: None,
};

pub static VARS_ATH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eise"),
        dictgen::InsensitiveStr::Ascii("eised"),
        dictgen::InsensitiveStr::Ascii("eises"),
        dictgen::InsensitiveStr::Ascii("eising"),
        dictgen::InsensitiveStr::Ascii("eize"),
        dictgen::InsensitiveStr::Ascii("eized"),
        dictgen::InsensitiveStr::Ascii("eizes"),
        dictgen::InsensitiveStr::Ascii("eizing"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ATHEIZE_1650523572049665618)],
        &[(0b10010, &ENTRY_ATHEIZED_8361944679804490409)],
        &[(0b10010, &ENTRY_ATHEIZES_131064789695988757)],
        &[(0b10010, &ENTRY_ATHEIZING_3233601106148671334)],
        &[(0b01001, &ENTRY_ATHEIZE_1650523572049665618)],
        &[(0b01001, &ENTRY_ATHEIZED_8361944679804490409)],
        &[(0b01001, &ENTRY_ATHEIZES_131064789695988757)],
        &[(0b01001, &ENTRY_ATHEIZING_3233601106148671334)],
        &[(0b10010, &ENTRY_ATHETIZE_16801924254921136220)],
        &[(0b10010, &ENTRY_ATHETIZED_9779500563027955411)],
        &[(0b10010, &ENTRY_ATHETIZES_3263174137872390116)],
        &[(0b10010, &ENTRY_ATHETIZING_9191281724888382129)],
        &[(0b01001, &ENTRY_ATHETIZE_16801924254921136220)],
        &[(0b01001, &ENTRY_ATHETIZED_9779500563027955411)],
        &[(0b01001, &ENTRY_ATHETIZES_3263174137872390116)],
        &[(0b01001, &ENTRY_ATHETIZING_9191281724888382129)],
    ],
    range: 4..=7,
};

static VARS_AS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AS_CHILDREN),
    value: None,
};

static VARS_AS_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ASA_NODE),
    None,
    Some(&VARS_ASC_NODE),
    None,
    Some(&VARS_ASE_NODE),
    None,
    None,
    None,
    Some(&VARS_ASI_NODE),
    None,
    None,
    None,
    Some(&VARS_ASM_NODE),
    None,
    None,
    Some(&VARS_ASP_NODE),
    None,
    None,
    Some(&VARS_ASS_NODE),
    Some(&VARS_AST_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ASY_NODE),
    None,
];

static VARS_ASY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASY_CHILDREN),
    value: None,
};

pub static VARS_ASY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nchronise"),
        dictgen::InsensitiveStr::Ascii("nchronised"),
        dictgen::InsensitiveStr::Ascii("nchronises"),
        dictgen::InsensitiveStr::Ascii("nchronising"),
        dictgen::InsensitiveStr::Ascii("nchronize"),
        dictgen::InsensitiveStr::Ascii("nchronized"),
        dictgen::InsensitiveStr::Ascii("nchronizes"),
        dictgen::InsensitiveStr::Ascii("nchronizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ASYNCHRONIZE_3165012635702999054)],
        &[(0b10010, &ENTRY_ASYNCHRONIZED_2264379807465924648)],
        &[(0b10010, &ENTRY_ASYNCHRONIZES_4368864858861627592)],
        &[(0b10010, &ENTRY_ASYNCHRONIZING_16727683109340331408)],
        &[(0b01001, &ENTRY_ASYNCHRONIZE_3165012635702999054)],
        &[(0b01001, &ENTRY_ASYNCHRONIZED_2264379807465924648)],
        &[(0b01001, &ENTRY_ASYNCHRONIZES_4368864858861627592)],
        &[(0b01001, &ENTRY_ASYNCHRONIZING_16727683109340331408)],
    ],
    range: 9..=11,
};

static VARS_AST_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AST_CHILDREN),
    value: None,
};

pub static VARS_AST_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("era"),
        dictgen::InsensitiveStr::Ascii("igmatiser"),
        dictgen::InsensitiveStr::Ascii("igmatisers"),
        dictgen::InsensitiveStr::Ascii("igmatizer"),
        dictgen::InsensitiveStr::Ascii("igmatizers"),
        dictgen::InsensitiveStr::Ascii("raea"),
        dictgen::InsensitiveStr::Ascii("raean"),
        dictgen::InsensitiveStr::Ascii("rea"),
        dictgen::InsensitiveStr::Ascii("rean"),
        dictgen::InsensitiveStr::Ascii("ronomise"),
        dictgen::InsensitiveStr::Ascii("ronomised"),
        dictgen::InsensitiveStr::Ascii("ronomises"),
        dictgen::InsensitiveStr::Ascii("ronomising"),
        dictgen::InsensitiveStr::Ascii("ronomize"),
        dictgen::InsensitiveStr::Ascii("ronomized"),
        dictgen::InsensitiveStr::Ascii("ronomizes"),
        dictgen::InsensitiveStr::Ascii("ronomizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ASTERA_15037794719691540402)],
        &[(0b10010, &ENTRY_ASTIGMATIZER_5573446594967375201)],
        &[(0b10010, &ENTRY_ASTIGMATIZERS_18090102560636046522)],
        &[(0b01001, &ENTRY_ASTIGMATIZER_5573446594967375201)],
        &[(0b01001, &ENTRY_ASTIGMATIZERS_18090102560636046522)],
        &[(0b11010, &ENTRY_ASTREA_9491635490797963619)],
        &[(0b11010, &ENTRY_ASTREAN_17672754089710155278)],
        &[
            (0b11010, &ENTRY_ASTERA_15037794719691540402),
            (0b00001, &ENTRY_ASTREA_9491635490797963619),
        ],
        &[(0b00001, &ENTRY_ASTREAN_17672754089710155278)],
        &[(0b10010, &ENTRY_ASTRONOMIZE_8434822243027737838)],
        &[(0b10010, &ENTRY_ASTRONOMIZED_17892819808746658022)],
        &[(0b10010, &ENTRY_ASTRONOMIZES_3426897682798715707)],
        &[(0b10010, &ENTRY_ASTRONOMIZING_14727829167008307417)],
        &[(0b01001, &ENTRY_ASTRONOMIZE_8434822243027737838)],
        &[(0b01001, &ENTRY_ASTRONOMIZED_17892819808746658022)],
        &[(0b01001, &ENTRY_ASTRONOMIZES_3426897682798715707)],
        &[(0b01001, &ENTRY_ASTRONOMIZING_14727829167008307417)],
    ],
    range: 3..=10,
};

static VARS_ASS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASS_CHILDREN),
    value: None,
};

pub static VARS_ASS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("afetida"),
        dictgen::InsensitiveStr::Ascii("afetidas"),
        dictgen::InsensitiveStr::Ascii("afoetida"),
        dictgen::InsensitiveStr::Ascii("afoetidas"),
        dictgen::InsensitiveStr::Ascii("hole"),
        dictgen::InsensitiveStr::Ascii("holes"),
        dictgen::InsensitiveStr::Ascii("idaean"),
        dictgen::InsensitiveStr::Ascii("idean"),
        dictgen::InsensitiveStr::Ascii("yrianise"),
        dictgen::InsensitiveStr::Ascii("yrianises"),
        dictgen::InsensitiveStr::Ascii("yrianize"),
        dictgen::InsensitiveStr::Ascii("yrianizes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ASSAFETIDA_113224093999442010)],
        &[(0b00001, &ENTRY_ASSAFETIDAS_15617703533170914973)],
        &[(0b11010, &ENTRY_ASSAFETIDA_113224093999442010)],
        &[(0b11010, &ENTRY_ASSAFETIDAS_15617703533170914973)],
        &[(0b00001, &ENTRY_ASSHOLE_12964338351998611148)],
        &[(0b00001, &ENTRY_ASSHOLES_13924057355694920061)],
        &[(0b11010, &ENTRY_ASSIDEAN_4573494847516673943)],
        &[(0b00001, &ENTRY_ASSIDEAN_4573494847516673943)],
        &[(0b10010, &ENTRY_ASSYRIANIZE_9925515178117509112)],
        &[(0b10010, &ENTRY_ASSYRIANIZES_1350783930464276444)],
        &[(0b01001, &ENTRY_ASSYRIANIZE_9925515178117509112)],
        &[(0b01001, &ENTRY_ASSYRIANIZES_1350783930464276444)],
    ],
    range: 4..=9,
};

static VARS_ASP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASP_CHILDREN),
    value: None,
};

pub static VARS_ASP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("heterise"),
        dictgen::InsensitiveStr::Ascii("heterised"),
        dictgen::InsensitiveStr::Ascii("heterises"),
        dictgen::InsensitiveStr::Ascii("heterising"),
        dictgen::InsensitiveStr::Ascii("heterize"),
        dictgen::InsensitiveStr::Ascii("heterized"),
        dictgen::InsensitiveStr::Ascii("heterizes"),
        dictgen::InsensitiveStr::Ascii("heterizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ASPHETERIZE_16117159886415614048)],
        &[(0b10010, &ENTRY_ASPHETERIZED_10290056046377700436)],
        &[(0b10010, &ENTRY_ASPHETERIZES_14734322769410196190)],
        &[(0b10010, &ENTRY_ASPHETERIZING_6898599003467614908)],
        &[(0b01001, &ENTRY_ASPHETERIZE_16117159886415614048)],
        &[(0b01001, &ENTRY_ASPHETERIZED_10290056046377700436)],
        &[(0b01001, &ENTRY_ASPHETERIZES_14734322769410196190)],
        &[(0b01001, &ENTRY_ASPHETERIZING_6898599003467614908)],
    ],
    range: 8..=10,
};

static VARS_ASM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASM_CHILDREN),
    value: None,
};

pub static VARS_ASM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onaean"),
        dictgen::InsensitiveStr::Ascii("onean"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ASMONEAN_8413395248866854750)],
        &[(0b10001, &ENTRY_ASMONEAN_8413395248866854750)],
    ],
    range: 5..=6,
};

static VARS_ASI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASI_CHILDREN),
    value: None,
};

pub static VARS_ASI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aticisation"),
        dictgen::InsensitiveStr::Ascii("aticisations"),
        dictgen::InsensitiveStr::Ascii("aticise"),
        dictgen::InsensitiveStr::Ascii("aticises"),
        dictgen::InsensitiveStr::Ascii("aticization"),
        dictgen::InsensitiveStr::Ascii("aticizations"),
        dictgen::InsensitiveStr::Ascii("aticize"),
        dictgen::InsensitiveStr::Ascii("aticizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ASIATICIZATION_4610120106437867166)],
        &[(0b10010, &ENTRY_ASIATICIZATIONS_12783056870942421620)],
        &[(0b10010, &ENTRY_ASIATICIZE_17700168473976448799)],
        &[(0b10010, &ENTRY_ASIATICIZES_16830856299856603906)],
        &[(0b01001, &ENTRY_ASIATICIZATION_4610120106437867166)],
        &[(0b01001, &ENTRY_ASIATICIZATIONS_12783056870942421620)],
        &[(0b01001, &ENTRY_ASIATICIZE_17700168473976448799)],
        &[(0b01001, &ENTRY_ASIATICIZES_16830856299856603906)],
    ],
    range: 7..=12,
};

static VARS_ASE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASE_CHILDREN),
    value: None,
};

pub static VARS_ASE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("l"),
        dictgen::InsensitiveStr::Ascii("pticise"),
        dictgen::InsensitiveStr::Ascii("pticised"),
        dictgen::InsensitiveStr::Ascii("pticises"),
        dictgen::InsensitiveStr::Ascii("pticising"),
        dictgen::InsensitiveStr::Ascii("pticize"),
        dictgen::InsensitiveStr::Ascii("pticized"),
        dictgen::InsensitiveStr::Ascii("pticizes"),
        dictgen::InsensitiveStr::Ascii("pticizing"),
        dictgen::InsensitiveStr::Ascii("xualisation"),
        dictgen::InsensitiveStr::Ascii("xualise"),
        dictgen::InsensitiveStr::Ascii("xualised"),
        dictgen::InsensitiveStr::Ascii("xualising"),
        dictgen::InsensitiveStr::Ascii("xualization"),
        dictgen::InsensitiveStr::Ascii("xualize"),
        dictgen::InsensitiveStr::Ascii("xualized"),
        dictgen::InsensitiveStr::Ascii("xualizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ASEL_2991140811333800185)],
        &[(0b10010, &ENTRY_ASEPTICIZE_3933929209320869926)],
        &[(0b10010, &ENTRY_ASEPTICIZED_17514342866645218287)],
        &[(0b10010, &ENTRY_ASEPTICIZES_18007236908793048941)],
        &[(0b10010, &ENTRY_ASEPTICIZING_16831292622846251458)],
        &[(0b01001, &ENTRY_ASEPTICIZE_3933929209320869926)],
        &[(0b01001, &ENTRY_ASEPTICIZED_17514342866645218287)],
        &[(0b01001, &ENTRY_ASEPTICIZES_18007236908793048941)],
        &[(0b01001, &ENTRY_ASEPTICIZING_16831292622846251458)],
        &[(0b10010, &ENTRY_ASEXUALIZATION_15410884236551711164)],
        &[(0b10010, &ENTRY_ASEXUALIZE_9124079032501171431)],
        &[(0b10010, &ENTRY_ASEXUALIZED_7482569439479163307)],
        &[(0b10010, &ENTRY_ASEXUALIZING_12563154882147712490)],
        &[(0b01001, &ENTRY_ASEXUALIZATION_15410884236551711164)],
        &[(0b01001, &ENTRY_ASEXUALIZE_9124079032501171431)],
        &[(0b01001, &ENTRY_ASEXUALIZED_7482569439479163307)],
        &[(0b01001, &ENTRY_ASEXUALIZING_12563154882147712490)],
    ],
    range: 1..=11,
};

static VARS_ASC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASC_CHILDREN),
    value: None,
};

pub static VARS_ASC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("endency"),
        dictgen::InsensitiveStr::Ascii("endent"),
        dictgen::InsensitiveStr::Ascii("endents"),
        dictgen::InsensitiveStr::Ascii("lepiadae"),
        dictgen::InsensitiveStr::Ascii("lepiade"),
    ],
    values: &[
        &[(0b01001, &ENTRY_ASCENDANCY_17212684530560634805)],
        &[(0b10011, &ENTRY_ASCENDANT_2752266460494779856)],
        &[(0b10011, &ENTRY_ASCENDANTS_15521170888856908309)],
        &[(0b11010, &ENTRY_ASCLEPIADE_10210677193219397680)],
        &[(0b00001, &ENTRY_ASCLEPIADE_10210677193219397680)],
    ],
    range: 6..=8,
};

static VARS_ASA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ASA_CHILDREN),
    value: None,
};

pub static VARS_ASA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("el"),
        dictgen::InsensitiveStr::Ascii("fetida"),
        dictgen::InsensitiveStr::Ascii("fetidas"),
        dictgen::InsensitiveStr::Ascii("foetida"),
        dictgen::InsensitiveStr::Ascii("foetidas"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ASEL_2991140811333800185)],
        &[(0b01001, &ENTRY_ASAFETIDA_14075127292131066209)],
        &[(0b01001, &ENTRY_ASAFETIDAS_3146529801559413940)],
        &[(0b11010, &ENTRY_ASAFETIDA_14075127292131066209)],
        &[(0b11010, &ENTRY_ASAFETIDAS_3146529801559413940)],
    ],
    range: 2..=8,
};

static VARS_AR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AR_CHILDREN),
    value: None,
};

static VARS_AR_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ARA_NODE),
    Some(&VARS_ARB_NODE),
    Some(&VARS_ARC_NODE),
    Some(&VARS_ARD_NODE),
    Some(&VARS_ARE_NODE),
    None,
    None,
    None,
    Some(&VARS_ARI_NODE),
    None,
    None,
    None,
    Some(&VARS_ARM_NODE),
    None,
    Some(&VARS_ARO_NODE),
    None,
    None,
    None,
    Some(&VARS_ARS_NODE),
    Some(&VARS_ART_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ARY_NODE),
    None,
];

static VARS_ARY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARY_CHILDREN),
    value: None,
};

pub static VARS_ARY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anisation"),
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anization"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("taenoid"),
        dictgen::InsensitiveStr::Ascii("taenoids"),
        dictgen::InsensitiveStr::Ascii("tenoid"),
        dictgen::InsensitiveStr::Ascii("tenoids"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ARYANIZATION_9851944027750269067)],
        &[(0b10010, &ENTRY_ARYANIZE_16869282873759611476)],
        &[(0b10010, &ENTRY_ARYANIZED_2198024662554456823)],
        &[(0b10010, &ENTRY_ARYANIZES_1271531809715528591)],
        &[(0b10010, &ENTRY_ARYANIZING_14999690626685964985)],
        &[(0b01001, &ENTRY_ARYANIZATION_9851944027750269067)],
        &[(0b01001, &ENTRY_ARYANIZE_16869282873759611476)],
        &[(0b01001, &ENTRY_ARYANIZED_2198024662554456823)],
        &[(0b01001, &ENTRY_ARYANIZES_1271531809715528591)],
        &[(0b01001, &ENTRY_ARYANIZING_14999690626685964985)],
        &[(0b11010, &ENTRY_ARYTENOID_7001515572255686205)],
        &[(0b11010, &ENTRY_ARYTENOIDS_4570196976416030148)],
        &[(0b00001, &ENTRY_ARYTENOID_7001515572255686205)],
        &[(0b00001, &ENTRY_ARYTENOIDS_4570196976416030148)],
    ],
    range: 5..=9,
};

static VARS_ART_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ART_CHILDREN),
    value: None,
};

pub static VARS_ART_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("efact"),
        dictgen::InsensitiveStr::Ascii("efacts"),
        dictgen::InsensitiveStr::Ascii("erialisation"),
        dictgen::InsensitiveStr::Ascii("erialisations"),
        dictgen::InsensitiveStr::Ascii("erialise"),
        dictgen::InsensitiveStr::Ascii("erialised"),
        dictgen::InsensitiveStr::Ascii("erialises"),
        dictgen::InsensitiveStr::Ascii("erialising"),
        dictgen::InsensitiveStr::Ascii("erialization"),
        dictgen::InsensitiveStr::Ascii("erializations"),
        dictgen::InsensitiveStr::Ascii("erialize"),
        dictgen::InsensitiveStr::Ascii("erialized"),
        dictgen::InsensitiveStr::Ascii("erializes"),
        dictgen::InsensitiveStr::Ascii("erializing"),
        dictgen::InsensitiveStr::Ascii("hrempyesis"),
        dictgen::InsensitiveStr::Ascii("hroempyesis"),
        dictgen::InsensitiveStr::Ascii("ifact"),
        dictgen::InsensitiveStr::Ascii("ifacts"),
        dictgen::InsensitiveStr::Ascii("ificialise"),
        dictgen::InsensitiveStr::Ascii("ificialised"),
        dictgen::InsensitiveStr::Ascii("ificialises"),
        dictgen::InsensitiveStr::Ascii("ificialising"),
        dictgen::InsensitiveStr::Ascii("ificialize"),
        dictgen::InsensitiveStr::Ascii("ificialized"),
        dictgen::InsensitiveStr::Ascii("ificializes"),
        dictgen::InsensitiveStr::Ascii("ificializing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ARTIFACT_2827424156037909074)],
        &[(0b11010, &ENTRY_ARTIFACTS_3550024244562413823)],
        &[(0b10010, &ENTRY_ARTERIALIZATION_17022790192875553359)],
        &[(0b10010, &ENTRY_ARTERIALIZATIONS_3727765437552603830)],
        &[(0b10010, &ENTRY_ARTERIALIZE_4417484011804302892)],
        &[(0b10010, &ENTRY_ARTERIALIZED_10808091996021730739)],
        &[(0b10010, &ENTRY_ARTERIALIZES_2237218216825221904)],
        &[(0b10010, &ENTRY_ARTERIALIZING_7575251577380617319)],
        &[(0b01001, &ENTRY_ARTERIALIZATION_17022790192875553359)],
        &[(0b01001, &ENTRY_ARTERIALIZATIONS_3727765437552603830)],
        &[(0b01001, &ENTRY_ARTERIALIZE_4417484011804302892)],
        &[(0b01001, &ENTRY_ARTERIALIZED_10808091996021730739)],
        &[(0b01001, &ENTRY_ARTERIALIZES_2237218216825221904)],
        &[(0b01001, &ENTRY_ARTERIALIZING_7575251577380617319)],
        &[(0b00001, &ENTRY_ARTHREMPYESIS_845595122000356547)],
        &[(0b11010, &ENTRY_ARTHREMPYESIS_845595122000356547)],
        &[(0b11001, &ENTRY_ARTIFACT_2827424156037909074)],
        &[(0b11001, &ENTRY_ARTIFACTS_3550024244562413823)],
        &[(0b10010, &ENTRY_ARTIFICIALIZE_6116923120575367102)],
        &[(0b10010, &ENTRY_ARTIFICIALIZED_3661622221795178801)],
        &[(0b10010, &ENTRY_ARTIFICIALIZES_12340528017967580371)],
        &[(0b10010, &ENTRY_ARTIFICIALIZING_6041141466863049208)],
        &[(0b01001, &ENTRY_ARTIFICIALIZE_6116923120575367102)],
        &[(0b01001, &ENTRY_ARTIFICIALIZED_3661622221795178801)],
        &[(0b01001, &ENTRY_ARTIFICIALIZES_12340528017967580371)],
        &[(0b01001, &ENTRY_ARTIFICIALIZING_6041141466863049208)],
    ],
    range: 5..=13,
};

static VARS_ARS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARS_CHILDREN),
    value: None,
};

pub static VARS_ARS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ehole"),
        dictgen::InsensitiveStr::Ascii("eholes"),
        dictgen::InsensitiveStr::Ascii("enicise"),
        dictgen::InsensitiveStr::Ascii("enicises"),
        dictgen::InsensitiveStr::Ascii("enicize"),
        dictgen::InsensitiveStr::Ascii("enicizes"),
        dictgen::InsensitiveStr::Ascii("es"),
        dictgen::InsensitiveStr::Ascii("inoae"),
        dictgen::InsensitiveStr::Ascii("inoe"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ASS_3108967481325135828)],
        &[(0b11010, &ENTRY_ASSHOLE_12964338351998611148)],
        &[(0b11010, &ENTRY_ASSHOLES_13924057355694920061)],
        &[(0b10010, &ENTRY_ARSENICIZE_13996042961629556869)],
        &[(0b10010, &ENTRY_ARSENICIZES_1017198980814944191)],
        &[(0b01001, &ENTRY_ARSENICIZE_13996042961629556869)],
        &[(0b01001, &ENTRY_ARSENICIZES_1017198980814944191)],
        &[(0b11010, &ENTRY_ASSES_13623663473667601400)],
        &[(0b11010, &ENTRY_ARSINOE_18015403196399169984)],
        &[(0b00001, &ENTRY_ARSINOE_18015403196399169984)],
    ],
    range: 1..=8,
};

static VARS_ARO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARO_CHILDREN),
    value: None,
};

pub static VARS_ARO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matisation"),
        dictgen::InsensitiveStr::Ascii("matise"),
        dictgen::InsensitiveStr::Ascii("matised"),
        dictgen::InsensitiveStr::Ascii("matiser"),
        dictgen::InsensitiveStr::Ascii("matises"),
        dictgen::InsensitiveStr::Ascii("matising"),
        dictgen::InsensitiveStr::Ascii("matitae"),
        dictgen::InsensitiveStr::Ascii("matite"),
        dictgen::InsensitiveStr::Ascii("matization"),
        dictgen::InsensitiveStr::Ascii("matize"),
        dictgen::InsensitiveStr::Ascii("matized"),
        dictgen::InsensitiveStr::Ascii("matizer"),
        dictgen::InsensitiveStr::Ascii("matizes"),
        dictgen::InsensitiveStr::Ascii("matizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AROMATIZATION_2953688635914420328)],
        &[(0b10010, &ENTRY_AROMATIZE_14212398289764823606)],
        &[(0b10010, &ENTRY_AROMATIZED_11509335206222252539)],
        &[(0b10010, &ENTRY_AROMATIZER_9784880273725424914)],
        &[(0b10010, &ENTRY_AROMATIZES_11689049401873834109)],
        &[(0b10010, &ENTRY_AROMATIZING_15725452162461845633)],
        &[(0b11010, &ENTRY_AROMATITE_13587883584590217655)],
        &[(0b00001, &ENTRY_AROMATITE_13587883584590217655)],
        &[(0b01001, &ENTRY_AROMATIZATION_2953688635914420328)],
        &[(0b01001, &ENTRY_AROMATIZE_14212398289764823606)],
        &[(0b01001, &ENTRY_AROMATIZED_11509335206222252539)],
        &[(0b01001, &ENTRY_AROMATIZER_9784880273725424914)],
        &[(0b01001, &ENTRY_AROMATIZES_11689049401873834109)],
        &[(0b01001, &ENTRY_AROMATIZING_15725452162461845633)],
    ],
    range: 6..=10,
};

static VARS_ARM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARM_CHILDREN),
    value: None,
};

pub static VARS_ARM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("orbearer"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("orer"),
        dictgen::InsensitiveStr::Ascii("orers"),
        dictgen::InsensitiveStr::Ascii("oried"),
        dictgen::InsensitiveStr::Ascii("ories"),
        dictgen::InsensitiveStr::Ascii("oring"),
        dictgen::InsensitiveStr::Ascii("orless"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("ory"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ourbearer"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("ourer"),
        dictgen::InsensitiveStr::Ascii("ourers"),
        dictgen::InsensitiveStr::Ascii("ouried"),
        dictgen::InsensitiveStr::Ascii("ouries"),
        dictgen::InsensitiveStr::Ascii("ouring"),
        dictgen::InsensitiveStr::Ascii("ourless"),
        dictgen::InsensitiveStr::Ascii("ours"),
        dictgen::InsensitiveStr::Ascii("oury"),
    ],
    values: &[
        &[(0b11001, &ENTRY_ARMOR_6791544457048582167)],
        &[(0b11001, &ENTRY_ARMORBEARER_2157362197814652336)],
        &[(0b11001, &ENTRY_ARMORED_982936021759049572)],
        &[(0b11001, &ENTRY_ARMORER_5772853517114648246)],
        &[(0b11001, &ENTRY_ARMORERS_5671193923544706720)],
        &[(0b11001, &ENTRY_ARMORIED_11535135214878289513)],
        &[(0b11001, &ENTRY_ARMORIES_4241896125070646795)],
        &[(0b11001, &ENTRY_ARMORING_6447756068859055780)],
        &[(0b11001, &ENTRY_ARMORLESS_17033530693523632986)],
        &[(0b11001, &ENTRY_ARMORS_8991902587170735735)],
        &[(0b11001, &ENTRY_ARMORY_16496001318701009580)],
        &[(0b11010, &ENTRY_ARMOR_6791544457048582167)],
        &[(0b11010, &ENTRY_ARMORBEARER_2157362197814652336)],
        &[(0b11010, &ENTRY_ARMORED_982936021759049572)],
        &[(0b11010, &ENTRY_ARMORER_5772853517114648246)],
        &[(0b11010, &ENTRY_ARMORERS_5671193923544706720)],
        &[(0b11010, &ENTRY_ARMORIED_11535135214878289513)],
        &[(0b11010, &ENTRY_ARMORIES_4241896125070646795)],
        &[(0b11010, &ENTRY_ARMORING_6447756068859055780)],
        &[(0b11010, &ENTRY_ARMORLESS_17033530693523632986)],
        &[(0b11010, &ENTRY_ARMORS_8991902587170735735)],
        &[(0b11010, &ENTRY_ARMORY_16496001318701009580)],
    ],
    range: 2..=9,
};

static VARS_ARI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARI_CHILDREN),
    value: None,
};

pub static VARS_ARI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anise"),
        dictgen::InsensitiveStr::Ascii("anised"),
        dictgen::InsensitiveStr::Ascii("anises"),
        dictgen::InsensitiveStr::Ascii("anising"),
        dictgen::InsensitiveStr::Ascii("anize"),
        dictgen::InsensitiveStr::Ascii("anized"),
        dictgen::InsensitiveStr::Ascii("anizes"),
        dictgen::InsensitiveStr::Ascii("anizing"),
        dictgen::InsensitiveStr::Ascii("mathaea"),
        dictgen::InsensitiveStr::Ascii("mathaean"),
        dictgen::InsensitiveStr::Ascii("mathea"),
        dictgen::InsensitiveStr::Ascii("mathean"),
        dictgen::InsensitiveStr::Ascii("stae"),
        dictgen::InsensitiveStr::Ascii("ste"),
        dictgen::InsensitiveStr::Ascii("thmetisation"),
        dictgen::InsensitiveStr::Ascii("thmetisations"),
        dictgen::InsensitiveStr::Ascii("thmetise"),
        dictgen::InsensitiveStr::Ascii("thmetised"),
        dictgen::InsensitiveStr::Ascii("thmetises"),
        dictgen::InsensitiveStr::Ascii("thmetization"),
        dictgen::InsensitiveStr::Ascii("thmetizations"),
        dictgen::InsensitiveStr::Ascii("thmetize"),
        dictgen::InsensitiveStr::Ascii("thmetized"),
        dictgen::InsensitiveStr::Ascii("thmetizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ARIANIZE_1475808498118197849)],
        &[(0b10010, &ENTRY_ARIANIZED_1259509742119549714)],
        &[(0b10010, &ENTRY_ARIANIZES_14713941213590902805)],
        &[(0b10010, &ENTRY_ARIANIZING_15061255978082885900)],
        &[(0b01001, &ENTRY_ARIANIZE_1475808498118197849)],
        &[(0b01001, &ENTRY_ARIANIZED_1259509742119549714)],
        &[(0b01001, &ENTRY_ARIANIZES_14713941213590902805)],
        &[(0b01001, &ENTRY_ARIANIZING_15061255978082885900)],
        &[(0b11010, &ENTRY_ARIMATHEA_13006899549940341201)],
        &[(0b11010, &ENTRY_ARIMATHEAN_16207104510661913460)],
        &[(0b10001, &ENTRY_ARIMATHEA_13006899549940341201)],
        &[(0b10001, &ENTRY_ARIMATHEAN_16207104510661913460)],
        &[(0b11010, &ENTRY_ARISTE_4207971148573549326)],
        &[(0b00001, &ENTRY_ARISTE_4207971148573549326)],
        &[(0b10010, &ENTRY_ARITHMETIZATION_10054898680334010685)],
        &[(0b10010, &ENTRY_ARITHMETIZATIONS_6133192991101865652)],
        &[(0b10010, &ENTRY_ARITHMETIZE_15576026606241266299)],
        &[(0b10010, &ENTRY_ARITHMETIZED_804241885225408901)],
        &[(0b10010, &ENTRY_ARITHMETIZES_4021129694449874179)],
        &[(0b01001, &ENTRY_ARITHMETIZATION_10054898680334010685)],
        &[(0b01001, &ENTRY_ARITHMETIZATIONS_6133192991101865652)],
        &[(0b01001, &ENTRY_ARITHMETIZE_15576026606241266299)],
        &[(0b01001, &ENTRY_ARITHMETIZED_804241885225408901)],
        &[(0b01001, &ENTRY_ARITHMETIZES_4021129694449874179)],
    ],
    range: 3..=13,
};

static VARS_ARE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARE_CHILDREN),
    value: None,
};

pub static VARS_ARE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("nicolor"),
        dictgen::InsensitiveStr::Ascii("nicolour"),
        dictgen::InsensitiveStr::Ascii("ographer"),
        dictgen::InsensitiveStr::Ascii("ographic"),
        dictgen::InsensitiveStr::Ascii("ographical"),
        dictgen::InsensitiveStr::Ascii("ographies"),
        dictgen::InsensitiveStr::Ascii("ography"),
        dictgen::InsensitiveStr::Ascii("olae"),
        dictgen::InsensitiveStr::Ascii("ole"),
        dictgen::InsensitiveStr::Ascii("ologic"),
        dictgen::InsensitiveStr::Ascii("ological"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ometers"),
        dictgen::InsensitiveStr::Ascii("ometric"),
        dictgen::InsensitiveStr::Ascii("ometrical"),
        dictgen::InsensitiveStr::Ascii("ostyle"),
        dictgen::InsensitiveStr::Ascii("ostyles"),
        dictgen::InsensitiveStr::Ascii("osystyle"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AERIC_17437245564230021595)],
        &[(0b10001, &ENTRY_ARENICOLOR_4953462878754370500)],
        &[(0b11010, &ENTRY_ARENICOLOR_4953462878754370500)],
        &[(0b11010, &ENTRY_AEROGRAPHER_10717546778729152195)],
        &[(0b11010, &ENTRY_AEROGRAPHIC_14818096080809523195)],
        &[(0b11010, &ENTRY_AEROGRAPHICAL_2429273948734988881)],
        &[(0b11010, &ENTRY_AEROGRAPHIES_11844593835635999782)],
        &[(0b11010, &ENTRY_AEROGRAPHY_8481321619438820366)],
        &[(0b11010, &ENTRY_AREOLE_12338780936099127737)],
        &[(0b00001, &ENTRY_AREOLE_12338780936099127737)],
        &[(0b11010, &ENTRY_AEROLOGIC_6581703267250668822)],
        &[(0b11010, &ENTRY_AEROLOGICAL_7035119647902064897)],
        &[(0b11010, &ENTRY_AEROLOGIES_9303474410588856691)],
        &[(0b11010, &ENTRY_AEROLOGIST_9043743609076361118)],
        &[(0b11010, &ENTRY_AEROLOGY_2536724281135360580)],
        &[(0b11010, &ENTRY_AEROMETER_11742833131164166928)],
        &[(0b11010, &ENTRY_AEROMETERS_18338221712051507310)],
        &[
            (0b11010, &ENTRY_AEROMETRIC_13993414140130418477),
            (0b00001, &ENTRY_AREOMETRIC_17639504932600545758),
        ],
        &[(0b10001, &ENTRY_AREOMETRICAL_17718812079898847508)],
        &[(0b10001, &ENTRY_AREOSTYLE_9887341032000748494)],
        &[(0b10001, &ENTRY_AREOSTYLES_1673942835480908773)],
        &[(0b00001, &ENTRY_AREOSYSTYLE_14135429367026377792)],
    ],
    range: 2..=10,
};

static VARS_ARD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARD_CHILDREN),
    value: None,
};

pub static VARS_ARD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b11001, &ENTRY_ARDOR_16738479217548171426)],
        &[(0b11001, &ENTRY_ARDORS_13859299160898289371)],
        &[(0b11010, &ENTRY_ARDOR_16738479217548171426)],
        &[(0b11010, &ENTRY_ARDORS_13859299160898289371)],
    ],
    range: 2..=4,
};

static VARS_ARC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARC_CHILDREN),
    value: None,
};

pub static VARS_ARC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hae"),
        dictgen::InsensitiveStr::Ascii("haeal"),
        dictgen::InsensitiveStr::Ascii("haean"),
        dictgen::InsensitiveStr::Ascii("haei"),
        dictgen::InsensitiveStr::Ascii("haeoastronomies"),
        dictgen::InsensitiveStr::Ascii("haeoastronomy"),
        dictgen::InsensitiveStr::Ascii("haeocyte"),
        dictgen::InsensitiveStr::Ascii("haeol"),
        dictgen::InsensitiveStr::Ascii("haeolithic"),
        dictgen::InsensitiveStr::Ascii("haeologian"),
        dictgen::InsensitiveStr::Ascii("haeometries"),
        dictgen::InsensitiveStr::Ascii("haeometry"),
        dictgen::InsensitiveStr::Ascii("haeozic"),
        dictgen::InsensitiveStr::Ascii("haeozoic"),
        dictgen::InsensitiveStr::Ascii("haeus"),
        dictgen::InsensitiveStr::Ascii("haise"),
        dictgen::InsensitiveStr::Ascii("haised"),
        dictgen::InsensitiveStr::Ascii("haiser"),
        dictgen::InsensitiveStr::Ascii("haisers"),
        dictgen::InsensitiveStr::Ascii("haises"),
        dictgen::InsensitiveStr::Ascii("haising"),
        dictgen::InsensitiveStr::Ascii("haize"),
        dictgen::InsensitiveStr::Ascii("haized"),
        dictgen::InsensitiveStr::Ascii("haizer"),
        dictgen::InsensitiveStr::Ascii("haizers"),
        dictgen::InsensitiveStr::Ascii("haizes"),
        dictgen::InsensitiveStr::Ascii("haizing"),
        dictgen::InsensitiveStr::Ascii("he"),
        dictgen::InsensitiveStr::Ascii("heal"),
        dictgen::InsensitiveStr::Ascii("hean"),
        dictgen::InsensitiveStr::Ascii("hei"),
        dictgen::InsensitiveStr::Ascii("heoastronomies"),
        dictgen::InsensitiveStr::Ascii("heoastronomy"),
        dictgen::InsensitiveStr::Ascii("heocyte"),
        dictgen::InsensitiveStr::Ascii("heol"),
        dictgen::InsensitiveStr::Ascii("heolithic"),
        dictgen::InsensitiveStr::Ascii("heologian"),
        dictgen::InsensitiveStr::Ascii("heologic"),
        dictgen::InsensitiveStr::Ascii("heological"),
        dictgen::InsensitiveStr::Ascii("heologies"),
        dictgen::InsensitiveStr::Ascii("heologist"),
        dictgen::InsensitiveStr::Ascii("heologists"),
        dictgen::InsensitiveStr::Ascii("heology"),
        dictgen::InsensitiveStr::Ascii("heometries"),
        dictgen::InsensitiveStr::Ascii("heometry"),
        dictgen::InsensitiveStr::Ascii("heozic"),
        dictgen::InsensitiveStr::Ascii("heozoic"),
        dictgen::InsensitiveStr::Ascii("heus"),
        dictgen::InsensitiveStr::Ascii("ticise"),
        dictgen::InsensitiveStr::Ascii("ticises"),
        dictgen::InsensitiveStr::Ascii("ticize"),
        dictgen::InsensitiveStr::Ascii("ticizes"),
        dictgen::InsensitiveStr::Ascii("togaea"),
        dictgen::InsensitiveStr::Ascii("togaean"),
        dictgen::InsensitiveStr::Ascii("togaeic"),
        dictgen::InsensitiveStr::Ascii("togea"),
        dictgen::InsensitiveStr::Ascii("togean"),
        dictgen::InsensitiveStr::Ascii("togeic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ARCHE_10156222017687532546)],
        &[(0b11010, &ENTRY_ARCHEAL_6179901035862490669)],
        &[(0b11010, &ENTRY_ARCHEAN_14847398170729505321)],
        &[(0b11010, &ENTRY_ARCHEI_14186317656172516337)],
        &[(0b11010, &ENTRY_ARCHEOASTRONOMIES_12672535196068691757)],
        &[(0b11010, &ENTRY_ARCHEOASTRONOMY_7568086850104584418)],
        &[(0b11010, &ENTRY_ARCHEOCYTE_544989770193462231)],
        &[(0b11010, &ENTRY_ARCHEOL_1621301161575668294)],
        &[(0b11010, &ENTRY_ARCHEOLITHIC_14371745948924816941)],
        &[(0b11010, &ENTRY_ARCHEOLOGIAN_11401650089021570001)],
        &[(0b11010, &ENTRY_ARCHEOMETRIES_9109698910620640943)],
        &[(0b11010, &ENTRY_ARCHEOMETRY_17067814741857159557)],
        &[(0b11010, &ENTRY_ARCHEOZIC_9758294415454737448)],
        &[(0b11010, &ENTRY_ARCHEOZOIC_18268674600637414324)],
        &[(0b11010, &ENTRY_ARCHEUS_1328632190850149944)],
        &[(0b10010, &ENTRY_ARCHAIZE_1359278578081430792)],
        &[(0b10010, &ENTRY_ARCHAIZED_13322639529987334614)],
        &[(0b10010, &ENTRY_ARCHAIZER_13710837259267725318)],
        &[(0b10010, &ENTRY_ARCHAIZERS_6972696703859538503)],
        &[(0b10010, &ENTRY_ARCHAIZES_4876579109305121157)],
        &[(0b10010, &ENTRY_ARCHAIZING_3246941458311193300)],
        &[(0b01001, &ENTRY_ARCHAIZE_1359278578081430792)],
        &[(0b01001, &ENTRY_ARCHAIZED_13322639529987334614)],
        &[(0b01001, &ENTRY_ARCHAIZER_13710837259267725318)],
        &[(0b01001, &ENTRY_ARCHAIZERS_6972696703859538503)],
        &[(0b01001, &ENTRY_ARCHAIZES_4876579109305121157)],
        &[(0b01001, &ENTRY_ARCHAIZING_3246941458311193300)],
        &[(0b00001, &ENTRY_ARCHE_10156222017687532546)],
        &[(0b10001, &ENTRY_ARCHEAL_6179901035862490669)],
        &[(0b10001, &ENTRY_ARCHEAN_14847398170729505321)],
        &[(0b10001, &ENTRY_ARCHEI_14186317656172516337)],
        &[(0b10001, &ENTRY_ARCHEOASTRONOMIES_12672535196068691757)],
        &[(0b10001, &ENTRY_ARCHEOASTRONOMY_7568086850104584418)],
        &[(0b10001, &ENTRY_ARCHEOCYTE_544989770193462231)],
        &[(0b10001, &ENTRY_ARCHEOL_1621301161575668294)],
        &[(0b10001, &ENTRY_ARCHEOLITHIC_14371745948924816941)],
        &[(0b10001, &ENTRY_ARCHEOLOGIAN_11401650089021570001)],
        &[(0b11001, &ENTRY_ARCHAEOLOGIC_2454164999315616216)],
        &[(0b11001, &ENTRY_ARCHAEOLOGICAL_5745535416676733106)],
        &[(0b11001, &ENTRY_ARCHAEOLOGIES_14568028250477257186)],
        &[(0b11001, &ENTRY_ARCHAEOLOGIST_15696704416854872606)],
        &[(0b11001, &ENTRY_ARCHAEOLOGISTS_10939394023447922447)],
        &[(0b11001, &ENTRY_ARCHAEOLOGY_4126503997832873296)],
        &[(0b10001, &ENTRY_ARCHEOMETRIES_9109698910620640943)],
        &[(0b10001, &ENTRY_ARCHEOMETRY_17067814741857159557)],
        &[(0b10001, &ENTRY_ARCHEOZIC_9758294415454737448)],
        &[(0b10001, &ENTRY_ARCHEOZOIC_18268674600637414324)],
        &[(0b10001, &ENTRY_ARCHEUS_1328632190850149944)],
        &[(0b10010, &ENTRY_ARCTICIZE_14955043478793537404)],
        &[(0b10010, &ENTRY_ARCTICIZES_17488626861313077167)],
        &[(0b01001, &ENTRY_ARCTICIZE_14955043478793537404)],
        &[(0b01001, &ENTRY_ARCTICIZES_17488626861313077167)],
        &[(0b11010, &ENTRY_ARCTOGEA_15159053709851015323)],
        &[(0b11010, &ENTRY_ARCTOGEAN_2216179672115771268)],
        &[(0b11010, &ENTRY_ARCTOGEIC_12166436575342886940)],
        &[(0b10001, &ENTRY_ARCTOGEA_15159053709851015323)],
        &[(0b10001, &ENTRY_ARCTOGEAN_2216179672115771268)],
        &[(0b10001, &ENTRY_ARCTOGEIC_12166436575342886940)],
    ],
    range: 2..=15,
};

static VARS_ARB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARB_CHILDREN),
    value: None,
};

pub static VARS_ARB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alester"),
        dictgen::InsensitiveStr::Ascii("alestre"),
        dictgen::InsensitiveStr::Ascii("or"),
        dictgen::InsensitiveStr::Ascii("ored"),
        dictgen::InsensitiveStr::Ascii("ores"),
        dictgen::InsensitiveStr::Ascii("orisation"),
        dictgen::InsensitiveStr::Ascii("orisations"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orization"),
        dictgen::InsensitiveStr::Ascii("orizations"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
        dictgen::InsensitiveStr::Ascii("ors"),
        dictgen::InsensitiveStr::Ascii("our"),
        dictgen::InsensitiveStr::Ascii("oured"),
        dictgen::InsensitiveStr::Ascii("oures"),
        dictgen::InsensitiveStr::Ascii("ours"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ARBALESTER_17275327857939491618)],
        &[(0b11010, &ENTRY_ARBALESTER_17275327857939491618)],
        &[(0b01001, &ENTRY_ARBOR_2099081688991941134)],
        &[(0b00001, &ENTRY_ARBORED_6451632367270810042)],
        &[(0b01001, &ENTRY_ARBORES_2760921281327347095)],
        &[(0b10010, &ENTRY_ARBORIZATION_9677792163286494747)],
        &[(0b10010, &ENTRY_ARBORIZATIONS_2080512800793081270)],
        &[(0b10010, &ENTRY_ARBORIZE_13993474358635558324)],
        &[(0b10010, &ENTRY_ARBORIZED_10511833189104814553)],
        &[(0b10010, &ENTRY_ARBORIZES_11990594085526471423)],
        &[(0b10010, &ENTRY_ARBORIZING_9399803869936043047)],
        &[(0b01001, &ENTRY_ARBORIZATION_9677792163286494747)],
        &[(0b01001, &ENTRY_ARBORIZATIONS_2080512800793081270)],
        &[(0b01001, &ENTRY_ARBORIZE_13993474358635558324)],
        &[(0b01001, &ENTRY_ARBORIZED_10511833189104814553)],
        &[(0b01001, &ENTRY_ARBORIZES_11990594085526471423)],
        &[(0b01001, &ENTRY_ARBORIZING_9399803869936043047)],
        &[(0b01001, &ENTRY_ARBORS_9095342812626319615)],
        &[(0b11010, &ENTRY_ARBOR_2099081688991941134)],
        &[(0b11010, &ENTRY_ARBORED_6451632367270810042)],
        &[(0b11010, &ENTRY_ARBORES_2760921281327347095)],
        &[(0b11010, &ENTRY_ARBORS_9095342812626319615)],
    ],
    range: 2..=10,
};

static VARS_ARA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ARA_CHILDREN),
    value: None,
};

pub static VARS_ARA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("bianise"),
        dictgen::InsensitiveStr::Ascii("bianises"),
        dictgen::InsensitiveStr::Ascii("bianize"),
        dictgen::InsensitiveStr::Ascii("bianizes"),
        dictgen::InsensitiveStr::Ascii("bicise"),
        dictgen::InsensitiveStr::Ascii("bicises"),
        dictgen::InsensitiveStr::Ascii("bicize"),
        dictgen::InsensitiveStr::Ascii("bicizes"),
        dictgen::InsensitiveStr::Ascii("bisation"),
        dictgen::InsensitiveStr::Ascii("bisations"),
        dictgen::InsensitiveStr::Ascii("bise"),
        dictgen::InsensitiveStr::Ascii("bised"),
        dictgen::InsensitiveStr::Ascii("bises"),
        dictgen::InsensitiveStr::Ascii("bising"),
        dictgen::InsensitiveStr::Ascii("bization"),
        dictgen::InsensitiveStr::Ascii("bizations"),
        dictgen::InsensitiveStr::Ascii("bize"),
        dictgen::InsensitiveStr::Ascii("bized"),
        dictgen::InsensitiveStr::Ascii("bizes"),
        dictgen::InsensitiveStr::Ascii("bizing"),
        dictgen::InsensitiveStr::Ascii("eometric"),
        dictgen::InsensitiveStr::Ascii("eometrical"),
        dictgen::InsensitiveStr::Ascii("eostyle"),
        dictgen::InsensitiveStr::Ascii("eostyles"),
        dictgen::InsensitiveStr::Ascii("eosystyle"),
        dictgen::InsensitiveStr::Ascii("maean"),
        dictgen::InsensitiveStr::Ascii("maeans"),
        dictgen::InsensitiveStr::Ascii("mean"),
        dictgen::InsensitiveStr::Ascii("means"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ARABIANIZE_7091452592558944142)],
        &[(0b10010, &ENTRY_ARABIANIZES_6146778824890703405)],
        &[(0b01001, &ENTRY_ARABIANIZE_7091452592558944142)],
        &[(0b01001, &ENTRY_ARABIANIZES_6146778824890703405)],
        &[(0b10010, &ENTRY_ARABICIZE_7118455398303530058)],
        &[(0b10010, &ENTRY_ARABICIZES_17376878529951217199)],
        &[(0b01001, &ENTRY_ARABICIZE_7118455398303530058)],
        &[(0b01001, &ENTRY_ARABICIZES_17376878529951217199)],
        &[(0b10010, &ENTRY_ARABIZATION_18186190432640846471)],
        &[(0b10010, &ENTRY_ARABIZATIONS_3254497434968628478)],
        &[(0b10010, &ENTRY_ARABIZE_9595110188198649627)],
        &[(0b10010, &ENTRY_ARABIZED_13913844866590865979)],
        &[(0b10010, &ENTRY_ARABIZES_16630760146158946529)],
        &[(0b10010, &ENTRY_ARABIZING_10793371023736049149)],
        &[(0b01001, &ENTRY_ARABIZATION_18186190432640846471)],
        &[(0b01001, &ENTRY_ARABIZATIONS_3254497434968628478)],
        &[(0b01001, &ENTRY_ARABIZE_9595110188198649627)],
        &[(0b01001, &ENTRY_ARABIZED_13913844866590865979)],
        &[(0b01001, &ENTRY_ARABIZES_16630760146158946529)],
        &[(0b01001, &ENTRY_ARABIZING_10793371023736049149)],
        &[(0b11010, &ENTRY_AREOMETRIC_17639504932600545758)],
        &[(0b11010, &ENTRY_AREOMETRICAL_17718812079898847508)],
        &[(0b11010, &ENTRY_AREOSTYLE_9887341032000748494)],
        &[(0b11010, &ENTRY_AREOSTYLES_1673942835480908773)],
        &[(0b11010, &ENTRY_AREOSYSTYLE_14135429367026377792)],
        &[(0b11010, &ENTRY_ARAMEAN_4395400457535337445)],
        &[(0b11010, &ENTRY_ARAMEANS_13793987072806544505)],
        &[(0b10001, &ENTRY_ARAMEAN_4395400457535337445)],
        &[(0b10001, &ENTRY_ARAMEANS_13793987072806544505)],
    ],
    range: 4..=10,
};

static VARS_AP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AP_CHILDREN),
    value: None,
};

static VARS_AP_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_APA_NODE),
    None,
    None,
    None,
    Some(&VARS_APE_NODE),
    None,
    None,
    Some(&VARS_APH_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_APN_NODE),
    Some(&VARS_APO_NODE),
    Some(&VARS_APP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_APP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APP_CHILDREN),
    value: None,
};

pub static VARS_APP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("al"),
        dictgen::InsensitiveStr::Ascii("all"),
        dictgen::InsensitiveStr::Ascii("alls"),
        dictgen::InsensitiveStr::Ascii("als"),
        dictgen::InsensitiveStr::Ascii("areled"),
        dictgen::InsensitiveStr::Ascii("areling"),
        dictgen::InsensitiveStr::Ascii("arelled"),
        dictgen::InsensitiveStr::Ascii("arelling"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etisement"),
        dictgen::InsensitiveStr::Ascii("etisements"),
        dictgen::InsensitiveStr::Ascii("etiser"),
        dictgen::InsensitiveStr::Ascii("etisers"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etisingly"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizement"),
        dictgen::InsensitiveStr::Ascii("etizements"),
        dictgen::InsensitiveStr::Ascii("etizer"),
        dictgen::InsensitiveStr::Ascii("etizers"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
        dictgen::InsensitiveStr::Ascii("etizingly"),
        dictgen::InsensitiveStr::Ascii("risal"),
        dictgen::InsensitiveStr::Ascii("riser"),
        dictgen::InsensitiveStr::Ascii("risers"),
        dictgen::InsensitiveStr::Ascii("risings"),
        dictgen::InsensitiveStr::Ascii("rizal"),
        dictgen::InsensitiveStr::Ascii("rizer"),
        dictgen::InsensitiveStr::Ascii("rizers"),
        dictgen::InsensitiveStr::Ascii("rizings"),
    ],
    values: &[
        &[(0b11010, &ENTRY_APPALL_8105666145197803720)],
        &[(0b11001, &ENTRY_APPALL_8105666145197803720)],
        &[(0b11001, &ENTRY_APPALLS_20865698290307641)],
        &[(0b11010, &ENTRY_APPALLS_20865698290307641)],
        &[(0b00001, &ENTRY_APPARELED_10321717899864381527)],
        &[(0b00001, &ENTRY_APPARELING_16684109917693936517)],
        &[(0b11010, &ENTRY_APPARELED_10321717899864381527)],
        &[(0b11010, &ENTRY_APPARELING_16684109917693936517)],
        &[(0b10010, &ENTRY_APPETIZE_13936831634592536190)],
        &[(0b10010, &ENTRY_APPETIZED_10492350941175942222)],
        &[(0b10010, &ENTRY_APPETIZEMENT_16407004548503724456)],
        &[(0b10010, &ENTRY_APPETIZEMENTS_8628307177248201340)],
        &[(0b10010, &ENTRY_APPETIZER_5123269697918809384)],
        &[(0b10010, &ENTRY_APPETIZERS_7154598257569291418)],
        &[(0b10010, &ENTRY_APPETIZES_1889924664779699277)],
        &[(0b10010, &ENTRY_APPETIZING_383666770405789408)],
        &[(0b10010, &ENTRY_APPETIZINGLY_10760124750466327501)],
        &[(0b01001, &ENTRY_APPETIZE_13936831634592536190)],
        &[(0b01001, &ENTRY_APPETIZED_10492350941175942222)],
        &[(0b01001, &ENTRY_APPETIZEMENT_16407004548503724456)],
        &[(0b01001, &ENTRY_APPETIZEMENTS_8628307177248201340)],
        &[(0b01001, &ENTRY_APPETIZER_5123269697918809384)],
        &[(0b01001, &ENTRY_APPETIZERS_7154598257569291418)],
        &[(0b01001, &ENTRY_APPETIZES_1889924664779699277)],
        &[(0b01001, &ENTRY_APPETIZING_383666770405789408)],
        &[(0b01001, &ENTRY_APPETIZINGLY_10760124750466327501)],
        &[(0b10010, &ENTRY_APPRIZAL_6335618835659004475)],
        &[(0b10010, &ENTRY_APPRIZER_1067225642706442627)],
        &[(0b10010, &ENTRY_APPRIZERS_16559280108388910365)],
        &[(0b10010, &ENTRY_APPRIZINGS_13881830905723497559)],
        &[(0b01001, &ENTRY_APPRIZAL_6335618835659004475)],
        &[(0b01001, &ENTRY_APPRIZER_1067225642706442627)],
        &[(0b01001, &ENTRY_APPRIZERS_16559280108388910365)],
        &[(0b01001, &ENTRY_APPRIZINGS_13881830905723497559)],
    ],
    range: 2..=10,
};

static VARS_APO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_APO_CHILDREN),
    value: None,
};

static VARS_APO_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_APOC_NODE),
    None,
    None,
    None,
    Some(&VARS_APOG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_APOL_NODE),
    None,
    None,
    None,
    Some(&VARS_APOP_NODE),
    None,
    Some(&VARS_APOR_NODE),
    Some(&VARS_APOS_NODE),
    Some(&VARS_APOT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_APOT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOT_CHILDREN),
    value: None,
};

pub static VARS_APOT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hegmatise"),
        dictgen::InsensitiveStr::Ascii("hegmatised"),
        dictgen::InsensitiveStr::Ascii("hegmatises"),
        dictgen::InsensitiveStr::Ascii("hegmatising"),
        dictgen::InsensitiveStr::Ascii("hegmatize"),
        dictgen::InsensitiveStr::Ascii("hegmatized"),
        dictgen::InsensitiveStr::Ascii("hegmatizes"),
        dictgen::InsensitiveStr::Ascii("hegmatizing"),
        dictgen::InsensitiveStr::Ascii("heosise"),
        dictgen::InsensitiveStr::Ascii("heosised"),
        dictgen::InsensitiveStr::Ascii("heosises"),
        dictgen::InsensitiveStr::Ascii("heosising"),
        dictgen::InsensitiveStr::Ascii("heosize"),
        dictgen::InsensitiveStr::Ascii("heosized"),
        dictgen::InsensitiveStr::Ascii("heosizes"),
        dictgen::InsensitiveStr::Ascii("heosizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_APOTHEGMATIZE_9149577190229122350)],
        &[(0b10010, &ENTRY_APOTHEGMATIZED_15528209367579426804)],
        &[(0b10010, &ENTRY_APOTHEGMATIZES_3386118086394100613)],
        &[(0b10010, &ENTRY_APOTHEGMATIZING_2185890142177612358)],
        &[(0b01001, &ENTRY_APOTHEGMATIZE_9149577190229122350)],
        &[(0b01001, &ENTRY_APOTHEGMATIZED_15528209367579426804)],
        &[(0b01001, &ENTRY_APOTHEGMATIZES_3386118086394100613)],
        &[(0b01001, &ENTRY_APOTHEGMATIZING_2185890142177612358)],
        &[(0b10010, &ENTRY_APOTHEOSIZE_12839413435396426367)],
        &[(0b10010, &ENTRY_APOTHEOSIZED_2104097860710903144)],
        &[(0b10010, &ENTRY_APOTHEOSIZES_6448094166099469006)],
        &[(0b10010, &ENTRY_APOTHEOSIZING_10092556043562303850)],
        &[(0b01001, &ENTRY_APOTHEOSIZE_12839413435396426367)],
        &[(0b01001, &ENTRY_APOTHEOSIZED_2104097860710903144)],
        &[(0b01001, &ENTRY_APOTHEOSIZES_6448094166099469006)],
        &[(0b01001, &ENTRY_APOTHEOSIZING_10092556043562303850)],
    ],
    range: 7..=11,
};

static VARS_APOS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOS_CHILDREN),
    value: None,
};

pub static VARS_APOS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("tatisation"),
        dictgen::InsensitiveStr::Ascii("tatise"),
        dictgen::InsensitiveStr::Ascii("tatised"),
        dictgen::InsensitiveStr::Ascii("tatises"),
        dictgen::InsensitiveStr::Ascii("tatising"),
        dictgen::InsensitiveStr::Ascii("tatization"),
        dictgen::InsensitiveStr::Ascii("tatize"),
        dictgen::InsensitiveStr::Ascii("tatized"),
        dictgen::InsensitiveStr::Ascii("tatizes"),
        dictgen::InsensitiveStr::Ascii("tatizing"),
        dictgen::InsensitiveStr::Ascii("tolise"),
        dictgen::InsensitiveStr::Ascii("tolised"),
        dictgen::InsensitiveStr::Ascii("tolises"),
        dictgen::InsensitiveStr::Ascii("tolising"),
        dictgen::InsensitiveStr::Ascii("tolize"),
        dictgen::InsensitiveStr::Ascii("tolized"),
        dictgen::InsensitiveStr::Ascii("tolizes"),
        dictgen::InsensitiveStr::Ascii("tolizing"),
        dictgen::InsensitiveStr::Ascii("trophise"),
        dictgen::InsensitiveStr::Ascii("trophised"),
        dictgen::InsensitiveStr::Ascii("trophises"),
        dictgen::InsensitiveStr::Ascii("trophising"),
        dictgen::InsensitiveStr::Ascii("trophize"),
        dictgen::InsensitiveStr::Ascii("trophized"),
        dictgen::InsensitiveStr::Ascii("trophizes"),
        dictgen::InsensitiveStr::Ascii("trophizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_APOSTATIZATION_11912806942865124865)],
        &[(0b10010, &ENTRY_APOSTATIZE_13907286705070263227)],
        &[(0b10010, &ENTRY_APOSTATIZED_7948531497773688326)],
        &[(0b10010, &ENTRY_APOSTATIZES_17887605457755809141)],
        &[(0b10010, &ENTRY_APOSTATIZING_10968882224231134376)],
        &[(0b01001, &ENTRY_APOSTATIZATION_11912806942865124865)],
        &[(0b01001, &ENTRY_APOSTATIZE_13907286705070263227)],
        &[(0b01001, &ENTRY_APOSTATIZED_7948531497773688326)],
        &[(0b01001, &ENTRY_APOSTATIZES_17887605457755809141)],
        &[(0b01001, &ENTRY_APOSTATIZING_10968882224231134376)],
        &[(0b10010, &ENTRY_APOSTOLIZE_1194842762673394568)],
        &[(0b10010, &ENTRY_APOSTOLIZED_968548481129324663)],
        &[(0b10010, &ENTRY_APOSTOLIZES_11319414821221634427)],
        &[(0b10010, &ENTRY_APOSTOLIZING_7088290679795202865)],
        &[(0b01001, &ENTRY_APOSTOLIZE_1194842762673394568)],
        &[(0b01001, &ENTRY_APOSTOLIZED_968548481129324663)],
        &[(0b01001, &ENTRY_APOSTOLIZES_11319414821221634427)],
        &[(0b01001, &ENTRY_APOSTOLIZING_7088290679795202865)],
        &[(0b10010, &ENTRY_APOSTROPHIZE_6169660213182266890)],
        &[(0b10010, &ENTRY_APOSTROPHIZED_10608858047847867957)],
        &[(0b10010, &ENTRY_APOSTROPHIZES_7531964953977912072)],
        &[(0b10010, &ENTRY_APOSTROPHIZING_11255712027534928622)],
        &[(0b01001, &ENTRY_APOSTROPHIZE_6169660213182266890)],
        &[(0b01001, &ENTRY_APOSTROPHIZED_10608858047847867957)],
        &[(0b01001, &ENTRY_APOSTROPHIZES_7531964953977912072)],
        &[(0b01001, &ENTRY_APOSTROPHIZING_11255712027534928622)],
    ],
    range: 6..=10,
};

static VARS_APOR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOR_CHILDREN),
    value: None,
};

pub static VARS_APOR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rhea"),
        dictgen::InsensitiveStr::Ascii("rhoea"),
    ],
    values: &[
        &[(0b10001, &ENTRY_APORRHEA_16606851972678900170)],
        &[(0b11010, &ENTRY_APORRHEA_16606851972678900170)],
    ],
    range: 4..=5,
};

static VARS_APOP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOP_CHILDREN),
    value: None,
};

pub static VARS_APOP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hthegmatise"),
        dictgen::InsensitiveStr::Ascii("hthegmatised"),
        dictgen::InsensitiveStr::Ascii("hthegmatises"),
        dictgen::InsensitiveStr::Ascii("hthegmatising"),
        dictgen::InsensitiveStr::Ascii("hthegmatize"),
        dictgen::InsensitiveStr::Ascii("hthegmatized"),
        dictgen::InsensitiveStr::Ascii("hthegmatizes"),
        dictgen::InsensitiveStr::Ascii("hthegmatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_APOPHTHEGMATIZE_6610517743016644545)],
        &[(0b10010, &ENTRY_APOPHTHEGMATIZED_6403368858420510421)],
        &[(0b10010, &ENTRY_APOPHTHEGMATIZES_9217219445848562213)],
        &[(0b10010, &ENTRY_APOPHTHEGMATIZING_17329841406994799734)],
        &[(0b01001, &ENTRY_APOPHTHEGMATIZE_6610517743016644545)],
        &[(0b01001, &ENTRY_APOPHTHEGMATIZED_6403368858420510421)],
        &[(0b01001, &ENTRY_APOPHTHEGMATIZES_9217219445848562213)],
        &[(0b01001, &ENTRY_APOPHTHEGMATIZING_17329841406994799734)],
    ],
    range: 11..=13,
};

static VARS_APOL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOL_CHILDREN),
    value: None,
};

pub static VARS_APOL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogiser"),
        dictgen::InsensitiveStr::Ascii("ogisers"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizer"),
        dictgen::InsensitiveStr::Ascii("ogizers"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_APOLOGIZE_4808140733719974618)],
        &[(0b10010, &ENTRY_APOLOGIZED_766769648963130203)],
        &[(0b10010, &ENTRY_APOLOGIZER_6662783343430240014)],
        &[(0b10010, &ENTRY_APOLOGIZERS_9394583326468044369)],
        &[(0b10010, &ENTRY_APOLOGIZES_1886820837917495266)],
        &[(0b10010, &ENTRY_APOLOGIZING_17198773338731611091)],
        &[(0b01001, &ENTRY_APOLOGIZE_4808140733719974618)],
        &[(0b01001, &ENTRY_APOLOGIZED_766769648963130203)],
        &[(0b01001, &ENTRY_APOLOGIZER_6662783343430240014)],
        &[(0b01001, &ENTRY_APOLOGIZERS_9394583326468044369)],
        &[(0b01001, &ENTRY_APOLOGIZES_1886820837917495266)],
        &[(0b01001, &ENTRY_APOLOGIZING_17198773338731611091)],
    ],
    range: 5..=7,
};

static VARS_APOG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOG_CHILDREN),
    value: None,
};

pub static VARS_APOG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aeic"),
        dictgen::InsensitiveStr::Ascii("eic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_APOGEIC_10442075832990462520)],
        &[(0b00001, &ENTRY_APOGEIC_10442075832990462520)],
    ],
    range: 3..=4,
};

static VARS_APOC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APOC_CHILDREN),
    value: None,
};

pub static VARS_APOC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enter"),
        dictgen::InsensitiveStr::Ascii("entre"),
    ],
    values: &[
        &[(0b00001, &ENTRY_APOCENTER_6510924298032028131)],
        &[(0b11010, &ENTRY_APOCENTER_6510924298032028131)],
    ],
    range: 5..=5,
};

static VARS_APN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APN_CHILDREN),
    value: None,
};

pub static VARS_APN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ea"),
        dictgen::InsensitiveStr::Ascii("eal"),
        dictgen::InsensitiveStr::Ascii("eas"),
        dictgen::InsensitiveStr::Ascii("eic"),
        dictgen::InsensitiveStr::Ascii("oea"),
        dictgen::InsensitiveStr::Ascii("oeal"),
        dictgen::InsensitiveStr::Ascii("oeas"),
        dictgen::InsensitiveStr::Ascii("oeic"),
    ],
    values: &[
        &[(0b11001, &ENTRY_APNEA_1779953829356774189)],
        &[(0b10001, &ENTRY_APNEAL_9097304655696180790)],
        &[(0b11001, &ENTRY_APNEAS_16005692722117648490)],
        &[(0b10001, &ENTRY_APNEIC_8684812892754015714)],
        &[(0b10010, &ENTRY_APNEA_1779953829356774189)],
        &[(0b11010, &ENTRY_APNEAL_9097304655696180790)],
        &[(0b10010, &ENTRY_APNEAS_16005692722117648490)],
        &[(0b11010, &ENTRY_APNEIC_8684812892754015714)],
    ],
    range: 2..=4,
};

static VARS_APH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APH_CHILDREN),
    value: None,
};

pub static VARS_APH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aereses"),
        dictgen::InsensitiveStr::Ascii("aeresis"),
        dictgen::InsensitiveStr::Ascii("aeretic"),
        dictgen::InsensitiveStr::Ascii("ereses"),
        dictgen::InsensitiveStr::Ascii("eresis"),
        dictgen::InsensitiveStr::Ascii("eretic"),
        dictgen::InsensitiveStr::Ascii("etise"),
        dictgen::InsensitiveStr::Ascii("etised"),
        dictgen::InsensitiveStr::Ascii("etises"),
        dictgen::InsensitiveStr::Ascii("etising"),
        dictgen::InsensitiveStr::Ascii("etize"),
        dictgen::InsensitiveStr::Ascii("etized"),
        dictgen::InsensitiveStr::Ascii("etizes"),
        dictgen::InsensitiveStr::Ascii("etizing"),
        dictgen::InsensitiveStr::Ascii("orise"),
        dictgen::InsensitiveStr::Ascii("orised"),
        dictgen::InsensitiveStr::Ascii("oriser"),
        dictgen::InsensitiveStr::Ascii("orisers"),
        dictgen::InsensitiveStr::Ascii("orises"),
        dictgen::InsensitiveStr::Ascii("orising"),
        dictgen::InsensitiveStr::Ascii("orize"),
        dictgen::InsensitiveStr::Ascii("orized"),
        dictgen::InsensitiveStr::Ascii("orizer"),
        dictgen::InsensitiveStr::Ascii("orizers"),
        dictgen::InsensitiveStr::Ascii("orizes"),
        dictgen::InsensitiveStr::Ascii("orizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_APHERESES_873005030036232707)],
        &[(0b11010, &ENTRY_APHERESIS_14381380856101872428)],
        &[(0b11010, &ENTRY_APHERETIC_1426744147716989088)],
        &[(0b10001, &ENTRY_APHERESES_873005030036232707)],
        &[(0b10001, &ENTRY_APHERESIS_14381380856101872428)],
        &[(0b10001, &ENTRY_APHERETIC_1426744147716989088)],
        &[(0b10010, &ENTRY_APHETIZE_17206274738648406980)],
        &[(0b10010, &ENTRY_APHETIZED_3003107362630119729)],
        &[(0b10010, &ENTRY_APHETIZES_1747641243391683773)],
        &[(0b10010, &ENTRY_APHETIZING_13930569398062916036)],
        &[(0b01001, &ENTRY_APHETIZE_17206274738648406980)],
        &[(0b01001, &ENTRY_APHETIZED_3003107362630119729)],
        &[(0b01001, &ENTRY_APHETIZES_1747641243391683773)],
        &[(0b01001, &ENTRY_APHETIZING_13930569398062916036)],
        &[(0b10010, &ENTRY_APHORIZE_15454256210406202597)],
        &[(0b10010, &ENTRY_APHORIZED_1699636898236576866)],
        &[(0b10010, &ENTRY_APHORIZER_14605329647382162831)],
        &[(0b10010, &ENTRY_APHORIZERS_10347189849445130867)],
        &[(0b10010, &ENTRY_APHORIZES_13164228522572019559)],
        &[(0b10010, &ENTRY_APHORIZING_11576244252883430467)],
        &[(0b01001, &ENTRY_APHORIZE_15454256210406202597)],
        &[(0b01001, &ENTRY_APHORIZED_1699636898236576866)],
        &[(0b01001, &ENTRY_APHORIZER_14605329647382162831)],
        &[(0b01001, &ENTRY_APHORIZERS_10347189849445130867)],
        &[(0b01001, &ENTRY_APHORIZES_13164228522572019559)],
        &[(0b01001, &ENTRY_APHORIZING_11576244252883430467)],
    ],
    range: 5..=7,
};

static VARS_APE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APE_CHILDREN),
    value: None,
};

pub static VARS_APE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
    ],
    values: &[
        &[(0b00001, &ENTRY_APESTHESIA_13121175333380557565)],
        &[(0b00001, &ENTRY_APESTHETIC_15861671523251257086)],
    ],
    range: 7..=7,
};

static VARS_APA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_APA_CHILDREN),
    value: None,
};

pub static VARS_APA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("esthesia"),
        dictgen::InsensitiveStr::Ascii("esthetic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_APESTHESIA_13121175333380557565)],
        &[(0b11010, &ENTRY_APESTHETIC_15861671523251257086)],
    ],
    range: 8..=8,
};

static VARS_AN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AN_CHILDREN),
    value: None,
};

static VARS_AN_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ANA_NODE),
    None,
    Some(&VARS_ANC_NODE),
    None,
    Some(&VARS_ANE_NODE),
    None,
    Some(&VARS_ANG_NODE),
    Some(&VARS_ANH_NODE),
    Some(&VARS_ANI_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ANN_NODE),
    Some(&VARS_ANO_NODE),
    None,
    None,
    None,
    Some(&VARS_ANS_NODE),
    Some(&VARS_ANT_NODE),
    None,
    Some(&VARS_ANV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_ANV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANV_CHILDREN),
    value: None,
};

pub static VARS_ANV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("iled"),
        dictgen::InsensitiveStr::Ascii("iling"),
        dictgen::InsensitiveStr::Ascii("illed"),
        dictgen::InsensitiveStr::Ascii("illing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ANVILED_16736675705730161078)],
        &[(0b00001, &ENTRY_ANVILING_5771622187992250616)],
        &[(0b11010, &ENTRY_ANVILED_16736675705730161078)],
        &[(0b11010, &ENTRY_ANVILING_5771622187992250616)],
    ],
    range: 4..=6,
};

static VARS_ANT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ANT_CHILDREN),
    value: None,
};

static VARS_ANT_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ANTA_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ANTH_NODE),
    Some(&VARS_ANTI_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ANTI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ANTI_CHILDREN),
    value: None,
};

static VARS_ANTI_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    None,
    Some(&VARS_ANTIC_NODE),
    None,
    Some(&VARS_ANTIE_NODE),
    Some(&VARS_ANTIF_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_ANTIL_NODE),
    Some(&VARS_ANTIM_NODE),
    None,
    Some(&VARS_ANTIO_NODE),
    Some(&VARS_ANTIP_NODE),
    Some(&VARS_ANTIQ_NODE),
    Some(&VARS_ANTIR_NODE),
    Some(&VARS_ANTIS_NODE),
    Some(&VARS_ANTIT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ANTIT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIT_CHILDREN),
    value: None,
};

pub static VARS_ANTIT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hesise"),
        dictgen::InsensitiveStr::Ascii("hesises"),
        dictgen::InsensitiveStr::Ascii("hesize"),
        dictgen::InsensitiveStr::Ascii("hesizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTITHESIZE_6914205044378767893)],
        &[(0b10010, &ENTRY_ANTITHESIZES_6606468090715627462)],
        &[(0b01001, &ENTRY_ANTITHESIZE_6914205044378767893)],
        &[(0b01001, &ENTRY_ANTITHESIZES_6606468090715627462)],
    ],
    range: 6..=7,
};

static VARS_ANTIS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIS_CHILDREN),
    value: None,
};

pub static VARS_ANTIS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ensitise"),
        dictgen::InsensitiveStr::Ascii("ensitiser"),
        dictgen::InsensitiveStr::Ascii("ensitisers"),
        dictgen::InsensitiveStr::Ascii("ensitises"),
        dictgen::InsensitiveStr::Ascii("ensitize"),
        dictgen::InsensitiveStr::Ascii("ensitizer"),
        dictgen::InsensitiveStr::Ascii("ensitizers"),
        dictgen::InsensitiveStr::Ascii("ensitizes"),
        dictgen::InsensitiveStr::Ascii("epticise"),
        dictgen::InsensitiveStr::Ascii("epticised"),
        dictgen::InsensitiveStr::Ascii("epticises"),
        dictgen::InsensitiveStr::Ascii("epticising"),
        dictgen::InsensitiveStr::Ascii("epticize"),
        dictgen::InsensitiveStr::Ascii("epticized"),
        dictgen::InsensitiveStr::Ascii("epticizes"),
        dictgen::InsensitiveStr::Ascii("epticizing"),
        dictgen::InsensitiveStr::Ascii("eptise"),
        dictgen::InsensitiveStr::Ascii("eptises"),
        dictgen::InsensitiveStr::Ascii("eptize"),
        dictgen::InsensitiveStr::Ascii("eptizes"),
        dictgen::InsensitiveStr::Ascii("iphon"),
        dictgen::InsensitiveStr::Ascii("iphons"),
        dictgen::InsensitiveStr::Ascii("yphon"),
        dictgen::InsensitiveStr::Ascii("yphons"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTISENSITIZE_11055978247768215431)],
        &[(0b10010, &ENTRY_ANTISENSITIZER_12937207493474321236)],
        &[(0b10010, &ENTRY_ANTISENSITIZERS_633215389454343262)],
        &[(0b10010, &ENTRY_ANTISENSITIZES_16880204120152034442)],
        &[(0b01001, &ENTRY_ANTISENSITIZE_11055978247768215431)],
        &[(0b01001, &ENTRY_ANTISENSITIZER_12937207493474321236)],
        &[(0b01001, &ENTRY_ANTISENSITIZERS_633215389454343262)],
        &[(0b01001, &ENTRY_ANTISENSITIZES_16880204120152034442)],
        &[(0b10010, &ENTRY_ANTISEPTICIZE_3241553852417294791)],
        &[(0b10010, &ENTRY_ANTISEPTICIZED_3518662086162245234)],
        &[(0b10010, &ENTRY_ANTISEPTICIZES_13502357588080215816)],
        &[(0b10010, &ENTRY_ANTISEPTICIZING_5069156061578073106)],
        &[(0b01001, &ENTRY_ANTISEPTICIZE_3241553852417294791)],
        &[(0b01001, &ENTRY_ANTISEPTICIZED_3518662086162245234)],
        &[(0b01001, &ENTRY_ANTISEPTICIZES_13502357588080215816)],
        &[(0b01001, &ENTRY_ANTISEPTICIZING_5069156061578073106)],
        &[(0b10010, &ENTRY_ANTISEPTIZE_3729071818555121770)],
        &[(0b10010, &ENTRY_ANTISEPTIZES_15830751901555519360)],
        &[(0b01001, &ENTRY_ANTISEPTIZE_3729071818555121770)],
        &[(0b01001, &ENTRY_ANTISEPTIZES_15830751901555519360)],
        &[(0b00001, &ENTRY_ANTISIPHON_15645040475271523141)],
        &[(0b00001, &ENTRY_ANTISIPHONS_9333803036952068517)],
        &[(0b11010, &ENTRY_ANTISIPHON_15645040475271523141)],
        &[(0b11010, &ENTRY_ANTISIPHONS_9333803036952068517)],
    ],
    range: 5..=10,
};

static VARS_ANTIR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIR_CHILDREN),
    value: None,
};

pub static VARS_ANTIR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("umor"),
        dictgen::InsensitiveStr::Ascii("umors"),
        dictgen::InsensitiveStr::Ascii("umour"),
        dictgen::InsensitiveStr::Ascii("umours"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ANTIRUMOR_17427963938068472854)],
        &[(0b10001, &ENTRY_ANTIRUMORS_10439853249354862297)],
        &[(0b11010, &ENTRY_ANTIRUMOR_17427963938068472854)],
        &[(0b11010, &ENTRY_ANTIRUMORS_10439853249354862297)],
    ],
    range: 4..=6,
};

static VARS_ANTIQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIQ_CHILDREN),
    value: None,
};

pub static VARS_ANTIQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("uarianise"),
        dictgen::InsensitiveStr::Ascii("uarianises"),
        dictgen::InsensitiveStr::Ascii("uarianize"),
        dictgen::InsensitiveStr::Ascii("uarianizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTIQUARIANIZE_12102393390446972744)],
        &[(0b10010, &ENTRY_ANTIQUARIANIZES_668583703801855532)],
        &[(0b01001, &ENTRY_ANTIQUARIANIZE_12102393390446972744)],
        &[(0b01001, &ENTRY_ANTIQUARIANIZES_668583703801855532)],
    ],
    range: 9..=10,
};

static VARS_ANTIP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIP_CHILDREN),
    value: None,
};

pub static VARS_ANTIP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("athise"),
        dictgen::InsensitiveStr::Ascii("athises"),
        dictgen::InsensitiveStr::Ascii("athize"),
        dictgen::InsensitiveStr::Ascii("athizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTIPATHIZE_14999471117461116868)],
        &[(0b10010, &ENTRY_ANTIPATHIZES_8032094931129328603)],
        &[(0b01001, &ENTRY_ANTIPATHIZE_14999471117461116868)],
        &[(0b01001, &ENTRY_ANTIPATHIZES_8032094931129328603)],
    ],
    range: 6..=7,
};

static VARS_ANTIO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIO_CHILDREN),
    value: None,
};

pub static VARS_ANTIO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("xidiser"),
        dictgen::InsensitiveStr::Ascii("xidisers"),
        dictgen::InsensitiveStr::Ascii("xidising"),
        dictgen::InsensitiveStr::Ascii("xidisings"),
        dictgen::InsensitiveStr::Ascii("xidizer"),
        dictgen::InsensitiveStr::Ascii("xidizers"),
        dictgen::InsensitiveStr::Ascii("xidizing"),
        dictgen::InsensitiveStr::Ascii("xidizings"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTIOXIDIZER_12620825255232115928)],
        &[(0b10010, &ENTRY_ANTIOXIDIZERS_10675061378003290626)],
        &[(0b10010, &ENTRY_ANTIOXIDIZING_2522097081998511687)],
        &[(0b10010, &ENTRY_ANTIOXIDIZINGS_16313410243816058314)],
        &[(0b01001, &ENTRY_ANTIOXIDIZER_12620825255232115928)],
        &[(0b01001, &ENTRY_ANTIOXIDIZERS_10675061378003290626)],
        &[(0b01001, &ENTRY_ANTIOXIDIZING_2522097081998511687)],
        &[(0b01001, &ENTRY_ANTIOXIDIZINGS_16313410243816058314)],
    ],
    range: 7..=9,
};

static VARS_ANTIM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIM_CHILDREN),
    value: None,
};

pub static VARS_ANTIM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ediaeval"),
        dictgen::InsensitiveStr::Ascii("ediaevalism"),
        dictgen::InsensitiveStr::Ascii("ediaevalist"),
        dictgen::InsensitiveStr::Ascii("ediaevally"),
        dictgen::InsensitiveStr::Ascii("edieval"),
        dictgen::InsensitiveStr::Ascii("edievalism"),
        dictgen::InsensitiveStr::Ascii("edievalist"),
        dictgen::InsensitiveStr::Ascii("edievally"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANTIMEDIEVAL_6846585678553345503)],
        &[(0b11010, &ENTRY_ANTIMEDIEVALISM_8317263462919339358)],
        &[(0b11010, &ENTRY_ANTIMEDIEVALIST_3072518728053155006)],
        &[(0b11010, &ENTRY_ANTIMEDIEVALLY_17141320310909970911)],
        &[(0b00001, &ENTRY_ANTIMEDIEVAL_6846585678553345503)],
        &[(0b00001, &ENTRY_ANTIMEDIEVALISM_8317263462919339358)],
        &[(0b00001, &ENTRY_ANTIMEDIEVALIST_3072518728053155006)],
        &[(0b00001, &ENTRY_ANTIMEDIEVALLY_17141320310909970911)],
    ],
    range: 7..=11,
};

static VARS_ANTIL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIL_CHILDREN),
    value: None,
};

pub static VARS_ANTIL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("abor"),
        dictgen::InsensitiveStr::Ascii("abors"),
        dictgen::InsensitiveStr::Ascii("abour"),
        dictgen::InsensitiveStr::Ascii("abours"),
        dictgen::InsensitiveStr::Ascii("emic"),
        dictgen::InsensitiveStr::Ascii("oemic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ANTILABOR_9287358752473165308)],
        &[(0b10001, &ENTRY_ANTILABORS_3039533109874187414)],
        &[(0b11010, &ENTRY_ANTILABOR_9287358752473165308)],
        &[(0b11010, &ENTRY_ANTILABORS_3039533109874187414)],
        &[(0b00001, &ENTRY_ANTILEMIC_9212729723604435140)],
        &[(0b11010, &ENTRY_ANTILEMIC_9212729723604435140)],
    ],
    range: 4..=6,
};

static VARS_ANTIF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIF_CHILDREN),
    value: None,
};

pub static VARS_ANTIF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ertiliser"),
        dictgen::InsensitiveStr::Ascii("ertilisers"),
        dictgen::InsensitiveStr::Ascii("ertilizer"),
        dictgen::InsensitiveStr::Ascii("ertilizers"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTIFERTILIZER_9953475323473604594)],
        &[(0b10010, &ENTRY_ANTIFERTILIZERS_13569559599612590243)],
        &[(0b01001, &ENTRY_ANTIFERTILIZER_9953475323473604594)],
        &[(0b01001, &ENTRY_ANTIFERTILIZERS_13569559599612590243)],
    ],
    range: 9..=10,
};

static VARS_ANTIE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIE_CHILDREN),
    value: None,
};

pub static VARS_ANTIE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("picenter"),
        dictgen::InsensitiveStr::Ascii("picenters"),
        dictgen::InsensitiveStr::Ascii("picentre"),
        dictgen::InsensitiveStr::Ascii("picentres"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ANTIEPICENTER_12788218346335819271)],
        &[(0b00001, &ENTRY_ANTIEPICENTERS_7717054593335253563)],
        &[(0b11010, &ENTRY_ANTIEPICENTER_12788218346335819271)],
        &[(0b11010, &ENTRY_ANTIEPICENTERS_7717054593335253563)],
    ],
    range: 8..=9,
};

static VARS_ANTIC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTIC_CHILDREN),
    value: None,
};

pub static VARS_ANTIC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("atalyser"),
        dictgen::InsensitiveStr::Ascii("atalysers"),
        dictgen::InsensitiveStr::Ascii("atalyzer"),
        dictgen::InsensitiveStr::Ascii("atalyzers"),
        dictgen::InsensitiveStr::Ascii("entralisation"),
        dictgen::InsensitiveStr::Ascii("entralisations"),
        dictgen::InsensitiveStr::Ascii("entralization"),
        dictgen::InsensitiveStr::Ascii("entralizations"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("izes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANTICATALYZER_4172121096489270019)],
        &[(0b11010, &ENTRY_ANTICATALYZERS_14048896960716076262)],
        &[(0b00001, &ENTRY_ANTICATALYZER_4172121096489270019)],
        &[(0b00001, &ENTRY_ANTICATALYZERS_14048896960716076262)],
        &[(0b10010, &ENTRY_ANTICENTRALIZATION_14344770334712817786)],
        &[(0b10010, &ENTRY_ANTICENTRALIZATIONS_13464164849647372934)],
        &[(0b01001, &ENTRY_ANTICENTRALIZATION_14344770334712817786)],
        &[(0b01001, &ENTRY_ANTICENTRALIZATIONS_13464164849647372934)],
        &[(0b10010, &ENTRY_ANTICIZE_16286568034747030643)],
        &[(0b10010, &ENTRY_ANTICIZES_10127792012492899699)],
        &[(0b01001, &ENTRY_ANTICIZE_16286568034747030643)],
        &[(0b01001, &ENTRY_ANTICIZES_10127792012492899699)],
    ],
    range: 3..=14,
};

static VARS_ANTH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTH_CHILDREN),
    value: None,
};

pub static VARS_ANTH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ecological"),
        dictgen::InsensitiveStr::Ascii("ecologist"),
        dictgen::InsensitiveStr::Ascii("ecology"),
        dictgen::InsensitiveStr::Ascii("oecological"),
        dictgen::InsensitiveStr::Ascii("oecologist"),
        dictgen::InsensitiveStr::Ascii("oecology"),
        dictgen::InsensitiveStr::Ascii("ologisation"),
        dictgen::InsensitiveStr::Ascii("ologise"),
        dictgen::InsensitiveStr::Ascii("ologised"),
        dictgen::InsensitiveStr::Ascii("ologiser"),
        dictgen::InsensitiveStr::Ascii("ologises"),
        dictgen::InsensitiveStr::Ascii("ologising"),
        dictgen::InsensitiveStr::Ascii("ologization"),
        dictgen::InsensitiveStr::Ascii("ologize"),
        dictgen::InsensitiveStr::Ascii("ologized"),
        dictgen::InsensitiveStr::Ascii("ologizer"),
        dictgen::InsensitiveStr::Ascii("ologizes"),
        dictgen::InsensitiveStr::Ascii("ologizing"),
        dictgen::InsensitiveStr::Ascii("racaemia"),
        dictgen::InsensitiveStr::Ascii("racemia"),
        dictgen::InsensitiveStr::Ascii("racitisation"),
        dictgen::InsensitiveStr::Ascii("racitisations"),
        dictgen::InsensitiveStr::Ascii("racitization"),
        dictgen::InsensitiveStr::Ascii("racitizations"),
        dictgen::InsensitiveStr::Ascii("ropomorphisation"),
        dictgen::InsensitiveStr::Ascii("ropomorphisations"),
        dictgen::InsensitiveStr::Ascii("ropomorphise"),
        dictgen::InsensitiveStr::Ascii("ropomorphised"),
        dictgen::InsensitiveStr::Ascii("ropomorphises"),
        dictgen::InsensitiveStr::Ascii("ropomorphising"),
        dictgen::InsensitiveStr::Ascii("ropomorphization"),
        dictgen::InsensitiveStr::Ascii("ropomorphizations"),
        dictgen::InsensitiveStr::Ascii("ropomorphize"),
        dictgen::InsensitiveStr::Ascii("ropomorphized"),
        dictgen::InsensitiveStr::Ascii("ropomorphizes"),
        dictgen::InsensitiveStr::Ascii("ropomorphizing"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ANTHECOLOGICAL_17004641370097456161)],
        &[(0b00001, &ENTRY_ANTHECOLOGIST_10842025172326516523)],
        &[(0b00001, &ENTRY_ANTHECOLOGY_3713437946183115906)],
        &[(0b11010, &ENTRY_ANTHECOLOGICAL_17004641370097456161)],
        &[(0b11010, &ENTRY_ANTHECOLOGIST_10842025172326516523)],
        &[(0b11010, &ENTRY_ANTHECOLOGY_3713437946183115906)],
        &[(0b10010, &ENTRY_ANTHOLOGIZATION_16268833295952924414)],
        &[(0b10010, &ENTRY_ANTHOLOGIZE_15075070972324121611)],
        &[(0b10010, &ENTRY_ANTHOLOGIZED_12562962063091396112)],
        &[(0b10010, &ENTRY_ANTHOLOGIZER_4038135053732224148)],
        &[(0b10010, &ENTRY_ANTHOLOGIZES_5463829982103826072)],
        &[(0b10010, &ENTRY_ANTHOLOGIZING_16324123758427872169)],
        &[(0b01001, &ENTRY_ANTHOLOGIZATION_16268833295952924414)],
        &[(0b01001, &ENTRY_ANTHOLOGIZE_15075070972324121611)],
        &[(0b01001, &ENTRY_ANTHOLOGIZED_12562962063091396112)],
        &[(0b01001, &ENTRY_ANTHOLOGIZER_4038135053732224148)],
        &[(0b01001, &ENTRY_ANTHOLOGIZES_5463829982103826072)],
        &[(0b01001, &ENTRY_ANTHOLOGIZING_16324123758427872169)],
        &[(0b11010, &ENTRY_ANTHRACEMIA_14146688523586379951)],
        &[(0b00001, &ENTRY_ANTHRACEMIA_14146688523586379951)],
        &[(0b10010, &ENTRY_ANTHRACITIZATION_8950863959835278016)],
        &[(0b10010, &ENTRY_ANTHRACITIZATIONS_1915110451729220165)],
        &[(0b01001, &ENTRY_ANTHRACITIZATION_8950863959835278016)],
        &[(0b01001, &ENTRY_ANTHRACITIZATIONS_1915110451729220165)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZATION_15471734561820106871)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZATIONS_18314256758800098784)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZE_18370683813510312473)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZED_14538403291788237977)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZES_1701634817856038507)],
        &[(0b10010, &ENTRY_ANTHROPOMORPHIZING_2456478028362212796)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZATION_15471734561820106871)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZATIONS_18314256758800098784)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZE_18370683813510312473)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZED_14538403291788237977)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZES_1701634817856038507)],
        &[(0b01001, &ENTRY_ANTHROPOMORPHIZING_2456478028362212796)],
    ],
    range: 7..=17,
};

static VARS_ANTA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANTA_CHILDREN),
    value: None,
};

pub static VARS_ANTA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gonisable"),
        dictgen::InsensitiveStr::Ascii("gonisation"),
        dictgen::InsensitiveStr::Ascii("gonisations"),
        dictgen::InsensitiveStr::Ascii("gonise"),
        dictgen::InsensitiveStr::Ascii("gonised"),
        dictgen::InsensitiveStr::Ascii("goniser"),
        dictgen::InsensitiveStr::Ascii("gonisers"),
        dictgen::InsensitiveStr::Ascii("gonises"),
        dictgen::InsensitiveStr::Ascii("gonising"),
        dictgen::InsensitiveStr::Ascii("gonizable"),
        dictgen::InsensitiveStr::Ascii("gonization"),
        dictgen::InsensitiveStr::Ascii("gonizations"),
        dictgen::InsensitiveStr::Ascii("gonize"),
        dictgen::InsensitiveStr::Ascii("gonized"),
        dictgen::InsensitiveStr::Ascii("gonizer"),
        dictgen::InsensitiveStr::Ascii("gonizers"),
        dictgen::InsensitiveStr::Ascii("gonizes"),
        dictgen::InsensitiveStr::Ascii("gonizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANTAGONIZABLE_7443781692023206072)],
        &[(0b10010, &ENTRY_ANTAGONIZATION_15721044409672903140)],
        &[(0b10010, &ENTRY_ANTAGONIZATIONS_4109454268643874511)],
        &[(0b10010, &ENTRY_ANTAGONIZE_10601283474489177682)],
        &[(0b10010, &ENTRY_ANTAGONIZED_871138940432104250)],
        &[(0b10010, &ENTRY_ANTAGONIZER_2788747943091284362)],
        &[(0b10010, &ENTRY_ANTAGONIZERS_12305563490012496402)],
        &[(0b10010, &ENTRY_ANTAGONIZES_10859788922464934847)],
        &[(0b10010, &ENTRY_ANTAGONIZING_7228037109106376861)],
        &[(0b01001, &ENTRY_ANTAGONIZABLE_7443781692023206072)],
        &[(0b01001, &ENTRY_ANTAGONIZATION_15721044409672903140)],
        &[(0b01001, &ENTRY_ANTAGONIZATIONS_4109454268643874511)],
        &[(0b01001, &ENTRY_ANTAGONIZE_10601283474489177682)],
        &[(0b01001, &ENTRY_ANTAGONIZED_871138940432104250)],
        &[(0b01001, &ENTRY_ANTAGONIZER_2788747943091284362)],
        &[(0b01001, &ENTRY_ANTAGONIZERS_12305563490012496402)],
        &[(0b01001, &ENTRY_ANTAGONIZES_10859788922464934847)],
        &[(0b01001, &ENTRY_ANTAGONIZING_7228037109106376861)],
    ],
    range: 6..=11,
};

static VARS_ANS_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANS_CHILDREN),
    value: None,
};

pub static VARS_ANS_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("erinae"),
        dictgen::InsensitiveStr::Ascii("erine"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANSERINE_7284353552541073260)],
        &[(0b00001, &ENTRY_ANSERINE_7284353552541073260)],
    ],
    range: 5..=6,
};

static VARS_ANO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANO_CHILDREN),
    value: None,
};

pub static VARS_ANO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("disation"),
        dictgen::InsensitiveStr::Ascii("dise"),
        dictgen::InsensitiveStr::Ascii("dised"),
        dictgen::InsensitiveStr::Ascii("dises"),
        dictgen::InsensitiveStr::Ascii("dising"),
        dictgen::InsensitiveStr::Ascii("dization"),
        dictgen::InsensitiveStr::Ascii("dize"),
        dictgen::InsensitiveStr::Ascii("dized"),
        dictgen::InsensitiveStr::Ascii("dizes"),
        dictgen::InsensitiveStr::Ascii("dizing"),
        dictgen::InsensitiveStr::Ascii("esis"),
        dictgen::InsensitiveStr::Ascii("estra"),
        dictgen::InsensitiveStr::Ascii("estri"),
        dictgen::InsensitiveStr::Ascii("estrous"),
        dictgen::InsensitiveStr::Ascii("estrum"),
        dictgen::InsensitiveStr::Ascii("estrus"),
        dictgen::InsensitiveStr::Ascii("estruses"),
        dictgen::InsensitiveStr::Ascii("etic"),
        dictgen::InsensitiveStr::Ascii("nymise"),
        dictgen::InsensitiveStr::Ascii("nymised"),
        dictgen::InsensitiveStr::Ascii("nymises"),
        dictgen::InsensitiveStr::Ascii("nymising"),
        dictgen::InsensitiveStr::Ascii("nymize"),
        dictgen::InsensitiveStr::Ascii("nymized"),
        dictgen::InsensitiveStr::Ascii("nymizes"),
        dictgen::InsensitiveStr::Ascii("nymizing"),
        dictgen::InsensitiveStr::Ascii("ra"),
        dictgen::InsensitiveStr::Ascii("ura"),
        dictgen::InsensitiveStr::Ascii("xaemia"),
        dictgen::InsensitiveStr::Ascii("xaemic"),
        dictgen::InsensitiveStr::Ascii("xemia"),
        dictgen::InsensitiveStr::Ascii("xemic"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANODIZATION_733182598382300688)],
        &[(0b10010, &ENTRY_ANODIZE_13790793654476230265)],
        &[(0b10010, &ENTRY_ANODIZED_7735922642387297722)],
        &[(0b10010, &ENTRY_ANODIZES_16654764323679187252)],
        &[(0b10010, &ENTRY_ANODIZING_15645879132035324138)],
        &[(0b01001, &ENTRY_ANODIZATION_733182598382300688)],
        &[(0b01001, &ENTRY_ANODIZE_13790793654476230265)],
        &[(0b01001, &ENTRY_ANODIZED_7735922642387297722)],
        &[(0b01001, &ENTRY_ANODIZES_16654764323679187252)],
        &[(0b01001, &ENTRY_ANODIZING_15645879132035324138)],
        &[(0b11010, &ENTRY_ANESIS_16817046064174279211)],
        &[(0b11010, &ENTRY_ANESTRA_3216556063016372977)],
        &[(0b11010, &ENTRY_ANESTRI_8008769930372220485)],
        &[(0b11010, &ENTRY_ANESTROUS_9129522172283593493)],
        &[(0b11010, &ENTRY_ANESTRUM_11523934029574851144)],
        &[(0b11010, &ENTRY_ANESTRUS_9353558396235507225)],
        &[(0b11010, &ENTRY_ANESTRUSES_8824267452405407476)],
        &[(0b11010, &ENTRY_ANETIC_9540754510599321451)],
        &[(0b10010, &ENTRY_ANONYMIZE_1026063515222292659)],
        &[(0b10010, &ENTRY_ANONYMIZED_12511764813081644809)],
        &[(0b10010, &ENTRY_ANONYMIZES_8133801285918261260)],
        &[(0b10010, &ENTRY_ANONYMIZING_8330567531910680906)],
        &[(0b01001, &ENTRY_ANONYMIZE_1026063515222292659)],
        &[(0b01001, &ENTRY_ANONYMIZED_12511764813081644809)],
        &[(0b01001, &ENTRY_ANONYMIZES_8133801285918261260)],
        &[(0b01001, &ENTRY_ANONYMIZING_8330567531910680906)],
        &[(0b00001, &ENTRY_ANORA_9499275694738114232)],
        &[(0b11010, &ENTRY_ANORA_9499275694738114232)],
        &[(0b11010, &ENTRY_ANOXEMIA_938996689614149150)],
        &[(0b11010, &ENTRY_ANOXEMIC_11133442815252282278)],
        &[(0b10001, &ENTRY_ANOXEMIA_938996689614149150)],
        &[(0b10001, &ENTRY_ANOXEMIC_11133442815252282278)],
    ],
    range: 2..=8,
};

static VARS_ANN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANN_CHILDREN),
    value: None,
};

pub static VARS_ANN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANNALIZE_5262176181932588410)],
        &[(0b10010, &ENTRY_ANNALIZED_1584431856817967939)],
        &[(0b10010, &ENTRY_ANNALIZES_9421823492557620465)],
        &[(0b10010, &ENTRY_ANNALIZING_7591181130486416840)],
        &[(0b01001, &ENTRY_ANNALIZE_5262176181932588410)],
        &[(0b01001, &ENTRY_ANNALIZED_1584431856817967939)],
        &[(0b01001, &ENTRY_ANNALIZES_9421823492557620465)],
        &[(0b01001, &ENTRY_ANNALIZING_7591181130486416840)],
        &[(0b10010, &ENTRY_ANNUALIZATION_7581292024702563132)],
        &[(0b10010, &ENTRY_ANNUALIZE_10377266175278860708)],
        &[(0b10010, &ENTRY_ANNUALIZED_1903235447181584612)],
        &[(0b10010, &ENTRY_ANNUALIZES_784688421746976936)],
        &[(0b10010, &ENTRY_ANNUALIZING_2550568847360033478)],
        &[(0b01001, &ENTRY_ANNUALIZATION_7581292024702563132)],
        &[(0b01001, &ENTRY_ANNUALIZE_10377266175278860708)],
        &[(0b01001, &ENTRY_ANNUALIZED_1903235447181584612)],
        &[(0b01001, &ENTRY_ANNUALIZES_784688421746976936)],
        &[(0b01001, &ENTRY_ANNUALIZING_2550568847360033478)],
    ],
    range: 5..=10,
};

static VARS_ANI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANI_CHILDREN),
    value: None,
};

pub static VARS_ANI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("malisation"),
        dictgen::InsensitiveStr::Ascii("malisations"),
        dictgen::InsensitiveStr::Ascii("malise"),
        dictgen::InsensitiveStr::Ascii("malised"),
        dictgen::InsensitiveStr::Ascii("malises"),
        dictgen::InsensitiveStr::Ascii("malising"),
        dictgen::InsensitiveStr::Ascii("malization"),
        dictgen::InsensitiveStr::Ascii("malizations"),
        dictgen::InsensitiveStr::Ascii("malize"),
        dictgen::InsensitiveStr::Ascii("malized"),
        dictgen::InsensitiveStr::Ascii("malizes"),
        dictgen::InsensitiveStr::Ascii("malizing"),
        dictgen::InsensitiveStr::Ascii("mised"),
        dictgen::InsensitiveStr::Ascii("mized"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANIMALIZATION_13800839490330789274)],
        &[(0b10010, &ENTRY_ANIMALIZATIONS_9150262297922812039)],
        &[(0b10010, &ENTRY_ANIMALIZE_10795005523464430843)],
        &[(0b10010, &ENTRY_ANIMALIZED_14858832182572412268)],
        &[(0b10010, &ENTRY_ANIMALIZES_10069318372695209095)],
        &[(0b10010, &ENTRY_ANIMALIZING_14729872040352851901)],
        &[(0b01001, &ENTRY_ANIMALIZATION_13800839490330789274)],
        &[(0b01001, &ENTRY_ANIMALIZATIONS_9150262297922812039)],
        &[(0b01001, &ENTRY_ANIMALIZE_10795005523464430843)],
        &[(0b01001, &ENTRY_ANIMALIZED_14858832182572412268)],
        &[(0b01001, &ENTRY_ANIMALIZES_10069318372695209095)],
        &[(0b01001, &ENTRY_ANIMALIZING_14729872040352851901)],
        &[(0b10010, &ENTRY_ANIMIZED_3366606492537025225)],
        &[(0b01001, &ENTRY_ANIMIZED_3366606492537025225)],
    ],
    range: 5..=11,
};

static VARS_ANH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANH_CHILDREN),
    value: None,
};

pub static VARS_ANH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aematopoiesis"),
        dictgen::InsensitiveStr::Ascii("aematosis"),
        dictgen::InsensitiveStr::Ascii("aemolytic"),
        dictgen::InsensitiveStr::Ascii("ematopoiesis"),
        dictgen::InsensitiveStr::Ascii("ematosis"),
        dictgen::InsensitiveStr::Ascii("emolytic"),
        dictgen::InsensitiveStr::Ascii("ydraemia"),
        dictgen::InsensitiveStr::Ascii("ydraemic"),
        dictgen::InsensitiveStr::Ascii("ydremia"),
        dictgen::InsensitiveStr::Ascii("ydremic"),
        dictgen::InsensitiveStr::Ascii("ydridisation"),
        dictgen::InsensitiveStr::Ascii("ydridisations"),
        dictgen::InsensitiveStr::Ascii("ydridise"),
        dictgen::InsensitiveStr::Ascii("ydridises"),
        dictgen::InsensitiveStr::Ascii("ydridization"),
        dictgen::InsensitiveStr::Ascii("ydridizations"),
        dictgen::InsensitiveStr::Ascii("ydridize"),
        dictgen::InsensitiveStr::Ascii("ydridizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANHEMATOPOIESIS_17033044080627588200)],
        &[(0b11010, &ENTRY_ANHEMATOSIS_1202870001006935602)],
        &[(0b11010, &ENTRY_ANHEMOLYTIC_16692415296726473453)],
        &[(0b10001, &ENTRY_ANHEMATOPOIESIS_17033044080627588200)],
        &[(0b10001, &ENTRY_ANHEMATOSIS_1202870001006935602)],
        &[(0b10001, &ENTRY_ANHEMOLYTIC_16692415296726473453)],
        &[(0b11010, &ENTRY_ANHYDREMIA_6316263310895692445)],
        &[(0b11010, &ENTRY_ANHYDREMIC_15977830070786776453)],
        &[(0b10001, &ENTRY_ANHYDREMIA_6316263310895692445)],
        &[(0b10001, &ENTRY_ANHYDREMIC_15977830070786776453)],
        &[(0b10010, &ENTRY_ANHYDRIDIZATION_5779486140945991167)],
        &[(0b10010, &ENTRY_ANHYDRIDIZATIONS_6600161284303257781)],
        &[(0b10010, &ENTRY_ANHYDRIDIZE_15475133187948388972)],
        &[(0b10010, &ENTRY_ANHYDRIDIZES_14731666580950863474)],
        &[(0b01001, &ENTRY_ANHYDRIDIZATION_5779486140945991167)],
        &[(0b01001, &ENTRY_ANHYDRIDIZATIONS_6600161284303257781)],
        &[(0b01001, &ENTRY_ANHYDRIDIZE_15475133187948388972)],
        &[(0b01001, &ENTRY_ANHYDRIDIZES_14731666580950863474)],
    ],
    range: 7..=13,
};

static VARS_ANG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANG_CHILDREN),
    value: None,
};

pub static VARS_ANG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("elicise"),
        dictgen::InsensitiveStr::Ascii("elicises"),
        dictgen::InsensitiveStr::Ascii("elicize"),
        dictgen::InsensitiveStr::Ascii("elicizes"),
        dictgen::InsensitiveStr::Ascii("elise"),
        dictgen::InsensitiveStr::Ascii("elises"),
        dictgen::InsensitiveStr::Ascii("elize"),
        dictgen::InsensitiveStr::Ascii("elizes"),
        dictgen::InsensitiveStr::Ascii("licanise"),
        dictgen::InsensitiveStr::Ascii("licanises"),
        dictgen::InsensitiveStr::Ascii("licanize"),
        dictgen::InsensitiveStr::Ascii("licanizes"),
        dictgen::InsensitiveStr::Ascii("licisation"),
        dictgen::InsensitiveStr::Ascii("licisations"),
        dictgen::InsensitiveStr::Ascii("licise"),
        dictgen::InsensitiveStr::Ascii("licised"),
        dictgen::InsensitiveStr::Ascii("licises"),
        dictgen::InsensitiveStr::Ascii("licising"),
        dictgen::InsensitiveStr::Ascii("licization"),
        dictgen::InsensitiveStr::Ascii("licizations"),
        dictgen::InsensitiveStr::Ascii("licize"),
        dictgen::InsensitiveStr::Ascii("licized"),
        dictgen::InsensitiveStr::Ascii("licizes"),
        dictgen::InsensitiveStr::Ascii("licizing"),
        dictgen::InsensitiveStr::Ascii("raecum"),
        dictgen::InsensitiveStr::Ascii("recum"),
        dictgen::InsensitiveStr::Ascii("ularisation"),
        dictgen::InsensitiveStr::Ascii("ularisations"),
        dictgen::InsensitiveStr::Ascii("ularise"),
        dictgen::InsensitiveStr::Ascii("ularises"),
        dictgen::InsensitiveStr::Ascii("ularization"),
        dictgen::InsensitiveStr::Ascii("ularizations"),
        dictgen::InsensitiveStr::Ascii("ularize"),
        dictgen::InsensitiveStr::Ascii("ularizes"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANGELICIZE_12868295367561294619)],
        &[(0b10010, &ENTRY_ANGELICIZES_1637579071183202501)],
        &[(0b01001, &ENTRY_ANGELICIZE_12868295367561294619)],
        &[(0b01001, &ENTRY_ANGELICIZES_1637579071183202501)],
        &[(0b10010, &ENTRY_ANGELIZE_3309439384866912750)],
        &[(0b10010, &ENTRY_ANGELIZES_11526151045543007463)],
        &[(0b01001, &ENTRY_ANGELIZE_3309439384866912750)],
        &[(0b01001, &ENTRY_ANGELIZES_11526151045543007463)],
        &[(0b10010, &ENTRY_ANGLICANIZE_6589690597387603909)],
        &[(0b10010, &ENTRY_ANGLICANIZES_16783014059494751778)],
        &[(0b01001, &ENTRY_ANGLICANIZE_6589690597387603909)],
        &[(0b01001, &ENTRY_ANGLICANIZES_16783014059494751778)],
        &[(0b10010, &ENTRY_ANGLICIZATION_15673594215730164653)],
        &[(0b10010, &ENTRY_ANGLICIZATIONS_18401409530730050577)],
        &[(0b10010, &ENTRY_ANGLICIZE_3954997619999275868)],
        &[(0b10010, &ENTRY_ANGLICIZED_926209429237587197)],
        &[(0b10010, &ENTRY_ANGLICIZES_17586920051951268985)],
        &[(0b10010, &ENTRY_ANGLICIZING_9709864366695655479)],
        &[(0b01001, &ENTRY_ANGLICIZATION_15673594215730164653)],
        &[(0b01001, &ENTRY_ANGLICIZATIONS_18401409530730050577)],
        &[(0b01001, &ENTRY_ANGLICIZE_3954997619999275868)],
        &[(0b01001, &ENTRY_ANGLICIZED_926209429237587197)],
        &[(0b01001, &ENTRY_ANGLICIZES_17586920051951268985)],
        &[(0b01001, &ENTRY_ANGLICIZING_9709864366695655479)],
        &[(0b11010, &ENTRY_ANGRECUM_15932729819544960039)],
        &[(0b00001, &ENTRY_ANGRECUM_15932729819544960039)],
        &[(0b10010, &ENTRY_ANGULARIZATION_15472457872184311028)],
        &[(0b10010, &ENTRY_ANGULARIZATIONS_11452719329473280471)],
        &[(0b10010, &ENTRY_ANGULARIZE_12397633129669042330)],
        &[(0b10010, &ENTRY_ANGULARIZES_5024097194073065261)],
        &[(0b01001, &ENTRY_ANGULARIZATION_15472457872184311028)],
        &[(0b01001, &ENTRY_ANGULARIZATIONS_11452719329473280471)],
        &[(0b01001, &ENTRY_ANGULARIZE_12397633129669042330)],
        &[(0b01001, &ENTRY_ANGULARIZES_5024097194073065261)],
    ],
    range: 5..=12,
};

static VARS_ANE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANE_CHILDREN),
    value: None,
};

pub static VARS_ANE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matosis"),
        dictgen::InsensitiveStr::Ascii("mia"),
        dictgen::InsensitiveStr::Ascii("mias"),
        dictgen::InsensitiveStr::Ascii("mic"),
        dictgen::InsensitiveStr::Ascii("mically"),
        dictgen::InsensitiveStr::Ascii("micer"),
        dictgen::InsensitiveStr::Ascii("micest"),
        dictgen::InsensitiveStr::Ascii("mics"),
        dictgen::InsensitiveStr::Ascii("retic"),
        dictgen::InsensitiveStr::Ascii("sis"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesiant"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthesiologies"),
        dictgen::InsensitiveStr::Ascii("sthesiologist"),
        dictgen::InsensitiveStr::Ascii("sthesiologists"),
        dictgen::InsensitiveStr::Ascii("sthesiology"),
        dictgen::InsensitiveStr::Ascii("sthesis"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("sthetically"),
        dictgen::InsensitiveStr::Ascii("stheticer"),
        dictgen::InsensitiveStr::Ascii("stheticest"),
        dictgen::InsensitiveStr::Ascii("sthetics"),
        dictgen::InsensitiveStr::Ascii("sthetisation"),
        dictgen::InsensitiveStr::Ascii("sthetise"),
        dictgen::InsensitiveStr::Ascii("sthetised"),
        dictgen::InsensitiveStr::Ascii("sthetiser"),
        dictgen::InsensitiveStr::Ascii("sthetisers"),
        dictgen::InsensitiveStr::Ascii("sthetises"),
        dictgen::InsensitiveStr::Ascii("sthetising"),
        dictgen::InsensitiveStr::Ascii("sthetist"),
        dictgen::InsensitiveStr::Ascii("sthetists"),
        dictgen::InsensitiveStr::Ascii("sthetization"),
        dictgen::InsensitiveStr::Ascii("sthetizations"),
        dictgen::InsensitiveStr::Ascii("sthetize"),
        dictgen::InsensitiveStr::Ascii("sthetized"),
        dictgen::InsensitiveStr::Ascii("sthetizer"),
        dictgen::InsensitiveStr::Ascii("sthetizers"),
        dictgen::InsensitiveStr::Ascii("sthetizes"),
        dictgen::InsensitiveStr::Ascii("sthetizing"),
        dictgen::InsensitiveStr::Ascii("sthyl"),
        dictgen::InsensitiveStr::Ascii("stra"),
        dictgen::InsensitiveStr::Ascii("stri"),
        dictgen::InsensitiveStr::Ascii("strous"),
        dictgen::InsensitiveStr::Ascii("strum"),
        dictgen::InsensitiveStr::Ascii("strus"),
        dictgen::InsensitiveStr::Ascii("struses"),
        dictgen::InsensitiveStr::Ascii("tic"),
        dictgen::InsensitiveStr::Ascii("tiological"),
    ],
    values: &[
        &[(0b00001, &ENTRY_ANEMATOSIS_2231831205038246544)],
        &[(0b11001, &ENTRY_ANEMIA_11444125334540196345)],
        &[(0b11001, &ENTRY_ANEMIAS_11793613272534563937)],
        &[(0b11001, &ENTRY_ANEMIC_3144161607917365302)],
        &[(0b11001, &ENTRY_ANEMICALLY_6100474579337104939)],
        &[(0b11001, &ENTRY_ANEMICER_16024076703657819532)],
        &[(0b11001, &ENTRY_ANEMICEST_17483472184329322961)],
        &[(0b11001, &ENTRY_ANEMICS_9964370762426059120)],
        &[(0b00001, &ENTRY_ANERETIC_6982175402554498005)],
        &[(0b00001, &ENTRY_ANESIS_16817046064174279211)],
        &[(0b11001, &ENTRY_ANESTHESIA_9822581388335098553)],
        &[(0b11001, &ENTRY_ANESTHESIANT_15565352975099719303)],
        &[(0b11001, &ENTRY_ANESTHESIAS_9838908694750944673)],
        &[(0b11001, &ENTRY_ANESTHESIOLOGIES_6679603096569359713)],
        &[(0b11001, &ENTRY_ANESTHESIOLOGIST_15509935416057002830)],
        &[(0b11001, &ENTRY_ANESTHESIOLOGISTS_5770405695630095861)],
        &[(0b11001, &ENTRY_ANESTHESIOLOGY_1255532677711876584)],
        &[(0b11001, &ENTRY_ANESTHESIS_3798568430045477742)],
        &[(0b11001, &ENTRY_ANESTHETIC_7346810397925011981)],
        &[(0b11001, &ENTRY_ANESTHETICALLY_17611597914394933738)],
        &[(0b11001, &ENTRY_ANESTHETICER_1712235669739749819)],
        &[(0b11001, &ENTRY_ANESTHETICEST_13273804515231488648)],
        &[(0b11001, &ENTRY_ANESTHETICS_9673867241310151800)],
        &[
            (0b10000, &ENTRY_ANESTHETIZATIONS_10494265552871488873),
            (0b10000, &ENTRY_ANESTHETIZATION_11701429006232412151),
        ],
        &[(0b10000, &ENTRY_ANESTHETIZE_9242516368594572411)],
        &[(0b10000, &ENTRY_ANESTHETIZED_10115321731074208256)],
        &[(0b10000, &ENTRY_ANESTHETIZER_5418733284803121475)],
        &[(0b10000, &ENTRY_ANESTHETIZERS_17863131477627405979)],
        &[(0b10000, &ENTRY_ANESTHETIZES_6149697878942963698)],
        &[(0b10000, &ENTRY_ANESTHETIZING_15816199569084558224)],
        &[(0b11001, &ENTRY_ANESTHETIST_10778880823396904501)],
        &[(0b11001, &ENTRY_ANESTHETISTS_8741608628280855523)],
        &[(0b00001, &ENTRY_ANESTHETIZATION_11701429006232412151)],
        &[(0b00001, &ENTRY_ANESTHETIZATIONS_10494265552871488873)],
        &[(0b01001, &ENTRY_ANESTHETIZE_9242516368594572411)],
        &[(0b01001, &ENTRY_ANESTHETIZED_10115321731074208256)],
        &[(0b00001, &ENTRY_ANESTHETIZER_5418733284803121475)],
        &[(0b00001, &ENTRY_ANESTHETIZERS_17863131477627405979)],
        &[(0b01001, &ENTRY_ANESTHETIZES_6149697878942963698)],
        &[(0b01001, &ENTRY_ANESTHETIZING_15816199569084558224)],
        &[(0b00001, &ENTRY_ANESTHYL_8174332230955659903)],
        &[(0b10001, &ENTRY_ANESTRA_3216556063016372977)],
        &[(0b10001, &ENTRY_ANESTRI_8008769930372220485)],
        &[(0b10001, &ENTRY_ANESTROUS_9129522172283593493)],
        &[(0b10001, &ENTRY_ANESTRUM_11523934029574851144)],
        &[(0b10001, &ENTRY_ANESTRUS_9353558396235507225)],
        &[(0b10001, &ENTRY_ANESTRUSES_8824267452405407476)],
        &[(0b10001, &ENTRY_ANETIC_9540754510599321451)],
        &[(0b10001, &ENTRY_ANETIOLOGICAL_10165110800520199298)],
    ],
    range: 3..=14,
};

static VARS_ANC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANC_CHILDREN),
    value: None,
};

pub static VARS_ANC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hinoae"),
        dictgen::InsensitiveStr::Ascii("hinoe"),
        dictgen::InsensitiveStr::Ascii("illae"),
        dictgen::InsensitiveStr::Ascii("ille"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANCHINOE_163304748892282636)],
        &[(0b00001, &ENTRY_ANCHINOE_163304748892282636)],
        &[(0b11010, &ENTRY_ANCILLE_15818318021107678161)],
        &[(0b00001, &ENTRY_ANCILLE_15818318021107678161)],
    ],
    range: 4..=6,
};

static VARS_ANA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_ANA_CHILDREN),
    value: None,
};

static VARS_ANA_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_ANAB_NODE),
    None,
    None,
    Some(&VARS_ANAE_NODE),
    None,
    Some(&VARS_ANAG_NODE),
    None,
    None,
    None,
    None,
    Some(&VARS_ANAL_NODE),
    None,
    None,
    None,
    Some(&VARS_ANAP_NODE),
    None,
    Some(&VARS_ANAR_NODE),
    None,
    Some(&VARS_ANAT_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
];

static VARS_ANAT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAT_CHILDREN),
    value: None,
};

pub static VARS_ANAT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hematisation"),
        dictgen::InsensitiveStr::Ascii("hematisations"),
        dictgen::InsensitiveStr::Ascii("hematise"),
        dictgen::InsensitiveStr::Ascii("hematised"),
        dictgen::InsensitiveStr::Ascii("hematiser"),
        dictgen::InsensitiveStr::Ascii("hematises"),
        dictgen::InsensitiveStr::Ascii("hematising"),
        dictgen::InsensitiveStr::Ascii("hematization"),
        dictgen::InsensitiveStr::Ascii("hematizations"),
        dictgen::InsensitiveStr::Ascii("hematize"),
        dictgen::InsensitiveStr::Ascii("hematized"),
        dictgen::InsensitiveStr::Ascii("hematizer"),
        dictgen::InsensitiveStr::Ascii("hematizes"),
        dictgen::InsensitiveStr::Ascii("hematizing"),
        dictgen::InsensitiveStr::Ascii("omisable"),
        dictgen::InsensitiveStr::Ascii("omisation"),
        dictgen::InsensitiveStr::Ascii("omise"),
        dictgen::InsensitiveStr::Ascii("omised"),
        dictgen::InsensitiveStr::Ascii("omiser"),
        dictgen::InsensitiveStr::Ascii("omises"),
        dictgen::InsensitiveStr::Ascii("omising"),
        dictgen::InsensitiveStr::Ascii("omizable"),
        dictgen::InsensitiveStr::Ascii("omization"),
        dictgen::InsensitiveStr::Ascii("omize"),
        dictgen::InsensitiveStr::Ascii("omized"),
        dictgen::InsensitiveStr::Ascii("omizer"),
        dictgen::InsensitiveStr::Ascii("omizes"),
        dictgen::InsensitiveStr::Ascii("omizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANATHEMATIZATION_15280298908583722308)],
        &[(0b10010, &ENTRY_ANATHEMATIZATIONS_620207996168887075)],
        &[(0b10010, &ENTRY_ANATHEMATIZE_9250331648604756093)],
        &[(0b10010, &ENTRY_ANATHEMATIZED_3874188261925704186)],
        &[(0b10010, &ENTRY_ANATHEMATIZER_3378013434055917757)],
        &[(0b10010, &ENTRY_ANATHEMATIZES_8973479734940337633)],
        &[(0b10010, &ENTRY_ANATHEMATIZING_10299965854697438675)],
        &[(0b01001, &ENTRY_ANATHEMATIZATION_15280298908583722308)],
        &[(0b01001, &ENTRY_ANATHEMATIZATIONS_620207996168887075)],
        &[(0b01001, &ENTRY_ANATHEMATIZE_9250331648604756093)],
        &[(0b01001, &ENTRY_ANATHEMATIZED_3874188261925704186)],
        &[(0b01001, &ENTRY_ANATHEMATIZER_3378013434055917757)],
        &[(0b01001, &ENTRY_ANATHEMATIZES_8973479734940337633)],
        &[(0b01001, &ENTRY_ANATHEMATIZING_10299965854697438675)],
        &[(0b10010, &ENTRY_ANATOMIZABLE_6218592416722946394)],
        &[(0b10010, &ENTRY_ANATOMIZATION_4269547902777954197)],
        &[(0b10010, &ENTRY_ANATOMIZE_841129889860317661)],
        &[(0b10010, &ENTRY_ANATOMIZED_862561253191916873)],
        &[(0b10010, &ENTRY_ANATOMIZER_10181303822973702398)],
        &[(0b10010, &ENTRY_ANATOMIZES_6453710897733584587)],
        &[(0b10010, &ENTRY_ANATOMIZING_14431856406330078710)],
        &[(0b01001, &ENTRY_ANATOMIZABLE_6218592416722946394)],
        &[(0b01001, &ENTRY_ANATOMIZATION_4269547902777954197)],
        &[(0b01001, &ENTRY_ANATOMIZE_841129889860317661)],
        &[(0b01001, &ENTRY_ANATOMIZED_862561253191916873)],
        &[(0b01001, &ENTRY_ANATOMIZER_10181303822973702398)],
        &[(0b01001, &ENTRY_ANATOMIZES_6453710897733584587)],
        &[(0b01001, &ENTRY_ANATOMIZING_14431856406330078710)],
    ],
    range: 5..=13,
};

static VARS_ANAR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAR_CHILDREN),
    value: None,
};

pub static VARS_ANAR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("chise"),
        dictgen::InsensitiveStr::Ascii("chised"),
        dictgen::InsensitiveStr::Ascii("chises"),
        dictgen::InsensitiveStr::Ascii("chising"),
        dictgen::InsensitiveStr::Ascii("chize"),
        dictgen::InsensitiveStr::Ascii("chized"),
        dictgen::InsensitiveStr::Ascii("chizes"),
        dictgen::InsensitiveStr::Ascii("chizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANARCHIZE_16873413817474048843)],
        &[(0b10010, &ENTRY_ANARCHIZED_13521160029536762262)],
        &[(0b10010, &ENTRY_ANARCHIZES_2426137200100120755)],
        &[(0b10010, &ENTRY_ANARCHIZING_11629066219610630589)],
        &[(0b01001, &ENTRY_ANARCHIZE_16873413817474048843)],
        &[(0b01001, &ENTRY_ANARCHIZED_13521160029536762262)],
        &[(0b01001, &ENTRY_ANARCHIZES_2426137200100120755)],
        &[(0b01001, &ENTRY_ANARCHIZING_11629066219610630589)],
    ],
    range: 5..=7,
};

static VARS_ANAP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAP_CHILDREN),
    value: None,
};

pub static VARS_ANAP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aestically"),
        dictgen::InsensitiveStr::Ascii("estically"),
        dictgen::InsensitiveStr::Ascii("neic"),
        dictgen::InsensitiveStr::Ascii("noeic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANAPESTICALLY_15963069963215922817)],
        &[(0b00001, &ENTRY_ANAPESTICALLY_15963069963215922817)],
        &[(0b00001, &ENTRY_ANAPNEIC_9824624761463965547)],
        &[(0b11010, &ENTRY_ANAPNEIC_9824624761463965547)],
    ],
    range: 4..=10,
};

static VARS_ANAL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAL_CHILDREN),
    value: None,
};

pub static VARS_ANAL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ogise"),
        dictgen::InsensitiveStr::Ascii("ogised"),
        dictgen::InsensitiveStr::Ascii("ogises"),
        dictgen::InsensitiveStr::Ascii("ogising"),
        dictgen::InsensitiveStr::Ascii("ogize"),
        dictgen::InsensitiveStr::Ascii("ogized"),
        dictgen::InsensitiveStr::Ascii("ogizes"),
        dictgen::InsensitiveStr::Ascii("ogizing"),
        dictgen::InsensitiveStr::Ascii("ysability"),
        dictgen::InsensitiveStr::Ascii("ysable"),
        dictgen::InsensitiveStr::Ascii("ysabler"),
        dictgen::InsensitiveStr::Ascii("ysablest"),
        dictgen::InsensitiveStr::Ascii("ysation"),
        dictgen::InsensitiveStr::Ascii("ysations"),
        dictgen::InsensitiveStr::Ascii("yse"),
        dictgen::InsensitiveStr::Ascii("ysed"),
        dictgen::InsensitiveStr::Ascii("yser"),
        dictgen::InsensitiveStr::Ascii("ysers"),
        dictgen::InsensitiveStr::Ascii("ysing"),
        dictgen::InsensitiveStr::Ascii("yzability"),
        dictgen::InsensitiveStr::Ascii("yzable"),
        dictgen::InsensitiveStr::Ascii("yzabler"),
        dictgen::InsensitiveStr::Ascii("yzablest"),
        dictgen::InsensitiveStr::Ascii("yzation"),
        dictgen::InsensitiveStr::Ascii("yzations"),
        dictgen::InsensitiveStr::Ascii("yze"),
        dictgen::InsensitiveStr::Ascii("yzed"),
        dictgen::InsensitiveStr::Ascii("yzer"),
        dictgen::InsensitiveStr::Ascii("yzers"),
        dictgen::InsensitiveStr::Ascii("yzes"),
        dictgen::InsensitiveStr::Ascii("yzing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANALOGIZE_5536035389372667946)],
        &[(0b10010, &ENTRY_ANALOGIZED_15332378387951220039)],
        &[(0b10010, &ENTRY_ANALOGIZES_2435391307518285611)],
        &[(0b10010, &ENTRY_ANALOGIZING_5193184992170428572)],
        &[(0b01001, &ENTRY_ANALOGIZE_5536035389372667946)],
        &[(0b01001, &ENTRY_ANALOGIZED_15332378387951220039)],
        &[(0b01001, &ENTRY_ANALOGIZES_2435391307518285611)],
        &[(0b01001, &ENTRY_ANALOGIZING_5193184992170428572)],
        &[(0b10010, &ENTRY_ANALYZABILITY_1551141386065817504)],
        &[(0b10010, &ENTRY_ANALYZABLE_617037050560332150)],
        &[(0b10010, &ENTRY_ANALYZABLER_17997925440256942572)],
        &[(0b10010, &ENTRY_ANALYZABLEST_8874109193021320157)],
        &[(0b10010, &ENTRY_ANALYZATION_15073164819277453463)],
        &[(0b10010, &ENTRY_ANALYZATIONS_10325231710634833644)],
        &[(0b11010, &ENTRY_ANALYZE_13435707901024257028)],
        &[(0b11010, &ENTRY_ANALYZED_3241611515791740784)],
        &[(0b10010, &ENTRY_ANALYZER_13687050517411638821)],
        &[(0b10010, &ENTRY_ANALYZERS_7884682095017825661)],
        &[(0b11010, &ENTRY_ANALYZING_17972193862022825096)],
        &[(0b01001, &ENTRY_ANALYZABILITY_1551141386065817504)],
        &[(0b01001, &ENTRY_ANALYZABLE_617037050560332150)],
        &[(0b01001, &ENTRY_ANALYZABLER_17997925440256942572)],
        &[(0b01001, &ENTRY_ANALYZABLEST_8874109193021320157)],
        &[(0b01001, &ENTRY_ANALYZATION_15073164819277453463)],
        &[(0b01001, &ENTRY_ANALYZATIONS_10325231710634833644)],
        &[(0b01001, &ENTRY_ANALYZE_13435707901024257028)],
        &[(0b01001, &ENTRY_ANALYZED_3241611515791740784)],
        &[(0b01001, &ENTRY_ANALYZER_13687050517411638821)],
        &[(0b01001, &ENTRY_ANALYZERS_7884682095017825661)],
        &[(0b01001, &ENTRY_ANALYZES_13473182794044934522)],
        &[(0b01001, &ENTRY_ANALYZING_17972193862022825096)],
    ],
    range: 3..=9,
};

static VARS_ANAG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAG_CHILDREN),
    value: None,
};

pub static VARS_ANAG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("rammatise"),
        dictgen::InsensitiveStr::Ascii("rammatised"),
        dictgen::InsensitiveStr::Ascii("rammatises"),
        dictgen::InsensitiveStr::Ascii("rammatising"),
        dictgen::InsensitiveStr::Ascii("rammatize"),
        dictgen::InsensitiveStr::Ascii("rammatized"),
        dictgen::InsensitiveStr::Ascii("rammatizes"),
        dictgen::InsensitiveStr::Ascii("rammatizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANAGRAMMATIZE_1294531725794717084)],
        &[(0b10010, &ENTRY_ANAGRAMMATIZED_17231243584520853895)],
        &[(0b10010, &ENTRY_ANAGRAMMATIZES_13203766080338850548)],
        &[(0b10010, &ENTRY_ANAGRAMMATIZING_7360812298529172732)],
        &[(0b01001, &ENTRY_ANAGRAMMATIZE_1294531725794717084)],
        &[(0b01001, &ENTRY_ANAGRAMMATIZED_17231243584520853895)],
        &[(0b01001, &ENTRY_ANAGRAMMATIZES_13203766080338850548)],
        &[(0b01001, &ENTRY_ANAGRAMMATIZING_7360812298529172732)],
    ],
    range: 9..=11,
};

static VARS_ANAE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAE_CHILDREN),
    value: None,
};

pub static VARS_ANAE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("matosis"),
        dictgen::InsensitiveStr::Ascii("mia"),
        dictgen::InsensitiveStr::Ascii("mias"),
        dictgen::InsensitiveStr::Ascii("mic"),
        dictgen::InsensitiveStr::Ascii("mically"),
        dictgen::InsensitiveStr::Ascii("micer"),
        dictgen::InsensitiveStr::Ascii("micest"),
        dictgen::InsensitiveStr::Ascii("mics"),
        dictgen::InsensitiveStr::Ascii("retic"),
        dictgen::InsensitiveStr::Ascii("sthesia"),
        dictgen::InsensitiveStr::Ascii("sthesiant"),
        dictgen::InsensitiveStr::Ascii("sthesias"),
        dictgen::InsensitiveStr::Ascii("sthesiologies"),
        dictgen::InsensitiveStr::Ascii("sthesiologist"),
        dictgen::InsensitiveStr::Ascii("sthesiologists"),
        dictgen::InsensitiveStr::Ascii("sthesiology"),
        dictgen::InsensitiveStr::Ascii("sthesis"),
        dictgen::InsensitiveStr::Ascii("sthetic"),
        dictgen::InsensitiveStr::Ascii("sthetically"),
        dictgen::InsensitiveStr::Ascii("stheticer"),
        dictgen::InsensitiveStr::Ascii("stheticest"),
        dictgen::InsensitiveStr::Ascii("sthetics"),
        dictgen::InsensitiveStr::Ascii("sthetisation"),
        dictgen::InsensitiveStr::Ascii("sthetisations"),
        dictgen::InsensitiveStr::Ascii("sthetise"),
        dictgen::InsensitiveStr::Ascii("sthetised"),
        dictgen::InsensitiveStr::Ascii("sthetiser"),
        dictgen::InsensitiveStr::Ascii("sthetisers"),
        dictgen::InsensitiveStr::Ascii("sthetises"),
        dictgen::InsensitiveStr::Ascii("sthetising"),
        dictgen::InsensitiveStr::Ascii("sthetist"),
        dictgen::InsensitiveStr::Ascii("sthetists"),
        dictgen::InsensitiveStr::Ascii("sthetization"),
        dictgen::InsensitiveStr::Ascii("sthetizations"),
        dictgen::InsensitiveStr::Ascii("sthetize"),
        dictgen::InsensitiveStr::Ascii("sthetized"),
        dictgen::InsensitiveStr::Ascii("sthetizer"),
        dictgen::InsensitiveStr::Ascii("sthetizers"),
        dictgen::InsensitiveStr::Ascii("sthetizes"),
        dictgen::InsensitiveStr::Ascii("sthetizing"),
        dictgen::InsensitiveStr::Ascii("sthyl"),
        dictgen::InsensitiveStr::Ascii("tiological"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ANEMATOSIS_2231831205038246544)],
        &[(0b10010, &ENTRY_ANEMIA_11444125334540196345)],
        &[(0b10010, &ENTRY_ANEMIAS_11793613272534563937)],
        &[(0b10010, &ENTRY_ANEMIC_3144161607917365302)],
        &[(0b10010, &ENTRY_ANEMICALLY_6100474579337104939)],
        &[(0b10010, &ENTRY_ANEMICER_16024076703657819532)],
        &[(0b10010, &ENTRY_ANEMICEST_17483472184329322961)],
        &[(0b10010, &ENTRY_ANEMICS_9964370762426059120)],
        &[(0b11010, &ENTRY_ANERETIC_6982175402554498005)],
        &[(0b11010, &ENTRY_ANESTHESIA_9822581388335098553)],
        &[(0b11010, &ENTRY_ANESTHESIANT_15565352975099719303)],
        &[(0b11010, &ENTRY_ANESTHESIAS_9838908694750944673)],
        &[(0b10010, &ENTRY_ANESTHESIOLOGIES_6679603096569359713)],
        &[(0b10010, &ENTRY_ANESTHESIOLOGIST_15509935416057002830)],
        &[(0b10010, &ENTRY_ANESTHESIOLOGISTS_5770405695630095861)],
        &[(0b10010, &ENTRY_ANESTHESIOLOGY_1255532677711876584)],
        &[(0b10010, &ENTRY_ANESTHESIS_3798568430045477742)],
        &[(0b11010, &ENTRY_ANESTHETIC_7346810397925011981)],
        &[(0b11010, &ENTRY_ANESTHETICALLY_17611597914394933738)],
        &[(0b11010, &ENTRY_ANESTHETICER_1712235669739749819)],
        &[(0b11010, &ENTRY_ANESTHETICEST_13273804515231488648)],
        &[(0b11010, &ENTRY_ANESTHETICS_9673867241310151800)],
        &[(0b10010, &ENTRY_ANESTHETIZATION_11701429006232412151)],
        &[(0b10010, &ENTRY_ANESTHETIZATIONS_10494265552871488873)],
        &[(0b10010, &ENTRY_ANESTHETIZE_9242516368594572411)],
        &[(0b10010, &ENTRY_ANESTHETIZED_10115321731074208256)],
        &[(0b10010, &ENTRY_ANESTHETIZER_5418733284803121475)],
        &[(0b10010, &ENTRY_ANESTHETIZERS_17863131477627405979)],
        &[(0b10010, &ENTRY_ANESTHETIZES_6149697878942963698)],
        &[(0b10010, &ENTRY_ANESTHETIZING_15816199569084558224)],
        &[(0b11010, &ENTRY_ANESTHETIST_10778880823396904501)],
        &[(0b11010, &ENTRY_ANESTHETISTS_8741608628280855523)],
        &[(0b01000, &ENTRY_ANESTHETIZATION_11701429006232412151)],
        &[(0b01000, &ENTRY_ANESTHETIZATIONS_10494265552871488873)],
        &[(0b01000, &ENTRY_ANESTHETIZE_9242516368594572411)],
        &[(0b01000, &ENTRY_ANESTHETIZED_10115321731074208256)],
        &[(0b01000, &ENTRY_ANESTHETIZER_5418733284803121475)],
        &[(0b01000, &ENTRY_ANESTHETIZERS_17863131477627405979)],
        &[(0b01000, &ENTRY_ANESTHETIZES_6149697878942963698)],
        &[(0b01000, &ENTRY_ANESTHETIZING_15816199569084558224)],
        &[(0b11010, &ENTRY_ANESTHYL_8174332230955659903)],
        &[(0b11010, &ENTRY_ANETIOLOGICAL_10165110800520199298)],
    ],
    range: 3..=14,
};

static VARS_ANAB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ANAB_CHILDREN),
    value: None,
};

pub static VARS_ANAB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aptise"),
        dictgen::InsensitiveStr::Ascii("aptised"),
        dictgen::InsensitiveStr::Ascii("aptises"),
        dictgen::InsensitiveStr::Ascii("aptising"),
        dictgen::InsensitiveStr::Ascii("aptize"),
        dictgen::InsensitiveStr::Ascii("aptized"),
        dictgen::InsensitiveStr::Ascii("aptizes"),
        dictgen::InsensitiveStr::Ascii("aptizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ANABAPTIZE_2729267296806864066)],
        &[(0b10010, &ENTRY_ANABAPTIZED_10937015334598797503)],
        &[(0b10010, &ENTRY_ANABAPTIZES_5845461765970005402)],
        &[(0b10010, &ENTRY_ANABAPTIZING_3689660901707732301)],
        &[(0b01001, &ENTRY_ANABAPTIZE_2729267296806864066)],
        &[(0b01001, &ENTRY_ANABAPTIZED_10937015334598797503)],
        &[(0b01001, &ENTRY_ANABAPTIZES_5845461765970005402)],
        &[(0b01001, &ENTRY_ANABAPTIZING_3689660901707732301)],
    ],
    range: 6..=8,
};

static VARS_AM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AM_CHILDREN),
    value: None,
};

static VARS_AM_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_AMA_NODE),
    Some(&VARS_AMB_NODE),
    None,
    None,
    Some(&VARS_AME_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AMM_NODE),
    None,
    Some(&VARS_AMO_NODE),
    Some(&VARS_AMP_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AMY_NODE),
    None,
];

static VARS_AMY_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMY_CHILDREN),
    value: None,
};

pub static VARS_AMY_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("gdalae"),
        dictgen::InsensitiveStr::Ascii("gdale"),
        dictgen::InsensitiveStr::Ascii("xorrhea"),
        dictgen::InsensitiveStr::Ascii("xorrhoea"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AMYGDALE_9445312936529667739)],
        &[(0b00001, &ENTRY_AMYGDALE_9445312936529667739)],
        &[(0b00001, &ENTRY_AMYXORRHEA_4253893643371161289)],
        &[(0b11010, &ENTRY_AMYXORRHEA_4253893643371161289)],
    ],
    range: 5..=8,
};

static VARS_AMP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMP_CHILDREN),
    value: None,
};

pub static VARS_AMP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("higaean"),
        dictgen::InsensitiveStr::Ascii("higean"),
        dictgen::InsensitiveStr::Ascii("hitheater"),
        dictgen::InsensitiveStr::Ascii("hitheaters"),
        dictgen::InsensitiveStr::Ascii("hitheatre"),
        dictgen::InsensitiveStr::Ascii("hitheatres"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AMPHIGEAN_2635547525436752336)],
        &[(0b00001, &ENTRY_AMPHIGEAN_2635547525436752336)],
        &[(0b01001, &ENTRY_AMPHITHEATER_3688102909787113288)],
        &[(0b01001, &ENTRY_AMPHITHEATERS_6166627403689463943)],
        &[(0b11010, &ENTRY_AMPHITHEATER_3688102909787113288)],
        &[(0b11010, &ENTRY_AMPHITHEATERS_6166627403689463943)],
    ],
    range: 6..=10,
};

static VARS_AMO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMO_CHILDREN),
    value: None,
};

pub static VARS_AMO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eban"),
        dictgen::InsensitiveStr::Ascii("ebean"),
        dictgen::InsensitiveStr::Ascii("ebian"),
        dictgen::InsensitiveStr::Ascii("ebiases"),
        dictgen::InsensitiveStr::Ascii("ebiasis"),
        dictgen::InsensitiveStr::Ascii("ebicidal"),
        dictgen::InsensitiveStr::Ascii("ebicide"),
        dictgen::InsensitiveStr::Ascii("ebid"),
        dictgen::InsensitiveStr::Ascii("ebiform"),
        dictgen::InsensitiveStr::Ascii("ebiosis"),
        dictgen::InsensitiveStr::Ascii("ebocyte"),
        dictgen::InsensitiveStr::Ascii("ebocytes"),
        dictgen::InsensitiveStr::Ascii("eboidism"),
        dictgen::InsensitiveStr::Ascii("ebous"),
        dictgen::InsensitiveStr::Ascii("ebula"),
        dictgen::InsensitiveStr::Ascii("ralise"),
        dictgen::InsensitiveStr::Ascii("ralises"),
        dictgen::InsensitiveStr::Ascii("ralize"),
        dictgen::InsensitiveStr::Ascii("ralizes"),
        dictgen::InsensitiveStr::Ascii("ret"),
        dictgen::InsensitiveStr::Ascii("rism"),
        dictgen::InsensitiveStr::Ascii("risms"),
        dictgen::InsensitiveStr::Ascii("rist"),
        dictgen::InsensitiveStr::Ascii("ristic"),
        dictgen::InsensitiveStr::Ascii("ristics"),
        dictgen::InsensitiveStr::Ascii("rists"),
        dictgen::InsensitiveStr::Ascii("rphisation"),
        dictgen::InsensitiveStr::Ascii("rphise"),
        dictgen::InsensitiveStr::Ascii("rphization"),
        dictgen::InsensitiveStr::Ascii("rphize"),
        dictgen::InsensitiveStr::Ascii("rtisable"),
        dictgen::InsensitiveStr::Ascii("rtisabler"),
        dictgen::InsensitiveStr::Ascii("rtisables"),
        dictgen::InsensitiveStr::Ascii("rtisablest"),
        dictgen::InsensitiveStr::Ascii("rtisation"),
        dictgen::InsensitiveStr::Ascii("rtisations"),
        dictgen::InsensitiveStr::Ascii("rtise"),
        dictgen::InsensitiveStr::Ascii("rtised"),
        dictgen::InsensitiveStr::Ascii("rtisement"),
        dictgen::InsensitiveStr::Ascii("rtisements"),
        dictgen::InsensitiveStr::Ascii("rtises"),
        dictgen::InsensitiveStr::Ascii("rtising"),
        dictgen::InsensitiveStr::Ascii("rtizable"),
        dictgen::InsensitiveStr::Ascii("rtizabler"),
        dictgen::InsensitiveStr::Ascii("rtizables"),
        dictgen::InsensitiveStr::Ascii("rtizablest"),
        dictgen::InsensitiveStr::Ascii("rtization"),
        dictgen::InsensitiveStr::Ascii("rtizations"),
        dictgen::InsensitiveStr::Ascii("rtize"),
        dictgen::InsensitiveStr::Ascii("rtized"),
        dictgen::InsensitiveStr::Ascii("rtizement"),
        dictgen::InsensitiveStr::Ascii("rtizements"),
        dictgen::InsensitiveStr::Ascii("rtizes"),
        dictgen::InsensitiveStr::Ascii("rtizing"),
        dictgen::InsensitiveStr::Ascii("uret"),
        dictgen::InsensitiveStr::Ascii("urism"),
        dictgen::InsensitiveStr::Ascii("urisms"),
        dictgen::InsensitiveStr::Ascii("urist"),
        dictgen::InsensitiveStr::Ascii("uristic"),
        dictgen::InsensitiveStr::Ascii("uristics"),
        dictgen::InsensitiveStr::Ascii("urists"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AMEBAN_5277068494503541064)],
        &[(0b11010, &ENTRY_AMEBEAN_1913759118822823378)],
        &[(0b11010, &ENTRY_AMEBIAN_4002663444157694529)],
        &[(0b11010, &ENTRY_AMEBIASES_11778219912968682475)],
        &[(0b11010, &ENTRY_AMEBIASIS_6361517279962028009)],
        &[(0b11010, &ENTRY_AMEBICIDAL_17077923016456623176)],
        &[(0b11010, &ENTRY_AMEBICIDE_340489975023787457)],
        &[(0b11010, &ENTRY_AMEBID_2070455756616987385)],
        &[(0b11010, &ENTRY_AMEBIFORM_7555597990047716880)],
        &[(0b11010, &ENTRY_AMEBIOSIS_4936567060198771189)],
        &[(0b11010, &ENTRY_AMEBOCYTE_14677487577192167094)],
        &[(0b11010, &ENTRY_AMEBOCYTES_6917539757967941181)],
        &[(0b11010, &ENTRY_AMEBOIDISM_6330017017844207166)],
        &[(0b11010, &ENTRY_AMEBOUS_1006698274831009682)],
        &[(0b11010, &ENTRY_AMEBULA_11715705581331080902)],
        &[(0b10010, &ENTRY_AMORALIZE_437899974996323138)],
        &[(0b10010, &ENTRY_AMORALIZES_3004553231540605930)],
        &[(0b01001, &ENTRY_AMORALIZE_437899974996323138)],
        &[(0b01001, &ENTRY_AMORALIZES_3004553231540605930)],
        &[(0b00001, &ENTRY_AMORET_11190930336071907365)],
        &[(0b00001, &ENTRY_AMORISM_13622053629400049439)],
        &[(0b00001, &ENTRY_AMORISMS_8591683750858003331)],
        &[(0b00001, &ENTRY_AMORIST_15615749666067796835)],
        &[(0b00001, &ENTRY_AMORISTIC_9227858452058548163)],
        &[(0b00001, &ENTRY_AMORISTICS_18339349616054530724)],
        &[(0b00001, &ENTRY_AMORISTS_6019660879632735851)],
        &[(0b10010, &ENTRY_AMORPHIZATION_4718410488040839837)],
        &[(0b10010, &ENTRY_AMORPHIZE_15516090808530900584)],
        &[(0b01001, &ENTRY_AMORPHIZATION_4718410488040839837)],
        &[(0b01001, &ENTRY_AMORPHIZE_15516090808530900584)],
        &[(0b10010, &ENTRY_AMORTIZABLE_18025712452516364127)],
        &[(0b10010, &ENTRY_AMORTIZABLER_8597378575585075865)],
        &[(0b10010, &ENTRY_AMORTIZABLES_10949882004562997724)],
        &[(0b10010, &ENTRY_AMORTIZABLEST_2628369391782893993)],
        &[(0b10010, &ENTRY_AMORTIZATION_4181880901981206246)],
        &[(0b10010, &ENTRY_AMORTIZATIONS_10667746967250951820)],
        &[(0b10010, &ENTRY_AMORTIZE_14941813541869573228)],
        &[(0b10010, &ENTRY_AMORTIZED_5774086997820266664)],
        &[(0b10010, &ENTRY_AMORTIZEMENT_12103927078743615024)],
        &[(0b10010, &ENTRY_AMORTIZEMENTS_10400864127697785423)],
        &[(0b10010, &ENTRY_AMORTIZES_18292533417191526171)],
        &[(0b10010, &ENTRY_AMORTIZING_12733662438547175763)],
        &[(0b01001, &ENTRY_AMORTIZABLE_18025712452516364127)],
        &[(0b01001, &ENTRY_AMORTIZABLER_8597378575585075865)],
        &[(0b01001, &ENTRY_AMORTIZABLES_10949882004562997724)],
        &[(0b01001, &ENTRY_AMORTIZABLEST_2628369391782893993)],
        &[(0b01001, &ENTRY_AMORTIZATION_4181880901981206246)],
        &[(0b01001, &ENTRY_AMORTIZATIONS_10667746967250951820)],
        &[(0b01001, &ENTRY_AMORTIZE_14941813541869573228)],
        &[(0b01001, &ENTRY_AMORTIZED_5774086997820266664)],
        &[(0b01001, &ENTRY_AMORTIZEMENT_12103927078743615024)],
        &[(0b01001, &ENTRY_AMORTIZEMENTS_10400864127697785423)],
        &[(0b01001, &ENTRY_AMORTIZES_18292533417191526171)],
        &[(0b01001, &ENTRY_AMORTIZING_12733662438547175763)],
        &[(0b11010, &ENTRY_AMORET_11190930336071907365)],
        &[(0b11010, &ENTRY_AMORISM_13622053629400049439)],
        &[(0b11010, &ENTRY_AMORISMS_8591683750858003331)],
        &[(0b11010, &ENTRY_AMORIST_15615749666067796835)],
        &[(0b11010, &ENTRY_AMORISTIC_9227858452058548163)],
        &[(0b11010, &ENTRY_AMORISTICS_18339349616054530724)],
        &[(0b11010, &ENTRY_AMORISTS_6019660879632735851)],
    ],
    range: 3..=10,
};

static VARS_AMM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMM_CHILDREN),
    value: None,
};

pub static VARS_AMM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ocete"),
        dictgen::InsensitiveStr::Ascii("ocetes"),
        dictgen::InsensitiveStr::Ascii("ocoete"),
        dictgen::InsensitiveStr::Ascii("ocoetes"),
        dictgen::InsensitiveStr::Ascii("oniaemia"),
        dictgen::InsensitiveStr::Ascii("oniemia"),
    ],
    values: &[
        &[(0b10001, &ENTRY_AMMOCETE_11149092949437835019)],
        &[(0b10001, &ENTRY_AMMOCETES_15510029871033694789)],
        &[(0b11010, &ENTRY_AMMOCETE_11149092949437835019)],
        &[(0b11010, &ENTRY_AMMOCETES_15510029871033694789)],
        &[(0b11010, &ENTRY_AMMONIEMIA_12378710937857988312)],
        &[(0b00001, &ENTRY_AMMONIEMIA_12378710937857988312)],
    ],
    range: 5..=8,
};

static VARS_AME_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AME_CHILDREN),
    value: None,
};

pub static VARS_AME_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ba"),
        dictgen::InsensitiveStr::Ascii("bae"),
        dictgen::InsensitiveStr::Ascii("ban"),
        dictgen::InsensitiveStr::Ascii("bas"),
        dictgen::InsensitiveStr::Ascii("bean"),
        dictgen::InsensitiveStr::Ascii("bian"),
        dictgen::InsensitiveStr::Ascii("biases"),
        dictgen::InsensitiveStr::Ascii("biasis"),
        dictgen::InsensitiveStr::Ascii("bic"),
        dictgen::InsensitiveStr::Ascii("bicidal"),
        dictgen::InsensitiveStr::Ascii("bicide"),
        dictgen::InsensitiveStr::Ascii("bid"),
        dictgen::InsensitiveStr::Ascii("biform"),
        dictgen::InsensitiveStr::Ascii("biosis"),
        dictgen::InsensitiveStr::Ascii("bocyte"),
        dictgen::InsensitiveStr::Ascii("bocytes"),
        dictgen::InsensitiveStr::Ascii("boid"),
        dictgen::InsensitiveStr::Ascii("boidism"),
        dictgen::InsensitiveStr::Ascii("bous"),
        dictgen::InsensitiveStr::Ascii("bula"),
        dictgen::InsensitiveStr::Ascii("norrhea"),
        dictgen::InsensitiveStr::Ascii("norrheal"),
        dictgen::InsensitiveStr::Ascii("norrheas"),
        dictgen::InsensitiveStr::Ascii("norrheic"),
        dictgen::InsensitiveStr::Ascii("norrhoea"),
        dictgen::InsensitiveStr::Ascii("norrhoeal"),
        dictgen::InsensitiveStr::Ascii("norrhoeas"),
        dictgen::InsensitiveStr::Ascii("norrhoeic"),
        dictgen::InsensitiveStr::Ascii("ricanisation"),
        dictgen::InsensitiveStr::Ascii("ricanisations"),
        dictgen::InsensitiveStr::Ascii("ricanise"),
        dictgen::InsensitiveStr::Ascii("ricanised"),
        dictgen::InsensitiveStr::Ascii("ricaniser"),
        dictgen::InsensitiveStr::Ascii("ricanisers"),
        dictgen::InsensitiveStr::Ascii("ricanises"),
        dictgen::InsensitiveStr::Ascii("ricanising"),
        dictgen::InsensitiveStr::Ascii("ricanization"),
        dictgen::InsensitiveStr::Ascii("ricanizations"),
        dictgen::InsensitiveStr::Ascii("ricanize"),
        dictgen::InsensitiveStr::Ascii("ricanized"),
        dictgen::InsensitiveStr::Ascii("ricanizer"),
        dictgen::InsensitiveStr::Ascii("ricanizers"),
        dictgen::InsensitiveStr::Ascii("ricanizes"),
        dictgen::InsensitiveStr::Ascii("ricanizing"),
    ],
    values: &[
        &[(0b10001, &ENTRY_AMOEBA_4495880425081872610)],
        &[(0b10001, &ENTRY_AMOEBAS_12713021889803788234)],
        &[(0b10001, &ENTRY_AMEBAN_5277068494503541064)],
        &[(0b10001, &ENTRY_AMOEBAS_12713021889803788234)],
        &[(0b10001, &ENTRY_AMEBEAN_1913759118822823378)],
        &[(0b10001, &ENTRY_AMEBIAN_4002663444157694529)],
        &[(0b10001, &ENTRY_AMEBIASES_11778219912968682475)],
        &[(0b10001, &ENTRY_AMEBIASIS_6361517279962028009)],
        &[(0b10001, &ENTRY_AMOEBIC_8026378913624369514)],
        &[(0b10001, &ENTRY_AMEBICIDAL_17077923016456623176)],
        &[(0b10001, &ENTRY_AMEBICIDE_340489975023787457)],
        &[(0b10001, &ENTRY_AMEBID_2070455756616987385)],
        &[(0b10001, &ENTRY_AMEBIFORM_7555597990047716880)],
        &[(0b10001, &ENTRY_AMEBIOSIS_4936567060198771189)],
        &[(0b10001, &ENTRY_AMEBOCYTE_14677487577192167094)],
        &[(0b10001, &ENTRY_AMEBOCYTES_6917539757967941181)],
        &[(0b10001, &ENTRY_AMOEBOID_10813571979914678921)],
        &[(0b10001, &ENTRY_AMEBOIDISM_6330017017844207166)],
        &[(0b10001, &ENTRY_AMEBOUS_1006698274831009682)],
        &[(0b10001, &ENTRY_AMEBULA_11715705581331080902)],
        &[(0b11001, &ENTRY_AMENORRHEA_9430440773940411667)],
        &[(0b11001, &ENTRY_AMENORRHEAL_12274073988422822411)],
        &[(0b11001, &ENTRY_AMENORRHEAS_3707756389439454986)],
        &[(0b11001, &ENTRY_AMENORRHEIC_7520675613225846121)],
        &[(0b11010, &ENTRY_AMENORRHEA_9430440773940411667)],
        &[(0b11010, &ENTRY_AMENORRHEAL_12274073988422822411)],
        &[(0b11010, &ENTRY_AMENORRHEAS_3707756389439454986)],
        &[(0b11010, &ENTRY_AMENORRHEIC_7520675613225846121)],
        &[(0b10010, &ENTRY_AMERICANIZATION_6309260318644804917)],
        &[(0b10010, &ENTRY_AMERICANIZATIONS_9566538544452946630)],
        &[(0b10010, &ENTRY_AMERICANIZE_8636777715370127651)],
        &[(0b10010, &ENTRY_AMERICANIZED_1906052736648918553)],
        &[(0b10010, &ENTRY_AMERICANIZER_5573339924551090371)],
        &[(0b10010, &ENTRY_AMERICANIZERS_7997596044566128128)],
        &[(0b10010, &ENTRY_AMERICANIZES_1895797903602224728)],
        &[(0b10010, &ENTRY_AMERICANIZING_15437774827264361694)],
        &[(0b01001, &ENTRY_AMERICANIZATION_6309260318644804917)],
        &[(0b01001, &ENTRY_AMERICANIZATIONS_9566538544452946630)],
        &[(0b01001, &ENTRY_AMERICANIZE_8636777715370127651)],
        &[(0b01001, &ENTRY_AMERICANIZED_1906052736648918553)],
        &[(0b01001, &ENTRY_AMERICANIZER_5573339924551090371)],
        &[(0b01001, &ENTRY_AMERICANIZERS_7997596044566128128)],
        &[(0b01001, &ENTRY_AMERICANIZES_1895797903602224728)],
        &[(0b01001, &ENTRY_AMERICANIZING_15437774827264361694)],
    ],
    range: 2..=13,
};

static VARS_AMB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMB_CHILDREN),
    value: None,
};

pub static VARS_AMB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icolorate"),
        dictgen::InsensitiveStr::Ascii("icoloration"),
        dictgen::InsensitiveStr::Ascii("icolourate"),
        dictgen::InsensitiveStr::Ascii("icolouration"),
        dictgen::InsensitiveStr::Ascii("ilaevous"),
        dictgen::InsensitiveStr::Ascii("ilevous"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AMBICOLORATE_6721589398342053523)],
        &[(0b00001, &ENTRY_AMBICOLORATION_14002894506100288246)],
        &[(0b11010, &ENTRY_AMBICOLORATE_6721589398342053523)],
        &[(0b11010, &ENTRY_AMBICOLORATION_14002894506100288246)],
        &[(0b11010, &ENTRY_AMBILEVOUS_16610037464217485655)],
        &[(0b00001, &ENTRY_AMBILEVOUS_16610037464217485655)],
    ],
    range: 7..=12,
};

static VARS_AMA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AMA_CHILDREN),
    value: None,
};

pub static VARS_AMA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lgamatise"),
        dictgen::InsensitiveStr::Ascii("lgamatises"),
        dictgen::InsensitiveStr::Ascii("lgamatize"),
        dictgen::InsensitiveStr::Ascii("lgamatizes"),
        dictgen::InsensitiveStr::Ascii("lgamisation"),
        dictgen::InsensitiveStr::Ascii("lgamisations"),
        dictgen::InsensitiveStr::Ascii("lgamise"),
        dictgen::InsensitiveStr::Ascii("lgamises"),
        dictgen::InsensitiveStr::Ascii("lgamization"),
        dictgen::InsensitiveStr::Ascii("lgamizations"),
        dictgen::InsensitiveStr::Ascii("lgamize"),
        dictgen::InsensitiveStr::Ascii("lgamizes"),
        dictgen::InsensitiveStr::Ascii("lthaea"),
        dictgen::InsensitiveStr::Ascii("lthea"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AMALGAMATIZE_7375445972208185230)],
        &[(0b10010, &ENTRY_AMALGAMATIZES_11197265529776604273)],
        &[(0b01001, &ENTRY_AMALGAMATIZE_7375445972208185230)],
        &[(0b01001, &ENTRY_AMALGAMATIZES_11197265529776604273)],
        &[(0b10010, &ENTRY_AMALGAMIZATION_6873838956097053791)],
        &[(0b10010, &ENTRY_AMALGAMIZATIONS_11642266614868063418)],
        &[(0b10010, &ENTRY_AMALGAMIZE_6774540532866713160)],
        &[(0b10010, &ENTRY_AMALGAMIZES_18246550602932639451)],
        &[(0b01001, &ENTRY_AMALGAMIZATION_6873838956097053791)],
        &[(0b01001, &ENTRY_AMALGAMIZATIONS_11642266614868063418)],
        &[(0b01001, &ENTRY_AMALGAMIZE_6774540532866713160)],
        &[(0b01001, &ENTRY_AMALGAMIZES_18246550602932639451)],
        &[(0b11010, &ENTRY_AMALTHEA_17903426763265878110)],
        &[(0b00001, &ENTRY_AMALTHEA_17903426763265878110)],
    ],
    range: 5..=12,
};

static VARS_AL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AL_CHILDREN),
    value: None,
};

static VARS_AL_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    None,
    Some(&VARS_ALB_NODE),
    Some(&VARS_ALC_NODE),
    None,
    Some(&VARS_ALE_NODE),
    None,
    Some(&VARS_ALG_NODE),
    None,
    Some(&VARS_ALI_NODE),
    None,
    Some(&VARS_ALK_NODE),
    Some(&VARS_ALL_NODE),
    Some(&VARS_ALM_NODE),
    None,
    Some(&VARS_ALO_NODE),
    Some(&VARS_ALP_NODE),
    None,
    None,
    None,
    Some(&VARS_ALT_NODE),
    Some(&VARS_ALU_NODE),
    Some(&VARS_ALV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_ALV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALV_CHILDREN),
    value: None,
};

pub static VARS_ALV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("eolae"),
        dictgen::InsensitiveStr::Ascii("eole"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ALVEOLE_16490342143918785702)],
        &[(0b00001, &ENTRY_ALVEOLE_16490342143918785702)],
    ],
    range: 4..=5,
};

static VARS_ALU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALU_CHILDREN),
    value: None,
};

pub static VARS_ALU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("minisation"),
        dictgen::InsensitiveStr::Ascii("minise"),
        dictgen::InsensitiveStr::Ascii("minised"),
        dictgen::InsensitiveStr::Ascii("minises"),
        dictgen::InsensitiveStr::Ascii("minising"),
        dictgen::InsensitiveStr::Ascii("minium"),
        dictgen::InsensitiveStr::Ascii("miniums"),
        dictgen::InsensitiveStr::Ascii("minization"),
        dictgen::InsensitiveStr::Ascii("minize"),
        dictgen::InsensitiveStr::Ascii("minized"),
        dictgen::InsensitiveStr::Ascii("minizes"),
        dictgen::InsensitiveStr::Ascii("minizing"),
        dictgen::InsensitiveStr::Ascii("minum"),
        dictgen::InsensitiveStr::Ascii("minums"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALUMINIZATION_18425035090862987036)],
        &[(0b10010, &ENTRY_ALUMINIZE_15056197197529932132)],
        &[(0b10010, &ENTRY_ALUMINIZED_10495213790591424683)],
        &[(0b10010, &ENTRY_ALUMINIZES_13441975977760937538)],
        &[(0b10010, &ENTRY_ALUMINIZING_12430331523650185895)],
        &[(0b10010, &ENTRY_ALUMINUM_12230548845456538965)],
        &[(0b10010, &ENTRY_ALUMINUMS_235477509529996640)],
        &[(0b01001, &ENTRY_ALUMINIZATION_18425035090862987036)],
        &[(0b01001, &ENTRY_ALUMINIZE_15056197197529932132)],
        &[(0b01001, &ENTRY_ALUMINIZED_10495213790591424683)],
        &[(0b01001, &ENTRY_ALUMINIZES_13441975977760937538)],
        &[(0b01001, &ENTRY_ALUMINIZING_12430331523650185895)],
        &[(0b01001, &ENTRY_ALUMINUM_12230548845456538965)],
        &[(0b01001, &ENTRY_ALUMINUMS_235477509529996640)],
    ],
    range: 5..=10,
};

static VARS_ALT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALT_CHILDREN),
    value: None,
};

pub static VARS_ALT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ernise"),
        dictgen::InsensitiveStr::Ascii("ernises"),
        dictgen::InsensitiveStr::Ascii("ernize"),
        dictgen::InsensitiveStr::Ascii("ernizes"),
        dictgen::InsensitiveStr::Ascii("haea"),
        dictgen::InsensitiveStr::Ascii("haeas"),
        dictgen::InsensitiveStr::Ascii("haein"),
        dictgen::InsensitiveStr::Ascii("hea"),
        dictgen::InsensitiveStr::Ascii("heas"),
        dictgen::InsensitiveStr::Ascii("hein"),
        dictgen::InsensitiveStr::Ascii("ho"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALTERNIZE_285767739893718525)],
        &[(0b10010, &ENTRY_ALTERNIZES_9696050258020074609)],
        &[(0b01001, &ENTRY_ALTERNIZE_285767739893718525)],
        &[(0b01001, &ENTRY_ALTERNIZES_9696050258020074609)],
        &[(0b11010, &ENTRY_ALTHEA_11553591055146462879)],
        &[(0b11010, &ENTRY_ALTHEAS_841278574081921149)],
        &[(0b11010, &ENTRY_ALTHEIN_11491174847546175682)],
        &[(0b10001, &ENTRY_ALTHEA_11553591055146462879)],
        &[(0b10001, &ENTRY_ALTHEAS_841278574081921149)],
        &[(0b00001, &ENTRY_ALTHEIN_11491174847546175682)],
        &[(0b00001, &ENTRY_ALTHOUGH_9541446420672118730)],
    ],
    range: 2..=7,
};

static VARS_ALP_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALP_CHILDREN),
    value: None,
};

pub static VARS_ALP_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("habetisation"),
        dictgen::InsensitiveStr::Ascii("habetisations"),
        dictgen::InsensitiveStr::Ascii("habetise"),
        dictgen::InsensitiveStr::Ascii("habetised"),
        dictgen::InsensitiveStr::Ascii("habetiser"),
        dictgen::InsensitiveStr::Ascii("habetisers"),
        dictgen::InsensitiveStr::Ascii("habetises"),
        dictgen::InsensitiveStr::Ascii("habetising"),
        dictgen::InsensitiveStr::Ascii("habetization"),
        dictgen::InsensitiveStr::Ascii("habetizations"),
        dictgen::InsensitiveStr::Ascii("habetize"),
        dictgen::InsensitiveStr::Ascii("habetized"),
        dictgen::InsensitiveStr::Ascii("habetizer"),
        dictgen::InsensitiveStr::Ascii("habetizers"),
        dictgen::InsensitiveStr::Ascii("habetizes"),
        dictgen::InsensitiveStr::Ascii("habetizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALPHABETIZATION_16660905929935057642)],
        &[(0b10010, &ENTRY_ALPHABETIZATIONS_17047359931254284362)],
        &[(0b10010, &ENTRY_ALPHABETIZE_5185363765846869604)],
        &[(0b10010, &ENTRY_ALPHABETIZED_1298633346805774272)],
        &[(0b10010, &ENTRY_ALPHABETIZER_14767864421419944921)],
        &[(0b10010, &ENTRY_ALPHABETIZERS_6296269536595041194)],
        &[(0b10010, &ENTRY_ALPHABETIZES_12175651960887303885)],
        &[(0b10010, &ENTRY_ALPHABETIZING_8059168115305559564)],
        &[(0b01001, &ENTRY_ALPHABETIZATION_16660905929935057642)],
        &[(0b01001, &ENTRY_ALPHABETIZATIONS_17047359931254284362)],
        &[(0b01001, &ENTRY_ALPHABETIZE_5185363765846869604)],
        &[(0b01001, &ENTRY_ALPHABETIZED_1298633346805774272)],
        &[(0b01001, &ENTRY_ALPHABETIZER_14767864421419944921)],
        &[(0b01001, &ENTRY_ALPHABETIZERS_6296269536595041194)],
        &[(0b01001, &ENTRY_ALPHABETIZES_12175651960887303885)],
        &[(0b01001, &ENTRY_ALPHABETIZING_8059168115305559564)],
    ],
    range: 8..=13,
};

static VARS_ALO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALO_CHILDREN),
    value: None,
};

pub static VARS_ALO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("eus")],
    values: &[&[(0b11010, &ENTRY_ALEUS_15999250050243856705)]],
    range: 3..=3,
};

static VARS_ALM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALM_CHILDREN),
    value: None,
};

pub static VARS_ALM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("anack"),
        dictgen::InsensitiveStr::Ascii("anacks"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALMANAC_15717861359409582720)],
        &[(0b10010, &ENTRY_ALMANACS_9267005522772569452)],
    ],
    range: 5..=6,
};

static VARS_ALL_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALL_CHILDREN),
    value: None,
};

pub static VARS_ALL_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("egorisation"),
        dictgen::InsensitiveStr::Ascii("egorisations"),
        dictgen::InsensitiveStr::Ascii("egorise"),
        dictgen::InsensitiveStr::Ascii("egorised"),
        dictgen::InsensitiveStr::Ascii("egoriser"),
        dictgen::InsensitiveStr::Ascii("egorisers"),
        dictgen::InsensitiveStr::Ascii("egorises"),
        dictgen::InsensitiveStr::Ascii("egorising"),
        dictgen::InsensitiveStr::Ascii("egorization"),
        dictgen::InsensitiveStr::Ascii("egorizations"),
        dictgen::InsensitiveStr::Ascii("egorize"),
        dictgen::InsensitiveStr::Ascii("egorized"),
        dictgen::InsensitiveStr::Ascii("egorizer"),
        dictgen::InsensitiveStr::Ascii("egorizers"),
        dictgen::InsensitiveStr::Ascii("egorizes"),
        dictgen::InsensitiveStr::Ascii("egorizing"),
        dictgen::InsensitiveStr::Ascii("oxuraemia"),
        dictgen::InsensitiveStr::Ascii("oxuremia"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALLEGORIZATION_14762864111557060395)],
        &[(0b10010, &ENTRY_ALLEGORIZATIONS_1317829325279302497)],
        &[(0b10010, &ENTRY_ALLEGORIZE_6482121904165219135)],
        &[(0b10010, &ENTRY_ALLEGORIZED_11740413629820898932)],
        &[(0b10010, &ENTRY_ALLEGORIZER_4274874326715631309)],
        &[(0b10010, &ENTRY_ALLEGORIZERS_114835122393079616)],
        &[(0b10010, &ENTRY_ALLEGORIZES_4178362701003728243)],
        &[(0b10010, &ENTRY_ALLEGORIZING_899303066346673273)],
        &[(0b01001, &ENTRY_ALLEGORIZATION_14762864111557060395)],
        &[(0b01001, &ENTRY_ALLEGORIZATIONS_1317829325279302497)],
        &[(0b01001, &ENTRY_ALLEGORIZE_6482121904165219135)],
        &[(0b01001, &ENTRY_ALLEGORIZED_11740413629820898932)],
        &[(0b01001, &ENTRY_ALLEGORIZER_4274874326715631309)],
        &[(0b01001, &ENTRY_ALLEGORIZERS_114835122393079616)],
        &[(0b01001, &ENTRY_ALLEGORIZES_4178362701003728243)],
        &[(0b01001, &ENTRY_ALLEGORIZING_899303066346673273)],
        &[(0b11010, &ENTRY_ALLOXUREMIA_6517416850737377397)],
        &[(0b00001, &ENTRY_ALLOXUREMIA_6517416850737377397)],
    ],
    range: 7..=12,
};

static VARS_ALK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALK_CHILDREN),
    value: None,
};

pub static VARS_ALK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("alinisation"),
        dictgen::InsensitiveStr::Ascii("alinisations"),
        dictgen::InsensitiveStr::Ascii("alinise"),
        dictgen::InsensitiveStr::Ascii("alinised"),
        dictgen::InsensitiveStr::Ascii("alinises"),
        dictgen::InsensitiveStr::Ascii("alinising"),
        dictgen::InsensitiveStr::Ascii("alinization"),
        dictgen::InsensitiveStr::Ascii("alinizations"),
        dictgen::InsensitiveStr::Ascii("alinize"),
        dictgen::InsensitiveStr::Ascii("alinized"),
        dictgen::InsensitiveStr::Ascii("alinizes"),
        dictgen::InsensitiveStr::Ascii("alinizing"),
        dictgen::InsensitiveStr::Ascii("alisable"),
        dictgen::InsensitiveStr::Ascii("alisation"),
        dictgen::InsensitiveStr::Ascii("alisations"),
        dictgen::InsensitiveStr::Ascii("alise"),
        dictgen::InsensitiveStr::Ascii("alised"),
        dictgen::InsensitiveStr::Ascii("aliser"),
        dictgen::InsensitiveStr::Ascii("alises"),
        dictgen::InsensitiveStr::Ascii("alising"),
        dictgen::InsensitiveStr::Ascii("alizable"),
        dictgen::InsensitiveStr::Ascii("alization"),
        dictgen::InsensitiveStr::Ascii("alizations"),
        dictgen::InsensitiveStr::Ascii("alize"),
        dictgen::InsensitiveStr::Ascii("alized"),
        dictgen::InsensitiveStr::Ascii("alizer"),
        dictgen::InsensitiveStr::Ascii("alizes"),
        dictgen::InsensitiveStr::Ascii("alizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALKALINIZATION_8644837671846444891)],
        &[(0b10010, &ENTRY_ALKALINIZATIONS_2537063136327717146)],
        &[(0b10010, &ENTRY_ALKALINIZE_11019313678160087688)],
        &[(0b10010, &ENTRY_ALKALINIZED_13701976256938611329)],
        &[(0b10010, &ENTRY_ALKALINIZES_12313309629208791921)],
        &[(0b10010, &ENTRY_ALKALINIZING_4329175391998172496)],
        &[(0b01001, &ENTRY_ALKALINIZATION_8644837671846444891)],
        &[(0b01001, &ENTRY_ALKALINIZATIONS_2537063136327717146)],
        &[(0b01001, &ENTRY_ALKALINIZE_11019313678160087688)],
        &[(0b01001, &ENTRY_ALKALINIZED_13701976256938611329)],
        &[(0b01001, &ENTRY_ALKALINIZES_12313309629208791921)],
        &[(0b01001, &ENTRY_ALKALINIZING_4329175391998172496)],
        &[(0b10010, &ENTRY_ALKALIZABLE_11752711297106864279)],
        &[(0b10010, &ENTRY_ALKALIZATION_8215651930061013709)],
        &[(0b10010, &ENTRY_ALKALIZATIONS_1922502555535793567)],
        &[(0b10010, &ENTRY_ALKALIZE_5536262726734715214)],
        &[(0b10010, &ENTRY_ALKALIZED_13051886098360700675)],
        &[(0b10010, &ENTRY_ALKALIZER_6759136131876406609)],
        &[(0b10010, &ENTRY_ALKALIZES_13569450310007941622)],
        &[(0b10010, &ENTRY_ALKALIZING_8020169751754023745)],
        &[(0b01001, &ENTRY_ALKALIZABLE_11752711297106864279)],
        &[(0b01001, &ENTRY_ALKALIZATION_8215651930061013709)],
        &[(0b01001, &ENTRY_ALKALIZATIONS_1922502555535793567)],
        &[(0b01001, &ENTRY_ALKALIZE_5536262726734715214)],
        &[(0b01001, &ENTRY_ALKALIZED_13051886098360700675)],
        &[(0b01001, &ENTRY_ALKALIZER_6759136131876406609)],
        &[(0b01001, &ENTRY_ALKALIZES_13569450310007941622)],
        &[(0b01001, &ENTRY_ALKALIZING_8020169751754023745)],
    ],
    range: 5..=12,
};

static VARS_ALI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALI_CHILDREN),
    value: None,
};

pub static VARS_ALI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("enise"),
        dictgen::InsensitiveStr::Ascii("enises"),
        dictgen::InsensitiveStr::Ascii("enize"),
        dictgen::InsensitiveStr::Ascii("enizes"),
        dictgen::InsensitiveStr::Ascii("ne"),
        dictgen::InsensitiveStr::Ascii("ned"),
        dictgen::InsensitiveStr::Ascii("nement"),
        dictgen::InsensitiveStr::Ascii("nements"),
        dictgen::InsensitiveStr::Ascii("nes"),
        dictgen::InsensitiveStr::Ascii("ning"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALIENIZE_2375788601438381665)],
        &[(0b10010, &ENTRY_ALIENIZES_16619977169071842029)],
        &[(0b01001, &ENTRY_ALIENIZE_2375788601438381665)],
        &[(0b01001, &ENTRY_ALIENIZES_16619977169071842029)],
        &[(0b00001, &ENTRY_ALIGN_12031178495543818165)],
        &[(0b00001, &ENTRY_ALIGNED_12402894359661352325)],
        &[(0b00001, &ENTRY_ALIGNMENT_2011105833470144949)],
        &[(0b00001, &ENTRY_ALIGNMENTS_14673777835100591286)],
        &[(0b00001, &ENTRY_ALIGNS_7566776423028199708)],
        &[(0b00001, &ENTRY_ALIGNING_11699553166951544819)],
    ],
    range: 2..=7,
};

static VARS_ALG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALG_CHILDREN),
    value: None,
};

pub static VARS_ALG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesis"),
        dictgen::InsensitiveStr::Ascii("ebraisation"),
        dictgen::InsensitiveStr::Ascii("ebraisations"),
        dictgen::InsensitiveStr::Ascii("ebraise"),
        dictgen::InsensitiveStr::Ascii("ebraises"),
        dictgen::InsensitiveStr::Ascii("ebraization"),
        dictgen::InsensitiveStr::Ascii("ebraizations"),
        dictgen::InsensitiveStr::Ascii("ebraize"),
        dictgen::InsensitiveStr::Ascii("ebraizes"),
        dictgen::InsensitiveStr::Ascii("esthesis"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ALGESTHESIS_11669784295039335497)],
        &[(0b10010, &ENTRY_ALGEBRAIZATION_6100403580413387962)],
        &[(0b10010, &ENTRY_ALGEBRAIZATIONS_8499204281897687517)],
        &[(0b10010, &ENTRY_ALGEBRAIZE_3156432712023151827)],
        &[(0b10010, &ENTRY_ALGEBRAIZES_8779747351341505922)],
        &[(0b01001, &ENTRY_ALGEBRAIZATION_6100403580413387962)],
        &[(0b01001, &ENTRY_ALGEBRAIZATIONS_8499204281897687517)],
        &[(0b01001, &ENTRY_ALGEBRAIZE_3156432712023151827)],
        &[(0b01001, &ENTRY_ALGEBRAIZES_8779747351341505922)],
        &[(0b00001, &ENTRY_ALGESTHESIS_11669784295039335497)],
    ],
    range: 7..=12,
};

static VARS_ALE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALE_CHILDREN),
    value: None,
};

pub static VARS_ALE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ucaemic"),
        dictgen::InsensitiveStr::Ascii("ucemic"),
        dictgen::InsensitiveStr::Ascii("ukaemic"),
        dictgen::InsensitiveStr::Ascii("ukemic"),
        dictgen::InsensitiveStr::Ascii("us"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ALEUCEMIC_13145390844272291381)],
        &[(0b00001, &ENTRY_ALEUCEMIC_13145390844272291381)],
        &[(0b11010, &ENTRY_ALEUKEMIC_1675800078665474730)],
        &[(0b00001, &ENTRY_ALEUKEMIC_1675800078665474730)],
        &[(0b00001, &ENTRY_ALEUS_15999250050243856705)],
    ],
    range: 2..=7,
};

static VARS_ALC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALC_CHILDREN),
    value: None,
};

pub static VARS_ALC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("hemise"),
        dictgen::InsensitiveStr::Ascii("hemised"),
        dictgen::InsensitiveStr::Ascii("hemises"),
        dictgen::InsensitiveStr::Ascii("hemising"),
        dictgen::InsensitiveStr::Ascii("hemize"),
        dictgen::InsensitiveStr::Ascii("hemized"),
        dictgen::InsensitiveStr::Ascii("hemizes"),
        dictgen::InsensitiveStr::Ascii("hemizing"),
        dictgen::InsensitiveStr::Ascii("idae"),
        dictgen::InsensitiveStr::Ascii("ide"),
        dictgen::InsensitiveStr::Ascii("ithoae"),
        dictgen::InsensitiveStr::Ascii("ithoe"),
        dictgen::InsensitiveStr::Ascii("oholisable"),
        dictgen::InsensitiveStr::Ascii("oholisables"),
        dictgen::InsensitiveStr::Ascii("oholisation"),
        dictgen::InsensitiveStr::Ascii("oholisations"),
        dictgen::InsensitiveStr::Ascii("oholise"),
        dictgen::InsensitiveStr::Ascii("oholised"),
        dictgen::InsensitiveStr::Ascii("oholises"),
        dictgen::InsensitiveStr::Ascii("oholising"),
        dictgen::InsensitiveStr::Ascii("oholizable"),
        dictgen::InsensitiveStr::Ascii("oholizables"),
        dictgen::InsensitiveStr::Ascii("oholization"),
        dictgen::InsensitiveStr::Ascii("oholizations"),
        dictgen::InsensitiveStr::Ascii("oholize"),
        dictgen::InsensitiveStr::Ascii("oholized"),
        dictgen::InsensitiveStr::Ascii("oholizes"),
        dictgen::InsensitiveStr::Ascii("oholizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALCHEMIZE_5791832055645561888)],
        &[(0b10010, &ENTRY_ALCHEMIZED_8934414538470219345)],
        &[(0b10010, &ENTRY_ALCHEMIZES_6042589921854557418)],
        &[(0b10010, &ENTRY_ALCHEMIZING_12951450180936067566)],
        &[(0b01001, &ENTRY_ALCHEMIZE_5791832055645561888)],
        &[(0b01001, &ENTRY_ALCHEMIZED_8934414538470219345)],
        &[(0b01001, &ENTRY_ALCHEMIZES_6042589921854557418)],
        &[(0b01001, &ENTRY_ALCHEMIZING_12951450180936067566)],
        &[(0b11010, &ENTRY_ALCIDE_3165060712397761800)],
        &[(0b00001, &ENTRY_ALCIDE_3165060712397761800)],
        &[(0b11010, &ENTRY_ALCITHOE_1570391634240756603)],
        &[(0b00001, &ENTRY_ALCITHOE_1570391634240756603)],
        &[(0b10010, &ENTRY_ALCOHOLIZABLE_5712454359040751327)],
        &[(0b10010, &ENTRY_ALCOHOLIZABLES_787461776643349088)],
        &[(0b10010, &ENTRY_ALCOHOLIZATION_9324633993605207466)],
        &[(0b10010, &ENTRY_ALCOHOLIZATIONS_5826849890784377569)],
        &[(0b10010, &ENTRY_ALCOHOLIZE_7529158246880124791)],
        &[(0b10010, &ENTRY_ALCOHOLIZED_1088708612671476327)],
        &[(0b10010, &ENTRY_ALCOHOLIZES_155350708519960662)],
        &[(0b10010, &ENTRY_ALCOHOLIZING_9204884893125609497)],
        &[(0b01001, &ENTRY_ALCOHOLIZABLE_5712454359040751327)],
        &[(0b01001, &ENTRY_ALCOHOLIZABLES_787461776643349088)],
        &[(0b01001, &ENTRY_ALCOHOLIZATION_9324633993605207466)],
        &[(0b01001, &ENTRY_ALCOHOLIZATIONS_5826849890784377569)],
        &[(0b01001, &ENTRY_ALCOHOLIZE_7529158246880124791)],
        &[(0b01001, &ENTRY_ALCOHOLIZED_1088708612671476327)],
        &[(0b01001, &ENTRY_ALCOHOLIZES_155350708519960662)],
        &[(0b01001, &ENTRY_ALCOHOLIZING_9204884893125609497)],
    ],
    range: 3..=12,
};

static VARS_ALB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ALB_CHILDREN),
    value: None,
};

pub static VARS_ALB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("itise"),
        dictgen::InsensitiveStr::Ascii("itised"),
        dictgen::InsensitiveStr::Ascii("itises"),
        dictgen::InsensitiveStr::Ascii("itising"),
        dictgen::InsensitiveStr::Ascii("itize"),
        dictgen::InsensitiveStr::Ascii("itized"),
        dictgen::InsensitiveStr::Ascii("itizes"),
        dictgen::InsensitiveStr::Ascii("itizing"),
        dictgen::InsensitiveStr::Ascii("umeniser"),
        dictgen::InsensitiveStr::Ascii("umenization"),
        dictgen::InsensitiveStr::Ascii("umenizations"),
        dictgen::InsensitiveStr::Ascii("umenize"),
        dictgen::InsensitiveStr::Ascii("umenized"),
        dictgen::InsensitiveStr::Ascii("umenizer"),
        dictgen::InsensitiveStr::Ascii("umenizes"),
        dictgen::InsensitiveStr::Ascii("umenizing"),
        dictgen::InsensitiveStr::Ascii("uminisation"),
        dictgen::InsensitiveStr::Ascii("uminisations"),
        dictgen::InsensitiveStr::Ascii("uminise"),
        dictgen::InsensitiveStr::Ascii("uminised"),
        dictgen::InsensitiveStr::Ascii("uminises"),
        dictgen::InsensitiveStr::Ascii("uminising"),
        dictgen::InsensitiveStr::Ascii("uminization"),
        dictgen::InsensitiveStr::Ascii("uminizations"),
        dictgen::InsensitiveStr::Ascii("uminize"),
        dictgen::InsensitiveStr::Ascii("uminized"),
        dictgen::InsensitiveStr::Ascii("uminizes"),
        dictgen::InsensitiveStr::Ascii("uminizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ALBITIZE_10634446337478573748)],
        &[(0b10010, &ENTRY_ALBITIZED_5682763730263988051)],
        &[(0b10010, &ENTRY_ALBITIZES_8014501325445378157)],
        &[(0b10010, &ENTRY_ALBITIZING_13797609614113010011)],
        &[(0b01001, &ENTRY_ALBITIZE_10634446337478573748)],
        &[(0b01001, &ENTRY_ALBITIZED_5682763730263988051)],
        &[(0b01001, &ENTRY_ALBITIZES_8014501325445378157)],
        &[(0b01001, &ENTRY_ALBITIZING_13797609614113010011)],
        &[(0b10010, &ENTRY_ALBUMENIZER_59375995865224011)],
        &[(0b00001, &ENTRY_ALBUMENIZATION_3169676911273449215)],
        &[(0b00001, &ENTRY_ALBUMENIZATIONS_15542650325957452592)],
        &[(0b00001, &ENTRY_ALBUMENIZE_15336406098611814458)],
        &[(0b00001, &ENTRY_ALBUMENIZED_9044864672629997378)],
        &[(0b01001, &ENTRY_ALBUMENIZER_59375995865224011)],
        &[(0b00001, &ENTRY_ALBUMENIZES_2079965422881672979)],
        &[(0b00001, &ENTRY_ALBUMENIZING_16229928715193703812)],
        &[(0b10010, &ENTRY_ALBUMENIZATION_3169676911273449215)],
        &[(0b10010, &ENTRY_ALBUMENIZATIONS_15542650325957452592)],
        &[(0b10010, &ENTRY_ALBUMENIZE_15336406098611814458)],
        &[(0b10010, &ENTRY_ALBUMENIZED_9044864672629997378)],
        &[(0b10010, &ENTRY_ALBUMENIZES_2079965422881672979)],
        &[(0b10010, &ENTRY_ALBUMENIZING_16229928715193703812)],
        &[(0b01000, &ENTRY_ALBUMENIZATION_3169676911273449215)],
        &[(0b01000, &ENTRY_ALBUMENIZATIONS_15542650325957452592)],
        &[(0b01000, &ENTRY_ALBUMENIZE_15336406098611814458)],
        &[(0b01000, &ENTRY_ALBUMENIZED_9044864672629997378)],
        &[(0b01000, &ENTRY_ALBUMENIZES_2079965422881672979)],
        &[(0b01000, &ENTRY_ALBUMENIZING_16229928715193703812)],
    ],
    range: 5..=12,
};

static VARS_AK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AK_CHILDREN),
    value: None,
};

pub static VARS_AK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("re"),
        dictgen::InsensitiveStr::Ascii("tistetae"),
        dictgen::InsensitiveStr::Ascii("tistete"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AKER_7390977175698591709)],
        &[(0b11010, &ENTRY_AKER_7390977175698591709)],
        &[(0b11010, &ENTRY_AKTISTETE_9761990384859089931)],
        &[(0b00001, &ENTRY_AKTISTETE_9761990384859089931)],
    ],
    range: 2..=8,
};

static VARS_AI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AI_CHILDREN),
    value: None,
};

pub static VARS_AI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ger"),
        dictgen::InsensitiveStr::Ascii("gre"),
        dictgen::InsensitiveStr::Ascii("rfoil"),
        dictgen::InsensitiveStr::Ascii("rfoils"),
        dictgen::InsensitiveStr::Ascii("rgel"),
        dictgen::InsensitiveStr::Ascii("rplane"),
        dictgen::InsensitiveStr::Ascii("rplanes"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AIGER_3810072320924874026)],
        &[(0b11010, &ENTRY_AIGER_3810072320924874026)],
        &[(0b01001, &ENTRY_AIRFOIL_6251188039396016525)],
        &[(0b01001, &ENTRY_AIRFOILS_11117747260949333982)],
        &[(0b00001, &ENTRY_AIRGEL_9703257971421731594)],
        &[(0b11001, &ENTRY_AIRPLANE_8782402934308236857)],
        &[(0b11001, &ENTRY_AIRPLANES_10807576172790324268)],
    ],
    range: 3..=7,
};

static VARS_AG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AG_CHILDREN),
    value: None,
};

static VARS_AG_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_AGA_NODE),
    None,
    None,
    None,
    Some(&VARS_AGE_NODE),
    None,
    Some(&VARS_AGG_NODE),
    None,
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AGN_NODE),
    Some(&VARS_AGO_NODE),
    None,
    None,
    Some(&VARS_AGR_NODE),
    None,
    None,
    Some(&VARS_AGU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_AGU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGU_CHILDREN),
    value: None,
};

pub static VARS_AGU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGUIZE_11273323337042225528)],
        &[(0b10010, &ENTRY_AGUIZED_11146501883929771035)],
        &[(0b10010, &ENTRY_AGUIZES_3631645618729972992)],
        &[(0b10010, &ENTRY_AGUIZING_13415435362810054429)],
        &[(0b01001, &ENTRY_AGUIZE_11273323337042225528)],
        &[(0b01001, &ENTRY_AGUIZED_11146501883929771035)],
        &[(0b01001, &ENTRY_AGUIZES_3631645618729972992)],
        &[(0b01001, &ENTRY_AGUIZING_13415435362810054429)],
    ],
    range: 3..=5,
};

static VARS_AGR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGR_CHILDREN),
    value: None,
};

pub static VARS_AGR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("arianise"),
        dictgen::InsensitiveStr::Ascii("arianises"),
        dictgen::InsensitiveStr::Ascii("arianize"),
        dictgen::InsensitiveStr::Ascii("arianizes"),
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGRARIANIZE_6371637247712194397)],
        &[(0b10010, &ENTRY_AGRARIANIZES_6961780232175522640)],
        &[(0b01001, &ENTRY_AGRARIANIZE_6371637247712194397)],
        &[(0b01001, &ENTRY_AGRARIANIZES_6961780232175522640)],
        &[(0b11010, &ENTRY_AGER_10154545747728403667)],
        &[(0b10010, &ENTRY_AGRIZE_1296239263088830290)],
        &[(0b10010, &ENTRY_AGRIZED_5916161568343203612)],
        &[(0b10010, &ENTRY_AGRIZES_8679221560630105389)],
        &[(0b10010, &ENTRY_AGRIZING_15134245886550376210)],
        &[(0b01001, &ENTRY_AGRIZE_1296239263088830290)],
        &[(0b01001, &ENTRY_AGRIZED_5916161568343203612)],
        &[(0b01001, &ENTRY_AGRIZES_8679221560630105389)],
        &[(0b01001, &ENTRY_AGRIZING_15134245886550376210)],
    ],
    range: 1..=9,
};

static VARS_AGO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGO_CHILDREN),
    value: None,
};

pub static VARS_AGO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nised"),
        dictgen::InsensitiveStr::Ascii("nisedlies"),
        dictgen::InsensitiveStr::Ascii("nisedly"),
        dictgen::InsensitiveStr::Ascii("niser"),
        dictgen::InsensitiveStr::Ascii("nisers"),
        dictgen::InsensitiveStr::Ascii("nises"),
        dictgen::InsensitiveStr::Ascii("nising"),
        dictgen::InsensitiveStr::Ascii("nisinglier"),
        dictgen::InsensitiveStr::Ascii("nisingliest"),
        dictgen::InsensitiveStr::Ascii("nisingly"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("nized"),
        dictgen::InsensitiveStr::Ascii("nizedlies"),
        dictgen::InsensitiveStr::Ascii("nizedly"),
        dictgen::InsensitiveStr::Ascii("nizer"),
        dictgen::InsensitiveStr::Ascii("nizers"),
        dictgen::InsensitiveStr::Ascii("nizes"),
        dictgen::InsensitiveStr::Ascii("nizing"),
        dictgen::InsensitiveStr::Ascii("nizinglier"),
        dictgen::InsensitiveStr::Ascii("nizingliest"),
        dictgen::InsensitiveStr::Ascii("nizingly"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGONIZE_1178366636885440302)],
        &[(0b10010, &ENTRY_AGONIZED_8097803478456449055)],
        &[(0b10010, &ENTRY_AGONIZEDLIES_3178039635895059319)],
        &[(0b10010, &ENTRY_AGONIZEDLY_2195479848919207850)],
        &[(0b10010, &ENTRY_AGONIZER_17018191209891639507)],
        &[(0b10010, &ENTRY_AGONIZERS_12684640191692446391)],
        &[(0b10010, &ENTRY_AGONIZES_3115769157415966926)],
        &[(0b10010, &ENTRY_AGONIZING_1569032344642333561)],
        &[(0b10010, &ENTRY_AGONIZINGLIER_8898888445219953420)],
        &[(0b10010, &ENTRY_AGONIZINGLIEST_12888967969387776485)],
        &[(0b10010, &ENTRY_AGONIZINGLY_4863314422731006583)],
        &[(0b01001, &ENTRY_AGONIZE_1178366636885440302)],
        &[(0b01001, &ENTRY_AGONIZED_8097803478456449055)],
        &[(0b01001, &ENTRY_AGONIZEDLIES_3178039635895059319)],
        &[(0b01001, &ENTRY_AGONIZEDLY_2195479848919207850)],
        &[(0b01001, &ENTRY_AGONIZER_17018191209891639507)],
        &[(0b01001, &ENTRY_AGONIZERS_12684640191692446391)],
        &[(0b01001, &ENTRY_AGONIZES_3115769157415966926)],
        &[(0b01001, &ENTRY_AGONIZING_1569032344642333561)],
        &[(0b01001, &ENTRY_AGONIZINGLIER_8898888445219953420)],
        &[(0b01001, &ENTRY_AGONIZINGLIEST_12888967969387776485)],
        &[(0b01001, &ENTRY_AGONIZINGLY_4863314422731006583)],
    ],
    range: 4..=11,
};

static VARS_AGN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGN_CHILDREN),
    value: None,
};

pub static VARS_AGN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ise"),
        dictgen::InsensitiveStr::Ascii("ised"),
        dictgen::InsensitiveStr::Ascii("ises"),
        dictgen::InsensitiveStr::Ascii("ising"),
        dictgen::InsensitiveStr::Ascii("ize"),
        dictgen::InsensitiveStr::Ascii("ized"),
        dictgen::InsensitiveStr::Ascii("izes"),
        dictgen::InsensitiveStr::Ascii("izing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGNIZE_5083365122577693060)],
        &[(0b10010, &ENTRY_AGNIZED_9871346460164509669)],
        &[(0b10010, &ENTRY_AGNIZES_14381052475043058703)],
        &[(0b10010, &ENTRY_AGNIZING_312582546202684561)],
        &[(0b01001, &ENTRY_AGNIZE_5083365122577693060)],
        &[(0b01001, &ENTRY_AGNIZED_9871346460164509669)],
        &[(0b01001, &ENTRY_AGNIZES_14381052475043058703)],
        &[(0b01001, &ENTRY_AGNIZING_312582546202684561)],
    ],
    range: 3..=5,
};

static VARS_AGG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGG_CHILDREN),
    value: None,
};

pub static VARS_AGG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("randisable"),
        dictgen::InsensitiveStr::Ascii("randisables"),
        dictgen::InsensitiveStr::Ascii("randisation"),
        dictgen::InsensitiveStr::Ascii("randise"),
        dictgen::InsensitiveStr::Ascii("randised"),
        dictgen::InsensitiveStr::Ascii("randisement"),
        dictgen::InsensitiveStr::Ascii("randisements"),
        dictgen::InsensitiveStr::Ascii("randiser"),
        dictgen::InsensitiveStr::Ascii("randisers"),
        dictgen::InsensitiveStr::Ascii("randises"),
        dictgen::InsensitiveStr::Ascii("randising"),
        dictgen::InsensitiveStr::Ascii("randizable"),
        dictgen::InsensitiveStr::Ascii("randizables"),
        dictgen::InsensitiveStr::Ascii("randization"),
        dictgen::InsensitiveStr::Ascii("randize"),
        dictgen::InsensitiveStr::Ascii("randized"),
        dictgen::InsensitiveStr::Ascii("randizement"),
        dictgen::InsensitiveStr::Ascii("randizements"),
        dictgen::InsensitiveStr::Ascii("randizer"),
        dictgen::InsensitiveStr::Ascii("randizers"),
        dictgen::InsensitiveStr::Ascii("randizes"),
        dictgen::InsensitiveStr::Ascii("randizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGGRANDIZABLE_14295678675229969268)],
        &[(0b10010, &ENTRY_AGGRANDIZABLES_10156833661701900004)],
        &[(0b10010, &ENTRY_AGGRANDIZATION_1714468788436088442)],
        &[(0b10010, &ENTRY_AGGRANDIZE_708175043678043149)],
        &[(0b10010, &ENTRY_AGGRANDIZED_13651433120186758007)],
        &[(0b10010, &ENTRY_AGGRANDIZEMENT_16561527183094401215)],
        &[(0b10010, &ENTRY_AGGRANDIZEMENTS_13855550959345858286)],
        &[(0b10010, &ENTRY_AGGRANDIZER_8153478492362781998)],
        &[(0b10010, &ENTRY_AGGRANDIZERS_760901957715839582)],
        &[(0b10010, &ENTRY_AGGRANDIZES_15288429086103149165)],
        &[(0b10010, &ENTRY_AGGRANDIZING_15004603903858043564)],
        &[(0b01001, &ENTRY_AGGRANDIZABLE_14295678675229969268)],
        &[(0b01001, &ENTRY_AGGRANDIZABLES_10156833661701900004)],
        &[(0b01001, &ENTRY_AGGRANDIZATION_1714468788436088442)],
        &[(0b01001, &ENTRY_AGGRANDIZE_708175043678043149)],
        &[(0b01001, &ENTRY_AGGRANDIZED_13651433120186758007)],
        &[(0b01001, &ENTRY_AGGRANDIZEMENT_16561527183094401215)],
        &[(0b01001, &ENTRY_AGGRANDIZEMENTS_13855550959345858286)],
        &[(0b01001, &ENTRY_AGGRANDIZER_8153478492362781998)],
        &[(0b01001, &ENTRY_AGGRANDIZERS_760901957715839582)],
        &[(0b01001, &ENTRY_AGGRANDIZES_15288429086103149165)],
        &[(0b01001, &ENTRY_AGGRANDIZING_15004603903858043564)],
    ],
    range: 7..=12,
};

static VARS_AGE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGE_CHILDREN),
    value: None,
};

pub static VARS_AGE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nise"),
        dictgen::InsensitiveStr::Ascii("nize"),
        dictgen::InsensitiveStr::Ascii("r"),
    ],
    values: &[
        &[(0b10010, &ENTRY_AGENIZE_15273268881147024151)],
        &[(0b01001, &ENTRY_AGENIZE_15273268881147024151)],
        &[(0b00001, &ENTRY_AGER_10154545747728403667)],
    ],
    range: 1..=4,
};

static VARS_AGA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AGA_CHILDREN),
    value: None,
};

pub static VARS_AGA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("thodaemon"),
        dictgen::InsensitiveStr::Ascii("thodemon"),
        dictgen::InsensitiveStr::Ascii("tise"),
        dictgen::InsensitiveStr::Ascii("tises"),
        dictgen::InsensitiveStr::Ascii("tize"),
        dictgen::InsensitiveStr::Ascii("tizes"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AGATHODEMON_1771853124296768685)],
        &[(0b00001, &ENTRY_AGATHODEMON_1771853124296768685)],
        &[(0b10010, &ENTRY_AGATIZE_541023285637455463)],
        &[(0b10010, &ENTRY_AGATIZES_10204676816406829653)],
        &[(0b01001, &ENTRY_AGATIZE_541023285637455463)],
        &[(0b01001, &ENTRY_AGATIZES_10204676816406829653)],
    ],
    range: 4..=9,
};

static VARS_AF_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AF_CHILDREN),
    value: None,
};

pub static VARS_AF_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("feer"),
        dictgen::InsensitiveStr::Ascii("fere"),
        dictgen::InsensitiveStr::Ascii("ricanisation"),
        dictgen::InsensitiveStr::Ascii("ricanisations"),
        dictgen::InsensitiveStr::Ascii("ricanise"),
        dictgen::InsensitiveStr::Ascii("ricanised"),
        dictgen::InsensitiveStr::Ascii("ricanises"),
        dictgen::InsensitiveStr::Ascii("ricanising"),
        dictgen::InsensitiveStr::Ascii("ricanization"),
        dictgen::InsensitiveStr::Ascii("ricanizations"),
        dictgen::InsensitiveStr::Ascii("ricanize"),
        dictgen::InsensitiveStr::Ascii("ricanized"),
        dictgen::InsensitiveStr::Ascii("ricanizes"),
        dictgen::InsensitiveStr::Ascii("ricanizing"),
        dictgen::InsensitiveStr::Ascii("rikanerisation"),
        dictgen::InsensitiveStr::Ascii("rikanerise"),
        dictgen::InsensitiveStr::Ascii("rikanerised"),
        dictgen::InsensitiveStr::Ascii("rikanerises"),
        dictgen::InsensitiveStr::Ascii("rikanerising"),
        dictgen::InsensitiveStr::Ascii("rikanerization"),
        dictgen::InsensitiveStr::Ascii("rikanerize"),
        dictgen::InsensitiveStr::Ascii("rikanerized"),
        dictgen::InsensitiveStr::Ascii("rikanerizes"),
        dictgen::InsensitiveStr::Ascii("rikanerizing"),
        dictgen::InsensitiveStr::Ascii("terward"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AFFEER_4911847901267534123)],
        &[(0b11010, &ENTRY_AFFEER_4911847901267534123)],
        &[(0b10010, &ENTRY_AFRICANIZATION_8630277601343405336)],
        &[(0b10010, &ENTRY_AFRICANIZATIONS_15208317190739871380)],
        &[(0b10010, &ENTRY_AFRICANIZE_3531149313200349890)],
        &[(0b10010, &ENTRY_AFRICANIZED_1736896838594873888)],
        &[(0b10010, &ENTRY_AFRICANIZES_9591823452366186347)],
        &[(0b10010, &ENTRY_AFRICANIZING_3956855341391764965)],
        &[(0b01001, &ENTRY_AFRICANIZATION_8630277601343405336)],
        &[(0b01001, &ENTRY_AFRICANIZATIONS_15208317190739871380)],
        &[(0b01001, &ENTRY_AFRICANIZE_3531149313200349890)],
        &[(0b01001, &ENTRY_AFRICANIZED_1736896838594873888)],
        &[(0b01001, &ENTRY_AFRICANIZES_9591823452366186347)],
        &[(0b01001, &ENTRY_AFRICANIZING_3956855341391764965)],
        &[(0b10010, &ENTRY_AFRIKANERIZATION_7997032707492466163)],
        &[(0b10010, &ENTRY_AFRIKANERIZE_10253557183425033567)],
        &[(0b10010, &ENTRY_AFRIKANERIZED_7798629609213388411)],
        &[(0b10010, &ENTRY_AFRIKANERIZES_8717515483112090861)],
        &[(0b10010, &ENTRY_AFRIKANERIZING_601585902747830882)],
        &[(0b01001, &ENTRY_AFRIKANERIZATION_7997032707492466163)],
        &[(0b01001, &ENTRY_AFRIKANERIZE_10253557183425033567)],
        &[(0b01001, &ENTRY_AFRIKANERIZED_7798629609213388411)],
        &[(0b01001, &ENTRY_AFRIKANERIZES_8717515483112090861)],
        &[(0b01001, &ENTRY_AFRIKANERIZING_601585902747830882)],
        &[(0b01001, &ENTRY_AFTERWARDS_3336707444743528318)],
    ],
    range: 4..=14,
};

static VARS_AE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AE_CHILDREN),
    value: None,
};

static VARS_AE_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_AEA_NODE),
    None,
    Some(&VARS_AEC_NODE),
    Some(&VARS_AED_NODE),
    Some(&VARS_AEE_NODE),
    None,
    Some(&VARS_AEG_NODE),
    None,
    None,
    None,
    None,
    None,
    Some(&VARS_AEM_NODE),
    Some(&VARS_AEN_NODE),
    Some(&VARS_AEO_NODE),
    None,
    Some(&VARS_AEQ_NODE),
    Some(&VARS_AER_NODE),
    Some(&VARS_AES_NODE),
    Some(&VARS_AET_NODE),
    None,
    Some(&VARS_AEV_NODE),
    None,
    None,
    None,
    None,
];

static VARS_AEV_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEV_CHILDREN),
    value: None,
};

pub static VARS_AEV_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("iternal")],
    values: &[&[(0b11010, &ENTRY_EVITERNAL_11859651719653588022)]],
    range: 7..=7,
};

static VARS_AET_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AET_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_ET_11650800039480951541)]),
};

pub static VARS_AET_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("heling"),
        dictgen::InsensitiveStr::Ascii("hered"),
        dictgen::InsensitiveStr::Ascii("heric"),
        dictgen::InsensitiveStr::Ascii("iogenic"),
        dictgen::InsensitiveStr::Ascii("iologically"),
        dictgen::InsensitiveStr::Ascii("iologist"),
        dictgen::InsensitiveStr::Ascii("iologue"),
        dictgen::InsensitiveStr::Ascii("iology"),
        dictgen::InsensitiveStr::Ascii("iophyllin"),
        dictgen::InsensitiveStr::Ascii("iotropic"),
        dictgen::InsensitiveStr::Ascii("iotropically"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ETHELING_7453000440584654761)],
        &[(0b11010, &ENTRY_ETHERED_11737830389019716848)],
        &[(0b11010, &ENTRY_ETHERIC_14308840270744949246)],
        &[(0b11010, &ENTRY_ETIOGENIC_4607596180327733291)],
        &[(0b10010, &ENTRY_ETIOLOGICALLY_16961054798674884692)],
        &[(0b11010, &ENTRY_ETIOLOGIST_11212980661305626571)],
        &[(0b11010, &ENTRY_ETIOLOGUE_3427764260416926249)],
        &[(0b10010, &ENTRY_ETIOLOGY_7123968270032580321)],
        &[(0b11010, &ENTRY_ETIOPHYLLIN_9404514496968390932)],
        &[(0b11010, &ENTRY_ETIOTROPIC_17191333273430729692)],
        &[(0b11010, &ENTRY_ETIOTROPICALLY_9902369940420748380)],
    ],
    range: 5..=12,
};

static VARS_AES_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AES_CHILDREN),
    value: None,
};

pub static VARS_AES_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("c"),
        dictgen::InsensitiveStr::Ascii("chynite"),
        dictgen::InsensitiveStr::Ascii("culapian"),
        dictgen::InsensitiveStr::Ascii("culetin"),
        dictgen::InsensitiveStr::Ascii("culin"),
        dictgen::InsensitiveStr::Ascii("op"),
        dictgen::InsensitiveStr::Ascii("theses"),
        dictgen::InsensitiveStr::Ascii("thesia"),
        dictgen::InsensitiveStr::Ascii("thesias"),
        dictgen::InsensitiveStr::Ascii("thesiogen"),
        dictgen::InsensitiveStr::Ascii("thesiogenic"),
        dictgen::InsensitiveStr::Ascii("thesiogens"),
        dictgen::InsensitiveStr::Ascii("thesis"),
        dictgen::InsensitiveStr::Ascii("thetical"),
        dictgen::InsensitiveStr::Ascii("thetician"),
        dictgen::InsensitiveStr::Ascii("theticians"),
        dictgen::InsensitiveStr::Ascii("theticise"),
        dictgen::InsensitiveStr::Ascii("theticised"),
        dictgen::InsensitiveStr::Ascii("theticises"),
        dictgen::InsensitiveStr::Ascii("theticising"),
        dictgen::InsensitiveStr::Ascii("theticize"),
        dictgen::InsensitiveStr::Ascii("theticized"),
        dictgen::InsensitiveStr::Ascii("theticizes"),
        dictgen::InsensitiveStr::Ascii("theticizing"),
        dictgen::InsensitiveStr::Ascii("tivate"),
        dictgen::InsensitiveStr::Ascii("tivated"),
        dictgen::InsensitiveStr::Ascii("tivates"),
        dictgen::InsensitiveStr::Ascii("tivating"),
        dictgen::InsensitiveStr::Ascii("tivation"),
        dictgen::InsensitiveStr::Ascii("tivations"),
        dictgen::InsensitiveStr::Ascii("tivator"),
        dictgen::InsensitiveStr::Ascii("tive"),
        dictgen::InsensitiveStr::Ascii("tuate"),
        dictgen::InsensitiveStr::Ascii("tuous"),
        dictgen::InsensitiveStr::Ascii("ture"),
        dictgen::InsensitiveStr::Ascii("tus"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ESC_734356833349788703)],
        &[(0b11010, &ENTRY_ESCHYNITE_18313041144585925088)],
        &[(0b11010, &ENTRY_ESCULAPIAN_490183703265219666)],
        &[(0b11010, &ENTRY_ESCULETIN_4799035190382857787)],
        &[(0b11010, &ENTRY_ESCULIN_10740850830469064996)],
        &[(0b11010, &ENTRY_ESOP_13490095149926411543)],
        &[(0b11010, &ENTRY_ESTHESES_16116389526306967239)],
        &[(0b11010, &ENTRY_ESTHESIA_12451548753996008599)],
        &[(0b11010, &ENTRY_ESTHESIAS_5684600885047217053)],
        &[(0b11010, &ENTRY_ESTHESIOGEN_10989515066374267030)],
        &[(0b11010, &ENTRY_ESTHESIOGENIC_8056723690025617876)],
        &[(0b11010, &ENTRY_ESTHESIOGENS_8380315319153501054)],
        &[(0b11010, &ENTRY_ESTHESIS_7143001285276086388)],
        &[(0b11010, &ENTRY_ESTHETICAL_827198906307006506)],
        &[(0b11010, &ENTRY_ESTHETICIAN_4531333424171533067)],
        &[(0b11010, &ENTRY_ESTHETICIANS_4428473313020471578)],
        &[(0b10010, &ENTRY_AESTHETICIZE_2522964024252633997)],
        &[(0b10010, &ENTRY_AESTHETICIZED_15671920631201201295)],
        &[(0b10010, &ENTRY_AESTHETICIZES_11101104846362678924)],
        &[(0b10010, &ENTRY_AESTHETICIZING_12506567272891321736)],
        &[(0b01001, &ENTRY_AESTHETICIZE_2522964024252633997)],
        &[(0b01001, &ENTRY_AESTHETICIZED_15671920631201201295)],
        &[(0b01001, &ENTRY_AESTHETICIZES_11101104846362678924)],
        &[(0b01001, &ENTRY_AESTHETICIZING_12506567272891321736)],
        &[(0b11010, &ENTRY_ESTIVATE_6682485567558262552)],
        &[(0b11010, &ENTRY_ESTIVATED_17659059957305359175)],
        &[(0b11010, &ENTRY_ESTIVATES_15795900041274255113)],
        &[(0b11010, &ENTRY_ESTIVATING_3590628019702465357)],
        &[(0b11010, &ENTRY_ESTIVATION_970593505059854945)],
        &[(0b11010, &ENTRY_ESTIVATIONS_11925170250729275718)],
        &[(0b11010, &ENTRY_ESTIVATOR_17192827254089360161)],
        &[(0b11010, &ENTRY_ESTIVE_5420134362059951702)],
        &[(0b11010, &ENTRY_ESTUATE_7237204571723121927)],
        &[(0b11010, &ENTRY_ESTUOUS_15581034853542643799)],
        &[(0b11010, &ENTRY_ESTURE_3483676630062562550)],
        &[(0b11010, &ENTRY_ESTUS_10309034292162795617)],
    ],
    range: 1..=11,
};

static VARS_AER_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AER_CHILDREN),
    value: None,
};

pub static VARS_AER_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ialness"),
        dictgen::InsensitiveStr::Ascii("ic"),
        dictgen::InsensitiveStr::Ascii("ical"),
        dictgen::InsensitiveStr::Ascii("ofoil"),
        dictgen::InsensitiveStr::Ascii("ofoils"),
        dictgen::InsensitiveStr::Ascii("ogel"),
        dictgen::InsensitiveStr::Ascii("ogenesis"),
        dictgen::InsensitiveStr::Ascii("ogenic"),
        dictgen::InsensitiveStr::Ascii("ographer"),
        dictgen::InsensitiveStr::Ascii("ographic"),
        dictgen::InsensitiveStr::Ascii("ographical"),
        dictgen::InsensitiveStr::Ascii("ographies"),
        dictgen::InsensitiveStr::Ascii("ography"),
        dictgen::InsensitiveStr::Ascii("ologic"),
        dictgen::InsensitiveStr::Ascii("ological"),
        dictgen::InsensitiveStr::Ascii("ologies"),
        dictgen::InsensitiveStr::Ascii("ologist"),
        dictgen::InsensitiveStr::Ascii("ology"),
        dictgen::InsensitiveStr::Ascii("ometer"),
        dictgen::InsensitiveStr::Ascii("ometers"),
        dictgen::InsensitiveStr::Ascii("ometric"),
        dictgen::InsensitiveStr::Ascii("ope"),
        dictgen::InsensitiveStr::Ascii("oplane"),
        dictgen::InsensitiveStr::Ascii("oplanes"),
        dictgen::InsensitiveStr::Ascii("os"),
        dictgen::InsensitiveStr::Ascii("ose"),
        dictgen::InsensitiveStr::Ascii("uginous"),
        dictgen::InsensitiveStr::Ascii("ugo"),
        dictgen::InsensitiveStr::Ascii("ugos"),
    ],
    values: &[
        &[(0b00001, &ENTRY_AERIALNESS_16182249999029135790)],
        &[
            (0b00001, &ENTRY_AERIC_17437245564230021595),
            (0b11010, &ENTRY_ERIC_7184163800386574200),
        ],
        &[(0b11010, &ENTRY_ERICAL_12478419361229949219)],
        &[(0b10010, &ENTRY_AIRFOIL_6251188039396016525)],
        &[(0b10010, &ENTRY_AIRFOILS_11117747260949333982)],
        &[(0b11010, &ENTRY_AIRGEL_9703257971421731594)],
        &[(0b11010, &ENTRY_EROGENESIS_4465855575040947833)],
        &[(0b11010, &ENTRY_EROGENIC_3058184513432824304)],
        &[(0b00001, &ENTRY_AEROGRAPHER_10717546778729152195)],
        &[(0b00001, &ENTRY_AEROGRAPHIC_14818096080809523195)],
        &[(0b00001, &ENTRY_AEROGRAPHICAL_2429273948734988881)],
        &[(0b00001, &ENTRY_AEROGRAPHIES_11844593835635999782)],
        &[(0b00001, &ENTRY_AEROGRAPHY_8481321619438820366)],
        &[(0b00001, &ENTRY_AEROLOGIC_6581703267250668822)],
        &[(0b00001, &ENTRY_AEROLOGICAL_7035119647902064897)],
        &[(0b00001, &ENTRY_AEROLOGIES_9303474410588856691)],
        &[(0b00001, &ENTRY_AEROLOGIST_9043743609076361118)],
        &[(0b00001, &ENTRY_AEROLOGY_2536724281135360580)],
        &[(0b00001, &ENTRY_AEROMETER_11742833131164166928)],
        &[(0b00001, &ENTRY_AEROMETERS_18338221712051507310)],
        &[(0b00001, &ENTRY_AEROMETRIC_13993414140130418477)],
        &[(0b00001, &ENTRY_AEROPE_15996663583730344470)],
        &[(0b10010, &ENTRY_AIRPLANE_8782402934308236857)],
        &[(0b10010, &ENTRY_AIRPLANES_10807576172790324268)],
        &[(0b11010, &ENTRY_EROS_265509765297093167)],
        &[(0b11010, &ENTRY_EROSE_5357559857770402424)],
        &[(0b11010, &ENTRY_ERUGINOUS_5828853281772845437)],
        &[(0b11010, &ENTRY_ERUGO_17158132187061977414)],
        &[(0b11010, &ENTRY_ERUGOS_15673647349394448977)],
    ],
    range: 2..=10,
};

static VARS_AEQ_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEQ_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_EQ_17801056412005353118)]),
};

pub static VARS_AEQ_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_AEO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEO_CHILDREN),
    value: None,
};

pub static VARS_AEO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("lic"),
        dictgen::InsensitiveStr::Ascii("lipile"),
        dictgen::InsensitiveStr::Ascii("lipiles"),
        dictgen::InsensitiveStr::Ascii("lotropic"),
        dictgen::InsensitiveStr::Ascii("nian"),
        dictgen::InsensitiveStr::Ascii("nism"),
        dictgen::InsensitiveStr::Ascii("nisms"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EOLIC_690118974702284625)],
        &[(0b11010, &ENTRY_EOLIPILE_11849651097249565492)],
        &[(0b11010, &ENTRY_EOLIPILES_6469066293612545970)],
        &[(0b11010, &ENTRY_EOLOTROPIC_9928061474103766564)],
        &[(0b11010, &ENTRY_EONIAN_2585817843108266796)],
        &[(0b11010, &ENTRY_EONISM_12314541365765950888)],
        &[(0b11010, &ENTRY_EONISMS_13022437471464751142)],
    ],
    range: 3..=8,
};

static VARS_AEN_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEN_CHILDREN),
    value: None,
};

pub static VARS_AEN_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("eid")],
    values: &[&[(0b11010, &ENTRY_ENEID_5242893003172218406)]],
    range: 3..=3,
};

static VARS_AEM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEM_CHILDREN),
    value: None,
};

pub static VARS_AEM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ule"),
        dictgen::InsensitiveStr::Ascii("uled"),
        dictgen::InsensitiveStr::Ascii("ules"),
        dictgen::InsensitiveStr::Ascii("uling"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EMULE_1972234654623253784)],
        &[(0b11010, &ENTRY_EMULED_10357664319101512866)],
        &[(0b11010, &ENTRY_EMULES_6796003945794582963)],
        &[(0b11010, &ENTRY_EMULING_11304283679719960362)],
    ],
    range: 3..=5,
};

static VARS_AEG_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEG_CHILDREN),
    value: None,
};

pub static VARS_AEG_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("er"),
        dictgen::InsensitiveStr::Ascii("ilops"),
        dictgen::InsensitiveStr::Ascii("logue"),
        dictgen::InsensitiveStr::Ascii("ophony"),
        dictgen::InsensitiveStr::Ascii("ritude"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EGER_370209078151771517)],
        &[(0b11010, &ENTRY_EGILOPS_15304768767282746036)],
        &[(0b11010, &ENTRY_EGLOGUE_16104631981488511989)],
        &[(0b11010, &ENTRY_EGOPHONY_2012602110086773588)],
        &[(0b11010, &ENTRY_EGRITUDE_9946971293935803579)],
    ],
    range: 2..=6,
};

static VARS_AEE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEE_CHILDREN),
    value: None,
};

pub static VARS_AEE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("tes")],
    values: &[&[(0b00001, &ENTRY_AEETES_13066320965486982172)]],
    range: 3..=3,
};

static VARS_AED_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AED_CHILDREN),
    value: None,
};

pub static VARS_AED_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("icule"),
        dictgen::InsensitiveStr::Ascii("ility"),
        dictgen::InsensitiveStr::Ascii("on"),
    ],
    values: &[
        &[(0b11010, &ENTRY_EDICULE_10918770642841249439)],
        &[(0b11010, &ENTRY_EDILITY_10658105135103528164)],
        &[(0b00001, &ENTRY_AEDON_13423944760872171401)],
    ],
    range: 2..=5,
};

static VARS_AEC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEC_CHILDREN),
    value: Some(&[(0b11010, &ENTRY_EC_18369594411890017360)]),
};

pub static VARS_AEC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[],
    values: &[],
    range: 0..=0,
};

static VARS_AEA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AEA_CHILDREN),
    value: None,
};

pub static VARS_AEA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[dictgen::InsensitiveStr::Ascii("etes")],
    values: &[&[(0b11010, &ENTRY_AEETES_13066320965486982172)]],
    range: 4..=4,
};

static VARS_AD_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AD_CHILDREN),
    value: None,
};

pub static VARS_AD_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("onise"),
        dictgen::InsensitiveStr::Ascii("onised"),
        dictgen::InsensitiveStr::Ascii("onises"),
        dictgen::InsensitiveStr::Ascii("onising"),
        dictgen::InsensitiveStr::Ascii("onize"),
        dictgen::InsensitiveStr::Ascii("onized"),
        dictgen::InsensitiveStr::Ascii("onizes"),
        dictgen::InsensitiveStr::Ascii("onizing"),
        dictgen::InsensitiveStr::Ascii("ulterise"),
        dictgen::InsensitiveStr::Ascii("ulterised"),
        dictgen::InsensitiveStr::Ascii("ulterises"),
        dictgen::InsensitiveStr::Ascii("ulterising"),
        dictgen::InsensitiveStr::Ascii("ulterize"),
        dictgen::InsensitiveStr::Ascii("ulterized"),
        dictgen::InsensitiveStr::Ascii("ulterizes"),
        dictgen::InsensitiveStr::Ascii("ulterizing"),
        dictgen::InsensitiveStr::Ascii("venae"),
        dictgen::InsensitiveStr::Ascii("vene"),
        dictgen::InsensitiveStr::Ascii("verbialise"),
        dictgen::InsensitiveStr::Ascii("verbialised"),
        dictgen::InsensitiveStr::Ascii("verbialises"),
        dictgen::InsensitiveStr::Ascii("verbialising"),
        dictgen::InsensitiveStr::Ascii("verbialize"),
        dictgen::InsensitiveStr::Ascii("verbialized"),
        dictgen::InsensitiveStr::Ascii("verbializes"),
        dictgen::InsensitiveStr::Ascii("verbializing"),
        dictgen::InsensitiveStr::Ascii("vertisable"),
        dictgen::InsensitiveStr::Ascii("vertizable"),
        dictgen::InsensitiveStr::Ascii("vertize"),
        dictgen::InsensitiveStr::Ascii("vertized"),
        dictgen::InsensitiveStr::Ascii("vertizement"),
        dictgen::InsensitiveStr::Ascii("vertizements"),
        dictgen::InsensitiveStr::Ascii("vertizes"),
        dictgen::InsensitiveStr::Ascii("vertizing"),
        dictgen::InsensitiveStr::Ascii("z"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ADONIZE_9869544785563490952)],
        &[(0b10010, &ENTRY_ADONIZED_2235806445765610165)],
        &[(0b10010, &ENTRY_ADONIZES_12390820180008298287)],
        &[(0b10010, &ENTRY_ADONIZING_5588260356811603655)],
        &[(0b01001, &ENTRY_ADONIZE_9869544785563490952)],
        &[(0b01001, &ENTRY_ADONIZED_2235806445765610165)],
        &[(0b01001, &ENTRY_ADONIZES_12390820180008298287)],
        &[(0b01001, &ENTRY_ADONIZING_5588260356811603655)],
        &[(0b10010, &ENTRY_ADULTERIZE_4357377158717268989)],
        &[(0b10010, &ENTRY_ADULTERIZED_9727259542657623653)],
        &[(0b10010, &ENTRY_ADULTERIZES_8588447326790555058)],
        &[(0b10010, &ENTRY_ADULTERIZING_3717589244256498605)],
        &[(0b01001, &ENTRY_ADULTERIZE_4357377158717268989)],
        &[(0b01001, &ENTRY_ADULTERIZED_9727259542657623653)],
        &[(0b01001, &ENTRY_ADULTERIZES_8588447326790555058)],
        &[(0b01001, &ENTRY_ADULTERIZING_3717589244256498605)],
        &[(0b11010, &ENTRY_ADVENE_12688820738991001632)],
        &[(0b00001, &ENTRY_ADVENE_12688820738991001632)],
        &[(0b10010, &ENTRY_ADVERBIALIZE_2474916322327345748)],
        &[(0b10010, &ENTRY_ADVERBIALIZED_11573126518987347280)],
        &[(0b10010, &ENTRY_ADVERBIALIZES_5412565270521609710)],
        &[(0b10010, &ENTRY_ADVERBIALIZING_4313670731186707316)],
        &[(0b01001, &ENTRY_ADVERBIALIZE_2474916322327345748)],
        &[(0b01001, &ENTRY_ADVERBIALIZED_11573126518987347280)],
        &[(0b01001, &ENTRY_ADVERBIALIZES_5412565270521609710)],
        &[(0b01001, &ENTRY_ADVERBIALIZING_4313670731186707316)],
        &[(0b10010, &ENTRY_ADVERTIZABLE_5401609881263486182)],
        &[(0b01001, &ENTRY_ADVERTIZABLE_5401609881263486182)],
        &[(0b00001, &ENTRY_ADVERTISE_3306761264995947644)],
        &[(0b00001, &ENTRY_ADVERTISED_7933765869847731594)],
        &[(0b00001, &ENTRY_ADVERTISEMENT_16394932953244560183)],
        &[(0b00001, &ENTRY_ADVERTISEMENTS_17895556266113847062)],
        &[(0b00001, &ENTRY_ADVERTISES_3486027710577794712)],
        &[(0b00001, &ENTRY_ADVERTISING_11899923599707408720)],
        &[(0b00001, &ENTRY_ADZE_7687504085143207741)],
    ],
    range: 1..=12,
};

static VARS_AC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Nested(&VARS_AC_CHILDREN),
    value: None,
};

static VARS_AC_CHILDREN: [Option<&dictgen::DictTrieNode<&[(u8, &VariantsMap)]>>; 26] = [
    Some(&VARS_ACA_NODE),
    None,
    Some(&VARS_ACC_NODE),
    None,
    Some(&VARS_ACE_NODE),
    None,
    None,
    Some(&VARS_ACH_NODE),
    Some(&VARS_ACI_NODE),
    None,
    Some(&VARS_ACK_NODE),
    None,
    Some(&VARS_ACM_NODE),
    None,
    Some(&VARS_ACO_NODE),
    None,
    None,
    Some(&VARS_ACR_NODE),
    None,
    Some(&VARS_ACT_NODE),
    Some(&VARS_ACU_NODE),
    None,
    None,
    None,
    None,
    None,
];

static VARS_ACU_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACU_CHILDREN),
    value: None,
};

pub static VARS_ACU_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACUESTHESIA_12188708987996711429)],
        &[(0b00001, &ENTRY_ACUESTHESIA_12188708987996711429)],
    ],
    range: 8..=9,
};

static VARS_ACT_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACT_CHILDREN),
    value: None,
};

pub static VARS_ACT_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("ualisation"),
        dictgen::InsensitiveStr::Ascii("ualisations"),
        dictgen::InsensitiveStr::Ascii("ualise"),
        dictgen::InsensitiveStr::Ascii("ualised"),
        dictgen::InsensitiveStr::Ascii("ualises"),
        dictgen::InsensitiveStr::Ascii("ualising"),
        dictgen::InsensitiveStr::Ascii("ualization"),
        dictgen::InsensitiveStr::Ascii("ualizations"),
        dictgen::InsensitiveStr::Ascii("ualize"),
        dictgen::InsensitiveStr::Ascii("ualized"),
        dictgen::InsensitiveStr::Ascii("ualizes"),
        dictgen::InsensitiveStr::Ascii("ualizing"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ACTUALIZATION_10932469677827186244)],
        &[(0b10010, &ENTRY_ACTUALIZATIONS_12953081702088345443)],
        &[(0b10010, &ENTRY_ACTUALIZE_13650893073188599056)],
        &[(0b10010, &ENTRY_ACTUALIZED_18291562385674574688)],
        &[(0b10010, &ENTRY_ACTUALIZES_1551714425800475584)],
        &[(0b10010, &ENTRY_ACTUALIZING_4690007636134300688)],
        &[(0b01001, &ENTRY_ACTUALIZATION_10932469677827186244)],
        &[(0b01001, &ENTRY_ACTUALIZATIONS_12953081702088345443)],
        &[(0b01001, &ENTRY_ACTUALIZE_13650893073188599056)],
        &[(0b01001, &ENTRY_ACTUALIZED_18291562385674574688)],
        &[(0b01001, &ENTRY_ACTUALIZES_1551714425800475584)],
        &[(0b01001, &ENTRY_ACTUALIZING_4690007636134300688)],
    ],
    range: 6..=11,
};

static VARS_ACR_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACR_CHILDREN),
    value: None,
};

pub static VARS_ACR_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("e"),
        dictgen::InsensitiveStr::Ascii("oaesthesia"),
        dictgen::InsensitiveStr::Ascii("oanaesthesia"),
        dictgen::InsensitiveStr::Ascii("oanesthesia"),
        dictgen::InsensitiveStr::Ascii("oesthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACER_5343338374924634546)],
        &[(0b11010, &ENTRY_ACROESTHESIA_8308136510880851740)],
        &[(0b11010, &ENTRY_ACROANESTHESIA_106439738109694339)],
        &[(0b00001, &ENTRY_ACROANESTHESIA_106439738109694339)],
        &[(0b00001, &ENTRY_ACROESTHESIA_8308136510880851740)],
    ],
    range: 1..=12,
};

static VARS_ACO_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACO_CHILDREN),
    value: None,
};

pub static VARS_ACO_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("emetae"),
        dictgen::InsensitiveStr::Ascii("emetic"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACEMETAE_6749477089975884632)],
        &[(0b11010, &ENTRY_ACEMETIC_4282768793534979903)],
    ],
    range: 6..=6,
};

static VARS_ACM_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACM_CHILDREN),
    value: None,
};

pub static VARS_ACM_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aesthesia"),
        dictgen::InsensitiveStr::Ascii("esthesia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACMESTHESIA_7394645664517202151)],
        &[(0b00001, &ENTRY_ACMESTHESIA_7394645664517202151)],
    ],
    range: 8..=9,
};

static VARS_ACK_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACK_CHILDREN),
    value: None,
};

pub static VARS_ACK_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("nowledgment"),
        dictgen::InsensitiveStr::Ascii("nowledgments"),
    ],
    values: &[
        &[(0b01001, &ENTRY_ACKNOWLEDGMENT_15886905214207494222)],
        &[(0b01001, &ENTRY_ACKNOWLEDGMENTS_6498568084190984931)],
    ],
    range: 11..=12,
};

static VARS_ACI_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACI_CHILDREN),
    value: None,
};

pub static VARS_ACI_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("daemia"),
        dictgen::InsensitiveStr::Ascii("demia"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACIDEMIA_4441947562863004388)],
        &[(0b10001, &ENTRY_ACIDEMIA_4441947562863004388)],
    ],
    range: 5..=6,
};

static VARS_ACH_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACH_CHILDREN),
    value: None,
};

pub static VARS_ACH_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("aenia"),
        dictgen::InsensitiveStr::Ascii("aenium"),
        dictgen::InsensitiveStr::Ascii("aeniums"),
        dictgen::InsensitiveStr::Ascii("aenocarp"),
        dictgen::InsensitiveStr::Ascii("enia"),
        dictgen::InsensitiveStr::Ascii("enium"),
        dictgen::InsensitiveStr::Ascii("eniums"),
        dictgen::InsensitiveStr::Ascii("enocarp"),
        dictgen::InsensitiveStr::Ascii("roiocythaemia"),
        dictgen::InsensitiveStr::Ascii("roiocythemia"),
        dictgen::InsensitiveStr::Ascii("romatisation"),
        dictgen::InsensitiveStr::Ascii("romatisations"),
        dictgen::InsensitiveStr::Ascii("romatise"),
        dictgen::InsensitiveStr::Ascii("romatised"),
        dictgen::InsensitiveStr::Ascii("romatises"),
        dictgen::InsensitiveStr::Ascii("romatising"),
        dictgen::InsensitiveStr::Ascii("romatization"),
        dictgen::InsensitiveStr::Ascii("romatizations"),
        dictgen::InsensitiveStr::Ascii("romatize"),
        dictgen::InsensitiveStr::Ascii("romatized"),
        dictgen::InsensitiveStr::Ascii("romatizes"),
        dictgen::InsensitiveStr::Ascii("romatizing"),
    ],
    values: &[
        &[(0b11010, &ENTRY_ACHENIA_8478499188556204365)],
        &[(0b11010, &ENTRY_ACHENIUM_11897993706664093871)],
        &[(0b11010, &ENTRY_ACHENIUMS_13963140948852387190)],
        &[(0b11010, &ENTRY_ACHENOCARP_853831801713732483)],
        &[(0b10001, &ENTRY_ACHENIA_8478499188556204365)],
        &[(0b10001, &ENTRY_ACHENIUM_11897993706664093871)],
        &[(0b10001, &ENTRY_ACHENIUMS_13963140948852387190)],
        &[(0b10001, &ENTRY_ACHENOCARP_853831801713732483)],
        &[(0b11010, &ENTRY_ACHROIOCYTHEMIA_5792381842511219354)],
        &[(0b10001, &ENTRY_ACHROIOCYTHEMIA_5792381842511219354)],
        &[(0b10010, &ENTRY_ACHROMATIZATION_3261887351568242902)],
        &[(0b10010, &ENTRY_ACHROMATIZATIONS_17303571046130875052)],
        &[(0b10010, &ENTRY_ACHROMATIZE_11381534851343983212)],
        &[(0b10010, &ENTRY_ACHROMATIZED_10686154542806055086)],
        &[(0b10010, &ENTRY_ACHROMATIZES_12398014174188745620)],
        &[(0b10010, &ENTRY_ACHROMATIZING_8797256910702313821)],
        &[(0b01001, &ENTRY_ACHROMATIZATION_3261887351568242902)],
        &[(0b01001, &ENTRY_ACHROMATIZATIONS_17303571046130875052)],
        &[(0b01001, &ENTRY_ACHROMATIZE_11381534851343983212)],
        &[(0b01001, &ENTRY_ACHROMATIZED_10686154542806055086)],
        &[(0b01001, &ENTRY_ACHROMATIZES_12398014174188745620)],
        &[(0b01001, &ENTRY_ACHROMATIZING_8797256910702313821)],
    ],
    range: 4..=13,
};

static VARS_ACE_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACE_CHILDREN),
    value: None,
};

pub static VARS_ACE_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("metae"),
        dictgen::InsensitiveStr::Ascii("metic"),
        dictgen::InsensitiveStr::Ascii("r"),
        dictgen::InsensitiveStr::Ascii("tonaemia"),
        dictgen::InsensitiveStr::Ascii("tonaemic"),
        dictgen::InsensitiveStr::Ascii("tonemia"),
        dictgen::InsensitiveStr::Ascii("tonemic"),
    ],
    values: &[
        &[(0b10001, &ENTRY_ACEMETAE_6749477089975884632)],
        &[(0b10001, &ENTRY_ACEMETIC_4282768793534979903)],
        &[(0b00001, &ENTRY_ACER_5343338374924634546)],
        &[(0b11010, &ENTRY_ACETONEMIA_4459698585404045008)],
        &[(0b11010, &ENTRY_ACETONEMIC_3556838368325334069)],
        &[(0b10001, &ENTRY_ACETONEMIA_4459698585404045008)],
        &[(0b10001, &ENTRY_ACETONEMIC_3556838368325334069)],
    ],
    range: 1..=8,
};

static VARS_ACC_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACC_CHILDREN),
    value: None,
};

pub static VARS_ACC_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("essorise"),
        dictgen::InsensitiveStr::Ascii("essorised"),
        dictgen::InsensitiveStr::Ascii("essorises"),
        dictgen::InsensitiveStr::Ascii("essorising"),
        dictgen::InsensitiveStr::Ascii("essorize"),
        dictgen::InsensitiveStr::Ascii("essorized"),
        dictgen::InsensitiveStr::Ascii("essorizes"),
        dictgen::InsensitiveStr::Ascii("essorizing"),
        dictgen::InsensitiveStr::Ascii("limatisable"),
        dictgen::InsensitiveStr::Ascii("limatisation"),
        dictgen::InsensitiveStr::Ascii("limatise"),
        dictgen::InsensitiveStr::Ascii("limatised"),
        dictgen::InsensitiveStr::Ascii("limatiser"),
        dictgen::InsensitiveStr::Ascii("limatisers"),
        dictgen::InsensitiveStr::Ascii("limatises"),
        dictgen::InsensitiveStr::Ascii("limatising"),
        dictgen::InsensitiveStr::Ascii("limatizable"),
        dictgen::InsensitiveStr::Ascii("limatization"),
        dictgen::InsensitiveStr::Ascii("limatize"),
        dictgen::InsensitiveStr::Ascii("limatized"),
        dictgen::InsensitiveStr::Ascii("limatizer"),
        dictgen::InsensitiveStr::Ascii("limatizers"),
        dictgen::InsensitiveStr::Ascii("limatizes"),
        dictgen::InsensitiveStr::Ascii("limatizing"),
        dictgen::InsensitiveStr::Ascii("orage"),
        dictgen::InsensitiveStr::Ascii("oraged"),
        dictgen::InsensitiveStr::Ascii("orages"),
        dictgen::InsensitiveStr::Ascii("oraging"),
        dictgen::InsensitiveStr::Ascii("ourage"),
        dictgen::InsensitiveStr::Ascii("ouraged"),
        dictgen::InsensitiveStr::Ascii("ourages"),
        dictgen::InsensitiveStr::Ascii("ouraging"),
        dictgen::InsensitiveStr::Ascii("outer"),
        dictgen::InsensitiveStr::Ascii("outered"),
        dictgen::InsensitiveStr::Ascii("outering"),
        dictgen::InsensitiveStr::Ascii("outerment"),
        dictgen::InsensitiveStr::Ascii("outerments"),
        dictgen::InsensitiveStr::Ascii("outers"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ACCESSORIZE_3359544250876737878)],
        &[(0b10010, &ENTRY_ACCESSORIZED_1434587952006445874)],
        &[(0b10010, &ENTRY_ACCESSORIZES_15659000820256764933)],
        &[(0b10010, &ENTRY_ACCESSORIZING_1228113688984999234)],
        &[(0b01001, &ENTRY_ACCESSORIZE_3359544250876737878)],
        &[(0b01001, &ENTRY_ACCESSORIZED_1434587952006445874)],
        &[(0b01001, &ENTRY_ACCESSORIZES_15659000820256764933)],
        &[(0b01001, &ENTRY_ACCESSORIZING_1228113688984999234)],
        &[(0b10010, &ENTRY_ACCLIMATIZABLE_5975234751050111354)],
        &[(0b10010, &ENTRY_ACCLIMATIZATION_16603745532174886246)],
        &[(0b10010, &ENTRY_ACCLIMATIZE_5381021471129203780)],
        &[(0b10010, &ENTRY_ACCLIMATIZED_4642628968725123515)],
        &[(0b10010, &ENTRY_ACCLIMATIZER_3168716002029159117)],
        &[(0b10010, &ENTRY_ACCLIMATIZERS_12279845242555753697)],
        &[(0b10010, &ENTRY_ACCLIMATIZES_1207160639773800361)],
        &[(0b10010, &ENTRY_ACCLIMATIZING_3751997949097583159)],
        &[(0b01001, &ENTRY_ACCLIMATIZABLE_5975234751050111354)],
        &[(0b01001, &ENTRY_ACCLIMATIZATION_16603745532174886246)],
        &[(0b01001, &ENTRY_ACCLIMATIZE_5381021471129203780)],
        &[(0b01001, &ENTRY_ACCLIMATIZED_4642628968725123515)],
        &[(0b01001, &ENTRY_ACCLIMATIZER_3168716002029159117)],
        &[(0b01001, &ENTRY_ACCLIMATIZERS_12279845242555753697)],
        &[(0b01001, &ENTRY_ACCLIMATIZES_1207160639773800361)],
        &[(0b01001, &ENTRY_ACCLIMATIZING_3751997949097583159)],
        &[(0b00001, &ENTRY_ACCORAGE_4223546442621665298)],
        &[(0b00001, &ENTRY_ACCORAGED_14521717986957835986)],
        &[(0b00001, &ENTRY_ACCORAGES_9708962964447816459)],
        &[(0b00001, &ENTRY_ACCORAGING_15274251691846060767)],
        &[(0b11010, &ENTRY_ACCORAGE_4223546442621665298)],
        &[(0b11010, &ENTRY_ACCORAGED_14521717986957835986)],
        &[(0b11010, &ENTRY_ACCORAGES_9708962964447816459)],
        &[(0b11010, &ENTRY_ACCORAGING_15274251691846060767)],
        &[(0b00001, &ENTRY_ACCOUTER_17639188035801239900)],
        &[(0b00001, &ENTRY_ACCOUTERED_12457139511982164079)],
        &[(0b00001, &ENTRY_ACCOUTERING_11722729971237237966)],
        &[(0b00001, &ENTRY_ACCOUTERMENT_5633078260473567371)],
        &[(0b00001, &ENTRY_ACCOUTERMENTS_7782625256444191565)],
        &[(0b00001, &ENTRY_ACCOUTERS_7708387867770638479)],
    ],
    range: 5..=12,
};

static VARS_ACA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_ACA_CHILDREN),
    value: None,
};

pub static VARS_ACA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("demise"),
        dictgen::InsensitiveStr::Ascii("demised"),
        dictgen::InsensitiveStr::Ascii("demising"),
        dictgen::InsensitiveStr::Ascii("demize"),
        dictgen::InsensitiveStr::Ascii("demized"),
        dictgen::InsensitiveStr::Ascii("demizing"),
        dictgen::InsensitiveStr::Ascii("lephae"),
        dictgen::InsensitiveStr::Ascii("lephe"),
    ],
    values: &[
        &[(0b10010, &ENTRY_ACADEMIZE_744429990211461933)],
        &[(0b10010, &ENTRY_ACADEMIZED_12979046795383243853)],
        &[(0b10010, &ENTRY_ACADEMIZING_4383983952783387022)],
        &[(0b01001, &ENTRY_ACADEMIZE_744429990211461933)],
        &[(0b01001, &ENTRY_ACADEMIZED_12979046795383243853)],
        &[(0b01001, &ENTRY_ACADEMIZING_4383983952783387022)],
        &[(0b11010, &ENTRY_ACALEPHE_1796191466689570332)],
        &[(0b00001, &ENTRY_ACALEPHE_1796191466689570332)],
    ],
    range: 5..=8,
};

static VARS_AB_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AB_CHILDREN),
    value: None,
};

pub static VARS_AB_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("etter"),
        dictgen::InsensitiveStr::Ascii("etters"),
        dictgen::InsensitiveStr::Ascii("normalise"),
        dictgen::InsensitiveStr::Ascii("normalised"),
        dictgen::InsensitiveStr::Ascii("normalising"),
        dictgen::InsensitiveStr::Ascii("normalize"),
        dictgen::InsensitiveStr::Ascii("normalized"),
        dictgen::InsensitiveStr::Ascii("normalizing"),
        dictgen::InsensitiveStr::Ascii("olitionise"),
        dictgen::InsensitiveStr::Ascii("olitionised"),
        dictgen::InsensitiveStr::Ascii("olitionising"),
        dictgen::InsensitiveStr::Ascii("olitionize"),
        dictgen::InsensitiveStr::Ascii("olitionized"),
        dictgen::InsensitiveStr::Ascii("olitionizing"),
        dictgen::InsensitiveStr::Ascii("ridgement"),
        dictgen::InsensitiveStr::Ascii("ridgements"),
    ],
    values: &[
        &[(0b10011, &ENTRY_ABETTOR_7009618908225223897)],
        &[(0b10011, &ENTRY_ABETTORS_7043394254318611656)],
        &[(0b10010, &ENTRY_ABNORMALIZE_17439831460907058384)],
        &[(0b10010, &ENTRY_ABNORMALIZED_16673259772579712474)],
        &[(0b10010, &ENTRY_ABNORMALIZING_11364803739175296383)],
        &[(0b01001, &ENTRY_ABNORMALIZE_17439831460907058384)],
        &[(0b01001, &ENTRY_ABNORMALIZED_16673259772579712474)],
        &[(0b01001, &ENTRY_ABNORMALIZING_11364803739175296383)],
        &[(0b10010, &ENTRY_ABOLITIONIZE_13202486319737181929)],
        &[(0b10010, &ENTRY_ABOLITIONIZED_11758918826177421917)],
        &[(0b10010, &ENTRY_ABOLITIONIZING_6296954614763706120)],
        &[(0b01001, &ENTRY_ABOLITIONIZE_13202486319737181929)],
        &[(0b01001, &ENTRY_ABOLITIONIZED_11758918826177421917)],
        &[(0b01001, &ENTRY_ABOLITIONIZING_6296954614763706120)],
        &[(0b11010, &ENTRY_ABRIDGMENT_12609101589412407813)],
        &[(0b11010, &ENTRY_ABRIDGMENTS_5740240316470863413)],
    ],
    range: 5..=12,
};

static VARS_AA_NODE: dictgen::DictTrieNode<&[(u8, &VariantsMap)]> = dictgen::DictTrieNode {
    children: dictgen::DictTrieChild::Flat(&VARS_AA_CHILDREN),
    value: None,
};

pub static VARS_AA_CHILDREN: dictgen::DictTable<&[(u8, &VariantsMap)]> = dictgen::DictTable {
    keys: &[
        dictgen::InsensitiveStr::Ascii("edon"),
        dictgen::InsensitiveStr::Ascii("erialness"),
        dictgen::InsensitiveStr::Ascii("erope"),
    ],
    values: &[
        &[(0b11010, &ENTRY_AEDON_13423944760872171401)],
        &[(0b11010, &ENTRY_AERIALNESS_16182249999029135790)],
        &[(0b11010, &ENTRY_AEROPE_15996663583730344470)],
    ],
    range: 4..=9,
};

pub const NO_INVALID: bool = true;

pub(crate) static ENTRY_ABETTORS_7043394254318611656: VariantsMap =
    [&["abettors"], &["abetters"], &["abettors"], &["abetters"]];

pub(crate) static ENTRY_ABETTOR_7009618908225223897: VariantsMap =
    [&["abettor"], &["abetter"], &["abettor"], &["abetter"]];

pub(crate) static ENTRY_ABNORMALIZED_16673259772579712474: VariantsMap = [
    &["abnormalized"],
    &["abnormalised"],
    &["abnormalized"],
    &["abnormalised"],
];

pub(crate) static ENTRY_ABNORMALIZE_17439831460907058384: VariantsMap = [
    &["abnormalize"],
    &["abnormalise"],
    &["abnormalize"],
    &["abnormalise"],
];

pub(crate) static ENTRY_ABNORMALIZING_11364803739175296383: VariantsMap = [
    &["abnormalizing"],
    &["abnormalising"],
    &["abnormalizing"],
    &["abnormalising"],
];

pub(crate) static ENTRY_ABOLITIONIZED_11758918826177421917: VariantsMap = [
    &["abolitionized"],
    &["abolitionised"],
    &["abolitionized"],
    &["abolitionised"],
];

pub(crate) static ENTRY_ABOLITIONIZE_13202486319737181929: VariantsMap = [
    &["abolitionize"],
    &["abolitionise"],
    &["abolitionize"],
    &["abolitionise"],
];

pub(crate) static ENTRY_ABOLITIONIZING_6296954614763706120: VariantsMap = [
    &["abolitionizing"],
    &["abolitionising"],
    &["abolitionizing"],
    &["abolitionising"],
];

pub(crate) static ENTRY_ABRIDGMENTS_5740240316470863413: VariantsMap = [
    &["abridgments"],
    &["abridgements"],
    &["abridgements"],
    &["abridgements"],
];

pub(crate) static ENTRY_ABRIDGMENT_12609101589412407813: VariantsMap = [
    &["abridgment"],
    &["abridgement"],
    &["abridgement"],
    &["abridgement"],
];

pub(crate) static ENTRY_ACADEMIZED_12979046795383243853: VariantsMap = [
    &["academized"],
    &["academised"],
    &["academized"],
    &["academised"],
];

pub(crate) static ENTRY_ACADEMIZE_744429990211461933: VariantsMap = [
    &["academize"],
    &["academise"],
    &["academize"],
    &["academise"],
];

pub(crate) static ENTRY_ACADEMIZING_4383983952783387022: VariantsMap = [
    &["academizing"],
    &["academising"],
    &["academizing"],
    &["academising"],
];

pub(crate) static ENTRY_ACALEPHE_1796191466689570332: VariantsMap = [
    &["acalephe"],
    &["acalephae"],
    &["acalephae"],
    &["acalephae"],
];

pub(crate) static ENTRY_ACCESSORIZED_1434587952006445874: VariantsMap = [
    &["accessorized"],
    &["accessorised"],
    &["accessorized"],
    &["accessorised"],
];

pub(crate) static ENTRY_ACCESSORIZES_15659000820256764933: VariantsMap = [
    &["accessorizes"],
    &["accessorises"],
    &["accessorizes"],
    &["accessorises"],
];

pub(crate) static ENTRY_ACCESSORIZE_3359544250876737878: VariantsMap = [
    &["accessorize"],
    &["accessorise"],
    &["accessorize"],
    &["accessorise"],
];

pub(crate) static ENTRY_ACCESSORIZING_1228113688984999234: VariantsMap = [
    &["accessorizing"],
    &["accessorising"],
    &["accessorizing"],
    &["accessorising"],
];

pub(crate) static ENTRY_ACCLIMATIZABLE_5975234751050111354: VariantsMap = [
    &["acclimatizable"],
    &["acclimatisable"],
    &["acclimatizable"],
    &["acclimatisable"],
];

pub(crate) static ENTRY_ACCLIMATIZATION_16603745532174886246: VariantsMap = [
    &["acclimatization"],
    &["acclimatisation"],
    &["acclimatization"],
    &["acclimatisation"],
];

pub(crate) static ENTRY_ACCLIMATIZED_4642628968725123515: VariantsMap = [
    &["acclimatized"],
    &["acclimatised"],
    &["acclimatized"],
    &["acclimatised"],
];

pub(crate) static ENTRY_ACCLIMATIZERS_12279845242555753697: VariantsMap = [
    &["acclimatizers"],
    &["acclimatisers"],
    &["acclimatizers"],
    &["acclimatisers"],
];

pub(crate) static ENTRY_ACCLIMATIZER_3168716002029159117: VariantsMap = [
    &["acclimatizer"],
    &["acclimatiser"],
    &["acclimatizer"],
    &["acclimatiser"],
];

pub(crate) static ENTRY_ACCLIMATIZES_1207160639773800361: VariantsMap = [
    &["acclimatizes"],
    &["acclimatises"],
    &["acclimatizes"],
    &["acclimatises"],
];

pub(crate) static ENTRY_ACCLIMATIZE_5381021471129203780: VariantsMap = [
    &["acclimatize"],
    &["acclimatise"],
    &["acclimatize"],
    &["acclimatise"],
];

pub(crate) static ENTRY_ACCLIMATIZING_3751997949097583159: VariantsMap = [
    &["acclimatizing"],
    &["acclimatising"],
    &["acclimatizing"],
    &["acclimatising"],
];

pub(crate) static ENTRY_ACCORAGED_14521717986957835986: VariantsMap = [
    &["accoraged"],
    &["accouraged"],
    &["accouraged"],
    &["accouraged"],
];

pub(crate) static ENTRY_ACCORAGES_9708962964447816459: VariantsMap = [
    &["accorages"],
    &["accourages"],
    &["accourages"],
    &["accourages"],
];

pub(crate) static ENTRY_ACCORAGE_4223546442621665298: VariantsMap = [
    &["accorage"],
    &["accourage"],
    &["accourage"],
    &["accourage"],
];

pub(crate) static ENTRY_ACCORAGING_15274251691846060767: VariantsMap = [
    &["accoraging"],
    &["accouraging"],
    &["accouraging"],
    &["accouraging"],
];

pub(crate) static ENTRY_ACCOUTERED_12457139511982164079: VariantsMap = [
    &["accoutered"],
    &["accoutred"],
    &["accoutred"],
    &["accoutred"],
];

pub(crate) static ENTRY_ACCOUTERING_11722729971237237966: VariantsMap = [
    &["accoutering"],
    &["accoutring"],
    &["accoutring"],
    &["accoutring"],
];

pub(crate) static ENTRY_ACCOUTERMENTS_7782625256444191565: VariantsMap = [
    &["accouterments"],
    &["accoutrements"],
    &["accoutrements"],
    &["accoutrements"],
];

pub(crate) static ENTRY_ACCOUTERMENT_5633078260473567371: VariantsMap = [
    &["accouterment"],
    &["accoutrement"],
    &["accoutrement"],
    &["accoutrement"],
];

pub(crate) static ENTRY_ACCOUTERS_7708387867770638479: VariantsMap = [
    &["accouters"],
    &["accoutres"],
    &["accoutres"],
    &["accoutres"],
];

pub(crate) static ENTRY_ACCOUTER_17639188035801239900: VariantsMap =
    [&["accouter"], &["accoutre"], &["accoutre"], &["accoutre"]];

pub(crate) static ENTRY_ACEMETAE_6749477089975884632: VariantsMap = [
    &["acemetae"],
    &["acoemetae"],
    &["acoemetae"],
    &["acoemetae"],
];

pub(crate) static ENTRY_ACEMETIC_4282768793534979903: VariantsMap = [
    &["acemetic"],
    &["acoemetic"],
    &["acoemetic"],
    &["acoemetic"],
];

pub(crate) static ENTRY_ACER_5343338374924634546: VariantsMap =
    [&["acer"], &["acre"], &["acre"], &["acre"]];

pub(crate) static ENTRY_ACETONEMIA_4459698585404045008: VariantsMap = [
    &["acetonemia"],
    &["acetonaemia"],
    &["acetonaemia"],
    &["acetonaemia"],
];

pub(crate) static ENTRY_ACETONEMIC_3556838368325334069: VariantsMap = [
    &["acetonemic"],
    &["acetonaemic"],
    &["acetonaemic"],
    &["acetonaemic"],
];

pub(crate) static ENTRY_ACHENIA_8478499188556204365: VariantsMap =
    [&["achenia"], &["achaenia"], &["achaenia"], &["achaenia"]];

pub(crate) static ENTRY_ACHENIUMS_13963140948852387190: VariantsMap = [
    &["acheniums"],
    &["achaeniums"],
    &["achaeniums"],
    &["achaeniums"],
];

pub(crate) static ENTRY_ACHENIUM_11897993706664093871: VariantsMap = [
    &["achenium"],
    &["achaenium"],
    &["achaenium"],
    &["achaenium"],
];

pub(crate) static ENTRY_ACHENOCARP_853831801713732483: VariantsMap = [
    &["achenocarp"],
    &["achaenocarp"],
    &["achaenocarp"],
    &["achaenocarp"],
];

pub(crate) static ENTRY_ACHROIOCYTHEMIA_5792381842511219354: VariantsMap = [
    &["achroiocythemia"],
    &["achroiocythaemia"],
    &["achroiocythaemia"],
    &["achroiocythaemia"],
];

pub(crate) static ENTRY_ACHROMATIZATIONS_17303571046130875052: VariantsMap = [
    &["achromatizations"],
    &["achromatisations"],
    &["achromatizations"],
    &["achromatisations"],
];

pub(crate) static ENTRY_ACHROMATIZATION_3261887351568242902: VariantsMap = [
    &["achromatization"],
    &["achromatisation"],
    &["achromatization"],
    &["achromatisation"],
];

pub(crate) static ENTRY_ACHROMATIZED_10686154542806055086: VariantsMap = [
    &["achromatized"],
    &["achromatised"],
    &["achromatized"],
    &["achromatised"],
];

pub(crate) static ENTRY_ACHROMATIZES_12398014174188745620: VariantsMap = [
    &["achromatizes"],
    &["achromatises"],
    &["achromatizes"],
    &["achromatises"],
];

pub(crate) static ENTRY_ACHROMATIZE_11381534851343983212: VariantsMap = [
    &["achromatize"],
    &["achromatise"],
    &["achromatize"],
    &["achromatise"],
];

pub(crate) static ENTRY_ACHROMATIZING_8797256910702313821: VariantsMap = [
    &["achromatizing"],
    &["achromatising"],
    &["achromatizing"],
    &["achromatising"],
];

pub(crate) static ENTRY_ACIDEMIA_4441947562863004388: VariantsMap = [
    &["acidemia"],
    &["acidaemia"],
    &["acidaemia"],
    &["acidaemia"],
];

pub(crate) static ENTRY_ACKNOWLEDGMENTS_6498568084190984931: VariantsMap = [
    &["acknowledgments"],
    &["acknowledgements"],
    &["acknowledgements"],
    &["acknowledgements"],
];

pub(crate) static ENTRY_ACKNOWLEDGMENT_15886905214207494222: VariantsMap = [
    &["acknowledgment"],
    &["acknowledgement"],
    &["acknowledgement"],
    &["acknowledgement"],
];

pub(crate) static ENTRY_ACMESTHESIA_7394645664517202151: VariantsMap = [
    &["acmesthesia"],
    &["acmaesthesia"],
    &["acmaesthesia"],
    &["acmaesthesia"],
];

pub(crate) static ENTRY_ACROANESTHESIA_106439738109694339: VariantsMap = [
    &["acroanesthesia"],
    &["acroanaesthesia"],
    &["acroanaesthesia"],
    &["acroanaesthesia"],
];

pub(crate) static ENTRY_ACROESTHESIA_8308136510880851740: VariantsMap = [
    &["acroesthesia"],
    &["acroaesthesia"],
    &["acroaesthesia"],
    &["acroaesthesia"],
];

pub(crate) static ENTRY_ACTUALIZATIONS_12953081702088345443: VariantsMap = [
    &["actualizations"],
    &["actualisations"],
    &["actualizations"],
    &["actualisations"],
];

pub(crate) static ENTRY_ACTUALIZATION_10932469677827186244: VariantsMap = [
    &["actualization"],
    &["actualisation"],
    &["actualization"],
    &["actualisation"],
];

pub(crate) static ENTRY_ACTUALIZED_18291562385674574688: VariantsMap = [
    &["actualized"],
    &["actualised"],
    &["actualized"],
    &["actualised"],
];

pub(crate) static ENTRY_ACTUALIZES_1551714425800475584: VariantsMap = [
    &["actualizes"],
    &["actualises"],
    &["actualizes"],
    &["actualises"],
];

pub(crate) static ENTRY_ACTUALIZE_13650893073188599056: VariantsMap = [
    &["actualize"],
    &["actualise"],
    &["actualize"],
    &["actualise"],
];

pub(crate) static ENTRY_ACTUALIZING_4690007636134300688: VariantsMap = [
    &["actualizing"],
    &["actualising"],
    &["actualizing"],
    &["actualising"],
];

pub(crate) static ENTRY_ACUESTHESIA_12188708987996711429: VariantsMap = [
    &["acuesthesia"],
    &["acuaesthesia"],
    &["acuaesthesia"],
    &["acuaesthesia"],
];

pub(crate) static ENTRY_ADONIZED_2235806445765610165: VariantsMap =
    [&["adonized"], &["adonised"], &["adonized"], &["adonised"]];

pub(crate) static ENTRY_ADONIZES_12390820180008298287: VariantsMap =
    [&["adonizes"], &["adonises"], &["adonizes"], &["adonises"]];

pub(crate) static ENTRY_ADONIZE_9869544785563490952: VariantsMap =
    [&["adonize"], &["adonise"], &["adonize"], &["adonise"]];

pub(crate) static ENTRY_ADONIZING_5588260356811603655: VariantsMap = [
    &["adonizing"],
    &["adonising"],
    &["adonizing"],
    &["adonising"],
];

pub(crate) static ENTRY_ADULTERIZED_9727259542657623653: VariantsMap = [
    &["adulterized"],
    &["adulterised"],
    &["adulterized"],
    &["adulterised"],
];

pub(crate) static ENTRY_ADULTERIZES_8588447326790555058: VariantsMap = [
    &["adulterizes"],
    &["adulterises"],
    &["adulterizes"],
    &["adulterises"],
];

pub(crate) static ENTRY_ADULTERIZE_4357377158717268989: VariantsMap = [
    &["adulterize"],
    &["adulterise"],
    &["adulterize"],
    &["adulterise"],
];

pub(crate) static ENTRY_ADULTERIZING_3717589244256498605: VariantsMap = [
    &["adulterizing"],
    &["adulterising"],
    &["adulterizing"],
    &["adulterising"],
];

pub(crate) static ENTRY_ADVENE_12688820738991001632: VariantsMap =
    [&["advene"], &["advenae"], &["advenae"], &["advenae"]];

pub(crate) static ENTRY_ADVERBIALIZED_11573126518987347280: VariantsMap = [
    &["adverbialized"],
    &["adverbialised"],
    &["adverbialized"],
    &["adverbialised"],
];

pub(crate) static ENTRY_ADVERBIALIZES_5412565270521609710: VariantsMap = [
    &["adverbializes"],
    &["adverbialises"],
    &["adverbializes"],
    &["adverbialises"],
];

pub(crate) static ENTRY_ADVERBIALIZE_2474916322327345748: VariantsMap = [
    &["adverbialize"],
    &["adverbialise"],
    &["adverbialize"],
    &["adverbialise"],
];

pub(crate) static ENTRY_ADVERBIALIZING_4313670731186707316: VariantsMap = [
    &["adverbializing"],
    &["adverbialising"],
    &["adverbializing"],
    &["adverbialising"],
];

pub(crate) static ENTRY_ADVERTISED_7933765869847731594: VariantsMap = [
    &["advertised"],
    &["advertised"],
    &["advertised"],
    &["advertised"],
];

pub(crate) static ENTRY_ADVERTISEMENTS_17895556266113847062: VariantsMap = [
    &["advertisements"],
    &["advertisements"],
    &["advertisements"],
    &["advertisements"],
];

pub(crate) static ENTRY_ADVERTISEMENT_16394932953244560183: VariantsMap = [
    &["advertisement"],
    &["advertisement"],
    &["advertisement"],
    &["advertisement"],
];

pub(crate) static ENTRY_ADVERTISES_3486027710577794712: VariantsMap = [
    &["advertises"],
    &["advertises"],
    &["advertises"],
    &["advertises"],
];

pub(crate) static ENTRY_ADVERTISE_3306761264995947644: VariantsMap = [
    &["advertise"],
    &["advertise"],
    &["advertise"],
    &["advertise"],
];

pub(crate) static ENTRY_ADVERTISING_11899923599707408720: VariantsMap = [
    &["advertising"],
    &["advertising"],
    &["advertising"],
    &["advertising"],
];

pub(crate) static ENTRY_ADVERTIZABLE_5401609881263486182: VariantsMap = [
    &["advertizable"],
    &["advertisable"],
    &["advertizable"],
    &["advertisable"],
];

pub(crate) static ENTRY_ADZE_7687504085143207741: VariantsMap =
    [&["adze"], &["adze"], &["adze"], &["adze"]];

pub(crate) static ENTRY_AEDILES_7017631595752864436: VariantsMap =
    [&["aediles"], &["aediles"], &["aediles"], &["aediles"]];

pub(crate) static ENTRY_AEDILE_7817422603194149495: VariantsMap =
    [&["aedile"], &["aedile"], &["aedile"], &["aedile"]];

pub(crate) static ENTRY_AEDON_13423944760872171401: VariantsMap =
    [&["aedon"], &["aaedon"], &["aaedon"], &["aaedon"]];

pub(crate) static ENTRY_AEETES_13066320965486982172: VariantsMap =
    [&["aeetes"], &["aeaetes"], &["aeaetes"], &["aeaetes"]];

pub(crate) static ENTRY_AEGISES_17452084053545629669: VariantsMap =
    [&["aegises"], &["aegises"], &["aegises"], &["aegises"]];

pub(crate) static ENTRY_AEGIS_7746172769585303727: VariantsMap =
    [&["aegis"], &["aegis"], &["aegis"], &["aegis"]];

pub(crate) static ENTRY_AERIALNESS_16182249999029135790: VariantsMap = [
    &["aerialness"],
    &["aaerialness"],
    &["aaerialness"],
    &["aaerialness"],
];

pub(crate) static ENTRY_AERIC_17437245564230021595: VariantsMap =
    [&["aeric"], &["areic"], &["areic"], &["areic"]];

pub(crate) static ENTRY_AEROGRAPHER_10717546778729152195: VariantsMap = [
    &["aerographer"],
    &["areographer"],
    &["areographer"],
    &["areographer"],
];

pub(crate) static ENTRY_AEROGRAPHICAL_2429273948734988881: VariantsMap = [
    &["aerographical"],
    &["areographical"],
    &["areographical"],
    &["areographical"],
];

pub(crate) static ENTRY_AEROGRAPHIC_14818096080809523195: VariantsMap = [
    &["aerographic"],
    &["areographic"],
    &["areographic"],
    &["areographic"],
];

pub(crate) static ENTRY_AEROGRAPHIES_11844593835635999782: VariantsMap = [
    &["aerographies"],
    &["areographies"],
    &["areographies"],
    &["areographies"],
];

pub(crate) static ENTRY_AEROGRAPHY_8481321619438820366: VariantsMap = [
    &["aerography"],
    &["areography"],
    &["areography"],
    &["areography"],
];

pub(crate) static ENTRY_AEROLOGICAL_7035119647902064897: VariantsMap = [
    &["aerological"],
    &["areological"],
    &["areological"],
    &["areological"],
];

pub(crate) static ENTRY_AEROLOGIC_6581703267250668822: VariantsMap = [
    &["aerologic"],
    &["areologic"],
    &["areologic"],
    &["areologic"],
];

pub(crate) static ENTRY_AEROLOGIES_9303474410588856691: VariantsMap = [
    &["aerologies"],
    &["areologies"],
    &["areologies"],
    &["areologies"],
];

pub(crate) static ENTRY_AEROLOGIST_9043743609076361118: VariantsMap = [
    &["aerologist"],
    &["areologist"],
    &["areologist"],
    &["areologist"],
];

pub(crate) static ENTRY_AEROLOGY_2536724281135360580: VariantsMap =
    [&["aerology"], &["areology"], &["areology"], &["areology"]];

pub(crate) static ENTRY_AEROMETERS_18338221712051507310: VariantsMap = [
    &["aerometers"],
    &["areometers"],
    &["areometers"],
    &["areometers"],
];

pub(crate) static ENTRY_AEROMETER_11742833131164166928: VariantsMap = [
    &["aerometer"],
    &["areometer"],
    &["areometer"],
    &["areometer"],
];

pub(crate) static ENTRY_AEROMETRIC_13993414140130418477: VariantsMap = [
    &["aerometric"],
    &["areometric"],
    &["areometric"],
    &["areometric"],
];

pub(crate) static ENTRY_AEROPE_15996663583730344470: VariantsMap =
    [&["aerope"], &["aaerope"], &["aaerope"], &["aaerope"]];

pub(crate) static ENTRY_AESTHETES_9473189152352933863: VariantsMap = [
    &["aesthetes"],
    &["aesthetes"],
    &["aesthetes"],
    &["aesthetes"],
];

pub(crate) static ENTRY_AESTHETE_1223222359482085570: VariantsMap =
    [&["aesthete"], &["aesthete"], &["aesthete"], &["aesthete"]];

pub(crate) static ENTRY_AESTHETICALLY_17149093527344769493: VariantsMap = [
    &["aesthetically"],
    &["aesthetically"],
    &["aesthetically"],
    &["aesthetically"],
];

pub(crate) static ENTRY_AESTHETICIZED_15671920631201201295: VariantsMap = [
    &["aestheticized"],
    &["aestheticised"],
    &["aestheticized"],
    &["aestheticised"],
];

pub(crate) static ENTRY_AESTHETICIZES_11101104846362678924: VariantsMap = [
    &["aestheticizes"],
    &["aestheticises"],
    &["aestheticizes"],
    &["aestheticises"],
];

pub(crate) static ENTRY_AESTHETICIZE_2522964024252633997: VariantsMap = [
    &["aestheticize"],
    &["aestheticise"],
    &["aestheticize"],
    &["aestheticise"],
];

pub(crate) static ENTRY_AESTHETICIZING_12506567272891321736: VariantsMap = [
    &["aestheticizing"],
    &["aestheticising"],
    &["aestheticizing"],
    &["aestheticising"],
];

pub(crate) static ENTRY_AESTHETICS_9838605701252615431: VariantsMap = [
    &["aesthetics"],
    &["aesthetics"],
    &["aesthetics"],
    &["aesthetics"],
];

pub(crate) static ENTRY_AESTHETIC_854984485637846897: VariantsMap = [
    &["aesthetic"],
    &["aesthetic"],
    &["aesthetic"],
    &["aesthetic"],
];

pub(crate) static ENTRY_AFFEER_4911847901267534123: VariantsMap =
    [&["affeer"], &["affere"], &["affere"], &["affere"]];

pub(crate) static ENTRY_AFRICANIZATIONS_15208317190739871380: VariantsMap = [
    &["africanizations"],
    &["africanisations"],
    &["africanizations"],
    &["africanisations"],
];

pub(crate) static ENTRY_AFRICANIZATION_8630277601343405336: VariantsMap = [
    &["africanization"],
    &["africanisation"],
    &["africanization"],
    &["africanisation"],
];

pub(crate) static ENTRY_AFRICANIZED_1736896838594873888: VariantsMap = [
    &["africanized"],
    &["africanised"],
    &["africanized"],
    &["africanised"],
];

pub(crate) static ENTRY_AFRICANIZES_9591823452366186347: VariantsMap = [
    &["africanizes"],
    &["africanises"],
    &["africanizes"],
    &["africanises"],
];

pub(crate) static ENTRY_AFRICANIZE_3531149313200349890: VariantsMap = [
    &["africanize"],
    &["africanise"],
    &["africanize"],
    &["africanise"],
];

pub(crate) static ENTRY_AFRICANIZING_3956855341391764965: VariantsMap = [
    &["africanizing"],
    &["africanising"],
    &["africanizing"],
    &["africanising"],
];

pub(crate) static ENTRY_AFRIKANERIZATION_7997032707492466163: VariantsMap = [
    &["afrikanerization"],
    &["afrikanerisation"],
    &["afrikanerization"],
    &["afrikanerisation"],
];

pub(crate) static ENTRY_AFRIKANERIZED_7798629609213388411: VariantsMap = [
    &["afrikanerized"],
    &["afrikanerised"],
    &["afrikanerized"],
    &["afrikanerised"],
];

pub(crate) static ENTRY_AFRIKANERIZES_8717515483112090861: VariantsMap = [
    &["afrikanerizes"],
    &["afrikanerises"],
    &["afrikanerizes"],
    &["afrikanerises"],
];

pub(crate) static ENTRY_AFRIKANERIZE_10253557183425033567: VariantsMap = [
    &["afrikanerize"],
    &["afrikanerise"],
    &["afrikanerize"],
    &["afrikanerise"],
];

pub(crate) static ENTRY_AFRIKANERIZING_601585902747830882: VariantsMap = [
    &["afrikanerizing"],
    &["afrikanerising"],
    &["afrikanerizing"],
    &["afrikanerising"],
];

pub(crate) static ENTRY_AFTERWARDS_3336707444743528318: VariantsMap = [
    &["afterward", "afterwards"],
    &["afterwards"],
    &["afterwards"],
    &["afterwards"],
];

pub(crate) static ENTRY_AGATHODEMON_1771853124296768685: VariantsMap = [
    &["agathodemon"],
    &["agathodaemon"],
    &["agathodaemon"],
    &["agathodaemon"],
];

pub(crate) static ENTRY_AGATIZES_10204676816406829653: VariantsMap =
    [&["agatizes"], &["agatises"], &["agatizes"], &["agatises"]];

pub(crate) static ENTRY_AGATIZE_541023285637455463: VariantsMap =
    [&["agatize"], &["agatise"], &["agatize"], &["agatise"]];

pub(crate) static ENTRY_AGENIZE_15273268881147024151: VariantsMap =
    [&["agenize"], &["agenise"], &["agenize"], &["agenise"]];

pub(crate) static ENTRY_AGER_10154545747728403667: VariantsMap =
    [&["ager"], &["agre"], &["agre"], &["agre"]];

pub(crate) static ENTRY_AGGRANDIZABLES_10156833661701900004: VariantsMap = [
    &["aggrandizables"],
    &["aggrandisables"],
    &["aggrandizables"],
    &["aggrandisables"],
];

pub(crate) static ENTRY_AGGRANDIZABLE_14295678675229969268: VariantsMap = [
    &["aggrandizable"],
    &["aggrandisable"],
    &["aggrandizable"],
    &["aggrandisable"],
];

pub(crate) static ENTRY_AGGRANDIZATION_1714468788436088442: VariantsMap = [
    &["aggrandization"],
    &["aggrandisation"],
    &["aggrandization"],
    &["aggrandisation"],
];

pub(crate) static ENTRY_AGGRANDIZED_13651433120186758007: VariantsMap = [
    &["aggrandized"],
    &["aggrandised"],
    &["aggrandized"],
    &["aggrandised"],
];

pub(crate) static ENTRY_AGGRANDIZEMENTS_13855550959345858286: VariantsMap = [
    &["aggrandizements"],
    &["aggrandisements"],
    &["aggrandizements"],
    &["aggrandisements"],
];

pub(crate) static ENTRY_AGGRANDIZEMENT_16561527183094401215: VariantsMap = [
    &["aggrandizement"],
    &["aggrandisement"],
    &["aggrandizement"],
    &["aggrandisement"],
];

pub(crate) static ENTRY_AGGRANDIZERS_760901957715839582: VariantsMap = [
    &["aggrandizers"],
    &["aggrandisers"],
    &["aggrandizers"],
    &["aggrandisers"],
];

pub(crate) static ENTRY_AGGRANDIZER_8153478492362781998: VariantsMap = [
    &["aggrandizer"],
    &["aggrandiser"],
    &["aggrandizer"],
    &["aggrandiser"],
];

pub(crate) static ENTRY_AGGRANDIZES_15288429086103149165: VariantsMap = [
    &["aggrandizes"],
    &["aggrandises"],
    &["aggrandizes"],
    &["aggrandises"],
];

pub(crate) static ENTRY_AGGRANDIZE_708175043678043149: VariantsMap = [
    &["aggrandize"],
    &["aggrandise"],
    &["aggrandize"],
    &["aggrandise"],
];

pub(crate) static ENTRY_AGGRANDIZING_15004603903858043564: VariantsMap = [
    &["aggrandizing"],
    &["aggrandising"],
    &["aggrandizing"],
    &["aggrandising"],
];

pub(crate) static ENTRY_AGNIZED_9871346460164509669: VariantsMap =
    [&["agnized"], &["agnised"], &["agnized"], &["agnised"]];

pub(crate) static ENTRY_AGNIZES_14381052475043058703: VariantsMap =
    [&["agnizes"], &["agnises"], &["agnizes"], &["agnises"]];

pub(crate) static ENTRY_AGNIZE_5083365122577693060: VariantsMap =
    [&["agnize"], &["agnise"], &["agnize"], &["agnise"]];

pub(crate) static ENTRY_AGNIZING_312582546202684561: VariantsMap =
    [&["agnizing"], &["agnising"], &["agnizing"], &["agnising"]];

pub(crate) static ENTRY_AGONIZEDLIES_3178039635895059319: VariantsMap = [
    &["agonizedlies"],
    &["agonisedlies"],
    &["agonizedlies"],
    &["agonisedlies"],
];

pub(crate) static ENTRY_AGONIZEDLY_2195479848919207850: VariantsMap = [
    &["agonizedly"],
    &["agonisedly"],
    &["agonizedly"],
    &["agonisedly"],
];

pub(crate) static ENTRY_AGONIZED_8097803478456449055: VariantsMap =
    [&["agonized"], &["agonised"], &["agonized"], &["agonised"]];

pub(crate) static ENTRY_AGONIZERS_12684640191692446391: VariantsMap = [
    &["agonizers"],
    &["agonisers"],
    &["agonizers"],
    &["agonisers"],
];

pub(crate) static ENTRY_AGONIZER_17018191209891639507: VariantsMap =
    [&["agonizer"], &["agoniser"], &["agonizer"], &["agoniser"]];

pub(crate) static ENTRY_AGONIZES_3115769157415966926: VariantsMap =
    [&["agonizes"], &["agonises"], &["agonizes"], &["agonises"]];

pub(crate) static ENTRY_AGONIZE_1178366636885440302: VariantsMap =
    [&["agonize"], &["agonise"], &["agonize"], &["agonise"]];

pub(crate) static ENTRY_AGONIZINGLIER_8898888445219953420: VariantsMap = [
    &["agonizinglier"],
    &["agonisinglier"],
    &["agonizinglier"],
    &["agonisinglier"],
];

pub(crate) static ENTRY_AGONIZINGLIEST_12888967969387776485: VariantsMap = [
    &["agonizingliest"],
    &["agonisingliest"],
    &["agonizingliest"],
    &["agonisingliest"],
];

pub(crate) static ENTRY_AGONIZINGLY_4863314422731006583: VariantsMap = [
    &["agonizingly"],
    &["agonisingly"],
    &["agonizingly"],
    &["agonisingly"],
];

pub(crate) static ENTRY_AGONIZING_1569032344642333561: VariantsMap = [
    &["agonizing"],
    &["agonising"],
    &["agonizing"],
    &["agonising"],
];

pub(crate) static ENTRY_AGRARIANIZES_6961780232175522640: VariantsMap = [
    &["agrarianizes"],
    &["agrarianises"],
    &["agrarianizes"],
    &["agrarianises"],
];

pub(crate) static ENTRY_AGRARIANIZE_6371637247712194397: VariantsMap = [
    &["agrarianize"],
    &["agrarianise"],
    &["agrarianize"],
    &["agrarianise"],
];

pub(crate) static ENTRY_AGRIZED_5916161568343203612: VariantsMap =
    [&["agrized"], &["agrised"], &["agrized"], &["agrised"]];

pub(crate) static ENTRY_AGRIZES_8679221560630105389: VariantsMap =
    [&["agrizes"], &["agrises"], &["agrizes"], &["agrises"]];

pub(crate) static ENTRY_AGRIZE_1296239263088830290: VariantsMap =
    [&["agrize"], &["agrise"], &["agrize"], &["agrise"]];

pub(crate) static ENTRY_AGRIZING_15134245886550376210: VariantsMap =
    [&["agrizing"], &["agrising"], &["agrizing"], &["agrising"]];

pub(crate) static ENTRY_AGUIZED_11146501883929771035: VariantsMap =
    [&["aguized"], &["aguised"], &["aguized"], &["aguised"]];

pub(crate) static ENTRY_AGUIZES_3631645618729972992: VariantsMap =
    [&["aguizes"], &["aguises"], &["aguizes"], &["aguises"]];

pub(crate) static ENTRY_AGUIZE_11273323337042225528: VariantsMap =
    [&["aguize"], &["aguise"], &["aguize"], &["aguise"]];

pub(crate) static ENTRY_AGUIZING_13415435362810054429: VariantsMap =
    [&["aguizing"], &["aguising"], &["aguizing"], &["aguising"]];

pub(crate) static ENTRY_AIGER_3810072320924874026: VariantsMap =
    [&["aiger"], &["aigre"], &["aigre"], &["aigre"]];

pub(crate) static ENTRY_AIRFOILS_11117747260949333982: VariantsMap =
    [&["airfoils"], &["aerofoils"], &["airfoils"], &["aerofoils"]];

pub(crate) static ENTRY_AIRFOIL_6251188039396016525: VariantsMap =
    [&["airfoil"], &["aerofoil"], &["airfoil"], &["aerofoil"]];

pub(crate) static ENTRY_AIRGEL_9703257971421731594: VariantsMap =
    [&["airgel"], &["aerogel"], &["aerogel"], &["aerogel"]];

pub(crate) static ENTRY_AIRPLANES_10807576172790324268: VariantsMap = [
    &["airplanes"],
    &["aeroplanes"],
    &["airplanes"],
    &["aeroplanes"],
];

pub(crate) static ENTRY_AIRPLANE_8782402934308236857: VariantsMap =
    [&["airplane"], &["aeroplane"], &["airplane"], &["aeroplane"]];

pub(crate) static ENTRY_AKER_7390977175698591709: VariantsMap =
    [&["aker"], &["akre"], &["akre"], &["akre"]];

pub(crate) static ENTRY_AKTISTETE_9761990384859089931: VariantsMap = [
    &["aktistete"],
    &["aktistetae"],
    &["aktistetae"],
    &["aktistetae"],
];

pub(crate) static ENTRY_ALBITIZED_5682763730263988051: VariantsMap = [
    &["albitized"],
    &["albitised"],
    &["albitized"],
    &["albitised"],
];

pub(crate) static ENTRY_ALBITIZES_8014501325445378157: VariantsMap = [
    &["albitizes"],
    &["albitises"],
    &["albitizes"],
    &["albitises"],
];

pub(crate) static ENTRY_ALBITIZE_10634446337478573748: VariantsMap =
    [&["albitize"], &["albitise"], &["albitize"], &["albitise"]];

pub(crate) static ENTRY_ALBITIZING_13797609614113010011: VariantsMap = [
    &["albitizing"],
    &["albitising"],
    &["albitizing"],
    &["albitising"],
];

pub(crate) static ENTRY_ALBUMENIZATIONS_15542650325957452592: VariantsMap = [
    &["albumenizations"],
    &["albuminisations"],
    &["albuminizations"],
    &["albuminisations"],
];

pub(crate) static ENTRY_ALBUMENIZATION_3169676911273449215: VariantsMap = [
    &["albumenization"],
    &["albuminisation"],
    &["albuminization"],
    &["albuminisation"],
];

pub(crate) static ENTRY_ALBUMENIZED_9044864672629997378: VariantsMap = [
    &["albumenized"],
    &["albuminised"],
    &["albuminized"],
    &["albuminised"],
];

pub(crate) static ENTRY_ALBUMENIZER_59375995865224011: VariantsMap = [
    &["albumenizer"],
    &["albumeniser"],
    &["albumenizer"],
    &["albumeniser"],
];

pub(crate) static ENTRY_ALBUMENIZES_2079965422881672979: VariantsMap = [
    &["albumenizes"],
    &["albuminises"],
    &["albuminizes"],
    &["albuminises"],
];

pub(crate) static ENTRY_ALBUMENIZE_15336406098611814458: VariantsMap = [
    &["albumenize"],
    &["albuminise"],
    &["albuminize"],
    &["albuminise"],
];

pub(crate) static ENTRY_ALBUMENIZING_16229928715193703812: VariantsMap = [
    &["albumenizing"],
    &["albuminising"],
    &["albuminizing"],
    &["albuminising"],
];

pub(crate) static ENTRY_ALCHEMIZED_8934414538470219345: VariantsMap = [
    &["alchemized"],
    &["alchemised"],
    &["alchemized"],
    &["alchemised"],
];

pub(crate) static ENTRY_ALCHEMIZES_6042589921854557418: VariantsMap = [
    &["alchemizes"],
    &["alchemises"],
    &["alchemizes"],
    &["alchemises"],
];

pub(crate) static ENTRY_ALCHEMIZE_5791832055645561888: VariantsMap = [
    &["alchemize"],
    &["alchemise"],
    &["alchemize"],
    &["alchemise"],
];

pub(crate) static ENTRY_ALCHEMIZING_12951450180936067566: VariantsMap = [
    &["alchemizing"],
    &["alchemising"],
    &["alchemizing"],
    &["alchemising"],
];

pub(crate) static ENTRY_ALCIDE_3165060712397761800: VariantsMap =
    [&["alcide"], &["alcidae"], &["alcidae"], &["alcidae"]];

pub(crate) static ENTRY_ALCITHOE_1570391634240756603: VariantsMap = [
    &["alcithoe"],
    &["alcithoae"],
    &["alcithoae"],
    &["alcithoae"],
];

pub(crate) static ENTRY_ALCOHOLIZABLES_787461776643349088: VariantsMap = [
    &["alcoholizables"],
    &["alcoholisables"],
    &["alcoholizables"],
    &["alcoholisables"],
];

pub(crate) static ENTRY_ALCOHOLIZABLE_5712454359040751327: VariantsMap = [
    &["alcoholizable"],
    &["alcoholisable"],
    &["alcoholizable"],
    &["alcoholisable"],
];

pub(crate) static ENTRY_ALCOHOLIZATIONS_5826849890784377569: VariantsMap = [
    &["alcoholizations"],
    &["alcoholisations"],
    &["alcoholizations"],
    &["alcoholisations"],
];

pub(crate) static ENTRY_ALCOHOLIZATION_9324633993605207466: VariantsMap = [
    &["alcoholization"],
    &["alcoholisation"],
    &["alcoholization"],
    &["alcoholisation"],
];

pub(crate) static ENTRY_ALCOHOLIZED_1088708612671476327: VariantsMap = [
    &["alcoholized"],
    &["alcoholised"],
    &["alcoholized"],
    &["alcoholised"],
];

pub(crate) static ENTRY_ALCOHOLIZES_155350708519960662: VariantsMap = [
    &["alcoholizes"],
    &["alcoholises"],
    &["alcoholizes"],
    &["alcoholises"],
];

pub(crate) static ENTRY_ALCOHOLIZE_7529158246880124791: VariantsMap = [
    &["alcoholize"],
    &["alcoholise"],
    &["alcoholize"],
    &["alcoholise"],
];

pub(crate) static ENTRY_ALCOHOLIZING_9204884893125609497: VariantsMap = [
    &["alcoholizing"],
    &["alcoholising"],
    &["alcoholizing"],
    &["alcoholising"],
];

pub(crate) static ENTRY_ALEUCEMIC_13145390844272291381: VariantsMap = [
    &["aleucemic"],
    &["aleucaemic"],
    &["aleucaemic"],
    &["aleucaemic"],
];

pub(crate) static ENTRY_ALEUKEMIC_1675800078665474730: VariantsMap = [
    &["aleukemic"],
    &["aleukaemic"],
    &["aleukaemic"],
    &["aleukaemic"],
];

pub(crate) static ENTRY_ALEUS_15999250050243856705: VariantsMap =
    [&["aleus"], &["aloeus"], &["aloeus"], &["aloeus"]];

pub(crate) static ENTRY_ALGEBRAIZATIONS_8499204281897687517: VariantsMap = [
    &["algebraizations"],
    &["algebraisations"],
    &["algebraizations"],
    &["algebraisations"],
];

pub(crate) static ENTRY_ALGEBRAIZATION_6100403580413387962: VariantsMap = [
    &["algebraization"],
    &["algebraisation"],
    &["algebraization"],
    &["algebraisation"],
];

pub(crate) static ENTRY_ALGEBRAIZES_8779747351341505922: VariantsMap = [
    &["algebraizes"],
    &["algebraises"],
    &["algebraizes"],
    &["algebraises"],
];

pub(crate) static ENTRY_ALGEBRAIZE_3156432712023151827: VariantsMap = [
    &["algebraize"],
    &["algebraise"],
    &["algebraize"],
    &["algebraise"],
];

pub(crate) static ENTRY_ALGESTHESIS_11669784295039335497: VariantsMap = [
    &["algesthesis"],
    &["algaesthesis"],
    &["algaesthesis"],
    &["algaesthesis"],
];

pub(crate) static ENTRY_ALIENIZES_16619977169071842029: VariantsMap = [
    &["alienizes"],
    &["alienises"],
    &["alienizes"],
    &["alienises"],
];

pub(crate) static ENTRY_ALIENIZE_2375788601438381665: VariantsMap =
    [&["alienize"], &["alienise"], &["alienize"], &["alienise"]];

pub(crate) static ENTRY_ALIGNED_12402894359661352325: VariantsMap =
    [&["aligned"], &["aligned"], &["aligned"], &["aligned"]];

pub(crate) static ENTRY_ALIGNING_11699553166951544819: VariantsMap =
    [&["aligning"], &["aligning"], &["aligning"], &["aligning"]];

pub(crate) static ENTRY_ALIGNMENTS_14673777835100591286: VariantsMap = [
    &["alignments"],
    &["alignments"],
    &["alignments"],
    &["alignments"],
];

pub(crate) static ENTRY_ALIGNMENT_2011105833470144949: VariantsMap = [
    &["alignment"],
    &["alignment"],
    &["alignment"],
    &["alignment"],
];

pub(crate) static ENTRY_ALIGNS_7566776423028199708: VariantsMap =
    [&["aligns"], &["aligns"], &["aligns"], &["aligns"]];

pub(crate) static ENTRY_ALIGN_12031178495543818165: VariantsMap =
    [&["align"], &["align"], &["align"], &["align"]];

pub(crate) static ENTRY_ALKALINIZATIONS_2537063136327717146: VariantsMap = [
    &["alkalinizations"],
    &["alkalinisations"],
    &["alkalinizations"],
    &["alkalinisations"],
];

pub(crate) static ENTRY_ALKALINIZATION_8644837671846444891: VariantsMap = [
    &["alkalinization"],
    &["alkalinisation"],
    &["alkalinization"],
    &["alkalinisation"],
];

pub(crate) static ENTRY_ALKALINIZED_13701976256938611329: VariantsMap = [
    &["alkalinized"],
    &["alkalinised"],
    &["alkalinized"],
    &["alkalinised"],
];

pub(crate) static ENTRY_ALKALINIZES_12313309629208791921: VariantsMap = [
    &["alkalinizes"],
    &["alkalinises"],
    &["alkalinizes"],
    &["alkalinises"],
];

pub(crate) static ENTRY_ALKALINIZE_11019313678160087688: VariantsMap = [
    &["alkalinize"],
    &["alkalinise"],
    &["alkalinize"],
    &["alkalinise"],
];

pub(crate) static ENTRY_ALKALINIZING_4329175391998172496: VariantsMap = [
    &["alkalinizing"],
    &["alkalinising"],
    &["alkalinizing"],
    &["alkalinising"],
];

pub(crate) static ENTRY_ALKALIZABLE_11752711297106864279: VariantsMap = [
    &["alkalizable"],
    &["alkalisable"],
    &["alkalizable"],
    &["alkalisable"],
];

pub(crate) static ENTRY_ALKALIZATIONS_1922502555535793567: VariantsMap = [
    &["alkalizations"],
    &["alkalisations"],
    &["alkalizations"],
    &["alkalisations"],
];

pub(crate) static ENTRY_ALKALIZATION_8215651930061013709: VariantsMap = [
    &["alkalization"],
    &["alkalisation"],
    &["alkalization"],
    &["alkalisation"],
];

pub(crate) static ENTRY_ALKALIZED_13051886098360700675: VariantsMap = [
    &["alkalized"],
    &["alkalised"],
    &["alkalized"],
    &["alkalised"],
];

pub(crate) static ENTRY_ALKALIZER_6759136131876406609: VariantsMap = [
    &["alkalizer"],
    &["alkaliser"],
    &["alkalizer"],
    &["alkaliser"],
];

pub(crate) static ENTRY_ALKALIZES_13569450310007941622: VariantsMap = [
    &["alkalizes"],
    &["alkalises"],
    &["alkalizes"],
    &["alkalises"],
];

pub(crate) static ENTRY_ALKALIZE_5536262726734715214: VariantsMap =
    [&["alkalize"], &["alkalise"], &["alkalize"], &["alkalise"]];

pub(crate) static ENTRY_ALKALIZING_8020169751754023745: VariantsMap = [
    &["alkalizing"],
    &["alkalising"],
    &["alkalizing"],
    &["alkalising"],
];

pub(crate) static ENTRY_ALLEGORIZATIONS_1317829325279302497: VariantsMap = [
    &["allegorizations"],
    &["allegorisations"],
    &["allegorizations"],
    &["allegorisations"],
];

pub(crate) static ENTRY_ALLEGORIZATION_14762864111557060395: VariantsMap = [
    &["allegorization"],
    &["allegorisation"],
    &["allegorization"],
    &["allegorisation"],
];

pub(crate) static ENTRY_ALLEGORIZED_11740413629820898932: VariantsMap = [
    &["allegorized"],
    &["allegorised"],
    &["allegorized"],
    &["allegorised"],
];

pub(crate) static ENTRY_ALLEGORIZERS_114835122393079616: VariantsMap = [
    &["allegorizers"],
    &["allegorisers"],
    &["allegorizers"],
    &["allegorisers"],
];

pub(crate) static ENTRY_ALLEGORIZER_4274874326715631309: VariantsMap = [
    &["allegorizer"],
    &["allegoriser"],
    &["allegorizer"],
    &["allegoriser"],
];

pub(crate) static ENTRY_ALLEGORIZES_4178362701003728243: VariantsMap = [
    &["allegorizes"],
    &["allegorises"],
    &["allegorizes"],
    &["allegorises"],
];

pub(crate) static ENTRY_ALLEGORIZE_6482121904165219135: VariantsMap = [
    &["allegorize"],
    &["allegorise"],
    &["allegorize"],
    &["allegorise"],
];

pub(crate) static ENTRY_ALLEGORIZING_899303066346673273: VariantsMap = [
    &["allegorizing"],
    &["allegorising"],
    &["allegorizing"],
    &["allegorising"],
];

pub(crate) static ENTRY_ALLOXUREMIA_6517416850737377397: VariantsMap = [
    &["alloxuremia"],
    &["alloxuraemia"],
    &["alloxuraemia"],
    &["alloxuraemia"],
];

pub(crate) static ENTRY_ALMANACS_9267005522772569452: VariantsMap =
    [&["almanacs"], &["almanacs"], &["almanacs"], &["almanacs"]];

pub(crate) static ENTRY_ALMANAC_15717861359409582720: VariantsMap =
    [&["almanac"], &["almanac"], &["almanac"], &["almanac"]];

pub(crate) static ENTRY_ALPHABETIZATIONS_17047359931254284362: VariantsMap = [
    &["alphabetizations"],
    &["alphabetisations"],
    &["alphabetizations"],
    &["alphabetisations"],
];

pub(crate) static ENTRY_ALPHABETIZATION_16660905929935057642: VariantsMap = [
    &["alphabetization"],
    &["alphabetisation"],
    &["alphabetization"],
    &["alphabetisation"],
];

pub(crate) static ENTRY_ALPHABETIZED_1298633346805774272: VariantsMap = [
    &["alphabetized"],
    &["alphabetised"],
    &["alphabetized"],
    &["alphabetised"],
];

pub(crate) static ENTRY_ALPHABETIZERS_6296269536595041194: VariantsMap = [
    &["alphabetizers"],
    &["alphabetisers"],
    &["alphabetizers"],
    &["alphabetisers"],
];

pub(crate) static ENTRY_ALPHABETIZER_14767864421419944921: VariantsMap = [
    &["alphabetizer"],
    &["alphabetiser"],
    &["alphabetizer"],
    &["alphabetiser"],
];

pub(crate) static ENTRY_ALPHABETIZES_12175651960887303885: VariantsMap = [
    &["alphabetizes"],
    &["alphabetises"],
    &["alphabetizes"],
    &["alphabetises"],
];

pub(crate) static ENTRY_ALPHABETIZE_5185363765846869604: VariantsMap = [
    &["alphabetize"],
    &["alphabetise"],
    &["alphabetize"],
    &["alphabetise"],
];

pub(crate) static ENTRY_ALPHABETIZING_8059168115305559564: VariantsMap = [
    &["alphabetizing"],
    &["alphabetising"],
    &["alphabetizing"],
    &["alphabetising"],
];

pub(crate) static ENTRY_ALTERNIZES_9696050258020074609: VariantsMap = [
    &["alternizes"],
    &["alternises"],
    &["alternizes"],
    &["alternises"],
];

pub(crate) static ENTRY_ALTERNIZE_285767739893718525: VariantsMap = [
    &["alternize"],
    &["alternise"],
    &["alternize"],
    &["alternise"],
];

pub(crate) static ENTRY_ALTHEAS_841278574081921149: VariantsMap =
    [&["altheas"], &["althaeas"], &["althaeas"], &["althaeas"]];

pub(crate) static ENTRY_ALTHEA_11553591055146462879: VariantsMap =
    [&["althea"], &["althaea"], &["althaea"], &["althaea"]];

pub(crate) static ENTRY_ALTHEIN_11491174847546175682: VariantsMap =
    [&["althein"], &["althaein"], &["althaein"], &["althaein"]];

pub(crate) static ENTRY_ALTHOUGH_9541446420672118730: VariantsMap =
    [&["although"], &["although"], &["although"], &["although"]];

pub(crate) static ENTRY_ALUMINIZATION_18425035090862987036: VariantsMap = [
    &["aluminization"],
    &["aluminisation"],
    &["aluminization"],
    &["aluminisation"],
];

pub(crate) static ENTRY_ALUMINIZED_10495213790591424683: VariantsMap = [
    &["aluminized"],
    &["aluminised"],
    &["aluminized"],
    &["aluminised"],
];

pub(crate) static ENTRY_ALUMINIZES_13441975977760937538: VariantsMap = [
    &["aluminizes"],
    &["aluminises"],
    &["aluminizes"],
    &["aluminises"],
];

pub(crate) static ENTRY_ALUMINIZE_15056197197529932132: VariantsMap = [
    &["aluminize"],
    &["aluminise"],
    &["aluminize"],
    &["aluminise"],
];

pub(crate) static ENTRY_ALUMINIZING_12430331523650185895: VariantsMap = [
    &["aluminizing"],
    &["aluminising"],
    &["aluminizing"],
    &["aluminising"],
];

pub(crate) static ENTRY_ALUMINUMS_235477509529996640: VariantsMap = [
    &["aluminums"],
    &["aluminiums"],
    &["aluminums"],
    &["aluminiums"],
];

pub(crate) static ENTRY_ALUMINUM_12230548845456538965: VariantsMap =
    [&["aluminum"], &["aluminium"], &["aluminum"], &["aluminium"]];

pub(crate) static ENTRY_ALVEOLE_16490342143918785702: VariantsMap =
    [&["alveole"], &["alveolae"], &["alveolae"], &["alveolae"]];

pub(crate) static ENTRY_AMALGAMATIZES_11197265529776604273: VariantsMap = [
    &["amalgamatizes"],
    &["amalgamatises"],
    &["amalgamatizes"],
    &["amalgamatises"],
];

pub(crate) static ENTRY_AMALGAMATIZE_7375445972208185230: VariantsMap = [
    &["amalgamatize"],
    &["amalgamatise"],
    &["amalgamatize"],
    &["amalgamatise"],
];

pub(crate) static ENTRY_AMALGAMIZATIONS_11642266614868063418: VariantsMap = [
    &["amalgamizations"],
    &["amalgamisations"],
    &["amalgamizations"],
    &["amalgamisations"],
];

pub(crate) static ENTRY_AMALGAMIZATION_6873838956097053791: VariantsMap = [
    &["amalgamization"],
    &["amalgamisation"],
    &["amalgamization"],
    &["amalgamisation"],
];

pub(crate) static ENTRY_AMALGAMIZES_18246550602932639451: VariantsMap = [
    &["amalgamizes"],
    &["amalgamises"],
    &["amalgamizes"],
    &["amalgamises"],
];

pub(crate) static ENTRY_AMALGAMIZE_6774540532866713160: VariantsMap = [
    &["amalgamize"],
    &["amalgamise"],
    &["amalgamize"],
    &["amalgamise"],
];

pub(crate) static ENTRY_AMALTHEA_17903426763265878110: VariantsMap = [
    &["amalthea"],
    &["amalthaea"],
    &["amalthaea"],
    &["amalthaea"],
];

pub(crate) static ENTRY_AMBICOLORATE_6721589398342053523: VariantsMap = [
    &["ambicolorate"],
    &["ambicolourate"],
    &["ambicolourate"],
    &["ambicolourate"],
];

pub(crate) static ENTRY_AMBICOLORATION_14002894506100288246: VariantsMap = [
    &["ambicoloration"],
    &["ambicolouration"],
    &["ambicolouration"],
    &["ambicolouration"],
];

pub(crate) static ENTRY_AMBILEVOUS_16610037464217485655: VariantsMap = [
    &["ambilevous"],
    &["ambilaevous"],
    &["ambilaevous"],
    &["ambilaevous"],
];

pub(crate) static ENTRY_AMEBAN_5277068494503541064: VariantsMap =
    [&["ameban"], &["amoeban"], &["amoeban"], &["amoeban"]];

pub(crate) static ENTRY_AMEBEAN_1913759118822823378: VariantsMap =
    [&["amebean"], &["amoebean"], &["amoebean"], &["amoebean"]];

pub(crate) static ENTRY_AMEBIAN_4002663444157694529: VariantsMap =
    [&["amebian"], &["amoebian"], &["amoebian"], &["amoebian"]];

pub(crate) static ENTRY_AMEBIASES_11778219912968682475: VariantsMap = [
    &["amebiases"],
    &["amoebiases"],
    &["amoebiases"],
    &["amoebiases"],
];

pub(crate) static ENTRY_AMEBIASIS_6361517279962028009: VariantsMap = [
    &["amebiasis"],
    &["amoebiasis"],
    &["amoebiasis"],
    &["amoebiasis"],
];

pub(crate) static ENTRY_AMEBICIDAL_17077923016456623176: VariantsMap = [
    &["amebicidal"],
    &["amoebicidal"],
    &["amoebicidal"],
    &["amoebicidal"],
];

pub(crate) static ENTRY_AMEBICIDE_340489975023787457: VariantsMap = [
    &["amebicide"],
    &["amoebicide"],
    &["amoebicide"],
    &["amoebicide"],
];

pub(crate) static ENTRY_AMEBID_2070455756616987385: VariantsMap =
    [&["amebid"], &["amoebid"], &["amoebid"], &["amoebid"]];

pub(crate) static ENTRY_AMEBIFORM_7555597990047716880: VariantsMap = [
    &["amebiform"],
    &["amoebiform"],
    &["amoebiform"],
    &["amoebiform"],
];

pub(crate) static ENTRY_AMEBIOSIS_4936567060198771189: VariantsMap = [
    &["amebiosis"],
    &["amoebiosis"],
    &["amoebiosis"],
    &["amoebiosis"],
];

pub(crate) static ENTRY_AMEBOCYTES_6917539757967941181: VariantsMap = [
    &["amebocytes"],
    &["amoebocytes"],
    &["amoebocytes"],
    &["amoebocytes"],
];

pub(crate) static ENTRY_AMEBOCYTE_14677487577192167094: VariantsMap = [
    &["amebocyte"],
    &["amoebocyte"],
    &["amoebocyte"],
    &["amoebocyte"],
];

pub(crate) static ENTRY_AMEBOIDISM_6330017017844207166: VariantsMap = [
    &["ameboidism"],
    &["amoeboidism"],
    &["amoeboidism"],
    &["amoeboidism"],
];

pub(crate) static ENTRY_AMEBOUS_1006698274831009682: VariantsMap =
    [&["amebous"], &["amoebous"], &["amoebous"], &["amoebous"]];

pub(crate) static ENTRY_AMEBULA_11715705581331080902: VariantsMap =
    [&["amebula"], &["amoebula"], &["amoebula"], &["amoebula"]];

pub(crate) static ENTRY_AMENORRHEAL_12274073988422822411: VariantsMap = [
    &["amenorrheal"],
    &["amenorrhoeal"],
    &["amenorrheal"],
    &["amenorrhoeal"],
];

pub(crate) static ENTRY_AMENORRHEAS_3707756389439454986: VariantsMap = [
    &["amenorrheas"],
    &["amenorrhoeas"],
    &["amenorrheas"],
    &["amenorrhoeas"],
];

pub(crate) static ENTRY_AMENORRHEA_9430440773940411667: VariantsMap = [
    &["amenorrhea"],
    &["amenorrhoea"],
    &["amenorrhea"],
    &["amenorrhoea"],
];

pub(crate) static ENTRY_AMENORRHEIC_7520675613225846121: VariantsMap = [
    &["amenorrheic"],
    &["amenorrhoeic"],
    &["amenorrheic"],
    &["amenorrhoeic"],
];

pub(crate) static ENTRY_AMERICANIZATIONS_9566538544452946630: VariantsMap = [
    &["americanizations"],
    &["americanisations"],
    &["americanizations"],
    &["americanisations"],
];

pub(crate) static ENTRY_AMERICANIZATION_6309260318644804917: VariantsMap = [
    &["americanization"],
    &["americanisation"],
    &["americanization"],
    &["americanisation"],
];

pub(crate) static ENTRY_AMERICANIZED_1906052736648918553: VariantsMap = [
    &["americanized"],
    &["americanised"],
    &["americanized"],
    &["americanised"],
];

pub(crate) static ENTRY_AMERICANIZERS_7997596044566128128: VariantsMap = [
    &["americanizers"],
    &["americanisers"],
    &["americanizers"],
    &["americanisers"],
];

pub(crate) static ENTRY_AMERICANIZER_5573339924551090371: VariantsMap = [
    &["americanizer"],
    &["americaniser"],
    &["americanizer"],
    &["americaniser"],
];

pub(crate) static ENTRY_AMERICANIZES_1895797903602224728: VariantsMap = [
    &["americanizes"],
    &["americanises"],
    &["americanizes"],
    &["americanises"],
];

pub(crate) static ENTRY_AMERICANIZE_8636777715370127651: VariantsMap = [
    &["americanize"],
    &["americanise"],
    &["americanize"],
    &["americanise"],
];

pub(crate) static ENTRY_AMERICANIZING_15437774827264361694: VariantsMap = [
    &["americanizing"],
    &["americanising"],
    &["americanizing"],
    &["americanising"],
];

pub(crate) static ENTRY_AMMOCETES_15510029871033694789: VariantsMap = [
    &["ammocetes"],
    &["ammocoetes"],
    &["ammocoetes"],
    &["ammocoetes"],
];

pub(crate) static ENTRY_AMMOCETE_11149092949437835019: VariantsMap = [
    &["ammocete"],
    &["ammocoete"],
    &["ammocoete"],
    &["ammocoete"],
];

pub(crate) static ENTRY_AMMONIEMIA_12378710937857988312: VariantsMap = [
    &["ammoniemia"],
    &["ammoniaemia"],
    &["ammoniaemia"],
    &["ammoniaemia"],
];

pub(crate) static ENTRY_AMOEBAS_12713021889803788234: VariantsMap =
    [&["amoebas"], &["amoebas"], &["amoebas"], &["amoebas"]];

pub(crate) static ENTRY_AMOEBA_4495880425081872610: VariantsMap =
    [&["amoeba"], &["amoeba"], &["amoeba"], &["amoeba"]];

pub(crate) static ENTRY_AMOEBIC_8026378913624369514: VariantsMap =
    [&["amoebic"], &["amoebic"], &["amoebic"], &["amoebic"]];

pub(crate) static ENTRY_AMOEBOID_10813571979914678921: VariantsMap =
    [&["amoeboid"], &["amoeboid"], &["amoeboid"], &["amoeboid"]];

pub(crate) static ENTRY_AMORALIZES_3004553231540605930: VariantsMap = [
    &["amoralizes"],
    &["amoralises"],
    &["amoralizes"],
    &["amoralises"],
];

pub(crate) static ENTRY_AMORALIZE_437899974996323138: VariantsMap = [
    &["amoralize"],
    &["amoralise"],
    &["amoralize"],
    &["amoralise"],
];

pub(crate) static ENTRY_AMORET_11190930336071907365: VariantsMap =
    [&["amoret"], &["amouret"], &["amouret"], &["amouret"]];

pub(crate) static ENTRY_AMORISMS_8591683750858003331: VariantsMap = [
    &["amorisms"],
    &["amourisms"],
    &["amourisms"],
    &["amourisms"],
];

pub(crate) static ENTRY_AMORISM_13622053629400049439: VariantsMap =
    [&["amorism"], &["amourism"], &["amourism"], &["amourism"]];

pub(crate) static ENTRY_AMORISTICS_18339349616054530724: VariantsMap = [
    &["amoristics"],
    &["amouristics"],
    &["amouristics"],
    &["amouristics"],
];

pub(crate) static ENTRY_AMORISTIC_9227858452058548163: VariantsMap = [
    &["amoristic"],
    &["amouristic"],
    &["amouristic"],
    &["amouristic"],
];

pub(crate) static ENTRY_AMORISTS_6019660879632735851: VariantsMap = [
    &["amorists"],
    &["amourists"],
    &["amourists"],
    &["amourists"],
];

pub(crate) static ENTRY_AMORIST_15615749666067796835: VariantsMap =
    [&["amorist"], &["amourist"], &["amourist"], &["amourist"]];

pub(crate) static ENTRY_AMORPHIZATION_4718410488040839837: VariantsMap = [
    &["amorphization"],
    &["amorphisation"],
    &["amorphization"],
    &["amorphisation"],
];

pub(crate) static ENTRY_AMORPHIZE_15516090808530900584: VariantsMap = [
    &["amorphize"],
    &["amorphise"],
    &["amorphize"],
    &["amorphise"],
];

pub(crate) static ENTRY_AMORTIZABLER_8597378575585075865: VariantsMap = [
    &["amortizabler"],
    &["amortisabler"],
    &["amortizabler"],
    &["amortisabler"],
];

pub(crate) static ENTRY_AMORTIZABLEST_2628369391782893993: VariantsMap = [
    &["amortizablest"],
    &["amortisablest"],
    &["amortizablest"],
    &["amortisablest"],
];

pub(crate) static ENTRY_AMORTIZABLES_10949882004562997724: VariantsMap = [
    &["amortizables"],
    &["amortisables"],
    &["amortizables"],
    &["amortisables"],
];

pub(crate) static ENTRY_AMORTIZABLE_18025712452516364127: VariantsMap = [
    &["amortizable"],
    &["amortisable"],
    &["amortizable"],
    &["amortisable"],
];

pub(crate) static ENTRY_AMORTIZATIONS_10667746967250951820: VariantsMap = [
    &["amortizations"],
    &["amortisations"],
    &["amortizations"],
    &["amortisations"],
];

pub(crate) static ENTRY_AMORTIZATION_4181880901981206246: VariantsMap = [
    &["amortization"],
    &["amortisation"],
    &["amortization"],
    &["amortisation"],
];

pub(crate) static ENTRY_AMORTIZED_5774086997820266664: VariantsMap = [
    &["amortized"],
    &["amortised"],
    &["amortized"],
    &["amortised"],
];

pub(crate) static ENTRY_AMORTIZEMENTS_10400864127697785423: VariantsMap = [
    &["amortizements"],
    &["amortisements"],
    &["amortizements"],
    &["amortisements"],
];

pub(crate) static ENTRY_AMORTIZEMENT_12103927078743615024: VariantsMap = [
    &["amortizement"],
    &["amortisement"],
    &["amortizement"],
    &["amortisement"],
];

pub(crate) static ENTRY_AMORTIZES_18292533417191526171: VariantsMap = [
    &["amortizes"],
    &["amortises"],
    &["amortizes"],
    &["amortises"],
];

pub(crate) static ENTRY_AMORTIZE_14941813541869573228: VariantsMap =
    [&["amortize"], &["amortise"], &["amortize"], &["amortise"]];

pub(crate) static ENTRY_AMORTIZING_12733662438547175763: VariantsMap = [
    &["amortizing"],
    &["amortising"],
    &["amortizing"],
    &["amortising"],
];

pub(crate) static ENTRY_AMPHIGEAN_2635547525436752336: VariantsMap = [
    &["amphigean"],
    &["amphigaean"],
    &["amphigaean"],
    &["amphigaean"],
];

pub(crate) static ENTRY_AMPHITHEATERS_6166627403689463943: VariantsMap = [
    &["amphitheaters"],
    &["amphitheatres"],
    &["amphitheatres"],
    &["amphitheatres"],
];

pub(crate) static ENTRY_AMPHITHEATER_3688102909787113288: VariantsMap = [
    &["amphitheater"],
    &["amphitheatre"],
    &["amphitheatre"],
    &["amphitheatre"],
];

pub(crate) static ENTRY_AMYGDALE_9445312936529667739: VariantsMap = [
    &["amygdale"],
    &["amygdalae"],
    &["amygdalae"],
    &["amygdalae"],
];

pub(crate) static ENTRY_AMYXORRHEA_4253893643371161289: VariantsMap = [
    &["amyxorrhea"],
    &["amyxorrhoea"],
    &["amyxorrhoea"],
    &["amyxorrhoea"],
];

pub(crate) static ENTRY_ANABAPTIZED_10937015334598797503: VariantsMap = [
    &["anabaptized"],
    &["anabaptised"],
    &["anabaptized"],
    &["anabaptised"],
];

pub(crate) static ENTRY_ANABAPTIZES_5845461765970005402: VariantsMap = [
    &["anabaptizes"],
    &["anabaptises"],
    &["anabaptizes"],
    &["anabaptises"],
];

pub(crate) static ENTRY_ANABAPTIZE_2729267296806864066: VariantsMap = [
    &["anabaptize"],
    &["anabaptise"],
    &["anabaptize"],
    &["anabaptise"],
];

pub(crate) static ENTRY_ANABAPTIZING_3689660901707732301: VariantsMap = [
    &["anabaptizing"],
    &["anabaptising"],
    &["anabaptizing"],
    &["anabaptising"],
];

pub(crate) static ENTRY_ANAGRAMMATIZED_17231243584520853895: VariantsMap = [
    &["anagrammatized"],
    &["anagrammatised"],
    &["anagrammatized"],
    &["anagrammatised"],
];

pub(crate) static ENTRY_ANAGRAMMATIZES_13203766080338850548: VariantsMap = [
    &["anagrammatizes"],
    &["anagrammatises"],
    &["anagrammatizes"],
    &["anagrammatises"],
];

pub(crate) static ENTRY_ANAGRAMMATIZE_1294531725794717084: VariantsMap = [
    &["anagrammatize"],
    &["anagrammatise"],
    &["anagrammatize"],
    &["anagrammatise"],
];

pub(crate) static ENTRY_ANAGRAMMATIZING_7360812298529172732: VariantsMap = [
    &["anagrammatizing"],
    &["anagrammatising"],
    &["anagrammatizing"],
    &["anagrammatising"],
];

pub(crate) static ENTRY_ANALOGIZED_15332378387951220039: VariantsMap = [
    &["analogized"],
    &["analogised"],
    &["analogized"],
    &["analogised"],
];

pub(crate) static ENTRY_ANALOGIZES_2435391307518285611: VariantsMap = [
    &["analogizes"],
    &["analogises"],
    &["analogizes"],
    &["analogises"],
];

pub(crate) static ENTRY_ANALOGIZE_5536035389372667946: VariantsMap = [
    &["analogize"],
    &["analogise"],
    &["analogize"],
    &["analogise"],
];

pub(crate) static ENTRY_ANALOGIZING_5193184992170428572: VariantsMap = [
    &["analogizing"],
    &["analogising"],
    &["analogizing"],
    &["analogising"],
];

pub(crate) static ENTRY_ANALYZABILITY_1551141386065817504: VariantsMap = [
    &["analyzability"],
    &["analysability"],
    &["analyzability"],
    &["analysability"],
];

pub(crate) static ENTRY_ANALYZABLER_17997925440256942572: VariantsMap = [
    &["analyzabler"],
    &["analysabler"],
    &["analyzabler"],
    &["analysabler"],
];

pub(crate) static ENTRY_ANALYZABLEST_8874109193021320157: VariantsMap = [
    &["analyzablest"],
    &["analysablest"],
    &["analyzablest"],
    &["analysablest"],
];

pub(crate) static ENTRY_ANALYZABLE_617037050560332150: VariantsMap = [
    &["analyzable"],
    &["analysable"],
    &["analyzable"],
    &["analysable"],
];

pub(crate) static ENTRY_ANALYZATIONS_10325231710634833644: VariantsMap = [
    &["analyzations"],
    &["analysations"],
    &["analyzations"],
    &["analysations"],
];

pub(crate) static ENTRY_ANALYZATION_15073164819277453463: VariantsMap = [
    &["analyzation"],
    &["analysation"],
    &["analyzation"],
    &["analysation"],
];

pub(crate) static ENTRY_ANALYZED_3241611515791740784: VariantsMap =
    [&["analyzed"], &["analysed"], &["analyzed"], &["analysed"]];

pub(crate) static ENTRY_ANALYZERS_7884682095017825661: VariantsMap = [
    &["analyzers"],
    &["analysers"],
    &["analyzers"],
    &["analysers"],
];

pub(crate) static ENTRY_ANALYZER_13687050517411638821: VariantsMap =
    [&["analyzer"], &["analyser"], &["analyzer"], &["analyser"]];

pub(crate) static ENTRY_ANALYZES_13473182794044934522: VariantsMap =
    [&["analyzes"], &["analyses"], &["analyzes"], &["analyses"]];

pub(crate) static ENTRY_ANALYZE_13435707901024257028: VariantsMap =
    [&["analyze"], &["analyse"], &["analyze"], &["analyse"]];

pub(crate) static ENTRY_ANALYZING_17972193862022825096: VariantsMap = [
    &["analyzing"],
    &["analysing"],
    &["analyzing"],
    &["analysing"],
];

pub(crate) static ENTRY_ANAPESTICALLY_15963069963215922817: VariantsMap = [
    &["anapestically"],
    &["anapaestically"],
    &["anapaestically"],
    &["anapaestically"],
];

pub(crate) static ENTRY_ANAPNEIC_9824624761463965547: VariantsMap = [
    &["anapneic"],
    &["anapnoeic"],
    &["anapnoeic"],
    &["anapnoeic"],
];

pub(crate) static ENTRY_ANARCHIZED_13521160029536762262: VariantsMap = [
    &["anarchized"],
    &["anarchised"],
    &["anarchized"],
    &["anarchised"],
];

pub(crate) static ENTRY_ANARCHIZES_2426137200100120755: VariantsMap = [
    &["anarchizes"],
    &["anarchises"],
    &["anarchizes"],
    &["anarchises"],
];

pub(crate) static ENTRY_ANARCHIZE_16873413817474048843: VariantsMap = [
    &["anarchize"],
    &["anarchise"],
    &["anarchize"],
    &["anarchise"],
];

pub(crate) static ENTRY_ANARCHIZING_11629066219610630589: VariantsMap = [
    &["anarchizing"],
    &["anarchising"],
    &["anarchizing"],
    &["anarchising"],
];

pub(crate) static ENTRY_ANATHEMATIZATIONS_620207996168887075: VariantsMap = [
    &["anathematizations"],
    &["anathematisations"],
    &["anathematizations"],
    &["anathematisations"],
];

pub(crate) static ENTRY_ANATHEMATIZATION_15280298908583722308: VariantsMap = [
    &["anathematization"],
    &["anathematisation"],
    &["anathematization"],
    &["anathematisation"],
];

pub(crate) static ENTRY_ANATHEMATIZED_3874188261925704186: VariantsMap = [
    &["anathematized"],
    &["anathematised"],
    &["anathematized"],
    &["anathematised"],
];

pub(crate) static ENTRY_ANATHEMATIZER_3378013434055917757: VariantsMap = [
    &["anathematizer"],
    &["anathematiser"],
    &["anathematizer"],
    &["anathematiser"],
];

pub(crate) static ENTRY_ANATHEMATIZES_8973479734940337633: VariantsMap = [
    &["anathematizes"],
    &["anathematises"],
    &["anathematizes"],
    &["anathematises"],
];

pub(crate) static ENTRY_ANATHEMATIZE_9250331648604756093: VariantsMap = [
    &["anathematize"],
    &["anathematise"],
    &["anathematize"],
    &["anathematise"],
];

pub(crate) static ENTRY_ANATHEMATIZING_10299965854697438675: VariantsMap = [
    &["anathematizing"],
    &["anathematising"],
    &["anathematizing"],
    &["anathematising"],
];

pub(crate) static ENTRY_ANATOMIZABLE_6218592416722946394: VariantsMap = [
    &["anatomizable"],
    &["anatomisable"],
    &["anatomizable"],
    &["anatomisable"],
];

pub(crate) static ENTRY_ANATOMIZATION_4269547902777954197: VariantsMap = [
    &["anatomization"],
    &["anatomisation"],
    &["anatomization"],
    &["anatomisation"],
];

pub(crate) static ENTRY_ANATOMIZED_862561253191916873: VariantsMap = [
    &["anatomized"],
    &["anatomised"],
    &["anatomized"],
    &["anatomised"],
];

pub(crate) static ENTRY_ANATOMIZER_10181303822973702398: VariantsMap = [
    &["anatomizer"],
    &["anatomiser"],
    &["anatomizer"],
    &["anatomiser"],
];

pub(crate) static ENTRY_ANATOMIZES_6453710897733584587: VariantsMap = [
    &["anatomizes"],
    &["anatomises"],
    &["anatomizes"],
    &["anatomises"],
];

pub(crate) static ENTRY_ANATOMIZE_841129889860317661: VariantsMap = [
    &["anatomize"],
    &["anatomise"],
    &["anatomize"],
    &["anatomise"],
];

pub(crate) static ENTRY_ANATOMIZING_14431856406330078710: VariantsMap = [
    &["anatomizing"],
    &["anatomising"],
    &["anatomizing"],
    &["anatomising"],
];

pub(crate) static ENTRY_ANCHINOE_163304748892282636: VariantsMap = [
    &["anchinoe"],
    &["anchinoae"],
    &["anchinoae"],
    &["anchinoae"],
];

pub(crate) static ENTRY_ANCILLE_15818318021107678161: VariantsMap =
    [&["ancille"], &["ancillae"], &["ancillae"], &["ancillae"]];

pub(crate) static ENTRY_ANEMATOSIS_2231831205038246544: VariantsMap = [
    &["anematosis"],
    &["anaematosis"],
    &["anaematosis"],
    &["anaematosis"],
];

pub(crate) static ENTRY_ANEMIAS_11793613272534563937: VariantsMap =
    [&["anemias"], &["anaemias"], &["anemias"], &["anaemias"]];

pub(crate) static ENTRY_ANEMIA_11444125334540196345: VariantsMap =
    [&["anemia"], &["anaemia"], &["anemia"], &["anaemia"]];

pub(crate) static ENTRY_ANEMICALLY_6100474579337104939: VariantsMap = [
    &["anemically"],
    &["anaemically"],
    &["anemically"],
    &["anaemically"],
];

pub(crate) static ENTRY_ANEMICER_16024076703657819532: VariantsMap =
    [&["anemicer"], &["anaemicer"], &["anemicer"], &["anaemicer"]];

pub(crate) static ENTRY_ANEMICEST_17483472184329322961: VariantsMap = [
    &["anemicest"],
    &["anaemicest"],
    &["anemicest"],
    &["anaemicest"],
];

pub(crate) static ENTRY_ANEMICS_9964370762426059120: VariantsMap =
    [&["anemics"], &["anaemics"], &["anemics"], &["anaemics"]];

pub(crate) static ENTRY_ANEMIC_3144161607917365302: VariantsMap =
    [&["anemic"], &["anaemic"], &["anemic"], &["anaemic"]];

pub(crate) static ENTRY_ANERETIC_6982175402554498005: VariantsMap = [
    &["aneretic"],
    &["anaeretic"],
    &["anaeretic"],
    &["anaeretic"],
];

pub(crate) static ENTRY_ANESIS_16817046064174279211: VariantsMap =
    [&["anesis"], &["anoesis"], &["anoesis"], &["anoesis"]];

pub(crate) static ENTRY_ANESTHESIANT_15565352975099719303: VariantsMap = [
    &["anesthesiant"],
    &["anaesthesiant"],
    &["anaesthesiant"],
    &["anaesthesiant"],
];

pub(crate) static ENTRY_ANESTHESIAS_9838908694750944673: VariantsMap = [
    &["anesthesias"],
    &["anaesthesias"],
    &["anaesthesias"],
    &["anaesthesias"],
];

pub(crate) static ENTRY_ANESTHESIA_9822581388335098553: VariantsMap = [
    &["anesthesia"],
    &["anaesthesia"],
    &["anaesthesia"],
    &["anaesthesia"],
];

pub(crate) static ENTRY_ANESTHESIOLOGIES_6679603096569359713: VariantsMap = [
    &["anesthesiologies"],
    &["anaesthesiologies"],
    &["anesthesiologies"],
    &["anaesthesiologies"],
];

pub(crate) static ENTRY_ANESTHESIOLOGISTS_5770405695630095861: VariantsMap = [
    &["anesthesiologists"],
    &["anaesthesiologists"],
    &["anesthesiologists"],
    &["anaesthesiologists"],
];

pub(crate) static ENTRY_ANESTHESIOLOGIST_15509935416057002830: VariantsMap = [
    &["anesthesiologist"],
    &["anaesthesiologist"],
    &["anesthesiologist"],
    &["anaesthesiologist"],
];

pub(crate) static ENTRY_ANESTHESIOLOGY_1255532677711876584: VariantsMap = [
    &["anesthesiology"],
    &["anaesthesiology"],
    &["anesthesiology"],
    &["anaesthesiology"],
];

pub(crate) static ENTRY_ANESTHESIS_3798568430045477742: VariantsMap = [
    &["anesthesis"],
    &["anaesthesis"],
    &["anesthesis"],
    &["anaesthesis"],
];

pub(crate) static ENTRY_ANESTHETICALLY_17611597914394933738: VariantsMap = [
    &["anesthetically"],
    &["anaesthetically"],
    &["anaesthetically"],
    &["anaesthetically"],
];

pub(crate) static ENTRY_ANESTHETICER_1712235669739749819: VariantsMap = [
    &["anestheticer"],
    &["anaestheticer"],
    &["anaestheticer"],
    &["anaestheticer"],
];

pub(crate) static ENTRY_ANESTHETICEST_13273804515231488648: VariantsMap = [
    &["anestheticest"],
    &["anaestheticest"],
    &["anaestheticest"],
    &["anaestheticest"],
];

pub(crate) static ENTRY_ANESTHETICS_9673867241310151800: VariantsMap = [
    &["anesthetics"],
    &["anaesthetics"],
    &["anaesthetics"],
    &["anaesthetics"],
];

pub(crate) static ENTRY_ANESTHETIC_7346810397925011981: VariantsMap = [
    &["anesthetic"],
    &["anaesthetic"],
    &["anaesthetic"],
    &["anaesthetic"],
];

pub(crate) static ENTRY_ANESTHETISTS_8741608628280855523: VariantsMap = [
    &["anesthetists"],
    &["anaesthetists"],
    &["anaesthetists"],
    &["anaesthetists"],
];

pub(crate) static ENTRY_ANESTHETIST_10778880823396904501: VariantsMap = [
    &["anesthetist"],
    &["anaesthetist"],
    &["anaesthetist"],
    &["anaesthetist"],
];

pub(crate) static ENTRY_ANESTHETIZATIONS_10494265552871488873: VariantsMap = [
    &["anesthetizations"],
    &["anaesthetisations"],
    &["anaesthetizations"],
    &["anaesthetisations"],
];

pub(crate) static ENTRY_ANESTHETIZATION_11701429006232412151: VariantsMap = [
    &["anesthetization"],
    &["anaesthetisation"],
    &["anaesthetization"],
    &["anaesthetisation"],
];

pub(crate) static ENTRY_ANESTHETIZED_10115321731074208256: VariantsMap = [
    &["anesthetized"],
    &["anaesthetised"],
    &["anaesthetized"],
    &["anaesthetised"],
];

pub(crate) static ENTRY_ANESTHETIZERS_17863131477627405979: VariantsMap = [
    &["anesthetizers"],
    &["anaesthetisers"],
    &["anaesthetizers"],
    &["anaesthetisers"],
];

pub(crate) static ENTRY_ANESTHETIZER_5418733284803121475: VariantsMap = [
    &["anesthetizer"],
    &["anaesthetiser"],
    &["anaesthetizer"],
    &["anaesthetiser"],
];

pub(crate) static ENTRY_ANESTHETIZES_6149697878942963698: VariantsMap = [
    &["anesthetizes"],
    &["anaesthetises"],
    &["anaesthetizes"],
    &["anaesthetises"],
];

pub(crate) static ENTRY_ANESTHETIZE_9242516368594572411: VariantsMap = [
    &["anesthetize"],
    &["anaesthetise"],
    &["anaesthetize"],
    &["anaesthetise"],
];

pub(crate) static ENTRY_ANESTHETIZING_15816199569084558224: VariantsMap = [
    &["anesthetizing"],
    &["anaesthetising"],
    &["anaesthetizing"],
    &["anaesthetising"],
];

pub(crate) static ENTRY_ANESTHYL_8174332230955659903: VariantsMap = [
    &["anesthyl"],
    &["anaesthyl"],
    &["anaesthyl"],
    &["anaesthyl"],
];

pub(crate) static ENTRY_ANESTRA_3216556063016372977: VariantsMap =
    [&["anestra"], &["anoestra"], &["anoestra"], &["anoestra"]];

pub(crate) static ENTRY_ANESTRI_8008769930372220485: VariantsMap =
    [&["anestri"], &["anoestri"], &["anoestri"], &["anoestri"]];

pub(crate) static ENTRY_ANESTROUS_9129522172283593493: VariantsMap = [
    &["anestrous"],
    &["anoestrous"],
    &["anoestrous"],
    &["anoestrous"],
];

pub(crate) static ENTRY_ANESTRUM_11523934029574851144: VariantsMap = [
    &["anestrum"],
    &["anoestrum"],
    &["anoestrum"],
    &["anoestrum"],
];

pub(crate) static ENTRY_ANESTRUSES_8824267452405407476: VariantsMap = [
    &["anestruses"],
    &["anoestruses"],
    &["anoestruses"],
    &["anoestruses"],
];

pub(crate) static ENTRY_ANESTRUS_9353558396235507225: VariantsMap = [
    &["anestrus"],
    &["anoestrus"],
    &["anoestrus"],
    &["anoestrus"],
];

pub(crate) static ENTRY_ANETIC_9540754510599321451: VariantsMap =
    [&["anetic"], &["anoetic"], &["anoetic"], &["anoetic"]];

pub(crate) static ENTRY_ANETIOLOGICAL_10165110800520199298: VariantsMap = [
    &["anetiological"],
    &["anaetiological"],
    &["anaetiological"],
    &["anaetiological"],
];

pub(crate) static ENTRY_ANGELICIZES_1637579071183202501: VariantsMap = [
    &["angelicizes"],
    &["angelicises"],
    &["angelicizes"],
    &["angelicises"],
];

pub(crate) static ENTRY_ANGELICIZE_12868295367561294619: VariantsMap = [
    &["angelicize"],
    &["angelicise"],
    &["angelicize"],
    &["angelicise"],
];

pub(crate) static ENTRY_ANGELIZES_11526151045543007463: VariantsMap = [
    &["angelizes"],
    &["angelises"],
    &["angelizes"],
    &["angelises"],
];

pub(crate) static ENTRY_ANGELIZE_3309439384866912750: VariantsMap =
    [&["angelize"], &["angelise"], &["angelize"], &["angelise"]];

pub(crate) static ENTRY_ANGLICANIZES_16783014059494751778: VariantsMap = [
    &["anglicanizes"],
    &["anglicanises"],
    &["anglicanizes"],
    &["anglicanises"],
];

pub(crate) static ENTRY_ANGLICANIZE_6589690597387603909: VariantsMap = [
    &["anglicanize"],
    &["anglicanise"],
    &["anglicanize"],
    &["anglicanise"],
];

pub(crate) static ENTRY_ANGLICIZATIONS_18401409530730050577: VariantsMap = [
    &["anglicizations"],
    &["anglicisations"],
    &["anglicizations"],
    &["anglicisations"],
];

pub(crate) static ENTRY_ANGLICIZATION_15673594215730164653: VariantsMap = [
    &["anglicization"],
    &["anglicisation"],
    &["anglicization"],
    &["anglicisation"],
];

pub(crate) static ENTRY_ANGLICIZED_926209429237587197: VariantsMap = [
    &["anglicized"],
    &["anglicised"],
    &["anglicized"],
    &["anglicised"],
];

pub(crate) static ENTRY_ANGLICIZES_17586920051951268985: VariantsMap = [
    &["anglicizes"],
    &["anglicises"],
    &["anglicizes"],
    &["anglicises"],
];

pub(crate) static ENTRY_ANGLICIZE_3954997619999275868: VariantsMap = [
    &["anglicize"],
    &["anglicise"],
    &["anglicize"],
    &["anglicise"],
];

pub(crate) static ENTRY_ANGLICIZING_9709864366695655479: VariantsMap = [
    &["anglicizing"],
    &["anglicising"],
    &["anglicizing"],
    &["anglicising"],
];

pub(crate) static ENTRY_ANGRECUM_15932729819544960039: VariantsMap = [
    &["angrecum"],
    &["angraecum"],
    &["angraecum"],
    &["angraecum"],
];

pub(crate) static ENTRY_ANGULARIZATIONS_11452719329473280471: VariantsMap = [
    &["angularizations"],
    &["angularisations"],
    &["angularizations"],
    &["angularisations"],
];

pub(crate) static ENTRY_ANGULARIZATION_15472457872184311028: VariantsMap = [
    &["angularization"],
    &["angularisation"],
    &["angularization"],
    &["angularisation"],
];

pub(crate) static ENTRY_ANGULARIZES_5024097194073065261: VariantsMap = [
    &["angularizes"],
    &["angularises"],
    &["angularizes"],
    &["angularises"],
];

pub(crate) static ENTRY_ANGULARIZE_12397633129669042330: VariantsMap = [
    &["angularize"],
    &["angularise"],
    &["angularize"],
    &["angularise"],
];

pub(crate) static ENTRY_ANHEMATOPOIESIS_17033044080627588200: VariantsMap = [
    &["anhematopoiesis"],
    &["anhaematopoiesis"],
    &["anhaematopoiesis"],
    &["anhaematopoiesis"],
];

pub(crate) static ENTRY_ANHEMATOSIS_1202870001006935602: VariantsMap = [
    &["anhematosis"],
    &["anhaematosis"],
    &["anhaematosis"],
    &["anhaematosis"],
];

pub(crate) static ENTRY_ANHEMOLYTIC_16692415296726473453: VariantsMap = [
    &["anhemolytic"],
    &["anhaemolytic"],
    &["anhaemolytic"],
    &["anhaemolytic"],
];

pub(crate) static ENTRY_ANHYDREMIA_6316263310895692445: VariantsMap = [
    &["anhydremia"],
    &["anhydraemia"],
    &["anhydraemia"],
    &["anhydraemia"],
];

pub(crate) static ENTRY_ANHYDREMIC_15977830070786776453: VariantsMap = [
    &["anhydremic"],
    &["anhydraemic"],
    &["anhydraemic"],
    &["anhydraemic"],
];

pub(crate) static ENTRY_ANHYDRIDIZATIONS_6600161284303257781: VariantsMap = [
    &["anhydridizations"],
    &["anhydridisations"],
    &["anhydridizations"],
    &["anhydridisations"],
];

pub(crate) static ENTRY_ANHYDRIDIZATION_5779486140945991167: VariantsMap = [
    &["anhydridization"],
    &["anhydridisation"],
    &["anhydridization"],
    &["anhydridisation"],
];

pub(crate) static ENTRY_ANHYDRIDIZES_14731666580950863474: VariantsMap = [
    &["anhydridizes"],
    &["anhydridises"],
    &["anhydridizes"],
    &["anhydridises"],
];

pub(crate) static ENTRY_ANHYDRIDIZE_15475133187948388972: VariantsMap = [
    &["anhydridize"],
    &["anhydridise"],
    &["anhydridize"],
    &["anhydridise"],
];

pub(crate) static ENTRY_ANIMALIZATIONS_9150262297922812039: VariantsMap = [
    &["animalizations"],
    &["animalisations"],
    &["animalizations"],
    &["animalisations"],
];

pub(crate) static ENTRY_ANIMALIZATION_13800839490330789274: VariantsMap = [
    &["animalization"],
    &["animalisation"],
    &["animalization"],
    &["animalisation"],
];

pub(crate) static ENTRY_ANIMALIZED_14858832182572412268: VariantsMap = [
    &["animalized"],
    &["animalised"],
    &["animalized"],
    &["animalised"],
];

pub(crate) static ENTRY_ANIMALIZES_10069318372695209095: VariantsMap = [
    &["animalizes"],
    &["animalises"],
    &["animalizes"],
    &["animalises"],
];

pub(crate) static ENTRY_ANIMALIZE_10795005523464430843: VariantsMap = [
    &["animalize"],
    &["animalise"],
    &["animalize"],
    &["animalise"],
];

pub(crate) static ENTRY_ANIMALIZING_14729872040352851901: VariantsMap = [
    &["animalizing"],
    &["animalising"],
    &["animalizing"],
    &["animalising"],
];

pub(crate) static ENTRY_ANIMIZED_3366606492537025225: VariantsMap =
    [&["animized"], &["animised"], &["animized"], &["animised"]];

pub(crate) static ENTRY_ANNALIZED_1584431856817967939: VariantsMap = [
    &["annalized"],
    &["annalised"],
    &["annalized"],
    &["annalised"],
];

pub(crate) static ENTRY_ANNALIZES_9421823492557620465: VariantsMap = [
    &["annalizes"],
    &["annalises"],
    &["annalizes"],
    &["annalises"],
];

pub(crate) static ENTRY_ANNALIZE_5262176181932588410: VariantsMap =
    [&["annalize"], &["annalise"], &["annalize"], &["annalise"]];

pub(crate) static ENTRY_ANNALIZING_7591181130486416840: VariantsMap = [
    &["annalizing"],
    &["annalising"],
    &["annalizing"],
    &["annalising"],
];

pub(crate) static ENTRY_ANNUALIZATION_7581292024702563132: VariantsMap = [
    &["annualization"],
    &["annualisation"],
    &["annualization"],
    &["annualisation"],
];

pub(crate) static ENTRY_ANNUALIZED_1903235447181584612: VariantsMap = [
    &["annualized"],
    &["annualised"],
    &["annualized"],
    &["annualised"],
];

pub(crate) static ENTRY_ANNUALIZES_784688421746976936: VariantsMap = [
    &["annualizes"],
    &["annualises"],
    &["annualizes"],
    &["annualises"],
];

pub(crate) static ENTRY_ANNUALIZE_10377266175278860708: VariantsMap = [
    &["annualize"],
    &["annualise"],
    &["annualize"],
    &["annualise"],
];

pub(crate) static ENTRY_ANNUALIZING_2550568847360033478: VariantsMap = [
    &["annualizing"],
    &["annualising"],
    &["annualizing"],
    &["annualising"],
];

pub(crate) static ENTRY_ANODIZATION_733182598382300688: VariantsMap = [
    &["anodization"],
    &["anodisation"],
    &["anodization"],
    &["anodisation"],
];

pub(crate) static ENTRY_ANODIZED_7735922642387297722: VariantsMap =
    [&["anodized"], &["anodised"], &["anodized"], &["anodised"]];

pub(crate) static ENTRY_ANODIZES_16654764323679187252: VariantsMap =
    [&["anodizes"], &["anodises"], &["anodizes"], &["anodises"]];

pub(crate) static ENTRY_ANODIZE_13790793654476230265: VariantsMap =
    [&["anodize"], &["anodise"], &["anodize"], &["anodise"]];

pub(crate) static ENTRY_ANODIZING_15645879132035324138: VariantsMap = [
    &["anodizing"],
    &["anodising"],
    &["anodizing"],
    &["anodising"],
];

pub(crate) static ENTRY_ANONYMIZED_12511764813081644809: VariantsMap = [
    &["anonymized"],
    &["anonymised"],
    &["anonymized"],
    &["anonymised"],
];

pub(crate) static ENTRY_ANONYMIZES_8133801285918261260: VariantsMap = [
    &["anonymizes"],
    &["anonymises"],
    &["anonymizes"],
    &["anonymises"],
];

pub(crate) static ENTRY_ANONYMIZE_1026063515222292659: VariantsMap = [
    &["anonymize"],
    &["anonymise"],
    &["anonymize"],
    &["anonymise"],
];

pub(crate) static ENTRY_ANONYMIZING_8330567531910680906: VariantsMap = [
    &["anonymizing"],
    &["anonymising"],
    &["anonymizing"],
    &["anonymising"],
];

pub(crate) static ENTRY_ANORA_9499275694738114232: VariantsMap =
    [&["anora"], &["anoura"], &["anoura"], &["anoura"]];

pub(crate) static ENTRY_ANOXEMIA_938996689614149150: VariantsMap = [
    &["anoxemia"],
    &["anoxaemia"],
    &["anoxaemia"],
    &["anoxaemia"],
];

pub(crate) static ENTRY_ANOXEMIC_11133442815252282278: VariantsMap = [
    &["anoxemic"],
    &["anoxaemic"],
    &["anoxaemic"],
    &["anoxaemic"],
];

pub(crate) static ENTRY_ANSERINE_7284353552541073260: VariantsMap = [
    &["anserine"],
    &["anserinae"],
    &["anserinae"],
    &["anserinae"],
];

pub(crate) static ENTRY_ANTAGONIZABLE_7443781692023206072: VariantsMap = [
    &["antagonizable"],
    &["antagonisable"],
    &["antagonizable"],
    &["antagonisable"],
];

pub(crate) static ENTRY_ANTAGONIZATIONS_4109454268643874511: VariantsMap = [
    &["antagonizations"],
    &["antagonisations"],
    &["antagonizations"],
    &["antagonisations"],
];

pub(crate) static ENTRY_ANTAGONIZATION_15721044409672903140: VariantsMap = [
    &["antagonization"],
    &["antagonisation"],
    &["antagonization"],
    &["antagonisation"],
];

pub(crate) static ENTRY_ANTAGONIZED_871138940432104250: VariantsMap = [
    &["antagonized"],
    &["antagonised"],
    &["antagonized"],
    &["antagonised"],
];

pub(crate) static ENTRY_ANTAGONIZERS_12305563490012496402: VariantsMap = [
    &["antagonizers"],
    &["antagonisers"],
    &["antagonizers"],
    &["antagonisers"],
];

pub(crate) static ENTRY_ANTAGONIZER_2788747943091284362: VariantsMap = [
    &["antagonizer"],
    &["antagoniser"],
    &["antagonizer"],
    &["antagoniser"],
];

pub(crate) static ENTRY_ANTAGONIZES_10859788922464934847: VariantsMap = [
    &["antagonizes"],
    &["antagonises"],
    &["antagonizes"],
    &["antagonises"],
];

pub(crate) static ENTRY_ANTAGONIZE_10601283474489177682: VariantsMap = [
    &["antagonize"],
    &["antagonise"],
    &["antagonize"],
    &["antagonise"],
];

pub(crate) static ENTRY_ANTAGONIZING_7228037109106376861: VariantsMap = [
    &["antagonizing"],
    &["antagonising"],
    &["antagonizing"],
    &["antagonising"],
];

pub(crate) static ENTRY_ANTHECOLOGICAL_17004641370097456161: VariantsMap = [
    &["anthecological"],
    &["anthoecological"],
    &["anthoecological"],
    &["anthoecological"],
];

pub(crate) static ENTRY_ANTHECOLOGIST_10842025172326516523: VariantsMap = [
    &["anthecologist"],
    &["anthoecologist"],
    &["anthoecologist"],
    &["anthoecologist"],
];

pub(crate) static ENTRY_ANTHECOLOGY_3713437946183115906: VariantsMap = [
    &["anthecology"],
    &["anthoecology"],
    &["anthoecology"],
    &["anthoecology"],
];

pub(crate) static ENTRY_ANTHOLOGIZATION_16268833295952924414: VariantsMap = [
    &["anthologization"],
    &["anthologisation"],
    &["anthologization"],
    &["anthologisation"],
];

pub(crate) static ENTRY_ANTHOLOGIZED_12562962063091396112: VariantsMap = [
    &["anthologized"],
    &["anthologised"],
    &["anthologized"],
    &["anthologised"],
];

pub(crate) static ENTRY_ANTHOLOGIZER_4038135053732224148: VariantsMap = [
    &["anthologizer"],
    &["anthologiser"],
    &["anthologizer"],
    &["anthologiser"],
];

pub(crate) static ENTRY_ANTHOLOGIZES_5463829982103826072: VariantsMap = [
    &["anthologizes"],
    &["anthologises"],
    &["anthologizes"],
    &["anthologises"],
];

pub(crate) static ENTRY_ANTHOLOGIZE_15075070972324121611: VariantsMap = [
    &["anthologize"],
    &["anthologise"],
    &["anthologize"],
    &["anthologise"],
];

pub(crate) static ENTRY_ANTHOLOGIZING_16324123758427872169: VariantsMap = [
    &["anthologizing"],
    &["anthologising"],
    &["anthologizing"],
    &["anthologising"],
];

pub(crate) static ENTRY_ANTHRACEMIA_14146688523586379951: VariantsMap = [
    &["anthracemia"],
    &["anthracaemia"],
    &["anthracaemia"],
    &["anthracaemia"],
];

pub(crate) static ENTRY_ANTHRACITIZATIONS_1915110451729220165: VariantsMap = [
    &["anthracitizations"],
    &["anthracitisations"],
    &["anthracitizations"],
    &["anthracitisations"],
];

pub(crate) static ENTRY_ANTHRACITIZATION_8950863959835278016: VariantsMap = [
    &["anthracitization"],
    &["anthracitisation"],
    &["anthracitization"],
    &["anthracitisation"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZATIONS_18314256758800098784: VariantsMap = [
    &["anthropomorphizations"],
    &["anthropomorphisations"],
    &["anthropomorphizations"],
    &["anthropomorphisations"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZATION_15471734561820106871: VariantsMap = [
    &["anthropomorphization"],
    &["anthropomorphisation"],
    &["anthropomorphization"],
    &["anthropomorphisation"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZED_14538403291788237977: VariantsMap = [
    &["anthropomorphized"],
    &["anthropomorphised"],
    &["anthropomorphized"],
    &["anthropomorphised"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZES_1701634817856038507: VariantsMap = [
    &["anthropomorphizes"],
    &["anthropomorphises"],
    &["anthropomorphizes"],
    &["anthropomorphises"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZE_18370683813510312473: VariantsMap = [
    &["anthropomorphize"],
    &["anthropomorphise"],
    &["anthropomorphize"],
    &["anthropomorphise"],
];

pub(crate) static ENTRY_ANTHROPOMORPHIZING_2456478028362212796: VariantsMap = [
    &["anthropomorphizing"],
    &["anthropomorphising"],
    &["anthropomorphizing"],
    &["anthropomorphising"],
];

pub(crate) static ENTRY_ANTICATALYZERS_14048896960716076262: VariantsMap = [
    &["anticatalyzers"],
    &["anticatalysers"],
    &["anticatalysers"],
    &["anticatalysers"],
];

pub(crate) static ENTRY_ANTICATALYZER_4172121096489270019: VariantsMap = [
    &["anticatalyzer"],
    &["anticatalyser"],
    &["anticatalyser"],
    &["anticatalyser"],
];

pub(crate) static ENTRY_ANTICENTRALIZATIONS_13464164849647372934: VariantsMap = [
    &["anticentralizations"],
    &["anticentralisations"],
    &["anticentralizations"],
    &["anticentralisations"],
];

pub(crate) static ENTRY_ANTICENTRALIZATION_14344770334712817786: VariantsMap = [
    &["anticentralization"],
    &["anticentralisation"],
    &["anticentralization"],
    &["anticentralisation"],
];

pub(crate) static ENTRY_ANTICIZES_10127792012492899699: VariantsMap = [
    &["anticizes"],
    &["anticises"],
    &["anticizes"],
    &["anticises"],
];

pub(crate) static ENTRY_ANTICIZE_16286568034747030643: VariantsMap =
    [&["anticize"], &["anticise"], &["anticize"], &["anticise"]];

pub(crate) static ENTRY_ANTIEPICENTERS_7717054593335253563: VariantsMap = [
    &["antiepicenters"],
    &["antiepicentres"],
    &["antiepicentres"],
    &["antiepicentres"],
];

pub(crate) static ENTRY_ANTIEPICENTER_12788218346335819271: VariantsMap = [
    &["antiepicenter"],
    &["antiepicentre"],
    &["antiepicentre"],
    &["antiepicentre"],
];

pub(crate) static ENTRY_ANTIFERTILIZERS_13569559599612590243: VariantsMap = [
    &["antifertilizers"],
    &["antifertilisers"],
    &["antifertilizers"],
    &["antifertilisers"],
];

pub(crate) static ENTRY_ANTIFERTILIZER_9953475323473604594: VariantsMap = [
    &["antifertilizer"],
    &["antifertiliser"],
    &["antifertilizer"],
    &["antifertiliser"],
];

pub(crate) static ENTRY_ANTILABORS_3039533109874187414: VariantsMap = [
    &["antilabors"],
    &["antilabours"],
    &["antilabours"],
    &["antilabours"],
];

pub(crate) static ENTRY_ANTILABOR_9287358752473165308: VariantsMap = [
    &["antilabor"],
    &["antilabour"],
    &["antilabour"],
    &["antilabour"],
];

pub(crate) static ENTRY_ANTILEMIC_9212729723604435140: VariantsMap = [
    &["antilemic"],
    &["antiloemic"],
    &["antiloemic"],
    &["antiloemic"],
];

pub(crate) static ENTRY_ANTIMEDIEVALISM_8317263462919339358: VariantsMap = [
    &["antimedievalism"],
    &["antimediaevalism"],
    &["antimediaevalism"],
    &["antimediaevalism"],
];

pub(crate) static ENTRY_ANTIMEDIEVALIST_3072518728053155006: VariantsMap = [
    &["antimedievalist"],
    &["antimediaevalist"],
    &["antimediaevalist"],
    &["antimediaevalist"],
];

pub(crate) static ENTRY_ANTIMEDIEVALLY_17141320310909970911: VariantsMap = [
    &["antimedievally"],
    &["antimediaevally"],
    &["antimediaevally"],
    &["antimediaevally"],
];

pub(crate) static ENTRY_ANTIMEDIEVAL_6846585678553345503: VariantsMap = [
    &["antimedieval"],
    &["antimediaeval"],
    &["antimediaeval"],
    &["antimediaeval"],
];

pub(crate) static ENTRY_ANTIOXIDIZERS_10675061378003290626: VariantsMap = [
    &["antioxidizers"],
    &["antioxidisers"],
    &["antioxidizers"],
    &["antioxidisers"],
];

pub(crate) static ENTRY_ANTIOXIDIZER_12620825255232115928: VariantsMap = [
    &["antioxidizer"],
    &["antioxidiser"],
    &["antioxidizer"],
    &["antioxidiser"],
];

pub(crate) static ENTRY_ANTIOXIDIZINGS_16313410243816058314: VariantsMap = [
    &["antioxidizings"],
    &["antioxidisings"],
    &["antioxidizings"],
    &["antioxidisings"],
];

pub(crate) static ENTRY_ANTIOXIDIZING_2522097081998511687: VariantsMap = [
    &["antioxidizing"],
    &["antioxidising"],
    &["antioxidizing"],
    &["antioxidising"],
];

pub(crate) static ENTRY_ANTIPATHIZES_8032094931129328603: VariantsMap = [
    &["antipathizes"],
    &["antipathises"],
    &["antipathizes"],
    &["antipathises"],
];

pub(crate) static ENTRY_ANTIPATHIZE_14999471117461116868: VariantsMap = [
    &["antipathize"],
    &["antipathise"],
    &["antipathize"],
    &["antipathise"],
];

pub(crate) static ENTRY_ANTIQUARIANIZES_668583703801855532: VariantsMap = [
    &["antiquarianizes"],
    &["antiquarianises"],
    &["antiquarianizes"],
    &["antiquarianises"],
];

pub(crate) static ENTRY_ANTIQUARIANIZE_12102393390446972744: VariantsMap = [
    &["antiquarianize"],
    &["antiquarianise"],
    &["antiquarianize"],
    &["antiquarianise"],
];

pub(crate) static ENTRY_ANTIRUMORS_10439853249354862297: VariantsMap = [
    &["antirumors"],
    &["antirumours"],
    &["antirumours"],
    &["antirumours"],
];

pub(crate) static ENTRY_ANTIRUMOR_17427963938068472854: VariantsMap = [
    &["antirumor"],
    &["antirumour"],
    &["antirumour"],
    &["antirumour"],
];

pub(crate) static ENTRY_ANTISENSITIZERS_633215389454343262: VariantsMap = [
    &["antisensitizers"],
    &["antisensitisers"],
    &["antisensitizers"],
    &["antisensitisers"],
];

pub(crate) static ENTRY_ANTISENSITIZER_12937207493474321236: VariantsMap = [
    &["antisensitizer"],
    &["antisensitiser"],
    &["antisensitizer"],
    &["antisensitiser"],
];

pub(crate) static ENTRY_ANTISENSITIZES_16880204120152034442: VariantsMap = [
    &["antisensitizes"],
    &["antisensitises"],
    &["antisensitizes"],
    &["antisensitises"],
];

pub(crate) static ENTRY_ANTISENSITIZE_11055978247768215431: VariantsMap = [
    &["antisensitize"],
    &["antisensitise"],
    &["antisensitize"],
    &["antisensitise"],
];

pub(crate) static ENTRY_ANTISEPTICIZED_3518662086162245234: VariantsMap = [
    &["antisepticized"],
    &["antisepticised"],
    &["antisepticized"],
    &["antisepticised"],
];

pub(crate) static ENTRY_ANTISEPTICIZES_13502357588080215816: VariantsMap = [
    &["antisepticizes"],
    &["antisepticises"],
    &["antisepticizes"],
    &["antisepticises"],
];

pub(crate) static ENTRY_ANTISEPTICIZE_3241553852417294791: VariantsMap = [
    &["antisepticize"],
    &["antisepticise"],
    &["antisepticize"],
    &["antisepticise"],
];

pub(crate) static ENTRY_ANTISEPTICIZING_5069156061578073106: VariantsMap = [
    &["antisepticizing"],
    &["antisepticising"],
    &["antisepticizing"],
    &["antisepticising"],
];

pub(crate) static ENTRY_ANTISEPTIZES_15830751901555519360: VariantsMap = [
    &["antiseptizes"],
    &["antiseptises"],
    &["antiseptizes"],
    &["antiseptises"],
];

pub(crate) static ENTRY_ANTISEPTIZE_3729071818555121770: VariantsMap = [
    &["antiseptize"],
    &["antiseptise"],
    &["antiseptize"],
    &["antiseptise"],
];

pub(crate) static ENTRY_ANTISIPHONS_9333803036952068517: VariantsMap = [
    &["antisiphons"],
    &["antisyphons"],
    &["antisyphons"],
    &["antisyphons"],
];

pub(crate) static ENTRY_ANTISIPHON_15645040475271523141: VariantsMap = [
    &["antisiphon"],
    &["antisyphon"],
    &["antisyphon"],
    &["antisyphon"],
];

pub(crate) static ENTRY_ANTITHESIZES_6606468090715627462: VariantsMap = [
    &["antithesizes"],
    &["antithesises"],
    &["antithesizes"],
    &["antithesises"],
];

pub(crate) static ENTRY_ANTITHESIZE_6914205044378767893: VariantsMap = [
    &["antithesize"],
    &["antithesise"],
    &["antithesize"],
    &["antithesise"],
];

pub(crate) static ENTRY_ANVILED_16736675705730161078: VariantsMap =
    [&["anviled"], &["anvilled"], &["anvilled"], &["anvilled"]];

pub(crate) static ENTRY_ANVILING_5771622187992250616: VariantsMap = [
    &["anviling"],
    &["anvilling"],
    &["anvilling"],
    &["anvilling"],
];

pub(crate) static ENTRY_APESTHESIA_13121175333380557565: VariantsMap = [
    &["apesthesia"],
    &["apaesthesia"],
    &["apaesthesia"],
    &["apaesthesia"],
];

pub(crate) static ENTRY_APESTHETIC_15861671523251257086: VariantsMap = [
    &["apesthetic"],
    &["apaesthetic"],
    &["apaesthetic"],
    &["apaesthetic"],
];

pub(crate) static ENTRY_APHERESES_873005030036232707: VariantsMap = [
    &["aphereses"],
    &["aphaereses"],
    &["aphaereses"],
    &["aphaereses"],
];

pub(crate) static ENTRY_APHERESIS_14381380856101872428: VariantsMap = [
    &["apheresis"],
    &["aphaeresis"],
    &["aphaeresis"],
    &["aphaeresis"],
];

pub(crate) static ENTRY_APHERETIC_1426744147716989088: VariantsMap = [
    &["apheretic"],
    &["aphaeretic"],
    &["aphaeretic"],
    &["aphaeretic"],
];

pub(crate) static ENTRY_APHETIZED_3003107362630119729: VariantsMap = [
    &["aphetized"],
    &["aphetised"],
    &["aphetized"],
    &["aphetised"],
];

pub(crate) static ENTRY_APHETIZES_1747641243391683773: VariantsMap = [
    &["aphetizes"],
    &["aphetises"],
    &["aphetizes"],
    &["aphetises"],
];

pub(crate) static ENTRY_APHETIZE_17206274738648406980: VariantsMap =
    [&["aphetize"], &["aphetise"], &["aphetize"], &["aphetise"]];

pub(crate) static ENTRY_APHETIZING_13930569398062916036: VariantsMap = [
    &["aphetizing"],
    &["aphetising"],
    &["aphetizing"],
    &["aphetising"],
];

pub(crate) static ENTRY_APHORIZED_1699636898236576866: VariantsMap = [
    &["aphorized"],
    &["aphorised"],
    &["aphorized"],
    &["aphorised"],
];

pub(crate) static ENTRY_APHORIZERS_10347189849445130867: VariantsMap = [
    &["aphorizers"],
    &["aphorisers"],
    &["aphorizers"],
    &["aphorisers"],
];

pub(crate) static ENTRY_APHORIZER_14605329647382162831: VariantsMap = [
    &["aphorizer"],
    &["aphoriser"],
    &["aphorizer"],
    &["aphoriser"],
];

pub(crate) static ENTRY_APHORIZES_13164228522572019559: VariantsMap = [
    &["aphorizes"],
    &["aphorises"],
    &["aphorizes"],
    &["aphorises"],
];

pub(crate) static ENTRY_APHORIZE_15454256210406202597: VariantsMap =
    [&["aphorize"], &["aphorise"], &["aphorize"], &["aphorise"]];

pub(crate) static ENTRY_APHORIZING_11576244252883430467: VariantsMap = [
    &["aphorizing"],
    &["aphorising"],
    &["aphorizing"],
    &["aphorising"],
];

pub(crate) static ENTRY_APNEAL_9097304655696180790: VariantsMap =
    [&["apneal"], &["apnoeal"], &["apnoeal"], &["apnoeal"]];

pub(crate) static ENTRY_APNEAS_16005692722117648490: VariantsMap =
    [&["apneas"], &["apnoeas"], &["apneas"], &["apnoeas"]];

pub(crate) static ENTRY_APNEA_1779953829356774189: VariantsMap =
    [&["apnea"], &["apnoea"], &["apnea"], &["apnoea"]];

pub(crate) static ENTRY_APNEIC_8684812892754015714: VariantsMap =
    [&["apneic"], &["apnoeic"], &["apnoeic"], &["apnoeic"]];

pub(crate) static ENTRY_APOCENTER_6510924298032028131: VariantsMap = [
    &["apocenter"],
    &["apocentre"],
    &["apocentre"],
    &["apocentre"],
];

pub(crate) static ENTRY_APOGEIC_10442075832990462520: VariantsMap =
    [&["apogeic"], &["apogaeic"], &["apogaeic"], &["apogaeic"]];

pub(crate) static ENTRY_APOLOGIZED_766769648963130203: VariantsMap = [
    &["apologized"],
    &["apologised"],
    &["apologized"],
    &["apologised"],
];

pub(crate) static ENTRY_APOLOGIZERS_9394583326468044369: VariantsMap = [
    &["apologizers"],
    &["apologisers"],
    &["apologizers"],
    &["apologisers"],
];

pub(crate) static ENTRY_APOLOGIZER_6662783343430240014: VariantsMap = [
    &["apologizer"],
    &["apologiser"],
    &["apologizer"],
    &["apologiser"],
];

pub(crate) static ENTRY_APOLOGIZES_1886820837917495266: VariantsMap = [
    &["apologizes"],
    &["apologises"],
    &["apologizes"],
    &["apologises"],
];

pub(crate) static ENTRY_APOLOGIZE_4808140733719974618: VariantsMap = [
    &["apologize"],
    &["apologise"],
    &["apologize"],
    &["apologise"],
];

pub(crate) static ENTRY_APOLOGIZING_17198773338731611091: VariantsMap = [
    &["apologizing"],
    &["apologising"],
    &["apologizing"],
    &["apologising"],
];

pub(crate) static ENTRY_APOPHTHEGMATIZED_6403368858420510421: VariantsMap = [
    &["apophthegmatized"],
    &["apophthegmatised"],
    &["apophthegmatized"],
    &["apophthegmatised"],
];

pub(crate) static ENTRY_APOPHTHEGMATIZES_9217219445848562213: VariantsMap = [
    &["apophthegmatizes"],
    &["apophthegmatises"],
    &["apophthegmatizes"],
    &["apophthegmatises"],
];

pub(crate) static ENTRY_APOPHTHEGMATIZE_6610517743016644545: VariantsMap = [
    &["apophthegmatize"],
    &["apophthegmatise"],
    &["apophthegmatize"],
    &["apophthegmatise"],
];

pub(crate) static ENTRY_APOPHTHEGMATIZING_17329841406994799734: VariantsMap = [
    &["apophthegmatizing"],
    &["apophthegmatising"],
    &["apophthegmatizing"],
    &["apophthegmatising"],
];

pub(crate) static ENTRY_APORRHEA_16606851972678900170: VariantsMap = [
    &["aporrhea"],
    &["aporrhoea"],
    &["aporrhoea"],
    &["aporrhoea"],
];

pub(crate) static ENTRY_APOSTATIZATION_11912806942865124865: VariantsMap = [
    &["apostatization"],
    &["apostatisation"],
    &["apostatization"],
    &["apostatisation"],
];

pub(crate) static ENTRY_APOSTATIZED_7948531497773688326: VariantsMap = [
    &["apostatized"],
    &["apostatised"],
    &["apostatized"],
    &["apostatised"],
];

pub(crate) static ENTRY_APOSTATIZES_17887605457755809141: VariantsMap = [
    &["apostatizes"],
    &["apostatises"],
    &["apostatizes"],
    &["apostatises"],
];

pub(crate) static ENTRY_APOSTATIZE_13907286705070263227: VariantsMap = [
    &["apostatize"],
    &["apostatise"],
    &["apostatize"],
    &["apostatise"],
];

pub(crate) static ENTRY_APOSTATIZING_10968882224231134376: VariantsMap = [
    &["apostatizing"],
    &["apostatising"],
    &["apostatizing"],
    &["apostatising"],
];

pub(crate) static ENTRY_APOSTOLIZED_968548481129324663: VariantsMap = [
    &["apostolized"],
    &["apostolised"],
    &["apostolized"],
    &["apostolised"],
];

pub(crate) static ENTRY_APOSTOLIZES_11319414821221634427: VariantsMap = [
    &["apostolizes"],
    &["apostolises"],
    &["apostolizes"],
    &["apostolises"],
];

pub(crate) static ENTRY_APOSTOLIZE_1194842762673394568: VariantsMap = [
    &["apostolize"],
    &["apostolise"],
    &["apostolize"],
    &["apostolise"],
];

pub(crate) static ENTRY_APOSTOLIZING_7088290679795202865: VariantsMap = [
    &["apostolizing"],
    &["apostolising"],
    &["apostolizing"],
    &["apostolising"],
];

pub(crate) static ENTRY_APOSTROPHIZED_10608858047847867957: VariantsMap = [
    &["apostrophized"],
    &["apostrophised"],
    &["apostrophized"],
    &["apostrophised"],
];

pub(crate) static ENTRY_APOSTROPHIZES_7531964953977912072: VariantsMap = [
    &["apostrophizes"],
    &["apostrophises"],
    &["apostrophizes"],
    &["apostrophises"],
];

pub(crate) static ENTRY_APOSTROPHIZE_6169660213182266890: VariantsMap = [
    &["apostrophize"],
    &["apostrophise"],
    &["apostrophize"],
    &["apostrophise"],
];

pub(crate) static ENTRY_APOSTROPHIZING_11255712027534928622: VariantsMap = [
    &["apostrophizing"],
    &["apostrophising"],
    &["apostrophizing"],
    &["apostrophising"],
];

pub(crate) static ENTRY_APOTHEGMATIZED_15528209367579426804: VariantsMap = [
    &["apothegmatized"],
    &["apothegmatised"],
    &["apothegmatized"],
    &["apothegmatised"],
];

pub(crate) static ENTRY_APOTHEGMATIZES_3386118086394100613: VariantsMap = [
    &["apothegmatizes"],
    &["apothegmatises"],
    &["apothegmatizes"],
    &["apothegmatises"],
];

pub(crate) static ENTRY_APOTHEGMATIZE_9149577190229122350: VariantsMap = [
    &["apothegmatize"],
    &["apothegmatise"],
    &["apothegmatize"],
    &["apothegmatise"],
];

pub(crate) static ENTRY_APOTHEGMATIZING_2185890142177612358: VariantsMap = [
    &["apothegmatizing"],
    &["apothegmatising"],
    &["apothegmatizing"],
    &["apothegmatising"],
];

pub(crate) static ENTRY_APOTHEOSIZED_2104097860710903144: VariantsMap = [
    &["apotheosized"],
    &["apotheosised"],
    &["apotheosized"],
    &["apotheosised"],
];

pub(crate) static ENTRY_APOTHEOSIZES_6448094166099469006: VariantsMap = [
    &["apotheosizes"],
    &["apotheosises"],
    &["apotheosizes"],
    &["apotheosises"],
];

pub(crate) static ENTRY_APOTHEOSIZE_12839413435396426367: VariantsMap = [
    &["apotheosize"],
    &["apotheosise"],
    &["apotheosize"],
    &["apotheosise"],
];

pub(crate) static ENTRY_APOTHEOSIZING_10092556043562303850: VariantsMap = [
    &["apotheosizing"],
    &["apotheosising"],
    &["apotheosizing"],
    &["apotheosising"],
];

pub(crate) static ENTRY_APPALLS_20865698290307641: VariantsMap =
    [&["appalls"], &["appals"], &["appalls"], &["appals"]];

pub(crate) static ENTRY_APPALL_8105666145197803720: VariantsMap =
    [&["appall"], &["appal"], &["appall"], &["appal"]];

pub(crate) static ENTRY_APPARELED_10321717899864381527: VariantsMap = [
    &["appareled"],
    &["apparelled"],
    &["apparelled"],
    &["apparelled"],
];

pub(crate) static ENTRY_APPARELING_16684109917693936517: VariantsMap = [
    &["appareling"],
    &["apparelling"],
    &["apparelling"],
    &["apparelling"],
];

pub(crate) static ENTRY_APPETIZED_10492350941175942222: VariantsMap = [
    &["appetized"],
    &["appetised"],
    &["appetized"],
    &["appetised"],
];

pub(crate) static ENTRY_APPETIZEMENTS_8628307177248201340: VariantsMap = [
    &["appetizements"],
    &["appetisements"],
    &["appetizements"],
    &["appetisements"],
];

pub(crate) static ENTRY_APPETIZEMENT_16407004548503724456: VariantsMap = [
    &["appetizement"],
    &["appetisement"],
    &["appetizement"],
    &["appetisement"],
];

pub(crate) static ENTRY_APPETIZERS_7154598257569291418: VariantsMap = [
    &["appetizers"],
    &["appetisers"],
    &["appetizers"],
    &["appetisers"],
];

pub(crate) static ENTRY_APPETIZER_5123269697918809384: VariantsMap = [
    &["appetizer"],
    &["appetiser"],
    &["appetizer"],
    &["appetiser"],
];

pub(crate) static ENTRY_APPETIZES_1889924664779699277: VariantsMap = [
    &["appetizes"],
    &["appetises"],
    &["appetizes"],
    &["appetises"],
];

pub(crate) static ENTRY_APPETIZE_13936831634592536190: VariantsMap =
    [&["appetize"], &["appetise"], &["appetize"], &["appetise"]];

pub(crate) static ENTRY_APPETIZINGLY_10760124750466327501: VariantsMap = [
    &["appetizingly"],
    &["appetisingly"],
    &["appetizingly"],
    &["appetisingly"],
];

pub(crate) static ENTRY_APPETIZING_383666770405789408: VariantsMap = [
    &["appetizing"],
    &["appetising"],
    &["appetizing"],
    &["appetising"],
];

pub(crate) static ENTRY_APPRIZAL_6335618835659004475: VariantsMap =
    [&["apprizal"], &["apprisal"], &["apprizal"], &["apprisal"]];

pub(crate) static ENTRY_APPRIZERS_16559280108388910365: VariantsMap = [
    &["apprizers"],
    &["apprisers"],
    &["apprizers"],
    &["apprisers"],
];

pub(crate) static ENTRY_APPRIZER_1067225642706442627: VariantsMap =
    [&["apprizer"], &["appriser"], &["apprizer"], &["appriser"]];

pub(crate) static ENTRY_APPRIZINGS_13881830905723497559: VariantsMap = [
    &["apprizings"],
    &["apprisings"],
    &["apprizings"],
    &["apprisings"],
];

pub(crate) static ENTRY_ARABIANIZES_6146778824890703405: VariantsMap = [
    &["arabianizes"],
    &["arabianises"],
    &["arabianizes"],
    &["arabianises"],
];

pub(crate) static ENTRY_ARABIANIZE_7091452592558944142: VariantsMap = [
    &["arabianize"],
    &["arabianise"],
    &["arabianize"],
    &["arabianise"],
];

pub(crate) static ENTRY_ARABICIZES_17376878529951217199: VariantsMap = [
    &["arabicizes"],
    &["arabicises"],
    &["arabicizes"],
    &["arabicises"],
];

pub(crate) static ENTRY_ARABICIZE_7118455398303530058: VariantsMap = [
    &["arabicize"],
    &["arabicise"],
    &["arabicize"],
    &["arabicise"],
];

pub(crate) static ENTRY_ARABIZATIONS_3254497434968628478: VariantsMap = [
    &["arabizations"],
    &["arabisations"],
    &["arabizations"],
    &["arabisations"],
];

pub(crate) static ENTRY_ARABIZATION_18186190432640846471: VariantsMap = [
    &["arabization"],
    &["arabisation"],
    &["arabization"],
    &["arabisation"],
];

pub(crate) static ENTRY_ARABIZED_13913844866590865979: VariantsMap =
    [&["arabized"], &["arabised"], &["arabized"], &["arabised"]];

pub(crate) static ENTRY_ARABIZES_16630760146158946529: VariantsMap =
    [&["arabizes"], &["arabises"], &["arabizes"], &["arabises"]];

pub(crate) static ENTRY_ARABIZE_9595110188198649627: VariantsMap =
    [&["arabize"], &["arabise"], &["arabize"], &["arabise"]];

pub(crate) static ENTRY_ARABIZING_10793371023736049149: VariantsMap = [
    &["arabizing"],
    &["arabising"],
    &["arabizing"],
    &["arabising"],
];

pub(crate) static ENTRY_ARAMEANS_13793987072806544505: VariantsMap = [
    &["arameans"],
    &["aramaeans"],
    &["aramaeans"],
    &["aramaeans"],
];

pub(crate) static ENTRY_ARAMEAN_4395400457535337445: VariantsMap =
    [&["aramean"], &["aramaean"], &["aramaean"], &["aramaean"]];

pub(crate) static ENTRY_ARBALESTER_17275327857939491618: VariantsMap = [
    &["arbalester"],
    &["arbalestre"],
    &["arbalestre"],
    &["arbalestre"],
];

pub(crate) static ENTRY_ARBORED_6451632367270810042: VariantsMap =
    [&["arbored"], &["arboured"], &["arboured"], &["arboured"]];

pub(crate) static ENTRY_ARBORES_2760921281327347095: VariantsMap =
    [&["arbores"], &["arboures"], &["arboures"], &["arboures"]];

pub(crate) static ENTRY_ARBORIZATIONS_2080512800793081270: VariantsMap = [
    &["arborizations"],
    &["arborisations"],
    &["arborizations"],
    &["arborisations"],
];

pub(crate) static ENTRY_ARBORIZATION_9677792163286494747: VariantsMap = [
    &["arborization"],
    &["arborisation"],
    &["arborization"],
    &["arborisation"],
];

pub(crate) static ENTRY_ARBORIZED_10511833189104814553: VariantsMap = [
    &["arborized"],
    &["arborised"],
    &["arborized"],
    &["arborised"],
];

pub(crate) static ENTRY_ARBORIZES_11990594085526471423: VariantsMap = [
    &["arborizes"],
    &["arborises"],
    &["arborizes"],
    &["arborises"],
];

pub(crate) static ENTRY_ARBORIZE_13993474358635558324: VariantsMap =
    [&["arborize"], &["arborise"], &["arborize"], &["arborise"]];

pub(crate) static ENTRY_ARBORIZING_9399803869936043047: VariantsMap = [
    &["arborizing"],
    &["arborising"],
    &["arborizing"],
    &["arborising"],
];

pub(crate) static ENTRY_ARBORS_9095342812626319615: VariantsMap =
    [&["arbors"], &["arbours"], &["arbours"], &["arbours"]];

pub(crate) static ENTRY_ARBOR_2099081688991941134: VariantsMap =
    [&["arbor"], &["arbour"], &["arbour"], &["arbour"]];

pub(crate) static ENTRY_ARCHAEOLOGICAL_5745535416676733106: VariantsMap = [
    &["archaeological"],
    &["archaeological"],
    &["archaeological"],
    &["archaeological"],
];

pub(crate) static ENTRY_ARCHAEOLOGIC_2454164999315616216: VariantsMap = [
    &["archaeologic"],
    &["archaeologic"],
    &["archaeologic"],
    &["archaeologic"],
];

pub(crate) static ENTRY_ARCHAEOLOGIES_14568028250477257186: VariantsMap = [
    &["archaeologies"],
    &["archaeologies"],
    &["archaeologies"],
    &["archaeologies"],
];

pub(crate) static ENTRY_ARCHAEOLOGISTS_10939394023447922447: VariantsMap = [
    &["archaeologists"],
    &["archaeologists"],
    &["archaeologists"],
    &["archaeologists"],
];

pub(crate) static ENTRY_ARCHAEOLOGIST_15696704416854872606: VariantsMap = [
    &["archaeologist"],
    &["archaeologist"],
    &["archaeologist"],
    &["archaeologist"],
];

pub(crate) static ENTRY_ARCHAEOLOGY_4126503997832873296: VariantsMap = [
    &["archaeology"],
    &["archaeology"],
    &["archaeology"],
    &["archaeology"],
];

pub(crate) static ENTRY_ARCHAIZED_13322639529987334614: VariantsMap = [
    &["archaized"],
    &["archaised"],
    &["archaized"],
    &["archaised"],
];

pub(crate) static ENTRY_ARCHAIZERS_6972696703859538503: VariantsMap = [
    &["archaizers"],
    &["archaisers"],
    &["archaizers"],
    &["archaisers"],
];

pub(crate) static ENTRY_ARCHAIZER_13710837259267725318: VariantsMap = [
    &["archaizer"],
    &["archaiser"],
    &["archaizer"],
    &["archaiser"],
];

pub(crate) static ENTRY_ARCHAIZES_4876579109305121157: VariantsMap = [
    &["archaizes"],
    &["archaises"],
    &["archaizes"],
    &["archaises"],
];

pub(crate) static ENTRY_ARCHAIZE_1359278578081430792: VariantsMap =
    [&["archaize"], &["archaise"], &["archaize"], &["archaise"]];

pub(crate) static ENTRY_ARCHAIZING_3246941458311193300: VariantsMap = [
    &["archaizing"],
    &["archaising"],
    &["archaizing"],
    &["archaising"],
];

pub(crate) static ENTRY_ARCHEAL_6179901035862490669: VariantsMap =
    [&["archeal"], &["archaeal"], &["archaeal"], &["archaeal"]];

pub(crate) static ENTRY_ARCHEAN_14847398170729505321: VariantsMap =
    [&["archean"], &["archaean"], &["archaean"], &["archaean"]];

pub(crate) static ENTRY_ARCHEI_14186317656172516337: VariantsMap =
    [&["archei"], &["archaei"], &["archaei"], &["archaei"]];

pub(crate) static ENTRY_ARCHEOASTRONOMIES_12672535196068691757: VariantsMap = [
    &["archeoastronomies"],
    &["archaeoastronomies"],
    &["archaeoastronomies"],
    &["archaeoastronomies"],
];

pub(crate) static ENTRY_ARCHEOASTRONOMY_7568086850104584418: VariantsMap = [
    &["archeoastronomy"],
    &["archaeoastronomy"],
    &["archaeoastronomy"],
    &["archaeoastronomy"],
];

pub(crate) static ENTRY_ARCHEOCYTE_544989770193462231: VariantsMap = [
    &["archeocyte"],
    &["archaeocyte"],
    &["archaeocyte"],
    &["archaeocyte"],
];

pub(crate) static ENTRY_ARCHEOLITHIC_14371745948924816941: VariantsMap = [
    &["archeolithic"],
    &["archaeolithic"],
    &["archaeolithic"],
    &["archaeolithic"],
];

pub(crate) static ENTRY_ARCHEOLOGIAN_11401650089021570001: VariantsMap = [
    &["archeologian"],
    &["archaeologian"],
    &["archaeologian"],
    &["archaeologian"],
];

pub(crate) static ENTRY_ARCHEOL_1621301161575668294: VariantsMap =
    [&["archeol"], &["archaeol"], &["archaeol"], &["archaeol"]];

pub(crate) static ENTRY_ARCHEOMETRIES_9109698910620640943: VariantsMap = [
    &["archeometries"],
    &["archaeometries"],
    &["archaeometries"],
    &["archaeometries"],
];

pub(crate) static ENTRY_ARCHEOMETRY_17067814741857159557: VariantsMap = [
    &["archeometry"],
    &["archaeometry"],
    &["archaeometry"],
    &["archaeometry"],
];

pub(crate) static ENTRY_ARCHEOZIC_9758294415454737448: VariantsMap = [
    &["archeozic"],
    &["archaeozic"],
    &["archaeozic"],
    &["archaeozic"],
];

pub(crate) static ENTRY_ARCHEOZOIC_18268674600637414324: VariantsMap = [
    &["archeozoic"],
    &["archaeozoic"],
    &["archaeozoic"],
    &["archaeozoic"],
];

pub(crate) static ENTRY_ARCHEUS_1328632190850149944: VariantsMap =
    [&["archeus"], &["archaeus"], &["archaeus"], &["archaeus"]];

pub(crate) static ENTRY_ARCHE_10156222017687532546: VariantsMap =
    [&["arche"], &["archae"], &["archae"], &["archae"]];

pub(crate) static ENTRY_ARCTICIZES_17488626861313077167: VariantsMap = [
    &["arcticizes"],
    &["arcticises"],
    &["arcticizes"],
    &["arcticises"],
];

pub(crate) static ENTRY_ARCTICIZE_14955043478793537404: VariantsMap = [
    &["arcticize"],
    &["arcticise"],
    &["arcticize"],
    &["arcticise"],
];

pub(crate) static ENTRY_ARCTOGEAN_2216179672115771268: VariantsMap = [
    &["arctogean"],
    &["arctogaean"],
    &["arctogaean"],
    &["arctogaean"],
];

pub(crate) static ENTRY_ARCTOGEA_15159053709851015323: VariantsMap = [
    &["arctogea"],
    &["arctogaea"],
    &["arctogaea"],
    &["arctogaea"],
];

pub(crate) static ENTRY_ARCTOGEIC_12166436575342886940: VariantsMap = [
    &["arctogeic"],
    &["arctogaeic"],
    &["arctogaeic"],
    &["arctogaeic"],
];

pub(crate) static ENTRY_ARDORS_13859299160898289371: VariantsMap =
    [&["ardors"], &["ardours"], &["ardours"], &["ardours"]];

pub(crate) static ENTRY_ARDOR_16738479217548171426: VariantsMap =
    [&["ardor"], &["ardour"], &["ardour"], &["ardour"]];

pub(crate) static ENTRY_ARENICOLOR_4953462878754370500: VariantsMap = [
    &["arenicolor"],
    &["arenicolour"],
    &["arenicolour"],
    &["arenicolour"],
];

pub(crate) static ENTRY_AREOLE_12338780936099127737: VariantsMap =
    [&["areole"], &["areolae"], &["areolae"], &["areolae"]];

pub(crate) static ENTRY_AREOMETRICAL_17718812079898847508: VariantsMap = [
    &["areometrical"],
    &["araeometrical"],
    &["araeometrical"],
    &["araeometrical"],
];

pub(crate) static ENTRY_AREOMETRIC_17639504932600545758: VariantsMap = [
    &["areometric"],
    &["araeometric"],
    &["araeometric"],
    &["araeometric"],
];

pub(crate) static ENTRY_AREOSTYLES_1673942835480908773: VariantsMap = [
    &["areostyles"],
    &["araeostyles"],
    &["araeostyles"],
    &["araeostyles"],
];

pub(crate) static ENTRY_AREOSTYLE_9887341032000748494: VariantsMap = [
    &["areostyle"],
    &["araeostyle"],
    &["araeostyle"],
    &["araeostyle"],
];

pub(crate) static ENTRY_AREOSYSTYLE_14135429367026377792: VariantsMap = [
    &["areosystyle"],
    &["araeosystyle"],
    &["araeosystyle"],
    &["araeosystyle"],
];

pub(crate) static ENTRY_ARIANIZED_1259509742119549714: VariantsMap = [
    &["arianized"],
    &["arianised"],
    &["arianized"],
    &["arianised"],
];

pub(crate) static ENTRY_ARIANIZES_14713941213590902805: VariantsMap = [
    &["arianizes"],
    &["arianises"],
    &["arianizes"],
    &["arianises"],
];

pub(crate) static ENTRY_ARIANIZE_1475808498118197849: VariantsMap =
    [&["arianize"], &["arianise"], &["arianize"], &["arianise"]];

pub(crate) static ENTRY_ARIANIZING_15061255978082885900: VariantsMap = [
    &["arianizing"],
    &["arianising"],
    &["arianizing"],
    &["arianising"],
];

pub(crate) static ENTRY_ARIMATHEAN_16207104510661913460: VariantsMap = [
    &["arimathean"],
    &["arimathaean"],
    &["arimathaean"],
    &["arimathaean"],
];

pub(crate) static ENTRY_ARIMATHEA_13006899549940341201: VariantsMap = [
    &["arimathea"],
    &["arimathaea"],
    &["arimathaea"],
    &["arimathaea"],
];

pub(crate) static ENTRY_ARISTE_4207971148573549326: VariantsMap =
    [&["ariste"], &["aristae"], &["aristae"], &["aristae"]];

pub(crate) static ENTRY_ARITHMETIZATIONS_6133192991101865652: VariantsMap = [
    &["arithmetizations"],
    &["arithmetisations"],
    &["arithmetizations"],
    &["arithmetisations"],
];

pub(crate) static ENTRY_ARITHMETIZATION_10054898680334010685: VariantsMap = [
    &["arithmetization"],
    &["arithmetisation"],
    &["arithmetization"],
    &["arithmetisation"],
];

pub(crate) static ENTRY_ARITHMETIZED_804241885225408901: VariantsMap = [
    &["arithmetized"],
    &["arithmetised"],
    &["arithmetized"],
    &["arithmetised"],
];

pub(crate) static ENTRY_ARITHMETIZES_4021129694449874179: VariantsMap = [
    &["arithmetizes"],
    &["arithmetises"],
    &["arithmetizes"],
    &["arithmetises"],
];

pub(crate) static ENTRY_ARITHMETIZE_15576026606241266299: VariantsMap = [
    &["arithmetize"],
    &["arithmetise"],
    &["arithmetize"],
    &["arithmetise"],
];

pub(crate) static ENTRY_ARMORBEARER_2157362197814652336: VariantsMap = [
    &["armorbearer"],
    &["armourbearer"],
    &["armourbearer"],
    &["armourbearer"],
];

pub(crate) static ENTRY_ARMORED_982936021759049572: VariantsMap =
    [&["armored"], &["armoured"], &["armoured"], &["armoured"]];

pub(crate) static ENTRY_ARMORERS_5671193923544706720: VariantsMap = [
    &["armorers"],
    &["armourers"],
    &["armourers"],
    &["armourers"],
];

pub(crate) static ENTRY_ARMORER_5772853517114648246: VariantsMap =
    [&["armorer"], &["armourer"], &["armourer"], &["armourer"]];

pub(crate) static ENTRY_ARMORIED_11535135214878289513: VariantsMap = [
    &["armoried"],
    &["armouried"],
    &["armouried"],
    &["armouried"],
];

pub(crate) static ENTRY_ARMORIES_4241896125070646795: VariantsMap = [
    &["armories"],
    &["armouries"],
    &["armouries"],
    &["armouries"],
];

pub(crate) static ENTRY_ARMORING_6447756068859055780: VariantsMap = [
    &["armoring"],
    &["armouring"],
    &["armouring"],
    &["armouring"],
];

pub(crate) static ENTRY_ARMORLESS_17033530693523632986: VariantsMap = [
    &["armorless"],
    &["armourless"],
    &["armourless"],
    &["armourless"],
];

pub(crate) static ENTRY_ARMORS_8991902587170735735: VariantsMap =
    [&["armors"], &["armours"], &["armours"], &["armours"]];

pub(crate) static ENTRY_ARMORY_16496001318701009580: VariantsMap =
    [&["armory"], &["armoury"], &["armoury"], &["armoury"]];

pub(crate) static ENTRY_ARMOR_6791544457048582167: VariantsMap =
    [&["armor"], &["armour"], &["armour"], &["armour"]];

pub(crate) static ENTRY_AROMATITE_13587883584590217655: VariantsMap = [
    &["aromatite"],
    &["aromatitae"],
    &["aromatitae"],
    &["aromatitae"],
];

pub(crate) static ENTRY_AROMATIZATION_2953688635914420328: VariantsMap = [
    &["aromatization"],
    &["aromatisation"],
    &["aromatization"],
    &["aromatisation"],
];

pub(crate) static ENTRY_AROMATIZED_11509335206222252539: VariantsMap = [
    &["aromatized"],
    &["aromatised"],
    &["aromatized"],
    &["aromatised"],
];

pub(crate) static ENTRY_AROMATIZER_9784880273725424914: VariantsMap = [
    &["aromatizer"],
    &["aromatiser"],
    &["aromatizer"],
    &["aromatiser"],
];

pub(crate) static ENTRY_AROMATIZES_11689049401873834109: VariantsMap = [
    &["aromatizes"],
    &["aromatises"],
    &["aromatizes"],
    &["aromatises"],
];

pub(crate) static ENTRY_AROMATIZE_14212398289764823606: VariantsMap = [
    &["aromatize"],
    &["aromatise"],
    &["aromatize"],
    &["aromatise"],
];

pub(crate) static ENTRY_AROMATIZING_15725452162461845633: VariantsMap = [
    &["aromatizing"],
    &["aromatising"],
    &["aromatizing"],
    &["aromatising"],
];

pub(crate) static ENTRY_ARSENICIZES_1017198980814944191: VariantsMap = [
    &["arsenicizes"],
    &["arsenicises"],
    &["arsenicizes"],
    &["arsenicises"],
];

pub(crate) static ENTRY_ARSENICIZE_13996042961629556869: VariantsMap = [
    &["arsenicize"],
    &["arsenicise"],
    &["arsenicize"],
    &["arsenicise"],
];

pub(crate) static ENTRY_ARSINOE_18015403196399169984: VariantsMap =
    [&["arsinoe"], &["arsinoae"], &["arsinoae"], &["arsinoae"]];

pub(crate) static ENTRY_ARTERIALIZATIONS_3727765437552603830: VariantsMap = [
    &["arterializations"],
    &["arterialisations"],
    &["arterializations"],
    &["arterialisations"],
];

pub(crate) static ENTRY_ARTERIALIZATION_17022790192875553359: VariantsMap = [
    &["arterialization"],
    &["arterialisation"],
    &["arterialization"],
    &["arterialisation"],
];

pub(crate) static ENTRY_ARTERIALIZED_10808091996021730739: VariantsMap = [
    &["arterialized"],
    &["arterialised"],
    &["arterialized"],
    &["arterialised"],
];

pub(crate) static ENTRY_ARTERIALIZES_2237218216825221904: VariantsMap = [
    &["arterializes"],
    &["arterialises"],
    &["arterializes"],
    &["arterialises"],
];

pub(crate) static ENTRY_ARTERIALIZE_4417484011804302892: VariantsMap = [
    &["arterialize"],
    &["arterialise"],
    &["arterialize"],
    &["arterialise"],
];

pub(crate) static ENTRY_ARTERIALIZING_7575251577380617319: VariantsMap = [
    &["arterializing"],
    &["arterialising"],
    &["arterializing"],
    &["arterialising"],
];

pub(crate) static ENTRY_ARTHREMPYESIS_845595122000356547: VariantsMap = [
    &["arthrempyesis"],
    &["arthroempyesis"],
    &["arthroempyesis"],
    &["arthroempyesis"],
];

pub(crate) static ENTRY_ARTIFACTS_3550024244562413823: VariantsMap = [
    &["artifacts"],
    &["artefacts"],
    &["artifacts"],
    &["artefacts"],
];

pub(crate) static ENTRY_ARTIFACT_2827424156037909074: VariantsMap =
    [&["artifact"], &["artefact"], &["artifact"], &["artefact"]];

pub(crate) static ENTRY_ARTIFICIALIZED_3661622221795178801: VariantsMap = [
    &["artificialized"],
    &["artificialised"],
    &["artificialized"],
    &["artificialised"],
];

pub(crate) static ENTRY_ARTIFICIALIZES_12340528017967580371: VariantsMap = [
    &["artificializes"],
    &["artificialises"],
    &["artificializes"],
    &["artificialises"],
];

pub(crate) static ENTRY_ARTIFICIALIZE_6116923120575367102: VariantsMap = [
    &["artificialize"],
    &["artificialise"],
    &["artificialize"],
    &["artificialise"],
];

pub(crate) static ENTRY_ARTIFICIALIZING_6041141466863049208: VariantsMap = [
    &["artificializing"],
    &["artificialising"],
    &["artificializing"],
    &["artificialising"],
];

pub(crate) static ENTRY_ARYANIZATION_9851944027750269067: VariantsMap = [
    &["aryanization"],
    &["aryanisation"],
    &["aryanization"],
    &["aryanisation"],
];

pub(crate) static ENTRY_ARYANIZED_2198024662554456823: VariantsMap = [
    &["aryanized"],
    &["aryanised"],
    &["aryanized"],
    &["aryanised"],
];

pub(crate) static ENTRY_ARYANIZES_1271531809715528591: VariantsMap = [
    &["aryanizes"],
    &["aryanises"],
    &["aryanizes"],
    &["aryanises"],
];

pub(crate) static ENTRY_ARYANIZE_16869282873759611476: VariantsMap =
    [&["aryanize"], &["aryanise"], &["aryanize"], &["aryanise"]];

pub(crate) static ENTRY_ARYANIZING_14999690626685964985: VariantsMap = [
    &["aryanizing"],
    &["aryanising"],
    &["aryanizing"],
    &["aryanising"],
];

pub(crate) static ENTRY_ARYTENOIDS_4570196976416030148: VariantsMap = [
    &["arytenoids"],
    &["arytaenoids"],
    &["arytaenoids"],
    &["arytaenoids"],
];

pub(crate) static ENTRY_ARYTENOID_7001515572255686205: VariantsMap = [
    &["arytenoid"],
    &["arytaenoid"],
    &["arytaenoid"],
    &["arytaenoid"],
];

pub(crate) static ENTRY_ASAFETIDAS_3146529801559413940: VariantsMap = [
    &["asafetidas"],
    &["asafoetidas"],
    &["asafetidas"],
    &["asafoetidas"],
];

pub(crate) static ENTRY_ASAFETIDA_14075127292131066209: VariantsMap = [
    &["asafetida"],
    &["asafoetida"],
    &["asafetida"],
    &["asafoetida"],
];

pub(crate) static ENTRY_ASCENDANCY_17212684530560634805: VariantsMap = [
    &["ascendancy"],
    &["ascendancy"],
    &["ascendancy"],
    &["ascendancy"],
];

pub(crate) static ENTRY_ASCENDANTS_15521170888856908309: VariantsMap = [
    &["ascendants"],
    &["ascendants"],
    &["ascendants"],
    &["ascendants"],
];

pub(crate) static ENTRY_ASCENDANT_2752266460494779856: VariantsMap = [
    &["ascendant"],
    &["ascendant"],
    &["ascendant"],
    &["ascendant"],
];

pub(crate) static ENTRY_ASCLEPIADE_10210677193219397680: VariantsMap = [
    &["asclepiade"],
    &["asclepiadae"],
    &["asclepiadae"],
    &["asclepiadae"],
];

pub(crate) static ENTRY_ASEL_2991140811333800185: VariantsMap =
    [&["asel"], &["asael"], &["asael"], &["asael"]];

pub(crate) static ENTRY_ASEPTICIZED_17514342866645218287: VariantsMap = [
    &["asepticized"],
    &["asepticised"],
    &["asepticized"],
    &["asepticised"],
];

pub(crate) static ENTRY_ASEPTICIZES_18007236908793048941: VariantsMap = [
    &["asepticizes"],
    &["asepticises"],
    &["asepticizes"],
    &["asepticises"],
];

pub(crate) static ENTRY_ASEPTICIZE_3933929209320869926: VariantsMap = [
    &["asepticize"],
    &["asepticise"],
    &["asepticize"],
    &["asepticise"],
];

pub(crate) static ENTRY_ASEPTICIZING_16831292622846251458: VariantsMap = [
    &["asepticizing"],
    &["asepticising"],
    &["asepticizing"],
    &["asepticising"],
];

pub(crate) static ENTRY_ASEXUALIZATION_15410884236551711164: VariantsMap = [
    &["asexualization"],
    &["asexualisation"],
    &["asexualization"],
    &["asexualisation"],
];

pub(crate) static ENTRY_ASEXUALIZED_7482569439479163307: VariantsMap = [
    &["asexualized"],
    &["asexualised"],
    &["asexualized"],
    &["asexualised"],
];

pub(crate) static ENTRY_ASEXUALIZE_9124079032501171431: VariantsMap = [
    &["asexualize"],
    &["asexualise"],
    &["asexualize"],
    &["asexualise"],
];

pub(crate) static ENTRY_ASEXUALIZING_12563154882147712490: VariantsMap = [
    &["asexualizing"],
    &["asexualising"],
    &["asexualizing"],
    &["asexualising"],
];

pub(crate) static ENTRY_ASIATICIZATIONS_12783056870942421620: VariantsMap = [
    &["asiaticizations"],
    &["asiaticisations"],
    &["asiaticizations"],
    &["asiaticisations"],
];

pub(crate) static ENTRY_ASIATICIZATION_4610120106437867166: VariantsMap = [
    &["asiaticization"],
    &["asiaticisation"],
    &["asiaticization"],
    &["asiaticisation"],
];

pub(crate) static ENTRY_ASIATICIZES_16830856299856603906: VariantsMap = [
    &["asiaticizes"],
    &["asiaticises"],
    &["asiaticizes"],
    &["asiaticises"],
];

pub(crate) static ENTRY_ASIATICIZE_17700168473976448799: VariantsMap = [
    &["asiaticize"],
    &["asiaticise"],
    &["asiaticize"],
    &["asiaticise"],
];

pub(crate) static ENTRY_ASMONEAN_8413395248866854750: VariantsMap = [
    &["asmonean"],
    &["asmonaean"],
    &["asmonaean"],
    &["asmonaean"],
];

pub(crate) static ENTRY_ASPHETERIZED_10290056046377700436: VariantsMap = [
    &["aspheterized"],
    &["aspheterised"],
    &["aspheterized"],
    &["aspheterised"],
];

pub(crate) static ENTRY_ASPHETERIZES_14734322769410196190: VariantsMap = [
    &["aspheterizes"],
    &["aspheterises"],
    &["aspheterizes"],
    &["aspheterises"],
];

pub(crate) static ENTRY_ASPHETERIZE_16117159886415614048: VariantsMap = [
    &["aspheterize"],
    &["aspheterise"],
    &["aspheterize"],
    &["aspheterise"],
];

pub(crate) static ENTRY_ASPHETERIZING_6898599003467614908: VariantsMap = [
    &["aspheterizing"],
    &["aspheterising"],
    &["aspheterizing"],
    &["aspheterising"],
];

pub(crate) static ENTRY_ASSAFETIDAS_15617703533170914973: VariantsMap = [
    &["assafetidas"],
    &["assafoetidas"],
    &["assafoetidas"],
    &["assafoetidas"],
];

pub(crate) static ENTRY_ASSAFETIDA_113224093999442010: VariantsMap = [
    &["assafetida"],
    &["assafoetida"],
    &["assafoetida"],
    &["assafoetida"],
];

pub(crate) static ENTRY_ASSES_13623663473667601400: VariantsMap =
    [&["asses"], &["arses"], &["arses"], &["arses"]];

pub(crate) static ENTRY_ASSHOLES_13924057355694920061: VariantsMap = [
    &["assholes"],
    &["arseholes"],
    &["arseholes"],
    &["arseholes"],
];

pub(crate) static ENTRY_ASSHOLE_12964338351998611148: VariantsMap =
    [&["asshole"], &["arsehole"], &["arsehole"], &["arsehole"]];

pub(crate) static ENTRY_ASSIDEAN_4573494847516673943: VariantsMap = [
    &["assidean"],
    &["assidaean"],
    &["assidaean"],
    &["assidaean"],
];

pub(crate) static ENTRY_ASSYRIANIZES_1350783930464276444: VariantsMap = [
    &["assyrianizes"],
    &["assyrianises"],
    &["assyrianizes"],
    &["assyrianises"],
];

pub(crate) static ENTRY_ASSYRIANIZE_9925515178117509112: VariantsMap = [
    &["assyrianize"],
    &["assyrianise"],
    &["assyrianize"],
    &["assyrianise"],
];

pub(crate) static ENTRY_ASS_3108967481325135828: VariantsMap =
    [&["ass"], &["arse"], &["arse"], &["arse"]];

pub(crate) static ENTRY_ASTERA_15037794719691540402: VariantsMap =
    [&["astera"], &["astrea"], &["astrea"], &["astrea"]];

pub(crate) static ENTRY_ASTIGMATIZERS_18090102560636046522: VariantsMap = [
    &["astigmatizers"],
    &["astigmatisers"],
    &["astigmatizers"],
    &["astigmatisers"],
];

pub(crate) static ENTRY_ASTIGMATIZER_5573446594967375201: VariantsMap = [
    &["astigmatizer"],
    &["astigmatiser"],
    &["astigmatizer"],
    &["astigmatiser"],
];

pub(crate) static ENTRY_ASTREAN_17672754089710155278: VariantsMap =
    [&["astrean"], &["astraean"], &["astraean"], &["astraean"]];

pub(crate) static ENTRY_ASTREA_9491635490797963619: VariantsMap =
    [&["astrea"], &["astraea"], &["astraea"], &["astraea"]];

pub(crate) static ENTRY_ASTRONOMIZED_17892819808746658022: VariantsMap = [
    &["astronomized"],
    &["astronomised"],
    &["astronomized"],
    &["astronomised"],
];

pub(crate) static ENTRY_ASTRONOMIZES_3426897682798715707: VariantsMap = [
    &["astronomizes"],
    &["astronomises"],
    &["astronomizes"],
    &["astronomises"],
];

pub(crate) static ENTRY_ASTRONOMIZE_8434822243027737838: VariantsMap = [
    &["astronomize"],
    &["astronomise"],
    &["astronomize"],
    &["astronomise"],
];

pub(crate) static ENTRY_ASTRONOMIZING_14727829167008307417: VariantsMap = [
    &["astronomizing"],
    &["astronomising"],
    &["astronomizing"],
    &["astronomising"],
];

pub(crate) static ENTRY_ASYNCHRONIZED_2264379807465924648: VariantsMap = [
    &["asynchronized"],
    &["asynchronised"],
    &["asynchronized"],
    &["asynchronised"],
];

pub(crate) static ENTRY_ASYNCHRONIZES_4368864858861627592: VariantsMap = [
    &["asynchronizes"],
    &["asynchronises"],
    &["asynchronizes"],
    &["asynchronises"],
];

pub(crate) static ENTRY_ASYNCHRONIZE_3165012635702999054: VariantsMap = [
    &["asynchronize"],
    &["asynchronise"],
    &["asynchronize"],
    &["asynchronise"],
];

pub(crate) static ENTRY_ASYNCHRONIZING_16727683109340331408: VariantsMap = [
    &["asynchronizing"],
    &["asynchronising"],
    &["asynchronizing"],
    &["asynchronising"],
];

pub(crate) static ENTRY_ATHEIZED_8361944679804490409: VariantsMap =
    [&["atheized"], &["atheised"], &["atheized"], &["atheised"]];

pub(crate) static ENTRY_ATHEIZES_131064789695988757: VariantsMap =
    [&["atheizes"], &["atheises"], &["atheizes"], &["atheises"]];

pub(crate) static ENTRY_ATHEIZE_1650523572049665618: VariantsMap =
    [&["atheize"], &["atheise"], &["atheize"], &["atheise"]];

pub(crate) static ENTRY_ATHEIZING_3233601106148671334: VariantsMap = [
    &["atheizing"],
    &["atheising"],
    &["atheizing"],
    &["atheising"],
];

pub(crate) static ENTRY_ATHETIZED_9779500563027955411: VariantsMap = [
    &["athetized"],
    &["athetised"],
    &["athetized"],
    &["athetised"],
];

pub(crate) static ENTRY_ATHETIZES_3263174137872390116: VariantsMap = [
    &["athetizes"],
    &["athetises"],
    &["athetizes"],
    &["athetises"],
];

pub(crate) static ENTRY_ATHETIZE_16801924254921136220: VariantsMap =
    [&["athetize"], &["athetise"], &["athetize"], &["athetise"]];

pub(crate) static ENTRY_ATHETIZING_9191281724888382129: VariantsMap = [
    &["athetizing"],
    &["athetising"],
    &["athetizing"],
    &["athetising"],
];

pub(crate) static ENTRY_ATMOLYZED_12772305670820601939: VariantsMap = [
    &["atmolyzed"],
    &["atmolysed"],
    &["atmolyzed"],
    &["atmolysed"],
];

pub(crate) static ENTRY_ATMOLYZES_14417513048999254193: VariantsMap = [
    &["atmolyzes"],
    &["atmolyses"],
    &["atmolyzes"],
    &["atmolyses"],
];

pub(crate) static ENTRY_ATMOLYZE_6907417165654906772: VariantsMap =
    [&["atmolyze"], &["atmolyse"], &["atmolyze"], &["atmolyse"]];

pub(crate) static ENTRY_ATMOLYZING_12067305970424863391: VariantsMap = [
    &["atmolyzing"],
    &["atmolysing"],
    &["atmolyzing"],
    &["atmolysing"],
];

pub(crate) static ENTRY_ATOMIZABILITY_3662844297231153629: VariantsMap = [
    &["atomizability"],
    &["atomisability"],
    &["atomizability"],
    &["atomisability"],
];

pub(crate) static ENTRY_ATOMIZABLE_9006232702939622749: VariantsMap = [
    &["atomizable"],
    &["atomisable"],
    &["atomizable"],
    &["atomisable"],
];

pub(crate) static ENTRY_ATOMIZATIONS_15654929944891871906: VariantsMap = [
    &["atomizations"],
    &["atomisations"],
    &["atomizations"],
    &["atomisations"],
];

pub(crate) static ENTRY_ATOMIZATION_17590563802310665738: VariantsMap = [
    &["atomization"],
    &["atomisation"],
    &["atomization"],
    &["atomisation"],
];

pub(crate) static ENTRY_ATOMIZED_8537277580871094585: VariantsMap =
    [&["atomized"], &["atomised"], &["atomized"], &["atomised"]];

pub(crate) static ENTRY_ATOMIZERS_14449646570970952892: VariantsMap = [
    &["atomizers"],
    &["atomisers"],
    &["atomizers"],
    &["atomisers"],
];

pub(crate) static ENTRY_ATOMIZER_10420576678406032842: VariantsMap =
    [&["atomizer"], &["atomiser"], &["atomizer"], &["atomiser"]];

pub(crate) static ENTRY_ATOMIZES_963643916071531136: VariantsMap =
    [&["atomizes"], &["atomises"], &["atomizes"], &["atomises"]];

pub(crate) static ENTRY_ATOMIZE_2064605152651050847: VariantsMap =
    [&["atomize"], &["atomise"], &["atomize"], &["atomise"]];

pub(crate) static ENTRY_ATOMIZING_14986115038272633138: VariantsMap = [
    &["atomizing"],
    &["atomising"],
    &["atomizing"],
    &["atomising"],
];

pub(crate) static ENTRY_ATROCERULEUS_7452134384217065626: VariantsMap = [
    &["atroceruleus"],
    &["atrocoeruleus"],
    &["atrocoeruleus"],
    &["atrocoeruleus"],
];

pub(crate) static ENTRY_ATTEMPER_10321595750792114646: VariantsMap =
    [&["attemper"], &["attempre"], &["attempre"], &["attempre"]];

pub(crate) static ENTRY_ATTICIZED_17898369434810945049: VariantsMap = [
    &["atticized"],
    &["atticised"],
    &["atticized"],
    &["atticised"],
];

pub(crate) static ENTRY_ATTICIZES_7824093798291526926: VariantsMap = [
    &["atticizes"],
    &["atticises"],
    &["atticizes"],
    &["atticises"],
];

pub(crate) static ENTRY_ATTICIZE_10540291067079331794: VariantsMap =
    [&["atticize"], &["atticise"], &["atticize"], &["atticise"]];

pub(crate) static ENTRY_ATTICIZING_12115148616495024690: VariantsMap = [
    &["atticizing"],
    &["atticising"],
    &["atticizing"],
    &["atticising"],
];

pub(crate) static ENTRY_ATTITUDINIZATION_17706899523030773650: VariantsMap = [
    &["attitudinization"],
    &["attitudinisation"],
    &["attitudinization"],
    &["attitudinisation"],
];

pub(crate) static ENTRY_ATTITUDINIZED_5404939483170560810: VariantsMap = [
    &["attitudinized"],
    &["attitudinised"],
    &["attitudinized"],
    &["attitudinised"],
];

pub(crate) static ENTRY_ATTITUDINIZERS_11505676119055064972: VariantsMap = [
    &["attitudinizers"],
    &["attitudinisers"],
    &["attitudinizers"],
    &["attitudinisers"],
];

pub(crate) static ENTRY_ATTITUDINIZER_2282587564825240743: VariantsMap = [
    &["attitudinizer"],
    &["attitudiniser"],
    &["attitudinizer"],
    &["attitudiniser"],
];

pub(crate) static ENTRY_ATTITUDINIZES_4849080985867035260: VariantsMap = [
    &["attitudinizes"],
    &["attitudinises"],
    &["attitudinizes"],
    &["attitudinises"],
];

pub(crate) static ENTRY_ATTITUDINIZE_4708014689700982410: VariantsMap = [
    &["attitudinize"],
    &["attitudinise"],
    &["attitudinize"],
    &["attitudinise"],
];

pub(crate) static ENTRY_ATTITUDINIZINGS_1081765832368849783: VariantsMap = [
    &["attitudinizings"],
    &["attitudinisings"],
    &["attitudinizings"],
    &["attitudinisings"],
];

pub(crate) static ENTRY_ATTITUDINIZING_3722680743543175700: VariantsMap = [
    &["attitudinizing"],
    &["attitudinising"],
    &["attitudinizing"],
    &["attitudinising"],
];

pub(crate) static ENTRY_AUNTER_3984069006526724037: VariantsMap =
    [&["aunter"], &["auntre"], &["auntre"], &["auntre"]];

pub(crate) static ENTRY_AUSTRALIANIZES_15628526718481795434: VariantsMap = [
    &["australianizes"],
    &["australianises"],
    &["australianizes"],
    &["australianises"],
];

pub(crate) static ENTRY_AUSTRALIANIZE_15680337575086561646: VariantsMap = [
    &["australianize"],
    &["australianise"],
    &["australianize"],
    &["australianise"],
];

pub(crate) static ENTRY_AUSTRALOPITHECINE_461885205668956581: VariantsMap = [
    &["australopithecine"],
    &["australopithecinae"],
    &["australopithecinae"],
    &["australopithecinae"],
];

pub(crate) static ENTRY_AUSTRIANIZES_15942538329526351866: VariantsMap = [
    &["austrianizes"],
    &["austrianises"],
    &["austrianizes"],
    &["austrianises"],
];

pub(crate) static ENTRY_AUSTRIANIZE_13889494210532044520: VariantsMap = [
    &["austrianize"],
    &["austrianise"],
    &["austrianize"],
    &["austrianise"],
];

pub(crate) static ENTRY_AUTECIOUSLY_14502261960323316507: VariantsMap = [
    &["auteciously"],
    &["autoeciously"],
    &["autoeciously"],
    &["autoeciously"],
];

pub(crate) static ENTRY_AUTECIOUSNESS_11976285547644733901: VariantsMap = [
    &["auteciousness"],
    &["autoeciousness"],
    &["autoeciousness"],
    &["autoeciousness"],
];

pub(crate) static ENTRY_AUTECIOUS_13333061310808681838: VariantsMap = [
    &["autecious"],
    &["autoecious"],
    &["autoecious"],
    &["autoecious"],
];

pub(crate) static ENTRY_AUTECISMS_2180607123628399675: VariantsMap = [
    &["autecisms"],
    &["autoecisms"],
    &["autoecisms"],
    &["autoecisms"],
];

pub(crate) static ENTRY_AUTECISM_1715619165077149465: VariantsMap = [
    &["autecism"],
    &["autoecism"],
    &["autoecism"],
    &["autoecism"],
];

pub(crate) static ENTRY_AUTECY_13719576853502314463: VariantsMap =
    [&["autecy"], &["autoecy"], &["autoecy"], &["autoecy"]];

pub(crate) static ENTRY_AUTHORIZABLE_5231844717756889861: VariantsMap = [
    &["authorizable"],
    &["authorisable"],
    &["authorizable"],
    &["authorisable"],
];

pub(crate) static ENTRY_AUTHORIZATIONS_3134679260837487294: VariantsMap = [
    &["authorizations"],
    &["authorisations"],
    &["authorizations"],
    &["authorisations"],
];

pub(crate) static ENTRY_AUTHORIZATION_395843400641738718: VariantsMap = [
    &["authorization"],
    &["authorisation"],
    &["authorization"],
    &["authorisation"],
];

pub(crate) static ENTRY_AUTHORIZED_2551432787313490355: VariantsMap = [
    &["authorized"],
    &["authorised"],
    &["authorized"],
    &["authorised"],
];

pub(crate) static ENTRY_AUTHORIZERS_8627630439372760014: VariantsMap = [
    &["authorizers"],
    &["authorisers"],
    &["authorizers"],
    &["authorisers"],
];

pub(crate) static ENTRY_AUTHORIZER_4327258003305487952: VariantsMap = [
    &["authorizer"],
    &["authoriser"],
    &["authorizer"],
    &["authoriser"],
];

pub(crate) static ENTRY_AUTHORIZES_17496628475906077057: VariantsMap = [
    &["authorizes"],
    &["authorises"],
    &["authorizes"],
    &["authorises"],
];

pub(crate) static ENTRY_AUTHORIZE_12314763752837557145: VariantsMap = [
    &["authorize"],
    &["authorise"],
    &["authorize"],
    &["authorise"],
];

pub(crate) static ENTRY_AUTHORIZING_6195944790124186706: VariantsMap = [
    &["authorizing"],
    &["authorising"],
    &["authorizing"],
    &["authorising"],
];

pub(crate) static ENTRY_AUTOCATALYZED_11100710334159127743: VariantsMap = [
    &["autocatalyzed"],
    &["autocatalysed"],
    &["autocatalyzed"],
    &["autocatalysed"],
];

pub(crate) static ENTRY_AUTOCATALYZES_5725738045167769178: VariantsMap = [
    &["autocatalyzes"],
    &["autocatalyses"],
    &["autocatalyzes"],
    &["autocatalyses"],
];

pub(crate) static ENTRY_AUTOCATALYZE_11377656786611519467: VariantsMap = [
    &["autocatalyze"],
    &["autocatalyse"],
    &["autocatalyze"],
    &["autocatalyse"],
];

pub(crate) static ENTRY_AUTOCATALYZING_5159779918854952475: VariantsMap = [
    &["autocatalyzing"],
    &["autocatalysing"],
    &["autocatalyzing"],
    &["autocatalysing"],
];

pub(crate) static ENTRY_AUTODIALER_1134450050813174093: VariantsMap = [
    &["autodialer"],
    &["autodialler"],
    &["autodialler"],
    &["autodialler"],
];

pub(crate) static ENTRY_AUTOIMMUNIZATION_9708656153855152039: VariantsMap = [
    &["autoimmunization"],
    &["autoimmunisation"],
    &["autoimmunization"],
    &["autoimmunisation"],
];

pub(crate) static ENTRY_AUTOIONIZATION_6978369082999863184: VariantsMap = [
    &["autoionization"],
    &["autoionisation"],
    &["autoionization"],
    &["autoionisation"],
];

pub(crate) static ENTRY_AUTOLYZATES_1225100042828836123: VariantsMap = [
    &["autolyzates"],
    &["autolysates"],
    &["autolyzates"],
    &["autolysates"],
];

pub(crate) static ENTRY_AUTOLYZATE_13897976732846843186: VariantsMap = [
    &["autolyzate"],
    &["autolysate"],
    &["autolyzate"],
    &["autolysate"],
];

pub(crate) static ENTRY_AUTOLYZED_17033910730696642695: VariantsMap = [
    &["autolyzed"],
    &["autolysed"],
    &["autolyzed"],
    &["autolysed"],
];

pub(crate) static ENTRY_AUTOLYZES_15600692012613351200: VariantsMap = [
    &["autolyzes"],
    &["autolyses"],
    &["autolyzes"],
    &["autolyses"],
];

pub(crate) static ENTRY_AUTOLYZE_11473855583949653238: VariantsMap =
    [&["autolyze"], &["autolyse"], &["autolyze"], &["autolyse"]];

pub(crate) static ENTRY_AUTOLYZING_489296052443611874: VariantsMap = [
    &["autolyzing"],
    &["autolysing"],
    &["autolyzing"],
    &["autolysing"],
];

pub(crate) static ENTRY_AUTOMATIZATIONS_619849714390905963: VariantsMap = [
    &["automatizations"],
    &["automatisations"],
    &["automatizations"],
    &["automatisations"],
];

pub(crate) static ENTRY_AUTOMATIZATION_1620858880780330964: VariantsMap = [
    &["automatization"],
    &["automatisation"],
    &["automatization"],
    &["automatisation"],
];

pub(crate) static ENTRY_AUTOMATIZED_9571719111299962204: VariantsMap = [
    &["automatized"],
    &["automatised"],
    &["automatized"],
    &["automatised"],
];

pub(crate) static ENTRY_AUTOMATIZES_9261149387605266072: VariantsMap = [
    &["automatizes"],
    &["automatises"],
    &["automatizes"],
    &["automatises"],
];

pub(crate) static ENTRY_AUTOMATIZE_7880401560635519882: VariantsMap = [
    &["automatize"],
    &["automatise"],
    &["automatize"],
    &["automatise"],
];

pub(crate) static ENTRY_AUTOMATIZING_11897346773175064542: VariantsMap = [
    &["automatizing"],
    &["automatising"],
    &["automatizing"],
    &["automatising"],
];

pub(crate) static ENTRY_AUTONOE_11409143792101174133: VariantsMap =
    [&["autonoe"], &["autonoae"], &["autonoae"], &["autonoae"]];

pub(crate) static ENTRY_AUTOTOMIZED_7590157601515171803: VariantsMap = [
    &["autotomized"],
    &["autotomised"],
    &["autotomized"],
    &["autotomised"],
];

pub(crate) static ENTRY_AUTOTOMIZES_9909588375372995524: VariantsMap = [
    &["autotomizes"],
    &["autotomises"],
    &["autotomizes"],
    &["autotomises"],
];

pub(crate) static ENTRY_AUTOTOMIZE_10870376480991549462: VariantsMap = [
    &["autotomize"],
    &["autotomise"],
    &["autotomize"],
    &["autotomise"],
];

pub(crate) static ENTRY_AUTOTOMIZING_18376066296486340252: VariantsMap = [
    &["autotomizing"],
    &["autotomising"],
    &["autotomizing"],
    &["autotomising"],
];

pub(crate) static ENTRY_AUTOTOXEMIAS_3350713876222978889: VariantsMap = [
    &["autotoxemias"],
    &["autotoxaemias"],
    &["autotoxaemias"],
    &["autotoxaemias"],
];

pub(crate) static ENTRY_AUTOTOXEMIA_18366267511576797743: VariantsMap = [
    &["autotoxemia"],
    &["autotoxaemia"],
    &["autotoxaemia"],
    &["autotoxaemia"],
];

pub(crate) static ENTRY_AVIANIZED_3624907102508634438: VariantsMap = [
    &["avianized"],
    &["avianised"],
    &["avianized"],
    &["avianised"],
];

pub(crate) static ENTRY_AVIANIZES_6407105568503397650: VariantsMap = [
    &["avianizes"],
    &["avianises"],
    &["avianizes"],
    &["avianises"],
];

pub(crate) static ENTRY_AVIANIZE_10110854240867535999: VariantsMap =
    [&["avianize"], &["avianise"], &["avianize"], &["avianise"]];

pub(crate) static ENTRY_AVIANIZING_14608259848585895347: VariantsMap = [
    &["avianizing"],
    &["avianising"],
    &["avianizing"],
    &["avianising"],
];

pub(crate) static ENTRY_AVIZANDUMS_10365146430390683692: VariantsMap = [
    &["avizandums"],
    &["avisandums"],
    &["avizandums"],
    &["avisandums"],
];

pub(crate) static ENTRY_AVIZANDUM_15832266843653276586: VariantsMap = [
    &["avizandum"],
    &["avisandum"],
    &["avizandum"],
    &["avisandum"],
];

pub(crate) static ENTRY_AVIZED_374462512849482817: VariantsMap =
    [&["avized"], &["avised"], &["avized"], &["avised"]];

pub(crate) static ENTRY_AVIZES_4714530384314138108: VariantsMap =
    [&["avizes"], &["avises"], &["avizes"], &["avises"]];

pub(crate) static ENTRY_AVIZE_558609699481267671: VariantsMap =
    [&["avize"], &["avise"], &["avize"], &["avise"]];

pub(crate) static ENTRY_AVIZING_3841969763676440589: VariantsMap =
    [&["avizing"], &["avising"], &["avizing"], &["avising"]];

pub(crate) static ENTRY_AXIOMATIZATIONS_4377624432478694059: VariantsMap = [
    &["axiomatizations"],
    &["axiomatisations"],
    &["axiomatizations"],
    &["axiomatisations"],
];

pub(crate) static ENTRY_AXIOMATIZATION_2512913160865628279: VariantsMap = [
    &["axiomatization"],
    &["axiomatisation"],
    &["axiomatization"],
    &["axiomatisation"],
];

pub(crate) static ENTRY_AXIOMATIZED_13606089758225327424: VariantsMap = [
    &["axiomatized"],
    &["axiomatised"],
    &["axiomatized"],
    &["axiomatised"],
];

pub(crate) static ENTRY_AXIOMATIZES_8178035167309590431: VariantsMap = [
    &["axiomatizes"],
    &["axiomatises"],
    &["axiomatizes"],
    &["axiomatises"],
];

pub(crate) static ENTRY_AXIOMATIZE_10684888507156394817: VariantsMap = [
    &["axiomatize"],
    &["axiomatise"],
    &["axiomatize"],
    &["axiomatise"],
];

pub(crate) static ENTRY_AXIOMATIZING_1265140579235398858: VariantsMap = [
    &["axiomatizing"],
    &["axiomatising"],
    &["axiomatizing"],
    &["axiomatising"],
];

pub(crate) static ENTRY_AX_1575519092942394335: VariantsMap =
    [&["ax"], &["axe"], &["axe"], &["axe"]];

pub(crate) static ENTRY_AZOTEMIA_11026435551695672571: VariantsMap = [
    &["azotemia"],
    &["azotaemia"],
    &["azotaemia"],
    &["azotaemia"],
];

pub(crate) static ENTRY_AZOTIZATION_16963563287305367427: VariantsMap = [
    &["azotization"],
    &["azotisation"],
    &["azotization"],
    &["azotisation"],
];

pub(crate) static ENTRY_AZOTIZED_5442413055636672930: VariantsMap =
    [&["azotized"], &["azotised"], &["azotized"], &["azotised"]];

pub(crate) static ENTRY_AZOTIZES_11787523905240626686: VariantsMap =
    [&["azotizes"], &["azotises"], &["azotizes"], &["azotises"]];

pub(crate) static ENTRY_AZOTIZE_2287686933818550495: VariantsMap =
    [&["azotize"], &["azotise"], &["azotize"], &["azotise"]];

pub(crate) static ENTRY_AZOTIZING_14086470722290046366: VariantsMap = [
    &["azotizing"],
    &["azotising"],
    &["azotizing"],
    &["azotising"],
];

pub(crate) static ENTRY_AZOTORRHEA_15953136960912190838: VariantsMap = [
    &["azotorrhea"],
    &["azotorrhoea"],
    &["azotorrhoea"],
    &["azotorrhoea"],
];

pub(crate) static ENTRY_BABELIZATION_6227505335585113751: VariantsMap = [
    &["babelization"],
    &["babelisation"],
    &["babelization"],
    &["babelisation"],
];

pub(crate) static ENTRY_BABELIZED_9260063960247770923: VariantsMap = [
    &["babelized"],
    &["babelised"],
    &["babelized"],
    &["babelised"],
];

pub(crate) static ENTRY_BABELIZE_14685836478937353557: VariantsMap =
    [&["babelize"], &["babelise"], &["babelize"], &["babelise"]];

pub(crate) static ENTRY_BABELIZING_3570390515053010427: VariantsMap = [
    &["babelizing"],
    &["babelising"],
    &["babelizing"],
    &["babelising"],
];

pub(crate) static ENTRY_BABYLONIZES_15691990922940613274: VariantsMap = [
    &["babylonizes"],
    &["babylonises"],
    &["babylonizes"],
    &["babylonises"],
];

pub(crate) static ENTRY_BABYLONIZE_11002600115818594610: VariantsMap = [
    &["babylonize"],
    &["babylonise"],
    &["babylonize"],
    &["babylonise"],
];

pub(crate) static ENTRY_BACHELORIZES_18287548054552021920: VariantsMap = [
    &["bachelorizes"],
    &["bachelorises"],
    &["bachelorizes"],
    &["bachelorises"],
];

pub(crate) static ENTRY_BACHELORIZE_16140957144715523023: VariantsMap = [
    &["bachelorize"],
    &["bachelorise"],
    &["bachelorize"],
    &["bachelorise"],
];

pub(crate) static ENTRY_BACILLEMIAS_5457140517144338455: VariantsMap = [
    &["bacillemias"],
    &["bacillaemias"],
    &["bacillaemias"],
    &["bacillaemias"],
];

pub(crate) static ENTRY_BACILLEMIA_6966726555392631595: VariantsMap = [
    &["bacillemia"],
    &["bacillaemia"],
    &["bacillaemia"],
    &["bacillaemia"],
];

pub(crate) static ENTRY_BACKPEDALED_15080995488497192935: VariantsMap = [
    &["backpedaled"],
    &["backpedalled"],
    &["backpedalled"],
    &["backpedalled"],
];

pub(crate) static ENTRY_BACKPEDALING_16889760085914099362: VariantsMap = [
    &["backpedaling"],
    &["backpedalling"],
    &["backpedalling"],
    &["backpedalling"],
];

pub(crate) static ENTRY_BACONIZES_15492280776277479142: VariantsMap = [
    &["baconizes"],
    &["baconises"],
    &["baconizes"],
    &["baconises"],
];

pub(crate) static ENTRY_BACONIZE_13936618010843734949: VariantsMap =
    [&["baconize"], &["baconise"], &["baconize"], &["baconise"]];

pub(crate) static ENTRY_BACTEREMIAS_3485923405679674442: VariantsMap = [
    &["bacteremias"],
    &["bacteraemias"],
    &["bacteraemias"],
    &["bacteraemias"],
];

pub(crate) static ENTRY_BACTEREMIA_7447506279056258270: VariantsMap = [
    &["bacteremia"],
    &["bacteraemia"],
    &["bacteraemia"],
    &["bacteraemia"],
];

pub(crate) static ENTRY_BACTERIA_932829979244663072: VariantsMap =
    [&["bacteria"], &["bacteria"], &["bacteria"], &["bacteria"]];

pub(crate) static ENTRY_BACTERIEMIA_1013683590812100357: VariantsMap = [
    &["bacteriemia"],
    &["bacteriaemia"],
    &["bacteriaemia"],
    &["bacteriaemia"],
];

pub(crate) static ENTRY_BACTERIZED_2369187923965453166: VariantsMap = [
    &["bacterized"],
    &["bacterised"],
    &["bacterized"],
    &["bacterised"],
];

pub(crate) static ENTRY_BACTERIZES_16999732192120374065: VariantsMap = [
    &["bacterizes"],
    &["bacterises"],
    &["bacterizes"],
    &["bacterises"],
];

pub(crate) static ENTRY_BACTERIZE_18408113064097816790: VariantsMap = [
    &["bacterize"],
    &["bacterise"],
    &["bacterize"],
    &["bacterise"],
];

pub(crate) static ENTRY_BACTERIZING_3356633906290065053: VariantsMap = [
    &["bacterizing"],
    &["bacterising"],
    &["bacterizing"],
    &["bacterising"],
];

pub(crate) static ENTRY_BAER_14581860992483818503: VariantsMap =
    [&["baer"], &["bare"], &["bare"], &["bare"]];

pub(crate) static ENTRY_BALKANIZATIONS_1102575160899563311: VariantsMap = [
    &["balkanizations"],
    &["balkanisations"],
    &["balkanizations"],
    &["balkanisations"],
];

pub(crate) static ENTRY_BALKANIZATION_7162843825151431114: VariantsMap = [
    &["balkanization"],
    &["balkanisation"],
    &["balkanization"],
    &["balkanisation"],
];

pub(crate) static ENTRY_BALKANIZED_7283200167845869640: VariantsMap = [
    &["balkanized"],
    &["balkanised"],
    &["balkanized"],
    &["balkanised"],
];

pub(crate) static ENTRY_BALKANIZES_15710898030250571993: VariantsMap = [
    &["balkanizes"],
    &["balkanises"],
    &["balkanizes"],
    &["balkanises"],
];

pub(crate) static ENTRY_BALKANIZE_626464622875805915: VariantsMap = [
    &["balkanize"],
    &["balkanise"],
    &["balkanize"],
    &["balkanise"],
];

pub(crate) static ENTRY_BALKANIZING_2444358339203572953: VariantsMap = [
    &["balkanizing"],
    &["balkanising"],
    &["balkanizing"],
    &["balkanising"],
];

pub(crate) static ENTRY_BALKED_13168474275010509248: VariantsMap =
    [&["balked"], &["baulked"], &["balked"], &["baulked"]];

pub(crate) static ENTRY_BALKING_4782897688469985529: VariantsMap =
    [&["balking"], &["baulking"], &["balking"], &["baulking"]];

pub(crate) static ENTRY_BALKS_15300503195053466242: VariantsMap =
    [&["balks"], &["baulks"], &["balks"], &["baulks"]];

pub(crate) static ENTRY_BALK_16157341829373855465: VariantsMap =
    [&["balk"], &["baulk"], &["balk"], &["baulk"]];

pub(crate) static ENTRY_BALLADIZED_2167734885988214874: VariantsMap = [
    &["balladized"],
    &["balladised"],
    &["balladized"],
    &["balladised"],
];

pub(crate) static ENTRY_BALLADIZES_6866475825533925100: VariantsMap = [
    &["balladizes"],
    &["balladises"],
    &["balladizes"],
    &["balladises"],
];

pub(crate) static ENTRY_BALLADIZE_15696239668228025324: VariantsMap = [
    &["balladize"],
    &["balladise"],
    &["balladize"],
    &["balladise"],
];

pub(crate) static ENTRY_BALLADIZING_3534870542470368404: VariantsMap = [
    &["balladizing"],
    &["balladising"],
    &["balladizing"],
    &["balladising"],
];

pub(crate) static ENTRY_BALSAMIZES_9137778879856125866: VariantsMap = [
    &["balsamizes"],
    &["balsamises"],
    &["balsamizes"],
    &["balsamises"],
];

pub(crate) static ENTRY_BALSAMIZE_1201263166025813215: VariantsMap = [
    &["balsamize"],
    &["balsamise"],
    &["balsamize"],
    &["balsamise"],
];

pub(crate) static ENTRY_BANALIZATIONS_13442258248647777583: VariantsMap = [
    &["banalizations"],
    &["banalisations"],
    &["banalizations"],
    &["banalisations"],
];

pub(crate) static ENTRY_BANALIZATION_11638029989791824412: VariantsMap = [
    &["banalization"],
    &["banalisation"],
    &["banalization"],
    &["banalisation"],
];

pub(crate) static ENTRY_BANALIZED_7402767891348368303: VariantsMap = [
    &["banalized"],
    &["banalised"],
    &["banalized"],
    &["banalised"],
];

pub(crate) static ENTRY_BANALIZES_18046806542989340297: VariantsMap = [
    &["banalizes"],
    &["banalises"],
    &["banalizes"],
    &["banalises"],
];

pub(crate) static ENTRY_BANALIZE_3555517535598908983: VariantsMap =
    [&["banalize"], &["banalise"], &["banalize"], &["banalise"]];

pub(crate) static ENTRY_BANALIZING_4703954921087288770: VariantsMap = [
    &["banalizing"],
    &["banalising"],
    &["banalizing"],
    &["banalising"],
];

pub(crate) static ENTRY_BANTAMIZES_12701524523935305027: VariantsMap = [
    &["bantamizes"],
    &["bantamises"],
    &["bantamizes"],
    &["bantamises"],
];

pub(crate) static ENTRY_BANTAMIZE_16291863723097401467: VariantsMap = [
    &["bantamize"],
    &["bantamise"],
    &["bantamize"],
    &["bantamise"],
];

pub(crate) static ENTRY_BAPTIZABLES_14971615946689154480: VariantsMap = [
    &["baptizables"],
    &["baptisables"],
    &["baptizables"],
    &["baptisables"],
];

pub(crate) static ENTRY_BAPTIZABLE_16415989175028506130: VariantsMap = [
    &["baptizable"],
    &["baptisable"],
    &["baptizable"],
    &["baptisable"],
];

pub(crate) static ENTRY_BAPTIZED_13515788660771621839: VariantsMap =
    [&["baptized"], &["baptised"], &["baptized"], &["baptised"]];

pub(crate) static ENTRY_BAPTIZEMENTS_11049026893818752213: VariantsMap = [
    &["baptizements"],
    &["baptisements"],
    &["baptizements"],
    &["baptisements"],
];

pub(crate) static ENTRY_BAPTIZEMENT_738422419453567978: VariantsMap = [
    &["baptizement"],
    &["baptisement"],
    &["baptizement"],
    &["baptisement"],
];

pub(crate) static ENTRY_BAPTIZERS_10757448844252252817: VariantsMap = [
    &["baptizers"],
    &["baptisers"],
    &["baptizers"],
    &["baptisers"],
];

pub(crate) static ENTRY_BAPTIZER_9063381427387950458: VariantsMap =
    [&["baptizer"], &["baptiser"], &["baptizer"], &["baptiser"]];

pub(crate) static ENTRY_BAPTIZES_6929806982786773033: VariantsMap =
    [&["baptizes"], &["baptises"], &["baptizes"], &["baptises"]];

pub(crate) static ENTRY_BAPTIZE_1514931118124683391: VariantsMap =
    [&["baptize"], &["baptise"], &["baptize"], &["baptise"]];

pub(crate) static ENTRY_BAPTIZING_13695168305550097810: VariantsMap = [
    &["baptizing"],
    &["baptising"],
    &["baptizing"],
    &["baptising"],
];

pub(crate) static ENTRY_BARBARIANIZES_11395565352922752182: VariantsMap = [
    &["barbarianizes"],
    &["barbarianises"],
    &["barbarianizes"],
    &["barbarianises"],
];

pub(crate) static ENTRY_BARBARIANIZE_15261658705914178060: VariantsMap = [
    &["barbarianize"],
    &["barbarianise"],
    &["barbarianize"],
    &["barbarianise"],
];

pub(crate) static ENTRY_BARBARIZATIONS_6457370917232767902: VariantsMap = [
    &["barbarizations"],
    &["barbarisations"],
    &["barbarizations"],
    &["barbarisations"],
];

pub(crate) static ENTRY_BARBARIZATION_637634415456611000: VariantsMap = [
    &["barbarization"],
    &["barbarisation"],
    &["barbarization"],
    &["barbarisation"],
];

pub(crate) static ENTRY_BARBARIZED_408182624919762132: VariantsMap = [
    &["barbarized"],
    &["barbarised"],
    &["barbarized"],
    &["barbarised"],
];

pub(crate) static ENTRY_BARBARIZES_7081317051698057651: VariantsMap = [
    &["barbarizes"],
    &["barbarises"],
    &["barbarizes"],
    &["barbarises"],
];

pub(crate) static ENTRY_BARBARIZE_3245642365916369243: VariantsMap = [
    &["barbarize"],
    &["barbarise"],
    &["barbarize"],
    &["barbarise"],
];

pub(crate) static ENTRY_BARBARIZING_9364260930235464394: VariantsMap = [
    &["barbarizing"],
    &["barbarising"],
    &["barbarizing"],
    &["barbarising"],
];

pub(crate) static ENTRY_BARONETIZED_15717984216308695709: VariantsMap = [
    &["baronetized"],
    &["baronetised"],
    &["baronetized"],
    &["baronetised"],
];

pub(crate) static ENTRY_BARONETIZE_816321287514212290: VariantsMap = [
    &["baronetize"],
    &["baronetise"],
    &["baronetize"],
    &["baronetise"],
];

pub(crate) static ENTRY_BARONETIZING_3724487241546723880: VariantsMap = [
    &["baronetizing"],
    &["baronetising"],
    &["baronetizing"],
    &["baronetising"],
];

pub(crate) static ENTRY_BARONIZES_2387447146173200401: VariantsMap = [
    &["baronizes"],
    &["baronises"],
    &["baronizes"],
    &["baronises"],
];

pub(crate) static ENTRY_BARONIZE_14549807395279592595: VariantsMap =
    [&["baronize"], &["baronise"], &["baronize"], &["baronise"]];

pub(crate) static ENTRY_BARRELED_771246087900113850: VariantsMap = [
    &["barreled"],
    &["barrelled"],
    &["barrelled"],
    &["barrelled"],
];

pub(crate) static ENTRY_BARRELING_14371038101917122463: VariantsMap = [
    &["barreling"],
    &["barrelling"],
    &["barrelling"],
    &["barrelling"],
];

pub(crate) static ENTRY_BARTIZANED_11308940237767481814: VariantsMap = [
    &["bartizaned"],
    &["bartisaned"],
    &["bartizaned"],
    &["bartisaned"],
];

pub(crate) static ENTRY_BARTIZANS_12739620651264432470: VariantsMap = [
    &["bartizans"],
    &["bartisans"],
    &["bartizans"],
    &["bartisans"],
];

pub(crate) static ENTRY_BARTIZAN_3091667005685807749: VariantsMap =
    [&["bartizan"], &["bartisan"], &["bartizan"], &["bartisan"]];

pub(crate) static ENTRY_BARYCENTER_18352620831248386358: VariantsMap = [
    &["barycenter"],
    &["barycentre"],
    &["barycentre"],
    &["barycentre"],
];

pub(crate) static ENTRY_BASTARDIZATIONS_13505445987148951791: VariantsMap = [
    &["bastardizations"],
    &["bastardisations"],
    &["bastardizations"],
    &["bastardisations"],
];

pub(crate) static ENTRY_BASTARDIZATION_15150400898607735555: VariantsMap = [
    &["bastardization"],
    &["bastardisation"],
    &["bastardization"],
    &["bastardisation"],
];

pub(crate) static ENTRY_BASTARDIZED_15327063659865539383: VariantsMap = [
    &["bastardized"],
    &["bastardised"],
    &["bastardized"],
    &["bastardised"],
];

pub(crate) static ENTRY_BASTARDIZES_1734137171535573217: VariantsMap = [
    &["bastardizes"],
    &["bastardises"],
    &["bastardizes"],
    &["bastardises"],
];

pub(crate) static ENTRY_BASTARDIZE_17168607737816618553: VariantsMap = [
    &["bastardize"],
    &["bastardise"],
    &["bastardize"],
    &["bastardise"],
];

pub(crate) static ENTRY_BASTARDIZING_4525888023760792804: VariantsMap = [
    &["bastardizing"],
    &["bastardising"],
    &["bastardizing"],
    &["bastardising"],
];

pub(crate) static ENTRY_BASTINADED_10916132116078316936: VariantsMap = [
    &["bastinaded"],
    &["bastinadoed"],
    &["bastinadoed"],
    &["bastinadoed"],
];

pub(crate) static ENTRY_BASTINADES_16941290810871621543: VariantsMap = [
    &["bastinades"],
    &["bastinadoes"],
    &["bastinadoes"],
    &["bastinadoes"],
];

pub(crate) static ENTRY_BATTLEAXE_15052343884109974687: VariantsMap = [
    &["battleaxe"],
    &["battleaxe"],
    &["battleaxe"],
    &["battleaxe"],
];

pub(crate) static ENTRY_BATTOLOGIZED_12783274211026027611: VariantsMap = [
    &["battologized"],
    &["battologised"],
    &["battologized"],
    &["battologised"],
];

pub(crate) static ENTRY_BATTOLOGIZE_12105586747261105341: VariantsMap = [
    &["battologize"],
    &["battologise"],
    &["battologize"],
    &["battologise"],
];

pub(crate) static ENTRY_BATTOLOGIZING_6018370845171871626: VariantsMap = [
    &["battologizing"],
    &["battologising"],
    &["battologizing"],
    &["battologising"],
];

pub(crate) static ENTRY_BEAVERIZES_3003655027714564574: VariantsMap = [
    &["beaverizes"],
    &["beaverises"],
    &["beaverizes"],
    &["beaverises"],
];

pub(crate) static ENTRY_BEAVERIZE_17666585249999378311: VariantsMap = [
    &["beaverize"],
    &["beaverise"],
    &["beaverize"],
    &["beaverise"],
];

pub(crate) static ENTRY_BECLAMORED_11429770894371708638: VariantsMap = [
    &["beclamored"],
    &["beclamoured"],
    &["beclamoured"],
    &["beclamoured"],
];

pub(crate) static ENTRY_BECLAMORING_9503333775494226894: VariantsMap = [
    &["beclamoring"],
    &["beclamouring"],
    &["beclamouring"],
    &["beclamouring"],
];

pub(crate) static ENTRY_BECLAMORS_13615720098742172165: VariantsMap = [
    &["beclamors"],
    &["beclamours"],
    &["beclamours"],
    &["beclamours"],
];

pub(crate) static ENTRY_BECLAMOR_15010060560531866056: VariantsMap = [
    &["beclamor"],
    &["beclamour"],
    &["beclamour"],
    &["beclamour"],
];

pub(crate) static ENTRY_BECOLOR_1820125413532981726: VariantsMap =
    [&["becolor"], &["becolour"], &["becolour"], &["becolour"]];

pub(crate) static ENTRY_BECUDGELED_10688892400774535279: VariantsMap = [
    &["becudgeled"],
    &["becudgelled"],
    &["becudgelled"],
    &["becudgelled"],
];

pub(crate) static ENTRY_BECUDGELING_2856359572329458860: VariantsMap = [
    &["becudgeling"],
    &["becudgelling"],
    &["becudgelling"],
    &["becudgelling"],
];

pub(crate) static ENTRY_BEDEVILED_14137634025943909745: VariantsMap = [
    &["bedeviled"],
    &["bedevilled"],
    &["bedevilled"],
    &["bedevilled"],
];

pub(crate) static ENTRY_BEDEVILING_3264516468398917500: VariantsMap = [
    &["bedeviling"],
    &["bedevilling"],
    &["bedevilling"],
    &["bedevilling"],
];

pub(crate) static ENTRY_BEDLAMIZED_8070235127373715475: VariantsMap = [
    &["bedlamized"],
    &["bedlamised"],
    &["bedlamized"],
    &["bedlamised"],
];

pub(crate) static ENTRY_BEDLAMIZES_2905803091441936414: VariantsMap = [
    &["bedlamizes"],
    &["bedlamises"],
    &["bedlamizes"],
    &["bedlamises"],
];

pub(crate) static ENTRY_BEDLAMIZE_8032432031457666621: VariantsMap = [
    &["bedlamize"],
    &["bedlamise"],
    &["bedlamize"],
    &["bedlamise"],
];

pub(crate) static ENTRY_BEDLAMIZING_5249207699535847866: VariantsMap = [
    &["bedlamizing"],
    &["bedlamising"],
    &["bedlamizing"],
    &["bedlamising"],
];

pub(crate) static ENTRY_BEDRIVELED_16825680695984036015: VariantsMap = [
    &["bedriveled"],
    &["bedrivelled"],
    &["bedrivelled"],
    &["bedrivelled"],
];

pub(crate) static ENTRY_BEDRIVELING_12159930547505129231: VariantsMap = [
    &["bedriveling"],
    &["bedrivelling"],
    &["bedrivelling"],
    &["bedrivelling"],
];

pub(crate) static ENTRY_BEERA_6010693163623887132: VariantsMap =
    [&["beera"], &["berea"], &["berea"], &["berea"]];

pub(crate) static ENTRY_BEFAVOR_4929864496662345763: VariantsMap =
    [&["befavor"], &["befavour"], &["befavour"], &["befavour"]];

pub(crate) static ENTRY_BEGLAMORED_17236768717735314854: VariantsMap = [
    &["beglamored"],
    &["beglamoured"],
    &["beglamoured"],
    &["beglamoured"],
];

pub(crate) static ENTRY_BEGLAMORING_16675826950855681606: VariantsMap = [
    &["beglamoring"],
    &["beglamouring"],
    &["beglamouring"],
    &["beglamouring"],
];

pub(crate) static ENTRY_BEGLAMORS_12605296861327651664: VariantsMap = [
    &["beglamors"],
    &["beglamours"],
    &["beglamours"],
    &["beglamours"],
];

pub(crate) static ENTRY_BEGLAMOR_13712112495668100470: VariantsMap = [
    &["beglamor"],
    &["beglamour"],
    &["beglamour"],
    &["beglamour"],
];

pub(crate) static ENTRY_BEHAVIORALER_6184370577289856922: VariantsMap = [
    &["behavioraler"],
    &["behaviouraler"],
    &["behaviouraler"],
    &["behaviouraler"],
];

pub(crate) static ENTRY_BEHAVIORALEST_3631208384433367206: VariantsMap = [
    &["behavioralest"],
    &["behaviouralest"],
    &["behaviouralest"],
    &["behaviouralest"],
];

pub(crate) static ENTRY_BEHAVIORALLY_3392730520394326300: VariantsMap = [
    &["behaviorally"],
    &["behaviourally"],
    &["behaviourally"],
    &["behaviourally"],
];

pub(crate) static ENTRY_BEHAVIORAL_16431863374575357094: VariantsMap = [
    &["behavioral"],
    &["behavioural"],
    &["behavioural"],
    &["behavioural"],
];

pub(crate) static ENTRY_BEHAVIORED_496799855263187779: VariantsMap = [
    &["behaviored"],
    &["behavioured"],
    &["behavioured"],
    &["behavioured"],
];

pub(crate) static ENTRY_BEHAVIORISMS_1554586755841111618: VariantsMap = [
    &["behaviorisms"],
    &["behaviourisms"],
    &["behaviourisms"],
    &["behaviourisms"],
];

pub(crate) static ENTRY_BEHAVIORISM_4176615940346575759: VariantsMap = [
    &["behaviorism"],
    &["behaviourism"],
    &["behaviourism"],
    &["behaviourism"],
];

pub(crate) static ENTRY_BEHAVIORISTICER_3955710407140770528: VariantsMap = [
    &["behavioristicer"],
    &["behaviouristicer"],
    &["behaviouristicer"],
    &["behaviouristicer"],
];

pub(crate) static ENTRY_BEHAVIORISTICEST_9606870366866079149: VariantsMap = [
    &["behavioristicest"],
    &["behaviouristicest"],
    &["behaviouristicest"],
    &["behaviouristicest"],
];

pub(crate) static ENTRY_BEHAVIORISTICS_18376773413500646501: VariantsMap = [
    &["behavioristics"],
    &["behaviouristics"],
    &["behaviouristics"],
    &["behaviouristics"],
];

pub(crate) static ENTRY_BEHAVIORISTIC_2362575912476199312: VariantsMap = [
    &["behavioristic"],
    &["behaviouristic"],
    &["behaviouristic"],
    &["behaviouristic"],
];

pub(crate) static ENTRY_BEHAVIORISTS_16129454263271072388: VariantsMap = [
    &["behaviorists"],
    &["behaviourists"],
    &["behaviourists"],
    &["behaviourists"],
];

pub(crate) static ENTRY_BEHAVIORIST_5628596059711288582: VariantsMap = [
    &["behaviorist"],
    &["behaviourist"],
    &["behaviourist"],
    &["behaviourist"],
];

pub(crate) static ENTRY_BEHAVIORS_3758424170765605620: VariantsMap = [
    &["behaviors"],
    &["behaviours"],
    &["behaviours"],
    &["behaviours"],
];

pub(crate) static ENTRY_BEHAVIOR_14651200144504457213: VariantsMap = [
    &["behavior"],
    &["behaviour"],
    &["behaviour"],
    &["behaviour"],
];

pub(crate) static ENTRY_BEHMENISM_16450421455239972566: VariantsMap = [
    &["behmenism"],
    &["boehmenism"],
    &["boehmenism"],
    &["boehmenism"],
];

pub(crate) static ENTRY_BEHMENIST_12053790631810257124: VariantsMap = [
    &["behmenist"],
    &["boehmenist"],
    &["boehmenist"],
    &["boehmenist"],
];

pub(crate) static ENTRY_BEHMENITE_3335321400081704671: VariantsMap = [
    &["behmenite"],
    &["boehmenite"],
    &["boehmenite"],
    &["boehmenite"],
];

pub(crate) static ENTRY_BEHOOVED_1655251573785223409: VariantsMap =
    [&["behooved"], &["behoved"], &["behooved"], &["behoved"]];

pub(crate) static ENTRY_BEHOOVES_3868425672448610419: VariantsMap =
    [&["behooves"], &["behoves"], &["behooves"], &["behoves"]];

pub(crate) static ENTRY_BEHOOVE_6147219241654589987: VariantsMap =
    [&["behoove"], &["behove"], &["behoove"], &["behove"]];

pub(crate) static ENTRY_BEHOOVINGLY_4751705039419506689: VariantsMap = [
    &["behoovingly"],
    &["behovingly"],
    &["behovingly"],
    &["behovingly"],
];

pub(crate) static ENTRY_BEHOOVINGS_8205659410382773823: VariantsMap = [
    &["behoovings"],
    &["behovings"],
    &["behoovings"],
    &["behovings"],
];

pub(crate) static ENTRY_BEHOOVING_8088190138647815853: VariantsMap =
    [&["behooving"], &["behoving"], &["behooving"], &["behoving"]];

pub(crate) static ENTRY_BEJEWELED_4984569160882024545: VariantsMap = [
    &["bejeweled"],
    &["bejewelled"],
    &["bejewelled"],
    &["bejewelled"],
];

pub(crate) static ENTRY_BEJEWELING_6307871362607074541: VariantsMap = [
    &["bejeweling"],
    &["bejewelling"],
    &["bejewelling"],
    &["bejewelling"],
];

pub(crate) static ENTRY_BELABORED_2071671744170951559: VariantsMap = [
    &["belabored"],
    &["belaboured"],
    &["belaboured"],
    &["belaboured"],
];

pub(crate) static ENTRY_BELABORING_1181160254749158200: VariantsMap = [
    &["belaboring"],
    &["belabouring"],
    &["belabouring"],
    &["belabouring"],
];

pub(crate) static ENTRY_BELABORS_6186916057783206938: VariantsMap = [
    &["belabors"],
    &["belabours"],
    &["belabours"],
    &["belabours"],
];

pub(crate) static ENTRY_BELABOR_9577593579762971199: VariantsMap =
    [&["belabor"], &["belabour"], &["belabour"], &["belabour"]];

pub(crate) static ENTRY_BELS_17074483974516039729: VariantsMap =
    [&["bels"], &["baels"], &["baels"], &["baels"]];

pub(crate) static ENTRY_BELTER_6595324842513246324: VariantsMap =
    [&["belter"], &["boelter"], &["boelter"], &["boelter"]];

pub(crate) static ENTRY_BELUS_10707973760047908555: VariantsMap =
    [&["belus"], &["boelus"], &["boelus"], &["boelus"]];

pub(crate) static ENTRY_BEL_14468840991245400678: VariantsMap =
    [&["bel"], &["bael"], &["bael"], &["bael"]];

pub(crate) static ENTRY_BEMEDALED_11565185958895431981: VariantsMap = [
    &["bemedaled"],
    &["bemedalled"],
    &["bemedalled"],
    &["bemedalled"],
];

pub(crate) static ENTRY_BERIA_6249864324866743848: VariantsMap =
    [&["beria"], &["baeria"], &["baeria"], &["baeria"]];

pub(crate) static ENTRY_BERLINIZES_5780526359977067580: VariantsMap = [
    &["berlinizes"],
    &["berlinises"],
    &["berlinizes"],
    &["berlinises"],
];

pub(crate) static ENTRY_BERLINIZE_15633104344359694284: VariantsMap = [
    &["berlinize"],
    &["berlinise"],
    &["berlinize"],
    &["berlinise"],
];

pub(crate) static ENTRY_BERLOQUE_16973140256876933299: VariantsMap =
    [&["berloque"], &["breloque"], &["breloque"], &["breloque"]];

pub(crate) static ENTRY_BERL_1185444321092270619: VariantsMap =
    [&["berl"], &["baerl"], &["baerl"], &["baerl"]];

pub(crate) static ENTRY_BERME_13467983052397932132: VariantsMap =
    [&["berme"], &["breme"], &["breme"], &["breme"]];

pub(crate) static ENTRY_BERN_9411483658541257171: VariantsMap =
    [&["bern"], &["bren"], &["bren"], &["bren"]];

pub(crate) static ENTRY_BESSEMERIZES_6207831075537789134: VariantsMap = [
    &["bessemerizes"],
    &["bessemerises"],
    &["bessemerizes"],
    &["bessemerises"],
];

pub(crate) static ENTRY_BESSEMERIZE_14474112216075710864: VariantsMap = [
    &["bessemerize"],
    &["bessemerise"],
    &["bessemerize"],
    &["bessemerise"],
];

pub(crate) static ENTRY_BESTIALIZED_9547393233273320821: VariantsMap = [
    &["bestialized"],
    &["bestialised"],
    &["bestialized"],
    &["bestialised"],
];

pub(crate) static ENTRY_BESTIALIZES_1393652725255993657: VariantsMap = [
    &["bestializes"],
    &["bestialises"],
    &["bestializes"],
    &["bestialises"],
];

pub(crate) static ENTRY_BESTIALIZE_3056063670726597576: VariantsMap = [
    &["bestialize"],
    &["bestialise"],
    &["bestialize"],
    &["bestialise"],
];

pub(crate) static ENTRY_BESTIALIZING_3683935903600606612: VariantsMap = [
    &["bestializing"],
    &["bestialising"],
    &["bestializing"],
    &["bestialising"],
];

pub(crate) static ENTRY_BEVELED_464364200154775119: VariantsMap =
    [&["beveled"], &["bevelled"], &["bevelled"], &["bevelled"]];

pub(crate) static ENTRY_BEVELERS_9232933359348996649: VariantsMap = [
    &["bevelers"],
    &["bevellers"],
    &["bevellers"],
    &["bevellers"],
];

pub(crate) static ENTRY_BEVELER_2560516573011394819: VariantsMap =
    [&["beveler"], &["beveller"], &["beveller"], &["beveller"]];

pub(crate) static ENTRY_BEVELINGS_2452856377064833303: VariantsMap = [
    &["bevelings"],
    &["bevellings"],
    &["bevellings"],
    &["bevellings"],
];

pub(crate) static ENTRY_BEVELING_10855109562149223001: VariantsMap = [
    &["beveling"],
    &["bevelling"],
    &["bevelling"],
    &["bevelling"],
];

pub(crate) static ENTRY_BEYER_14898169439752870815: VariantsMap =
    [&["beyer"], &["baeyer"], &["baeyer"], &["baeyer"]];

pub(crate) static ENTRY_BIASED_1791974261124589682: VariantsMap =
    [&["biased"], &["biased"], &["biased"], &["biased"]];

pub(crate) static ENTRY_BIASING_6997021477668826126: VariantsMap =
    [&["biasing"], &["biasing"], &["biasing"], &["biasing"]];

pub(crate) static ENTRY_BICHROMATIZES_11938767258104126504: VariantsMap = [
    &["bichromatizes"],
    &["bichromatises"],
    &["bichromatizes"],
    &["bichromatises"],
];

pub(crate) static ENTRY_BICHROMATIZE_6575837359582309819: VariantsMap = [
    &["bichromatize"],
    &["bichromatise"],
    &["bichromatize"],
    &["bichromatise"],
];

pub(crate) static ENTRY_BICOLOREDDER_8362361841051385390: VariantsMap = [
    &["bicoloredder"],
    &["bicolouredder"],
    &["bicolouredder"],
    &["bicolouredder"],
];

pub(crate) static ENTRY_BICOLOREDDEST_8676331588438394982: VariantsMap = [
    &["bicoloreddest"],
    &["bicoloureddest"],
    &["bicoloureddest"],
    &["bicoloureddest"],
];

pub(crate) static ENTRY_BICOLORED_434708862208065723: VariantsMap = [
    &["bicolored"],
    &["bicoloured"],
    &["bicoloured"],
    &["bicoloured"],
];

pub(crate) static ENTRY_BICOLOROUS_9012574496998947343: VariantsMap = [
    &["bicolorous"],
    &["bicolourous"],
    &["bicolourous"],
    &["bicolourous"],
];

pub(crate) static ENTRY_BICOLORRER_5653522831142191999: VariantsMap = [
    &["bicolorrer"],
    &["bicolourer"],
    &["bicolourer"],
    &["bicolourer"],
];

pub(crate) static ENTRY_BICOLORREST_693010655310508411: VariantsMap = [
    &["bicolorrest"],
    &["bicolourest"],
    &["bicolourest"],
    &["bicolourest"],
];

pub(crate) static ENTRY_BICOLORS_9368006477019357638: VariantsMap = [
    &["bicolors"],
    &["bicolours"],
    &["bicolours"],
    &["bicolours"],
];

pub(crate) static ENTRY_BICOLOR_10164358994113091705: VariantsMap =
    [&["bicolor"], &["bicolour"], &["bicolour"], &["bicolour"]];

pub(crate) static ENTRY_BIMETALISTIC_10704026739410878685: VariantsMap = [
    &["bimetalistic"],
    &["bimetallistic"],
    &["bimetallistic"],
    &["bimetallistic"],
];

pub(crate) static ENTRY_BIMETALIST_7071235615867580313: VariantsMap = [
    &["bimetalist"],
    &["bimetallist"],
    &["bimetallist"],
    &["bimetallist"],
];

pub(crate) static ENTRY_BINGEING_14277432149077039485: VariantsMap =
    [&["bingeing"], &["bingeing"], &["bingeing"], &["bingeing"]];

pub(crate) static ENTRY_BIOCENOLOGY_14689209691235014054: VariantsMap = [
    &["biocenology"],
    &["biocoenology"],
    &["biocoenology"],
    &["biocoenology"],
];

pub(crate) static ENTRY_BIOCENOSES_13501584028527836531: VariantsMap = [
    &["biocenoses"],
    &["biocoenoses"],
    &["biocoenoses"],
    &["biocoenoses"],
];

pub(crate) static ENTRY_BIOCENOSE_3138770096544861410: VariantsMap = [
    &["biocenose"],
    &["biocoenose"],
    &["biocoenose"],
    &["biocoenose"],
];

pub(crate) static ENTRY_BIOCENOSIS_8916166807214256078: VariantsMap = [
    &["biocenosis"],
    &["biocoenosis"],
    &["biocoenosis"],
    &["biocoenosis"],
];

pub(crate) static ENTRY_BIOCENOTIC_8654469384514575281: VariantsMap = [
    &["biocenotic"],
    &["biocoenotic"],
    &["biocoenotic"],
    &["biocoenotic"],
];

pub(crate) static ENTRY_BIOGRAPHIZES_9794450292227006800: VariantsMap = [
    &["biographizes"],
    &["biographises"],
    &["biographizes"],
    &["biographises"],
];

pub(crate) static ENTRY_BIOGRAPHIZE_3101270671578058317: VariantsMap = [
    &["biographize"],
    &["biographise"],
    &["biographize"],
    &["biographise"],
];

pub(crate) static ENTRY_BIOLOGIZES_3124510342898949248: VariantsMap = [
    &["biologizes"],
    &["biologises"],
    &["biologizes"],
    &["biologises"],
];

pub(crate) static ENTRY_BIOLOGIZE_7350607900569346229: VariantsMap = [
    &["biologize"],
    &["biologise"],
    &["biologize"],
    &["biologise"],
];

pub(crate) static ENTRY_BIOSYNTHESIZED_13192699560463879497: VariantsMap = [
    &["biosynthesized"],
    &["biosynthesised"],
    &["biosynthesized"],
    &["biosynthesised"],
];

pub(crate) static ENTRY_BIPOLARIZATION_8043840355082199256: VariantsMap = [
    &["bipolarization"],
    &["bipolarisation"],
    &["bipolarization"],
    &["bipolarisation"],
];

pub(crate) static ENTRY_BIPOLARIZES_9309819257597037093: VariantsMap = [
    &["bipolarizes"],
    &["bipolarises"],
    &["bipolarizes"],
    &["bipolarises"],
];

pub(crate) static ENTRY_BIPOLARIZE_7871964341365869167: VariantsMap = [
    &["bipolarize"],
    &["bipolarise"],
    &["bipolarize"],
    &["bipolarise"],
];

pub(crate) static ENTRY_BIRMINGHAMIZES_18070978989186779877: VariantsMap = [
    &["birminghamizes"],
    &["birminghamises"],
    &["birminghamizes"],
    &["birminghamises"],
];

pub(crate) static ENTRY_BIRMINGHAMIZE_8569250108140387650: VariantsMap = [
    &["birminghamize"],
    &["birminghamise"],
    &["birminghamize"],
    &["birminghamise"],
];

pub(crate) static ENTRY_BISTEREDDER_4919702072233220862: VariantsMap = [
    &["bisteredder"],
    &["bistredder"],
    &["bistredder"],
    &["bistredder"],
];

pub(crate) static ENTRY_BISTEREDDEST_8076651195429169182: VariantsMap = [
    &["bistereddest"],
    &["bistreddest"],
    &["bistreddest"],
    &["bistreddest"],
];

pub(crate) static ENTRY_BISTERED_12594354785868849372: VariantsMap =
    [&["bistered"], &["bistred"], &["bistred"], &["bistred"]];

pub(crate) static ENTRY_BISTERS_2497112586905993305: VariantsMap =
    [&["bisters"], &["bistres"], &["bistres"], &["bistres"]];

pub(crate) static ENTRY_BISTER_12243394786223476364: VariantsMap =
    [&["bister"], &["bistre"], &["bistre"], &["bistre"]];

pub(crate) static ENTRY_BITTORS_11286171863858275118: VariantsMap =
    [&["bittors"], &["bittours"], &["bittours"], &["bittours"]];

pub(crate) static ENTRY_BITTOR_17121981854551948147: VariantsMap =
    [&["bittor"], &["bittour"], &["bittour"], &["bittour"]];

pub(crate) static ENTRY_BITUMINIZATIONS_4430255676913937183: VariantsMap = [
    &["bituminizations"],
    &["bituminisations"],
    &["bituminizations"],
    &["bituminisations"],
];

pub(crate) static ENTRY_BITUMINIZATION_17454899386160960184: VariantsMap = [
    &["bituminization"],
    &["bituminisation"],
    &["bituminization"],
    &["bituminisation"],
];

pub(crate) static ENTRY_BITUMINIZED_3973700773638176633: VariantsMap = [
    &["bituminized"],
    &["bituminised"],
    &["bituminized"],
    &["bituminised"],
];

pub(crate) static ENTRY_BITUMINIZES_15984764105434279145: VariantsMap = [
    &["bituminizes"],
    &["bituminises"],
    &["bituminizes"],
    &["bituminises"],
];

pub(crate) static ENTRY_BITUMINIZE_18416379614821284335: VariantsMap = [
    &["bituminize"],
    &["bituminise"],
    &["bituminize"],
    &["bituminise"],
];

pub(crate) static ENTRY_BITUMINIZING_14018683945005443597: VariantsMap = [
    &["bituminizing"],
    &["bituminising"],
    &["bituminizing"],
    &["bituminising"],
];

pub(crate) static ENTRY_BIZET_4586471071545262019: VariantsMap =
    [&["bizet"], &["biset"], &["bizet"], &["biset"]];

pub(crate) static ENTRY_BIZE_12936627068566021826: VariantsMap =
    [&["bize"], &["bise"], &["bize"], &["bise"]];

pub(crate) static ENTRY_BLAIZE_1220632059692388861: VariantsMap =
    [&["blaize"], &["blaise"], &["blaize"], &["blaise"]];

pub(crate) static ENTRY_BLAMABLE_7328528693620793783: VariantsMap = [
    &["blamable"],
    &["blameable"],
    &["blameable"],
    &["blameable"],
];

pub(crate) static ENTRY_BLASTOCELE_18161446415449857731: VariantsMap = [
    &["blastocele"],
    &["blastocoele"],
    &["blastocoele"],
    &["blastocoele"],
];

pub(crate) static ENTRY_BLASTULE_6565332400736377843: VariantsMap = [
    &["blastule"],
    &["blastulae"],
    &["blastulae"],
    &["blastulae"],
];

pub(crate) static ENTRY_BLENNEMESIS_12408003891077842527: VariantsMap = [
    &["blennemesis"],
    &["blennoemesis"],
    &["blennoemesis"],
    &["blennoemesis"],
];

pub(crate) static ENTRY_BLENNORRHEA_2218782057410422271: VariantsMap = [
    &["blennorrhea"],
    &["blennorrhoea"],
    &["blennorrhoea"],
    &["blennorrhoea"],
];

pub(crate) static ENTRY_BOEDROMIUS_10140569261433699587: VariantsMap = [
    &["boedromius"],
    &["boaedromius"],
    &["boaedromius"],
    &["boaedromius"],
];

pub(crate) static ENTRY_BOLED_14696249241634637180: VariantsMap =
    [&["boled"], &["boloed"], &["boloed"], &["boloed"]];

pub(crate) static ENTRY_BOLSHEVIZED_12985511351822149082: VariantsMap = [
    &["bolshevized"],
    &["bolshevised"],
    &["bolshevized"],
    &["bolshevised"],
];

pub(crate) static ENTRY_BOLSHEVIZES_2750006029755985666: VariantsMap = [
    &["bolshevizes"],
    &["bolshevises"],
    &["bolshevizes"],
    &["bolshevises"],
];

pub(crate) static ENTRY_BOLSHEVIZE_9295222616139275092: VariantsMap = [
    &["bolshevize"],
    &["bolshevise"],
    &["bolshevize"],
    &["bolshevise"],
];

pub(crate) static ENTRY_BOLSHEVIZING_2242830870498003369: VariantsMap = [
    &["bolshevizing"],
    &["bolshevising"],
    &["bolshevizing"],
    &["bolshevising"],
];

pub(crate) static ENTRY_BONDERIZE_7272076124653249026: VariantsMap = [
    &["bonderize"],
    &["bonderise"],
    &["bonderize"],
    &["bonderise"],
];

pub(crate) static ENTRY_BORAGE_11906407082412349878: VariantsMap =
    [&["borage"], &["bourage"], &["bourage"], &["bourage"]];

pub(crate) static ENTRY_BORASQUE_12463950773551631809: VariantsMap = [
    &["borasque"],
    &["bourasque"],
    &["bourasque"],
    &["bourasque"],
];

pub(crate) static ENTRY_BORDS_7324219903916101004: VariantsMap =
    [&["bords"], &["bourds"], &["bourds"], &["bourds"]];

pub(crate) static ENTRY_BORD_18164452795863545372: VariantsMap =
    [&["bord"], &["bourd"], &["bourd"], &["bourd"]];

pub(crate) static ENTRY_BORG_5368387535636175671: VariantsMap =
    [&["borg"], &["bourg"], &["bourg"], &["bourg"]];

pub(crate) static ENTRY_BORIZES_16866165125304621719: VariantsMap =
    [&["borizes"], &["borises"], &["borizes"], &["borises"]];

pub(crate) static ENTRY_BORIZE_10330616917016533656: VariantsMap =
    [&["borize"], &["borise"], &["borize"], &["borise"]];

pub(crate) static ENTRY_BOR_15726996487969007319: VariantsMap =
    [&["bor"], &["bour"], &["bour"], &["bour"]];

pub(crate) static ENTRY_BOSWELLIZED_8124331813443724374: VariantsMap = [
    &["boswellized"],
    &["boswellised"],
    &["boswellized"],
    &["boswellised"],
];

pub(crate) static ENTRY_BOSWELLIZES_11578704107127902682: VariantsMap = [
    &["boswellizes"],
    &["boswellises"],
    &["boswellizes"],
    &["boswellises"],
];

pub(crate) static ENTRY_BOSWELLIZE_3698602768600626065: VariantsMap = [
    &["boswellize"],
    &["boswellise"],
    &["boswellize"],
    &["boswellise"],
];

pub(crate) static ENTRY_BOSWELLIZING_5812126249996086388: VariantsMap = [
    &["boswellizing"],
    &["boswellising"],
    &["boswellizing"],
    &["boswellising"],
];

pub(crate) static ENTRY_BOTANIZED_6978246195480656091: VariantsMap = [
    &["botanized"],
    &["botanised"],
    &["botanized"],
    &["botanised"],
];

pub(crate) static ENTRY_BOTANIZER_10688902380199603159: VariantsMap = [
    &["botanizer"],
    &["botaniser"],
    &["botanizer"],
    &["botaniser"],
];

pub(crate) static ENTRY_BOTANIZES_4460206956631925576: VariantsMap = [
    &["botanizes"],
    &["botanises"],
    &["botanizes"],
    &["botanises"],
];

pub(crate) static ENTRY_BOTANIZE_7551170961793070479: VariantsMap =
    [&["botanize"], &["botanise"], &["botanize"], &["botanise"]];

pub(crate) static ENTRY_BOTANIZING_15845930378851783636: VariantsMap = [
    &["botanizing"],
    &["botanising"],
    &["botanizing"],
    &["botanising"],
];

pub(crate) static ENTRY_BOULDERS_3864700166179251654: VariantsMap =
    [&["boulders"], &["boulders"], &["boulders"], &["boulders"]];

pub(crate) static ENTRY_BOULDER_12516261271833260895: VariantsMap =
    [&["boulder"], &["boulder"], &["boulder"], &["boulder"]];

pub(crate) static ENTRY_BOULEVARDIZES_9859087317378411554: VariantsMap = [
    &["boulevardizes"],
    &["boulevardises"],
    &["boulevardizes"],
    &["boulevardises"],
];

pub(crate) static ENTRY_BOULEVARDIZE_8185506525213597267: VariantsMap = [
    &["boulevardize"],
    &["boulevardise"],
    &["boulevardize"],
    &["boulevardise"],
];

pub(crate) static ENTRY_BOURBONIZES_14462412263603486786: VariantsMap = [
    &["bourbonizes"],
    &["bourbonises"],
    &["bourbonizes"],
    &["bourbonises"],
];

pub(crate) static ENTRY_BOURBONIZE_1178395603606873081: VariantsMap = [
    &["bourbonize"],
    &["bourbonise"],
    &["bourbonize"],
    &["bourbonise"],
];

pub(crate) static ENTRY_BOWDLERIZATIONS_4765159417978820500: VariantsMap = [
    &["bowdlerizations"],
    &["bowdlerisations"],
    &["bowdlerizations"],
    &["bowdlerisations"],
];

pub(crate) static ENTRY_BOWDLERIZATION_15003666665570033944: VariantsMap = [
    &["bowdlerization"],
    &["bowdlerisation"],
    &["bowdlerization"],
    &["bowdlerisation"],
];

pub(crate) static ENTRY_BOWDLERIZED_11555956899762270807: VariantsMap = [
    &["bowdlerized"],
    &["bowdlerised"],
    &["bowdlerized"],
    &["bowdlerised"],
];

pub(crate) static ENTRY_BOWDLERIZERS_3135273670642498247: VariantsMap = [
    &["bowdlerizers"],
    &["bowdlerisers"],
    &["bowdlerizers"],
    &["bowdlerisers"],
];

pub(crate) static ENTRY_BOWDLERIZER_9391658950288862007: VariantsMap = [
    &["bowdlerizer"],
    &["bowdleriser"],
    &["bowdlerizer"],
    &["bowdleriser"],
];

pub(crate) static ENTRY_BOWDLERIZES_996948036211004202: VariantsMap = [
    &["bowdlerizes"],
    &["bowdlerises"],
    &["bowdlerizes"],
    &["bowdlerises"],
];

pub(crate) static ENTRY_BOWDLERIZE_3564223313490479365: VariantsMap = [
    &["bowdlerize"],
    &["bowdlerise"],
    &["bowdlerize"],
    &["bowdlerise"],
];

pub(crate) static ENTRY_BOWDLERIZING_8658675993569127303: VariantsMap = [
    &["bowdlerizing"],
    &["bowdlerising"],
    &["bowdlerizing"],
    &["bowdlerising"],
];

pub(crate) static ENTRY_BOWELED_17573142053252288008: VariantsMap =
    [&["boweled"], &["bowelled"], &["bowelled"], &["bowelled"]];

pub(crate) static ENTRY_BOWELING_12067574292037953398: VariantsMap = [
    &["boweling"],
    &["bowelling"],
    &["bowelling"],
    &["bowelling"],
];

pub(crate) static ENTRY_BRADYPNEA_14990069084802510573: VariantsMap = [
    &["bradypnea"],
    &["bradypnoea"],
    &["bradypnoea"],
    &["bradypnoea"],
];

pub(crate) static ENTRY_BREATHALYZED_10540875853111278249: VariantsMap = [
    &["breathalyzed"],
    &["breathalysed"],
    &["breathalyzed"],
    &["breathalysed"],
];

pub(crate) static ENTRY_BREATHALYZERS_7686418927650730063: VariantsMap = [
    &["breathalyzers"],
    &["breathalysers"],
    &["breathalysers"],
    &["breathalysers"],
];

pub(crate) static ENTRY_BREATHALYZER_15434122011452224968: VariantsMap = [
    &["breathalyzer"],
    &["breathalyser"],
    &["breathalyser"],
    &["breathalyser"],
];

pub(crate) static ENTRY_BREATHALYZES_15395076049944664352: VariantsMap = [
    &["breathalyzes"],
    &["breathalyses"],
    &["breathalyzes"],
    &["breathalyses"],
];

pub(crate) static ENTRY_BREATHALYZE_10553810929293173557: VariantsMap = [
    &["breathalyze"],
    &["breathalyse"],
    &["breathalyze"],
    &["breathalyse"],
];

pub(crate) static ENTRY_BREATHALYZING_9538292620264111634: VariantsMap = [
    &["breathalyzing"],
    &["breathalysing"],
    &["breathalyzing"],
    &["breathalysing"],
];

pub(crate) static ENTRY_BRIZA_6020459019937063540: VariantsMap =
    [&["briza"], &["brisa"], &["briza"], &["brisa"]];

pub(crate) static ENTRY_BROMETHYLENE_12089993515876146438: VariantsMap = [
    &["bromethylene"],
    &["bromoethylene"],
    &["bromoethylene"],
    &["bromoethylene"],
];

pub(crate) static ENTRY_BROMINIZES_11166943960094705541: VariantsMap = [
    &["brominizes"],
    &["brominises"],
    &["brominizes"],
    &["brominises"],
];

pub(crate) static ENTRY_BROMINIZE_17329310617302550026: VariantsMap = [
    &["brominize"],
    &["brominise"],
    &["brominize"],
    &["brominise"],
];

pub(crate) static ENTRY_BROMIZATION_2640938302052484551: VariantsMap = [
    &["bromization"],
    &["bromisation"],
    &["bromization"],
    &["bromisation"],
];

pub(crate) static ENTRY_BROMIZED_1262409682973727998: VariantsMap =
    [&["bromized"], &["bromised"], &["bromized"], &["bromised"]];

pub(crate) static ENTRY_BROMIZE_9408768460954085967: VariantsMap =
    [&["bromize"], &["bromise"], &["bromize"], &["bromise"]];

pub(crate) static ENTRY_BROMIZING_11142091927559534073: VariantsMap = [
    &["bromizing"],
    &["bromising"],
    &["bromizing"],
    &["bromising"],
];

pub(crate) static ENTRY_BRUTALIZATIONS_14502881577076747180: VariantsMap = [
    &["brutalizations"],
    &["brutalisations"],
    &["brutalizations"],
    &["brutalisations"],
];

pub(crate) static ENTRY_BRUTALIZATION_5823277448598256026: VariantsMap = [
    &["brutalization"],
    &["brutalisation"],
    &["brutalization"],
    &["brutalisation"],
];

pub(crate) static ENTRY_BRUTALIZED_12350992663397007437: VariantsMap = [
    &["brutalized"],
    &["brutalised"],
    &["brutalized"],
    &["brutalised"],
];

pub(crate) static ENTRY_BRUTALIZES_14319976079482108516: VariantsMap = [
    &["brutalizes"],
    &["brutalises"],
    &["brutalizes"],
    &["brutalises"],
];

pub(crate) static ENTRY_BRUTALIZE_15445890938697612049: VariantsMap = [
    &["brutalize"],
    &["brutalise"],
    &["brutalize"],
    &["brutalise"],
];

pub(crate) static ENTRY_BRUTALIZING_17352191512105797054: VariantsMap = [
    &["brutalizing"],
    &["brutalising"],
    &["brutalizing"],
    &["brutalising"],
];

pub(crate) static ENTRY_BUDENNY_11099115713729619046: VariantsMap =
    [&["budenny"], &["budaenny"], &["budaenny"], &["budaenny"]];

pub(crate) static ENTRY_BUREAUCRATIZATIONS_4497039635998929992: VariantsMap = [
    &["bureaucratizations"],
    &["bureaucratisations"],
    &["bureaucratizations"],
    &["bureaucratisations"],
];

pub(crate) static ENTRY_BUREAUCRATIZATION_16556810164478202459: VariantsMap = [
    &["bureaucratization"],
    &["bureaucratisation"],
    &["bureaucratization"],
    &["bureaucratisation"],
];

pub(crate) static ENTRY_BUREAUCRATIZED_15775450558155547918: VariantsMap = [
    &["bureaucratized"],
    &["bureaucratised"],
    &["bureaucratized"],
    &["bureaucratised"],
];

pub(crate) static ENTRY_BUREAUCRATIZES_961794786572965629: VariantsMap = [
    &["bureaucratizes"],
    &["bureaucratises"],
    &["bureaucratizes"],
    &["bureaucratises"],
];

pub(crate) static ENTRY_BUREAUCRATIZE_16395985087531018238: VariantsMap = [
    &["bureaucratize"],
    &["bureaucratise"],
    &["bureaucratize"],
    &["bureaucratise"],
];

pub(crate) static ENTRY_BUREAUCRATIZING_11662006117549455029: VariantsMap = [
    &["bureaucratizing"],
    &["bureaucratising"],
    &["bureaucratizing"],
    &["bureaucratising"],
];

pub(crate) static ENTRY_BURGLARIZED_12847959995142931775: VariantsMap = [
    &["burglarized"],
    &["burglarised"],
    &["burglarized"],
    &["burglarised"],
];

pub(crate) static ENTRY_BURGLARIZES_9695092733654355865: VariantsMap = [
    &["burglarizes"],
    &["burglarises"],
    &["burglarizes"],
    &["burglarises"],
];

pub(crate) static ENTRY_BURGLARIZE_3702042591254065955: VariantsMap = [
    &["burglarize"],
    &["burglarise"],
    &["burglarize"],
    &["burglarise"],
];

pub(crate) static ENTRY_BURGLARIZING_8183010640223344875: VariantsMap = [
    &["burglarizing"],
    &["burglarising"],
    &["burglarizing"],
    &["burglarising"],
];

pub(crate) static ENTRY_BURKAS_17648103133414783175: VariantsMap = [
    &["burkas"],
    &["burkas", "burkhas", "burqas"],
    &["burkas", "burkhas", "burqas"],
    &["burqas"],
];

pub(crate) static ENTRY_BURKA_1159530484671088481: VariantsMap = [
    &["burka"],
    &["burka", "burkha", "burqa"],
    &["burka", "burkha", "burqa"],
    &["burqa"],
];

pub(crate) static ENTRY_BURNETTIZED_4236600316315443722: VariantsMap = [
    &["burnettized"],
    &["burnettised"],
    &["burnettized"],
    &["burnettised"],
];

pub(crate) static ENTRY_BURNETTIZES_11084091521976824076: VariantsMap = [
    &["burnettizes"],
    &["burnettises"],
    &["burnettizes"],
    &["burnettises"],
];

pub(crate) static ENTRY_BURNETTIZE_2544477078181246197: VariantsMap = [
    &["burnettize"],
    &["burnettise"],
    &["burnettize"],
    &["burnettise"],
];

pub(crate) static ENTRY_BURNETTIZING_7002913660791249279: VariantsMap = [
    &["burnettizing"],
    &["burnettising"],
    &["burnettizing"],
    &["burnettising"],
];

pub(crate) static ENTRY_BUSED_11356679774879450486: VariantsMap =
    [&["bused"], &["bussed"], &["bused"], &["bussed"]];

pub(crate) static ENTRY_BUSHELED_1118763777829214027: VariantsMap = [
    &["busheled"],
    &["bushelled"],
    &["bushelled"],
    &["bushelled"],
];

pub(crate) static ENTRY_BUSHELERS_15210446479419969885: VariantsMap = [
    &["bushelers"],
    &["bushellers"],
    &["bushellers"],
    &["bushellers"],
];

pub(crate) static ENTRY_BUSHELER_17954630284099342763: VariantsMap = [
    &["busheler"],
    &["busheller"],
    &["busheller"],
    &["busheller"],
];

pub(crate) static ENTRY_BUSHELINGS_985942199985401750: VariantsMap = [
    &["bushelings"],
    &["bushellings"],
    &["bushellings"],
    &["bushellings"],
];

pub(crate) static ENTRY_BUSHELING_12570417250242863334: VariantsMap = [
    &["busheling"],
    &["bushelling"],
    &["bushelling"],
    &["bushelling"],
];

pub(crate) static ENTRY_BUSINGS_5189350881089292254: VariantsMap =
    [&["busings"], &["bussings"], &["busings"], &["bussings"]];

pub(crate) static ENTRY_BUSING_14976108434828724214: VariantsMap =
    [&["busing"], &["bussing"], &["busing"], &["bussing"]];

pub(crate) static ENTRY_BYRONIZES_17917324563061221571: VariantsMap = [
    &["byronizes"],
    &["byronises"],
    &["byronizes"],
    &["byronises"],
];

pub(crate) static ENTRY_BYRONIZE_12114867653355624724: VariantsMap =
    [&["byronize"], &["byronise"], &["byronize"], &["byronise"]];

pub(crate) static ENTRY_BYZANTINIZES_7526286864523963129: VariantsMap = [
    &["byzantinizes"],
    &["byzantinises"],
    &["byzantinizes"],
    &["byzantinises"],
];

pub(crate) static ENTRY_BYZANTINIZE_8123759068349438218: VariantsMap = [
    &["byzantinize"],
    &["byzantinise"],
    &["byzantinize"],
    &["byzantinise"],
];

pub(crate) static ENTRY_CACESTHESIA_3355744088099232950: VariantsMap = [
    &["cacesthesia"],
    &["cacaesthesia"],
    &["cacaesthesia"],
    &["cacaesthesia"],
];

pub(crate) static ENTRY_CACHEMIA_7087156802078224155: VariantsMap = [
    &["cachemia"],
    &["cachaemia"],
    &["cachaemia"],
    &["cachaemia"],
];

pub(crate) static ENTRY_CACHEMIC_8607330359013703184: VariantsMap = [
    &["cachemic"],
    &["cachaemic"],
    &["cachaemic"],
    &["cachaemic"],
];

pub(crate) static ENTRY_CACODEMONIAC_1398909674946225762: VariantsMap = [
    &["cacodemoniac"],
    &["cacodaemoniac"],
    &["cacodaemoniac"],
    &["cacodaemoniac"],
];

pub(crate) static ENTRY_CACODEMONIAL_4666484075733322158: VariantsMap = [
    &["cacodemonial"],
    &["cacodaemonial"],
    &["cacodaemonial"],
    &["cacodaemonial"],
];

pub(crate) static ENTRY_CACODEMONIC_13766389188311207544: VariantsMap = [
    &["cacodemonic"],
    &["cacodaemonic"],
    &["cacodaemonic"],
    &["cacodaemonic"],
];

pub(crate) static ENTRY_CACODEMONS_4825079147053974709: VariantsMap = [
    &["cacodemons"],
    &["cacodaemons"],
    &["cacodaemons"],
    &["cacodaemons"],
];

pub(crate) static ENTRY_CACODEMON_14159660385143717967: VariantsMap = [
    &["cacodemon"],
    &["cacodaemon"],
    &["cacodaemon"],
    &["cacodaemon"],
];

pub(crate) static ENTRY_CACOETHES_16920803313087394954: VariantsMap = [
    &["cacoethes"],
    &["cacoaethes"],
    &["cacoaethes"],
    &["cacoaethes"],
];

pub(crate) static ENTRY_CADASTERS_582180790478148418: VariantsMap = [
    &["cadasters"],
    &["cadastres"],
    &["cadastres"],
    &["cadastres"],
];

pub(crate) static ENTRY_CADASTER_600878410341713165: VariantsMap =
    [&["cadaster"], &["cadastre"], &["cadastre"], &["cadastre"]];

pub(crate) static ENTRY_CADAVERIZES_5212133003303242117: VariantsMap = [
    &["cadaverizes"],
    &["cadaverises"],
    &["cadaverizes"],
    &["cadaverises"],
];

pub(crate) static ENTRY_CADAVERIZE_7507726269443380406: VariantsMap = [
    &["cadaverize"],
    &["cadaverise"],
    &["cadaverize"],
    &["cadaverise"],
];

pub(crate) static ENTRY_CADMIUMIZES_784331431098990189: VariantsMap = [
    &["cadmiumizes"],
    &["cadmiumises"],
    &["cadmiumizes"],
    &["cadmiumises"],
];

pub(crate) static ENTRY_CADMIUMIZE_6211453858315644291: VariantsMap = [
    &["cadmiumize"],
    &["cadmiumise"],
    &["cadmiumize"],
    &["cadmiumise"],
];

pub(crate) static ENTRY_CAESARIZES_16957983591444579370: VariantsMap = [
    &["caesarizes"],
    &["caesarises"],
    &["caesarizes"],
    &["caesarises"],
];

pub(crate) static ENTRY_CAESARIZE_5575641651919740489: VariantsMap = [
    &["caesarize"],
    &["caesarise"],
    &["caesarize"],
    &["caesarise"],
];

pub(crate) static ENTRY_CAFFER_7853146588750420256: VariantsMap =
    [&["caffer"], &["caffre"], &["caffre"], &["caffre"]];

pub(crate) static ENTRY_CALANDER_1319585864060436502: VariantsMap =
    [&["calander"], &["calandre"], &["calandre"], &["calandre"]];

pub(crate) static ENTRY_CALCEMIA_1283576588856942148: VariantsMap = [
    &["calcemia"],
    &["calcaemia"],
    &["calcaemia"],
    &["calcaemia"],
];

pub(crate) static ENTRY_CALENDARIZATIONS_4887826632899373259: VariantsMap = [
    &["calendarizations"],
    &["calendarisations"],
    &["calendarizations"],
    &["calendarisations"],
];

pub(crate) static ENTRY_CALENDARIZATION_11275927263521422623: VariantsMap = [
    &["calendarization"],
    &["calendarisation"],
    &["calendarization"],
    &["calendarisation"],
];

pub(crate) static ENTRY_CALENDARIZED_16767057265330067481: VariantsMap = [
    &["calendarized"],
    &["calendarised"],
    &["calendarized"],
    &["calendarised"],
];

pub(crate) static ENTRY_CALENDARIZES_9729766993143146526: VariantsMap = [
    &["calendarizes"],
    &["calendarises"],
    &["calendarizes"],
    &["calendarises"],
];

pub(crate) static ENTRY_CALENDARIZE_14479923013676531010: VariantsMap = [
    &["calendarize"],
    &["calendarise"],
    &["calendarize"],
    &["calendarise"],
];

pub(crate) static ENTRY_CALENDARIZING_12252223763201845409: VariantsMap = [
    &["calendarizing"],
    &["calendarising"],
    &["calendarizing"],
    &["calendarising"],
];

pub(crate) static ENTRY_CALENDER_4820301279587696859: VariantsMap =
    [&["calender"], &["calendre"], &["calendre"], &["calendre"]];

pub(crate) static ENTRY_CALIBERS_1430668361820786824: VariantsMap =
    [&["calibers"], &["calibres"], &["calibres"], &["calibres"]];

pub(crate) static ENTRY_CALIBER_6088618581414349459: VariantsMap =
    [&["caliber"], &["calibre"], &["calibre"], &["calibre"]];

pub(crate) static ENTRY_CALIPERED_235483477506157991: VariantsMap = [
    &["calipered"],
    &["calipered"],
    &["calipered"],
    &["calipered"],
];

pub(crate) static ENTRY_CALIPERING_10891416031331783411: VariantsMap = [
    &["calipering"],
    &["calipering"],
    &["calipering"],
    &["calipering"],
];

pub(crate) static ENTRY_CALIPERS_7817536690880904969: VariantsMap =
    [&["calipers"], &["calipers"], &["calipers"], &["calipers"]];

pub(crate) static ENTRY_CALIPER_1634512857873448114: VariantsMap =
    [&["caliper"], &["caliper"], &["caliper"], &["caliper"]];

pub(crate) static ENTRY_CALISTHENICS_3364072204597622667: VariantsMap = [
    &["calisthenics"],
    &["callisthenics"],
    &["calisthenics"],
    &["callisthenics"],
];

pub(crate) static ENTRY_CALKED_9181583761946600913: VariantsMap =
    [&["calked"], &["caulked"], &["caulked"], &["caulked"]];

pub(crate) static ENTRY_CALKING_11924577664112241546: VariantsMap =
    [&["calking"], &["caulking"], &["caulking"], &["caulking"]];

pub(crate) static ENTRY_CALKS_16035962776808869627: VariantsMap =
    [&["calks"], &["caulks"], &["caulks"], &["caulks"]];

pub(crate) static ENTRY_CALK_12575257056050776341: VariantsMap =
    [&["calk"], &["caulk"], &["caulk"], &["caulk"]];

pub(crate) static ENTRY_CALLIRRHOE_14861380595191797356: VariantsMap = [
    &["callirrhoe"],
    &["callirrhoae"],
    &["callirrhoae"],
    &["callirrhoae"],
];

pub(crate) static ENTRY_CALODEMON_13354165079519258551: VariantsMap = [
    &["calodemon"],
    &["calodaemon"],
    &["calodaemon"],
    &["calodaemon"],
];

pub(crate) static ENTRY_CALVINIZES_5436345566017846080: VariantsMap = [
    &["calvinizes"],
    &["calvinises"],
    &["calvinizes"],
    &["calvinises"],
];

pub(crate) static ENTRY_CALVINIZE_13816648771193752029: VariantsMap = [
    &["calvinize"],
    &["calvinise"],
    &["calvinize"],
    &["calvinise"],
];

pub(crate) static ENTRY_CAMISADES_11807808624178252595: VariantsMap = [
    &["camisades"],
    &["camisadoes"],
    &["camisadoes"],
    &["camisadoes"],
];

pub(crate) static ENTRY_CAMIZE_10411458476841511707: VariantsMap =
    [&["camize"], &["camise"], &["camize"], &["camise"]];

pub(crate) static ENTRY_CANADIANIZATIONS_406463589942768872: VariantsMap = [
    &["canadianizations"],
    &["canadianisations"],
    &["canadianizations"],
    &["canadianisations"],
];

pub(crate) static ENTRY_CANADIANIZATION_11574644012372626466: VariantsMap = [
    &["canadianization"],
    &["canadianisation"],
    &["canadianization"],
    &["canadianisation"],
];

pub(crate) static ENTRY_CANADIANIZES_962660416621258364: VariantsMap = [
    &["canadianizes"],
    &["canadianises"],
    &["canadianizes"],
    &["canadianises"],
];

pub(crate) static ENTRY_CANADIANIZE_16890380569827973630: VariantsMap = [
    &["canadianize"],
    &["canadianise"],
    &["canadianize"],
    &["canadianise"],
];

pub(crate) static ENTRY_CANALED_1837439099016219610: VariantsMap =
    [&["canaled"], &["canalled"], &["canalled"], &["canalled"]];

pub(crate) static ENTRY_CANALERS_7689806565376794966: VariantsMap = [
    &["canalers"],
    &["canallers"],
    &["canallers"],
    &["canallers"],
];

pub(crate) static ENTRY_CANALER_18198043193093593287: VariantsMap =
    [&["canaler"], &["canaller"], &["canaller"], &["canaller"]];

pub(crate) static ENTRY_CANALING_8814927178454078271: VariantsMap = [
    &["canaling"],
    &["canalling"],
    &["canalling"],
    &["canalling"],
];

pub(crate) static ENTRY_CANALIZATIONS_2935456196223694503: VariantsMap = [
    &["canalizations"],
    &["canalisations"],
    &["canalizations"],
    &["canalisations"],
];

pub(crate) static ENTRY_CANALIZATION_9901281941769542241: VariantsMap = [
    &["canalization"],
    &["canalisation"],
    &["canalization"],
    &["canalisation"],
];

pub(crate) static ENTRY_CANALIZED_5067325481202256530: VariantsMap = [
    &["canalized"],
    &["canalised"],
    &["canalized"],
    &["canalised"],
];

pub(crate) static ENTRY_CANALIZES_14989578106312573774: VariantsMap = [
    &["canalizes"],
    &["canalises"],
    &["canalizes"],
    &["canalises"],
];

pub(crate) static ENTRY_CANALIZE_911721963215339223: VariantsMap =
    [&["canalize"], &["canalise"], &["canalize"], &["canalise"]];

pub(crate) static ENTRY_CANALIZING_4812741747649871906: VariantsMap = [
    &["canalizing"],
    &["canalising"],
    &["canalizing"],
    &["canalising"],
];

pub(crate) static ENTRY_CANANEAN_5897518141290055149: VariantsMap = [
    &["cananean"],
    &["cananaean"],
    &["cananaean"],
    &["cananaean"],
];

pub(crate) static ENTRY_CANCELABLE_3744022220960108237: VariantsMap = [
    &["cancelable"],
    &["cancellable"],
    &["cancellable"],
    &["cancellable"],
];

pub(crate) static ENTRY_CANCELATED_14737160893696822649: VariantsMap = [
    &["cancelated"],
    &["cancellated"],
    &["cancellated"],
    &["cancellated"],
];

pub(crate) static ENTRY_CANCELATE_11514029187019320804: VariantsMap = [
    &["cancelate"],
    &["cancellate"],
    &["cancellate"],
    &["cancellate"],
];

pub(crate) static ENTRY_CANCELED_8509071628121806534: VariantsMap = [
    &["canceled"],
    &["cancelled"],
    &["cancelled"],
    &["cancelled"],
];

pub(crate) static ENTRY_CANCELERS_843956304444885828: VariantsMap = [
    &["cancelers"],
    &["cancellers"],
    &["cancellers"],
    &["cancellers"],
];

pub(crate) static ENTRY_CANCELER_11336704721008790101: VariantsMap = [
    &["canceler"],
    &["canceller"],
    &["canceller"],
    &["canceller"],
];

pub(crate) static ENTRY_CANCELING_2043317365185195331: VariantsMap = [
    &["canceling"],
    &["cancelling"],
    &["cancelling"],
    &["cancelling"],
];

pub(crate) static ENTRY_CANCELLATION_16186923162114662177: VariantsMap = [
    &["cancellation"],
    &["cancellation"],
    &["cancellation"],
    &["cancellation"],
];

pub(crate) static ENTRY_CANCELOUS_13432632612523726300: VariantsMap = [
    &["cancelous"],
    &["cancellous"],
    &["cancellous"],
    &["cancellous"],
];

pub(crate) static ENTRY_CANDORS_352105524503647274: VariantsMap =
    [&["candors"], &["candours"], &["candours"], &["candours"]];

pub(crate) static ENTRY_CANDOR_14808094384111961913: VariantsMap =
    [&["candor"], &["candour"], &["candour"], &["candour"]];

pub(crate) static ENTRY_CANEPHORE_10522331887025347806: VariantsMap = [
    &["canephore"],
    &["canephoroe"],
    &["canephoroe"],
    &["canephoroe"],
];

pub(crate) static ENTRY_CANEPHORE_6434692370350146164: VariantsMap = [
    &["canephore"],
    &["canephorae"],
    &["canephorae"],
    &["canephorae"],
];

pub(crate) static ENTRY_CANISTERIZATIONS_16175257743062965718: VariantsMap = [
    &["canisterizations"],
    &["canisterisations"],
    &["canisterizations"],
    &["canisterisations"],
];

pub(crate) static ENTRY_CANISTERIZATION_9994917120138811095: VariantsMap = [
    &["canisterization"],
    &["canisterisation"],
    &["canisterization"],
    &["canisterisation"],
];

pub(crate) static ENTRY_CANISTERIZED_11516075806659176774: VariantsMap = [
    &["canisterized"],
    &["canisterised"],
    &["canisterized"],
    &["canisterised"],
];

pub(crate) static ENTRY_CANISTERIZES_8707191536977720595: VariantsMap = [
    &["canisterizes"],
    &["canisterises"],
    &["canisterizes"],
    &["canisterises"],
];

pub(crate) static ENTRY_CANISTERIZE_3823751102053887281: VariantsMap = [
    &["canisterize"],
    &["canisterise"],
    &["canisterize"],
    &["canisterise"],
];

pub(crate) static ENTRY_CANISTERIZING_3833251549971264383: VariantsMap = [
    &["canisterizing"],
    &["canisterising"],
    &["canisterizing"],
    &["canisterising"],
];

pub(crate) static ENTRY_CANNIBALIZATIONS_14659207523926251323: VariantsMap = [
    &["cannibalizations"],
    &["cannibalisations"],
    &["cannibalizations"],
    &["cannibalisations"],
];

pub(crate) static ENTRY_CANNIBALIZATION_7240357016697451118: VariantsMap = [
    &["cannibalization"],
    &["cannibalisation"],
    &["cannibalization"],
    &["cannibalisation"],
];

pub(crate) static ENTRY_CANNIBALIZED_8169504218362659851: VariantsMap = [
    &["cannibalized"],
    &["cannibalised"],
    &["cannibalized"],
    &["cannibalised"],
];

pub(crate) static ENTRY_CANNIBALIZES_7622852839420143979: VariantsMap = [
    &["cannibalizes"],
    &["cannibalises"],
    &["cannibalizes"],
    &["cannibalises"],
];

pub(crate) static ENTRY_CANNIBALIZE_6390598440678018772: VariantsMap = [
    &["cannibalize"],
    &["cannibalise"],
    &["cannibalize"],
    &["cannibalise"],
];

pub(crate) static ENTRY_CANNIBALIZING_12609939168668624233: VariantsMap = [
    &["cannibalizing"],
    &["cannibalising"],
    &["cannibalizing"],
    &["cannibalising"],
];

pub(crate) static ENTRY_CANONICALIZATION_7999615851945801309: VariantsMap = [
    &["canonicalization"],
    &["canonicalisation"],
    &["canonicalization"],
    &["canonicalisation"],
];

pub(crate) static ENTRY_CANONICALIZED_11250167296463797072: VariantsMap = [
    &["canonicalized"],
    &["canonicalised"],
    &["canonicalized"],
    &["canonicalised"],
];

pub(crate) static ENTRY_CANONICALIZES_18227657368670160690: VariantsMap = [
    &["canonicalizes"],
    &["canonicalises"],
    &["canonicalizes"],
    &["canonicalises"],
];

pub(crate) static ENTRY_CANONICALIZE_2632431567177056192: VariantsMap = [
    &["canonicalize"],
    &["canonicalise"],
    &["canonicalize"],
    &["canonicalise"],
];

pub(crate) static ENTRY_CANONICALIZING_1431614031305230237: VariantsMap = [
    &["canonicalizing"],
    &["canonicalising"],
    &["canonicalizing"],
    &["canonicalising"],
];

pub(crate) static ENTRY_CANONIZATIONS_15946456967388997441: VariantsMap = [
    &["canonizations"],
    &["canonisations"],
    &["canonizations"],
    &["canonisations"],
];

pub(crate) static ENTRY_CANONIZATION_5080602976142523102: VariantsMap = [
    &["canonization"],
    &["canonisation"],
    &["canonization"],
    &["canonisation"],
];

pub(crate) static ENTRY_CANONIZED_4794312694447620033: VariantsMap = [
    &["canonized"],
    &["canonised"],
    &["canonized"],
    &["canonised"],
];

pub(crate) static ENTRY_CANONIZERS_1059373452134645246: VariantsMap = [
    &["canonizers"],
    &["canonisers"],
    &["canonizers"],
    &["canonisers"],
];

pub(crate) static ENTRY_CANONIZER_17140136837292538642: VariantsMap = [
    &["canonizer"],
    &["canoniser"],
    &["canonizer"],
    &["canoniser"],
];

pub(crate) static ENTRY_CANONIZES_17683915838157001675: VariantsMap = [
    &["canonizes"],
    &["canonises"],
    &["canonizes"],
    &["canonises"],
];

pub(crate) static ENTRY_CANONIZE_7683068140953197405: VariantsMap =
    [&["canonize"], &["canonise"], &["canonize"], &["canonise"]];

pub(crate) static ENTRY_CANONIZING_8668155521149668521: VariantsMap = [
    &["canonizing"],
    &["canonising"],
    &["canonizing"],
    &["canonising"],
];

pub(crate) static ENTRY_CANTALOUPES_10789009086995967817: VariantsMap = [
    &["cantaloupes"],
    &["cantaloupes"],
    &["cantaloupes"],
    &["cantaloupes"],
];

pub(crate) static ENTRY_CANTALOUPE_7760362447914940621: VariantsMap = [
    &["cantaloupe"],
    &["cantaloupe"],
    &["cantaloupe"],
    &["cantaloupe"],
];

pub(crate) static ENTRY_CANTONIZATIONS_17246812416090811840: VariantsMap = [
    &["cantonizations"],
    &["cantonisations"],
    &["cantonizations"],
    &["cantonisations"],
];

pub(crate) static ENTRY_CANTONIZATION_6677109296433610186: VariantsMap = [
    &["cantonization"],
    &["cantonisation"],
    &["cantonization"],
    &["cantonisation"],
];

pub(crate) static ENTRY_CANTONIZED_759359507372098389: VariantsMap = [
    &["cantonized"],
    &["cantonised"],
    &["cantonized"],
    &["cantonised"],
];

pub(crate) static ENTRY_CANTONIZES_10832472956122974528: VariantsMap = [
    &["cantonizes"],
    &["cantonises"],
    &["cantonizes"],
    &["cantonises"],
];

pub(crate) static ENTRY_CANTONIZE_1640483783874964493: VariantsMap = [
    &["cantonize"],
    &["cantonise"],
    &["cantonize"],
    &["cantonise"],
];

pub(crate) static ENTRY_CANTONIZING_12871143996405253104: VariantsMap = [
    &["cantonizing"],
    &["cantonising"],
    &["cantonizing"],
    &["cantonising"],
];

pub(crate) static ENTRY_CAPITALIZABLER_17031718845693435382: VariantsMap = [
    &["capitalizabler"],
    &["capitalisabler"],
    &["capitalizabler"],
    &["capitalisabler"],
];

pub(crate) static ENTRY_CAPITALIZABLEST_6136542042922432603: VariantsMap = [
    &["capitalizablest"],
    &["capitalisablest"],
    &["capitalizablest"],
    &["capitalisablest"],
];

pub(crate) static ENTRY_CAPITALIZABLES_12918035538804552826: VariantsMap = [
    &["capitalizables"],
    &["capitalisables"],
    &["capitalizables"],
    &["capitalisables"],
];

pub(crate) static ENTRY_CAPITALIZABLE_1765975557696773459: VariantsMap = [
    &["capitalizable"],
    &["capitalisable"],
    &["capitalizable"],
    &["capitalisable"],
];

pub(crate) static ENTRY_CAPITALIZATIONS_4554225755737415935: VariantsMap = [
    &["capitalizations"],
    &["capitalisations"],
    &["capitalizations"],
    &["capitalisations"],
];

pub(crate) static ENTRY_CAPITALIZATION_12627331264579480739: VariantsMap = [
    &["capitalization"],
    &["capitalisation"],
    &["capitalization"],
    &["capitalisation"],
];

pub(crate) static ENTRY_CAPITALIZED_15025949045206025922: VariantsMap = [
    &["capitalized"],
    &["capitalised"],
    &["capitalized"],
    &["capitalised"],
];

pub(crate) static ENTRY_CAPITALIZERS_10517751249028432560: VariantsMap = [
    &["capitalizers"],
    &["capitalisers"],
    &["capitalizers"],
    &["capitalisers"],
];

pub(crate) static ENTRY_CAPITALIZER_15938335196315218634: VariantsMap = [
    &["capitalizer"],
    &["capitaliser"],
    &["capitalizer"],
    &["capitaliser"],
];

pub(crate) static ENTRY_CAPITALIZES_16323417076992732600: VariantsMap = [
    &["capitalizes"],
    &["capitalises"],
    &["capitalizes"],
    &["capitalises"],
];

pub(crate) static ENTRY_CAPITALIZE_8725562284183074279: VariantsMap = [
    &["capitalize"],
    &["capitalise"],
    &["capitalize"],
    &["capitalise"],
];

pub(crate) static ENTRY_CAPITALIZING_2512967533316213598: VariantsMap = [
    &["capitalizing"],
    &["capitalising"],
    &["capitalizing"],
    &["capitalising"],
];

pub(crate) static ENTRY_CAPONIZATION_1938263787545597969: VariantsMap = [
    &["caponization"],
    &["caponisation"],
    &["caponization"],
    &["caponisation"],
];

pub(crate) static ENTRY_CAPONIZED_14836958589299432160: VariantsMap = [
    &["caponized"],
    &["caponised"],
    &["caponized"],
    &["caponised"],
];

pub(crate) static ENTRY_CAPONIZER_5653304916609979245: VariantsMap = [
    &["caponizer"],
    &["caponiser"],
    &["caponizer"],
    &["caponiser"],
];

pub(crate) static ENTRY_CAPONIZES_8415080645445299415: VariantsMap = [
    &["caponizes"],
    &["caponises"],
    &["caponizes"],
    &["caponises"],
];

pub(crate) static ENTRY_CAPONIZE_17964447872816434047: VariantsMap =
    [&["caponize"], &["caponise"], &["caponize"], &["caponise"]];

pub(crate) static ENTRY_CAPONIZING_12126070973152497349: VariantsMap = [
    &["caponizing"],
    &["caponising"],
    &["caponizing"],
    &["caponising"],
];

pub(crate) static ENTRY_CAPSULIZATION_1378111058341821834: VariantsMap = [
    &["capsulization"],
    &["capsulisation"],
    &["capsulization"],
    &["capsulisation"],
];

pub(crate) static ENTRY_CAPSULIZED_14587057948214962939: VariantsMap = [
    &["capsulized"],
    &["capsulised"],
    &["capsulized"],
    &["capsulised"],
];

pub(crate) static ENTRY_CAPSULIZES_12567539512302131751: VariantsMap = [
    &["capsulizes"],
    &["capsulises"],
    &["capsulizes"],
    &["capsulises"],
];

pub(crate) static ENTRY_CAPSULIZE_7935266522075201942: VariantsMap = [
    &["capsulize"],
    &["capsulise"],
    &["capsulize"],
    &["capsulise"],
];

pub(crate) static ENTRY_CAPSULIZING_7016335058787637735: VariantsMap = [
    &["capsulizing"],
    &["capsulising"],
    &["capsulizing"],
    &["capsulising"],
];

pub(crate) static ENTRY_CARACOLED_8083634779350238799: VariantsMap = [
    &["caracoled"],
    &["caracolled"],
    &["caracolled"],
    &["caracolled"],
];

pub(crate) static ENTRY_CARACOLING_4913840131879532625: VariantsMap = [
    &["caracoling"],
    &["caracolling"],
    &["caracolling"],
    &["caracolling"],
];

pub(crate) static ENTRY_CARAMELIZATIONS_16073975104161787099: VariantsMap = [
    &["caramelizations"],
    &["caramelisations"],
    &["caramelizations"],
    &["caramelisations"],
];

pub(crate) static ENTRY_CARAMELIZATION_12261843451362374441: VariantsMap = [
    &["caramelization"],
    &["caramelisation"],
    &["caramelization"],
    &["caramelisation"],
];

pub(crate) static ENTRY_CARAMELIZED_3143066068548786354: VariantsMap = [
    &["caramelized"],
    &["caramelised"],
    &["caramelized"],
    &["caramelised"],
];

pub(crate) static ENTRY_CARAMELIZES_12354251654432497813: VariantsMap = [
    &["caramelizes"],
    &["caramelises"],
    &["caramelizes"],
    &["caramelises"],
];

pub(crate) static ENTRY_CARAMELIZE_15122592141568398862: VariantsMap = [
    &["caramelize"],
    &["caramelise"],
    &["caramelize"],
    &["caramelise"],
];

pub(crate) static ENTRY_CARAMELIZING_10890268661953323278: VariantsMap = [
    &["caramelizing"],
    &["caramelising"],
    &["caramelizing"],
    &["caramelising"],
];

pub(crate) static ENTRY_CARBOLIZATION_16908167377588079008: VariantsMap = [
    &["carbolization"],
    &["carbolisation"],
    &["carbolization"],
    &["carbolisation"],
];

pub(crate) static ENTRY_CARBOLIZED_3610204407073437611: VariantsMap = [
    &["carbolized"],
    &["carbolised"],
    &["carbolized"],
    &["carbolised"],
];

pub(crate) static ENTRY_CARBOLIZES_16280869006659938468: VariantsMap = [
    &["carbolizes"],
    &["carbolises"],
    &["carbolizes"],
    &["carbolises"],
];

pub(crate) static ENTRY_CARBOLIZE_10498092873125902774: VariantsMap = [
    &["carbolize"],
    &["carbolise"],
    &["carbolize"],
    &["carbolise"],
];

pub(crate) static ENTRY_CARBOLIZING_10944405222501443697: VariantsMap = [
    &["carbolizing"],
    &["carbolising"],
    &["carbolizing"],
    &["carbolising"],
];

pub(crate) static ENTRY_CARBONADES_5678712770354789721: VariantsMap = [
    &["carbonades"],
    &["carbonadoes"],
    &["carbonadoes"],
    &["carbonadoes"],
];

pub(crate) static ENTRY_CARBONATIZATIONS_10498315283198909416: VariantsMap = [
    &["carbonatizations"],
    &["carbonatisations"],
    &["carbonatizations"],
    &["carbonatisations"],
];

pub(crate) static ENTRY_CARBONATIZATION_5251252289578036221: VariantsMap = [
    &["carbonatization"],
    &["carbonatisation"],
    &["carbonatization"],
    &["carbonatisation"],
];

pub(crate) static ENTRY_CARBONIZABLER_11011547734927627020: VariantsMap = [
    &["carbonizabler"],
    &["carbonisabler"],
    &["carbonizabler"],
    &["carbonisabler"],
];

pub(crate) static ENTRY_CARBONIZABLEST_112885352202057431: VariantsMap = [
    &["carbonizablest"],
    &["carbonisablest"],
    &["carbonizablest"],
    &["carbonisablest"],
];

pub(crate) static ENTRY_CARBONIZABLES_4143576460831039714: VariantsMap = [
    &["carbonizables"],
    &["carbonisables"],
    &["carbonizables"],
    &["carbonisables"],
];

pub(crate) static ENTRY_CARBONIZABLE_7275477916888704155: VariantsMap = [
    &["carbonizable"],
    &["carbonisable"],
    &["carbonizable"],
    &["carbonisable"],
];

pub(crate) static ENTRY_CARBONIZATIONS_6111370292147685550: VariantsMap = [
    &["carbonizations"],
    &["carbonisations"],
    &["carbonizations"],
    &["carbonisations"],
];

pub(crate) static ENTRY_CARBONIZATION_11122364629547796220: VariantsMap = [
    &["carbonization"],
    &["carbonisation"],
    &["carbonization"],
    &["carbonisation"],
];

pub(crate) static ENTRY_CARBONIZED_14795079813785129130: VariantsMap = [
    &["carbonized"],
    &["carbonised"],
    &["carbonized"],
    &["carbonised"],
];

pub(crate) static ENTRY_CARBONIZERS_13712244721486829214: VariantsMap = [
    &["carbonizers"],
    &["carbonisers"],
    &["carbonizers"],
    &["carbonisers"],
];

pub(crate) static ENTRY_CARBONIZER_12348552524098629169: VariantsMap = [
    &["carbonizer"],
    &["carboniser"],
    &["carbonizer"],
    &["carboniser"],
];

pub(crate) static ENTRY_CARBONIZES_14523315792081641044: VariantsMap = [
    &["carbonizes"],
    &["carbonises"],
    &["carbonizes"],
    &["carbonises"],
];

pub(crate) static ENTRY_CARBONIZE_16235242288107272785: VariantsMap = [
    &["carbonize"],
    &["carbonise"],
    &["carbonize"],
    &["carbonise"],
];

pub(crate) static ENTRY_CARBONIZING_6968560222274215193: VariantsMap = [
    &["carbonizing"],
    &["carbonising"],
    &["carbonizing"],
    &["carbonising"],
];

pub(crate) static ENTRY_CARBURETORS_16992407598754998108: VariantsMap = [
    &["carburetors"],
    &["carburettors"],
    &["carburettors"],
    &["carburettors"],
];

pub(crate) static ENTRY_CARBURETOR_3718140921594640872: VariantsMap = [
    &["carburetor"],
    &["carburettor"],
    &["carburettor"],
    &["carburettor"],
];

pub(crate) static ENTRY_CARBURIZATIONS_4288822688136593112: VariantsMap = [
    &["carburizations"],
    &["carburisations"],
    &["carburizations"],
    &["carburisations"],
];

pub(crate) static ENTRY_CARBURIZATION_14186154773415871277: VariantsMap = [
    &["carburization"],
    &["carburisation"],
    &["carburization"],
    &["carburisation"],
];

pub(crate) static ENTRY_CARBURIZED_2653066621032127976: VariantsMap = [
    &["carburized"],
    &["carburised"],
    &["carburized"],
    &["carburised"],
];

pub(crate) static ENTRY_CARBURIZER_1120017158252509510: VariantsMap = [
    &["carburizer"],
    &["carburiser"],
    &["carburizer"],
    &["carburiser"],
];

pub(crate) static ENTRY_CARBURIZES_2604386355014205446: VariantsMap = [
    &["carburizes"],
    &["carburises"],
    &["carburizes"],
    &["carburises"],
];

pub(crate) static ENTRY_CARBURIZE_886066375006540244: VariantsMap = [
    &["carburize"],
    &["carburise"],
    &["carburize"],
    &["carburise"],
];

pub(crate) static ENTRY_CARBURIZING_14362267205170352071: VariantsMap = [
    &["carburizing"],
    &["carburising"],
    &["carburizing"],
    &["carburising"],
];

pub(crate) static ENTRY_CARDIE_2205350999715185435: VariantsMap =
    [&["cardie"], &["cardiae"], &["cardiae"], &["cardiae"]];

pub(crate) static ENTRY_CARDUELINE_17268913123311282389: VariantsMap = [
    &["cardueline"],
    &["carduelinae"],
    &["carduelinae"],
    &["carduelinae"],
];

pub(crate) static ENTRY_CARNALIZED_7768933264922371251: VariantsMap = [
    &["carnalized"],
    &["carnalised"],
    &["carnalized"],
    &["carnalised"],
];

pub(crate) static ENTRY_CARNALIZES_5581084477739167595: VariantsMap = [
    &["carnalizes"],
    &["carnalises"],
    &["carnalizes"],
    &["carnalises"],
];

pub(crate) static ENTRY_CARNALIZE_5475208533929563421: VariantsMap = [
    &["carnalize"],
    &["carnalise"],
    &["carnalize"],
    &["carnalise"],
];

pub(crate) static ENTRY_CARNALIZING_6431076956231586367: VariantsMap = [
    &["carnalizing"],
    &["carnalising"],
    &["carnalizing"],
    &["carnalising"],
];

pub(crate) static ENTRY_CAROLED_10588023811542781156: VariantsMap =
    [&["caroled"], &["carolled"], &["carolled"], &["carolled"]];

pub(crate) static ENTRY_CAROLERS_10675807177319949622: VariantsMap = [
    &["carolers"],
    &["carollers"],
    &["carollers"],
    &["carollers"],
];

pub(crate) static ENTRY_CAROLER_7480138065296781672: VariantsMap =
    [&["caroler"], &["caroller"], &["caroller"], &["caroller"]];

pub(crate) static ENTRY_CAROLING_1021261814376249053: VariantsMap = [
    &["caroling"],
    &["carolling"],
    &["carolling"],
    &["carolling"],
];

pub(crate) static ENTRY_CAROTINEMIA_10522117710609229159: VariantsMap = [
    &["carotinemia"],
    &["carotinaemia"],
    &["carotinaemia"],
    &["carotinaemia"],
];

pub(crate) static ENTRY_CARTELIZATIONS_15852914117827138645: VariantsMap = [
    &["cartelizations"],
    &["cartelisations"],
    &["cartelizations"],
    &["cartelisations"],
];

pub(crate) static ENTRY_CARTELIZATION_1802711991797389087: VariantsMap = [
    &["cartelization"],
    &["cartelisation"],
    &["cartelization"],
    &["cartelisation"],
];

pub(crate) static ENTRY_CARTELIZED_9927132532859356643: VariantsMap = [
    &["cartelized"],
    &["cartelised"],
    &["cartelized"],
    &["cartelised"],
];

pub(crate) static ENTRY_CARTELIZES_14469260606626523795: VariantsMap = [
    &["cartelizes"],
    &["cartelises"],
    &["cartelizes"],
    &["cartelises"],
];

pub(crate) static ENTRY_CARTELIZE_7454101035459734890: VariantsMap = [
    &["cartelize"],
    &["cartelise"],
    &["cartelize"],
    &["cartelise"],
];

pub(crate) static ENTRY_CARTELIZING_16082986042795613861: VariantsMap = [
    &["cartelizing"],
    &["cartelising"],
    &["cartelizing"],
    &["cartelising"],
];

pub(crate) static ENTRY_CASTORIZEDS_7380053523540664448: VariantsMap = [
    &["castorizeds"],
    &["castoriseds"],
    &["castorizeds"],
    &["castoriseds"],
];

pub(crate) static ENTRY_CASTORIZED_17799018914377706815: VariantsMap = [
    &["castorized"],
    &["castorised"],
    &["castorized"],
    &["castorised"],
];

pub(crate) static ENTRY_CASUALIZATIONS_4776592355861975796: VariantsMap = [
    &["casualizations"],
    &["casualisations"],
    &["casualizations"],
    &["casualisations"],
];

pub(crate) static ENTRY_CASUALIZATION_12871483932151068766: VariantsMap = [
    &["casualization"],
    &["casualisation"],
    &["casualization"],
    &["casualisation"],
];

pub(crate) static ENTRY_CASUALIZED_3173806408429929886: VariantsMap = [
    &["casualized"],
    &["casualised"],
    &["casualized"],
    &["casualised"],
];

pub(crate) static ENTRY_CASUALIZES_2357569365432878510: VariantsMap = [
    &["casualizes"],
    &["casualises"],
    &["casualizes"],
    &["casualises"],
];

pub(crate) static ENTRY_CASUALIZE_10803983540374652623: VariantsMap = [
    &["casualize"],
    &["casualise"],
    &["casualize"],
    &["casualise"],
];

pub(crate) static ENTRY_CASUALIZING_16345100801087952198: VariantsMap = [
    &["casualizing"],
    &["casualising"],
    &["casualizing"],
    &["casualising"],
];

pub(crate) static ENTRY_CATABOLIZE_1177290851351235880: VariantsMap = [
    &["catabolize"],
    &["catabolise"],
    &["catabolize"],
    &["catabolise"],
];

pub(crate) static ENTRY_CATALOGED_17338507726872594232: VariantsMap = [
    &["cataloged"],
    &["catalogued"],
    &["catalogued"],
    &["catalogued"],
];

pub(crate) static ENTRY_CATALOGERS_18141804906921168384: VariantsMap = [
    &["catalogers"],
    &["cataloguers"],
    &["cataloguers"],
    &["cataloguers"],
];

pub(crate) static ENTRY_CATALOGER_1036462752165445499: VariantsMap = [
    &["cataloger"],
    &["cataloguer"],
    &["cataloguer"],
    &["cataloguer"],
];

pub(crate) static ENTRY_CATALOGING_8506877421439024861: VariantsMap = [
    &["cataloging"],
    &["cataloguing"],
    &["cataloguing"],
    &["cataloguing"],
];

pub(crate) static ENTRY_CATALOGS_8518416776176012476: VariantsMap = [
    &["catalogs"],
    &["catalogues"],
    &["catalogues"],
    &["catalogues"],
];

pub(crate) static ENTRY_CATALOGUIZED_4476989929563164358: VariantsMap = [
    &["cataloguized"],
    &["cataloguised"],
    &["cataloguized"],
    &["cataloguised"],
];

pub(crate) static ENTRY_CATALOGUIZES_3655562417907187515: VariantsMap = [
    &["cataloguizes"],
    &["cataloguises"],
    &["cataloguizes"],
    &["cataloguises"],
];

pub(crate) static ENTRY_CATALOGUIZE_1271806317788507924: VariantsMap = [
    &["cataloguize"],
    &["cataloguise"],
    &["cataloguize"],
    &["cataloguise"],
];

pub(crate) static ENTRY_CATALOGUIZING_15932890814645999252: VariantsMap = [
    &["cataloguizing"],
    &["cataloguising"],
    &["cataloguizing"],
    &["cataloguising"],
];

pub(crate) static ENTRY_CATALOG_6854298310343011085: VariantsMap =
    [&["catalog"], &["catalogue"], &["catalogue"], &["catalogue"]];

pub(crate) static ENTRY_CATALYZED_14626193667566838732: VariantsMap = [
    &["catalyzed"],
    &["catalysed"],
    &["catalyzed"],
    &["catalysed"],
];

pub(crate) static ENTRY_CATALYZERS_14386582083420565337: VariantsMap = [
    &["catalyzers"],
    &["catalysers"],
    &["catalysers"],
    &["catalysers"],
];

pub(crate) static ENTRY_CATALYZER_13103775222379027346: VariantsMap = [
    &["catalyzer"],
    &["catalyser"],
    &["catalyser"],
    &["catalyser"],
];

pub(crate) static ENTRY_CATALYZES_14856767428712676497: VariantsMap = [
    &["catalyzes"],
    &["catalyses"],
    &["catalyzes"],
    &["catalyses"],
];

pub(crate) static ENTRY_CATALYZE_2004345719426635958: VariantsMap =
    [&["catalyze"], &["catalyse"], &["catalyze"], &["catalyse"]];

pub(crate) static ENTRY_CATALYZING_5940201018784400445: VariantsMap = [
    &["catalyzing"],
    &["catalysing"],
    &["catalyzing"],
    &["catalysing"],
];

pub(crate) static ENTRY_CATECHIZABLER_5689981000220656601: VariantsMap = [
    &["catechizabler"],
    &["catechisabler"],
    &["catechizabler"],
    &["catechisabler"],
];

pub(crate) static ENTRY_CATECHIZABLEST_7714292286287558770: VariantsMap = [
    &["catechizablest"],
    &["catechisablest"],
    &["catechizablest"],
    &["catechisablest"],
];

pub(crate) static ENTRY_CATECHIZABLES_10992088782460228856: VariantsMap = [
    &["catechizables"],
    &["catechisables"],
    &["catechizables"],
    &["catechisables"],
];

pub(crate) static ENTRY_CATECHIZABLE_8282651021901386912: VariantsMap = [
    &["catechizable"],
    &["catechisable"],
    &["catechizable"],
    &["catechisable"],
];

pub(crate) static ENTRY_CATECHIZATIONS_7241271747980004634: VariantsMap = [
    &["catechizations"],
    &["catechisations"],
    &["catechizations"],
    &["catechisations"],
];

pub(crate) static ENTRY_CATECHIZATION_12810249719668086283: VariantsMap = [
    &["catechization"],
    &["catechisation"],
    &["catechization"],
    &["catechisation"],
];

pub(crate) static ENTRY_CATECHIZED_8126030264531245281: VariantsMap = [
    &["catechized"],
    &["catechised"],
    &["catechized"],
    &["catechised"],
];

pub(crate) static ENTRY_CATECHIZERS_10089039414007893489: VariantsMap = [
    &["catechizers"],
    &["catechisers"],
    &["catechizers"],
    &["catechisers"],
];

pub(crate) static ENTRY_CATECHIZER_8253596747885095438: VariantsMap = [
    &["catechizer"],
    &["catechiser"],
    &["catechizer"],
    &["catechiser"],
];

pub(crate) static ENTRY_CATECHIZES_9034465079743774482: VariantsMap = [
    &["catechizes"],
    &["catechises"],
    &["catechizes"],
    &["catechises"],
];

pub(crate) static ENTRY_CATECHIZE_4522606049079804123: VariantsMap = [
    &["catechize"],
    &["catechise"],
    &["catechize"],
    &["catechise"],
];

pub(crate) static ENTRY_CATECHIZINGS_5519486100889374813: VariantsMap = [
    &["catechizings"],
    &["catechisings"],
    &["catechizings"],
    &["catechisings"],
];

pub(crate) static ENTRY_CATECHIZING_12487941153933575504: VariantsMap = [
    &["catechizing"],
    &["catechising"],
    &["catechizing"],
    &["catechising"],
];

pub(crate) static ENTRY_CATEGORIZATIONS_16612628821035244612: VariantsMap = [
    &["categorizations"],
    &["categorisations"],
    &["categorizations"],
    &["categorisations"],
];

pub(crate) static ENTRY_CATEGORIZATION_8749709687767811950: VariantsMap = [
    &["categorization"],
    &["categorisation"],
    &["categorization"],
    &["categorisation"],
];

pub(crate) static ENTRY_CATEGORIZED_4533542698041220795: VariantsMap = [
    &["categorized"],
    &["categorised"],
    &["categorized"],
    &["categorised"],
];

pub(crate) static ENTRY_CATEGORIZERS_7439137280162913189: VariantsMap = [
    &["categorizers"],
    &["categorisers"],
    &["categorizers"],
    &["categorisers"],
];

pub(crate) static ENTRY_CATEGORIZER_7305291735145100306: VariantsMap = [
    &["categorizer"],
    &["categoriser"],
    &["categorizer"],
    &["categoriser"],
];

pub(crate) static ENTRY_CATEGORIZES_3536341508655848694: VariantsMap = [
    &["categorizes"],
    &["categorises"],
    &["categorizes"],
    &["categorises"],
];

pub(crate) static ENTRY_CATEGORIZE_12360966269850201965: VariantsMap = [
    &["categorize"],
    &["categorise"],
    &["categorize"],
    &["categorise"],
];

pub(crate) static ENTRY_CATEGORIZING_961096799238536775: VariantsMap = [
    &["categorizing"],
    &["categorising"],
    &["categorizing"],
    &["categorising"],
];

pub(crate) static ENTRY_CATHARIZED_5807291134697395135: VariantsMap = [
    &["catharized"],
    &["catharised"],
    &["catharized"],
    &["catharised"],
];

pub(crate) static ENTRY_CATHARIZES_15482284310469218680: VariantsMap = [
    &["catharizes"],
    &["catharises"],
    &["catharizes"],
    &["catharises"],
];

pub(crate) static ENTRY_CATHARIZE_13562362241692832662: VariantsMap = [
    &["catharize"],
    &["catharise"],
    &["catharize"],
    &["catharise"],
];

pub(crate) static ENTRY_CATHARIZING_1602215100886763291: VariantsMap = [
    &["catharizing"],
    &["catharising"],
    &["catharizing"],
    &["catharising"],
];

pub(crate) static ENTRY_CATHETERIZATIONS_13120993350154324986: VariantsMap = [
    &["catheterizations"],
    &["catheterisations"],
    &["catheterizations"],
    &["catheterisations"],
];

pub(crate) static ENTRY_CATHETERIZATION_11439863909552030833: VariantsMap = [
    &["catheterization"],
    &["catheterisation"],
    &["catheterization"],
    &["catheterisation"],
];

pub(crate) static ENTRY_CATHETERIZED_5620836466321605366: VariantsMap = [
    &["catheterized"],
    &["catheterised"],
    &["catheterized"],
    &["catheterised"],
];

pub(crate) static ENTRY_CATHETERIZES_11247243473913332794: VariantsMap = [
    &["catheterizes"],
    &["catheterises"],
    &["catheterizes"],
    &["catheterises"],
];

pub(crate) static ENTRY_CATHETERIZE_6492718106386820661: VariantsMap = [
    &["catheterize"],
    &["catheterise"],
    &["catheterize"],
    &["catheterise"],
];

pub(crate) static ENTRY_CATHETERIZING_17180903138518299050: VariantsMap = [
    &["catheterizing"],
    &["catheterising"],
    &["catheterizing"],
    &["catheterising"],
];

pub(crate) static ENTRY_CATHOLICIZATIONS_8828933916874627488: VariantsMap = [
    &["catholicizations"],
    &["catholicisations"],
    &["catholicizations"],
    &["catholicisations"],
];

pub(crate) static ENTRY_CATHOLICIZATION_1039966536643797028: VariantsMap = [
    &["catholicization"],
    &["catholicisation"],
    &["catholicization"],
    &["catholicisation"],
];

pub(crate) static ENTRY_CATHOLICIZED_14250990289821303382: VariantsMap = [
    &["catholicized"],
    &["catholicised"],
    &["catholicized"],
    &["catholicised"],
];

pub(crate) static ENTRY_CATHOLICIZERS_11183927485796882872: VariantsMap = [
    &["catholicizers"],
    &["catholicisers"],
    &["catholicizers"],
    &["catholicisers"],
];

pub(crate) static ENTRY_CATHOLICIZER_17454867137057099076: VariantsMap = [
    &["catholicizer"],
    &["catholiciser"],
    &["catholicizer"],
    &["catholiciser"],
];

pub(crate) static ENTRY_CATHOLICIZES_893481801065117743: VariantsMap = [
    &["catholicizes"],
    &["catholicises"],
    &["catholicizes"],
    &["catholicises"],
];

pub(crate) static ENTRY_CATHOLICIZE_4285061554275370513: VariantsMap = [
    &["catholicize"],
    &["catholicise"],
    &["catholicize"],
    &["catholicise"],
];

pub(crate) static ENTRY_CATHOLICIZING_483590190526039504: VariantsMap = [
    &["catholicizing"],
    &["catholicising"],
    &["catholicizing"],
    &["catholicising"],
];

pub(crate) static ENTRY_CAULDRONS_1493548229478431121: VariantsMap = [
    &["caldrons", "cauldrons"],
    &["cauldrons"],
    &["cauldrons"],
    &["cauldrons"],
];

pub(crate) static ENTRY_CAULDRON_2025597715474043203: VariantsMap = [
    &["caldron", "cauldron"],
    &["cauldron"],
    &["cauldron"],
    &["cauldron"],
];

pub(crate) static ENTRY_CAULKED_16471647952977568672: VariantsMap =
    [&["caulked"], &["caulked"], &["caulked"], &["caulked"]];

pub(crate) static ENTRY_CAULKING_9579808018830977690: VariantsMap =
    [&["caulking"], &["caulking"], &["caulking"], &["caulking"]];

pub(crate) static ENTRY_CAULKS_14651084141226031502: VariantsMap =
    [&["caulks"], &["caulks"], &["caulks"], &["caulks"]];

pub(crate) static ENTRY_CAULKS_9108482765718739748: VariantsMap =
    [&["caulks"], &["caulks"], &["caulks"], &["caulks"]];

pub(crate) static ENTRY_CAULK_17535979702514416347: VariantsMap =
    [&["caulk"], &["caulk"], &["caulk"], &["caulk"]];

pub(crate) static ENTRY_CAULK_18401647289797844299: VariantsMap =
    [&["caulk"], &["caulk"], &["caulk"], &["caulk"]];

pub(crate) static ENTRY_CAUSTICIZATIONS_3386787494158775873: VariantsMap = [
    &["causticizations"],
    &["causticisations"],
    &["causticizations"],
    &["causticisations"],
];

pub(crate) static ENTRY_CAUSTICIZATION_14179900306302530284: VariantsMap = [
    &["causticization"],
    &["causticisation"],
    &["causticization"],
    &["causticisation"],
];

pub(crate) static ENTRY_CAUSTICIZERS_3776323281922224631: VariantsMap = [
    &["causticizers"],
    &["causticisers"],
    &["causticizers"],
    &["causticisers"],
];

pub(crate) static ENTRY_CAUSTICIZER_11653296088268450856: VariantsMap = [
    &["causticizer"],
    &["causticiser"],
    &["causticizer"],
    &["causticiser"],
];

pub(crate) static ENTRY_CAUSTICIZES_9636663018478092014: VariantsMap = [
    &["causticizes"],
    &["causticises"],
    &["causticizes"],
    &["causticises"],
];

pub(crate) static ENTRY_CAUSTICIZE_8749392950417620936: VariantsMap = [
    &["causticize"],
    &["causticise"],
    &["causticize"],
    &["causticise"],
];

pub(crate) static ENTRY_CAUTERIZATIONS_6182254960121790836: VariantsMap = [
    &["cauterizations"],
    &["cauterisations"],
    &["cauterizations"],
    &["cauterisations"],
];

pub(crate) static ENTRY_CAUTERIZATION_13195615037701165081: VariantsMap = [
    &["cauterization"],
    &["cauterisation"],
    &["cauterization"],
    &["cauterisation"],
];

pub(crate) static ENTRY_CAUTERIZED_14634034015720450176: VariantsMap = [
    &["cauterized"],
    &["cauterised"],
    &["cauterized"],
    &["cauterised"],
];

pub(crate) static ENTRY_CAUTERIZES_10593916877351446728: VariantsMap = [
    &["cauterizes"],
    &["cauterises"],
    &["cauterizes"],
    &["cauterises"],
];

pub(crate) static ENTRY_CAUTERIZE_3418770242947142090: VariantsMap = [
    &["cauterize"],
    &["cauterise"],
    &["cauterize"],
    &["cauterise"],
];

pub(crate) static ENTRY_CAUTERIZING_13207260063277352862: VariantsMap = [
    &["cauterizing"],
    &["cauterising"],
    &["cauterizing"],
    &["cauterising"],
];

pub(crate) static ENTRY_CAVIARS_3052109653380368873: VariantsMap =
    [&["caviars"], &["caviars"], &["caviars"], &["caviars"]];

pub(crate) static ENTRY_CAVIAR_7938491403168755546: VariantsMap =
    [&["caviar"], &["caviar"], &["caviar"], &["caviar"]];

pub(crate) static ENTRY_CAVILATION_6485561782401683356: VariantsMap = [
    &["cavilation"],
    &["cavillation"],
    &["cavillation"],
    &["cavillation"],
];

pub(crate) static ENTRY_CAVILED_13259789881942666788: VariantsMap =
    [&["caviled"], &["cavilled"], &["cavilled"], &["cavilled"]];

pub(crate) static ENTRY_CAVILERS_17995770150287304299: VariantsMap = [
    &["cavilers"],
    &["cavillers"],
    &["cavillers"],
    &["cavillers"],
];

pub(crate) static ENTRY_CAVILER_18221555292854240655: VariantsMap =
    [&["caviler"], &["caviller"], &["caviller"], &["caviller"]];

pub(crate) static ENTRY_CAVILINGS_3979930879616230447: VariantsMap = [
    &["cavilings"],
    &["cavillings"],
    &["cavillings"],
    &["cavillings"],
];

pub(crate) static ENTRY_CAVILING_3938684952444630623: VariantsMap = [
    &["caviling"],
    &["cavilling"],
    &["cavilling"],
    &["cavilling"],
];

pub(crate) static ENTRY_CECALLY_12720796600011784892: VariantsMap =
    [&["cecally"], &["caecally"], &["caecally"], &["caecally"]];

pub(crate) static ENTRY_CECITISES_10355938704850723051: VariantsMap = [
    &["cecitises"],
    &["caecitises"],
    &["caecitises"],
    &["caecitises"],
];

pub(crate) static ENTRY_CECITIS_18034763690253072964: VariantsMap =
    [&["cecitis"], &["caecitis"], &["caecitis"], &["caecitis"]];

pub(crate) static ENTRY_CECITY_9865259183091102407: VariantsMap =
    [&["cecity"], &["caecity"], &["caecity"], &["caecity"]];

pub(crate) static ENTRY_CECOSTOMY_3475802463529305333: VariantsMap = [
    &["cecostomy"],
    &["caecostomy"],
    &["caecostomy"],
    &["caecostomy"],
];

pub(crate) static ENTRY_CECOTOMY_3978768287054362751: VariantsMap = [
    &["cecotomy"],
    &["caecotomy"],
    &["caecotomy"],
    &["caecotomy"],
];

pub(crate) static ENTRY_CELASTRACEAE_17324005888177982048: VariantsMap = [
    &["celastraceae"],
    &["coelastraceae"],
    &["coelastraceae"],
    &["coelastraceae"],
];

pub(crate) static ENTRY_CELASTRACEOUS_18174723794622646878: VariantsMap = [
    &["celastraceous"],
    &["coelastraceous"],
    &["coelastraceous"],
    &["coelastraceous"],
];

pub(crate) static ENTRY_CELESTIALIZES_10058751039284937485: VariantsMap = [
    &["celestializes"],
    &["celestialises"],
    &["celestializes"],
    &["celestialises"],
];

pub(crate) static ENTRY_CELESTIALIZE_2289649302276111708: VariantsMap = [
    &["celestialize"],
    &["celestialise"],
    &["celestialize"],
    &["celestialise"],
];

pub(crate) static ENTRY_CELESTINE_11011528250519125092: VariantsMap = [
    &["celestine"],
    &["coelestine"],
    &["coelestine"],
    &["coelestine"],
];

pub(crate) static ENTRY_CELIACS_10248347099141877177: VariantsMap =
    [&["celiacs"], &["coeliacs"], &["coeliacs"], &["coeliacs"]];

pub(crate) static ENTRY_CELIAC_10249133411124257957: VariantsMap =
    [&["celiac"], &["coeliac"], &["coeliac"], &["coeliac"]];

pub(crate) static ENTRY_CELIALGIA_4569927604389576150: VariantsMap = [
    &["celialgia"],
    &["coelialgia"],
    &["coelialgia"],
    &["coelialgia"],
];

pub(crate) static ENTRY_CELIOMYALGIA_14548383766443531737: VariantsMap = [
    &["celiomyalgia"],
    &["coeliomyalgia"],
    &["coeliomyalgia"],
    &["coeliomyalgia"],
];

pub(crate) static ENTRY_CELIORRHEA_5614182174276153091: VariantsMap = [
    &["celiorrhea"],
    &["coeliorrhea"],
    &["coeliorrhea"],
    &["coeliorrhea"],
];

pub(crate) static ENTRY_CELIOSCOPY_17821312237861674807: VariantsMap = [
    &["celioscopy"],
    &["coelioscopy"],
    &["coelioscopy"],
    &["coelioscopy"],
];

pub(crate) static ENTRY_CELIOTOMY_9141657999599968712: VariantsMap = [
    &["celiotomy"],
    &["coeliotomy"],
    &["coeliotomy"],
    &["coeliotomy"],
];

pub(crate) static ENTRY_CELOMATA_5399894536275260385: VariantsMap = [
    &["celomata"],
    &["coelomata"],
    &["coelomata"],
    &["coelomata"],
];

pub(crate) static ENTRY_CELOMA_8394900856159450271: VariantsMap =
    [&["celoma"], &["coeloma"], &["coeloma"], &["coeloma"]];

pub(crate) static ENTRY_CELOMS_16869648723221026513: VariantsMap =
    [&["celoms"], &["coeloms"], &["coeloms"], &["coeloms"]];

pub(crate) static ENTRY_CELOM_581114569279805851: VariantsMap =
    [&["celom"], &["coelom"], &["coelom"], &["coelom"]];

pub(crate) static ENTRY_CELOSCOPE_13733285893205563827: VariantsMap = [
    &["celoscope"],
    &["coeloscope"],
    &["coeloscope"],
    &["coeloscope"],
];

pub(crate) static ENTRY_CELTICIZES_13468713960478569237: VariantsMap = [
    &["celticizes"],
    &["celticises"],
    &["celticizes"],
    &["celticises"],
];

pub(crate) static ENTRY_CELTICIZE_15359124010454967826: VariantsMap = [
    &["celticize"],
    &["celticise"],
    &["celticize"],
    &["celticise"],
];

pub(crate) static ENTRY_CENACLE_4902172834128420652: VariantsMap =
    [&["cenacle"], &["coenacle"], &["coenacle"], &["coenacle"]];

pub(crate) static ENTRY_CENACULUM_14642801640862790402: VariantsMap = [
    &["cenaculum"],
    &["coenaculum"],
    &["coenaculum"],
    &["coenaculum"],
];

pub(crate) static ENTRY_CENESTHESIAS_17650055632548316730: VariantsMap = [
    &["cenesthesias"],
    &["coenesthesias"],
    &["coenesthesias"],
    &["coenesthesias"],
];

pub(crate) static ENTRY_CENESTHESIA_3973419130660988894: VariantsMap = [
    &["cenesthesia"],
    &["coenesthesia"],
    &["coenesthesia"],
    &["coenesthesia"],
];

pub(crate) static ENTRY_CENESTHESIS_2981771230300833707: VariantsMap = [
    &["cenesthesis"],
    &["coenesthesis"],
    &["coenesthesis"],
    &["coenesthesis"],
];

pub(crate) static ENTRY_CENIS_1991031411311203268: VariantsMap =
    [&["cenis"], &["caenis"], &["caenis"], &["caenis"]];

pub(crate) static ENTRY_CENOBE_17025760197236238291: VariantsMap =
    [&["cenobe"], &["coenobe"], &["coenobe"], &["coenobe"]];

pub(crate) static ENTRY_CENOBITES_12070792697281985215: VariantsMap = [
    &["cenobites"],
    &["coenobites"],
    &["cenobites"],
    &["coenobites"],
];

pub(crate) static ENTRY_CENOBITE_15084617731417587224: VariantsMap =
    [&["cenobite"], &["coenobite"], &["cenobite"], &["coenobite"]];

pub(crate) static ENTRY_CENOBITICAL_3907716283980683620: VariantsMap = [
    &["cenobitical"],
    &["coenobitical"],
    &["cenobitical"],
    &["coenobitical"],
];

pub(crate) static ENTRY_CENOBITIC_861253358414117823: VariantsMap = [
    &["cenobitic"],
    &["coenobitic"],
    &["cenobitic"],
    &["coenobitic"],
];

pub(crate) static ENTRY_CENOBITISM_5016689208030165500: VariantsMap = [
    &["cenobitism"],
    &["coenobitism"],
    &["coenobitism"],
    &["coenobitism"],
];

pub(crate) static ENTRY_CENOBIUM_6656148321160010108: VariantsMap = [
    &["cenobium"],
    &["coenobium"],
    &["coenobium"],
    &["coenobium"],
];

pub(crate) static ENTRY_CENOBY_6246310194380860627: VariantsMap =
    [&["cenoby"], &["coenoby"], &["coenoby"], &["coenoby"]];

pub(crate) static ENTRY_CENOGENETICALLY_14614059803186390481: VariantsMap = [
    &["cenogenetically"],
    &["caenogenetically"],
    &["caenogenetically"],
    &["caenogenetically"],
];

pub(crate) static ENTRY_CENOGENETIC_14752824343681490356: VariantsMap = [
    &["cenogenetic"],
    &["coenogenetic"],
    &["coenogenetic"],
    &["coenogenetic"],
];

pub(crate) static ENTRY_CENOGENETIC_4645405785928938913: VariantsMap = [
    &["cenogenetic"],
    &["caenogenetic"],
    &["caenogenetic"],
    &["caenogenetic"],
];

pub(crate) static ENTRY_CENOSITE_6962695398695523616: VariantsMap = [
    &["cenosite"],
    &["coenosite"],
    &["coenosite"],
    &["coenosite"],
];

pub(crate) static ENTRY_CENOSPECIES_18129881350317785306: VariantsMap = [
    &["cenospecies"],
    &["coenospecies"],
    &["coenospecies"],
    &["coenospecies"],
];

pub(crate) static ENTRY_CENOSPECIFICALLY_5111318916340201830: VariantsMap = [
    &["cenospecifically"],
    &["coenospecifically"],
    &["coenospecifically"],
    &["coenospecifically"],
];

pub(crate) static ENTRY_CENOSPECIFIC_10710765180299401749: VariantsMap = [
    &["cenospecific"],
    &["coenospecific"],
    &["coenospecific"],
    &["coenospecific"],
];

pub(crate) static ENTRY_CENOZOIC_2810735566450048802: VariantsMap = [
    &["cenozoic"],
    &["caenozoic"],
    &["caenozoic"],
    &["caenozoic"],
];

pub(crate) static ENTRY_CENTERABLES_284130752204252297: VariantsMap = [
    &["centerables"],
    &["centreables"],
    &["centreables"],
    &["centreables"],
];

pub(crate) static ENTRY_CENTERABLE_7850484022405363699: VariantsMap = [
    &["centerable"],
    &["centreable"],
    &["centreable"],
    &["centreable"],
];

pub(crate) static ENTRY_CENTERBOARDS_6194272976717122092: VariantsMap = [
    &["centerboards"],
    &["centreboards"],
    &["centreboards"],
    &["centreboards"],
];

pub(crate) static ENTRY_CENTERBOARD_6663399917522410894: VariantsMap = [
    &["centerboard"],
    &["centreboard"],
    &["centreboard"],
    &["centreboard"],
];

pub(crate) static ENTRY_CENTERED_7034434783664313969: VariantsMap =
    [&["centered"], &["centred"], &["centred"], &["centred"]];

pub(crate) static ENTRY_CENTERERS_8988197150993437622: VariantsMap =
    [&["centerers"], &["centrers"], &["centrers"], &["centrers"]];

pub(crate) static ENTRY_CENTERER_1283754348315229141: VariantsMap =
    [&["centerer"], &["centrer"], &["centrer"], &["centrer"]];

pub(crate) static ENTRY_CENTERFOLDS_3764205251661654267: VariantsMap = [
    &["centerfolds"],
    &["centrefolds"],
    &["centrefolds"],
    &["centrefolds"],
];

pub(crate) static ENTRY_CENTERFOLD_8184640290263929626: VariantsMap = [
    &["centerfold"],
    &["centrefold"],
    &["centrefold"],
    &["centrefold"],
];

pub(crate) static ENTRY_CENTERINGS_3934315661544059303: VariantsMap = [
    &["centerings"],
    &["centrings"],
    &["centrings"],
    &["centrings"],
];

pub(crate) static ENTRY_CENTERING_2288436236637604266: VariantsMap =
    [&["centering"], &["centring"], &["centring"], &["centring"]];

pub(crate) static ENTRY_CENTERLESSER_4828594898766209427: VariantsMap = [
    &["centerlesser"],
    &["centrelesser"],
    &["centrelesser"],
    &["centrelesser"],
];

pub(crate) static ENTRY_CENTERLESSEST_15729458226381131123: VariantsMap = [
    &["centerlessest"],
    &["centrelessest"],
    &["centrelessest"],
    &["centrelessest"],
];

pub(crate) static ENTRY_CENTERLESS_16010100430566689787: VariantsMap = [
    &["centerless"],
    &["centreless"],
    &["centreless"],
    &["centreless"],
];

pub(crate) static ENTRY_CENTERLINES_17943791483589954179: VariantsMap = [
    &["centerlines"],
    &["centrelines"],
    &["centrelines"],
    &["centrelines"],
];

pub(crate) static ENTRY_CENTERLINE_4175184067421726158: VariantsMap = [
    &["centerline"],
    &["centreline"],
    &["centreline"],
    &["centreline"],
];

pub(crate) static ENTRY_CENTERMOST_14667266636773107736: VariantsMap = [
    &["centermost"],
    &["centremost"],
    &["centremost"],
    &["centremost"],
];

pub(crate) static ENTRY_CENTERPIECES_2175158136644578025: VariantsMap = [
    &["centerpieces"],
    &["centrepieces"],
    &["centrepieces"],
    &["centrepieces"],
];

pub(crate) static ENTRY_CENTERPIECE_9404304832569952961: VariantsMap = [
    &["centerpiece"],
    &["centrepiece"],
    &["centrepiece"],
    &["centrepiece"],
];

pub(crate) static ENTRY_CENTERS_8512068248537945159: VariantsMap =
    [&["centers"], &["centres"], &["centres"], &["centres"]];

pub(crate) static ENTRY_CENTERVILLE_8888927316062312202: VariantsMap = [
    &["centerville"],
    &["centreville"],
    &["centreville"],
    &["centreville"],
];

pub(crate) static ENTRY_CENTER_5116273194089119472: VariantsMap =
    [&["center"], &["centre"], &["centre"], &["centre"]];

pub(crate) static ENTRY_CENTIGRAMS_13488008474576662923: VariantsMap = [
    &["centigrams"],
    &["centigrams"],
    &["centigrams"],
    &["centigrams"],
];

pub(crate) static ENTRY_CENTIGRAM_6661702624209880115: VariantsMap = [
    &["centigram"],
    &["centigram"],
    &["centigram"],
    &["centigram"],
];

pub(crate) static ENTRY_CENTILITERS_15644223244315246330: VariantsMap = [
    &["centiliters"],
    &["centilitres"],
    &["centilitres"],
    &["centilitres"],
];

pub(crate) static ENTRY_CENTILITER_16190905673789101195: VariantsMap = [
    &["centiliter"],
    &["centilitre"],
    &["centilitre"],
    &["centilitre"],
];

pub(crate) static ENTRY_CENTIMETERS_13218717043789536591: VariantsMap = [
    &["centimeters"],
    &["centimetres"],
    &["centimetres"],
    &["centimetres"],
];

pub(crate) static ENTRY_CENTIMETER_7893665458627405085: VariantsMap = [
    &["centimeter"],
    &["centimetre"],
    &["centimetre"],
    &["centimetre"],
];

pub(crate) static ENTRY_CENTRALIZATIONS_16044732569453119370: VariantsMap = [
    &["centralizations"],
    &["centralisations"],
    &["centralizations"],
    &["centralisations"],
];

pub(crate) static ENTRY_CENTRALIZATION_1234582649982497784: VariantsMap = [
    &["centralization"],
    &["centralisation"],
    &["centralization"],
    &["centralisation"],
];

pub(crate) static ENTRY_CENTRALIZED_70126610329667809: VariantsMap = [
    &["centralized"],
    &["centralised"],
    &["centralized"],
    &["centralised"],
];

pub(crate) static ENTRY_CENTRALIZERS_15668441115014907887: VariantsMap = [
    &["centralizers"],
    &["centralisers"],
    &["centralizers"],
    &["centralisers"],
];

pub(crate) static ENTRY_CENTRALIZER_12959940147090220134: VariantsMap = [
    &["centralizer"],
    &["centraliser"],
    &["centralizer"],
    &["centraliser"],
];

pub(crate) static ENTRY_CENTRALIZES_13145361766427986184: VariantsMap = [
    &["centralizes"],
    &["centralises"],
    &["centralizes"],
    &["centralises"],
];

pub(crate) static ENTRY_CENTRALIZE_15017664864759648047: VariantsMap = [
    &["centralize"],
    &["centralise"],
    &["centralize"],
    &["centralise"],
];

pub(crate) static ENTRY_CENTRALIZING_11205811887699159106: VariantsMap = [
    &["centralizing"],
    &["centralising"],
    &["centralizing"],
    &["centralising"],
];

pub(crate) static ENTRY_CENTRIFUGALIZATIONS_16355479198686645900: VariantsMap = [
    &["centrifugalizations"],
    &["centrifugalisations"],
    &["centrifugalizations"],
    &["centrifugalisations"],
];

pub(crate) static ENTRY_CENTRIFUGALIZATION_10319359115375445805: VariantsMap = [
    &["centrifugalization"],
    &["centrifugalisation"],
    &["centrifugalization"],
    &["centrifugalisation"],
];

pub(crate) static ENTRY_CENTRIFUGALIZED_16399570134709120738: VariantsMap = [
    &["centrifugalized"],
    &["centrifugalised"],
    &["centrifugalized"],
    &["centrifugalised"],
];

pub(crate) static ENTRY_CENTRIFUGALIZES_17016153988543053118: VariantsMap = [
    &["centrifugalizes"],
    &["centrifugalises"],
    &["centrifugalizes"],
    &["centrifugalises"],
];

pub(crate) static ENTRY_CENTRIFUGALIZE_12152362034063070075: VariantsMap = [
    &["centrifugalize"],
    &["centrifugalise"],
    &["centrifugalize"],
    &["centrifugalise"],
];

pub(crate) static ENTRY_CENTRIFUGALIZING_7217121477743759122: VariantsMap = [
    &["centrifugalizing"],
    &["centrifugalising"],
    &["centrifugalizing"],
    &["centrifugalising"],
];

pub(crate) static ENTRY_CEPHALIZATIONS_11274159904518065511: VariantsMap = [
    &["cephalizations"],
    &["cephalisations"],
    &["cephalizations"],
    &["cephalisations"],
];

pub(crate) static ENTRY_CEPHALIZATION_1313416802058839208: VariantsMap = [
    &["cephalization"],
    &["cephalisation"],
    &["cephalization"],
    &["cephalisation"],
];

pub(crate) static ENTRY_CERATINS_7956220450419624429: VariantsMap =
    [&["ceratins"], &["creatins"], &["creatins"], &["creatins"]];

pub(crate) static ENTRY_CERATIN_7844527544181435388: VariantsMap =
    [&["ceratin"], &["creatin"], &["creatin"], &["creatin"]];

pub(crate) static ENTRY_CERAT_1886332108569610985: VariantsMap =
    [&["cerat"], &["creat"], &["creat"], &["creat"]];

pub(crate) static ENTRY_CERA_7059694773303335761: VariantsMap =
    [&["cera"], &["crea"], &["crea"], &["crea"]];

pub(crate) static ENTRY_CEREBRALIZATIONS_10944353801184109081: VariantsMap = [
    &["cerebralizations"],
    &["cerebralisations"],
    &["cerebralizations"],
    &["cerebralisations"],
];

pub(crate) static ENTRY_CEREBRALIZATION_639759174762081390: VariantsMap = [
    &["cerebralization"],
    &["cerebralisation"],
    &["cerebralization"],
    &["cerebralisation"],
];

pub(crate) static ENTRY_CEREBRALIZES_14811698873620229158: VariantsMap = [
    &["cerebralizes"],
    &["cerebralises"],
    &["cerebralizes"],
    &["cerebralises"],
];

pub(crate) static ENTRY_CEREBRALIZE_4644072502748774455: VariantsMap = [
    &["cerebralize"],
    &["cerebralise"],
    &["cerebralize"],
    &["cerebralise"],
];

pub(crate) static ENTRY_CEREMONIALIZES_13518074193055353148: VariantsMap = [
    &["ceremonializes"],
    &["ceremonialises"],
    &["ceremonializes"],
    &["ceremonialises"],
];

pub(crate) static ENTRY_CEREMONIALIZE_8839368071947058377: VariantsMap = [
    &["ceremonialize"],
    &["ceremonialise"],
    &["ceremonialize"],
    &["ceremonialise"],
];

pub(crate) static ENTRY_CERES_4278379745962029428: VariantsMap =
    [&["ceres"], &["crees"], &["crees"], &["crees"]];

pub(crate) static ENTRY_CERE_9821157149992437937: VariantsMap =
    [&["cere"], &["cree"], &["cree"], &["cree"]];

pub(crate) static ENTRY_CEROLITE_7632841335460717740: VariantsMap =
    [&["cerolite"], &["creolite"], &["creolite"], &["creolite"]];

pub(crate) static ENTRY_CERULEOLACTITE_1277200430318336008: VariantsMap = [
    &["ceruleolactite"],
    &["coeruleolactite"],
    &["coeruleolactite"],
    &["coeruleolactite"],
];

pub(crate) static ENTRY_CERULE_1141707642753807571: VariantsMap =
    [&["cerule"], &["caerule"], &["caerule"], &["caerule"]];

pub(crate) static ENTRY_CER_16898181025911443964: VariantsMap =
    [&["cer"], &["cre"], &["cre"], &["cre"]];

pub(crate) static ENTRY_CESARIA_7497611325269733598: VariantsMap =
    [&["cesaria"], &["caesaria"], &["caesaria"], &["caesaria"]];

pub(crate) static ENTRY_CESAR_6074944643525905095: VariantsMap =
    [&["cesar"], &["caesar"], &["caesar"], &["caesar"]];

pub(crate) static ENTRY_CESIOUS_10445245552084517023: VariantsMap =
    [&["cesious"], &["caesious"], &["caesious"], &["caesious"]];

pub(crate) static ENTRY_CESIUMS_4513476447764778250: VariantsMap =
    [&["cesiums"], &["caesiums"], &["cesiums"], &["caesiums"]];

pub(crate) static ENTRY_CESIUM_17343129911628596363: VariantsMap =
    [&["cesium"], &["caesium"], &["cesium"], &["caesium"]];

pub(crate) static ENTRY_CESPITOSELY_7196666758904903124: VariantsMap = [
    &["cespitosely"],
    &["caespitosely"],
    &["caespitosely"],
    &["caespitosely"],
];

pub(crate) static ENTRY_CESPITOSE_2511412164776933409: VariantsMap = [
    &["cespitose"],
    &["caespitose"],
    &["caespitose"],
    &["caespitose"],
];

pub(crate) static ENTRY_CESTUSES_17262448748104314423: VariantsMap = [
    &["cestuses"],
    &["caestuses"],
    &["caestuses"],
    &["caestuses"],
];

pub(crate) static ENTRY_CESTUS_2264271345052468556: VariantsMap =
    [&["cestus"], &["caestus"], &["caestus"], &["caestus"]];

pub(crate) static ENTRY_CESURAL_2827531996476826616: VariantsMap =
    [&["cesural"], &["caesural"], &["caesural"], &["caesural"]];

pub(crate) static ENTRY_CETUS_11617299917311809086: VariantsMap =
    [&["cetus"], &["coetus"], &["coetus"], &["coetus"]];

pub(crate) static ENTRY_CE_254143254853835550: VariantsMap =
    [&["ce"], &["coe"], &["coe"], &["coe"]];

pub(crate) static ENTRY_CHACES_10965505579181904844: VariantsMap =
    [&["chaces"], &["chacoes"], &["chacoes"], &["chacoes"]];

pub(crate) static ENTRY_CHALAZE_4744907345488198318: VariantsMap =
    [&["chalaze"], &["chalazae"], &["chalazae"], &["chalazae"]];

pub(crate) static ENTRY_CHALDEANS_13473385401733030342: VariantsMap = [
    &["chaldeans"],
    &["chaldaeans"],
    &["chaldaeans"],
    &["chaldaeans"],
];

pub(crate) static ENTRY_CHAMELEONIZES_16228445024684788006: VariantsMap = [
    &["chameleonizes"],
    &["chameleonises"],
    &["chameleonizes"],
    &["chameleonises"],
];

pub(crate) static ENTRY_CHAMELEONIZE_6719282861796065512: VariantsMap = [
    &["chameleonize"],
    &["chameleonise"],
    &["chameleonize"],
    &["chameleonise"],
];

pub(crate) static ENTRY_CHAMIZAL_15395913577609401131: VariantsMap =
    [&["chamizal"], &["chamisal"], &["chamizal"], &["chamisal"]];

pub(crate) static ENTRY_CHAMPIONIZES_1300772143294053091: VariantsMap = [
    &["championizes"],
    &["championises"],
    &["championizes"],
    &["championises"],
];

pub(crate) static ENTRY_CHAMPIONIZE_6246420755652451774: VariantsMap = [
    &["championize"],
    &["championise"],
    &["championize"],
    &["championise"],
];

pub(crate) static ENTRY_CHANNELED_13645294606351550471: VariantsMap = [
    &["channeled"],
    &["channelled"],
    &["channelled"],
    &["channelled"],
];

pub(crate) static ENTRY_CHANNELERS_15986650866937147094: VariantsMap = [
    &["channelers"],
    &["channellers"],
    &["channellers"],
    &["channellers"],
];

pub(crate) static ENTRY_CHANNELER_15902006922249091823: VariantsMap = [
    &["channeler"],
    &["channeller"],
    &["channeller"],
    &["channeller"],
];

pub(crate) static ENTRY_CHANNELING_9266544299775335589: VariantsMap = [
    &["channeling"],
    &["channelling"],
    &["channelling"],
    &["channelling"],
];

pub(crate) static ENTRY_CHANNELIZATIONS_17088609630173428942: VariantsMap = [
    &["channelizations"],
    &["channelisations"],
    &["channelizations"],
    &["channelisations"],
];

pub(crate) static ENTRY_CHANNELIZATION_8051143060294686401: VariantsMap = [
    &["channelization"],
    &["channelisation"],
    &["channelization"],
    &["channelisation"],
];

pub(crate) static ENTRY_CHANNELIZED_5009658046976798401: VariantsMap = [
    &["channelized"],
    &["channelised"],
    &["channelized"],
    &["channelised"],
];

pub(crate) static ENTRY_CHANNELIZES_12481680265741921670: VariantsMap = [
    &["channelizes"],
    &["channelises"],
    &["channelizes"],
    &["channelises"],
];

pub(crate) static ENTRY_CHANNELIZE_12428404691676585341: VariantsMap = [
    &["channelize"],
    &["channelise"],
    &["channelize"],
    &["channelise"],
];

pub(crate) static ENTRY_CHANNELIZING_3206328004957832674: VariantsMap = [
    &["channelizing"],
    &["channelising"],
    &["channelizing"],
    &["channelising"],
];

pub(crate) static ENTRY_CHAPTALIZATIONS_11954144109418771855: VariantsMap = [
    &["chaptalizations"],
    &["chaptalisations"],
    &["chaptalizations"],
    &["chaptalisations"],
];

pub(crate) static ENTRY_CHAPTALIZATION_6705837795677885132: VariantsMap = [
    &["chaptalization"],
    &["chaptalisation"],
    &["chaptalization"],
    &["chaptalisation"],
];

pub(crate) static ENTRY_CHAPTALIZED_15614458859451523347: VariantsMap = [
    &["chaptalized"],
    &["chaptalised"],
    &["chaptalized"],
    &["chaptalised"],
];

pub(crate) static ENTRY_CHAPTALIZES_12293081829441947782: VariantsMap = [
    &["chaptalizes"],
    &["chaptalises"],
    &["chaptalizes"],
    &["chaptalises"],
];

pub(crate) static ENTRY_CHAPTALIZE_3805623131812885010: VariantsMap = [
    &["chaptalize"],
    &["chaptalise"],
    &["chaptalize"],
    &["chaptalise"],
];

pub(crate) static ENTRY_CHAPTALIZING_3323047688472626072: VariantsMap = [
    &["chaptalizing"],
    &["chaptalising"],
    &["chaptalizing"],
    &["chaptalising"],
];

pub(crate) static ENTRY_CHARACTERIZABLER_3425015125508980850: VariantsMap = [
    &["characterizabler"],
    &["characterisabler"],
    &["characterizabler"],
    &["characterisabler"],
];

pub(crate) static ENTRY_CHARACTERIZABLEST_13029951397962650520: VariantsMap = [
    &["characterizablest"],
    &["characterisablest"],
    &["characterizablest"],
    &["characterisablest"],
];

pub(crate) static ENTRY_CHARACTERIZABLES_15907805406605774252: VariantsMap = [
    &["characterizables"],
    &["characterisables"],
    &["characterizables"],
    &["characterisables"],
];

pub(crate) static ENTRY_CHARACTERIZABLE_5496268454277897612: VariantsMap = [
    &["characterizable"],
    &["characterisable"],
    &["characterizable"],
    &["characterisable"],
];

pub(crate) static ENTRY_CHARACTERIZATIONS_9619550519705951475: VariantsMap = [
    &["characterizations"],
    &["characterisations"],
    &["characterizations"],
    &["characterisations"],
];

pub(crate) static ENTRY_CHARACTERIZATION_14570061393281069506: VariantsMap = [
    &["characterization"],
    &["characterisation"],
    &["characterization"],
    &["characterisation"],
];

pub(crate) static ENTRY_CHARACTERIZED_3099918736243105904: VariantsMap = [
    &["characterized"],
    &["characterised"],
    &["characterized"],
    &["characterised"],
];

pub(crate) static ENTRY_CHARACTERIZERS_11394110184099705360: VariantsMap = [
    &["characterizers"],
    &["characterisers"],
    &["characterizers"],
    &["characterisers"],
];

pub(crate) static ENTRY_CHARACTERIZER_14416082234464511775: VariantsMap = [
    &["characterizer"],
    &["characteriser"],
    &["characterizer"],
    &["characteriser"],
];

pub(crate) static ENTRY_CHARACTERIZES_10537774223087357590: VariantsMap = [
    &["characterizes"],
    &["characterises"],
    &["characterizes"],
    &["characterises"],
];

pub(crate) static ENTRY_CHARACTERIZE_7158652718387618717: VariantsMap = [
    &["characterize"],
    &["characterise"],
    &["characterize"],
    &["characterise"],
];

pub(crate) static ENTRY_CHARACTERIZING_3950440594591682040: VariantsMap = [
    &["characterizing"],
    &["characterising"],
    &["characterizing"],
    &["characterising"],
];

pub(crate) static ENTRY_CHARER_7967793744452777217: VariantsMap =
    [&["charer"], &["charre"], &["charre"], &["charre"]];

pub(crate) static ENTRY_CHATTELIZATIONS_14825459471315247028: VariantsMap = [
    &["chattelizations"],
    &["chattelisations"],
    &["chattelizations"],
    &["chattelisations"],
];

pub(crate) static ENTRY_CHATTELIZATION_7363246458991523337: VariantsMap = [
    &["chattelization"],
    &["chattelisation"],
    &["chattelization"],
    &["chattelisation"],
];

pub(crate) static ENTRY_CHATTELIZES_8748236808052543965: VariantsMap = [
    &["chattelizes"],
    &["chattelises"],
    &["chattelizes"],
    &["chattelises"],
];

pub(crate) static ENTRY_CHATTELIZE_6140490582785528527: VariantsMap = [
    &["chattelize"],
    &["chattelise"],
    &["chattelize"],
    &["chattelise"],
];

pub(crate) static ENTRY_CHECKBOOKS_17794340270798521929: VariantsMap = [
    &["checkbooks"],
    &["chequebooks"],
    &["chequebooks"],
    &["chequebooks"],
];

pub(crate) static ENTRY_CHECKBOOK_9009854196001512796: VariantsMap = [
    &["checkbook"],
    &["chequebook"],
    &["chequebook"],
    &["chequebook"],
];

pub(crate) static ENTRY_CHECKED_864493317061472521: VariantsMap =
    [&["checked"], &["chequed"], &["chequed"], &["chequed"]];

pub(crate) static ENTRY_CHECKERBOARDS_18064653792576628856: VariantsMap = [
    &["checkerboards"],
    &["chequerboards"],
    &["chequerboards"],
    &["chequerboards"],
];

pub(crate) static ENTRY_CHECKERBOARD_8549731976664485147: VariantsMap = [
    &["checkerboard"],
    &["chequerboard"],
    &["chequerboard"],
    &["chequerboard"],
];

pub(crate) static ENTRY_CHECKERED_6058427683271064427: VariantsMap = [
    &["checkered"],
    &["chequered"],
    &["checkered"],
    &["chequered"],
];

pub(crate) static ENTRY_CHECKERING_13657948767544155739: VariantsMap = [
    &["checkering"],
    &["chequering"],
    &["checkering"],
    &["chequering"],
];

pub(crate) static ENTRY_CHECKERS_4651898690896940599: VariantsMap =
    [&["checkers"], &["chequers"], &["checkers"], &["chequers"]];

pub(crate) static ENTRY_CHECKER_9431957816562634502: VariantsMap =
    [&["checker"], &["chequer"], &["checker"], &["chequer"]];

pub(crate) static ENTRY_CHECKING_12030083975828633786: VariantsMap =
    [&["checking"], &["chequing"], &["chequing"], &["chequing"]];

pub(crate) static ENTRY_CHECKS_5429237539074196507: VariantsMap =
    [&["checks"], &["cheques"], &["cheques"], &["cheques"]];

pub(crate) static ENTRY_CHECK_17773922188155612180: VariantsMap =
    [&["check"], &["cheque"], &["cheque"], &["cheque"]];

pub(crate) static ENTRY_CHEERFULIZES_14800232417183976396: VariantsMap = [
    &["cheerfulizes"],
    &["cheerfulises"],
    &["cheerfulizes"],
    &["cheerfulises"],
];

pub(crate) static ENTRY_CHEERFULIZE_762771897588790882: VariantsMap = [
    &["cheerfulize"],
    &["cheerfulise"],
    &["cheerfulize"],
    &["cheerfulise"],
];

pub(crate) static ENTRY_CHEERLY_11367263964946583096: VariantsMap =
    [&["cheerly"], &["cherely"], &["cherely"], &["cherely"]];

pub(crate) static ENTRY_CHELICERE_10130398757296091498: VariantsMap = [
    &["chelicere"],
    &["chelicerae"],
    &["chelicerae"],
    &["chelicerae"],
];

pub(crate) static ENTRY_CHEMICALIZATIONS_17250488376229572482: VariantsMap = [
    &["chemicalizations"],
    &["chemicalisations"],
    &["chemicalizations"],
    &["chemicalisations"],
];

pub(crate) static ENTRY_CHEMICALIZATION_14523349755381906432: VariantsMap = [
    &["chemicalization"],
    &["chemicalisation"],
    &["chemicalization"],
    &["chemicalisation"],
];

pub(crate) static ENTRY_CHEMICALIZES_17947429043522126420: VariantsMap = [
    &["chemicalizes"],
    &["chemicalises"],
    &["chemicalizes"],
    &["chemicalises"],
];

pub(crate) static ENTRY_CHEMICALIZE_2429770358300165469: VariantsMap = [
    &["chemicalize"],
    &["chemicalise"],
    &["chemicalize"],
    &["chemicalise"],
];

pub(crate) static ENTRY_CHENIXES_18140842653808609264: VariantsMap = [
    &["chenixes"],
    &["choenixes"],
    &["choenixes"],
    &["choenixes"],
];

pub(crate) static ENTRY_CHENIX_6890496202644655006: VariantsMap =
    [&["chenix"], &["choenix"], &["choenix"], &["choenix"]];

pub(crate) static ENTRY_CHETOPOD_16990284463679767109: VariantsMap = [
    &["chetopod"],
    &["chaetopod"],
    &["chaetopod"],
    &["chaetopod"],
];

pub(crate) static ENTRY_CHIFFER_15730952033932406541: VariantsMap =
    [&["chiffer"], &["chiffre"], &["chiffre"], &["chiffre"]];

pub(crate) static ENTRY_CHILDER_1838168120264181115: VariantsMap =
    [&["childer"], &["childre"], &["childre"], &["childre"]];

pub(crate) static ENTRY_CHILIES_2805435102646559217: VariantsMap =
    [&["chilies"], &["chillies"], &["chilies"], &["chillies"]];

pub(crate) static ENTRY_CHILI_17288123216260222064: VariantsMap =
    [&["chili"], &["chilli"], &["chili"], &["chilli"]];

pub(crate) static ENTRY_CHIMERIDS_5877455725309387123: VariantsMap = [
    &["chimerids"],
    &["chimaerids"],
    &["chimaerids"],
    &["chimaerids"],
];

pub(crate) static ENTRY_CHIMERID_12786529903260126440: VariantsMap = [
    &["chimerid"],
    &["chimaerid"],
    &["chimaerid"],
    &["chimaerid"],
];

pub(crate) static ENTRY_CHIMERISMS_7406463563173008857: VariantsMap = [
    &["chimerisms"],
    &["chimaerisms"],
    &["chimaerisms"],
    &["chimaerisms"],
];

pub(crate) static ENTRY_CHIMERISM_7571951058816157382: VariantsMap = [
    &["chimerism"],
    &["chimaerism"],
    &["chimaerism"],
    &["chimaerism"],
];

pub(crate) static ENTRY_CHISELED_4085439916793683323: VariantsMap = [
    &["chiseled"],
    &["chiselled"],
    &["chiselled"],
    &["chiselled"],
];

pub(crate) static ENTRY_CHISELERS_2484752867150137049: VariantsMap = [
    &["chiselers"],
    &["chisellers"],
    &["chisellers"],
    &["chisellers"],
];

pub(crate) static ENTRY_CHISELER_5457396429234167127: VariantsMap = [
    &["chiseler"],
    &["chiseller"],
    &["chiseller"],
    &["chiseller"],
];

pub(crate) static ENTRY_CHISELING_10949176651834943898: VariantsMap = [
    &["chiseling"],
    &["chiselling"],
    &["chiselling"],
    &["chiselling"],
];

pub(crate) static ENTRY_CHLORANEMIA_14943573677886171490: VariantsMap = [
    &["chloranemia"],
    &["chloranaemia"],
    &["chloranaemia"],
    &["chloranaemia"],
];

pub(crate) static ENTRY_CHLOREMIA_11927970491263400748: VariantsMap = [
    &["chloremia"],
    &["chloraemia"],
    &["chloraemia"],
    &["chloraemia"],
];

pub(crate) static ENTRY_CHLORIDIZED_12549087814443170120: VariantsMap = [
    &["chloridized"],
    &["chloridised"],
    &["chloridized"],
    &["chloridised"],
];

pub(crate) static ENTRY_CHLORIDIZES_10968236782051706807: VariantsMap = [
    &["chloridizes"],
    &["chloridises"],
    &["chloridizes"],
    &["chloridises"],
];

pub(crate) static ENTRY_CHLORIDIZE_15852197382856458938: VariantsMap = [
    &["chloridize"],
    &["chloridise"],
    &["chloridize"],
    &["chloridise"],
];

pub(crate) static ENTRY_CHLORIDIZING_13412386735842532684: VariantsMap = [
    &["chloridizing"],
    &["chloridising"],
    &["chloridizing"],
    &["chloridising"],
];

pub(crate) static ENTRY_CHLORINIZED_17584986266499508813: VariantsMap = [
    &["chlorinized"],
    &["chlorinised"],
    &["chlorinized"],
    &["chlorinised"],
];

pub(crate) static ENTRY_CHLORINIZES_6611213572390335959: VariantsMap = [
    &["chlorinizes"],
    &["chlorinises"],
    &["chlorinizes"],
    &["chlorinises"],
];

pub(crate) static ENTRY_CHLORINIZE_4322542416170463875: VariantsMap = [
    &["chlorinize"],
    &["chlorinise"],
    &["chlorinize"],
    &["chlorinise"],
];

pub(crate) static ENTRY_CHLORINIZING_11381892907334769846: VariantsMap = [
    &["chlorinizing"],
    &["chlorinising"],
    &["chlorinizing"],
    &["chlorinising"],
];

pub(crate) static ENTRY_CHLORITIZATIONS_14114607753454173066: VariantsMap = [
    &["chloritizations"],
    &["chloritisations"],
    &["chloritizations"],
    &["chloritisations"],
];

pub(crate) static ENTRY_CHLORITIZATION_6329588467839471117: VariantsMap = [
    &["chloritization"],
    &["chloritisation"],
    &["chloritization"],
    &["chloritisation"],
];

pub(crate) static ENTRY_CHLOROANEMIA_6563825885243058247: VariantsMap = [
    &["chloroanemia"],
    &["chloroanaemia"],
    &["chloroanaemia"],
    &["chloroanaemia"],
];

pub(crate) static ENTRY_CHLOROFORMIZATIONS_10258939630473669855: VariantsMap = [
    &["chloroformizations"],
    &["chloroformisations"],
    &["chloroformizations"],
    &["chloroformisations"],
];

pub(crate) static ENTRY_CHLOROFORMIZATION_18266136341140668534: VariantsMap = [
    &["chloroformization"],
    &["chloroformisation"],
    &["chloroformization"],
    &["chloroformisation"],
];

pub(crate) static ENTRY_CHLOROFORMIZES_15872749603216002935: VariantsMap = [
    &["chloroformizes"],
    &["chloroformises"],
    &["chloroformizes"],
    &["chloroformises"],
];

pub(crate) static ENTRY_CHLOROFORMIZE_4267369403631594202: VariantsMap = [
    &["chloroformize"],
    &["chloroformise"],
    &["chloroformize"],
    &["chloroformise"],
];

pub(crate) static ENTRY_CHOEPHORI_13897909648270625076: VariantsMap = [
    &["choephori"],
    &["choaephori"],
    &["choaephori"],
    &["choaephori"],
];

pub(crate) static ENTRY_CHOLEMIAS_1320999302245492995: VariantsMap = [
    &["cholemias"],
    &["cholaemias"],
    &["cholaemias"],
    &["cholaemias"],
];

pub(crate) static ENTRY_CHOLEMIA_10472935038101851986: VariantsMap = [
    &["cholemia"],
    &["cholaemia"],
    &["cholaemia"],
    &["cholaemia"],
];

pub(crate) static ENTRY_CHOLOPHEIN_3609148772555478472: VariantsMap = [
    &["cholophein"],
    &["cholophaein"],
    &["cholophaein"],
    &["cholophaein"],
];

pub(crate) static ENTRY_CHORIZATIONS_15797795758878758614: VariantsMap = [
    &["chorizations"],
    &["chorisations"],
    &["chorizations"],
    &["chorisations"],
];

pub(crate) static ENTRY_CHORIZATION_2744114980681106174: VariantsMap = [
    &["chorization"],
    &["chorisation"],
    &["chorization"],
    &["chorisation"],
];

pub(crate) static ENTRY_CHRISTIANIZATIONS_939157464750574119: VariantsMap = [
    &["christianizations"],
    &["christianisations"],
    &["christianizations"],
    &["christianisations"],
];

pub(crate) static ENTRY_CHRISTIANIZATION_18360975039569708955: VariantsMap = [
    &["christianization"],
    &["christianisation"],
    &["christianization"],
    &["christianisation"],
];

pub(crate) static ENTRY_CHRISTIANIZED_2305498091852997860: VariantsMap = [
    &["christianized"],
    &["christianised"],
    &["christianized"],
    &["christianised"],
];

pub(crate) static ENTRY_CHRISTIANIZERS_2108724649580713236: VariantsMap = [
    &["christianizers"],
    &["christianisers"],
    &["christianizers"],
    &["christianisers"],
];

pub(crate) static ENTRY_CHRISTIANIZER_12661100042100507791: VariantsMap = [
    &["christianizer"],
    &["christianiser"],
    &["christianizer"],
    &["christianiser"],
];

pub(crate) static ENTRY_CHRISTIANIZES_14805680753012611713: VariantsMap = [
    &["christianizes"],
    &["christianises"],
    &["christianizes"],
    &["christianises"],
];

pub(crate) static ENTRY_CHRISTIANIZE_17043173566737823874: VariantsMap = [
    &["christianize"],
    &["christianise"],
    &["christianize"],
    &["christianise"],
];

pub(crate) static ENTRY_CHRISTIANIZING_3955473617595650674: VariantsMap = [
    &["christianizing"],
    &["christianising"],
    &["christianizing"],
    &["christianising"],
];

pub(crate) static ENTRY_CHROMATIZES_8188945171625541176: VariantsMap = [
    &["chromatizes"],
    &["chromatises"],
    &["chromatizes"],
    &["chromatises"],
];

pub(crate) static ENTRY_CHROMATIZE_11372633214051605374: VariantsMap = [
    &["chromatize"],
    &["chromatise"],
    &["chromatize"],
    &["chromatise"],
];

pub(crate) static ENTRY_CHROMESTHESIA_3768057935676918572: VariantsMap = [
    &["chromesthesia"],
    &["chromaesthesia"],
    &["chromaesthesia"],
    &["chromaesthesia"],
];

pub(crate) static ENTRY_CHROMICIZES_17571169233071174152: VariantsMap = [
    &["chromicizes"],
    &["chromicises"],
    &["chromicizes"],
    &["chromicises"],
];

pub(crate) static ENTRY_CHROMICIZE_2411849466836240319: VariantsMap = [
    &["chromicize"],
    &["chromicise"],
    &["chromicize"],
    &["chromicise"],
];

pub(crate) static ENTRY_CHROMIZED_10186147401749465104: VariantsMap = [
    &["chromized"],
    &["chromised"],
    &["chromized"],
    &["chromised"],
];

pub(crate) static ENTRY_CHROMIZES_15865986984042622696: VariantsMap = [
    &["chromizes"],
    &["chromises"],
    &["chromizes"],
    &["chromises"],
];

pub(crate) static ENTRY_CHROMIZE_5262872595657112785: VariantsMap =
    [&["chromize"], &["chromise"], &["chromize"], &["chromise"]];

pub(crate) static ENTRY_CHROMIZING_1826459851914480574: VariantsMap = [
    &["chromizing"],
    &["chromising"],
    &["chromizing"],
    &["chromising"],
];

pub(crate) static ENTRY_CHRONOLOGIZED_5845452320056255894: VariantsMap = [
    &["chronologized"],
    &["chronologised"],
    &["chronologized"],
    &["chronologised"],
];

pub(crate) static ENTRY_CHRONOLOGIZES_11841064468767540761: VariantsMap = [
    &["chronologizes"],
    &["chronologises"],
    &["chronologizes"],
    &["chronologises"],
];

pub(crate) static ENTRY_CHRONOLOGIZE_12846965199938511954: VariantsMap = [
    &["chronologize"],
    &["chronologise"],
    &["chronologize"],
    &["chronologise"],
];

pub(crate) static ENTRY_CHRONOLOGIZING_3430096775276619170: VariantsMap = [
    &["chronologizing"],
    &["chronologising"],
    &["chronologizing"],
    &["chronologising"],
];

pub(crate) static ENTRY_CICATRICES_6326588841275377818: VariantsMap = [
    &["cicatrices"],
    &["cicatrices"],
    &["cicatrices"],
    &["cicatrices"],
];

pub(crate) static ENTRY_CICATRICULE_5186934031307821263: VariantsMap = [
    &["cicatricule"],
    &["cicatriculae"],
    &["cicatriculae"],
    &["cicatriculae"],
];

pub(crate) static ENTRY_CICATRIZANT_12486636820913979450: VariantsMap = [
    &["cicatrizant"],
    &["cicatrisant"],
    &["cicatrizant"],
    &["cicatrisant"],
];

pub(crate) static ENTRY_CICATRIZATE_4590503640777088427: VariantsMap = [
    &["cicatrizate"],
    &["cicatrisate"],
    &["cicatrizate"],
    &["cicatrisate"],
];

pub(crate) static ENTRY_CICATRIZATIONS_18248179778439022462: VariantsMap = [
    &["cicatrizations"],
    &["cicatrisations"],
    &["cicatrizations"],
    &["cicatrisations"],
];

pub(crate) static ENTRY_CICATRIZATION_12095729010218257569: VariantsMap = [
    &["cicatrization"],
    &["cicatrisation"],
    &["cicatrization"],
    &["cicatrisation"],
];

pub(crate) static ENTRY_CICATRIZED_1926551778073289264: VariantsMap = [
    &["cicatrized"],
    &["cicatrised"],
    &["cicatrized"],
    &["cicatrised"],
];

pub(crate) static ENTRY_CICATRIZER_13415710374354046728: VariantsMap = [
    &["cicatrizer"],
    &["cicatriser"],
    &["cicatrizer"],
    &["cicatriser"],
];

pub(crate) static ENTRY_CICATRIZES_18063560548351573209: VariantsMap = [
    &["cicatrizes"],
    &["cicatrises"],
    &["cicatrizes"],
    &["cicatrises"],
];

pub(crate) static ENTRY_CICATRIZE_17449239625442097002: VariantsMap = [
    &["cicatrize"],
    &["cicatrise"],
    &["cicatrize"],
    &["cicatrise"],
];

pub(crate) static ENTRY_CICATRIZING_13257780105810264437: VariantsMap = [
    &["cicatrizing"],
    &["cicatrising"],
    &["cicatrizing"],
    &["cicatrising"],
];

pub(crate) static ENTRY_CICERONIANIZES_12944202395538543019: VariantsMap = [
    &["ciceronianizes"],
    &["ciceronianises"],
    &["ciceronianizes"],
    &["ciceronianises"],
];

pub(crate) static ENTRY_CICERONIANIZE_15017821268740384544: VariantsMap = [
    &["ciceronianize"],
    &["ciceronianise"],
    &["ciceronianize"],
    &["ciceronianise"],
];

pub(crate) static ENTRY_CIGARETTES_2896249679667819882: VariantsMap = [
    &["cigarettes"],
    &["cigarettes"],
    &["cigarettes"],
    &["cigarettes"],
];

pub(crate) static ENTRY_CIGARETTE_3240954964785468511: VariantsMap = [
    &["cigarette"],
    &["cigarette"],
    &["cigarette"],
    &["cigarette"],
];

pub(crate) static ENTRY_CIMICIDE_252691567770959002: VariantsMap = [
    &["cimicide"],
    &["cimicidae"],
    &["cimicidae"],
    &["cimicidae"],
];

pub(crate) static ENTRY_CINCHONIZATIONS_6677879833142170709: VariantsMap = [
    &["cinchonizations"],
    &["cinchonisations"],
    &["cinchonizations"],
    &["cinchonisations"],
];

pub(crate) static ENTRY_CINCHONIZATION_10888105560110104460: VariantsMap = [
    &["cinchonization"],
    &["cinchonisation"],
    &["cinchonization"],
    &["cinchonisation"],
];

pub(crate) static ENTRY_CINCHONIZED_1697201765172263780: VariantsMap = [
    &["cinchonized"],
    &["cinchonised"],
    &["cinchonized"],
    &["cinchonised"],
];

pub(crate) static ENTRY_CINCHONIZES_1522582946661651319: VariantsMap = [
    &["cinchonizes"],
    &["cinchonises"],
    &["cinchonizes"],
    &["cinchonises"],
];

pub(crate) static ENTRY_CINCHONIZE_14048235966165265995: VariantsMap = [
    &["cinchonize"],
    &["cinchonise"],
    &["cinchonize"],
    &["cinchonise"],
];

pub(crate) static ENTRY_CINCHONIZING_12181226423066017076: VariantsMap = [
    &["cinchonizing"],
    &["cinchonising"],
    &["cinchonizing"],
    &["cinchonising"],
];

pub(crate) static ENTRY_CINEMATIZE_14141234202546792174: VariantsMap = [
    &["cinematize"],
    &["cinematise"],
    &["cinematize"],
    &["cinematise"],
];

pub(crate) static ENTRY_CINTER_5255881384560882873: VariantsMap =
    [&["cinter"], &["cintre"], &["cintre"], &["cintre"]];

pub(crate) static ENTRY_CIRCEAN_2837826078225645071: VariantsMap =
    [&["circean"], &["circaean"], &["circaean"], &["circaean"]];

pub(crate) static ENTRY_CIRCULARIZATIONS_1984387235149986914: VariantsMap = [
    &["circularizations"],
    &["circularisations"],
    &["circularizations"],
    &["circularisations"],
];

pub(crate) static ENTRY_CIRCULARIZATION_17838622241027218582: VariantsMap = [
    &["circularization"],
    &["circularisation"],
    &["circularization"],
    &["circularisation"],
];

pub(crate) static ENTRY_CIRCULARIZED_17077855093521846327: VariantsMap = [
    &["circularized"],
    &["circularised"],
    &["circularized"],
    &["circularised"],
];

pub(crate) static ENTRY_CIRCULARIZERS_9484517890337368712: VariantsMap = [
    &["circularizers"],
    &["circularisers"],
    &["circularizers"],
    &["circularisers"],
];

pub(crate) static ENTRY_CIRCULARIZER_10781935971896485951: VariantsMap = [
    &["circularizer"],
    &["circulariser"],
    &["circularizer"],
    &["circulariser"],
];

pub(crate) static ENTRY_CIRCULARIZES_5373385699289469463: VariantsMap = [
    &["circularizes"],
    &["circularises"],
    &["circularizes"],
    &["circularises"],
];

pub(crate) static ENTRY_CIRCULARIZE_168549599908464304: VariantsMap = [
    &["circularize"],
    &["circularise"],
    &["circularize"],
    &["circularise"],
];

pub(crate) static ENTRY_CIRCULARIZING_13000180152805667363: VariantsMap = [
    &["circularizing"],
    &["circularising"],
    &["circularizing"],
    &["circularising"],
];

pub(crate) static ENTRY_CIRCUMCENTERS_3631459482063575085: VariantsMap = [
    &["circumcenters"],
    &["circumcentres"],
    &["circumcentres"],
    &["circumcentres"],
];

pub(crate) static ENTRY_CIRCUMCENTER_207116320690761995: VariantsMap = [
    &["circumcenter"],
    &["circumcentre"],
    &["circumcentre"],
    &["circumcentre"],
];

pub(crate) static ENTRY_CIRCUMESOPHAGAL_14446114158922149948: VariantsMap = [
    &["circumesophagal"],
    &["circumoesophagal"],
    &["circumoesophagal"],
    &["circumoesophagal"],
];

pub(crate) static ENTRY_CITHERNS_14301574885087358999: VariantsMap =
    [&["citherns"], &["cithrens"], &["cithrens"], &["cithrens"]];

pub(crate) static ENTRY_CITHERN_6627389279929637643: VariantsMap =
    [&["cithern"], &["cithren"], &["cithren"], &["cithren"]];

pub(crate) static ENTRY_CITIZENIZED_1264772045676693507: VariantsMap = [
    &["citizenized"],
    &["citizenised"],
    &["citizenized"],
    &["citizenised"],
];

pub(crate) static ENTRY_CITIZENIZES_18430750407999070293: VariantsMap = [
    &["citizenizes"],
    &["citizenises"],
    &["citizenizes"],
    &["citizenises"],
];

pub(crate) static ENTRY_CITIZENIZE_14957512849570966194: VariantsMap = [
    &["citizenize"],
    &["citizenise"],
    &["citizenize"],
    &["citizenise"],
];

pub(crate) static ENTRY_CITIZENIZING_4863665565831279155: VariantsMap = [
    &["citizenizing"],
    &["citizenising"],
    &["citizenizing"],
    &["citizenising"],
];

pub(crate) static ENTRY_CIVILIANIZATIONS_17045136972884179633: VariantsMap = [
    &["civilianizations"],
    &["civilianisations"],
    &["civilianizations"],
    &["civilianisations"],
];

pub(crate) static ENTRY_CIVILIANIZATION_17575505866978524289: VariantsMap = [
    &["civilianization"],
    &["civilianisation"],
    &["civilianization"],
    &["civilianisation"],
];

pub(crate) static ENTRY_CIVILIANIZED_15443763184741606790: VariantsMap = [
    &["civilianized"],
    &["civilianised"],
    &["civilianized"],
    &["civilianised"],
];

pub(crate) static ENTRY_CIVILIANIZES_1873437655700489131: VariantsMap = [
    &["civilianizes"],
    &["civilianises"],
    &["civilianizes"],
    &["civilianises"],
];

pub(crate) static ENTRY_CIVILIANIZE_4503116173799461974: VariantsMap = [
    &["civilianize"],
    &["civilianise"],
    &["civilianize"],
    &["civilianise"],
];

pub(crate) static ENTRY_CIVILIANIZING_10886647865038667032: VariantsMap = [
    &["civilianizing"],
    &["civilianising"],
    &["civilianizing"],
    &["civilianising"],
];

pub(crate) static ENTRY_CIVILIZABLER_1009443025003033054: VariantsMap = [
    &["civilizabler"],
    &["civilisabler"],
    &["civilizabler"],
    &["civilisabler"],
];

pub(crate) static ENTRY_CIVILIZABLEST_10363624488321164576: VariantsMap = [
    &["civilizablest"],
    &["civilisablest"],
    &["civilizablest"],
    &["civilisablest"],
];

pub(crate) static ENTRY_CIVILIZABLES_6992110506684451627: VariantsMap = [
    &["civilizables"],
    &["civilisables"],
    &["civilizables"],
    &["civilisables"],
];

pub(crate) static ENTRY_CIVILIZABLE_12250954830034270586: VariantsMap = [
    &["civilizable"],
    &["civilisable"],
    &["civilizable"],
    &["civilisable"],
];

pub(crate) static ENTRY_CIVILIZATIONALER_2223864160765042134: VariantsMap = [
    &["civilizationaler"],
    &["civilisationaler"],
    &["civilizationaler"],
    &["civilisationaler"],
];

pub(crate) static ENTRY_CIVILIZATIONALEST_8468211002452117483: VariantsMap = [
    &["civilizationalest"],
    &["civilisationalest"],
    &["civilizationalest"],
    &["civilisationalest"],
];

pub(crate) static ENTRY_CIVILIZATIONALS_16890543284368506921: VariantsMap = [
    &["civilizationals"],
    &["civilisationals"],
    &["civilizationals"],
    &["civilisationals"],
];

pub(crate) static ENTRY_CIVILIZATIONAL_6714937636315886610: VariantsMap = [
    &["civilizational"],
    &["civilisational"],
    &["civilizational"],
    &["civilisational"],
];

pub(crate) static ENTRY_CIVILIZATIONS_10559611739235699948: VariantsMap = [
    &["civilizations"],
    &["civilisations"],
    &["civilizations"],
    &["civilisations"],
];

pub(crate) static ENTRY_CIVILIZATION_15013403646640920675: VariantsMap = [
    &["civilization"],
    &["civilisation"],
    &["civilization"],
    &["civilisation"],
];

pub(crate) static ENTRY_CIVILIZATORY_1986047737625317948: VariantsMap = [
    &["civilizatory"],
    &["civilisatory"],
    &["civilizatory"],
    &["civilisatory"],
];

pub(crate) static ENTRY_CIVILIZEDNESSES_12980539923790842297: VariantsMap = [
    &["civilizednesses"],
    &["civilisednesses"],
    &["civilizednesses"],
    &["civilisednesses"],
];

pub(crate) static ENTRY_CIVILIZEDNESS_8991979933830574813: VariantsMap = [
    &["civilizedness"],
    &["civilisedness"],
    &["civilizedness"],
    &["civilisedness"],
];

pub(crate) static ENTRY_CIVILIZED_12545974517817432534: VariantsMap = [
    &["civilized"],
    &["civilised"],
    &["civilized"],
    &["civilised"],
];

pub(crate) static ENTRY_CIVILIZERS_15636793990348820949: VariantsMap = [
    &["civilizers"],
    &["civilisers"],
    &["civilizers"],
    &["civilisers"],
];

pub(crate) static ENTRY_CIVILIZER_6543816336610065762: VariantsMap = [
    &["civilizer"],
    &["civiliser"],
    &["civilizer"],
    &["civiliser"],
];

pub(crate) static ENTRY_CIVILIZES_10418281941070358506: VariantsMap = [
    &["civilizes"],
    &["civilises"],
    &["civilizes"],
    &["civilises"],
];

pub(crate) static ENTRY_CIVILIZE_11305300708024681316: VariantsMap =
    [&["civilize"], &["civilise"], &["civilize"], &["civilise"]];

pub(crate) static ENTRY_CIVILIZING_14404215502589538333: VariantsMap = [
    &["civilizing"],
    &["civilising"],
    &["civilizing"],
    &["civilising"],
];

pub(crate) static ENTRY_CIZE_6818406889408576007: VariantsMap =
    [&["cize"], &["cise"], &["cize"], &["cise"]];

pub(crate) static ENTRY_CLAMORED_4631300413281563513: VariantsMap = [
    &["clamored"],
    &["clamoured"],
    &["clamoured"],
    &["clamoured"],
];

pub(crate) static ENTRY_CLAMORERS_15362052334359174240: VariantsMap = [
    &["clamorers"],
    &["clamourers"],
    &["clamourers"],
    &["clamourers"],
];

pub(crate) static ENTRY_CLAMORER_17883337748457044767: VariantsMap = [
    &["clamorer"],
    &["clamourer"],
    &["clamourer"],
    &["clamourer"],
];

pub(crate) static ENTRY_CLAMORING_5415785372025381455: VariantsMap = [
    &["clamoring"],
    &["clamouring"],
    &["clamouring"],
    &["clamouring"],
];

pub(crate) static ENTRY_CLAMORIST_16325759197501191896: VariantsMap = [
    &["clamorist"],
    &["clamourist"],
    &["clamourist"],
    &["clamourist"],
];

pub(crate) static ENTRY_CLAMORSOME_7681677003017063573: VariantsMap = [
    &["clamorsome"],
    &["clamoursome"],
    &["clamoursome"],
    &["clamoursome"],
];

pub(crate) static ENTRY_CLAMORS_2773887349084725873: VariantsMap =
    [&["clamors"], &["clamours"], &["clamours"], &["clamours"]];

pub(crate) static ENTRY_CLAMOR_11722915000424769718: VariantsMap =
    [&["clamor"], &["clamour"], &["clamour"], &["clamour"]];

pub(crate) static ENTRY_CLANGORED_15084752842311792542: VariantsMap = [
    &["clangored"],
    &["clangoured"],
    &["clangoured"],
    &["clangoured"],
];

pub(crate) static ENTRY_CLANGORING_14458664811220315605: VariantsMap = [
    &["clangoring"],
    &["clangouring"],
    &["clangouring"],
    &["clangouring"],
];

pub(crate) static ENTRY_CLANGORS_14016497850837852764: VariantsMap = [
    &["clangors"],
    &["clangours"],
    &["clangours"],
    &["clangours"],
];

pub(crate) static ENTRY_CLANGOR_11515055037441300100: VariantsMap =
    [&["clangor"], &["clangour"], &["clangour"], &["clangour"]];

pub(crate) static ENTRY_CLARES_1731306513503085955: VariantsMap =
    [&["clares"], &["claroes"], &["claroes"], &["claroes"]];

pub(crate) static ENTRY_CLARINETISTS_8097106053649523838: VariantsMap = [
    &["clarinetists"],
    &["clarinettists"],
    &["clarinetists"],
    &["clarinettists"],
];

pub(crate) static ENTRY_CLARINETIST_8834681667523453854: VariantsMap = [
    &["clarinetist"],
    &["clarinettist"],
    &["clarinetist"],
    &["clarinettist"],
];

pub(crate) static ENTRY_CLASSICALIZES_2442176202643132547: VariantsMap = [
    &["classicalizes"],
    &["classicalises"],
    &["classicalizes"],
    &["classicalises"],
];

pub(crate) static ENTRY_CLASSICALIZE_7168633238933548715: VariantsMap = [
    &["classicalize"],
    &["classicalise"],
    &["classicalize"],
    &["classicalise"],
];

pub(crate) static ENTRY_CLASSICIZATION_4974218833361429454: VariantsMap = [
    &["classicization"],
    &["classicisation"],
    &["classicization"],
    &["classicisation"],
];

pub(crate) static ENTRY_CLASSICIZED_11040640355679759136: VariantsMap = [
    &["classicized"],
    &["classicised"],
    &["classicized"],
    &["classicised"],
];

pub(crate) static ENTRY_CLASSICIZES_7627137652355384645: VariantsMap = [
    &["classicizes"],
    &["classicises"],
    &["classicizes"],
    &["classicises"],
];

pub(crate) static ENTRY_CLASSICIZE_6847726068049490278: VariantsMap = [
    &["classicize"],
    &["classicise"],
    &["classicize"],
    &["classicise"],
];

pub(crate) static ENTRY_CLASSICIZING_13143908142359497861: VariantsMap = [
    &["classicizing"],
    &["classicising"],
    &["classicizing"],
    &["classicising"],
];

pub(crate) static ENTRY_CLAUSULE_67200534337080796: VariantsMap = [
    &["clausule"],
    &["clausulae"],
    &["clausulae"],
    &["clausulae"],
];

pub(crate) static ENTRY_CLERICALIZES_8269477549000417569: VariantsMap = [
    &["clericalizes"],
    &["clericalises"],
    &["clericalizes"],
    &["clericalises"],
];

pub(crate) static ENTRY_CLERICALIZE_1865718535677694450: VariantsMap = [
    &["clericalize"],
    &["clericalise"],
    &["clericalize"],
    &["clericalise"],
];

pub(crate) static ENTRY_CLETE_1876197067502328027: VariantsMap =
    [&["clete"], &["cloete"], &["cloete"], &["cloete"]];

pub(crate) static ENTRY_CLIMATIZED_124773700894549172: VariantsMap = [
    &["climatized"],
    &["climatised"],
    &["climatized"],
    &["climatised"],
];

pub(crate) static ENTRY_CLIMATIZES_13429047652583201954: VariantsMap = [
    &["climatizes"],
    &["climatises"],
    &["climatizes"],
    &["climatises"],
];

pub(crate) static ENTRY_CLIMATIZE_3452063415630301254: VariantsMap = [
    &["climatize"],
    &["climatise"],
    &["climatize"],
    &["climatise"],
];

pub(crate) static ENTRY_CLIMATIZING_4457168972427899649: VariantsMap = [
    &["climatizing"],
    &["climatising"],
    &["climatizing"],
    &["climatising"],
];

pub(crate) static ENTRY_CLOWER_9225698487842396572: VariantsMap =
    [&["clower"], &["clowre"], &["clowre"], &["clowre"]];

pub(crate) static ENTRY_CLYTIE_11851522067983621366: VariantsMap =
    [&["clytie"], &["clytiae"], &["clytiae"], &["clytiae"]];

pub(crate) static ENTRY_COALIZED_1331392537006305584: VariantsMap =
    [&["coalized"], &["coalised"], &["coalized"], &["coalised"]];

pub(crate) static ENTRY_COALIZERS_8541541270360324668: VariantsMap = [
    &["coalizers"],
    &["coalisers"],
    &["coalizers"],
    &["coalisers"],
];

pub(crate) static ENTRY_COALIZER_8326324895948995645: VariantsMap =
    [&["coalizer"], &["coaliser"], &["coalizer"], &["coaliser"]];

pub(crate) static ENTRY_COALIZES_12556076575141372172: VariantsMap =
    [&["coalizes"], &["coalises"], &["coalizes"], &["coalises"]];

pub(crate) static ENTRY_COALIZE_1093705182941742482: VariantsMap =
    [&["coalize"], &["coalise"], &["coalize"], &["coalise"]];

pub(crate) static ENTRY_COALIZING_8107852365569207830: VariantsMap = [
    &["coalizing"],
    &["coalising"],
    &["coalizing"],
    &["coalising"],
];

pub(crate) static ENTRY_COCAINIZATIONS_3037752219365718178: VariantsMap = [
    &["cocainizations"],
    &["cocainisations"],
    &["cocainizations"],
    &["cocainisations"],
];

pub(crate) static ENTRY_COCAINIZATION_18270228789956323677: VariantsMap = [
    &["cocainization"],
    &["cocainisation"],
    &["cocainization"],
    &["cocainisation"],
];

pub(crate) static ENTRY_COCAINIZED_11738928114927355282: VariantsMap = [
    &["cocainized"],
    &["cocainised"],
    &["cocainized"],
    &["cocainised"],
];

pub(crate) static ENTRY_COCAINIZES_4491426404312671844: VariantsMap = [
    &["cocainizes"],
    &["cocainises"],
    &["cocainizes"],
    &["cocainises"],
];

pub(crate) static ENTRY_COCAINIZE_5959521297540551059: VariantsMap = [
    &["cocainize"],
    &["cocainise"],
    &["cocainize"],
    &["cocainise"],
];

pub(crate) static ENTRY_COCAINIZING_3962782652468626350: VariantsMap = [
    &["cocainizing"],
    &["cocainising"],
    &["cocainizing"],
    &["cocainising"],
];

pub(crate) static ENTRY_COCUIZA_6504886933052210304: VariantsMap =
    [&["cocuiza"], &["cocuisa"], &["cocuiza"], &["cocuisa"]];

pub(crate) static ENTRY_COEDUCATIONALIZES_6378010748334869944: VariantsMap = [
    &["coeducationalizes"],
    &["coeducationalises"],
    &["coeducationalizes"],
    &["coeducationalises"],
];

pub(crate) static ENTRY_COEDUCATIONALIZE_1494210807334794701: VariantsMap = [
    &["coeducationalize"],
    &["coeducationalise"],
    &["coeducationalize"],
    &["coeducationalise"],
];

pub(crate) static ENTRY_COENAMORED_9568490962748517648: VariantsMap = [
    &["coenamored"],
    &["coenamoured"],
    &["coenamoured"],
    &["coenamoured"],
];

pub(crate) static ENTRY_COENAMORING_951487569841068233: VariantsMap = [
    &["coenamoring"],
    &["coenamouring"],
    &["coenamouring"],
    &["coenamouring"],
];

pub(crate) static ENTRY_COENAMORMENT_10116172708022357030: VariantsMap = [
    &["coenamorment"],
    &["coenamourment"],
    &["coenamourment"],
    &["coenamourment"],
];

pub(crate) static ENTRY_COENAMORS_8428808930600945906: VariantsMap = [
    &["coenamors"],
    &["coenamours"],
    &["coenamours"],
    &["coenamours"],
];

pub(crate) static ENTRY_COENAMOR_8473204005333691620: VariantsMap = [
    &["coenamor"],
    &["coenamour"],
    &["coenamour"],
    &["coenamour"],
];

pub(crate) static ENTRY_COEQUALIZES_1651368880238979086: VariantsMap = [
    &["coequalizes"],
    &["coequalises"],
    &["coequalizes"],
    &["coequalises"],
];

pub(crate) static ENTRY_COEQUALIZE_15105464134551790946: VariantsMap = [
    &["coequalize"],
    &["coequalise"],
    &["coequalize"],
    &["coequalise"],
];

pub(crate) static ENTRY_COE_10755603025154058571: VariantsMap =
    [&["coe"], &["cooe"], &["cooe"], &["cooe"]];

pub(crate) static ENTRY_COGNIZABILITY_660527253976403780: VariantsMap = [
    &["cognizability"],
    &["cognisability"],
    &["cognizability"],
    &["cognisability"],
];

pub(crate) static ENTRY_COGNIZABLENESS_16476592524827512160: VariantsMap = [
    &["cognizableness"],
    &["cognisableness"],
    &["cognizableness"],
    &["cognisableness"],
];

pub(crate) static ENTRY_COGNIZABLER_12070099101883833731: VariantsMap = [
    &["cognizabler"],
    &["cognisabler"],
    &["cognizabler"],
    &["cognisabler"],
];

pub(crate) static ENTRY_COGNIZABLEST_13955023369005527923: VariantsMap = [
    &["cognizablest"],
    &["cognisablest"],
    &["cognizablest"],
    &["cognisablest"],
];

pub(crate) static ENTRY_COGNIZABLE_13131115414619000772: VariantsMap = [
    &["cognizable"],
    &["cognisable"],
    &["cognizable"],
    &["cognisable"],
];

pub(crate) static ENTRY_COGNIZABLIER_1964601888045213766: VariantsMap = [
    &["cognizablier"],
    &["cognisablier"],
    &["cognizablier"],
    &["cognisablier"],
];

pub(crate) static ENTRY_COGNIZABLIEST_13701693542862328478: VariantsMap = [
    &["cognizabliest"],
    &["cognisabliest"],
    &["cognizabliest"],
    &["cognisabliest"],
];

pub(crate) static ENTRY_COGNIZABLY_17839926776700915805: VariantsMap = [
    &["cognizably"],
    &["cognisably"],
    &["cognizably"],
    &["cognisably"],
];

pub(crate) static ENTRY_COGNIZANCES_183948325192833313: VariantsMap = [
    &["cognizances"],
    &["cognisances"],
    &["cognizances"],
    &["cognisances"],
];

pub(crate) static ENTRY_COGNIZANCE_14359512853615918641: VariantsMap = [
    &["cognizance"],
    &["cognisance"],
    &["cognizance"],
    &["cognisance"],
];

pub(crate) static ENTRY_COGNIZANTER_9274314327914715355: VariantsMap = [
    &["cognizanter"],
    &["cognisanter"],
    &["cognizanter"],
    &["cognisanter"],
];

pub(crate) static ENTRY_COGNIZANTEST_9952434271050939774: VariantsMap = [
    &["cognizantest"],
    &["cognisantest"],
    &["cognizantest"],
    &["cognisantest"],
];

pub(crate) static ENTRY_COGNIZANT_2557847978553579663: VariantsMap = [
    &["cognizant"],
    &["cognisant"],
    &["cognizant"],
    &["cognisant"],
];

pub(crate) static ENTRY_COGNIZED_17562230997464673899: VariantsMap =
    [&["cognized"], &["cognised"], &["cognized"], &["cognised"]];

pub(crate) static ENTRY_COGNIZERS_16818874771090495789: VariantsMap = [
    &["cognizers"],
    &["cognisers"],
    &["cognizers"],
    &["cognisers"],
];

pub(crate) static ENTRY_COGNIZER_17235063272659781689: VariantsMap =
    [&["cognizer"], &["cogniser"], &["cognizer"], &["cogniser"]];

pub(crate) static ENTRY_COGNIZES_313141652357958777: VariantsMap =
    [&["cognizes"], &["cognises"], &["cognizes"], &["cognises"]];

pub(crate) static ENTRY_COGNIZE_7253118900028580039: VariantsMap =
    [&["cognize"], &["cognise"], &["cognize"], &["cognise"]];

pub(crate) static ENTRY_COGNIZING_14291458489887284299: VariantsMap = [
    &["cognizing"],
    &["cognising"],
    &["cognizing"],
    &["cognising"],
];

pub(crate) static ENTRY_COLLATERALIZE_4809202625356484324: VariantsMap = [
    &["collateralize"],
    &["collateralise"],
    &["collateralize"],
    &["collateralise"],
];

pub(crate) static ENTRY_COLLECTIBLES_1426649794037748395: VariantsMap = [
    &["collectibles"],
    &["collectables"],
    &["collectibles"],
    &["collectables"],
];

pub(crate) static ENTRY_COLLECTIBLE_16675394473838043634: VariantsMap = [
    &["collectible"],
    &["collectable"],
    &["collectible"],
    &["collectable"],
];

pub(crate) static ENTRY_COLLECTIVIZATIONS_6853316050939234055: VariantsMap = [
    &["collectivizations"],
    &["collectivisations"],
    &["collectivizations"],
    &["collectivisations"],
];

pub(crate) static ENTRY_COLLECTIVIZATION_10577206395052359405: VariantsMap = [
    &["collectivization"],
    &["collectivisation"],
    &["collectivization"],
    &["collectivisation"],
];

pub(crate) static ENTRY_COLLECTIVIZED_14370760959187496202: VariantsMap = [
    &["collectivized"],
    &["collectivised"],
    &["collectivized"],
    &["collectivised"],
];

pub(crate) static ENTRY_COLLECTIVIZES_15340840028673940577: VariantsMap = [
    &["collectivizes"],
    &["collectivises"],
    &["collectivizes"],
    &["collectivises"],
];

pub(crate) static ENTRY_COLLECTIVIZE_18197662740300515669: VariantsMap = [
    &["collectivize"],
    &["collectivise"],
    &["collectivize"],
    &["collectivise"],
];

pub(crate) static ENTRY_COLLECTIVIZING_6177450980824602558: VariantsMap = [
    &["collectivizing"],
    &["collectivising"],
    &["collectivizing"],
    &["collectivising"],
];

pub(crate) static ENTRY_COLLOQUIALIZES_11772046900035477346: VariantsMap = [
    &["colloquializes"],
    &["colloquialises"],
    &["colloquializes"],
    &["colloquialises"],
];

pub(crate) static ENTRY_COLLOQUIALIZE_400572582640316358: VariantsMap = [
    &["colloquialize"],
    &["colloquialise"],
    &["colloquialize"],
    &["colloquialise"],
];

pub(crate) static ENTRY_COLLOQUIZED_2987662592391153464: VariantsMap = [
    &["colloquized"],
    &["colloquised"],
    &["colloquized"],
    &["colloquised"],
];

pub(crate) static ENTRY_COLLOQUIZES_3694957155887273629: VariantsMap = [
    &["colloquizes"],
    &["colloquises"],
    &["colloquizes"],
    &["colloquises"],
];

pub(crate) static ENTRY_COLLOQUIZE_3542999561179306173: VariantsMap = [
    &["colloquize"],
    &["colloquise"],
    &["colloquize"],
    &["colloquise"],
];

pub(crate) static ENTRY_COLLOQUIZING_12005217252377921527: VariantsMap = [
    &["colloquizing"],
    &["colloquising"],
    &["colloquizing"],
    &["colloquising"],
];

pub(crate) static ENTRY_COLONIALIZED_13876149610938201725: VariantsMap = [
    &["colonialized"],
    &["colonialised"],
    &["colonialized"],
    &["colonialised"],
];

pub(crate) static ENTRY_COLONIALIZES_14570746695121826765: VariantsMap = [
    &["colonializes"],
    &["colonialises"],
    &["colonializes"],
    &["colonialises"],
];

pub(crate) static ENTRY_COLONIALIZE_17015664660619402146: VariantsMap = [
    &["colonialize"],
    &["colonialise"],
    &["colonialize"],
    &["colonialise"],
];

pub(crate) static ENTRY_COLONIALIZING_16068571893089538400: VariantsMap = [
    &["colonializing"],
    &["colonialising"],
    &["colonializing"],
    &["colonialising"],
];

pub(crate) static ENTRY_COLONIZABILITIES_12944259693371296365: VariantsMap = [
    &["colonizabilities"],
    &["colonisabilities"],
    &["colonizabilities"],
    &["colonisabilities"],
];

pub(crate) static ENTRY_COLONIZABILITY_11573587685077716438: VariantsMap = [
    &["colonizability"],
    &["colonisability"],
    &["colonizability"],
    &["colonisability"],
];

pub(crate) static ENTRY_COLONIZABLER_7503793641425675771: VariantsMap = [
    &["colonizabler"],
    &["colonisabler"],
    &["colonizabler"],
    &["colonisabler"],
];

pub(crate) static ENTRY_COLONIZABLEST_13287343767333590772: VariantsMap = [
    &["colonizablest"],
    &["colonisablest"],
    &["colonizablest"],
    &["colonisablest"],
];

pub(crate) static ENTRY_COLONIZABLES_7468307704661763383: VariantsMap = [
    &["colonizables"],
    &["colonisables"],
    &["colonizables"],
    &["colonisables"],
];

pub(crate) static ENTRY_COLONIZABLE_1551399607404148929: VariantsMap = [
    &["colonizable"],
    &["colonisable"],
    &["colonizable"],
    &["colonisable"],
];

pub(crate) static ENTRY_COLONIZATIONISTS_16863993202249434726: VariantsMap = [
    &["colonizationists"],
    &["colonisationists"],
    &["colonizationists"],
    &["colonisationists"],
];

pub(crate) static ENTRY_COLONIZATIONIST_176926856555957139: VariantsMap = [
    &["colonizationist"],
    &["colonisationist"],
    &["colonizationist"],
    &["colonisationist"],
];

pub(crate) static ENTRY_COLONIZATIONS_12298250811536901685: VariantsMap = [
    &["colonizations"],
    &["colonisations"],
    &["colonizations"],
    &["colonisations"],
];

pub(crate) static ENTRY_COLONIZATION_8572095881455583344: VariantsMap = [
    &["colonization"],
    &["colonisation"],
    &["colonization"],
    &["colonisation"],
];

pub(crate) static ENTRY_COLONIZED_12903152841060558253: VariantsMap = [
    &["colonized"],
    &["colonised"],
    &["colonized"],
    &["colonised"],
];

pub(crate) static ENTRY_COLONIZERS_11110896653251592981: VariantsMap = [
    &["colonizers"],
    &["colonisers"],
    &["colonizers"],
    &["colonisers"],
];

pub(crate) static ENTRY_COLONIZER_5320596989867894996: VariantsMap = [
    &["colonizer"],
    &["coloniser"],
    &["colonizer"],
    &["coloniser"],
];

pub(crate) static ENTRY_COLONIZES_5176087008588077388: VariantsMap = [
    &["colonizes"],
    &["colonises"],
    &["colonizes"],
    &["colonises"],
];

pub(crate) static ENTRY_COLONIZE_15302728430964322592: VariantsMap =
    [&["colonize"], &["colonise"], &["colonize"], &["colonise"]];

pub(crate) static ENTRY_COLONIZING_17297511401074881747: VariantsMap = [
    &["colonizing"],
    &["colonising"],
    &["colonizing"],
    &["colonising"],
];

pub(crate) static ENTRY_COLORABILITIES_17934830495879279238: VariantsMap = [
    &["colorabilities"],
    &["colourabilities"],
    &["colourabilities"],
    &["colourabilities"],
];

pub(crate) static ENTRY_COLORABILITY_3833618249244001959: VariantsMap = [
    &["colorability"],
    &["colourability"],
    &["colourability"],
    &["colourability"],
];

pub(crate) static ENTRY_COLORABLENESSES_10749946314548598617: VariantsMap = [
    &["colorablenesses"],
    &["colourablenesses"],
    &["colourablenesses"],
    &["colourablenesses"],
];

pub(crate) static ENTRY_COLORABLENESS_1061796348140451347: VariantsMap = [
    &["colorableness"],
    &["colourableness"],
    &["colourableness"],
    &["colourableness"],
];

pub(crate) static ENTRY_COLORABLER_1063847220352847404: VariantsMap = [
    &["colorabler"],
    &["colourabler"],
    &["colourabler"],
    &["colourabler"],
];

pub(crate) static ENTRY_COLORABLEST_3683085641889155962: VariantsMap = [
    &["colorablest"],
    &["colourablest"],
    &["colourablest"],
    &["colourablest"],
];

pub(crate) static ENTRY_COLORABLES_10854398030589164189: VariantsMap = [
    &["colorables"],
    &["colourables"],
    &["colourables"],
    &["colourables"],
];

pub(crate) static ENTRY_COLORABLE_9126609110540102083: VariantsMap = [
    &["colorable"],
    &["colourable"],
    &["colourable"],
    &["colourable"],
];

pub(crate) static ENTRY_COLORABLIER_5968483988144955864: VariantsMap = [
    &["colorablier"],
    &["colourablier"],
    &["colourablier"],
    &["colourablier"],
];

pub(crate) static ENTRY_COLORABLIEST_5199306118528597149: VariantsMap = [
    &["colorabliest"],
    &["colourabliest"],
    &["colourabliest"],
    &["colourabliest"],
];

pub(crate) static ENTRY_COLORABLIES_16005107918816262896: VariantsMap = [
    &["colorablies"],
    &["colourablies"],
    &["colourablies"],
    &["colourablies"],
];

pub(crate) static ENTRY_COLORABLY_13475999889111967538: VariantsMap = [
    &["colorably"],
    &["colourably"],
    &["colourably"],
    &["colourably"],
];

pub(crate) static ENTRY_COLORADANS_1537230991364273395: VariantsMap = [
    &["coloradans"],
    &["colouradans"],
    &["colouradans"],
    &["colouradans"],
];

pub(crate) static ENTRY_COLORADAN_1710087118093866996: VariantsMap = [
    &["coloradan"],
    &["colouradan"],
    &["colouradan"],
    &["colouradan"],
];

pub(crate) static ENTRY_COLORADOITE_10437671738809934244: VariantsMap = [
    &["coloradoite"],
    &["colouradoite"],
    &["colouradoite"],
    &["colouradoite"],
];

pub(crate) static ENTRY_COLORADO_672786360083421122: VariantsMap = [
    &["colorado"],
    &["colourado"],
    &["colourado"],
    &["colourado"],
];

pub(crate) static ENTRY_COLORAMA_10946100748903023597: VariantsMap = [
    &["colorama"],
    &["colourama"],
    &["colourama"],
    &["colourama"],
];

pub(crate) static ENTRY_COLORANTS_7537794752295559574: VariantsMap = [
    &["colorants"],
    &["colourants"],
    &["colourants"],
    &["colourants"],
];

pub(crate) static ENTRY_COLORANT_105918244627467133: VariantsMap = [
    &["colorant"],
    &["colourant"],
    &["colourant"],
    &["colourant"],
];

pub(crate) static ENTRY_COLORATE_7568881222694249579: VariantsMap = [
    &["colorate"],
    &["colourate"],
    &["colourate"],
    &["colourate"],
];

pub(crate) static ENTRY_COLORATIONALER_18110955114460055798: VariantsMap = [
    &["colorationaler"],
    &["colorationaler"],
    &["colorationaler"],
    &["colorationaler"],
];

pub(crate) static ENTRY_COLORATIONALEST_16549871838474883279: VariantsMap = [
    &["colorationalest"],
    &["colorationalest"],
    &["colorationalest"],
    &["colorationalest"],
];

pub(crate) static ENTRY_COLORATIONALLIER_11632159047499104121: VariantsMap = [
    &["colorationallier"],
    &["colorationallier"],
    &["colorationallier"],
    &["colorationallier"],
];

pub(crate) static ENTRY_COLORATIONALLIEST_15869239691609448176: VariantsMap = [
    &["colorationalliest"],
    &["colorationalliest"],
    &["colorationalliest"],
    &["colorationalliest"],
];

pub(crate) static ENTRY_COLORATIONALLY_6635974304993009997: VariantsMap = [
    &["colorationally"],
    &["colorationally"],
    &["colorationally"],
    &["colorationally"],
];

pub(crate) static ENTRY_COLORATIONAL_7644580988989747664: VariantsMap = [
    &["colorational"],
    &["colorational"],
    &["colorational"],
    &["colorational"],
];

pub(crate) static ENTRY_COLORATIONS_1952756960960680507: VariantsMap = [
    &["colorations"],
    &["colorations", "colourations"],
    &["colorations"],
    &["colorations", "colourations"],
];

pub(crate) static ENTRY_COLORATION_8662739203385742912: VariantsMap = [
    &["coloration"],
    &["coloration", "colouration"],
    &["coloration"],
    &["coloration", "colouration"],
];

pub(crate) static ENTRY_COLORATIVE_17851173748347347190: VariantsMap = [
    &["colorative"],
    &["colourative"],
    &["colourative"],
    &["colourative"],
];

pub(crate) static ENTRY_COLORBEARER_9903060614478418481: VariantsMap = [
    &["colorbearer"],
    &["colourbearer"],
    &["colourbearer"],
    &["colourbearer"],
];

pub(crate) static ENTRY_COLORBLINDNESSES_12714928556099515868: VariantsMap = [
    &["colorblindnesses"],
    &["colourblindnesses"],
    &["colourblindnesses"],
    &["colourblindnesses"],
];

pub(crate) static ENTRY_COLORBLINDNESS_15137443200927238655: VariantsMap = [
    &["colorblindness"],
    &["colourblindness"],
    &["colourblindness"],
    &["colourblindness"],
];

pub(crate) static ENTRY_COLORBLIND_6088870633188592041: VariantsMap = [
    &["colorblind"],
    &["colourblind"],
    &["colourblind"],
    &["colourblind"],
];

pub(crate) static ENTRY_COLORBRED_17391526765371994938: VariantsMap = [
    &["colorbred"],
    &["colourbred"],
    &["colourbred"],
    &["colourbred"],
];

pub(crate) static ENTRY_COLORBREEDING_14262752611756151320: VariantsMap = [
    &["colorbreeding"],
    &["colourbreeding"],
    &["colourbreeding"],
    &["colourbreeding"],
];

pub(crate) static ENTRY_COLORBREEDS_5534022895414416287: VariantsMap = [
    &["colorbreeds"],
    &["colourbreeds"],
    &["colourbreeds"],
    &["colourbreeds"],
];

pub(crate) static ENTRY_COLORBREED_988623603127049866: VariantsMap = [
    &["colorbreed"],
    &["colourbreed"],
    &["colourbreed"],
    &["colourbreed"],
];

pub(crate) static ENTRY_COLORCASTED_10398645425299808234: VariantsMap = [
    &["colorcasted"],
    &["colourcasted"],
    &["colourcasted"],
    &["colourcasted"],
];

pub(crate) static ENTRY_COLORCASTERS_9885877195250711665: VariantsMap = [
    &["colorcasters"],
    &["colourcasters"],
    &["colourcasters"],
    &["colourcasters"],
];

pub(crate) static ENTRY_COLORCASTER_8192206561724383576: VariantsMap = [
    &["colorcaster"],
    &["colourcaster"],
    &["colourcaster"],
    &["colourcaster"],
];

pub(crate) static ENTRY_COLORCASTING_9616298919649932012: VariantsMap = [
    &["colorcasting"],
    &["colourcasting"],
    &["colourcasting"],
    &["colourcasting"],
];

pub(crate) static ENTRY_COLORCASTS_17581853229444769235: VariantsMap = [
    &["colorcasts"],
    &["colourcasts"],
    &["colourcasts"],
    &["colourcasts"],
];

pub(crate) static ENTRY_COLORCAST_16740960231179575917: VariantsMap = [
    &["colorcast"],
    &["colourcast"],
    &["colourcast"],
    &["colourcast"],
];

pub(crate) static ENTRY_COLORECTAL_9394771582914199855: VariantsMap = [
    &["colorectal"],
    &["colourectal"],
    &["colourectal"],
    &["colourectal"],
];

pub(crate) static ENTRY_COLORECTITIS_11920759655606208881: VariantsMap = [
    &["colorectitis"],
    &["colourectitis"],
    &["colourectitis"],
    &["colourectitis"],
];

pub(crate) static ENTRY_COLORECTOSTOMY_809184159134628418: VariantsMap = [
    &["colorectostomy"],
    &["colourectostomy"],
    &["colourectostomy"],
    &["colourectostomy"],
];

pub(crate) static ENTRY_COLOREDS_5638105898846322523: VariantsMap = [
    &["coloreds"],
    &["coloureds"],
    &["coloureds"],
    &["coloureds"],
];

pub(crate) static ENTRY_COLORED_809367823820397764: VariantsMap =
    [&["colored"], &["coloured"], &["coloured"], &["coloured"]];

pub(crate) static ENTRY_COLORERS_5523036624009318320: VariantsMap = [
    &["colorers"],
    &["colourers"],
    &["colourers"],
    &["colourers"],
];

pub(crate) static ENTRY_COLORER_6377883908421217617: VariantsMap =
    [&["colorer"], &["colourer"], &["colourer"], &["colourer"]];

pub(crate) static ENTRY_COLORFASTNESSES_14995112700652023509: VariantsMap = [
    &["colorfastnesses"],
    &["colourfastnesses"],
    &["colourfastnesses"],
    &["colourfastnesses"],
];

pub(crate) static ENTRY_COLORFASTNESS_3258841464722986607: VariantsMap = [
    &["colorfastness"],
    &["colourfastness"],
    &["colourfastness"],
    &["colourfastness"],
];

pub(crate) static ENTRY_COLORFAST_16696822485914404702: VariantsMap = [
    &["colorfast"],
    &["colourfast"],
    &["colourfast"],
    &["colourfast"],
];

pub(crate) static ENTRY_COLORFULER_10294924989983822582: VariantsMap = [
    &["colorfuler"],
    &["colourfuler"],
    &["colourfuler"],
    &["colourfuler"],
];

pub(crate) static ENTRY_COLORFULEST_202572902882532719: VariantsMap = [
    &["colorfulest"],
    &["colourfulest"],
    &["colourfulest"],
    &["colourfulest"],
];

pub(crate) static ENTRY_COLORFULLIER_3454480613316383412: VariantsMap = [
    &["colorfullier"],
    &["colourfullier"],
    &["colourfullier"],
    &["colourfullier"],
];

pub(crate) static ENTRY_COLORFULLIEST_14019017521674302328: VariantsMap = [
    &["colorfulliest"],
    &["colourfulliest"],
    &["colourfulliest"],
    &["colourfulliest"],
];

pub(crate) static ENTRY_COLORFULLY_7749800674951458575: VariantsMap = [
    &["colorfully"],
    &["colourfully"],
    &["colourfully"],
    &["colourfully"],
];

pub(crate) static ENTRY_COLORFULNESSES_11724036744178299544: VariantsMap = [
    &["colorfulnesses"],
    &["colourfulnesses"],
    &["colourfulnesses"],
    &["colourfulnesses"],
];

pub(crate) static ENTRY_COLORFULNESS_8831709788792250227: VariantsMap = [
    &["colorfulness"],
    &["colourfulness"],
    &["colourfulness"],
    &["colourfulness"],
];

pub(crate) static ENTRY_COLORFUL_16225861255487751804: VariantsMap = [
    &["colorful"],
    &["colourful"],
    &["colourful"],
    &["colourful"],
];

pub(crate) static ENTRY_COLORIFICS_7493178994191350405: VariantsMap = [
    &["colorifics"],
    &["colourifics"],
    &["colourifics"],
    &["colourifics"],
];

pub(crate) static ENTRY_COLORIFIC_17453281363599547611: VariantsMap = [
    &["colorific"],
    &["colourific"],
    &["colourific"],
    &["colourific"],
];

pub(crate) static ENTRY_COLORIMETERS_16988328923257615588: VariantsMap = [
    &["colorimeters"],
    &["colorimeters"],
    &["colorimeters"],
    &["colorimeters"],
];

pub(crate) static ENTRY_COLORIMETER_5995992236279956204: VariantsMap = [
    &["colorimeter"],
    &["colorimeter"],
    &["colorimeter"],
    &["colorimeter"],
];

pub(crate) static ENTRY_COLORIMETRICALLY_5243289402205557910: VariantsMap = [
    &["colorimetrically"],
    &["colourimetrically"],
    &["colourimetrically"],
    &["colourimetrically"],
];

pub(crate) static ENTRY_COLORIMETRICAL_14932230836831976255: VariantsMap = [
    &["colorimetrical"],
    &["colourimetrical"],
    &["colourimetrical"],
    &["colourimetrical"],
];

pub(crate) static ENTRY_COLORIMETRICS_8847586357101611180: VariantsMap = [
    &["colorimetrics"],
    &["colorimetrics"],
    &["colorimetrics"],
    &["colorimetrics"],
];

pub(crate) static ENTRY_COLORIMETRIC_2752387257901137840: VariantsMap = [
    &["colorimetric"],
    &["colorimetric"],
    &["colorimetric"],
    &["colorimetric"],
];

pub(crate) static ENTRY_COLORIMETRIES_16352633730423789473: VariantsMap = [
    &["colorimetries"],
    &["colorimetries"],
    &["colorimetries"],
    &["colorimetries"],
];

pub(crate) static ENTRY_COLORIMETRIST_16103668754911113058: VariantsMap = [
    &["colorimetrist"],
    &["colourimetrist"],
    &["colourimetrist"],
    &["colourimetrist"],
];

pub(crate) static ENTRY_COLORIMETRY_1096025596659311412: VariantsMap = [
    &["colorimetry"],
    &["colorimetry"],
    &["colorimetry"],
    &["colorimetry"],
];

pub(crate) static ENTRY_COLORINGS_3076825598771260084: VariantsMap = [
    &["colorings"],
    &["colourings"],
    &["colourings"],
    &["colourings"],
];

pub(crate) static ENTRY_COLORING_3210137591351035939: VariantsMap = [
    &["coloring"],
    &["colouring"],
    &["colouring"],
    &["colouring"],
];

pub(crate) static ENTRY_COLORIN_7364447797547189461: VariantsMap =
    [&["colorin"], &["colourin"], &["colourin"], &["colourin"]];

pub(crate) static ENTRY_COLORISMS_9834615672957808489: VariantsMap = [
    &["colorisms"],
    &["colourisms"],
    &["colourisms"],
    &["colourisms"],
];

pub(crate) static ENTRY_COLORISM_11451642000509277550: VariantsMap = [
    &["colorism"],
    &["colourism"],
    &["colourism"],
    &["colourism"],
];

pub(crate) static ENTRY_COLORISTICALLY_4826074029409437505: VariantsMap = [
    &["coloristically"],
    &["colouristically"],
    &["colouristically"],
    &["colouristically"],
];

pub(crate) static ENTRY_COLORISTICER_8710817088617352267: VariantsMap = [
    &["coloristicer"],
    &["colouristicer"],
    &["colouristicer"],
    &["colouristicer"],
];

pub(crate) static ENTRY_COLORISTICEST_2991259503195608639: VariantsMap = [
    &["coloristicest"],
    &["colouristicest"],
    &["colouristicest"],
    &["colouristicest"],
];

pub(crate) static ENTRY_COLORISTICS_10161388239807067112: VariantsMap = [
    &["coloristics"],
    &["colouristics"],
    &["colouristics"],
    &["colouristics"],
];

pub(crate) static ENTRY_COLORISTIC_4901807440455152786: VariantsMap = [
    &["coloristic"],
    &["colouristic"],
    &["colouristic"],
    &["colouristic"],
];

pub(crate) static ENTRY_COLORISTS_205210891187993391: VariantsMap = [
    &["colorists"],
    &["colourists"],
    &["colourists"],
    &["colourists"],
];

pub(crate) static ENTRY_COLORIST_3170137357114879751: VariantsMap = [
    &["colorist"],
    &["colourist"],
    &["colourist"],
    &["colourist"],
];

pub(crate) static ENTRY_COLORIZATIONS_4267572307963209982: VariantsMap = [
    &["colorizations"],
    &["colourisations"],
    &["colourizations"],
    &["colourisations"],
];

pub(crate) static ENTRY_COLORIZATION_8112190634064658436: VariantsMap = [
    &["colorization"],
    &["colourisation"],
    &["colourization"],
    &["colourisation"],
];

pub(crate) static ENTRY_COLORIZED_1927556635004418734: VariantsMap = [
    &["colorized"],
    &["colourised"],
    &["colourized"],
    &["colourised"],
];

pub(crate) static ENTRY_COLORIZES_12579061677034347790: VariantsMap = [
    &["colorizes"],
    &["colourises"],
    &["colourizes"],
    &["colourises"],
];

pub(crate) static ENTRY_COLORIZE_378813947509810224: VariantsMap = [
    &["colorize"],
    &["colourise"],
    &["colourize"],
    &["colourise"],
];

pub(crate) static ENTRY_COLORIZING_2623120429929129787: VariantsMap = [
    &["colorizing"],
    &["colourising"],
    &["colourizing"],
    &["colourising"],
];

pub(crate) static ENTRY_COLORLESSER_9795559032347620897: VariantsMap = [
    &["colorlesser"],
    &["colourlesser"],
    &["colourlesser"],
    &["colourlesser"],
];

pub(crate) static ENTRY_COLORLESSEST_2853202552785506979: VariantsMap = [
    &["colorlessest"],
    &["colourlessest"],
    &["colourlessest"],
    &["colourlessest"],
];

pub(crate) static ENTRY_COLORLESSLIER_15143289294047728460: VariantsMap = [
    &["colorlesslier"],
    &["colourlesslier"],
    &["colourlesslier"],
    &["colourlesslier"],
];

pub(crate) static ENTRY_COLORLESSLIEST_12819557587409285660: VariantsMap = [
    &["colorlessliest"],
    &["colourlessliest"],
    &["colourlessliest"],
    &["colourlessliest"],
];

pub(crate) static ENTRY_COLORLESSLY_15719317170801627859: VariantsMap = [
    &["colorlessly"],
    &["colourlessly"],
    &["colourlessly"],
    &["colourlessly"],
];

pub(crate) static ENTRY_COLORLESSNESSES_17325232283084205852: VariantsMap = [
    &["colorlessnesses"],
    &["colourlessnesses"],
    &["colourlessnesses"],
    &["colourlessnesses"],
];

pub(crate) static ENTRY_COLORLESSNESS_3911470984873699039: VariantsMap = [
    &["colorlessness"],
    &["colourlessness"],
    &["colourlessness"],
    &["colourlessness"],
];

pub(crate) static ENTRY_COLORLESS_15335426167000546767: VariantsMap = [
    &["colorless"],
    &["colourless"],
    &["colourless"],
    &["colourless"],
];

pub(crate) static ENTRY_COLORMAKER_13048991323713933641: VariantsMap = [
    &["colormaker"],
    &["colourmaker"],
    &["colourmaker"],
    &["colourmaker"],
];

pub(crate) static ENTRY_COLORMAKING_3298385465563328410: VariantsMap = [
    &["colormaking"],
    &["colourmaking"],
    &["colourmaking"],
    &["colourmaking"],
];

pub(crate) static ENTRY_COLORMAN_9192316057645589430: VariantsMap = [
    &["colorman"],
    &["colourman"],
    &["colourman"],
    &["colourman"],
];

pub(crate) static ENTRY_COLORMAPS_11406342514432472514: VariantsMap = [
    &["colormaps"],
    &["colourmaps"],
    &["colourmaps"],
    &["colourmaps"],
];

pub(crate) static ENTRY_COLORMAP_18024738796464819872: VariantsMap = [
    &["colormap"],
    &["colourmap"],
    &["colourmap"],
    &["colourmap"],
];

pub(crate) static ENTRY_COLORMEN_1963797128559420405: VariantsMap = [
    &["colormen"],
    &["colourmen"],
    &["colourmen"],
    &["colourmen"],
];

pub(crate) static ENTRY_COLOROTO_5869254994177780978: VariantsMap = [
    &["coloroto"],
    &["colouroto"],
    &["colouroto"],
    &["colouroto"],
];

pub(crate) static ENTRY_COLORPOINTS_13015689836998141845: VariantsMap = [
    &["colorpoints"],
    &["colourpoints"],
    &["colourpoints"],
    &["colourpoints"],
];

pub(crate) static ENTRY_COLORPOINT_12353596064079181917: VariantsMap = [
    &["colorpoint"],
    &["colourpoint"],
    &["colourpoint"],
    &["colourpoint"],
];

pub(crate) static ENTRY_COLORREST_6777192705388068909: VariantsMap = [
    &["colorrest"],
    &["colourest"],
    &["colourest"],
    &["colourest"],
];

pub(crate) static ENTRY_COLORRHAPHY_13136665400257945176: VariantsMap = [
    &["colorrhaphy"],
    &["colourrhaphy"],
    &["colourrhaphy"],
    &["colourrhaphy"],
];

pub(crate) static ENTRY_COLORS_13018845474144214729: VariantsMap =
    [&["colors"], &["colours"], &["colours"], &["colours"]];

pub(crate) static ENTRY_COLORTYPE_14680038702599961625: VariantsMap = [
    &["colortype"],
    &["colourtype"],
    &["colourtype"],
    &["colourtype"],
];

pub(crate) static ENTRY_COLORWAYS_6062463807369877282: VariantsMap = [
    &["colorways"],
    &["colourways"],
    &["colourways"],
    &["colourways"],
];

pub(crate) static ENTRY_COLORWAY_14654249147936693420: VariantsMap = [
    &["colorway"],
    &["colourway"],
    &["colourway"],
    &["colourway"],
];

pub(crate) static ENTRY_COLORY_3235234236420467456: VariantsMap =
    [&["colory"], &["coloury"], &["coloury"], &["coloury"]];

pub(crate) static ENTRY_COLOR_17720358635329736641: VariantsMap =
    [&["color"], &["colour"], &["colour"], &["colour"]];

pub(crate) static ENTRY_COLUMNIZATIONS_12733006362612848403: VariantsMap = [
    &["columnizations"],
    &["columnisations"],
    &["columnizations"],
    &["columnisations"],
];

pub(crate) static ENTRY_COLUMNIZATION_11878276873729118026: VariantsMap = [
    &["columnization"],
    &["columnisation"],
    &["columnization"],
    &["columnisation"],
];

pub(crate) static ENTRY_COLUMNIZED_12525419582000651703: VariantsMap = [
    &["columnized"],
    &["columnised"],
    &["columnized"],
    &["columnised"],
];

pub(crate) static ENTRY_COLUMNIZES_920618881458905076: VariantsMap = [
    &["columnizes"],
    &["columnises"],
    &["columnizes"],
    &["columnises"],
];

pub(crate) static ENTRY_COLUMNIZE_7550365049509673455: VariantsMap = [
    &["columnize"],
    &["columnise"],
    &["columnize"],
    &["columnise"],
];

pub(crate) static ENTRY_COLUMNIZING_11760357087944386265: VariantsMap = [
    &["columnizing"],
    &["columnising"],
    &["columnizing"],
    &["columnising"],
];

pub(crate) static ENTRY_COMEDIA_5856845506973447538: VariantsMap =
    [&["comedia"], &["comoedia"], &["comoedia"], &["comoedia"]];

pub(crate) static ENTRY_COMMERCIALIZATIONS_17012404820436874389: VariantsMap = [
    &["commercializations"],
    &["commercialisations"],
    &["commercializations"],
    &["commercialisations"],
];

pub(crate) static ENTRY_COMMERCIALIZATION_1643106928830782978: VariantsMap = [
    &["commercialization"],
    &["commercialisation"],
    &["commercialization"],
    &["commercialisation"],
];

pub(crate) static ENTRY_COMMERCIALIZED_13681505620366419859: VariantsMap = [
    &["commercialized"],
    &["commercialised"],
    &["commercialized"],
    &["commercialised"],
];

pub(crate) static ENTRY_COMMERCIALIZES_7923464025673338308: VariantsMap = [
    &["commercializes"],
    &["commercialises"],
    &["commercializes"],
    &["commercialises"],
];

pub(crate) static ENTRY_COMMERCIALIZE_16888630425257885338: VariantsMap = [
    &["commercialize"],
    &["commercialise"],
    &["commercialize"],
    &["commercialise"],
];

pub(crate) static ENTRY_COMMERCIALIZING_10714170346661677285: VariantsMap = [
    &["commercializing"],
    &["commercialising"],
    &["commercializing"],
    &["commercialising"],
];

pub(crate) static ENTRY_COMMONIZES_1050237353426943643: VariantsMap = [
    &["commonizes"],
    &["commonises"],
    &["commonizes"],
    &["commonises"],
];

pub(crate) static ENTRY_COMMONIZE_3127845796652963145: VariantsMap = [
    &["commonize"],
    &["commonise"],
    &["commonize"],
    &["commonise"],
];

pub(crate) static ENTRY_COMMUNALIZATIONS_10004190720704121461: VariantsMap = [
    &["communalizations"],
    &["communalisations"],
    &["communalizations"],
    &["communalisations"],
];

pub(crate) static ENTRY_COMMUNALIZATION_1354902119947113774: VariantsMap = [
    &["communalization"],
    &["communalisation"],
    &["communalization"],
    &["communalisation"],
];

pub(crate) static ENTRY_COMMUNALIZED_8414107067770377657: VariantsMap = [
    &["communalized"],
    &["communalised"],
    &["communalized"],
    &["communalised"],
];

pub(crate) static ENTRY_COMMUNALIZERS_1419522334270734921: VariantsMap = [
    &["communalizers"],
    &["communalisers"],
    &["communalizers"],
    &["communalisers"],
];

pub(crate) static ENTRY_COMMUNALIZER_9067480767105491194: VariantsMap = [
    &["communalizer"],
    &["communaliser"],
    &["communalizer"],
    &["communaliser"],
];

pub(crate) static ENTRY_COMMUNALIZES_12395688431331928966: VariantsMap = [
    &["communalizes"],
    &["communalises"],
    &["communalizes"],
    &["communalises"],
];

pub(crate) static ENTRY_COMMUNALIZE_16978210201059417779: VariantsMap = [
    &["communalize"],
    &["communalise"],
    &["communalize"],
    &["communalise"],
];

pub(crate) static ENTRY_COMMUNALIZING_8021518098437504841: VariantsMap = [
    &["communalizing"],
    &["communalising"],
    &["communalizing"],
    &["communalising"],
];

pub(crate) static ENTRY_COMMUNIZATIONS_9900325170167101461: VariantsMap = [
    &["communizations"],
    &["communisations"],
    &["communizations"],
    &["communisations"],
];

pub(crate) static ENTRY_COMMUNIZATION_847361005287031401: VariantsMap = [
    &["communization"],
    &["communisation"],
    &["communization"],
    &["communisation"],
];

pub(crate) static ENTRY_COMMUNIZED_15644498154290457954: VariantsMap = [
    &["communized"],
    &["communised"],
    &["communized"],
    &["communised"],
];

pub(crate) static ENTRY_COMMUNIZES_16239995256080535914: VariantsMap = [
    &["communizes"],
    &["communises"],
    &["communizes"],
    &["communises"],
];

pub(crate) static ENTRY_COMMUNIZE_13614074380950312902: VariantsMap = [
    &["communize"],
    &["communise"],
    &["communize"],
    &["communise"],
];

pub(crate) static ENTRY_COMMUNIZING_4187287385336521999: VariantsMap = [
    &["communizing"],
    &["communising"],
    &["communizing"],
    &["communising"],
];

pub(crate) static ENTRY_COMPANIONIZES_159175304294701734: VariantsMap = [
    &["companionizes"],
    &["companionises"],
    &["companionizes"],
    &["companionises"],
];

pub(crate) static ENTRY_COMPANIONIZE_17295459993069832105: VariantsMap = [
    &["companionize"],
    &["companionise"],
    &["companionize"],
    &["companionise"],
];

pub(crate) static ENTRY_COMPARTMENTALIZATIONS_2073690646158683595: VariantsMap = [
    &["compartmentalizations"],
    &["compartmentalisations"],
    &["compartmentalizations"],
    &["compartmentalisations"],
];

pub(crate) static ENTRY_COMPARTMENTALIZATION_18240462251141060220: VariantsMap = [
    &["compartmentalization"],
    &["compartmentalisation"],
    &["compartmentalization"],
    &["compartmentalisation"],
];

pub(crate) static ENTRY_COMPARTMENTALIZED_2091042337396016604: VariantsMap = [
    &["compartmentalized"],
    &["compartmentalised"],
    &["compartmentalized"],
    &["compartmentalised"],
];

pub(crate) static ENTRY_COMPARTMENTALIZES_1429778905943784124: VariantsMap = [
    &["compartmentalizes"],
    &["compartmentalises"],
    &["compartmentalizes"],
    &["compartmentalises"],
];

pub(crate) static ENTRY_COMPARTMENTALIZE_6316599424281105903: VariantsMap = [
    &["compartmentalize"],
    &["compartmentalise"],
    &["compartmentalize"],
    &["compartmentalise"],
];

pub(crate) static ENTRY_COMPARTMENTALIZING_14853138630531540565: VariantsMap = [
    &["compartmentalizing"],
    &["compartmentalising"],
    &["compartmentalizing"],
    &["compartmentalising"],
];

pub(crate) static ENTRY_COMPARTMENTIZES_12901335302225578235: VariantsMap = [
    &["compartmentizes"],
    &["compartmentises"],
    &["compartmentizes"],
    &["compartmentises"],
];

pub(crate) static ENTRY_COMPARTMENTIZE_4090554704802645617: VariantsMap = [
    &["compartmentize"],
    &["compartmentise"],
    &["compartmentize"],
    &["compartmentise"],
];

pub(crate) static ENTRY_COMPER_13800353684688405016: VariantsMap =
    [&["comper"], &["compoer"], &["compoer"], &["compoer"]];

pub(crate) static ENTRY_COMPLEMENTIZER_6562757288101998612: VariantsMap = [
    &["complementizer"],
    &["complementiser"],
    &["complementizer"],
    &["complementiser"],
];

pub(crate) static ENTRY_COMPOSITE_2834997305530089174: VariantsMap = [
    &["composite"],
    &["compositae"],
    &["compositae"],
    &["compositae"],
];

pub(crate) static ENTRY_COMPREHENSIVIZATIONS_1893003905937999548: VariantsMap = [
    &["comprehensivizations"],
    &["comprehensivisations"],
    &["comprehensivizations"],
    &["comprehensivisations"],
];

pub(crate) static ENTRY_COMPREHENSIVIZATION_15958998661265330414: VariantsMap = [
    &["comprehensivization"],
    &["comprehensivisation"],
    &["comprehensivization"],
    &["comprehensivisation"],
];

pub(crate) static ENTRY_COMPREHENSIVIZED_2933839517192572218: VariantsMap = [
    &["comprehensivized"],
    &["comprehensivised"],
    &["comprehensivized"],
    &["comprehensivised"],
];

pub(crate) static ENTRY_COMPREHENSIVIZES_7584059223344239212: VariantsMap = [
    &["comprehensivizes"],
    &["comprehensivises"],
    &["comprehensivizes"],
    &["comprehensivises"],
];

pub(crate) static ENTRY_COMPREHENSIVIZE_12410257886709581767: VariantsMap = [
    &["comprehensivize"],
    &["comprehensivise"],
    &["comprehensivize"],
    &["comprehensivise"],
];

pub(crate) static ENTRY_COMPREHENSIVIZING_2953121830198164292: VariantsMap = [
    &["comprehensivizing"],
    &["comprehensivising"],
    &["comprehensivizing"],
    &["comprehensivising"],
];

pub(crate) static ENTRY_COMPRIZABLE_4826744105914478701: VariantsMap = [
    &["comprizable"],
    &["comprisable"],
    &["comprizable"],
    &["comprisable"],
];

pub(crate) static ENTRY_COMPRIZAL_9931805136956588535: VariantsMap = [
    &["comprizal"],
    &["comprisal"],
    &["comprizal"],
    &["comprisal"],
];

pub(crate) static ENTRY_COMPUTERIZABLE_11675963878159642483: VariantsMap = [
    &["computerizable"],
    &["computerisable"],
    &["computerizable"],
    &["computerisable"],
];

pub(crate) static ENTRY_COMPUTERIZATIONS_5765686861831125257: VariantsMap = [
    &["computerizations"],
    &["computerisations"],
    &["computerizations"],
    &["computerisations"],
];

pub(crate) static ENTRY_COMPUTERIZATION_14289958571575590804: VariantsMap = [
    &["computerization"],
    &["computerisation"],
    &["computerization"],
    &["computerisation"],
];

pub(crate) static ENTRY_COMPUTERIZED_15101489353463973212: VariantsMap = [
    &["computerized"],
    &["computerised"],
    &["computerized"],
    &["computerised"],
];

pub(crate) static ENTRY_COMPUTERIZES_14986241207867566402: VariantsMap = [
    &["computerizes"],
    &["computerises"],
    &["computerizes"],
    &["computerises"],
];

pub(crate) static ENTRY_COMPUTERIZE_15545915378374926111: VariantsMap = [
    &["computerize"],
    &["computerise"],
    &["computerize"],
    &["computerise"],
];

pub(crate) static ENTRY_COMPUTERIZING_12865766678094814563: VariantsMap = [
    &["computerizing"],
    &["computerising"],
    &["computerizing"],
    &["computerising"],
];

pub(crate) static ENTRY_CONCENTERED_5661172717823289893: VariantsMap = [
    &["concentered"],
    &["concentred"],
    &["concentred"],
    &["concentred"],
];

pub(crate) static ENTRY_CONCENTERING_8029206760572244740: VariantsMap = [
    &["concentering"],
    &["concentring"],
    &["concentring"],
    &["concentring"],
];

pub(crate) static ENTRY_CONCENTERS_15190503554801426852: VariantsMap = [
    &["concenters"],
    &["concentres"],
    &["concentres"],
    &["concentres"],
];

pub(crate) static ENTRY_CONCENTER_12599613659019972198: VariantsMap = [
    &["concenter"],
    &["concentre"],
    &["concentre"],
    &["concentre"],
];

pub(crate) static ENTRY_CONCEPTUALIZATIONS_11238993640785943456: VariantsMap = [
    &["conceptualizations"],
    &["conceptualisations"],
    &["conceptualizations"],
    &["conceptualisations"],
];

pub(crate) static ENTRY_CONCEPTUALIZATION_5738356471049765058: VariantsMap = [
    &["conceptualization"],
    &["conceptualisation"],
    &["conceptualization"],
    &["conceptualisation"],
];

pub(crate) static ENTRY_CONCEPTUALIZED_6046228406726865910: VariantsMap = [
    &["conceptualized"],
    &["conceptualised"],
    &["conceptualized"],
    &["conceptualised"],
];

pub(crate) static ENTRY_CONCEPTUALIZER_9902569432824476207: VariantsMap = [
    &["conceptualizer"],
    &["conceptualiser"],
    &["conceptualizer"],
    &["conceptualiser"],
];

pub(crate) static ENTRY_CONCEPTUALIZES_17221094629974506736: VariantsMap = [
    &["conceptualizes"],
    &["conceptualises"],
    &["conceptualizes"],
    &["conceptualises"],
];

pub(crate) static ENTRY_CONCEPTUALIZE_13986310691359872680: VariantsMap = [
    &["conceptualize"],
    &["conceptualise"],
    &["conceptualize"],
    &["conceptualise"],
];

pub(crate) static ENTRY_CONCEPTUALIZING_540854313698733535: VariantsMap = [
    &["conceptualizing"],
    &["conceptualising"],
    &["conceptualizing"],
    &["conceptualising"],
];

pub(crate) static ENTRY_CONCERTIST_12966623456893238257: VariantsMap = [
    &["concertist"],
    &["concretist"],
    &["concretist"],
    &["concretist"],
];

pub(crate) static ENTRY_CONCERTIZED_13322827190564875313: VariantsMap = [
    &["concertized"],
    &["concertised"],
    &["concertized"],
    &["concertised"],
];

pub(crate) static ENTRY_CONCERTIZERS_18408860231574633709: VariantsMap = [
    &["concertizers"],
    &["concertisers"],
    &["concertizers"],
    &["concertisers"],
];

pub(crate) static ENTRY_CONCERTIZER_1607241334899378280: VariantsMap = [
    &["concertizer"],
    &["concertiser"],
    &["concertizer"],
    &["concertiser"],
];

pub(crate) static ENTRY_CONCERTIZES_11707521685205330713: VariantsMap = [
    &["concertizes"],
    &["concertises"],
    &["concertizes"],
    &["concertises"],
];

pub(crate) static ENTRY_CONCERTIZE_12949550082462386391: VariantsMap = [
    &["concertize"],
    &["concertise"],
    &["concertize"],
    &["concertise"],
];

pub(crate) static ENTRY_CONCERTIZING_823694797397139539: VariantsMap = [
    &["concertizing"],
    &["concertising"],
    &["concertizing"],
    &["concertising"],
];

pub(crate) static ENTRY_CONCHE_198313554269271817: VariantsMap =
    [&["conche"], &["conchae"], &["conchae"], &["conchae"]];

pub(crate) static ENTRY_CONCOLOROUS_3163909145039836280: VariantsMap = [
    &["concolorous"],
    &["concolourous"],
    &["concolourous"],
    &["concolourous"],
];

pub(crate) static ENTRY_CONCOLOR_17454478296536964945: VariantsMap = [
    &["concolor"],
    &["concolour"],
    &["concolour"],
    &["concolour"],
];

pub(crate) static ENTRY_CONCRETIZATIONS_14806205502602655468: VariantsMap = [
    &["concretizations"],
    &["concretisations"],
    &["concretizations"],
    &["concretisations"],
];

pub(crate) static ENTRY_CONCRETIZATION_9902216531217228458: VariantsMap = [
    &["concretization"],
    &["concretisation"],
    &["concretization"],
    &["concretisation"],
];

pub(crate) static ENTRY_CONCRETIZED_4880170111921035163: VariantsMap = [
    &["concretized"],
    &["concretised"],
    &["concretized"],
    &["concretised"],
];

pub(crate) static ENTRY_CONCRETIZES_14141471054162706394: VariantsMap = [
    &["concretizes"],
    &["concretises"],
    &["concretizes"],
    &["concretises"],
];

pub(crate) static ENTRY_CONCRETIZE_5573134973876025446: VariantsMap = [
    &["concretize"],
    &["concretise"],
    &["concretize"],
    &["concretise"],
];

pub(crate) static ENTRY_CONCRETIZING_3165984632825616589: VariantsMap = [
    &["concretizing"],
    &["concretising"],
    &["concretizing"],
    &["concretising"],
];

pub(crate) static ENTRY_CONDITIONALIZES_15570057258703829423: VariantsMap = [
    &["conditionalizes"],
    &["conditionalises"],
    &["conditionalizes"],
    &["conditionalises"],
];

pub(crate) static ENTRY_CONDITIONALIZE_17072508968306397240: VariantsMap = [
    &["conditionalize"],
    &["conditionalise"],
    &["conditionalize"],
    &["conditionalise"],
];

pub(crate) static ENTRY_CONFEDERATIZES_13632434106090755943: VariantsMap = [
    &["confederatizes"],
    &["confederatises"],
    &["confederatizes"],
    &["confederatises"],
];

pub(crate) static ENTRY_CONFEDERATIZE_6554466446788291559: VariantsMap = [
    &["confederatize"],
    &["confederatise"],
    &["confederatize"],
    &["confederatise"],
];

pub(crate) static ENTRY_CONGENIALIZES_1415068390337769577: VariantsMap = [
    &["congenializes"],
    &["congenialises"],
    &["congenializes"],
    &["congenialises"],
];

pub(crate) static ENTRY_CONGENIALIZE_1800526471228574085: VariantsMap = [
    &["congenialize"],
    &["congenialise"],
    &["congenialize"],
    &["congenialise"],
];

pub(crate) static ENTRY_CONGES_13755371658333708467: VariantsMap =
    [&["conges"], &["congoes"], &["congoes"], &["congoes"]];

pub(crate) static ENTRY_CONGREGATIONALIZES_3694181040722978196: VariantsMap = [
    &["congregationalizes"],
    &["congregationalises"],
    &["congregationalizes"],
    &["congregationalises"],
];

pub(crate) static ENTRY_CONGREGATIONALIZE_9819463413052527180: VariantsMap = [
    &["congregationalize"],
    &["congregationalise"],
    &["congregationalize"],
    &["congregationalise"],
];

pub(crate) static ENTRY_CONNECTABLE_4141190038522560448: VariantsMap = [
    &["connectable"],
    &["connectable"],
    &["connectable"],
    &["connectable"],
];

pub(crate) static ENTRY_CONNECTIONS_4180526765108060503: VariantsMap = [
    &["connections"],
    &["connections"],
    &["connections"],
    &["connections"],
];

pub(crate) static ENTRY_CONNECTION_3596008768342696520: VariantsMap = [
    &["connection"],
    &["connection"],
    &["connection"],
    &["connection"],
];

pub(crate) static ENTRY_CONNECTORS_2322332520801589759: VariantsMap = [
    &["connectors"],
    &["connectors"],
    &["connectors"],
    &["connectors"],
];

pub(crate) static ENTRY_CONNECTOR_16799434896865993625: VariantsMap = [
    &["connector"],
    &["connector"],
    &["connector"],
    &["connector"],
];

pub(crate) static ENTRY_CONSERVATIZED_8955764860788295695: VariantsMap = [
    &["conservatized"],
    &["conservatised"],
    &["conservatized"],
    &["conservatised"],
];

pub(crate) static ENTRY_CONSERVATIZES_6230909821260907845: VariantsMap = [
    &["conservatizes"],
    &["conservatises"],
    &["conservatizes"],
    &["conservatises"],
];

pub(crate) static ENTRY_CONSERVATIZE_2070475109159374656: VariantsMap = [
    &["conservatize"],
    &["conservatise"],
    &["conservatize"],
    &["conservatise"],
];

pub(crate) static ENTRY_CONSERVATIZING_3183413058245669100: VariantsMap = [
    &["conservatizing"],
    &["conservatising"],
    &["conservatizing"],
    &["conservatising"],
];

pub(crate) static ENTRY_CONSONANTIZED_17873071838789420092: VariantsMap = [
    &["consonantized"],
    &["consonantised"],
    &["consonantized"],
    &["consonantised"],
];

pub(crate) static ENTRY_CONSONANTIZES_1574898332026499098: VariantsMap = [
    &["consonantizes"],
    &["consonantises"],
    &["consonantizes"],
    &["consonantises"],
];

pub(crate) static ENTRY_CONSONANTIZE_7643805442006694940: VariantsMap = [
    &["consonantize"],
    &["consonantise"],
    &["consonantize"],
    &["consonantise"],
];

pub(crate) static ENTRY_CONSONANTIZING_13097410576135380735: VariantsMap = [
    &["consonantizing"],
    &["consonantising"],
    &["consonantizing"],
    &["consonantising"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZATIONS_3173298060249661811: VariantsMap = [
    &["constitutionalizations"],
    &["constitutionalisations"],
    &["constitutionalizations"],
    &["constitutionalisations"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZATION_15784223903500663882: VariantsMap = [
    &["constitutionalization"],
    &["constitutionalisation"],
    &["constitutionalization"],
    &["constitutionalisation"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZED_9394750460084858253: VariantsMap = [
    &["constitutionalized"],
    &["constitutionalised"],
    &["constitutionalized"],
    &["constitutionalised"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZES_6011502541057503677: VariantsMap = [
    &["constitutionalizes"],
    &["constitutionalises"],
    &["constitutionalizes"],
    &["constitutionalises"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZE_4750305806592443640: VariantsMap = [
    &["constitutionalize"],
    &["constitutionalise"],
    &["constitutionalize"],
    &["constitutionalise"],
];

pub(crate) static ENTRY_CONSTITUTIONALIZING_15920645894132149057: VariantsMap = [
    &["constitutionalizing"],
    &["constitutionalising"],
    &["constitutionalizing"],
    &["constitutionalising"],
];

pub(crate) static ENTRY_CONTAINERIZATIONS_4036516080513202324: VariantsMap = [
    &["containerizations"],
    &["containerisations"],
    &["containerizations"],
    &["containerisations"],
];

pub(crate) static ENTRY_CONTAINERIZATION_5740732325462062174: VariantsMap = [
    &["containerization"],
    &["containerisation"],
    &["containerization"],
    &["containerisation"],
];

pub(crate) static ENTRY_CONTAINERIZED_11029791807154416517: VariantsMap = [
    &["containerized"],
    &["containerised"],
    &["containerized"],
    &["containerised"],
];

pub(crate) static ENTRY_CONTAINERIZES_5244588712773306715: VariantsMap = [
    &["containerizes"],
    &["containerises"],
    &["containerizes"],
    &["containerises"],
];

pub(crate) static ENTRY_CONTAINERIZE_17609445608339490283: VariantsMap = [
    &["containerize"],
    &["containerise"],
    &["containerize"],
    &["containerise"],
];

pub(crate) static ENTRY_CONTAINERIZING_9054115922997640811: VariantsMap = [
    &["containerizing"],
    &["containerising"],
    &["containerizing"],
    &["containerising"],
];

pub(crate) static ENTRY_CONTEMPORIZATION_16780108593197095593: VariantsMap = [
    &["contemporization"],
    &["contemporisation"],
    &["contemporization"],
    &["contemporisation"],
];

pub(crate) static ENTRY_CONTEMPORIZED_3426415243352581168: VariantsMap = [
    &["contemporized"],
    &["contemporised"],
    &["contemporized"],
    &["contemporised"],
];

pub(crate) static ENTRY_CONTEMPORIZES_2967807069359802216: VariantsMap = [
    &["contemporizes"],
    &["contemporises"],
    &["contemporizes"],
    &["contemporises"],
];

pub(crate) static ENTRY_CONTEMPORIZE_5008428677635696983: VariantsMap = [
    &["contemporize"],
    &["contemporise"],
    &["contemporize"],
    &["contemporise"],
];

pub(crate) static ENTRY_CONTEMPORIZING_6045892075236219913: VariantsMap = [
    &["contemporizing"],
    &["contemporising"],
    &["contemporizing"],
    &["contemporising"],
];

pub(crate) static ENTRY_CONTEXTUALIZATIONS_18105932896496599445: VariantsMap = [
    &["contextualizations"],
    &["contextualisations"],
    &["contextualizations"],
    &["contextualisations"],
];

pub(crate) static ENTRY_CONTEXTUALIZATION_6940693679263259371: VariantsMap = [
    &["contextualization"],
    &["contextualisation"],
    &["contextualization"],
    &["contextualisation"],
];

pub(crate) static ENTRY_CONTEXTUALIZED_6300908248792062084: VariantsMap = [
    &["contextualized"],
    &["contextualised"],
    &["contextualized"],
    &["contextualised"],
];

pub(crate) static ENTRY_CONTEXTUALIZES_12529336508087690726: VariantsMap = [
    &["contextualizes"],
    &["contextualises"],
    &["contextualizes"],
    &["contextualises"],
];

pub(crate) static ENTRY_CONTEXTUALIZE_4584369818380473712: VariantsMap = [
    &["contextualize"],
    &["contextualise"],
    &["contextualize"],
    &["contextualise"],
];

pub(crate) static ENTRY_CONTEXTUALIZING_7461111452640045211: VariantsMap = [
    &["contextualizing"],
    &["contextualising"],
    &["contextualizing"],
    &["contextualising"],
];

pub(crate) static ENTRY_CONTINENTALIZES_6196002065058300897: VariantsMap = [
    &["continentalizes"],
    &["continentalises"],
    &["continentalizes"],
    &["continentalises"],
];

pub(crate) static ENTRY_CONTINENTALIZE_15476635658600406518: VariantsMap = [
    &["continentalize"],
    &["continentalise"],
    &["continentalize"],
    &["continentalise"],
];

pub(crate) static ENTRY_CONTROVERSIALIZES_7981611622332565361: VariantsMap = [
    &["controversializes"],
    &["controversialises"],
    &["controversializes"],
    &["controversialises"],
];

pub(crate) static ENTRY_CONTROVERSIALIZE_3063821365593875585: VariantsMap = [
    &["controversialize"],
    &["controversialise"],
    &["controversialize"],
    &["controversialise"],
];

pub(crate) static ENTRY_CONUNDRUMIZES_7982003424972698355: VariantsMap = [
    &["conundrumizes"],
    &["conundrumises"],
    &["conundrumizes"],
    &["conundrumises"],
];

pub(crate) static ENTRY_CONUNDRUMIZE_12213997648480363330: VariantsMap = [
    &["conundrumize"],
    &["conundrumise"],
    &["conundrumize"],
    &["conundrumise"],
];

pub(crate) static ENTRY_CONVENTIONALIZATIONS_16276682879105179823: VariantsMap = [
    &["conventionalizations"],
    &["conventionalisations"],
    &["conventionalizations"],
    &["conventionalisations"],
];

pub(crate) static ENTRY_CONVENTIONALIZATION_13028625690092222465: VariantsMap = [
    &["conventionalization"],
    &["conventionalisation"],
    &["conventionalization"],
    &["conventionalisation"],
];

pub(crate) static ENTRY_CONVENTIONALIZED_12965553780389351275: VariantsMap = [
    &["conventionalized"],
    &["conventionalised"],
    &["conventionalized"],
    &["conventionalised"],
];

pub(crate) static ENTRY_CONVENTIONALIZES_9272151990564007911: VariantsMap = [
    &["conventionalizes"],
    &["conventionalises"],
    &["conventionalizes"],
    &["conventionalises"],
];

pub(crate) static ENTRY_CONVENTIONALIZE_5523697518996561640: VariantsMap = [
    &["conventionalize"],
    &["conventionalise"],
    &["conventionalize"],
    &["conventionalise"],
];

pub(crate) static ENTRY_CONVENTIONALIZING_8403911928878303814: VariantsMap = [
    &["conventionalizing"],
    &["conventionalising"],
    &["conventionalizing"],
    &["conventionalising"],
];

pub(crate) static ENTRY_CONVENTIONIZES_5985365324069048956: VariantsMap = [
    &["conventionizes"],
    &["conventionises"],
    &["conventionizes"],
    &["conventionises"],
];

pub(crate) static ENTRY_CONVENTIONIZE_10105849898246202377: VariantsMap = [
    &["conventionize"],
    &["conventionise"],
    &["conventionize"],
    &["conventionise"],
];

pub(crate) static ENTRY_CONVERSATIONIZES_17870350526921946834: VariantsMap = [
    &["conversationizes"],
    &["conversationises"],
    &["conversationizes"],
    &["conversationises"],
];

pub(crate) static ENTRY_CONVERSATIONIZE_5100069228660462527: VariantsMap = [
    &["conversationize"],
    &["conversationise"],
    &["conversationize"],
    &["conversationise"],
];

pub(crate) static ENTRY_CONVERTERS_3839419135582169647: VariantsMap = [
    &["converters"],
    &["converters"],
    &["converters"],
    &["converters"],
];

pub(crate) static ENTRY_CONVERTERS_5331070164538082909: VariantsMap = [
    &["converters"],
    &["converters"],
    &["converters"],
    &["converters"],
];

pub(crate) static ENTRY_CONVERTER_1832376138567767596: VariantsMap = [
    &["converter"],
    &["converter"],
    &["converter"],
    &["converter"],
];

pub(crate) static ENTRY_CONVERTER_5031978836001352470: VariantsMap = [
    &["converter"],
    &["converter"],
    &["converter"],
    &["converter"],
];

pub(crate) static ENTRY_CONVEYORIZED_1550738673068217452: VariantsMap = [
    &["conveyorized"],
    &["conveyorised"],
    &["conveyorized"],
    &["conveyorised"],
];

pub(crate) static ENTRY_CONVEYORIZES_5699299181152546893: VariantsMap = [
    &["conveyorizes"],
    &["conveyorises"],
    &["conveyorizes"],
    &["conveyorises"],
];

pub(crate) static ENTRY_CONVEYORIZE_13627331458498794547: VariantsMap = [
    &["conveyorize"],
    &["conveyorise"],
    &["conveyorize"],
    &["conveyorise"],
];

pub(crate) static ENTRY_CONVEYORIZING_12428816853490274627: VariantsMap = [
    &["conveyorizing"],
    &["conveyorising"],
    &["conveyorizing"],
    &["conveyorising"],
];

pub(crate) static ENTRY_CONVIVIALIZES_14081286682414244239: VariantsMap = [
    &["convivializes"],
    &["convivialises"],
    &["convivializes"],
    &["convivialises"],
];

pub(crate) static ENTRY_CONVIVIALIZE_12861322270762809887: VariantsMap = [
    &["convivialize"],
    &["convivialise"],
    &["convivialize"],
    &["convivialise"],
];

pub(crate) static ENTRY_COOKIE_7907860379600479031: VariantsMap =
    [&["cookie"], &["cookie"], &["cookie"], &["cookie"]];

pub(crate) static ENTRY_COPOLYMERIZATIONS_5973914645684635: VariantsMap = [
    &["copolymerizations"],
    &["copolymerisations"],
    &["copolymerizations"],
    &["copolymerisations"],
];

pub(crate) static ENTRY_COPOLYMERIZATION_3565686431310114577: VariantsMap = [
    &["copolymerization"],
    &["copolymerisation"],
    &["copolymerization"],
    &["copolymerisation"],
];

pub(crate) static ENTRY_COPOLYMERIZED_17760814634904159372: VariantsMap = [
    &["copolymerized"],
    &["copolymerised"],
    &["copolymerized"],
    &["copolymerised"],
];

pub(crate) static ENTRY_COPOLYMERIZES_13350833418414627371: VariantsMap = [
    &["copolymerizes"],
    &["copolymerises"],
    &["copolymerizes"],
    &["copolymerises"],
];

pub(crate) static ENTRY_COPOLYMERIZE_4215053249879524882: VariantsMap = [
    &["copolymerize"],
    &["copolymerise"],
    &["copolymerize"],
    &["copolymerise"],
];

pub(crate) static ENTRY_COPOLYMERIZING_322624390484211449: VariantsMap = [
    &["copolymerizing"],
    &["copolymerising"],
    &["copolymerizing"],
    &["copolymerising"],
];

pub(crate) static ENTRY_COPPERIZATIONS_6621746123672599508: VariantsMap = [
    &["copperizations"],
    &["copperisations"],
    &["copperizations"],
    &["copperisations"],
];

pub(crate) static ENTRY_COPPERIZATION_964826321420421086: VariantsMap = [
    &["copperization"],
    &["copperisation"],
    &["copperization"],
    &["copperisation"],
];

pub(crate) static ENTRY_COPPERIZES_11565506510531680556: VariantsMap = [
    &["copperizes"],
    &["copperises"],
    &["copperizes"],
    &["copperises"],
];

pub(crate) static ENTRY_COPPERIZE_8585777073067773483: VariantsMap = [
    &["copperize"],
    &["copperise"],
    &["copperize"],
    &["copperise"],
];

pub(crate) static ENTRY_COPREMIA_15716946293536237967: VariantsMap = [
    &["copremia"],
    &["copraemia"],
    &["copraemia"],
    &["copraemia"],
];

pub(crate) static ENTRY_COPREMIC_330320805830628274: VariantsMap = [
    &["copremic"],
    &["copraemic"],
    &["copraemic"],
    &["copraemic"],
];

pub(crate) static ENTRY_CORALED_17029032369203888932: VariantsMap =
    [&["coraled"], &["coralled"], &["coralled"], &["coralled"]];

pub(crate) static ENTRY_CORANTOES_3187574316281975902: VariantsMap = [
    &["corantoes"],
    &["courantoes"],
    &["courantoes"],
    &["courantoes"],
];

pub(crate) static ENTRY_CORANTOS_4303750137767317450: VariantsMap = [
    &["corantos"],
    &["courantos"],
    &["courantos"],
    &["courantos"],
];

pub(crate) static ENTRY_CORANTO_4279134034163662809: VariantsMap =
    [&["coranto"], &["couranto"], &["couranto"], &["couranto"]];

pub(crate) static ENTRY_CORBED_3736423820408057899: VariantsMap =
    [&["corbed"], &["courbed"], &["courbed"], &["courbed"]];

pub(crate) static ENTRY_CORBELED_6042612068469726728: VariantsMap = [
    &["corbeled"],
    &["corbelled"],
    &["corbelled"],
    &["corbelled"],
];

pub(crate) static ENTRY_CORBELINGS_3564173093504722553: VariantsMap = [
    &["corbelings"],
    &["corbellings"],
    &["corbellings"],
    &["corbellings"],
];

pub(crate) static ENTRY_CORBELING_17424209206512192853: VariantsMap = [
    &["corbeling"],
    &["corbelling"],
    &["corbelling"],
    &["corbelling"],
];

pub(crate) static ENTRY_CORBE_17730991887414349664: VariantsMap =
    [&["corbe"], &["courbe"], &["courbe"], &["courbe"]];

pub(crate) static ENTRY_CORDIALIZED_17060566600018841931: VariantsMap = [
    &["cordialized"],
    &["cordialised"],
    &["cordialized"],
    &["cordialised"],
];

pub(crate) static ENTRY_CORDIALIZES_15225222580021745806: VariantsMap = [
    &["cordializes"],
    &["cordialises"],
    &["cordializes"],
    &["cordialises"],
];

pub(crate) static ENTRY_CORDIALIZE_18283820928702090126: VariantsMap = [
    &["cordialize"],
    &["cordialise"],
    &["cordialize"],
    &["cordialise"],
];

pub(crate) static ENTRY_CORDIALIZING_16322807405354472673: VariantsMap = [
    &["cordializing"],
    &["cordialising"],
    &["cordializing"],
    &["cordialising"],
];

pub(crate) static ENTRY_CORGE_17139623337126675741: VariantsMap =
    [&["corge"], &["courge"], &["courge"], &["courge"]];

pub(crate) static ENTRY_CORINTHIANIZED_3878556826042603473: VariantsMap = [
    &["corinthianized"],
    &["corinthianised"],
    &["corinthianized"],
    &["corinthianised"],
];

pub(crate) static ENTRY_CORINTHIANIZES_15960209016441005021: VariantsMap = [
    &["corinthianizes"],
    &["corinthianises"],
    &["corinthianizes"],
    &["corinthianises"],
];

pub(crate) static ENTRY_CORINTHIANIZE_15193202304262813823: VariantsMap = [
    &["corinthianize"],
    &["corinthianise"],
    &["corinthianize"],
    &["corinthianise"],
];

pub(crate) static ENTRY_CORINTHIANIZING_5628303096329418476: VariantsMap = [
    &["corinthianizing"],
    &["corinthianising"],
    &["corinthianizing"],
    &["corinthianising"],
];

pub(crate) static ENTRY_CORPOREALIZATIONS_13406569937168049681: VariantsMap = [
    &["corporealizations"],
    &["corporealisations"],
    &["corporealizations"],
    &["corporealisations"],
];

pub(crate) static ENTRY_CORPOREALIZATION_13444603137664491535: VariantsMap = [
    &["corporealization"],
    &["corporealisation"],
    &["corporealization"],
    &["corporealisation"],
];

pub(crate) static ENTRY_CORPOREALIZED_12082854418069448893: VariantsMap = [
    &["corporealized"],
    &["corporealised"],
    &["corporealized"],
    &["corporealised"],
];

pub(crate) static ENTRY_CORPOREALIZES_13055328418208419278: VariantsMap = [
    &["corporealizes"],
    &["corporealises"],
    &["corporealizes"],
    &["corporealises"],
];

pub(crate) static ENTRY_CORPOREALIZE_15369417358773446090: VariantsMap = [
    &["corporealize"],
    &["corporealise"],
    &["corporealize"],
    &["corporealise"],
];

pub(crate) static ENTRY_CORPOREALIZING_3901751814264969100: VariantsMap = [
    &["corporealizing"],
    &["corporealising"],
    &["corporealizing"],
    &["corporealising"],
];

pub(crate) static ENTRY_CORSY_8397709613851582338: VariantsMap =
    [&["corsy"], &["coursy"], &["coursy"], &["coursy"]];

pub(crate) static ENTRY_CORTAGE_11582769904852791421: VariantsMap =
    [&["cortage"], &["courtage"], &["courtage"], &["courtage"]];

pub(crate) static ENTRY_CORTINE_13597620914405629291: VariantsMap =
    [&["cortine"], &["cortinae"], &["cortinae"], &["cortinae"]];

pub(crate) static ENTRY_CORTIN_6028563342284786375: VariantsMap =
    [&["cortin"], &["courtin"], &["courtin"], &["courtin"]];

pub(crate) static ENTRY_CORVE_15600376709730904093: VariantsMap =
    [&["corve"], &["corvae"], &["corvae"], &["corvae"]];

pub(crate) static ENTRY_CORYPHES_13646996028278890092: VariantsMap = [
    &["coryphes"],
    &["coryphaes"],
    &["coryphaes"],
    &["coryphaes"],
];

pub(crate) static ENTRY_CORYPHE_5310787045413936233: VariantsMap =
    [&["coryphe"], &["coryphae"], &["coryphae"], &["coryphae"]];

pub(crate) static ENTRY_COSMETICIZED_13397803251483774269: VariantsMap = [
    &["cosmeticized"],
    &["cosmeticised"],
    &["cosmeticized"],
    &["cosmeticised"],
];

pub(crate) static ENTRY_COSMETICIZES_5573800526141905092: VariantsMap = [
    &["cosmeticizes"],
    &["cosmeticises"],
    &["cosmeticizes"],
    &["cosmeticises"],
];

pub(crate) static ENTRY_COSMETICIZE_4510163316750805851: VariantsMap = [
    &["cosmeticize"],
    &["cosmeticise"],
    &["cosmeticize"],
    &["cosmeticise"],
];

pub(crate) static ENTRY_COSMETICIZING_4611837122081199790: VariantsMap = [
    &["cosmeticizing"],
    &["cosmeticising"],
    &["cosmeticizing"],
    &["cosmeticising"],
];

pub(crate) static ENTRY_COSMOPOLITANIZATIONS_17982550395466641141: VariantsMap = [
    &["cosmopolitanizations"],
    &["cosmopolitanisations"],
    &["cosmopolitanizations"],
    &["cosmopolitanisations"],
];

pub(crate) static ENTRY_COSMOPOLITANIZATION_13712421328153787188: VariantsMap = [
    &["cosmopolitanization"],
    &["cosmopolitanisation"],
    &["cosmopolitanization"],
    &["cosmopolitanisation"],
];

pub(crate) static ENTRY_COSMOPOLITANIZED_15042192345530983967: VariantsMap = [
    &["cosmopolitanized"],
    &["cosmopolitanised"],
    &["cosmopolitanized"],
    &["cosmopolitanised"],
];

pub(crate) static ENTRY_COSMOPOLITANIZES_57296618879818157: VariantsMap = [
    &["cosmopolitanizes"],
    &["cosmopolitanises"],
    &["cosmopolitanizes"],
    &["cosmopolitanises"],
];

pub(crate) static ENTRY_COSMOPOLITANIZE_11591269984956762481: VariantsMap = [
    &["cosmopolitanize"],
    &["cosmopolitanise"],
    &["cosmopolitanize"],
    &["cosmopolitanise"],
];

pub(crate) static ENTRY_COSMOPOLITANIZING_11804948920948531162: VariantsMap = [
    &["cosmopolitanizing"],
    &["cosmopolitanising"],
    &["cosmopolitanizing"],
    &["cosmopolitanising"],
];

pub(crate) static ENTRY_COSPLENDOR_14307850165475070048: VariantsMap = [
    &["cosplendor"],
    &["cosplendour"],
    &["cosplendour"],
    &["cosplendour"],
];

pub(crate) static ENTRY_COSTE_1360786639006955600: VariantsMap =
    [&["coste"], &["costae"], &["costae"], &["costae"]];

pub(crate) static ENTRY_COSTUMIER_4823477100121806221: VariantsMap = [
    &["costumier"],
    &["costumire"],
    &["costumire"],
    &["costumire"],
];

pub(crate) static ENTRY_COTTE_13644830532086634992: VariantsMap =
    [&["cotte"], &["cottae"], &["cottae"], &["cottae"]];

pub(crate) static ENTRY_COTTONIZATIONS_17749803100676719261: VariantsMap = [
    &["cottonizations"],
    &["cottonisations"],
    &["cottonizations"],
    &["cottonisations"],
];

pub(crate) static ENTRY_COTTONIZATION_3551122105294457662: VariantsMap = [
    &["cottonization"],
    &["cottonisation"],
    &["cottonization"],
    &["cottonisation"],
];

pub(crate) static ENTRY_COTTONIZES_9008427680743356385: VariantsMap = [
    &["cottonizes"],
    &["cottonises"],
    &["cottonizes"],
    &["cottonises"],
];

pub(crate) static ENTRY_COTTONIZE_937005096342491386: VariantsMap = [
    &["cottonize"],
    &["cottonise"],
    &["cottonize"],
    &["cottonise"],
];

pub(crate) static ENTRY_COTYLE_942493646255101754: VariantsMap =
    [&["cotyle"], &["cotylae"], &["cotylae"], &["cotylae"]];

pub(crate) static ENTRY_COUNCILORSHIPS_4030354772794301642: VariantsMap = [
    &["councilorships"],
    &["councillorships"],
    &["councillorships"],
    &["councillorships"],
];

pub(crate) static ENTRY_COUNCILORSHIP_11271914097682866054: VariantsMap = [
    &["councilorship"],
    &["councillorship"],
    &["councillorship"],
    &["councillorship"],
];

pub(crate) static ENTRY_COUNCILORS_10740681458284876699: VariantsMap = [
    &["councilors"],
    &["councillors"],
    &["councillors"],
    &["councillors"],
];

pub(crate) static ENTRY_COUNCILOR_9008971708424749691: VariantsMap = [
    &["councilor"],
    &["councillor"],
    &["councillor"],
    &["councillor"],
];

pub(crate) static ENTRY_COUNSELED_16528360610427400796: VariantsMap = [
    &["counseled"],
    &["counselled"],
    &["counselled"],
    &["counselled"],
];

pub(crate) static ENTRY_COUNSELEE_5928413848108470968: VariantsMap = [
    &["counselee"],
    &["counsellee"],
    &["counsellee"],
    &["counsellee"],
];

pub(crate) static ENTRY_COUNSELING_801410554831071578: VariantsMap = [
    &["counseling"],
    &["counselling"],
    &["counselling"],
    &["counselling"],
];

pub(crate) static ENTRY_COUNSELORSHIPS_7582354069010921169: VariantsMap = [
    &["counselorships"],
    &["counsellorships"],
    &["counsellorships"],
    &["counsellorships"],
];

pub(crate) static ENTRY_COUNSELORSHIP_5288062081367197198: VariantsMap = [
    &["counselorship"],
    &["counsellorship"],
    &["counsellorship"],
    &["counsellorship"],
];

pub(crate) static ENTRY_COUNSELORS_13992003748073450387: VariantsMap = [
    &["counselors"],
    &["counsellors"],
    &["counsellors"],
    &["counsellors"],
];

pub(crate) static ENTRY_COUNSELOR_10543167328253513516: VariantsMap = [
    &["counselor"],
    &["counsellor"],
    &["counsellor"],
    &["counsellor"],
];

pub(crate) static ENTRY_COUNTERCOLORED_4458254746746370067: VariantsMap = [
    &["countercolored"],
    &["countercoloured"],
    &["countercoloured"],
    &["countercoloured"],
];

pub(crate) static ENTRY_COUNTOR_3612808841271391195: VariantsMap =
    [&["countor"], &["countour"], &["countour"], &["countour"]];

pub(crate) static ENTRY_COZIED_892102520341074320: VariantsMap =
    [&["cozied"], &["cosied"], &["cozied"], &["cosied"]];

pub(crate) static ENTRY_COZIER_16664560812994447871: VariantsMap =
    [&["cozier"], &["cosier"], &["cozier"], &["cosier"]];

pub(crate) static ENTRY_COZIEST_2405878050968803482: VariantsMap =
    [&["coziest"], &["cosiest"], &["coziest"], &["cosiest"]];

pub(crate) static ENTRY_COZIES_14939999790619704585: VariantsMap =
    [&["cozies"], &["cosies"], &["cozies"], &["cosies"]];

pub(crate) static ENTRY_COZILY_12652080440015563463: VariantsMap =
    [&["cozily"], &["cosily"], &["cozily"], &["cosily"]];

pub(crate) static ENTRY_COZINESS_4340402800488732549: VariantsMap =
    [&["coziness"], &["cosiness"], &["coziness"], &["cosiness"]];

pub(crate) static ENTRY_COZYING_8737786447759601632: VariantsMap =
    [&["cozying"], &["cosying"], &["cozying"], &["cosying"]];

pub(crate) static ENTRY_COZY_16771377950900395846: VariantsMap =
    [&["cozy"], &["cosy"], &["cozy"], &["cosy"]];

pub(crate) static ENTRY_CRAIZEY_11207510142316496553: VariantsMap =
    [&["craizey"], &["craisey"], &["craizey"], &["craisey"]];

pub(crate) static ENTRY_CRAMBES_5154618776124525704: VariantsMap =
    [&["crambes"], &["cramboes"], &["cramboes"], &["cramboes"]];

pub(crate) static ENTRY_CRAWLERIZES_13469653902313454380: VariantsMap = [
    &["crawlerizes"],
    &["crawlerises"],
    &["crawlerizes"],
    &["crawlerises"],
];

pub(crate) static ENTRY_CRAWLERIZE_812960636373413412: VariantsMap = [
    &["crawlerize"],
    &["crawlerise"],
    &["crawlerize"],
    &["crawlerise"],
];

pub(crate) static ENTRY_CREATURIZES_11072091990116315598: VariantsMap = [
    &["creaturizes"],
    &["creaturises"],
    &["creaturizes"],
    &["creaturises"],
];

pub(crate) static ENTRY_CREATURIZE_11671782863777774169: VariantsMap = [
    &["creaturize"],
    &["creaturise"],
    &["creaturize"],
    &["creaturise"],
];

pub(crate) static ENTRY_CRENELATED_4747089085581062744: VariantsMap = [
    &["crenelated"],
    &["crenellated"],
    &["crenellated"],
    &["crenellated"],
];

pub(crate) static ENTRY_CRENELATER_17949792491463033916: VariantsMap = [
    &["crenelater"],
    &["crenellater"],
    &["crenellater"],
    &["crenellater"],
];

pub(crate) static ENTRY_CRENELATEST_4139190496016465578: VariantsMap = [
    &["crenelatest"],
    &["crenellatest"],
    &["crenellatest"],
    &["crenellatest"],
];

pub(crate) static ENTRY_CRENELATES_1558161520210179871: VariantsMap = [
    &["crenelates"],
    &["crenellates"],
    &["crenellates"],
    &["crenellates"],
];

pub(crate) static ENTRY_CRENELATE_4846628544233188866: VariantsMap = [
    &["crenelate"],
    &["crenellate"],
    &["crenellate"],
    &["crenellate"],
];

pub(crate) static ENTRY_CRENELATING_3475200518815041064: VariantsMap = [
    &["crenelating"],
    &["crenellating"],
    &["crenellating"],
    &["crenellating"],
];

pub(crate) static ENTRY_CRENELATIONS_13269172105110545010: VariantsMap = [
    &["crenelations"],
    &["crenellations"],
    &["crenellations"],
    &["crenellations"],
];

pub(crate) static ENTRY_CRENELATION_1079785305940612588: VariantsMap = [
    &["crenelation"],
    &["crenellation"],
    &["crenellation"],
    &["crenellation"],
];

pub(crate) static ENTRY_CRENELED_12587802714564552958: VariantsMap = [
    &["creneled"],
    &["crenelled"],
    &["crenelled"],
    &["crenelled"],
];

pub(crate) static ENTRY_CRENELING_15994472673064843243: VariantsMap = [
    &["creneling"],
    &["crenelling"],
    &["crenelling"],
    &["crenelling"],
];

pub(crate) static ENTRY_CREOLIZATIONS_18438815551943447952: VariantsMap = [
    &["creolizations"],
    &["creolisations"],
    &["creolizations"],
    &["creolisations"],
];

pub(crate) static ENTRY_CREOLIZATION_2399026028067198251: VariantsMap = [
    &["creolization"],
    &["creolisation"],
    &["creolization"],
    &["creolisation"],
];

pub(crate) static ENTRY_CREOLIZED_7643361883981250764: VariantsMap = [
    &["creolized"],
    &["creolised"],
    &["creolized"],
    &["creolised"],
];

pub(crate) static ENTRY_CREOLIZES_3089367645000699437: VariantsMap = [
    &["creolizes"],
    &["creolises"],
    &["creolizes"],
    &["creolises"],
];

pub(crate) static ENTRY_CREOLIZE_5145685228179089111: VariantsMap =
    [&["creolize"], &["creolise"], &["creolize"], &["creolise"]];

pub(crate) static ENTRY_CREOLIZING_12140091392528441353: VariantsMap = [
    &["creolizing"],
    &["creolising"],
    &["creolizing"],
    &["creolising"],
];

pub(crate) static ENTRY_CRETINIZATIONS_8550950897045447908: VariantsMap = [
    &["cretinizations"],
    &["cretinisations"],
    &["cretinizations"],
    &["cretinisations"],
];

pub(crate) static ENTRY_CRETINIZATION_9976126052462780936: VariantsMap = [
    &["cretinization"],
    &["cretinisation"],
    &["cretinization"],
    &["cretinisation"],
];

pub(crate) static ENTRY_CRETINIZED_970325680379971482: VariantsMap = [
    &["cretinized"],
    &["cretinised"],
    &["cretinized"],
    &["cretinised"],
];

pub(crate) static ENTRY_CRETINIZES_15606980122166252360: VariantsMap = [
    &["cretinizes"],
    &["cretinises"],
    &["cretinizes"],
    &["cretinises"],
];

pub(crate) static ENTRY_CRETINIZE_567737549892855222: VariantsMap = [
    &["cretinize"],
    &["cretinise"],
    &["cretinize"],
    &["cretinise"],
];

pub(crate) static ENTRY_CRETINIZING_10538665090855146969: VariantsMap = [
    &["cretinizing"],
    &["cretinising"],
    &["cretinizing"],
    &["cretinising"],
];

pub(crate) static ENTRY_CRIMINALIZATIONS_7033644149025759517: VariantsMap = [
    &["criminalizations"],
    &["criminalisations"],
    &["criminalizations"],
    &["criminalisations"],
];

pub(crate) static ENTRY_CRIMINALIZATION_3737684511061545754: VariantsMap = [
    &["criminalization"],
    &["criminalisation"],
    &["criminalization"],
    &["criminalisation"],
];

pub(crate) static ENTRY_CRIMINALIZED_11203535063879460381: VariantsMap = [
    &["criminalized"],
    &["criminalised"],
    &["criminalized"],
    &["criminalised"],
];

pub(crate) static ENTRY_CRIMINALIZES_3410670484073252306: VariantsMap = [
    &["criminalizes"],
    &["criminalises"],
    &["criminalizes"],
    &["criminalises"],
];

pub(crate) static ENTRY_CRIMINALIZE_11153638088565284591: VariantsMap = [
    &["criminalize"],
    &["criminalise"],
    &["criminalize"],
    &["criminalise"],
];

pub(crate) static ENTRY_CRIMINALIZING_910154589421830415: VariantsMap = [
    &["criminalizing"],
    &["criminalising"],
    &["criminalizing"],
    &["criminalising"],
];

pub(crate) static ENTRY_CRITICIZABLER_15788598655348442927: VariantsMap = [
    &["criticizabler"],
    &["criticisabler"],
    &["criticizabler"],
    &["criticisabler"],
];

pub(crate) static ENTRY_CRITICIZABLEST_16577651845714565882: VariantsMap = [
    &["criticizablest"],
    &["criticisablest"],
    &["criticizablest"],
    &["criticisablest"],
];

pub(crate) static ENTRY_CRITICIZABLES_15336014985309704799: VariantsMap = [
    &["criticizables"],
    &["criticisables"],
    &["criticizables"],
    &["criticisables"],
];

pub(crate) static ENTRY_CRITICIZABLE_11161073204477833540: VariantsMap = [
    &["criticizable"],
    &["criticisable"],
    &["criticizable"],
    &["criticisable"],
];

pub(crate) static ENTRY_CRITICIZED_11062690254551858674: VariantsMap = [
    &["criticized"],
    &["criticised"],
    &["criticized"],
    &["criticised"],
];

pub(crate) static ENTRY_CRITICIZERS_1569351139366706310: VariantsMap = [
    &["criticizers"],
    &["criticisers"],
    &["criticizers"],
    &["criticisers"],
];

pub(crate) static ENTRY_CRITICIZER_1957848661038883017: VariantsMap = [
    &["criticizer"],
    &["criticiser"],
    &["criticizer"],
    &["criticiser"],
];

pub(crate) static ENTRY_CRITICIZES_17213534894187218607: VariantsMap = [
    &["criticizes"],
    &["criticises"],
    &["criticizes"],
    &["criticises"],
];

pub(crate) static ENTRY_CRITICIZE_6068870801343218661: VariantsMap = [
    &["criticize"],
    &["criticise"],
    &["criticize"],
    &["criticise"],
];

pub(crate) static ENTRY_CRITICIZINGLIER_5644837899795371316: VariantsMap = [
    &["criticizinglier"],
    &["criticisinglier"],
    &["criticizinglier"],
    &["criticisinglier"],
];

pub(crate) static ENTRY_CRITICIZINGLIEST_16754553627614394252: VariantsMap = [
    &["criticizingliest"],
    &["criticisingliest"],
    &["criticizingliest"],
    &["criticisingliest"],
];

pub(crate) static ENTRY_CRITICIZINGLIES_10873838484352102652: VariantsMap = [
    &["criticizinglies"],
    &["criticisinglies"],
    &["criticizinglies"],
    &["criticisinglies"],
];

pub(crate) static ENTRY_CRITICIZINGLY_17073704302947432967: VariantsMap = [
    &["criticizingly"],
    &["criticisingly"],
    &["criticizingly"],
    &["criticisingly"],
];

pub(crate) static ENTRY_CRITICIZING_721139847503188555: VariantsMap = [
    &["criticizing"],
    &["criticising"],
    &["criticizing"],
    &["criticising"],
];

pub(crate) static ENTRY_CROFTERIZATIONS_16334682363476700656: VariantsMap = [
    &["crofterizations"],
    &["crofterisations"],
    &["crofterizations"],
    &["crofterisations"],
];

pub(crate) static ENTRY_CROFTERIZATION_5035727674537403320: VariantsMap = [
    &["crofterization"],
    &["crofterisation"],
    &["crofterization"],
    &["crofterisation"],
];

pub(crate) static ENTRY_CROFTERIZES_11462100976556470416: VariantsMap = [
    &["crofterizes"],
    &["crofterises"],
    &["crofterizes"],
    &["crofterises"],
];

pub(crate) static ENTRY_CROFTERIZE_16982662599909303513: VariantsMap = [
    &["crofterize"],
    &["crofterise"],
    &["crofterize"],
    &["crofterise"],
];

pub(crate) static ENTRY_CRUELER_8850779393447007974: VariantsMap =
    [&["crueler"], &["crueller"], &["crueller"], &["crueller"]];

pub(crate) static ENTRY_CRUELEST_9704800828794339180: VariantsMap = [
    &["cruelest"],
    &["cruellest"],
    &["cruellest"],
    &["cruellest"],
];

pub(crate) static ENTRY_CRUELIZES_5359533254509589966: VariantsMap = [
    &["cruelizes"],
    &["cruelises"],
    &["cruelizes"],
    &["cruelises"],
];

pub(crate) static ENTRY_CRUELIZE_1812841929360609104: VariantsMap =
    [&["cruelize"], &["cruelise"], &["cruelize"], &["cruelise"]];

pub(crate) static ENTRY_CRYESTHESIA_5758775181330161574: VariantsMap = [
    &["cryesthesia"],
    &["cryaesthesia"],
    &["cryaesthesia"],
    &["cryaesthesia"],
];

pub(crate) static ENTRY_CRYOANESTHESIA_5659435164723717323: VariantsMap = [
    &["cryoanesthesia"],
    &["cryoanaesthesia"],
    &["cryoanaesthesia"],
    &["cryoanaesthesia"],
];

pub(crate) static ENTRY_CRYPTANALYZES_8578659007864632505: VariantsMap = [
    &["cryptanalyzes"],
    &["cryptanalyses"],
    &["cryptanalyzes"],
    &["cryptanalyses"],
];

pub(crate) static ENTRY_CRYPTESTHESIAS_13878578396343060203: VariantsMap = [
    &["cryptesthesias"],
    &["cryptaesthesias"],
    &["cryptaesthesias"],
    &["cryptaesthesias"],
];

pub(crate) static ENTRY_CRYPTESTHESIA_11957770407798142447: VariantsMap = [
    &["cryptesthesia"],
    &["cryptaesthesia"],
    &["cryptaesthesia"],
    &["cryptaesthesia"],
];

pub(crate) static ENTRY_CRYPTESTHETIC_6202935653821971765: VariantsMap = [
    &["cryptesthetic"],
    &["cryptaesthetic"],
    &["cryptaesthetic"],
    &["cryptaesthetic"],
];

pub(crate) static ENTRY_CRYSTALLIZABILITIES_3954684427565379393: VariantsMap = [
    &["crystallizabilities"],
    &["crystallisabilities"],
    &["crystallizabilities"],
    &["crystallisabilities"],
];

pub(crate) static ENTRY_CRYSTALLIZABILITY_417676650172898499: VariantsMap = [
    &["crystallizability"],
    &["crystallisability"],
    &["crystallizability"],
    &["crystallisability"],
];

pub(crate) static ENTRY_CRYSTALLIZABLER_14422860421659122029: VariantsMap = [
    &["crystallizabler"],
    &["crystallisabler"],
    &["crystallizabler"],
    &["crystallisabler"],
];

pub(crate) static ENTRY_CRYSTALLIZABLEST_11639541143335039276: VariantsMap = [
    &["crystallizablest"],
    &["crystallisablest"],
    &["crystallizablest"],
    &["crystallisablest"],
];

pub(crate) static ENTRY_CRYSTALLIZABLES_13105784762937285967: VariantsMap = [
    &["crystallizables"],
    &["crystallisables"],
    &["crystallizables"],
    &["crystallisables"],
];

pub(crate) static ENTRY_CRYSTALLIZABLE_5487202742125994763: VariantsMap = [
    &["crystallizable"],
    &["crystallisable"],
    &["crystallizable"],
    &["crystallisable"],
];

pub(crate) static ENTRY_CRYSTALLIZATIONS_8117698772064969073: VariantsMap = [
    &["crystallizations"],
    &["crystallisations"],
    &["crystallizations"],
    &["crystallisations"],
];

pub(crate) static ENTRY_CRYSTALLIZATION_11917761263858890133: VariantsMap = [
    &["crystallization"],
    &["crystallisation"],
    &["crystallization"],
    &["crystallisation"],
];

pub(crate) static ENTRY_CRYSTALLIZED_1190597515180481232: VariantsMap = [
    &["crystallized"],
    &["crystallised"],
    &["crystallized"],
    &["crystallised"],
];

pub(crate) static ENTRY_CRYSTALLIZERS_541454243380461975: VariantsMap = [
    &["crystallizers"],
    &["crystallisers"],
    &["crystallizers"],
    &["crystallisers"],
];

pub(crate) static ENTRY_CRYSTALLIZER_9934670519220100357: VariantsMap = [
    &["crystallizer"],
    &["crystalliser"],
    &["crystallizer"],
    &["crystalliser"],
];

pub(crate) static ENTRY_CRYSTALLIZES_4917509722520652987: VariantsMap = [
    &["crystallizes"],
    &["crystallises"],
    &["crystallizes"],
    &["crystallises"],
];

pub(crate) static ENTRY_CRYSTALLIZE_16085680612819973763: VariantsMap = [
    &["crystallize"],
    &["crystallise"],
    &["crystallize"],
    &["crystallise"],
];

pub(crate) static ENTRY_CRYSTALLIZING_1947916141166292087: VariantsMap = [
    &["crystallizing"],
    &["crystallising"],
    &["crystallizing"],
    &["crystallising"],
];

pub(crate) static ENTRY_CUBANIZES_11947476283611479479: VariantsMap = [
    &["cubanizes"],
    &["cubanises"],
    &["cubanizes"],
    &["cubanises"],
];

pub(crate) static ENTRY_CUBANIZE_5406869394071964531: VariantsMap =
    [&["cubanize"], &["cubanise"], &["cubanize"], &["cubanise"]];

pub(crate) static ENTRY_CUCKOLDIZED_8063124355706017628: VariantsMap = [
    &["cuckoldized"],
    &["cuckoldised"],
    &["cuckoldized"],
    &["cuckoldised"],
];

pub(crate) static ENTRY_CUCKOLDIZES_12399951352713548106: VariantsMap = [
    &["cuckoldizes"],
    &["cuckoldises"],
    &["cuckoldizes"],
    &["cuckoldises"],
];

pub(crate) static ENTRY_CUCKOLDIZE_15621372017035539958: VariantsMap = [
    &["cuckoldize"],
    &["cuckoldise"],
    &["cuckoldize"],
    &["cuckoldise"],
];

pub(crate) static ENTRY_CUCKOLDIZING_7372514622681800766: VariantsMap = [
    &["cuckoldizing"],
    &["cuckoldising"],
    &["cuckoldizing"],
    &["cuckoldising"],
];

pub(crate) static ENTRY_CUDGELED_5228795318766271839: VariantsMap = [
    &["cudgeled"],
    &["cudgelled"],
    &["cudgelled"],
    &["cudgelled"],
];

pub(crate) static ENTRY_CUDGELERS_17674302985237395736: VariantsMap = [
    &["cudgelers"],
    &["cudgellers"],
    &["cudgellers"],
    &["cudgellers"],
];

pub(crate) static ENTRY_CUDGELER_14634684249116397869: VariantsMap = [
    &["cudgeler"],
    &["cudgeller"],
    &["cudgeller"],
    &["cudgeller"],
];

pub(crate) static ENTRY_CUDGELINGS_2528963097802037407: VariantsMap = [
    &["cudgelings"],
    &["cudgellings"],
    &["cudgellings"],
    &["cudgellings"],
];

pub(crate) static ENTRY_CUDGELING_10321409265487926568: VariantsMap = [
    &["cudgeling"],
    &["cudgelling"],
    &["cudgelling"],
    &["cudgelling"],
];

pub(crate) static ENTRY_CULICIDE_539049738338426871: VariantsMap = [
    &["culicide"],
    &["culicidae"],
    &["culicidae"],
    &["culicidae"],
];

pub(crate) static ENTRY_CULTURIZATIONS_433804245511281258: VariantsMap = [
    &["culturizations"],
    &["culturisations"],
    &["culturizations"],
    &["culturisations"],
];

pub(crate) static ENTRY_CULTURIZATION_8113112597865327363: VariantsMap = [
    &["culturization"],
    &["culturisation"],
    &["culturization"],
    &["culturisation"],
];

pub(crate) static ENTRY_CULTURIZES_8371845703179033846: VariantsMap = [
    &["culturizes"],
    &["culturises"],
    &["culturizes"],
    &["culturises"],
];

pub(crate) static ENTRY_CULTURIZE_9663475963702798186: VariantsMap = [
    &["culturize"],
    &["culturise"],
    &["culturize"],
    &["culturise"],
];

pub(crate) static ENTRY_CUPELATION_14255540896200543840: VariantsMap = [
    &["cupelation"],
    &["cupellation"],
    &["cupellation"],
    &["cupellation"],
];

pub(crate) static ENTRY_CUPELED_8946630193695466634: VariantsMap =
    [&["cupeled"], &["cupelled"], &["cupelled"], &["cupelled"]];

pub(crate) static ENTRY_CUPELERS_5725217363507193203: VariantsMap = [
    &["cupelers"],
    &["cupellers"],
    &["cupellers"],
    &["cupellers"],
];

pub(crate) static ENTRY_CUPELER_7377946170413406251: VariantsMap =
    [&["cupeler"], &["cupeller"], &["cupeller"], &["cupeller"]];

pub(crate) static ENTRY_CUPELING_4033682037469028100: VariantsMap = [
    &["cupeling"],
    &["cupelling"],
    &["cupelling"],
    &["cupelling"],
];

pub(crate) static ENTRY_CUPULE_4300809885306855718: VariantsMap =
    [&["cupule"], &["cupulae"], &["cupulae"], &["cupulae"]];

pub(crate) static ENTRY_CURARIZED_16380507751440201850: VariantsMap = [
    &["curarized"],
    &["curarised"],
    &["curarized"],
    &["curarised"],
];

pub(crate) static ENTRY_CURARIZES_11507088447457007709: VariantsMap = [
    &["curarizes"],
    &["curarises"],
    &["curarizes"],
    &["curarises"],
];

pub(crate) static ENTRY_CURARIZE_9480914079622972520: VariantsMap =
    [&["curarize"], &["curarise"], &["curarize"], &["curarise"]];

pub(crate) static ENTRY_CURARIZING_17039072217967273189: VariantsMap = [
    &["curarizing"],
    &["curarising"],
    &["curarizing"],
    &["curarising"],
];

pub(crate) static ENTRY_CURATIZES_4333181687986321191: VariantsMap = [
    &["curatizes"],
    &["curatises"],
    &["curatizes"],
    &["curatises"],
];

pub(crate) static ENTRY_CURATIZE_12754148319229450576: VariantsMap =
    [&["curatize"], &["curatise"], &["curatize"], &["curatise"]];

pub(crate) static ENTRY_CURBED_15767276793691280481: VariantsMap =
    [&["curbed"], &["kerbed"], &["curbed"], &["kerbed"]];

pub(crate) static ENTRY_CURBING_3527396542143388091: VariantsMap =
    [&["curbing"], &["kerbing"], &["curbing"], &["kerbing"]];

pub(crate) static ENTRY_CURBS_13740246248166179524: VariantsMap =
    [&["curbs"], &["kerbs"], &["curbs"], &["kerbs"]];

pub(crate) static ENTRY_CURB_10662074484175094483: VariantsMap =
    [&["curb"], &["kerb"], &["curb"], &["kerb"]];

pub(crate) static ENTRY_CURRICULARIZATIONS_8190097899978040825: VariantsMap = [
    &["curricularizations"],
    &["curricularisations"],
    &["curricularizations"],
    &["curricularisations"],
];

pub(crate) static ENTRY_CURRICULARIZATION_17949948352689251703: VariantsMap = [
    &["curricularization"],
    &["curricularisation"],
    &["curricularization"],
    &["curricularisation"],
];

pub(crate) static ENTRY_CURRICULARIZES_15886142937581991191: VariantsMap = [
    &["curricularizes"],
    &["curricularises"],
    &["curricularizes"],
    &["curricularises"],
];

pub(crate) static ENTRY_CURRICULARIZE_16163595528229474912: VariantsMap = [
    &["curricularize"],
    &["curricularise"],
    &["curricularize"],
    &["curricularise"],
];

pub(crate) static ENTRY_CUSTOMIZABLE_4188832830695107920: VariantsMap = [
    &["customizable"],
    &["customisable"],
    &["customizable"],
    &["customisable"],
];

pub(crate) static ENTRY_CUSTOMIZATIONS_5506803585454620316: VariantsMap = [
    &["customizations"],
    &["customisations"],
    &["customizations"],
    &["customisations"],
];

pub(crate) static ENTRY_CUSTOMIZATION_453875871734424262: VariantsMap = [
    &["customization"],
    &["customisation"],
    &["customization"],
    &["customisation"],
];

pub(crate) static ENTRY_CUSTOMIZED_13934442474650970923: VariantsMap = [
    &["customized"],
    &["customised"],
    &["customized"],
    &["customised"],
];

pub(crate) static ENTRY_CUSTOMIZERS_7343425341470389472: VariantsMap = [
    &["customizers"],
    &["customisers"],
    &["customizers"],
    &["customisers"],
];

pub(crate) static ENTRY_CUSTOMIZER_10903429132081239237: VariantsMap = [
    &["customizer"],
    &["customiser"],
    &["customizer"],
    &["customiser"],
];

pub(crate) static ENTRY_CUSTOMIZES_7573381294777108850: VariantsMap = [
    &["customizes"],
    &["customises"],
    &["customizes"],
    &["customises"],
];

pub(crate) static ENTRY_CUSTOMIZE_17506619842499670481: VariantsMap = [
    &["customize"],
    &["customise"],
    &["customize"],
    &["customise"],
];

pub(crate) static ENTRY_CUSTOMIZING_12981538261584263761: VariantsMap = [
    &["customizing"],
    &["customising"],
    &["customizing"],
    &["customising"],
];

pub(crate) static ENTRY_CUTICOLOR_17641383408080176141: VariantsMap = [
    &["cuticolor"],
    &["cuticolour"],
    &["cuticolour"],
    &["cuticolour"],
];

pub(crate) static ENTRY_CUTINIZATIONS_17168596603659079378: VariantsMap = [
    &["cutinizations"],
    &["cutinisations"],
    &["cutinizations"],
    &["cutinisations"],
];

pub(crate) static ENTRY_CUTINIZATION_7081285991404911992: VariantsMap = [
    &["cutinization"],
    &["cutinisation"],
    &["cutinization"],
    &["cutinisation"],
];

pub(crate) static ENTRY_CUTINIZED_8304546337057011168: VariantsMap = [
    &["cutinized"],
    &["cutinised"],
    &["cutinized"],
    &["cutinised"],
];

pub(crate) static ENTRY_CUTINIZES_7397928291454568665: VariantsMap = [
    &["cutinizes"],
    &["cutinises"],
    &["cutinizes"],
    &["cutinises"],
];

pub(crate) static ENTRY_CUTINIZE_17770128684096533482: VariantsMap =
    [&["cutinize"], &["cutinise"], &["cutinize"], &["cutinise"]];

pub(crate) static ENTRY_CUTINIZING_17947614786569489277: VariantsMap = [
    &["cutinizing"],
    &["cutinising"],
    &["cutinizing"],
    &["cutinising"],
];

pub(crate) static ENTRY_CUTIZATIONS_12588515800323296191: VariantsMap = [
    &["cutizations"],
    &["cutisations"],
    &["cutizations"],
    &["cutisations"],
];

pub(crate) static ENTRY_CUTIZATION_8177626209182721273: VariantsMap = [
    &["cutization"],
    &["cutisation"],
    &["cutization"],
    &["cutisation"],
];

pub(crate) static ENTRY_CUVE_11772864420884703925: VariantsMap =
    [&["cuve"], &["cuvae"], &["cuvae"], &["cuvae"]];

pub(crate) static ENTRY_CYANEE_11375348371881906566: VariantsMap =
    [&["cyanee"], &["cyaneae"], &["cyaneae"], &["cyaneae"]];

pub(crate) static ENTRY_CYANIZED_17361255917873352647: VariantsMap =
    [&["cyanized"], &["cyanised"], &["cyanized"], &["cyanised"]];

pub(crate) static ENTRY_CYANIZES_5685851010869963468: VariantsMap =
    [&["cyanizes"], &["cyanises"], &["cyanizes"], &["cyanises"]];

pub(crate) static ENTRY_CYANIZE_16155583626941063831: VariantsMap =
    [&["cyanize"], &["cyanise"], &["cyanize"], &["cyanise"]];

pub(crate) static ENTRY_CYANIZING_13714646055406888213: VariantsMap = [
    &["cyanizing"],
    &["cyanising"],
    &["cyanizing"],
    &["cyanising"],
];

pub(crate) static ENTRY_CYANOMETHEMOGLOBIN_17992938767240588113: VariantsMap = [
    &["cyanomethemoglobin"],
    &["cyanomethaemoglobin"],
    &["cyanomethaemoglobin"],
    &["cyanomethaemoglobin"],
];

pub(crate) static ENTRY_CYCLIZATIONS_3981106857955296675: VariantsMap = [
    &["cyclizations"],
    &["cyclisations"],
    &["cyclizations"],
    &["cyclisations"],
];

pub(crate) static ENTRY_CYCLIZATION_18360017396052282635: VariantsMap = [
    &["cyclization"],
    &["cyclisation"],
    &["cyclization"],
    &["cyclisation"],
];

pub(crate) static ENTRY_CYCLIZED_9753759946426964794: VariantsMap =
    [&["cyclized"], &["cyclised"], &["cyclized"], &["cyclised"]];

pub(crate) static ENTRY_CYCLIZES_5515758818050542691: VariantsMap =
    [&["cyclizes"], &["cyclises"], &["cyclizes"], &["cyclises"]];

pub(crate) static ENTRY_CYCLIZE_11964539384894004110: VariantsMap =
    [&["cyclize"], &["cyclise"], &["cyclize"], &["cyclise"]];

pub(crate) static ENTRY_CYCLIZING_8867677036457804725: VariantsMap = [
    &["cyclizing"],
    &["cyclising"],
    &["cyclizing"],
    &["cyclising"],
];

pub(crate) static ENTRY_CYME_3841905397007660900: VariantsMap =
    [&["cyme"], &["cymae"], &["cymae"], &["cymae"]];

pub(crate) static ENTRY_CZARS_6668028309318935455: VariantsMap =
    [&["czars"], &["tsars"], &["czars"], &["tsars"]];

pub(crate) static ENTRY_CZAR_11030798322432903782: VariantsMap =
    [&["czar"], &["tsar"], &["czar"], &["tsar"]];

pub(crate) static ENTRY_CZECHIZATIONS_406710155217652709: VariantsMap = [
    &["czechizations"],
    &["czechisations"],
    &["czechizations"],
    &["czechisations"],
];

pub(crate) static ENTRY_CZECHIZATION_14599848904820315137: VariantsMap = [
    &["czechization"],
    &["czechisation"],
    &["czechization"],
    &["czechisation"],
];

pub(crate) static ENTRY_DANAIDE_9364396268060723081: VariantsMap =
    [&["danaide"], &["danaidae"], &["danaidae"], &["danaidae"]];

pub(crate) static ENTRY_DANDIZETTE_7715971230906134138: VariantsMap = [
    &["dandizette"],
    &["dandisette"],
    &["dandizette"],
    &["dandisette"],
];

pub(crate) static ENTRY_DANDYIZES_5178148648982336582: VariantsMap = [
    &["dandyizes"],
    &["dandyises"],
    &["dandyizes"],
    &["dandyises"],
];

pub(crate) static ENTRY_DANDYIZE_10327123579855543927: VariantsMap =
    [&["dandyize"], &["dandyise"], &["dandyize"], &["dandyise"]];

pub(crate) static ENTRY_DANE_3862192600118407294: VariantsMap =
    [&["dane"], &["danae"], &["danae"], &["danae"]];

pub(crate) static ENTRY_DANIZATIONS_586018653689790602: VariantsMap = [
    &["danizations"],
    &["danisations"],
    &["danizations"],
    &["danisations"],
];

pub(crate) static ENTRY_DANIZATION_4527343444630609033: VariantsMap = [
    &["danization"],
    &["danisation"],
    &["danization"],
    &["danisation"],
];

pub(crate) static ENTRY_DANIZES_982119247166854426: VariantsMap =
    [&["danizes"], &["danises"], &["danizes"], &["danises"]];

pub(crate) static ENTRY_DANIZE_7643162790699672050: VariantsMap =
    [&["danize"], &["danise"], &["danize"], &["danise"]];

pub(crate) static ENTRY_DARWINIZES_4276823588989949702: VariantsMap = [
    &["darwinizes"],
    &["darwinises"],
    &["darwinizes"],
    &["darwinises"],
];

pub(crate) static ENTRY_DARWINIZE_17708644917698913001: VariantsMap = [
    &["darwinize"],
    &["darwinise"],
    &["darwinize"],
    &["darwinise"],
];

pub(crate) static ENTRY_DASTARDIZES_14814359505750971454: VariantsMap = [
    &["dastardizes"],
    &["dastardises"],
    &["dastardizes"],
    &["dastardises"],
];

pub(crate) static ENTRY_DASTARDIZE_9137258977351501392: VariantsMap = [
    &["dastardize"],
    &["dastardise"],
    &["dastardize"],
    &["dastardise"],
];

pub(crate) static ENTRY_DEACONIZES_10922795038830896546: VariantsMap = [
    &["deaconizes"],
    &["deaconises"],
    &["deaconizes"],
    &["deaconises"],
];

pub(crate) static ENTRY_DEACONIZE_18248452212031779732: VariantsMap = [
    &["deaconize"],
    &["deaconise"],
    &["deaconize"],
    &["deaconise"],
];

pub(crate) static ENTRY_DEADRIZE_16948183351591896893: VariantsMap =
    [&["deadrize"], &["deadrise"], &["deadrize"], &["deadrise"]];

pub(crate) static ENTRY_DEALCOHOLIZED_4879647847969574400: VariantsMap = [
    &["dealcoholized"],
    &["dealcoholised"],
    &["dealcoholized"],
    &["dealcoholised"],
];

pub(crate) static ENTRY_DEALCOHOLIZES_8191413688823277724: VariantsMap = [
    &["dealcoholizes"],
    &["dealcoholises"],
    &["dealcoholizes"],
    &["dealcoholises"],
];

pub(crate) static ENTRY_DEALCOHOLIZE_17481590891108727711: VariantsMap = [
    &["dealcoholize"],
    &["dealcoholise"],
    &["dealcoholize"],
    &["dealcoholise"],
];

pub(crate) static ENTRY_DEALCOHOLIZING_9291655249306543942: VariantsMap = [
    &["dealcoholizing"],
    &["dealcoholising"],
    &["dealcoholizing"],
    &["dealcoholising"],
];

pub(crate) static ENTRY_DEAMINIZE_18302767805033719686: VariantsMap = [
    &["deaminize"],
    &["deaminise"],
    &["deaminize"],
    &["deaminise"],
];

pub(crate) static ENTRY_DECALITERS_3685909594822331600: VariantsMap = [
    &["decaliters"],
    &["decalitres"],
    &["decalitres"],
    &["decalitres"],
];

pub(crate) static ENTRY_DECALITER_4375398060796975724: VariantsMap = [
    &["decaliter"],
    &["decalitre"],
    &["decalitre"],
    &["decalitre"],
];

pub(crate) static ENTRY_DECAMETERS_12345413372720956347: VariantsMap = [
    &["decameters"],
    &["decametres"],
    &["decametres"],
    &["decametres"],
];

pub(crate) static ENTRY_DECAMETER_14656314621987784949: VariantsMap = [
    &["decameter"],
    &["decametre"],
    &["decametre"],
    &["decametre"],
];

pub(crate) static ENTRY_DECAPITALIZATIONS_4946483081288861635: VariantsMap = [
    &["decapitalizations"],
    &["decapitalisations"],
    &["decapitalizations"],
    &["decapitalisations"],
];

pub(crate) static ENTRY_DECAPITALIZATION_10013185676274515636: VariantsMap = [
    &["decapitalization"],
    &["decapitalisation"],
    &["decapitalization"],
    &["decapitalisation"],
];

pub(crate) static ENTRY_DECAPITALIZED_11861526144439577453: VariantsMap = [
    &["decapitalized"],
    &["decapitalised"],
    &["decapitalized"],
    &["decapitalised"],
];

pub(crate) static ENTRY_DECAPITALIZES_3757956433811423536: VariantsMap = [
    &["decapitalizes"],
    &["decapitalises"],
    &["decapitalizes"],
    &["decapitalises"],
];

pub(crate) static ENTRY_DECAPITALIZE_16025876451254005657: VariantsMap = [
    &["decapitalize"],
    &["decapitalise"],
    &["decapitalize"],
    &["decapitalise"],
];

pub(crate) static ENTRY_DECAPITALIZING_9239457887018733519: VariantsMap = [
    &["decapitalizing"],
    &["decapitalising"],
    &["decapitalizing"],
    &["decapitalising"],
];

pub(crate) static ENTRY_DECARBONIZATIONS_12243161232853744724: VariantsMap = [
    &["decarbonizations"],
    &["decarbonisations"],
    &["decarbonizations"],
    &["decarbonisations"],
];

pub(crate) static ENTRY_DECARBONIZATION_8874762898635047514: VariantsMap = [
    &["decarbonization"],
    &["decarbonisation"],
    &["decarbonization"],
    &["decarbonisation"],
];

pub(crate) static ENTRY_DECARBONIZED_831670285440777483: VariantsMap = [
    &["decarbonized"],
    &["decarbonised"],
    &["decarbonized"],
    &["decarbonised"],
];

pub(crate) static ENTRY_DECARBONIZERS_11181600971431230502: VariantsMap = [
    &["decarbonizers"],
    &["decarbonisers"],
    &["decarbonizers"],
    &["decarbonisers"],
];

pub(crate) static ENTRY_DECARBONIZER_7249394058399586099: VariantsMap = [
    &["decarbonizer"],
    &["decarboniser"],
    &["decarbonizer"],
    &["decarboniser"],
];

pub(crate) static ENTRY_DECARBONIZES_16627154206935494807: VariantsMap = [
    &["decarbonizes"],
    &["decarbonises"],
    &["decarbonizes"],
    &["decarbonises"],
];

pub(crate) static ENTRY_DECARBONIZE_14547194689917209691: VariantsMap = [
    &["decarbonize"],
    &["decarbonise"],
    &["decarbonize"],
    &["decarbonise"],
];

pub(crate) static ENTRY_DECARBONIZING_17299516323553280568: VariantsMap = [
    &["decarbonizing"],
    &["decarbonising"],
    &["decarbonizing"],
    &["decarbonising"],
];

pub(crate) static ENTRY_DECARBURIZATIONS_2176112887354481552: VariantsMap = [
    &["decarburizations"],
    &["decarburisations"],
    &["decarburizations"],
    &["decarburisations"],
];

pub(crate) static ENTRY_DECARBURIZATION_9039500434838585200: VariantsMap = [
    &["decarburization"],
    &["decarburisation"],
    &["decarburization"],
    &["decarburisation"],
];

pub(crate) static ENTRY_DECARBURIZED_2477575653270598611: VariantsMap = [
    &["decarburized"],
    &["decarburised"],
    &["decarburized"],
    &["decarburised"],
];

pub(crate) static ENTRY_DECARBURIZES_4783060351348035100: VariantsMap = [
    &["decarburizes"],
    &["decarburises"],
    &["decarburizes"],
    &["decarburises"],
];

pub(crate) static ENTRY_DECARBURIZE_9459391841384624626: VariantsMap = [
    &["decarburize"],
    &["decarburise"],
    &["decarburize"],
    &["decarburise"],
];

pub(crate) static ENTRY_DECARBURIZING_6487494577812793164: VariantsMap = [
    &["decarburizing"],
    &["decarburising"],
    &["decarburizing"],
    &["decarburising"],
];

pub(crate) static ENTRY_DECASUALIZATIONS_3864825352222685439: VariantsMap = [
    &["decasualizations"],
    &["decasualisations"],
    &["decasualizations"],
    &["decasualisations"],
];

pub(crate) static ENTRY_DECASUALIZATION_10274253385824132479: VariantsMap = [
    &["decasualization"],
    &["decasualisation"],
    &["decasualization"],
    &["decasualisation"],
];

pub(crate) static ENTRY_DECASUALIZED_1520306088891108700: VariantsMap = [
    &["decasualized"],
    &["decasualised"],
    &["decasualized"],
    &["decasualised"],
];

pub(crate) static ENTRY_DECASUALIZE_17572605258851322561: VariantsMap = [
    &["decasualize"],
    &["decasualise"],
    &["decasualize"],
    &["decasualise"],
];

pub(crate) static ENTRY_DECASUALIZING_18325301279691614544: VariantsMap = [
    &["decasualizing"],
    &["decasualising"],
    &["decasualizing"],
    &["decasualising"],
];

pub(crate) static ENTRY_DECENTERS_782900641405037424: VariantsMap = [
    &["decenters"],
    &["decentres"],
    &["decentres"],
    &["decentres"],
];

pub(crate) static ENTRY_DECENTRALIZATIONIST_15242187117214090536: VariantsMap = [
    &["decentralizationist"],
    &["decentralisationist"],
    &["decentralizationist"],
    &["decentralisationist"],
];

pub(crate) static ENTRY_DECENTRALIZATIONS_17002754818902434488: VariantsMap = [
    &["decentralizations"],
    &["decentralisations"],
    &["decentralizations"],
    &["decentralisations"],
];

pub(crate) static ENTRY_DECENTRALIZATION_1145039421821383347: VariantsMap = [
    &["decentralization"],
    &["decentralisation"],
    &["decentralization"],
    &["decentralisation"],
];

pub(crate) static ENTRY_DECENTRALIZED_17904951634508172483: VariantsMap = [
    &["decentralized"],
    &["decentralised"],
    &["decentralized"],
    &["decentralised"],
];

pub(crate) static ENTRY_DECENTRALIZES_4819976769659557164: VariantsMap = [
    &["decentralizes"],
    &["decentralises"],
    &["decentralizes"],
    &["decentralises"],
];

pub(crate) static ENTRY_DECENTRALIZE_1723656843408900394: VariantsMap = [
    &["decentralize"],
    &["decentralise"],
    &["decentralize"],
    &["decentralise"],
];

pub(crate) static ENTRY_DECENTRALIZING_1061628518546631855: VariantsMap = [
    &["decentralizing"],
    &["decentralising"],
    &["decentralizing"],
    &["decentralising"],
];

pub(crate) static ENTRY_DECEREBRIZED_14339403834612181570: VariantsMap = [
    &["decerebrized"],
    &["decerebrised"],
    &["decerebrized"],
    &["decerebrised"],
];

pub(crate) static ENTRY_DECEREBRIZES_7217503420848291830: VariantsMap = [
    &["decerebrizes"],
    &["decerebrises"],
    &["decerebrizes"],
    &["decerebrises"],
];

pub(crate) static ENTRY_DECEREBRIZE_5169026104609683255: VariantsMap = [
    &["decerebrize"],
    &["decerebrise"],
    &["decerebrize"],
    &["decerebrise"],
];

pub(crate) static ENTRY_DECEREBRIZING_6341477046577811325: VariantsMap = [
    &["decerebrizing"],
    &["decerebrising"],
    &["decerebrizing"],
    &["decerebrising"],
];

pub(crate) static ENTRY_DECHRISTIANIZATIONS_17028100591913749882: VariantsMap = [
    &["dechristianizations"],
    &["dechristianisations"],
    &["dechristianizations"],
    &["dechristianisations"],
];

pub(crate) static ENTRY_DECHRISTIANIZATION_11836465351921531501: VariantsMap = [
    &["dechristianization"],
    &["dechristianisation"],
    &["dechristianization"],
    &["dechristianisation"],
];

pub(crate) static ENTRY_DECHRISTIANIZED_6964242037591866891: VariantsMap = [
    &["dechristianized"],
    &["dechristianised"],
    &["dechristianized"],
    &["dechristianised"],
];

pub(crate) static ENTRY_DECHRISTIANIZES_6387580170865898146: VariantsMap = [
    &["dechristianizes"],
    &["dechristianises"],
    &["dechristianizes"],
    &["dechristianises"],
];

pub(crate) static ENTRY_DECHRISTIANIZE_1708321262942279453: VariantsMap = [
    &["dechristianize"],
    &["dechristianise"],
    &["dechristianize"],
    &["dechristianise"],
];

pub(crate) static ENTRY_DECHRISTIANIZING_9955318127138092041: VariantsMap = [
    &["dechristianizing"],
    &["dechristianising"],
    &["dechristianizing"],
    &["dechristianising"],
];

pub(crate) static ENTRY_DECIGRAMS_7725289753257784879: VariantsMap = [
    &["decigrams"],
    &["decigrams"],
    &["decigrams"],
    &["decigrams"],
];

pub(crate) static ENTRY_DECIGRAM_17589790411371966600: VariantsMap =
    [&["decigram"], &["decigram"], &["decigram"], &["decigram"]];

pub(crate) static ENTRY_DECILITERS_4643786240815277020: VariantsMap = [
    &["deciliters"],
    &["decilitres"],
    &["decilitres"],
    &["decilitres"],
];

pub(crate) static ENTRY_DECILITER_16804458751438697102: VariantsMap = [
    &["deciliter"],
    &["decilitre"],
    &["decilitre"],
    &["decilitre"],
];

pub(crate) static ENTRY_DECIMALIZATIONS_7263991078898399657: VariantsMap = [
    &["decimalizations"],
    &["decimalisations"],
    &["decimalizations"],
    &["decimalisations"],
];

pub(crate) static ENTRY_DECIMALIZATION_6996195191656110298: VariantsMap = [
    &["decimalization"],
    &["decimalisation"],
    &["decimalization"],
    &["decimalisation"],
];

pub(crate) static ENTRY_DECIMALIZED_11759803687347791070: VariantsMap = [
    &["decimalized"],
    &["decimalised"],
    &["decimalized"],
    &["decimalised"],
];

pub(crate) static ENTRY_DECIMALIZES_10277653931987829798: VariantsMap = [
    &["decimalizes"],
    &["decimalises"],
    &["decimalizes"],
    &["decimalises"],
];

pub(crate) static ENTRY_DECIMALIZE_17840181587779229578: VariantsMap = [
    &["decimalize"],
    &["decimalise"],
    &["decimalize"],
    &["decimalise"],
];

pub(crate) static ENTRY_DECIMALIZING_6772930949596594022: VariantsMap = [
    &["decimalizing"],
    &["decimalising"],
    &["decimalizing"],
    &["decimalising"],
];

pub(crate) static ENTRY_DECIMETERS_4158783169372669202: VariantsMap = [
    &["decimeters"],
    &["decimetres"],
    &["decimetres"],
    &["decimetres"],
];

pub(crate) static ENTRY_DECIMETER_14067880338205453806: VariantsMap = [
    &["decimeter"],
    &["decimetre"],
    &["decimetre"],
    &["decimetre"],
];

pub(crate) static ENTRY_DECIVILIZED_5079080916308187134: VariantsMap = [
    &["decivilized"],
    &["decivilised"],
    &["decivilized"],
    &["decivilised"],
];

pub(crate) static ENTRY_DECIVILIZES_6813589689406092861: VariantsMap = [
    &["decivilizes"],
    &["decivilises"],
    &["decivilizes"],
    &["decivilises"],
];

pub(crate) static ENTRY_DECIVILIZE_16580511735338840581: VariantsMap = [
    &["decivilize"],
    &["decivilise"],
    &["decivilize"],
    &["decivilise"],
];

pub(crate) static ENTRY_DECIVILIZING_4023615304630258958: VariantsMap = [
    &["decivilizing"],
    &["decivilising"],
    &["decivilizing"],
    &["decivilising"],
];

pub(crate) static ENTRY_DECOLONIZATIONS_15473229397920826981: VariantsMap = [
    &["decolonizations"],
    &["decolonisations"],
    &["decolonizations"],
    &["decolonisations"],
];

pub(crate) static ENTRY_DECOLONIZATION_14844676044557344393: VariantsMap = [
    &["decolonization"],
    &["decolonisation"],
    &["decolonization"],
    &["decolonisation"],
];

pub(crate) static ENTRY_DECOLONIZED_2468128191816289613: VariantsMap = [
    &["decolonized"],
    &["decolonised"],
    &["decolonized"],
    &["decolonised"],
];

pub(crate) static ENTRY_DECOLONIZES_17529571225109301692: VariantsMap = [
    &["decolonizes"],
    &["decolonises"],
    &["decolonizes"],
    &["decolonises"],
];

pub(crate) static ENTRY_DECOLONIZE_8704444043034616664: VariantsMap = [
    &["decolonize"],
    &["decolonise"],
    &["decolonize"],
    &["decolonise"],
];

pub(crate) static ENTRY_DECOLONIZING_15890941705265622387: VariantsMap = [
    &["decolonizing"],
    &["decolonising"],
    &["decolonizing"],
    &["decolonising"],
];

pub(crate) static ENTRY_DECOLORANTS_14395800598549575388: VariantsMap = [
    &["decolorants"],
    &["decolourants"],
    &["decolourants"],
    &["decolourants"],
];

pub(crate) static ENTRY_DECOLORANT_5335359943030311716: VariantsMap = [
    &["decolorant"],
    &["decolourant"],
    &["decolourant"],
    &["decolourant"],
];

pub(crate) static ENTRY_DECOLORATED_13361198090261586484: VariantsMap = [
    &["decolorated"],
    &["decolourated"],
    &["decolourated"],
    &["decolourated"],
];

pub(crate) static ENTRY_DECOLORATES_970217286770855278: VariantsMap = [
    &["decolorates"],
    &["decolourates"],
    &["decolourates"],
    &["decolourates"],
];

pub(crate) static ENTRY_DECOLORATE_16171421314227384757: VariantsMap = [
    &["decolorate"],
    &["decolourate"],
    &["decolourate"],
    &["decolourate"],
];

pub(crate) static ENTRY_DECOLORATIONS_5937830887779716004: VariantsMap = [
    &["decolorations"],
    &["decolourations"],
    &["decolourations"],
    &["decolourations"],
];

pub(crate) static ENTRY_DECOLORATION_687527831916147355: VariantsMap = [
    &["decoloration"],
    &["decolouration"],
    &["decolouration"],
    &["decolouration"],
];

pub(crate) static ENTRY_DECOLORED_12789961260525747964: VariantsMap = [
    &["decolored"],
    &["decoloured"],
    &["decoloured"],
    &["decoloured"],
];

pub(crate) static ENTRY_DECOLORIMETER_9685638258569395132: VariantsMap = [
    &["decolorimeter"],
    &["decolourimeter"],
    &["decolourimeter"],
    &["decolourimeter"],
];

pub(crate) static ENTRY_DECOLORING_6691256159228887702: VariantsMap = [
    &["decoloring"],
    &["decolouring"],
    &["decolouring"],
    &["decolouring"],
];

pub(crate) static ENTRY_DECOLORIZATIONS_5583822483356878390: VariantsMap = [
    &["decolorizations"],
    &["decolourisations"],
    &["decolourizations"],
    &["decolourisations"],
];

pub(crate) static ENTRY_DECOLORIZATION_9440321833606051398: VariantsMap = [
    &["decolorization"],
    &["decolourisation"],
    &["decolourization"],
    &["decolourisation"],
];

pub(crate) static ENTRY_DECOLORIZED_17864546395597600300: VariantsMap = [
    &["decolorized"],
    &["decolourised"],
    &["decolourized"],
    &["decolourised"],
];

pub(crate) static ENTRY_DECOLORIZERS_2577270439983901494: VariantsMap = [
    &["decolorizers"],
    &["decolourisers"],
    &["decolourizers"],
    &["decolourisers"],
];

pub(crate) static ENTRY_DECOLORIZER_1117085801636205705: VariantsMap = [
    &["decolorizer"],
    &["decolouriser"],
    &["decolourizer"],
    &["decolouriser"],
];

pub(crate) static ENTRY_DECOLORIZES_5066928271122015081: VariantsMap = [
    &["decolorizes"],
    &["decolourises"],
    &["decolourizes"],
    &["decolourises"],
];

pub(crate) static ENTRY_DECOLORIZE_10787926865254737924: VariantsMap = [
    &["decolorize"],
    &["decolourise"],
    &["decolourize"],
    &["decolourise"],
];

pub(crate) static ENTRY_DECOLORIZING_16950423814877555244: VariantsMap = [
    &["decolorizing"],
    &["decolourising"],
    &["decolourizing"],
    &["decolourising"],
];

pub(crate) static ENTRY_DECOLORS_121898289642929190: VariantsMap = [
    &["decolors"],
    &["decolours"],
    &["decolours"],
    &["decolours"],
];

pub(crate) static ENTRY_DECOLOR_5736949126416349048: VariantsMap =
    [&["decolor"], &["decolour"], &["decolour"], &["decolour"]];

pub(crate) static ENTRY_DECRIMINALIZATIONS_8826141293763176549: VariantsMap = [
    &["decriminalizations"],
    &["decriminalisations"],
    &["decriminalizations"],
    &["decriminalisations"],
];

pub(crate) static ENTRY_DECRIMINALIZATION_11495835016656319471: VariantsMap = [
    &["decriminalization"],
    &["decriminalisation"],
    &["decriminalization"],
    &["decriminalisation"],
];

pub(crate) static ENTRY_DECRIMINALIZED_14857350688716779167: VariantsMap = [
    &["decriminalized"],
    &["decriminalised"],
    &["decriminalized"],
    &["decriminalised"],
];

pub(crate) static ENTRY_DECRIMINALIZES_6368952306309816010: VariantsMap = [
    &["decriminalizes"],
    &["decriminalises"],
    &["decriminalizes"],
    &["decriminalises"],
];

pub(crate) static ENTRY_DECRIMINALIZE_6091198611704708595: VariantsMap = [
    &["decriminalize"],
    &["decriminalise"],
    &["decriminalize"],
    &["decriminalise"],
];

pub(crate) static ENTRY_DECRIMINALIZING_16672118604268496422: VariantsMap = [
    &["decriminalizing"],
    &["decriminalising"],
    &["decriminalizing"],
    &["decriminalising"],
];

pub(crate) static ENTRY_DEDALIAN_1818689560079214410: VariantsMap = [
    &["dedalian"],
    &["daedalian"],
    &["daedalian"],
    &["daedalian"],
];

pub(crate) static ENTRY_DEDAL_3527172992604688330: VariantsMap =
    [&["dedal"], &["daedal"], &["daedal"], &["daedal"]];

pub(crate) static ENTRY_DEDRAMATIZED_322035020814147818: VariantsMap = [
    &["dedramatized"],
    &["dedramatised"],
    &["dedramatized"],
    &["dedramatised"],
];

pub(crate) static ENTRY_DEDRAMATIZES_17967690669487003147: VariantsMap = [
    &["dedramatizes"],
    &["dedramatises"],
    &["dedramatizes"],
    &["dedramatises"],
];

pub(crate) static ENTRY_DEDRAMATIZE_13453343698039522020: VariantsMap = [
    &["dedramatize"],
    &["dedramatise"],
    &["dedramatize"],
    &["dedramatise"],
];

pub(crate) static ENTRY_DEDRAMATIZING_62928488875515887: VariantsMap = [
    &["dedramatizing"],
    &["dedramatising"],
    &["dedramatizing"],
    &["dedramatising"],
];

pub(crate) static ENTRY_DEEMPHASIZATION_17228655479618550538: VariantsMap = [
    &["deemphasization"],
    &["deemphasisation"],
    &["deemphasization"],
    &["deemphasisation"],
];

pub(crate) static ENTRY_DEEMPHASIZED_14166971579948169339: VariantsMap = [
    &["deemphasized"],
    &["deemphasised"],
    &["deemphasized"],
    &["deemphasised"],
];

pub(crate) static ENTRY_DEEMPHASIZERS_13733231012811038223: VariantsMap = [
    &["deemphasizers"],
    &["deemphasisers"],
    &["deemphasizers"],
    &["deemphasisers"],
];

pub(crate) static ENTRY_DEEMPHASIZER_2232629022737279052: VariantsMap = [
    &["deemphasizer"],
    &["deemphasiser"],
    &["deemphasizer"],
    &["deemphasiser"],
];

pub(crate) static ENTRY_DEEMPHASIZES_13005114554703747835: VariantsMap = [
    &["deemphasizes"],
    &["deemphasises"],
    &["deemphasizes"],
    &["deemphasises"],
];

pub(crate) static ENTRY_DEEMPHASIZE_17692949100195205354: VariantsMap = [
    &["deemphasize"],
    &["deemphasise"],
    &["deemphasize"],
    &["deemphasise"],
];

pub(crate) static ENTRY_DEEMPHASIZING_11093382399783111373: VariantsMap = [
    &["deemphasizing"],
    &["deemphasising"],
    &["deemphasizing"],
    &["deemphasising"],
];

pub(crate) static ENTRY_DEENERGIZED_11846795185389581725: VariantsMap = [
    &["deenergized"],
    &["deenergised"],
    &["deenergized"],
    &["deenergised"],
];

pub(crate) static ENTRY_DEENERGIZER_385500425712909906: VariantsMap = [
    &["deenergizer"],
    &["deenergiser"],
    &["deenergizer"],
    &["deenergiser"],
];

pub(crate) static ENTRY_DEENERGIZES_12119467381981965243: VariantsMap = [
    &["deenergizes"],
    &["deenergises"],
    &["deenergizes"],
    &["deenergises"],
];

pub(crate) static ENTRY_DEENERGIZE_12832371231418785666: VariantsMap = [
    &["deenergize"],
    &["deenergise"],
    &["deenergize"],
    &["deenergise"],
];

pub(crate) static ENTRY_DEENERGIZING_5214336872196253860: VariantsMap = [
    &["deenergizing"],
    &["deenergising"],
    &["deenergizing"],
    &["deenergising"],
];

pub(crate) static ENTRY_DEFEDATION_1250124429421953221: VariantsMap = [
    &["defedation"],
    &["defoedation"],
    &["defoedation"],
    &["defoedation"],
];

pub(crate) static ENTRY_DEFEMINIZATION_10970895057607673057: VariantsMap = [
    &["defeminization"],
    &["defeminisation"],
    &["defeminization"],
    &["defeminisation"],
];

pub(crate) static ENTRY_DEFEMINIZED_501903520845893607: VariantsMap = [
    &["defeminized"],
    &["defeminised"],
    &["defeminized"],
    &["defeminised"],
];

pub(crate) static ENTRY_DEFEMINIZES_13215201164940484905: VariantsMap = [
    &["defeminizes"],
    &["defeminises"],
    &["defeminizes"],
    &["defeminises"],
];

pub(crate) static ENTRY_DEFEMINIZE_2460703809552770265: VariantsMap = [
    &["defeminize"],
    &["defeminise"],
    &["defeminize"],
    &["defeminise"],
];

pub(crate) static ENTRY_DEFEMINIZING_2126786312766733725: VariantsMap = [
    &["defeminizing"],
    &["defeminising"],
    &["defeminizing"],
    &["defeminising"],
];

pub(crate) static ENTRY_DEFENSED_4741744499926552984: VariantsMap =
    [&["defensed"], &["defenced"], &["defenced"], &["defenced"]];

pub(crate) static ENTRY_DEFENSELESSER_14429190642942612093: VariantsMap = [
    &["defenselesser"],
    &["defencelesser"],
    &["defencelesser"],
    &["defencelesser"],
];

pub(crate) static ENTRY_DEFENSELESSEST_2810886385008994530: VariantsMap = [
    &["defenselessest"],
    &["defencelessest"],
    &["defencelessest"],
    &["defencelessest"],
];

pub(crate) static ENTRY_DEFENSELESSLIER_16858376230646568189: VariantsMap = [
    &["defenselesslier"],
    &["defencelesslier"],
    &["defencelesslier"],
    &["defencelesslier"],
];

pub(crate) static ENTRY_DEFENSELESSLIEST_4063724903759190513: VariantsMap = [
    &["defenselessliest"],
    &["defencelessliest"],
    &["defencelessliest"],
    &["defencelessliest"],
];

pub(crate) static ENTRY_DEFENSELESSLY_14439715594919858663: VariantsMap = [
    &["defenselessly"],
    &["defencelessly"],
    &["defencelessly"],
    &["defencelessly"],
];

pub(crate) static ENTRY_DEFENSELESSNESSES_18348884860793393516: VariantsMap = [
    &["defenselessnesses"],
    &["defencelessnesses"],
    &["defencelessnesses"],
    &["defencelessnesses"],
];

pub(crate) static ENTRY_DEFENSELESSNESS_12644024888445988945: VariantsMap = [
    &["defenselessness"],
    &["defencelessness"],
    &["defencelessness"],
    &["defencelessness"],
];

pub(crate) static ENTRY_DEFENSELESS_10794271276397387569: VariantsMap = [
    &["defenseless"],
    &["defenceless"],
    &["defenceless"],
    &["defenceless"],
];

pub(crate) static ENTRY_DEFENSEMAN_4178732654030128668: VariantsMap = [
    &["defenseman"],
    &["defenceman"],
    &["defenceman"],
    &["defenceman"],
];

pub(crate) static ENTRY_DEFENSEMEN_13356773840082441675: VariantsMap = [
    &["defensemen"],
    &["defencemen"],
    &["defencemen"],
    &["defencemen"],
];

pub(crate) static ENTRY_DEFENSES_17918359003970109622: VariantsMap =
    [&["defenses"], &["defences"], &["defences"], &["defences"]];

pub(crate) static ENTRY_DEFENSE_11018687793676709280: VariantsMap =
    [&["defense"], &["defence"], &["defence"], &["defence"]];

pub(crate) static ENTRY_DEFENSING_13872432362849183791: VariantsMap = [
    &["defensing"],
    &["defencing"],
    &["defencing"],
    &["defencing"],
];

pub(crate) static ENTRY_DEFEUDALIZED_10926320617236271428: VariantsMap = [
    &["defeudalized"],
    &["defeudalised"],
    &["defeudalized"],
    &["defeudalised"],
];

pub(crate) static ENTRY_DEFEUDALIZES_8548426077225192329: VariantsMap = [
    &["defeudalizes"],
    &["defeudalises"],
    &["defeudalizes"],
    &["defeudalises"],
];

pub(crate) static ENTRY_DEFEUDALIZE_6153813523071316351: VariantsMap = [
    &["defeudalize"],
    &["defeudalise"],
    &["defeudalize"],
    &["defeudalise"],
];

pub(crate) static ENTRY_DEFEUDALIZING_6851219039661107804: VariantsMap = [
    &["defeudalizing"],
    &["defeudalising"],
    &["defeudalizing"],
    &["defeudalising"],
];

pub(crate) static ENTRY_DEFIBRINIZED_142002320112068005: VariantsMap = [
    &["defibrinized"],
    &["defibrinised"],
    &["defibrinized"],
    &["defibrinised"],
];

pub(crate) static ENTRY_DEFIBRINIZES_7864712038065216074: VariantsMap = [
    &["defibrinizes"],
    &["defibrinises"],
    &["defibrinizes"],
    &["defibrinises"],
];

pub(crate) static ENTRY_DEFIBRINIZE_18283930865175559011: VariantsMap = [
    &["defibrinize"],
    &["defibrinise"],
    &["defibrinize"],
    &["defibrinise"],
];

pub(crate) static ENTRY_DEFIBRINIZING_15126402992130628305: VariantsMap = [
    &["defibrinizing"],
    &["defibrinising"],
    &["defibrinizing"],
    &["defibrinising"],
];

pub(crate) static ENTRY_DEFINITIZATIONS_2927011527962264879: VariantsMap = [
    &["definitizations"],
    &["definitisations"],
    &["definitizations"],
    &["definitisations"],
];

pub(crate) static ENTRY_DEFINITIZATION_7958601692772655221: VariantsMap = [
    &["definitization"],
    &["definitisation"],
    &["definitization"],
    &["definitisation"],
];

pub(crate) static ENTRY_DEFINITIZED_9429215788712667143: VariantsMap = [
    &["definitized"],
    &["definitised"],
    &["definitized"],
    &["definitised"],
];

pub(crate) static ENTRY_DEFINITIZES_5808003072438523190: VariantsMap = [
    &["definitizes"],
    &["definitises"],
    &["definitizes"],
    &["definitises"],
];

pub(crate) static ENTRY_DEFINITIZE_13578665782923325519: VariantsMap = [
    &["definitize"],
    &["definitise"],
    &["definitize"],
    &["definitise"],
];

pub(crate) static ENTRY_DEFINITIZING_17784497757438565701: VariantsMap = [
    &["definitizing"],
    &["definitising"],
    &["definitizing"],
    &["definitising"],
];

pub(crate) static ENTRY_DEFLECTIONIZATIONS_17851027536180674050: VariantsMap = [
    &["deflectionizations"],
    &["deflectionisations"],
    &["deflectionizations"],
    &["deflectionisations"],
];

pub(crate) static ENTRY_DEFLECTIONIZATION_11878097824098112217: VariantsMap = [
    &["deflectionization"],
    &["deflectionisation"],
    &["deflectionization"],
    &["deflectionisation"],
];

pub(crate) static ENTRY_DEFLECTIONIZES_6073384244042155810: VariantsMap = [
    &["deflectionizes"],
    &["deflectionises"],
    &["deflectionizes"],
    &["deflectionises"],
];

pub(crate) static ENTRY_DEFLECTIONIZE_3095690419241116219: VariantsMap = [
    &["deflectionize"],
    &["deflectionise"],
    &["deflectionize"],
    &["deflectionise"],
];

pub(crate) static ENTRY_DEFORMALIZE_15907382900288731005: VariantsMap = [
    &["deformalize"],
    &["deformalise"],
    &["deformalize"],
    &["deformalise"],
];

pub(crate) static ENTRY_DEFUNCTIONALIZATIONS_13484968269526464929: VariantsMap = [
    &["defunctionalizations"],
    &["defunctionalisations"],
    &["defunctionalizations"],
    &["defunctionalisations"],
];

pub(crate) static ENTRY_DEFUNCTIONALIZATION_13807631024565298493: VariantsMap = [
    &["defunctionalization"],
    &["defunctionalisation"],
    &["defunctionalization"],
    &["defunctionalisation"],
];

pub(crate) static ENTRY_DEFUNCTIONALIZES_2354126124027039718: VariantsMap = [
    &["defunctionalizes"],
    &["defunctionalises"],
    &["defunctionalizes"],
    &["defunctionalises"],
];

pub(crate) static ENTRY_DEFUNCTIONALIZE_3067764666659364877: VariantsMap = [
    &["defunctionalize"],
    &["defunctionalise"],
    &["defunctionalize"],
    &["defunctionalise"],
];

pub(crate) static ENTRY_DEGLYCEROLIZED_5620184830818473145: VariantsMap = [
    &["deglycerolized"],
    &["deglycerolised"],
    &["deglycerolized"],
    &["deglycerolised"],
];

pub(crate) static ENTRY_DEHUMANIZATIONS_6897797502184645692: VariantsMap = [
    &["dehumanizations"],
    &["dehumanisations"],
    &["dehumanizations"],
    &["dehumanisations"],
];

pub(crate) static ENTRY_DEHUMANIZATION_3572788173744551934: VariantsMap = [
    &["dehumanization"],
    &["dehumanisation"],
    &["dehumanization"],
    &["dehumanisation"],
];

pub(crate) static ENTRY_DEHUMANIZED_2513733723938163946: VariantsMap = [
    &["dehumanized"],
    &["dehumanised"],
    &["dehumanized"],
    &["dehumanised"],
];

pub(crate) static ENTRY_DEHUMANIZES_79010027424209477: VariantsMap = [
    &["dehumanizes"],
    &["dehumanises"],
    &["dehumanizes"],
    &["dehumanises"],
];

pub(crate) static ENTRY_DEHUMANIZE_2232272408872299361: VariantsMap = [
    &["dehumanize"],
    &["dehumanise"],
    &["dehumanize"],
    &["dehumanise"],
];

pub(crate) static ENTRY_DEHUMANIZING_18121800466455281577: VariantsMap = [
    &["dehumanizing"],
    &["dehumanising"],
    &["dehumanizing"],
    &["dehumanising"],
];

pub(crate) static ENTRY_DEHYDROGENIZATION_17529379708129741720: VariantsMap = [
    &["dehydrogenization"],
    &["dehydrogenisation"],
    &["dehydrogenization"],
    &["dehydrogenisation"],
];

pub(crate) static ENTRY_DEHYDROGENIZED_4042573802152435240: VariantsMap = [
    &["dehydrogenized"],
    &["dehydrogenised"],
    &["dehydrogenized"],
    &["dehydrogenised"],
];

pub(crate) static ENTRY_DEHYDROGENIZER_8525507183037678721: VariantsMap = [
    &["dehydrogenizer"],
    &["dehydrogeniser"],
    &["dehydrogenizer"],
    &["dehydrogeniser"],
];

pub(crate) static ENTRY_DEHYDROGENIZE_7036691670691764716: VariantsMap = [
    &["dehydrogenize"],
    &["dehydrogenise"],
    &["dehydrogenize"],
    &["dehydrogenise"],
];

pub(crate) static ENTRY_DEHYDROGENIZING_5974089619476922717: VariantsMap = [
    &["dehydrogenizing"],
    &["dehydrogenising"],
    &["dehydrogenizing"],
    &["dehydrogenising"],
];

pub(crate) static ENTRY_DEHYPNOTIZATIONS_4718849388849423582: VariantsMap = [
    &["dehypnotizations"],
    &["dehypnotisations"],
    &["dehypnotizations"],
    &["dehypnotisations"],
];

pub(crate) static ENTRY_DEHYPNOTIZATION_12210599348961381724: VariantsMap = [
    &["dehypnotization"],
    &["dehypnotisation"],
    &["dehypnotization"],
    &["dehypnotisation"],
];

pub(crate) static ENTRY_DEHYPNOTIZED_6695632276418370962: VariantsMap = [
    &["dehypnotized"],
    &["dehypnotised"],
    &["dehypnotized"],
    &["dehypnotised"],
];

pub(crate) static ENTRY_DEHYPNOTIZES_6146772561847797201: VariantsMap = [
    &["dehypnotizes"],
    &["dehypnotises"],
    &["dehypnotizes"],
    &["dehypnotises"],
];

pub(crate) static ENTRY_DEHYPNOTIZE_10726010356831719725: VariantsMap = [
    &["dehypnotize"],
    &["dehypnotise"],
    &["dehypnotize"],
    &["dehypnotise"],
];

pub(crate) static ENTRY_DEHYPNOTIZING_12455661718180344756: VariantsMap = [
    &["dehypnotizing"],
    &["dehypnotising"],
    &["dehypnotizing"],
    &["dehypnotising"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZATIONS_15910460441488223406: VariantsMap = [
    &["deindustrializations"],
    &["deindustrialisations"],
    &["deindustrializations"],
    &["deindustrialisations"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZATION_14471451768199148096: VariantsMap = [
    &["deindustrialization"],
    &["deindustrialisation"],
    &["deindustrialization"],
    &["deindustrialisation"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZED_1125754572889024423: VariantsMap = [
    &["deindustrialized"],
    &["deindustrialised"],
    &["deindustrialized"],
    &["deindustrialised"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZES_13990996861462469130: VariantsMap = [
    &["deindustrializes"],
    &["deindustrialises"],
    &["deindustrializes"],
    &["deindustrialises"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZE_15995862968967762494: VariantsMap = [
    &["deindustrialize"],
    &["deindustrialise"],
    &["deindustrialize"],
    &["deindustrialise"],
];

pub(crate) static ENTRY_DEINDUSTRIALIZING_3929932887349601221: VariantsMap = [
    &["deindustrializing"],
    &["deindustrialising"],
    &["deindustrializing"],
    &["deindustrialising"],
];

pub(crate) static ENTRY_DEIONIZATION_18037411003245501415: VariantsMap = [
    &["deionization"],
    &["deionisation"],
    &["deionization"],
    &["deionisation"],
];

pub(crate) static ENTRY_DEIONIZED_18147519954228604298: VariantsMap = [
    &["deionized"],
    &["deionised"],
    &["deionized"],
    &["deionised"],
];

pub(crate) static ENTRY_DEIONIZES_2511822428052345171: VariantsMap = [
    &["deionizes"],
    &["deionises"],
    &["deionizes"],
    &["deionises"],
];

pub(crate) static ENTRY_DEIONIZE_3742251118696055698: VariantsMap =
    [&["deionize"], &["deionise"], &["deionize"], &["deionise"]];

pub(crate) static ENTRY_DEIONIZING_3409760745768493185: VariantsMap = [
    &["deionizing"],
    &["deionising"],
    &["deionizing"],
    &["deionising"],
];

pub(crate) static ENTRY_DEKAGRAMS_16794902135907120348: VariantsMap = [
    &["dekagrams"],
    &["dekagrams"],
    &["dekagrams"],
    &["dekagrams"],
];

pub(crate) static ENTRY_DEKAGRAM_12670145940876311522: VariantsMap =
    [&["dekagram"], &["dekagram"], &["dekagram"], &["dekagram"]];

pub(crate) static ENTRY_DEKALITERS_8450766135929935128: VariantsMap = [
    &["dekaliters"],
    &["dekalitres"],
    &["dekalitres"],
    &["dekalitres"],
];

pub(crate) static ENTRY_DEKALITER_3783941176090837116: VariantsMap = [
    &["dekaliter"],
    &["dekalitre"],
    &["dekalitre"],
    &["dekalitre"],
];

pub(crate) static ENTRY_DEKAMETERS_17531050124125527369: VariantsMap = [
    &["dekameters"],
    &["dekametres"],
    &["dekametres"],
    &["dekametres"],
];

pub(crate) static ENTRY_DEKAMETER_12894292200985003434: VariantsMap = [
    &["dekameter"],
    &["dekametre"],
    &["dekametre"],
    &["dekametre"],
];

pub(crate) static ENTRY_DELIMITIZES_8971276824870720345: VariantsMap = [
    &["delimitizes"],
    &["delimitises"],
    &["delimitizes"],
    &["delimitises"],
];

pub(crate) static ENTRY_DELIMITIZE_16541986644088610431: VariantsMap = [
    &["delimitize"],
    &["delimitise"],
    &["delimitize"],
    &["delimitise"],
];

pub(crate) static ENTRY_DELOCALIZATIONS_460587193756388712: VariantsMap = [
    &["delocalizations"],
    &["delocalisations"],
    &["delocalizations"],
    &["delocalisations"],
];

pub(crate) static ENTRY_DELOCALIZATION_4312310346451666001: VariantsMap = [
    &["delocalization"],
    &["delocalisation"],
    &["delocalization"],
    &["delocalisation"],
];

pub(crate) static ENTRY_DELOCALIZED_6707490578440021648: VariantsMap = [
    &["delocalized"],
    &["delocalised"],
    &["delocalized"],
    &["delocalised"],
];

pub(crate) static ENTRY_DELOCALIZES_15812480500294999003: VariantsMap = [
    &["delocalizes"],
    &["delocalises"],
    &["delocalizes"],
    &["delocalises"],
];

pub(crate) static ENTRY_DELOCALIZE_142384639921788725: VariantsMap = [
    &["delocalize"],
    &["delocalise"],
    &["delocalize"],
    &["delocalise"],
];

pub(crate) static ENTRY_DELOCALIZING_11766970531294712613: VariantsMap = [
    &["delocalizing"],
    &["delocalising"],
    &["delocalizing"],
    &["delocalising"],
];

pub(crate) static ENTRY_DELUSTER_14098580558613886243: VariantsMap =
    [&["deluster"], &["delustre"], &["delustre"], &["delustre"]];

pub(crate) static ENTRY_DEMAGNETIZABLER_14067236382470080700: VariantsMap = [
    &["demagnetizabler"],
    &["demagnetisabler"],
    &["demagnetizabler"],
    &["demagnetisabler"],
];

pub(crate) static ENTRY_DEMAGNETIZABLEST_231408157539452152: VariantsMap = [
    &["demagnetizablest"],
    &["demagnetisablest"],
    &["demagnetizablest"],
    &["demagnetisablest"],
];

pub(crate) static ENTRY_DEMAGNETIZABLES_17349604975000267862: VariantsMap = [
    &["demagnetizables"],
    &["demagnetisables"],
    &["demagnetizables"],
    &["demagnetisables"],
];

pub(crate) static ENTRY_DEMAGNETIZABLE_2829745576751479415: VariantsMap = [
    &["demagnetizable"],
    &["demagnetisable"],
    &["demagnetizable"],
    &["demagnetisable"],
];

pub(crate) static ENTRY_DEMAGNETIZATIONS_17906684919392124321: VariantsMap = [
    &["demagnetizations"],
    &["demagnetisations"],
    &["demagnetizations"],
    &["demagnetisations"],
];

pub(crate) static ENTRY_DEMAGNETIZATION_10848943172388045538: VariantsMap = [
    &["demagnetization"],
    &["demagnetisation"],
    &["demagnetization"],
    &["demagnetisation"],
];

pub(crate) static ENTRY_DEMAGNETIZED_429555390860227118: VariantsMap = [
    &["demagnetized"],
    &["demagnetised"],
    &["demagnetized"],
    &["demagnetised"],
];

pub(crate) static ENTRY_DEMAGNETIZERS_3139106218193590904: VariantsMap = [
    &["demagnetizers"],
    &["demagnetisers"],
    &["demagnetizers"],
    &["demagnetisers"],
];

pub(crate) static ENTRY_DEMAGNETIZER_7369266141467515452: VariantsMap = [
    &["demagnetizer"],
    &["demagnetiser"],
    &["demagnetizer"],
    &["demagnetiser"],
];

pub(crate) static ENTRY_DEMAGNETIZES_2351872097402777148: VariantsMap = [
    &["demagnetizes"],
    &["demagnetises"],
    &["demagnetizes"],
    &["demagnetises"],
];

pub(crate) static ENTRY_DEMAGNETIZE_17682740839823545869: VariantsMap = [
    &["demagnetize"],
    &["demagnetise"],
    &["demagnetize"],
    &["demagnetise"],
];

pub(crate) static ENTRY_DEMAGNETIZING_14763681981656800434: VariantsMap = [
    &["demagnetizing"],
    &["demagnetising"],
    &["demagnetizing"],
    &["demagnetising"],
];

pub(crate) static ENTRY_DEMAGOGUED_8161585994268339914: VariantsMap = [
    &["demagogued"],
    &["demagogued"],
    &["demagogued"],
    &["demagogued"],
];

pub(crate) static ENTRY_DEMAGOGUERY_18141115406054203519: VariantsMap = [
    &["demagoguery"],
    &["demagoguery"],
    &["demagoguery"],
    &["demagoguery"],
];

pub(crate) static ENTRY_DEMAGOGUES_12777890380184860275: VariantsMap = [
    &["demagogues"],
    &["demagogues"],
    &["demagogues"],
    &["demagogues"],
];

pub(crate) static ENTRY_DEMAGOGUE_5181969032657952767: VariantsMap = [
    &["demagogue"],
    &["demagogue"],
    &["demagogue"],
    &["demagogue"],
];

pub(crate) static ENTRY_DEMAGOGUING_1728340214383068433: VariantsMap = [
    &["demagoguing"],
    &["demagoguing"],
    &["demagoguing"],
    &["demagoguing"],
];

pub(crate) static ENTRY_DEMASCULINIZATION_3144268104204565212: VariantsMap = [
    &["demasculinization"],
    &["demasculinisation"],
    &["demasculinization"],
    &["demasculinisation"],
];

pub(crate) static ENTRY_DEMASCULINIZED_14641565565158279941: VariantsMap = [
    &["demasculinized"],
    &["demasculinised"],
    &["demasculinized"],
    &["demasculinised"],
];

pub(crate) static ENTRY_DEMASCULINIZE_10705941850922882000: VariantsMap = [
    &["demasculinize"],
    &["demasculinise"],
    &["demasculinize"],
    &["demasculinise"],
];

pub(crate) static ENTRY_DEMASCULINIZING_2815690345809976595: VariantsMap = [
    &["demasculinizing"],
    &["demasculinising"],
    &["demasculinizing"],
    &["demasculinising"],
];

pub(crate) static ENTRY_DEMATERIALIZATIONS_3461546780666068183: VariantsMap = [
    &["dematerializations"],
    &["dematerialisations"],
    &["dematerializations"],
    &["dematerialisations"],
];

pub(crate) static ENTRY_DEMATERIALIZATION_12365708154794235297: VariantsMap = [
    &["dematerialization"],
    &["dematerialisation"],
    &["dematerialization"],
    &["dematerialisation"],
];

pub(crate) static ENTRY_DEMATERIALIZED_7148599036847365626: VariantsMap = [
    &["dematerialized"],
    &["dematerialised"],
    &["dematerialized"],
    &["dematerialised"],
];

pub(crate) static ENTRY_DEMATERIALIZES_17865238971422686230: VariantsMap = [
    &["dematerializes"],
    &["dematerialises"],
    &["dematerializes"],
    &["dematerialises"],
];

pub(crate) static ENTRY_DEMATERIALIZE_204119081752940756: VariantsMap = [
    &["dematerialize"],
    &["dematerialise"],
    &["dematerialize"],
    &["dematerialise"],
];

pub(crate) static ENTRY_DEMATERIALIZING_10155714463244702927: VariantsMap = [
    &["dematerializing"],
    &["dematerialising"],
    &["dematerializing"],
    &["dematerialising"],
];

pub(crate) static ENTRY_DEMEANORS_15645246800979825016: VariantsMap = [
    &["demeanors"],
    &["demeanours"],
    &["demeanours"],
    &["demeanours"],
];

pub(crate) static ENTRY_DEMEANOR_13927976893530181065: VariantsMap = [
    &["demeanor"],
    &["demeanour"],
    &["demeanour"],
    &["demeanour"],
];

pub(crate) static ENTRY_DEMILITARIZATIONS_12252664721077083328: VariantsMap = [
    &["demilitarizations"],
    &["demilitarisations"],
    &["demilitarizations"],
    &["demilitarisations"],
];

pub(crate) static ENTRY_DEMILITARIZATION_1830348363036337787: VariantsMap = [
    &["demilitarization"],
    &["demilitarisation"],
    &["demilitarization"],
    &["demilitarisation"],
];

pub(crate) static ENTRY_DEMILITARIZED_7958961857075865134: VariantsMap = [
    &["demilitarized"],
    &["demilitarised"],
    &["demilitarized"],
    &["demilitarised"],
];

pub(crate) static ENTRY_DEMILITARIZES_17566131017554380497: VariantsMap = [
    &["demilitarizes"],
    &["demilitarises"],
    &["demilitarizes"],
    &["demilitarises"],
];

pub(crate) static ENTRY_DEMILITARIZE_16703679582695532386: VariantsMap = [
    &["demilitarize"],
    &["demilitarise"],
    &["demilitarize"],
    &["demilitarise"],
];

pub(crate) static ENTRY_DEMILITARIZING_5137023236614361970: VariantsMap = [
    &["demilitarizing"],
    &["demilitarising"],
    &["demilitarizing"],
    &["demilitarising"],
];

pub(crate) static ENTRY_DEMILUSTER_18156742814546492480: VariantsMap = [
    &["demiluster"],
    &["demilustre"],
    &["demilustre"],
    &["demilustre"],
];

pub(crate) static ENTRY_DEMINERALIZATIONS_9687527290224020253: VariantsMap = [
    &["demineralizations"],
    &["demineralisations"],
    &["demineralizations"],
    &["demineralisations"],
];

pub(crate) static ENTRY_DEMINERALIZATION_11860382402591403329: VariantsMap = [
    &["demineralization"],
    &["demineralisation"],
    &["demineralization"],
    &["demineralisation"],
];

pub(crate) static ENTRY_DEMINERALIZED_417389536885991347: VariantsMap = [
    &["demineralized"],
    &["demineralised"],
    &["demineralized"],
    &["demineralised"],
];

pub(crate) static ENTRY_DEMINERALIZER_11839062214960881518: VariantsMap = [
    &["demineralizer"],
    &["demineraliser"],
    &["demineralizer"],
    &["demineraliser"],
];

pub(crate) static ENTRY_DEMINERALIZES_10853907656124140046: VariantsMap = [
    &["demineralizes"],
    &["demineralises"],
    &["demineralizes"],
    &["demineralises"],
];

pub(crate) static ENTRY_DEMINERALIZE_2028750406115400134: VariantsMap = [
    &["demineralize"],
    &["demineralise"],
    &["demineralize"],
    &["demineralise"],
];

pub(crate) static ENTRY_DEMINERALIZING_8656195446853674994: VariantsMap = [
    &["demineralizing"],
    &["demineralising"],
    &["demineralizing"],
    &["demineralising"],
];

pub(crate) static ENTRY_DEMOBILIZATIONS_6851457664741914489: VariantsMap = [
    &["demobilizations"],
    &["demobilisations"],
    &["demobilizations"],
    &["demobilisations"],
];

pub(crate) static ENTRY_DEMOBILIZATION_8427760600922715154: VariantsMap = [
    &["demobilization"],
    &["demobilisation"],
    &["demobilization"],
    &["demobilisation"],
];

pub(crate) static ENTRY_DEMOBILIZED_9206102949665526961: VariantsMap = [
    &["demobilized"],
    &["demobilised"],
    &["demobilized"],
    &["demobilised"],
];

pub(crate) static ENTRY_DEMOBILIZES_9950566876349545979: VariantsMap = [
    &["demobilizes"],
    &["demobilises"],
    &["demobilizes"],
    &["demobilises"],
];

pub(crate) static ENTRY_DEMOBILIZE_7893368911880481234: VariantsMap = [
    &["demobilize"],
    &["demobilise"],
    &["demobilize"],
    &["demobilise"],
];

pub(crate) static ENTRY_DEMOBILIZING_2666589548621520076: VariantsMap = [
    &["demobilizing"],
    &["demobilising"],
    &["demobilizing"],
    &["demobilising"],
];

pub(crate) static ENTRY_DEMOCRATIZATIONS_4388695499854265807: VariantsMap = [
    &["democratizations"],
    &["democratisations"],
    &["democratizations"],
    &["democratisations"],
];

pub(crate) static ENTRY_DEMOCRATIZATION_17254764392338903283: VariantsMap = [
    &["democratization"],
    &["democratisation"],
    &["democratization"],
    &["democratisation"],
];

pub(crate) static ENTRY_DEMOCRATIZED_18121735197237538789: VariantsMap = [
    &["democratized"],
    &["democratised"],
    &["democratized"],
    &["democratised"],
];

pub(crate) static ENTRY_DEMOCRATIZER_15492342920596234152: VariantsMap = [
    &["democratizer"],
    &["democratiser"],
    &["democratizer"],
    &["democratiser"],
];

pub(crate) static ENTRY_DEMOCRATIZES_11290287892884717824: VariantsMap = [
    &["democratizes"],
    &["democratises"],
    &["democratizes"],
    &["democratises"],
];

pub(crate) static ENTRY_DEMOCRATIZE_10194385791283666571: VariantsMap = [
    &["democratize"],
    &["democratise"],
    &["democratize"],
    &["democratise"],
];

pub(crate) static ENTRY_DEMOCRATIZING_5756319688655505152: VariantsMap = [
    &["democratizing"],
    &["democratising"],
    &["democratizing"],
    &["democratising"],
];

pub(crate) static ENTRY_DEMONETIZATIONS_255741605004235275: VariantsMap = [
    &["demonetizations"],
    &["demonetisations"],
    &["demonetizations"],
    &["demonetisations"],
];

pub(crate) static ENTRY_DEMONETIZATION_10800150167569494235: VariantsMap = [
    &["demonetization"],
    &["demonetisation"],
    &["demonetization"],
    &["demonetisation"],
];

pub(crate) static ENTRY_DEMONETIZED_13800822593083516335: VariantsMap = [
    &["demonetized"],
    &["demonetised"],
    &["demonetized"],
    &["demonetised"],
];

pub(crate) static ENTRY_DEMONETIZES_7423921842471575397: VariantsMap = [
    &["demonetizes"],
    &["demonetises"],
    &["demonetizes"],
    &["demonetises"],
];

pub(crate) static ENTRY_DEMONETIZE_9169780209388435319: VariantsMap = [
    &["demonetize"],
    &["demonetise"],
    &["demonetize"],
    &["demonetise"],
];

pub(crate) static ENTRY_DEMONETIZING_6533722070664012445: VariantsMap = [
    &["demonetizing"],
    &["demonetising"],
    &["demonetizing"],
    &["demonetising"],
];

pub(crate) static ENTRY_DEMONIAN_17257435076983249346: VariantsMap = [
    &["demonian"],
    &["daemonian"],
    &["daemonian"],
    &["daemonian"],
];

pub(crate) static ENTRY_DEMONIZATION_16933975817485552160: VariantsMap = [
    &["demonization"],
    &["demonisation"],
    &["demonization"],
    &["demonisation"],
];

pub(crate) static ENTRY_DEMONIZED_12813528693273757543: VariantsMap = [
    &["demonized"],
    &["demonised"],
    &["demonized"],
    &["demonised"],
];

pub(crate) static ENTRY_DEMONIZES_9920698644496788584: VariantsMap = [
    &["demonizes"],
    &["demonises"],
    &["demonizes"],
    &["demonises"],
];

pub(crate) static ENTRY_DEMONIZE_12145752355966993821: VariantsMap =
    [&["demonize"], &["demonise"], &["demonize"], &["demonise"]];

pub(crate) static ENTRY_DEMONIZING_6566799728062813977: VariantsMap = [
    &["demonizing"],
    &["demonising"],
    &["demonizing"],
    &["demonising"],
];

pub(crate) static ENTRY_DEMORALIZATIONS_1875584783582242810: VariantsMap = [
    &["demoralizations"],
    &["demoralisations"],
    &["demoralizations"],
    &["demoralisations"],
];

pub(crate) static ENTRY_DEMORALIZATION_13446399219739683931: VariantsMap = [
    &["demoralization"],
    &["demoralisation"],
    &["demoralization"],
    &["demoralisation"],
];

pub(crate) static ENTRY_DEMORALIZED_11996398655519385837: VariantsMap = [
    &["demoralized"],
    &["demoralised"],
    &["demoralized"],
    &["demoralised"],
];

pub(crate) static ENTRY_DEMORALIZERS_600938080037133255: VariantsMap = [
    &["demoralizers"],
    &["demoralisers"],
    &["demoralizers"],
    &["demoralisers"],
];

pub(crate) static ENTRY_DEMORALIZER_9540636813033814633: VariantsMap = [
    &["demoralizer"],
    &["demoraliser"],
    &["demoralizer"],
    &["demoraliser"],
];

pub(crate) static ENTRY_DEMORALIZES_6517352001271737987: VariantsMap = [
    &["demoralizes"],
    &["demoralises"],
    &["demoralizes"],
    &["demoralises"],
];

pub(crate) static ENTRY_DEMORALIZE_5844727729581502857: VariantsMap = [
    &["demoralize"],
    &["demoralise"],
    &["demoralize"],
    &["demoralise"],
];

pub(crate) static ENTRY_DEMORALIZINGLY_8510512214576425144: VariantsMap = [
    &["demoralizingly"],
    &["demoralisingly"],
    &["demoralizingly"],
    &["demoralisingly"],
];

pub(crate) static ENTRY_DEMORALIZING_2653761035115515698: VariantsMap = [
    &["demoralizing"],
    &["demoralising"],
    &["demoralizing"],
    &["demoralising"],
];

pub(crate) static ENTRY_DEMUTUALIZATIONS_10275807852426892350: VariantsMap = [
    &["demutualizations"],
    &["demutualisations"],
    &["demutualizations"],
    &["demutualisations"],
];

pub(crate) static ENTRY_DEMUTUALIZATION_5558427623273214024: VariantsMap = [
    &["demutualization"],
    &["demutualisation"],
    &["demutualization"],
    &["demutualisation"],
];

pub(crate) static ENTRY_DEMUTUALIZED_11852403011547269121: VariantsMap = [
    &["demutualized"],
    &["demutualised"],
    &["demutualized"],
    &["demutualised"],
];

pub(crate) static ENTRY_DEMUTUALIZES_11099575180973682407: VariantsMap = [
    &["demutualizes"],
    &["demutualises"],
    &["demutualizes"],
    &["demutualises"],
];

pub(crate) static ENTRY_DEMUTUALIZE_2272296115716481128: VariantsMap = [
    &["demutualize"],
    &["demutualise"],
    &["demutualize"],
    &["demutualise"],
];

pub(crate) static ENTRY_DEMUTUALIZING_7987101933996172504: VariantsMap = [
    &["demutualizing"],
    &["demutualising"],
    &["demutualizing"],
    &["demutualising"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZATIONS_14134816474323970961: VariantsMap = [
    &["demythologizations"],
    &["demythologisations"],
    &["demythologizations"],
    &["demythologisations"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZATION_10340600013226874649: VariantsMap = [
    &["demythologization"],
    &["demythologisation"],
    &["demythologization"],
    &["demythologisation"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZED_4313900331791829006: VariantsMap = [
    &["demythologized"],
    &["demythologised"],
    &["demythologized"],
    &["demythologised"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZER_5237816041623179771: VariantsMap = [
    &["demythologizer"],
    &["demythologiser"],
    &["demythologizer"],
    &["demythologiser"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZES_18185232184173660209: VariantsMap = [
    &["demythologizes"],
    &["demythologises"],
    &["demythologizes"],
    &["demythologises"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZE_16862432836085218960: VariantsMap = [
    &["demythologize"],
    &["demythologise"],
    &["demythologize"],
    &["demythologise"],
];

pub(crate) static ENTRY_DEMYTHOLOGIZING_12409215121201891385: VariantsMap = [
    &["demythologizing"],
    &["demythologising"],
    &["demythologizing"],
    &["demythologising"],
];

pub(crate) static ENTRY_DENATIONALIZATIONS_9164415981140694292: VariantsMap = [
    &["denationalizations"],
    &["denationalisations"],
    &["denationalizations"],
    &["denationalisations"],
];

pub(crate) static ENTRY_DENATIONALIZATION_16856781549152365477: VariantsMap = [
    &["denationalization"],
    &["denationalisation"],
    &["denationalization"],
    &["denationalisation"],
];

pub(crate) static ENTRY_DENATIONALIZED_10472708594349713108: VariantsMap = [
    &["denationalized"],
    &["denationalised"],
    &["denationalized"],
    &["denationalised"],
];

pub(crate) static ENTRY_DENATIONALIZES_817254898726083409: VariantsMap = [
    &["denationalizes"],
    &["denationalises"],
    &["denationalizes"],
    &["denationalises"],
];

pub(crate) static ENTRY_DENATIONALIZE_10800464833245961489: VariantsMap = [
    &["denationalize"],
    &["denationalise"],
    &["denationalize"],
    &["denationalise"],
];

pub(crate) static ENTRY_DENATIONALIZING_8331022494929548611: VariantsMap = [
    &["denationalizing"],
    &["denationalising"],
    &["denationalizing"],
    &["denationalising"],
];

pub(crate) static ENTRY_DENATURALIZATIONS_16570465894458392415: VariantsMap = [
    &["denaturalizations"],
    &["denaturalisations"],
    &["denaturalizations"],
    &["denaturalisations"],
];

pub(crate) static ENTRY_DENATURALIZATION_4147617871911149693: VariantsMap = [
    &["denaturalization"],
    &["denaturalisation"],
    &["denaturalization"],
    &["denaturalisation"],
];

pub(crate) static ENTRY_DENATURALIZED_1338969835914266213: VariantsMap = [
    &["denaturalized"],
    &["denaturalised"],
    &["denaturalized"],
    &["denaturalised"],
];

pub(crate) static ENTRY_DENATURALIZES_12885068908916155509: VariantsMap = [
    &["denaturalizes"],
    &["denaturalises"],
    &["denaturalizes"],
    &["denaturalises"],
];

pub(crate) static ENTRY_DENATURALIZE_12142869922927195304: VariantsMap = [
    &["denaturalize"],
    &["denaturalise"],
    &["denaturalize"],
    &["denaturalise"],
];

pub(crate) static ENTRY_DENATURALIZING_11035796773484399105: VariantsMap = [
    &["denaturalizing"],
    &["denaturalising"],
    &["denaturalizing"],
    &["denaturalising"],
];

pub(crate) static ENTRY_DENATURIZATIONS_12481426158532842249: VariantsMap = [
    &["denaturizations"],
    &["denaturisations"],
    &["denaturizations"],
    &["denaturisations"],
];

pub(crate) static ENTRY_DENATURIZATION_2153844497547377154: VariantsMap = [
    &["denaturization"],
    &["denaturisation"],
    &["denaturization"],
    &["denaturisation"],
];

pub(crate) static ENTRY_DENATURIZED_11293306666666002972: VariantsMap = [
    &["denaturized"],
    &["denaturised"],
    &["denaturized"],
    &["denaturised"],
];

pub(crate) static ENTRY_DENATURIZERS_7527212398694915324: VariantsMap = [
    &["denaturizers"],
    &["denaturisers"],
    &["denaturizers"],
    &["denaturisers"],
];

pub(crate) static ENTRY_DENATURIZER_9311420005130802353: VariantsMap = [
    &["denaturizer"],
    &["denaturiser"],
    &["denaturizer"],
    &["denaturiser"],
];

pub(crate) static ENTRY_DENATURIZES_2160785183565221398: VariantsMap = [
    &["denaturizes"],
    &["denaturises"],
    &["denaturizes"],
    &["denaturises"],
];

pub(crate) static ENTRY_DENATURIZE_16665212717126083275: VariantsMap = [
    &["denaturize"],
    &["denaturise"],
    &["denaturize"],
    &["denaturise"],
];

pub(crate) static ENTRY_DENATURIZING_7455919186731907769: VariantsMap = [
    &["denaturizing"],
    &["denaturising"],
    &["denaturizing"],
    &["denaturising"],
];

pub(crate) static ENTRY_DENICOTINIZE_1657978267403261883: VariantsMap = [
    &["denicotinize"],
    &["denicotinise"],
    &["denicotinize"],
    &["denicotinise"],
];

pub(crate) static ENTRY_DENIZENIZES_4532386499907231320: VariantsMap = [
    &["denizenizes"],
    &["denizenises"],
    &["denizenizes"],
    &["denizenises"],
];

pub(crate) static ENTRY_DENIZENIZE_15175171930010739812: VariantsMap = [
    &["denizenize"],
    &["denizenise"],
    &["denizenize"],
    &["denizenise"],
];

pub(crate) static ENTRY_DENOMINATIONALIZES_16912479616014894849: VariantsMap = [
    &["denominationalizes"],
    &["denominationalises"],
    &["denominationalizes"],
    &["denominationalises"],
];

pub(crate) static ENTRY_DENOMINATIONALIZE_11508794372277368265: VariantsMap = [
    &["denominationalize"],
    &["denominationalise"],
    &["denominationalize"],
    &["denominationalise"],
];

pub(crate) static ENTRY_DENORMALIZE_14457389572229397553: VariantsMap = [
    &["denormalize"],
    &["denormalise"],
    &["denormalize"],
    &["denormalise"],
];

pub(crate) static ENTRY_DENTALIZATIONS_1316043456675495124: VariantsMap = [
    &["dentalizations"],
    &["dentalisations"],
    &["dentalizations"],
    &["dentalisations"],
];

pub(crate) static ENTRY_DENTALIZATION_15022518066445577537: VariantsMap = [
    &["dentalization"],
    &["dentalisation"],
    &["dentalization"],
    &["dentalisation"],
];

pub(crate) static ENTRY_DENTALIZED_2413837908707543437: VariantsMap = [
    &["dentalized"],
    &["dentalised"],
    &["dentalized"],
    &["dentalised"],
];

pub(crate) static ENTRY_DENTALIZES_6643609780500500774: VariantsMap = [
    &["dentalizes"],
    &["dentalises"],
    &["dentalizes"],
    &["dentalises"],
];

pub(crate) static ENTRY_DENTALIZE_13079577939938126746: VariantsMap = [
    &["dentalize"],
    &["dentalise"],
    &["dentalize"],
    &["dentalise"],
];

pub(crate) static ENTRY_DENTALIZING_324908095822959388: VariantsMap = [
    &["dentalizing"],
    &["dentalising"],
    &["dentalizing"],
    &["dentalising"],
];

pub(crate) static ENTRY_DENTINS_8462696171012072981: VariantsMap =
    [&["dentins"], &["dentines"], &["dentines"], &["dentines"]];

pub(crate) static ENTRY_DENTIN_8335953072295603807: VariantsMap =
    [&["dentin"], &["dentine"], &["dentine"], &["dentine"]];

pub(crate) static ENTRY_DENUCLEARIZATIONS_7167298608770271904: VariantsMap = [
    &["denuclearizations"],
    &["denuclearisations"],
    &["denuclearizations"],
    &["denuclearisations"],
];

pub(crate) static ENTRY_DENUCLEARIZATION_6246945169000847057: VariantsMap = [
    &["denuclearization"],
    &["denuclearisation"],
    &["denuclearization"],
    &["denuclearisation"],
];

pub(crate) static ENTRY_DENUCLEARIZED_14638949387306808248: VariantsMap = [
    &["denuclearized"],
    &["denuclearised"],
    &["denuclearized"],
    &["denuclearised"],
];

pub(crate) static ENTRY_DENUCLEARIZES_3857601007676937998: VariantsMap = [
    &["denuclearizes"],
    &["denuclearises"],
    &["denuclearizes"],
    &["denuclearises"],
];

pub(crate) static ENTRY_DENUCLEARIZE_7871525726880557534: VariantsMap = [
    &["denuclearize"],
    &["denuclearise"],
    &["denuclearize"],
    &["denuclearise"],
];

pub(crate) static ENTRY_DENUCLEARIZING_6228420000189119754: VariantsMap = [
    &["denuclearizing"],
    &["denuclearising"],
    &["denuclearizing"],
    &["denuclearising"],
];

pub(crate) static ENTRY_DEODORIZATIONS_12657185289043189294: VariantsMap = [
    &["deodorizations"],
    &["deodorisations"],
    &["deodorizations"],
    &["deodorisations"],
];

pub(crate) static ENTRY_DEODORIZATION_15234202985364171925: VariantsMap = [
    &["deodorization"],
    &["deodorisation"],
    &["deodorization"],
    &["deodorisation"],
];

pub(crate) static ENTRY_DEODORIZED_17559687252320728172: VariantsMap = [
    &["deodorized"],
    &["deodorised"],
    &["deodorized"],
    &["deodorised"],
];

pub(crate) static ENTRY_DEODORIZERS_7206686442131612842: VariantsMap = [
    &["deodorizers"],
    &["deodorisers"],
    &["deodorizers"],
    &["deodorisers"],
];

pub(crate) static ENTRY_DEODORIZER_13797022735041696461: VariantsMap = [
    &["deodorizer"],
    &["deodoriser"],
    &["deodorizer"],
    &["deodoriser"],
];

pub(crate) static ENTRY_DEODORIZES_4648778267610996306: VariantsMap = [
    &["deodorizes"],
    &["deodorises"],
    &["deodorizes"],
    &["deodorises"],
];

pub(crate) static ENTRY_DEODORIZE_16215032566622833150: VariantsMap = [
    &["deodorize"],
    &["deodorise"],
    &["deodorize"],
    &["deodorise"],
];

pub(crate) static ENTRY_DEODORIZING_12515361627952335019: VariantsMap = [
    &["deodorizing"],
    &["deodorising"],
    &["deodorizing"],
    &["deodorising"],
];

pub(crate) static ENTRY_DEOXIDIZATIONS_13683604498444194612: VariantsMap = [
    &["deoxidizations"],
    &["deoxidisations"],
    &["deoxidizations"],
    &["deoxidisations"],
];

pub(crate) static ENTRY_DEOXIDIZATION_7394934458510098573: VariantsMap = [
    &["deoxidization"],
    &["deoxidisation"],
    &["deoxidization"],
    &["deoxidisation"],
];

pub(crate) static ENTRY_DEOXIDIZED_14617928271424988803: VariantsMap = [
    &["deoxidized"],
    &["deoxidised"],
    &["deoxidized"],
    &["deoxidised"],
];

pub(crate) static ENTRY_DEOXIDIZERS_10105977169121575310: VariantsMap = [
    &["deoxidizers"],
    &["deoxidisers"],
    &["deoxidizers"],
    &["deoxidisers"],
];

pub(crate) static ENTRY_DEOXIDIZER_11973963213903362992: VariantsMap = [
    &["deoxidizer"],
    &["deoxidiser"],
    &["deoxidizer"],
    &["deoxidiser"],
];

pub(crate) static ENTRY_DEOXIDIZES_4018740714548992165: VariantsMap = [
    &["deoxidizes"],
    &["deoxidises"],
    &["deoxidizes"],
    &["deoxidises"],
];

pub(crate) static ENTRY_DEOXIDIZE_8564134429609100253: VariantsMap = [
    &["deoxidize"],
    &["deoxidise"],
    &["deoxidize"],
    &["deoxidise"],
];

pub(crate) static ENTRY_DEOXIDIZING_17849539330093953654: VariantsMap = [
    &["deoxidizing"],
    &["deoxidising"],
    &["deoxidizing"],
    &["deoxidising"],
];

pub(crate) static ENTRY_DEOXYGENIZED_6360726218188064127: VariantsMap = [
    &["deoxygenized"],
    &["deoxygenised"],
    &["deoxygenized"],
    &["deoxygenised"],
];

pub(crate) static ENTRY_DEOXYGENIZES_17788466892741650049: VariantsMap = [
    &["deoxygenizes"],
    &["deoxygenises"],
    &["deoxygenizes"],
    &["deoxygenises"],
];

pub(crate) static ENTRY_DEOXYGENIZE_7933890150357499237: VariantsMap = [
    &["deoxygenize"],
    &["deoxygenise"],
    &["deoxygenize"],
    &["deoxygenise"],
];

pub(crate) static ENTRY_DEOXYGENIZING_6445979304009334071: VariantsMap = [
    &["deoxygenizing"],
    &["deoxygenising"],
    &["deoxygenizing"],
    &["deoxygenising"],
];

pub(crate) static ENTRY_DEPARTMENTALIZATIONS_13030339549069230554: VariantsMap = [
    &["departmentalizations"],
    &["departmentalisations"],
    &["departmentalizations"],
    &["departmentalisations"],
];

pub(crate) static ENTRY_DEPARTMENTALIZATION_12611432409781436004: VariantsMap = [
    &["departmentalization"],
    &["departmentalisation"],
    &["departmentalization"],
    &["departmentalisation"],
];

pub(crate) static ENTRY_DEPARTMENTALIZED_7739211835934086119: VariantsMap = [
    &["departmentalized"],
    &["departmentalised"],
    &["departmentalized"],
    &["departmentalised"],
];

pub(crate) static ENTRY_DEPARTMENTALIZES_2816661299052746212: VariantsMap = [
    &["departmentalizes"],
    &["departmentalises"],
    &["departmentalizes"],
    &["departmentalises"],
];

pub(crate) static ENTRY_DEPARTMENTALIZE_14009690449414337770: VariantsMap = [
    &["departmentalize"],
    &["departmentalise"],
    &["departmentalize"],
    &["departmentalise"],
];

pub(crate) static ENTRY_DEPARTMENTALIZING_18236918120360172300: VariantsMap = [
    &["departmentalizing"],
    &["departmentalising"],
    &["departmentalizing"],
    &["departmentalising"],
];

pub(crate) static ENTRY_DEPARTMENTIZATIONS_3570201152511445119: VariantsMap = [
    &["departmentizations"],
    &["departmentisations"],
    &["departmentizations"],
    &["departmentisations"],
];

pub(crate) static ENTRY_DEPARTMENTIZATION_10520965656271033045: VariantsMap = [
    &["departmentization"],
    &["departmentisation"],
    &["departmentization"],
    &["departmentisation"],
];

pub(crate) static ENTRY_DEPARTMENTIZES_7420843837381616897: VariantsMap = [
    &["departmentizes"],
    &["departmentises"],
    &["departmentizes"],
    &["departmentises"],
];

pub(crate) static ENTRY_DEPARTMENTIZE_14523218551427073465: VariantsMap = [
    &["departmentize"],
    &["departmentise"],
    &["departmentize"],
    &["departmentise"],
];

pub(crate) static ENTRY_DEPAUPERIZATION_12167006445811415084: VariantsMap = [
    &["depauperization"],
    &["depauperisation"],
    &["depauperization"],
    &["depauperisation"],
];

pub(crate) static ENTRY_DEPAUPERIZED_18062942538181210641: VariantsMap = [
    &["depauperized"],
    &["depauperised"],
    &["depauperized"],
    &["depauperised"],
];

pub(crate) static ENTRY_DEPAUPERIZES_5838182964694454265: VariantsMap = [
    &["depauperizes"],
    &["depauperises"],
    &["depauperizes"],
    &["depauperises"],
];

pub(crate) static ENTRY_DEPAUPERIZE_5573322689772847322: VariantsMap = [
    &["depauperize"],
    &["depauperise"],
    &["depauperize"],
    &["depauperise"],
];

pub(crate) static ENTRY_DEPAUPERIZING_17019784408353154824: VariantsMap = [
    &["depauperizing"],
    &["depauperising"],
    &["depauperizing"],
    &["depauperising"],
];

pub(crate) static ENTRY_DEPENDENCES_3098774442639177584: VariantsMap = [
    &["dependences"],
    &["dependences"],
    &["dependences"],
    &["dependences"],
];

pub(crate) static ENTRY_DEPENDENCE_10489349889910496855: VariantsMap = [
    &["dependence"],
    &["dependence"],
    &["dependence"],
    &["dependence"],
];

pub(crate) static ENTRY_DEPENDENTS_1571044403913138535: VariantsMap = [
    &["dependents"],
    &["dependants"],
    &["dependants"],
    &["dependants"],
];

pub(crate) static ENTRY_DEPENDENT_14174944247872454288: VariantsMap = [
    &["dependent"],
    &["dependant"],
    &["dependant"],
    &["dependant"],
];

pub(crate) static ENTRY_DEPERSONALIZATIONS_934260460324727269: VariantsMap = [
    &["depersonalizations"],
    &["depersonalisations"],
    &["depersonalizations"],
    &["depersonalisations"],
];

pub(crate) static ENTRY_DEPERSONALIZATION_16899026211036624682: VariantsMap = [
    &["depersonalization"],
    &["depersonalisation"],
    &["depersonalization"],
    &["depersonalisation"],
];

pub(crate) static ENTRY_DEPERSONALIZED_6040306005149363450: VariantsMap = [
    &["depersonalized"],
    &["depersonalised"],
    &["depersonalized"],
    &["depersonalised"],
];

pub(crate) static ENTRY_DEPERSONALIZES_8248879637475981954: VariantsMap = [
    &["depersonalizes"],
    &["depersonalises"],
    &["depersonalizes"],
    &["depersonalises"],
];

pub(crate) static ENTRY_DEPERSONALIZE_18024338536202331812: VariantsMap = [
    &["depersonalize"],
    &["depersonalise"],
    &["depersonalize"],
    &["depersonalise"],
];

pub(crate) static ENTRY_DEPERSONALIZING_9579967389250229168: VariantsMap = [
    &["depersonalizing"],
    &["depersonalising"],
    &["depersonalizing"],
    &["depersonalising"],
];

pub(crate) static ENTRY_DEPOLARIZATIONS_6588998950476370531: VariantsMap = [
    &["depolarizations"],
    &["depolarisations"],
    &["depolarizations"],
    &["depolarisations"],
];

pub(crate) static ENTRY_DEPOLARIZATION_2742985217153412220: VariantsMap = [
    &["depolarization"],
    &["depolarisation"],
    &["depolarization"],
    &["depolarisation"],
];

pub(crate) static ENTRY_DEPOLARIZED_13852987575688176985: VariantsMap = [
    &["depolarized"],
    &["depolarised"],
    &["depolarized"],
    &["depolarised"],
];

pub(crate) static ENTRY_DEPOLARIZERS_17405526508830397920: VariantsMap = [
    &["depolarizers"],
    &["depolarisers"],
    &["depolarizers"],
    &["depolarisers"],
];

pub(crate) static ENTRY_DEPOLARIZER_13724559510199383868: VariantsMap = [
    &["depolarizer"],
    &["depolariser"],
    &["depolarizer"],
    &["depolariser"],
];

pub(crate) static ENTRY_DEPOLARIZES_16555447378193023350: VariantsMap = [
    &["depolarizes"],
    &["depolarises"],
    &["depolarizes"],
    &["depolarises"],
];

pub(crate) static ENTRY_DEPOLARIZE_13378765368414695477: VariantsMap = [
    &["depolarize"],
    &["depolarise"],
    &["depolarize"],
    &["depolarise"],
];

pub(crate) static ENTRY_DEPOLARIZING_1326681409200466325: VariantsMap = [
    &["depolarizing"],
    &["depolarising"],
    &["depolarizing"],
    &["depolarising"],
];

pub(crate) static ENTRY_DEPOLITICIZATION_14063377291726000588: VariantsMap = [
    &["depoliticization"],
    &["depoliticisation"],
    &["depoliticization"],
    &["depoliticisation"],
];

pub(crate) static ENTRY_DEPOLITICIZED_17863590655277271452: VariantsMap = [
    &["depoliticized"],
    &["depoliticised"],
    &["depoliticized"],
    &["depoliticised"],
];

pub(crate) static ENTRY_DEPOLITICIZES_17679110590239399087: VariantsMap = [
    &["depoliticizes"],
    &["depoliticises"],
    &["depoliticizes"],
    &["depoliticises"],
];

pub(crate) static ENTRY_DEPOLITICIZE_646707646854880895: VariantsMap = [
    &["depoliticize"],
    &["depoliticise"],
    &["depoliticize"],
    &["depoliticise"],
];

pub(crate) static ENTRY_DEPOLITICIZING_7335312451906636158: VariantsMap = [
    &["depoliticizing"],
    &["depoliticising"],
    &["depoliticizing"],
    &["depoliticising"],
];

pub(crate) static ENTRY_DEPOLYMERIZATIONS_10499384093097172145: VariantsMap = [
    &["depolymerizations"],
    &["depolymerisations"],
    &["depolymerizations"],
    &["depolymerisations"],
];

pub(crate) static ENTRY_DEPOLYMERIZATION_11553792676168407099: VariantsMap = [
    &["depolymerization"],
    &["depolymerisation"],
    &["depolymerization"],
    &["depolymerisation"],
];

pub(crate) static ENTRY_DEPOLYMERIZED_10301635163339565907: VariantsMap = [
    &["depolymerized"],
    &["depolymerised"],
    &["depolymerized"],
    &["depolymerised"],
];

pub(crate) static ENTRY_DEPOLYMERIZES_8621948432119164421: VariantsMap = [
    &["depolymerizes"],
    &["depolymerises"],
    &["depolymerizes"],
    &["depolymerises"],
];

pub(crate) static ENTRY_DEPOLYMERIZE_332335072679713287: VariantsMap = [
    &["depolymerize"],
    &["depolymerise"],
    &["depolymerize"],
    &["depolymerise"],
];

pub(crate) static ENTRY_DEPOLYMERIZING_9371889196944478207: VariantsMap = [
    &["depolymerizing"],
    &["depolymerising"],
    &["depolymerizing"],
    &["depolymerising"],
];

pub(crate) static ENTRY_DEPRESSURIZATIONS_11557965491679491854: VariantsMap = [
    &["depressurizations"],
    &["depressurisations"],
    &["depressurizations"],
    &["depressurisations"],
];

pub(crate) static ENTRY_DEPRESSURIZATION_8699831289105571367: VariantsMap = [
    &["depressurization"],
    &["depressurisation"],
    &["depressurization"],
    &["depressurisation"],
];

pub(crate) static ENTRY_DEPRESSURIZED_590523559314456395: VariantsMap = [
    &["depressurized"],
    &["depressurised"],
    &["depressurized"],
    &["depressurised"],
];

pub(crate) static ENTRY_DEPRESSURIZES_9794647774856679413: VariantsMap = [
    &["depressurizes"],
    &["depressurises"],
    &["depressurizes"],
    &["depressurises"],
];

pub(crate) static ENTRY_DEPRESSURIZE_2580273134181372193: VariantsMap = [
    &["depressurize"],
    &["depressurise"],
    &["depressurize"],
    &["depressurise"],
];

pub(crate) static ENTRY_DEPRESSURIZING_13641347976969899739: VariantsMap = [
    &["depressurizing"],
    &["depressurising"],
    &["depressurizing"],
    &["depressurising"],
];

pub(crate) static ENTRY_DEPUTATIONIZES_6787325415938091394: VariantsMap = [
    &["deputationizes"],
    &["deputationises"],
    &["deputationizes"],
    &["deputationises"],
];

pub(crate) static ENTRY_DEPUTATIONIZE_6925287050174299860: VariantsMap = [
    &["deputationize"],
    &["deputationise"],
    &["deputationize"],
    &["deputationise"],
];

pub(crate) static ENTRY_DEPUTIZATION_1712123122893688078: VariantsMap = [
    &["deputization"],
    &["deputisation"],
    &["deputization"],
    &["deputisation"],
];

pub(crate) static ENTRY_DEPUTIZED_7193789182724757168: VariantsMap = [
    &["deputized"],
    &["deputised"],
    &["deputized"],
    &["deputised"],
];

pub(crate) static ENTRY_DEPUTIZES_11101760392402320280: VariantsMap = [
    &["deputizes"],
    &["deputises"],
    &["deputizes"],
    &["deputises"],
];

pub(crate) static ENTRY_DEPUTIZE_2146946330988443787: VariantsMap =
    [&["deputize"], &["deputise"], &["deputize"], &["deputise"]];

pub(crate) static ENTRY_DEPUTIZING_7923968930248772327: VariantsMap = [
    &["deputizing"],
    &["deputising"],
    &["deputizing"],
    &["deputising"],
];

pub(crate) static ENTRY_DERACIALIZED_13925986860775238916: VariantsMap = [
    &["deracialized"],
    &["deracialised"],
    &["deracialized"],
    &["deracialised"],
];

pub(crate) static ENTRY_DERACIALIZES_3059282447110218733: VariantsMap = [
    &["deracializes"],
    &["deracialises"],
    &["deracializes"],
    &["deracialises"],
];

pub(crate) static ENTRY_DERACIALIZE_16127533532397871488: VariantsMap = [
    &["deracialize"],
    &["deracialise"],
    &["deracialize"],
    &["deracialise"],
];

pub(crate) static ENTRY_DERACIALIZING_14275754837816585059: VariantsMap = [
    &["deracializing"],
    &["deracialising"],
    &["deracializing"],
    &["deracialising"],
];

pub(crate) static ENTRY_DERATIONALIZATIONS_17119655431636120190: VariantsMap = [
    &["derationalizations"],
    &["derationalisations"],
    &["derationalizations"],
    &["derationalisations"],
];

pub(crate) static ENTRY_DERATIONALIZATION_10528830942768591126: VariantsMap = [
    &["derationalization"],
    &["derationalisation"],
    &["derationalization"],
    &["derationalisation"],
];

pub(crate) static ENTRY_DERATIONALIZES_3693097460338270754: VariantsMap = [
    &["derationalizes"],
    &["derationalises"],
    &["derationalizes"],
    &["derationalises"],
];

pub(crate) static ENTRY_DERATIONALIZE_2313042250140882971: VariantsMap = [
    &["derationalize"],
    &["derationalise"],
    &["derationalize"],
    &["derationalise"],
];

pub(crate) static ENTRY_DERATIZATIONS_2987948756893457504: VariantsMap = [
    &["deratizations"],
    &["deratisations"],
    &["deratizations"],
    &["deratisations"],
];

pub(crate) static ENTRY_DERATIZATION_1556052931660067306: VariantsMap = [
    &["deratization"],
    &["deratisation"],
    &["deratization"],
    &["deratisation"],
];

pub(crate) static ENTRY_DEREALIZATION_4431015585806198367: VariantsMap = [
    &["derealization"],
    &["derealisation"],
    &["derealization"],
    &["derealisation"],
];

pub(crate) static ENTRY_DERECOGNIZED_10133422456568606840: VariantsMap = [
    &["derecognized"],
    &["derecognised"],
    &["derecognized"],
    &["derecognised"],
];

pub(crate) static ENTRY_DERECOGNIZES_2898686597965431739: VariantsMap = [
    &["derecognizes"],
    &["derecognises"],
    &["derecognizes"],
    &["derecognises"],
];

pub(crate) static ENTRY_DERECOGNIZE_12966064062970832050: VariantsMap = [
    &["derecognize"],
    &["derecognise"],
    &["derecognize"],
    &["derecognise"],
];

pub(crate) static ENTRY_DERECOGNIZING_15630007461435589758: VariantsMap = [
    &["derecognizing"],
    &["derecognising"],
    &["derecognizing"],
    &["derecognising"],
];

pub(crate) static ENTRY_DEREGULATIONIZES_10669971165971717976: VariantsMap = [
    &["deregulationizes"],
    &["deregulationises"],
    &["deregulationizes"],
    &["deregulationises"],
];

pub(crate) static ENTRY_DEREGULATIONIZE_4270787265190494422: VariantsMap = [
    &["deregulationize"],
    &["deregulationise"],
    &["deregulationize"],
    &["deregulationise"],
];

pub(crate) static ENTRY_DERELIGIONIZED_12703552936820666292: VariantsMap = [
    &["dereligionized"],
    &["dereligionised"],
    &["dereligionized"],
    &["dereligionised"],
];

pub(crate) static ENTRY_DERELIGIONIZES_15734216747597028796: VariantsMap = [
    &["dereligionizes"],
    &["dereligionises"],
    &["dereligionizes"],
    &["dereligionises"],
];

pub(crate) static ENTRY_DERELIGIONIZE_2197762790814142315: VariantsMap = [
    &["dereligionize"],
    &["dereligionise"],
    &["dereligionize"],
    &["dereligionise"],
];

pub(crate) static ENTRY_DERELIGIONIZING_5815795344545989827: VariantsMap = [
    &["dereligionizing"],
    &["dereligionising"],
    &["dereligionizing"],
    &["dereligionising"],
];

pub(crate) static ENTRY_DERK_4716671464297446249: VariantsMap =
    [&["derk"], &["drek"], &["drek"], &["drek"]];

pub(crate) static ENTRY_DERMATORRHEA_1805754234241080569: VariantsMap = [
    &["dermatorrhea"],
    &["dermatorrhoea"],
    &["dermatorrhoea"],
    &["dermatorrhoea"],
];

pub(crate) static ENTRY_DERR_8497357744990730455: VariantsMap =
    [&["derr"], &["drer"], &["drer"], &["drer"]];

pub(crate) static ENTRY_DESACRALIZATIONS_3159008120594250545: VariantsMap = [
    &["desacralizations"],
    &["desacralisations"],
    &["desacralizations"],
    &["desacralisations"],
];

pub(crate) static ENTRY_DESACRALIZATION_8933482512308094840: VariantsMap = [
    &["desacralization"],
    &["desacralisation"],
    &["desacralization"],
    &["desacralisation"],
];

pub(crate) static ENTRY_DESACRALIZED_5172113800600262057: VariantsMap = [
    &["desacralized"],
    &["desacralised"],
    &["desacralized"],
    &["desacralised"],
];

pub(crate) static ENTRY_DESACRALIZES_3129397141770379489: VariantsMap = [
    &["desacralizes"],
    &["desacralises"],
    &["desacralizes"],
    &["desacralises"],
];

pub(crate) static ENTRY_DESACRALIZE_2904720596855309711: VariantsMap = [
    &["desacralize"],
    &["desacralise"],
    &["desacralize"],
    &["desacralise"],
];

pub(crate) static ENTRY_DESACRALIZING_1923812032604675331: VariantsMap = [
    &["desacralizing"],
    &["desacralising"],
    &["desacralizing"],
    &["desacralising"],
];

pub(crate) static ENTRY_DESALINIZATIONS_6688266856012610087: VariantsMap = [
    &["desalinizations"],
    &["desalinisations"],
    &["desalinizations"],
    &["desalinisations"],
];

pub(crate) static ENTRY_DESALINIZATION_3112141684596769008: VariantsMap = [
    &["desalinization"],
    &["desalinisation"],
    &["desalinization"],
    &["desalinisation"],
];

pub(crate) static ENTRY_DESALINIZED_15785822948480949641: VariantsMap = [
    &["desalinized"],
    &["desalinised"],
    &["desalinized"],
    &["desalinised"],
];

pub(crate) static ENTRY_DESALINIZES_9833000153222176974: VariantsMap = [
    &["desalinizes"],
    &["desalinises"],
    &["desalinizes"],
    &["desalinises"],
];

pub(crate) static ENTRY_DESALINIZE_14106924193733250969: VariantsMap = [
    &["desalinize"],
    &["desalinise"],
    &["desalinize"],
    &["desalinise"],
];

pub(crate) static ENTRY_DESALINIZING_375221854324330696: VariantsMap = [
    &["desalinizing"],
    &["desalinising"],
    &["desalinizing"],
    &["desalinising"],
];

pub(crate) static ENTRY_DESCENDANTS_13592723156308791185: VariantsMap = [
    &["descendants"],
    &["descendants"],
    &["descendants"],
    &["descendants"],
];

pub(crate) static ENTRY_DESENSITIZATIONS_8251374796564084894: VariantsMap = [
    &["desensitizations"],
    &["desensitisations"],
    &["desensitizations"],
    &["desensitisations"],
];

pub(crate) static ENTRY_DESENSITIZATION_12566365864470462238: VariantsMap = [
    &["desensitization"],
    &["desensitisation"],
    &["desensitization"],
    &["desensitisation"],
];

pub(crate) static ENTRY_DESENSITIZED_16642593456085222259: VariantsMap = [
    &["desensitized"],
    &["desensitised"],
    &["desensitized"],
    &["desensitised"],
];

pub(crate) static ENTRY_DESENSITIZERS_14718511209845696977: VariantsMap = [
    &["desensitizers"],
    &["desensitisers"],
    &["desensitizers"],
    &["desensitisers"],
];

pub(crate) static ENTRY_DESENSITIZER_6020988563376810609: VariantsMap = [
    &["desensitizer"],
    &["desensitiser"],
    &["desensitizer"],
    &["desensitiser"],
];

pub(crate) static ENTRY_DESENSITIZES_7107240430399068707: VariantsMap = [
    &["desensitizes"],
    &["desensitises"],
    &["desensitizes"],
    &["desensitises"],
];

pub(crate) static ENTRY_DESENSITIZE_3550903971648567607: VariantsMap = [
    &["desensitize"],
    &["desensitise"],
    &["desensitize"],
    &["desensitise"],
];

pub(crate) static ENTRY_DESENSITIZING_16627131864153604352: VariantsMap = [
    &["desensitizing"],
    &["desensitising"],
    &["desensitizing"],
    &["desensitising"],
];

pub(crate) static ENTRY_DESERTIZATIONS_9614321958416784718: VariantsMap = [
    &["desertizations"],
    &["desertisations"],
    &["desertizations"],
    &["desertisations"],
];

pub(crate) static ENTRY_DESERTIZATION_14992284590814327365: VariantsMap = [
    &["desertization"],
    &["desertisation"],
    &["desertization"],
    &["desertisation"],
];

pub(crate) static ENTRY_DESEXUALIZATIONS_317703425355638040: VariantsMap = [
    &["desexualizations"],
    &["desexualisations"],
    &["desexualizations"],
    &["desexualisations"],
];

pub(crate) static ENTRY_DESEXUALIZATION_7051669726674300306: VariantsMap = [
    &["desexualization"],
    &["desexualisation"],
    &["desexualization"],
    &["desexualisation"],
];

pub(crate) static ENTRY_DESEXUALIZED_709042860780979441: VariantsMap = [
    &["desexualized"],
    &["desexualised"],
    &["desexualized"],
    &["desexualised"],
];

pub(crate) static ENTRY_DESEXUALIZES_12483266755535786660: VariantsMap = [
    &["desexualizes"],
    &["desexualises"],
    &["desexualizes"],
    &["desexualises"],
];

pub(crate) static ENTRY_DESEXUALIZE_4949470699070422167: VariantsMap = [
    &["desexualize"],
    &["desexualise"],
    &["desexualize"],
    &["desexualise"],
];

pub(crate) static ENTRY_DESEXUALIZING_9440019274877492043: VariantsMap = [
    &["desexualizing"],
    &["desexualising"],
    &["desexualizing"],
    &["desexualising"],
];

pub(crate) static ENTRY_DESILVERIZATIONS_3476812538372816382: VariantsMap = [
    &["desilverizations"],
    &["desilverisations"],
    &["desilverizations"],
    &["desilverisations"],
];

pub(crate) static ENTRY_DESILVERIZATION_7083077588146441964: VariantsMap = [
    &["desilverization"],
    &["desilverisation"],
    &["desilverization"],
    &["desilverisation"],
];

pub(crate) static ENTRY_DESILVERIZED_16070622223837559170: VariantsMap = [
    &["desilverized"],
    &["desilverised"],
    &["desilverized"],
    &["desilverised"],
];

pub(crate) static ENTRY_DESILVERIZES_557243620662112813: VariantsMap = [
    &["desilverizes"],
    &["desilverises"],
    &["desilverizes"],
    &["desilverises"],
];

pub(crate) static ENTRY_DESILVERIZE_6336096088586818504: VariantsMap = [
    &["desilverize"],
    &["desilverise"],
    &["desilverize"],
    &["desilverise"],
];

pub(crate) static ENTRY_DESILVERIZING_13130813397466342155: VariantsMap = [
    &["desilverizing"],
    &["desilverising"],
    &["desilverizing"],
    &["desilverising"],
];

pub(crate) static ENTRY_DESPIRITUALIZATION_9440879345640859842: VariantsMap = [
    &["despiritualization"],
    &["despiritualisation"],
    &["despiritualization"],
    &["despiritualisation"],
];

pub(crate) static ENTRY_DESPIRITUALIZE_18226118672475753223: VariantsMap = [
    &["despiritualize"],
    &["despiritualise"],
    &["despiritualize"],
    &["despiritualise"],
];

pub(crate) static ENTRY_DESPOTIZES_5251286731168770044: VariantsMap = [
    &["despotizes"],
    &["despotises"],
    &["despotizes"],
    &["despotises"],
];

pub(crate) static ENTRY_DESPOTIZE_7875765767418230550: VariantsMap = [
    &["despotize"],
    &["despotise"],
    &["despotize"],
    &["despotise"],
];

pub(crate) static ENTRY_DESTABILIZATION_14326190546524052452: VariantsMap = [
    &["destabilization"],
    &["destabilisation"],
    &["destabilization"],
    &["destabilisation"],
];

pub(crate) static ENTRY_DESTABILIZED_1777832444349565509: VariantsMap = [
    &["destabilized"],
    &["destabilised"],
    &["destabilized"],
    &["destabilised"],
];

pub(crate) static ENTRY_DESTABILIZERS_6141576176215173386: VariantsMap = [
    &["destabilizers"],
    &["destabilisers"],
    &["destabilizers"],
    &["destabilisers"],
];

pub(crate) static ENTRY_DESTABILIZER_5486156107617069595: VariantsMap = [
    &["destabilizer"],
    &["destabiliser"],
    &["destabilizer"],
    &["destabiliser"],
];

pub(crate) static ENTRY_DESTABILIZES_13491486327241590151: VariantsMap = [
    &["destabilizes"],
    &["destabilises"],
    &["destabilizes"],
    &["destabilises"],
];

pub(crate) static ENTRY_DESTABILIZE_5513808993828420574: VariantsMap = [
    &["destabilize"],
    &["destabilise"],
    &["destabilize"],
    &["destabilise"],
];

pub(crate) static ENTRY_DESTABILIZING_10660910526175900618: VariantsMap = [
    &["destabilizing"],
    &["destabilising"],
    &["destabilizing"],
    &["destabilising"],
];

pub(crate) static ENTRY_DESTALINIZED_9729731297639277285: VariantsMap = [
    &["destalinized"],
    &["destalinised"],
    &["destalinized"],
    &["destalinised"],
];

pub(crate) static ENTRY_DESTALINIZES_5575846993066512172: VariantsMap = [
    &["destalinizes"],
    &["destalinises"],
    &["destalinizes"],
    &["destalinises"],
];

pub(crate) static ENTRY_DESTALINIZE_9557464174451415418: VariantsMap = [
    &["destalinize"],
    &["destalinise"],
    &["destalinize"],
    &["destalinise"],
];

pub(crate) static ENTRY_DESTALINIZING_365060634953959661: VariantsMap = [
    &["destalinizing"],
    &["destalinising"],
    &["destalinizing"],
    &["destalinising"],
];

pub(crate) static ENTRY_DESTERILIZE_10235095546341603640: VariantsMap = [
    &["desterilize"],
    &["desterilise"],
    &["desterilize"],
    &["desterilise"],
];

pub(crate) static ENTRY_DESTIGMATIZATION_76784710048289446: VariantsMap = [
    &["destigmatization"],
    &["destigmatisation"],
    &["destigmatization"],
    &["destigmatisation"],
];

pub(crate) static ENTRY_DESULFURIZATIONS_14861998503665123704: VariantsMap = [
    &["desulfurizations"],
    &["desulphurisations"],
    &["desulphurizations"],
    &["desulphurisations"],
];

pub(crate) static ENTRY_DESULFURIZATION_10145479217290079220: VariantsMap = [
    &["desulfurization"],
    &["desulphurisation"],
    &["desulphurization"],
    &["desulphurisation"],
];

pub(crate) static ENTRY_DESULFURIZED_1535371682591396877: VariantsMap = [
    &["desulfurized"],
    &["desulphurised"],
    &["desulphurized"],
    &["desulphurised"],
];

pub(crate) static ENTRY_DESULFURIZER_5734678686912127702: VariantsMap = [
    &["desulfurizer"],
    &["desulfuriser"],
    &["desulfurizer"],
    &["desulfuriser"],
];

pub(crate) static ENTRY_DESULFURIZES_1197207125684665875: VariantsMap = [
    &["desulfurizes"],
    &["desulphurises"],
    &["desulphurizes"],
    &["desulphurises"],
];

pub(crate) static ENTRY_DESULFURIZE_12876573712862714533: VariantsMap = [
    &["desulfurize"],
    &["desulphurise"],
    &["desulphurize"],
    &["desulphurise"],
];

pub(crate) static ENTRY_DESULFURIZING_7858975859555627847: VariantsMap = [
    &["desulfurizing"],
    &["desulphurising"],
    &["desulphurizing"],
    &["desulphurising"],
];

pub(crate) static ENTRY_DESULPHURIZERS_282853998000810658: VariantsMap = [
    &["desulphurizers"],
    &["desulphurisers"],
    &["desulphurizers"],
    &["desulphurisers"],
];

pub(crate) static ENTRY_DESULPHURIZER_10137789356803923951: VariantsMap = [
    &["desulphurizer"],
    &["desulphuriser"],
    &["desulphurizer"],
    &["desulphuriser"],
];

pub(crate) static ENTRY_DESYNCHRONIZATIONS_8142294090130517034: VariantsMap = [
    &["desynchronizations"],
    &["desynchronisations"],
    &["desynchronizations"],
    &["desynchronisations"],
];

pub(crate) static ENTRY_DESYNCHRONIZATION_15934272175464625660: VariantsMap = [
    &["desynchronization"],
    &["desynchronisation"],
    &["desynchronization"],
    &["desynchronisation"],
];

pub(crate) static ENTRY_DESYNCHRONIZED_13365058336037754735: VariantsMap = [
    &["desynchronized"],
    &["desynchronised"],
    &["desynchronized"],
    &["desynchronised"],
];

pub(crate) static ENTRY_DESYNCHRONIZES_3997067564763019035: VariantsMap = [
    &["desynchronizes"],
    &["desynchronises"],
    &["desynchronizes"],
    &["desynchronises"],
];

pub(crate) static ENTRY_DESYNCHRONIZE_8943647682721253433: VariantsMap = [
    &["desynchronize"],
    &["desynchronise"],
    &["desynchronize"],
    &["desynchronise"],
];

pub(crate) static ENTRY_DESYNCHRONIZING_15189349053662354180: VariantsMap = [
    &["desynchronizing"],
    &["desynchronising"],
    &["desynchronizing"],
    &["desynchronising"],
];

pub(crate) static ENTRY_DETRIBALIZATIONS_11756828771994817312: VariantsMap = [
    &["detribalizations"],
    &["detribalisations"],
    &["detribalizations"],
    &["detribalisations"],
];

pub(crate) static ENTRY_DETRIBALIZATION_16952730237997981409: VariantsMap = [
    &["detribalization"],
    &["detribalisation"],
    &["detribalization"],
    &["detribalisation"],
];

pub(crate) static ENTRY_DETRIBALIZED_7286047575373525196: VariantsMap = [
    &["detribalized"],
    &["detribalised"],
    &["detribalized"],
    &["detribalised"],
];

pub(crate) static ENTRY_DETRIBALIZES_17667503652444099945: VariantsMap = [
    &["detribalizes"],
    &["detribalises"],
    &["detribalizes"],
    &["detribalises"],
];

pub(crate) static ENTRY_DETRIBALIZE_15143242476306432587: VariantsMap = [
    &["detribalize"],
    &["detribalise"],
    &["detribalize"],
    &["detribalise"],
];

pub(crate) static ENTRY_DETRIBALIZING_12535699864595434298: VariantsMap = [
    &["detribalizing"],
    &["detribalising"],
    &["detribalizing"],
    &["detribalising"],
];

pub(crate) static ENTRY_DEVALORIZATIONS_12670639433164026734: VariantsMap = [
    &["devalorizations"],
    &["devalorisations"],
    &["devalorizations"],
    &["devalorisations"],
];

pub(crate) static ENTRY_DEVALORIZATION_15315014812840888413: VariantsMap = [
    &["devalorization"],
    &["devalorisation"],
    &["devalorization"],
    &["devalorisation"],
];

pub(crate) static ENTRY_DEVALORIZED_10544100609075377554: VariantsMap = [
    &["devalorized"],
    &["devalorised"],
    &["devalorized"],
    &["devalorised"],
];

pub(crate) static ENTRY_DEVALORIZES_4580727997112987764: VariantsMap = [
    &["devalorizes"],
    &["devalorises"],
    &["devalorizes"],
    &["devalorises"],
];

pub(crate) static ENTRY_DEVALORIZE_10794559313991782118: VariantsMap = [
    &["devalorize"],
    &["devalorise"],
    &["devalorize"],
    &["devalorise"],
];

pub(crate) static ENTRY_DEVALORIZING_745754966056062243: VariantsMap = [
    &["devalorizing"],
    &["devalorising"],
    &["devalorizing"],
    &["devalorising"],
];

pub(crate) static ENTRY_DEVA_18303315502243076060: VariantsMap =
    [&["deva"], &["daeva"], &["daeva"], &["daeva"]];

pub(crate) static ENTRY_DEVELED_13710518174394409286: VariantsMap =
    [&["develed"], &["develled"], &["develled"], &["develled"]];

pub(crate) static ENTRY_DEVELING_8091139982686168573: VariantsMap = [
    &["develing"],
    &["develling"],
    &["develling"],
    &["develling"],
];

pub(crate) static ENTRY_DEVILED_13014517801589922329: VariantsMap =
    [&["deviled"], &["devilled"], &["devilled"], &["devilled"]];

pub(crate) static ENTRY_DEVILING_6936097926436525993: VariantsMap = [
    &["deviling"],
    &["devilling"],
    &["devilling"],
    &["devilling"],
];

pub(crate) static ENTRY_DEVILIZES_17745578183045333673: VariantsMap = [
    &["devilizes"],
    &["devilises"],
    &["devilizes"],
    &["devilises"],
];

pub(crate) static ENTRY_DEVILIZE_9795464369905562385: VariantsMap =
    [&["devilize"], &["devilise"], &["devilize"], &["devilise"]];

pub(crate) static ENTRY_DEVITALIZATIONS_13354425441260498778: VariantsMap = [
    &["devitalizations"],
    &["devitalisations"],
    &["devitalizations"],
    &["devitalisations"],
];

pub(crate) static ENTRY_DEVITALIZATION_2114332477720992030: VariantsMap = [
    &["devitalization"],
    &["devitalisation"],
    &["devitalization"],
    &["devitalisation"],
];

pub(crate) static ENTRY_DEVITALIZED_8717395560461798050: VariantsMap = [
    &["devitalized"],
    &["devitalised"],
    &["devitalized"],
    &["devitalised"],
];

pub(crate) static ENTRY_DEVITALIZES_9074596952558116656: VariantsMap = [
    &["devitalizes"],
    &["devitalises"],
    &["devitalizes"],
    &["devitalises"],
];

pub(crate) static ENTRY_DEVITALIZE_1043658353870554736: VariantsMap = [
    &["devitalize"],
    &["devitalise"],
    &["devitalize"],
    &["devitalise"],
];

pub(crate) static ENTRY_DEVITALIZING_14131643871253145067: VariantsMap = [
    &["devitalizing"],
    &["devitalising"],
    &["devitalizing"],
    &["devitalising"],
];

pub(crate) static ENTRY_DEVOCALIZATION_10444917076714233126: VariantsMap = [
    &["devocalization"],
    &["devocalisation"],
    &["devocalization"],
    &["devocalisation"],
];

pub(crate) static ENTRY_DEVOCALIZED_16555396131330717996: VariantsMap = [
    &["devocalized"],
    &["devocalised"],
    &["devocalized"],
    &["devocalised"],
];

pub(crate) static ENTRY_DEVOCALIZES_11452435934127095123: VariantsMap = [
    &["devocalizes"],
    &["devocalises"],
    &["devocalizes"],
    &["devocalises"],
];

pub(crate) static ENTRY_DEVOCALIZE_1529649237001829017: VariantsMap = [
    &["devocalize"],
    &["devocalise"],
    &["devocalize"],
    &["devocalise"],
];

pub(crate) static ENTRY_DEVOCALIZING_540893798000083473: VariantsMap = [
    &["devocalizing"],
    &["devocalising"],
    &["devocalizing"],
    &["devocalising"],
];

pub(crate) static ENTRY_DEVOLATILIZATIONS_4707574596121848991: VariantsMap = [
    &["devolatilizations"],
    &["devolatilisations"],
    &["devolatilizations"],
    &["devolatilisations"],
];

pub(crate) static ENTRY_DEVOLATILIZATION_4689429575223597286: VariantsMap = [
    &["devolatilization"],
    &["devolatilisation"],
    &["devolatilization"],
    &["devolatilisation"],
];

pub(crate) static ENTRY_DEVOLATILIZED_507035959515124086: VariantsMap = [
    &["devolatilized"],
    &["devolatilised"],
    &["devolatilized"],
    &["devolatilised"],
];

pub(crate) static ENTRY_DEVOLATILIZES_8071137154044730701: VariantsMap = [
    &["devolatilizes"],
    &["devolatilises"],
    &["devolatilizes"],
    &["devolatilises"],
];

pub(crate) static ENTRY_DEVOLATILIZE_11441006506088892627: VariantsMap = [
    &["devolatilize"],
    &["devolatilise"],
    &["devolatilize"],
    &["devolatilise"],
];

pub(crate) static ENTRY_DEVOLATILIZING_9726618714956110506: VariantsMap = [
    &["devolatilizing"],
    &["devolatilising"],
    &["devolatilizing"],
    &["devolatilising"],
];

pub(crate) static ENTRY_DIABOLIZATIONS_3822742467764077320: VariantsMap = [
    &["diabolizations"],
    &["diabolisations"],
    &["diabolizations"],
    &["diabolisations"],
];

pub(crate) static ENTRY_DIABOLIZATION_8147427661526738727: VariantsMap = [
    &["diabolization"],
    &["diabolisation"],
    &["diabolization"],
    &["diabolisation"],
];

pub(crate) static ENTRY_DIABOLIZED_5121441305555041821: VariantsMap = [
    &["diabolized"],
    &["diabolised"],
    &["diabolized"],
    &["diabolised"],
];

pub(crate) static ENTRY_DIABOLIZES_6289744568368918053: VariantsMap = [
    &["diabolizes"],
    &["diabolises"],
    &["diabolizes"],
    &["diabolises"],
];

pub(crate) static ENTRY_DIABOLIZE_13327939806411873396: VariantsMap = [
    &["diabolize"],
    &["diabolise"],
    &["diabolize"],
    &["diabolise"],
];

pub(crate) static ENTRY_DIABOLIZING_17353660640060220296: VariantsMap = [
    &["diabolizing"],
    &["diabolising"],
    &["diabolizing"],
    &["diabolising"],
];

pub(crate) static ENTRY_DIAGONALIZABLE_10977422841248602526: VariantsMap = [
    &["diagonalizable"],
    &["diagonalisable"],
    &["diagonalizable"],
    &["diagonalisable"],
];

pub(crate) static ENTRY_DIAGONALIZATION_17906612353739944122: VariantsMap = [
    &["diagonalization"],
    &["diagonalisation"],
    &["diagonalization"],
    &["diagonalisation"],
];

pub(crate) static ENTRY_DIAGONALIZED_16278489065750351065: VariantsMap = [
    &["diagonalized"],
    &["diagonalised"],
    &["diagonalized"],
    &["diagonalised"],
];

pub(crate) static ENTRY_DIAGONALIZES_15436394800752209539: VariantsMap = [
    &["diagonalizes"],
    &["diagonalises"],
    &["diagonalizes"],
    &["diagonalises"],
];

pub(crate) static ENTRY_DIAGONALIZE_17545470866818361268: VariantsMap = [
    &["diagonalize"],
    &["diagonalise"],
    &["diagonalize"],
    &["diagonalise"],
];

pub(crate) static ENTRY_DIAGONALIZING_14520835686620115538: VariantsMap = [
    &["diagonalizing"],
    &["diagonalising"],
    &["diagonalizing"],
    &["diagonalising"],
];

pub(crate) static ENTRY_DIALECTICIZES_3201740277613515360: VariantsMap = [
    &["dialecticizes"],
    &["dialecticises"],
    &["dialecticizes"],
    &["dialecticises"],
];

pub(crate) static ENTRY_DIALECTICIZE_2204671560565196577: VariantsMap = [
    &["dialecticize"],
    &["dialecticise"],
    &["dialecticize"],
    &["dialecticise"],
];

pub(crate) static ENTRY_DIALED_12445554267564800284: VariantsMap =
    [&["dialed"], &["dialled"], &["dialed"], &["dialled"]];

pub(crate) static ENTRY_DIALERS_5602259152205050826: VariantsMap =
    [&["dialers"], &["diallers"], &["diallers"], &["diallers"]];

pub(crate) static ENTRY_DIALER_4550505305630586540: VariantsMap =
    [&["dialer"], &["dialler"], &["dialler"], &["dialler"]];

pub(crate) static ENTRY_DIALINGS_4797662219825576657: VariantsMap =
    [&["dialings"], &["diallings"], &["dialings"], &["diallings"]];

pub(crate) static ENTRY_DIALING_15825922980741414813: VariantsMap =
    [&["dialing"], &["dialling"], &["dialing"], &["dialling"]];

pub(crate) static ENTRY_DIALISTS_17620866403243878741: VariantsMap = [
    &["dialists"],
    &["diallists"],
    &["diallists"],
    &["diallists"],
];

pub(crate) static ENTRY_DIALIST_8678208478430149150: VariantsMap =
    [&["dialist"], &["diallist"], &["diallist"], &["diallist"]];

pub(crate) static ENTRY_DIALOGIZED_16517368637953000442: VariantsMap = [
    &["dialogized"],
    &["dialogised"],
    &["dialogized"],
    &["dialogised"],
];

pub(crate) static ENTRY_DIALOGIZES_10946689184118338197: VariantsMap = [
    &["dialogizes"],
    &["dialogises"],
    &["dialogizes"],
    &["dialogises"],
];

pub(crate) static ENTRY_DIALOGIZE_3147664435711992783: VariantsMap = [
    &["dialogize"],
    &["dialogise"],
    &["dialogize"],
    &["dialogise"],
];

pub(crate) static ENTRY_DIALOGIZING_10876002085618537096: VariantsMap = [
    &["dialogizing"],
    &["dialogising"],
    &["dialogizing"],
    &["dialogising"],
];

pub(crate) static ENTRY_DIALOGUED_1860543501002215986: VariantsMap = [
    &["dialogued"],
    &["dialogued"],
    &["dialogued"],
    &["dialogued"],
];

pub(crate) static ENTRY_DIALOGUES_11157018411024684853: VariantsMap = [
    &["dialogues"],
    &["dialogues"],
    &["dialogues"],
    &["dialogues"],
];

pub(crate) static ENTRY_DIALOGUING_14221452045191699395: VariantsMap = [
    &["dialoguing"],
    &["dialoguing"],
    &["dialoguing"],
    &["dialoguing"],
];

pub(crate) static ENTRY_DIALYZABILITIES_16919452053444132964: VariantsMap = [
    &["dialyzabilities"],
    &["dialysabilities"],
    &["dialysabilities"],
    &["dialysabilities"],
];

pub(crate) static ENTRY_DIALYZABILITY_2385882814800744278: VariantsMap = [
    &["dialyzability"],
    &["dialysability"],
    &["dialysability"],
    &["dialysability"],
];

pub(crate) static ENTRY_DIALYZABLER_2950437622828839578: VariantsMap = [
    &["dialyzabler"],
    &["dialysabler"],
    &["dialysabler"],
    &["dialysabler"],
];

pub(crate) static ENTRY_DIALYZABLEST_10251547193383432771: VariantsMap = [
    &["dialyzablest"],
    &["dialysablest"],
    &["dialysablest"],
    &["dialysablest"],
];

pub(crate) static ENTRY_DIALYZABLES_15000950498086971159: VariantsMap = [
    &["dialyzables"],
    &["dialysables"],
    &["dialysables"],
    &["dialysables"],
];

pub(crate) static ENTRY_DIALYZABLE_4481317071046410548: VariantsMap = [
    &["dialyzable"],
    &["dialysable"],
    &["dialysable"],
    &["dialysable"],
];

pub(crate) static ENTRY_DIALYZATES_16159553587347789538: VariantsMap = [
    &["dialyzates"],
    &["dialysates"],
    &["dialyzates"],
    &["dialysates"],
];

pub(crate) static ENTRY_DIALYZATE_847425955284979672: VariantsMap = [
    &["dialyzate"],
    &["dialysate"],
    &["dialyzate"],
    &["dialysate"],
];

pub(crate) static ENTRY_DIALYZATION_14569182709416219304: VariantsMap = [
    &["dialyzation"],
    &["dialysation"],
    &["dialyzation"],
    &["dialysation"],
];

pub(crate) static ENTRY_DIALYZED_1600178824809360907: VariantsMap =
    [&["dialyzed"], &["dialysed"], &["dialyzed"], &["dialysed"]];

pub(crate) static ENTRY_DIALYZERS_11623550947622716911: VariantsMap = [
    &["dialyzers"],
    &["dialysers"],
    &["dialyzers"],
    &["dialysers"],
];

pub(crate) static ENTRY_DIALYZER_7774506769012694605: VariantsMap =
    [&["dialyzer"], &["dialyser"], &["dialyzer"], &["dialyser"]];

pub(crate) static ENTRY_DIALYZES_9413207522578141113: VariantsMap =
    [&["dialyzes"], &["dialyses"], &["dialyzes"], &["dialyses"]];

pub(crate) static ENTRY_DIALYZE_6329229259949071274: VariantsMap =
    [&["dialyze"], &["dialyse"], &["dialyze"], &["dialyse"]];

pub(crate) static ENTRY_DIALYZING_4945836046675013341: VariantsMap = [
    &["dialyzing"],
    &["dialysing"],
    &["dialyzing"],
    &["dialysing"],
];

pub(crate) static ENTRY_DIAMONDIZES_11382117953228798781: VariantsMap = [
    &["diamondizes"],
    &["diamondises"],
    &["diamondizes"],
    &["diamondises"],
];

pub(crate) static ENTRY_DIAMONDIZE_974653197096494091: VariantsMap = [
    &["diamondize"],
    &["diamondise"],
    &["diamondize"],
    &["diamondise"],
];

pub(crate) static ENTRY_DIARIZED_15375708985365837815: VariantsMap =
    [&["diarized"], &["diarised"], &["diarized"], &["diarised"]];

pub(crate) static ENTRY_DIARIZES_6733157561570470769: VariantsMap =
    [&["diarizes"], &["diarises"], &["diarizes"], &["diarises"]];

pub(crate) static ENTRY_DIARIZE_7333441747497120999: VariantsMap =
    [&["diarize"], &["diarise"], &["diarize"], &["diarise"]];

pub(crate) static ENTRY_DIARIZING_6033557535432094232: VariantsMap = [
    &["diarizing"],
    &["diarising"],
    &["diarizing"],
    &["diarising"],
];

pub(crate) static ENTRY_DIARRHEALER_11350171176863314647: VariantsMap = [
    &["diarrhealer"],
    &["diarrhoealer"],
    &["diarrhealer"],
    &["diarrhoealer"],
];

pub(crate) static ENTRY_DIARRHEALEST_16171976767316321320: VariantsMap = [
    &["diarrhealest"],
    &["diarrhoealest"],
    &["diarrhealest"],
    &["diarrhoealest"],
];

pub(crate) static ENTRY_DIARRHEAL_13590773083958773898: VariantsMap = [
    &["diarrheal"],
    &["diarrhoeal"],
    &["diarrheal"],
    &["diarrhoeal"],
];

pub(crate) static ENTRY_DIARRHEAS_11453476003683730830: VariantsMap = [
    &["diarrheas"],
    &["diarrhoeas"],
    &["diarrheas"],
    &["diarrhoeas"],
];

pub(crate) static ENTRY_DIARRHEA_16651318537078726725: VariantsMap =
    [&["diarrhea"], &["diarrhoea"], &["diarrhea"], &["diarrhoea"]];

pub(crate) static ENTRY_DIARRHEICER_15169580495143503922: VariantsMap = [
    &["diarrheicer"],
    &["diarrhoeicer"],
    &["diarrhoeicer"],
    &["diarrhoeicer"],
];

pub(crate) static ENTRY_DIARRHEICEST_14221151968572902300: VariantsMap = [
    &["diarrheicest"],
    &["diarrhoeicest"],
    &["diarrhoeicest"],
    &["diarrhoeicest"],
];

pub(crate) static ENTRY_DIARRHEIC_5406216762270560046: VariantsMap = [
    &["diarrheic"],
    &["diarrhoeic"],
    &["diarrhoeic"],
    &["diarrhoeic"],
];

pub(crate) static ENTRY_DIARRHETICER_8758731973889395817: VariantsMap = [
    &["diarrheticer"],
    &["diarrhoeticer"],
    &["diarrhoeticer"],
    &["diarrhoeticer"],
];

pub(crate) static ENTRY_DIARRHETICEST_7576238721431437280: VariantsMap = [
    &["diarrheticest"],
    &["diarrhoeticest"],
    &["diarrhoeticest"],
    &["diarrhoeticest"],
];

pub(crate) static ENTRY_DIARRHETIC_6608432625592653807: VariantsMap = [
    &["diarrhetic"],
    &["diarrhoetic"],
    &["diarrhoetic"],
    &["diarrhoetic"],
];

pub(crate) static ENTRY_DICHOTOMIZATIONS_11511794064634282366: VariantsMap = [
    &["dichotomizations"],
    &["dichotomisations"],
    &["dichotomizations"],
    &["dichotomisations"],
];

pub(crate) static ENTRY_DICHOTOMIZATION_14814468761822605666: VariantsMap = [
    &["dichotomization"],
    &["dichotomisation"],
    &["dichotomization"],
    &["dichotomisation"],
];

pub(crate) static ENTRY_DICHOTOMIZED_11469969501387954088: VariantsMap = [
    &["dichotomized"],
    &["dichotomised"],
    &["dichotomized"],
    &["dichotomised"],
];

pub(crate) static ENTRY_DICHOTOMIZES_9486969443354667350: VariantsMap = [
    &["dichotomizes"],
    &["dichotomises"],
    &["dichotomizes"],
    &["dichotomises"],
];

pub(crate) static ENTRY_DICHOTOMIZE_2536151466993014840: VariantsMap = [
    &["dichotomize"],
    &["dichotomise"],
    &["dichotomize"],
    &["dichotomise"],
];

pub(crate) static ENTRY_DICHOTOMIZING_6605468293502488075: VariantsMap = [
    &["dichotomizing"],
    &["dichotomising"],
    &["dichotomizing"],
    &["dichotomising"],
];

pub(crate) static ENTRY_DIENE_8393408286309594192: VariantsMap =
    [&["diene"], &["diaene"], &["diaene"], &["diaene"]];

pub(crate) static ENTRY_DIERETIC_13830183413584247379: VariantsMap = [
    &["dieretic"],
    &["diaeretic"],
    &["diaeretic"],
    &["diaeretic"],
];

pub(crate) static ENTRY_DIESELIZATIONS_14749287237278344971: VariantsMap = [
    &["dieselizations"],
    &["dieselisations"],
    &["dieselizations"],
    &["dieselisations"],
];

pub(crate) static ENTRY_DIESELIZATION_16989738541584421026: VariantsMap = [
    &["dieselization"],
    &["dieselisation"],
    &["dieselization"],
    &["dieselisation"],
];

pub(crate) static ENTRY_DIESELIZED_1396909342953338000: VariantsMap = [
    &["dieselized"],
    &["dieselised"],
    &["dieselized"],
    &["dieselised"],
];

pub(crate) static ENTRY_DIESELIZES_13977733140626156483: VariantsMap = [
    &["dieselizes"],
    &["dieselises"],
    &["dieselizes"],
    &["dieselises"],
];

pub(crate) static ENTRY_DIESELIZE_14819412399240860707: VariantsMap = [
    &["dieselize"],
    &["dieselise"],
    &["dieselize"],
    &["dieselise"],
];

pub(crate) static ENTRY_DIESELIZING_17476118384961942350: VariantsMap = [
    &["dieselizing"],
    &["dieselising"],
    &["dieselizing"],
    &["dieselising"],
];

pub(crate) static ENTRY_DIESTROUS_2649092910168728128: VariantsMap = [
    &["diestrous"],
    &["dioestrous"],
    &["dioestrous"],
    &["dioestrous"],
];

pub(crate) static ENTRY_DIESTRUAL_4297674653321861564: VariantsMap = [
    &["diestrual"],
    &["dioestrual"],
    &["dioestrual"],
    &["dioestrual"],
];

pub(crate) static ENTRY_DIESTRUM_5374513461214013606: VariantsMap = [
    &["diestrum"],
    &["dioestrum"],
    &["dioestrum"],
    &["dioestrum"],
];

pub(crate) static ENTRY_DIESTRUSES_551696630438157478: VariantsMap = [
    &["diestruses"],
    &["dioestruses"],
    &["dioestruses"],
    &["dioestruses"],
];

pub(crate) static ENTRY_DIESTRUS_10065397832891326590: VariantsMap = [
    &["diestrus"],
    &["dioestrus"],
    &["dioestrus"],
    &["dioestrus"],
];

pub(crate) static ENTRY_DIETHYLSTILBESTROL_1887150150156134254: VariantsMap = [
    &["diethylstilbestrol"],
    &["diethylstilboestrol"],
    &["diethylstilboestrol"],
    &["diethylstilboestrol"],
];

pub(crate) static ENTRY_DIFFERENTIALIZES_2900226538448132077: VariantsMap = [
    &["differentializes"],
    &["differentialises"],
    &["differentializes"],
    &["differentialises"],
];

pub(crate) static ENTRY_DIFFERENTIALIZE_16668562110152154633: VariantsMap = [
    &["differentialize"],
    &["differentialise"],
    &["differentialize"],
    &["differentialise"],
];

pub(crate) static ENTRY_DIGITALIZATIONS_7057163228044401005: VariantsMap = [
    &["digitalizations"],
    &["digitalisations"],
    &["digitalizations"],
    &["digitalisations"],
];

pub(crate) static ENTRY_DIGITALIZATION_5413639479952668184: VariantsMap = [
    &["digitalization"],
    &["digitalisation"],
    &["digitalization"],
    &["digitalisation"],
];

pub(crate) static ENTRY_DIGITALIZED_10368572290482312188: VariantsMap = [
    &["digitalized"],
    &["digitalised"],
    &["digitalized"],
    &["digitalised"],
];

pub(crate) static ENTRY_DIGITALIZES_14236944342236594070: VariantsMap = [
    &["digitalizes"],
    &["digitalises"],
    &["digitalizes"],
    &["digitalises"],
];

pub(crate) static ENTRY_DIGITALIZE_7792956770391756553: VariantsMap = [
    &["digitalize"],
    &["digitalise"],
    &["digitalize"],
    &["digitalise"],
];

pub(crate) static ENTRY_DIGITALIZING_5922141572600056524: VariantsMap = [
    &["digitalizing"],
    &["digitalising"],
    &["digitalizing"],
    &["digitalising"],
];

pub(crate) static ENTRY_DIGITIZATIONS_16897900325023989676: VariantsMap = [
    &["digitizations"],
    &["digitisations"],
    &["digitizations"],
    &["digitisations"],
];

pub(crate) static ENTRY_DIGITIZATION_17548895183926914542: VariantsMap = [
    &["digitization"],
    &["digitisation"],
    &["digitization"],
    &["digitisation"],
];

pub(crate) static ENTRY_DIGITIZED_18167407254586843848: VariantsMap = [
    &["digitized"],
    &["digitised"],
    &["digitized"],
    &["digitised"],
];

pub(crate) static ENTRY_DIGITIZERS_13411982289262402294: VariantsMap = [
    &["digitizers"],
    &["digitisers"],
    &["digitizers"],
    &["digitisers"],
];

pub(crate) static ENTRY_DIGITIZER_10090672409246281037: VariantsMap = [
    &["digitizer"],
    &["digitiser"],
    &["digitizer"],
    &["digitiser"],
];

pub(crate) static ENTRY_DIGITIZES_2690419763079826049: VariantsMap = [
    &["digitizes"],
    &["digitises"],
    &["digitizes"],
    &["digitises"],
];

pub(crate) static ENTRY_DIGITIZE_9662348846686188302: VariantsMap =
    [&["digitize"], &["digitise"], &["digitize"], &["digitise"]];

pub(crate) static ENTRY_DIGITIZING_14141099429643492961: VariantsMap = [
    &["digitizing"],
    &["digitising"],
    &["digitizing"],
    &["digitising"],
];

pub(crate) static ENTRY_DIMENSIONALIZATION_928272190267284990: VariantsMap = [
    &["dimensionalization"],
    &["dimensionalisation"],
    &["dimensionalization"],
    &["dimensionalisation"],
];

pub(crate) static ENTRY_DIMENSIONALIZED_7314101641422273330: VariantsMap = [
    &["dimensionalized"],
    &["dimensionalised"],
    &["dimensionalized"],
    &["dimensionalised"],
];

pub(crate) static ENTRY_DIMENSIONALIZES_8173757650577128994: VariantsMap = [
    &["dimensionalizes"],
    &["dimensionalises"],
    &["dimensionalizes"],
    &["dimensionalises"],
];

pub(crate) static ENTRY_DIMENSIONALIZE_17867138639749619838: VariantsMap = [
    &["dimensionalize"],
    &["dimensionalise"],
    &["dimensionalize"],
    &["dimensionalise"],
];

pub(crate) static ENTRY_DIMENSIONALIZING_5188710411327541644: VariantsMap = [
    &["dimensionalizing"],
    &["dimensionalising"],
    &["dimensionalizing"],
    &["dimensionalising"],
];

pub(crate) static ENTRY_DIMERIZATIONS_14028175985445569270: VariantsMap = [
    &["dimerizations"],
    &["dimerisations"],
    &["dimerizations"],
    &["dimerisations"],
];

pub(crate) static ENTRY_DIMERIZATION_15302035121240997222: VariantsMap = [
    &["dimerization"],
    &["dimerisation"],
    &["dimerization"],
    &["dimerisation"],
];

pub(crate) static ENTRY_DIMERIZED_15199320696227405238: VariantsMap = [
    &["dimerized"],
    &["dimerised"],
    &["dimerized"],
    &["dimerised"],
];

pub(crate) static ENTRY_DIMERIZES_1537628000711484411: VariantsMap = [
    &["dimerizes"],
    &["dimerises"],
    &["dimerizes"],
    &["dimerises"],
];

pub(crate) static ENTRY_DIMERIZE_16193073428737317522: VariantsMap =
    [&["dimerize"], &["dimerise"], &["dimerize"], &["dimerise"]];

pub(crate) static ENTRY_DIMERIZING_14292842827296885678: VariantsMap = [
    &["dimerizing"],
    &["dimerising"],
    &["dimerizing"],
    &["dimerising"],
];

pub(crate) static ENTRY_DIMINUTIVIZES_340938279453222908: VariantsMap = [
    &["diminutivizes"],
    &["diminutivises"],
    &["diminutivizes"],
    &["diminutivises"],
];

pub(crate) static ENTRY_DIMINUTIVIZE_8157805496969771537: VariantsMap = [
    &["diminutivize"],
    &["diminutivise"],
    &["diminutivize"],
    &["diminutivise"],
];

pub(crate) static ENTRY_DIOECIOUSLY_10693807285796274184: VariantsMap = [
    &["dioeciously"],
    &["dioeciously"],
    &["dioeciously"],
    &["dioeciously"],
];

pub(crate) static ENTRY_DIOECIOUS_421155846144149881: VariantsMap = [
    &["dioecious"],
    &["dioecious"],
    &["dioecious"],
    &["dioecious"],
];

pub(crate) static ENTRY_DIONIZE_5302013842773672496: VariantsMap =
    [&["dionize"], &["dionise"], &["dionize"], &["dionise"]];

pub(crate) static ENTRY_DIOPTERS_516947549353623981: VariantsMap =
    [&["diopters"], &["dioptres"], &["dioptres"], &["dioptres"]];

pub(crate) static ENTRY_DIOPTER_10363011140557994074: VariantsMap =
    [&["diopter"], &["dioptre"], &["dioptre"], &["dioptre"]];

pub(crate) static ENTRY_DIPHTHONGIZATIONS_3965346305488551771: VariantsMap = [
    &["diphthongizations"],
    &["diphthongisations"],
    &["diphthongizations"],
    &["diphthongisations"],
];

pub(crate) static ENTRY_DIPHTHONGIZATION_4888277953337569133: VariantsMap = [
    &["diphthongization"],
    &["diphthongisation"],
    &["diphthongization"],
    &["diphthongisation"],
];

pub(crate) static ENTRY_DIPHTHONGIZED_7607687267591459487: VariantsMap = [
    &["diphthongized"],
    &["diphthongised"],
    &["diphthongized"],
    &["diphthongised"],
];

pub(crate) static ENTRY_DIPHTHONGIZES_9976473308769011757: VariantsMap = [
    &["diphthongizes"],
    &["diphthongises"],
    &["diphthongizes"],
    &["diphthongises"],
];

pub(crate) static ENTRY_DIPHTHONGIZE_12838588614712725416: VariantsMap = [
    &["diphthongize"],
    &["diphthongise"],
    &["diphthongize"],
    &["diphthongise"],
];

pub(crate) static ENTRY_DIPHTHONGIZING_9367101143579778156: VariantsMap = [
    &["diphthongizing"],
    &["diphthongising"],
    &["diphthongizing"],
    &["diphthongising"],
];

pub(crate) static ENTRY_DIPLE_3376459421960689495: VariantsMap =
    [&["diple"], &["diploe"], &["diploe"], &["diploe"]];

pub(crate) static ENTRY_DIPLOE_5571525081319448833: VariantsMap =
    [&["diploe"], &["diploae"], &["diploae"], &["diploae"]];

pub(crate) static ENTRY_DIPLOMATIZED_18386252538878346892: VariantsMap = [
    &["diplomatized"],
    &["diplomatised"],
    &["diplomatized"],
    &["diplomatised"],
];

pub(crate) static ENTRY_DIPLOMATIZES_17976479831103709392: VariantsMap = [
    &["diplomatizes"],
    &["diplomatises"],
    &["diplomatizes"],
    &["diplomatises"],
];

pub(crate) static ENTRY_DIPLOMATIZE_8810012624009252945: VariantsMap = [
    &["diplomatize"],
    &["diplomatise"],
    &["diplomatize"],
    &["diplomatise"],
];

pub(crate) static ENTRY_DIPLOMATIZING_10466832182528029316: VariantsMap = [
    &["diplomatizing"],
    &["diplomatising"],
    &["diplomatizing"],
    &["diplomatising"],
];

pub(crate) static ENTRY_DISANGULARIZES_4645387961020197923: VariantsMap = [
    &["disangularizes"],
    &["disangularises"],
    &["disangularizes"],
    &["disangularises"],
];

pub(crate) static ENTRY_DISANGULARIZE_15234154485855761347: VariantsMap = [
    &["disangularize"],
    &["disangularise"],
    &["disangularize"],
    &["disangularise"],
];

pub(crate) static ENTRY_DISAUTHORIZED_15149050577902575232: VariantsMap = [
    &["disauthorized"],
    &["disauthorised"],
    &["disauthorized"],
    &["disauthorised"],
];

pub(crate) static ENTRY_DISAUTHORIZES_16971580585403699509: VariantsMap = [
    &["disauthorizes"],
    &["disauthorises"],
    &["disauthorizes"],
    &["disauthorises"],
];

pub(crate) static ENTRY_DISAUTHORIZE_9729193059512637993: VariantsMap = [
    &["disauthorize"],
    &["disauthorise"],
    &["disauthorize"],
    &["disauthorise"],
];

pub(crate) static ENTRY_DISAUTHORIZING_1506123926769301204: VariantsMap = [
    &["disauthorizing"],
    &["disauthorising"],
    &["disauthorizing"],
    &["disauthorising"],
];

pub(crate) static ENTRY_DISBOWELED_8124420063056832999: VariantsMap = [
    &["disboweled"],
    &["disbowelled"],
    &["disbowelled"],
    &["disbowelled"],
];

pub(crate) static ENTRY_DISBOWELING_14146470427022244483: VariantsMap = [
    &["disboweling"],
    &["disbowelling"],
    &["disbowelling"],
    &["disbowelling"],
];

pub(crate) static ENTRY_DISCANONIZATIONS_714613792349570061: VariantsMap = [
    &["discanonizations"],
    &["discanonisations"],
    &["discanonizations"],
    &["discanonisations"],
];

pub(crate) static ENTRY_DISCANONIZATION_9504497596950273772: VariantsMap = [
    &["discanonization"],
    &["discanonisation"],
    &["discanonization"],
    &["discanonisation"],
];

pub(crate) static ENTRY_DISCANONIZES_7404724245545428484: VariantsMap = [
    &["discanonizes"],
    &["discanonises"],
    &["discanonizes"],
    &["discanonises"],
];

pub(crate) static ENTRY_DISCANONIZE_10059279715015590378: VariantsMap = [
    &["discanonize"],
    &["discanonise"],
    &["discanonize"],
    &["discanonise"],
];

pub(crate) static ENTRY_DISCOLORATED_9751918465389903770: VariantsMap = [
    &["discolorated"],
    &["discolourated"],
    &["discolourated"],
    &["discolourated"],
];

pub(crate) static ENTRY_DISCOLORATE_17525488967185123450: VariantsMap = [
    &["discolorate"],
    &["discolourate"],
    &["discolourate"],
    &["discolourate"],
];

pub(crate) static ENTRY_DISCOLORATIONS_161368754086315692: VariantsMap = [
    &["discolorations"],
    &["discolorations", "discolourations"],
    &["discolorations"],
    &["discolorations", "discolourations"],
];

pub(crate) static ENTRY_DISCOLORATION_14169998051189645771: VariantsMap = [
    &["discoloration"],
    &["discoloration", "discolouration"],
    &["discoloration"],
    &["discoloration", "discolouration"],
];

pub(crate) static ENTRY_DISCOLOREDNESS_6651369091187102535: VariantsMap = [
    &["discoloredness"],
    &["discolouredness"],
    &["discolouredness"],
    &["discolouredness"],
];

pub(crate) static ENTRY_DISCOLOREDS_2390131969640640898: VariantsMap = [
    &["discoloreds"],
    &["discoloureds"],
    &["discoloureds"],
    &["discoloureds"],
];

pub(crate) static ENTRY_DISCOLORED_11781061950619883476: VariantsMap = [
    &["discolored"],
    &["discoloured"],
    &["discoloured"],
    &["discoloured"],
];

pub(crate) static ENTRY_DISCOLORING_2630857377151306278: VariantsMap = [
    &["discoloring"],
    &["discolouring"],
    &["discolouring"],
    &["discolouring"],
];

pub(crate) static ENTRY_DISCOLORIZATIONS_14292400843926128979: VariantsMap = [
    &["discolorizations"],
    &["discolourisations"],
    &["discolourizations"],
    &["discolourisations"],
];

pub(crate) static ENTRY_DISCOLORIZATION_1561449986421291790: VariantsMap = [
    &["discolorization"],
    &["discolourisation"],
    &["discolourization"],
    &["discolourisation"],
];

pub(crate) static ENTRY_DISCOLORMENTS_11818433310186389225: VariantsMap = [
    &["discolorments"],
    &["discolourments"],
    &["discolourments"],
    &["discolourments"],
];

pub(crate) static ENTRY_DISCOLORMENT_14928622858833795102: VariantsMap = [
    &["discolorment"],
    &["discolourment"],
    &["discolourment"],
    &["discolourment"],
];

pub(crate) static ENTRY_DISCOLORS_5612202091276496972: VariantsMap = [
    &["discolors"],
    &["discolours"],
    &["discolours"],
    &["discolours"],
];

pub(crate) static ENTRY_DISCOLOR_5229997782497228003: VariantsMap = [
    &["discolor"],
    &["discolour"],
    &["discolour"],
    &["discolour"],
];

pub(crate) static ENTRY_DISCRETIZATION_12744800183024300851: VariantsMap = [
    &["discretization"],
    &["discretisation"],
    &["discretization"],
    &["discretisation"],
];

pub(crate) static ENTRY_DISCRETIZE_5822871996560826075: VariantsMap = [
    &["discretize"],
    &["discretise"],
    &["discretize"],
    &["discretise"],
];

pub(crate) static ENTRY_DISDENOMINATIONALIZES_12397562771885821092: VariantsMap = [
    &["disdenominationalizes"],
    &["disdenominationalises"],
    &["disdenominationalizes"],
    &["disdenominationalises"],
];

pub(crate) static ENTRY_DISDENOMINATIONALIZE_535012825291404497: VariantsMap = [
    &["disdenominationalize"],
    &["disdenominationalise"],
    &["disdenominationalize"],
    &["disdenominationalise"],
];

pub(crate) static ENTRY_DISDIPLOMATIZES_4891957747419116479: VariantsMap = [
    &["disdiplomatizes"],
    &["disdiplomatises"],
    &["disdiplomatizes"],
    &["disdiplomatises"],
];

pub(crate) static ENTRY_DISDIPLOMATIZE_885764438051293853: VariantsMap = [
    &["disdiplomatize"],
    &["disdiplomatise"],
    &["disdiplomatize"],
    &["disdiplomatise"],
];

pub(crate) static ENTRY_DISEMBOWELED_10970335018373428342: VariantsMap = [
    &["disemboweled"],
    &["disembowelled"],
    &["disembowelled"],
    &["disembowelled"],
];

pub(crate) static ENTRY_DISEMBOWELING_1397333253900455739: VariantsMap = [
    &["disemboweling"],
    &["disembowelling"],
    &["disembowelling"],
    &["disembowelling"],
];

pub(crate) static ENTRY_DISEQUALIZERS_17092206736491516096: VariantsMap = [
    &["disequalizers"],
    &["disequalisers"],
    &["disequalizers"],
    &["disequalisers"],
];

pub(crate) static ENTRY_DISEQUALIZER_15153684888095615538: VariantsMap = [
    &["disequalizer"],
    &["disequaliser"],
    &["disequalizer"],
    &["disequaliser"],
];

pub(crate) static ENTRY_DISEQUALIZES_7417403436798093715: VariantsMap = [
    &["disequalizes"],
    &["disequalises"],
    &["disequalizes"],
    &["disequalises"],
];

pub(crate) static ENTRY_DISEQUALIZE_2351244429763172565: VariantsMap = [
    &["disequalize"],
    &["disequalise"],
    &["disequalize"],
    &["disequalise"],
];

pub(crate) static ENTRY_DISFAVORED_4040006339995038210: VariantsMap = [
    &["disfavored"],
    &["disfavoured"],
    &["disfavoured"],
    &["disfavoured"],
];

pub(crate) static ENTRY_DISFAVORERS_18430656322920499015: VariantsMap = [
    &["disfavorers"],
    &["disfavourers"],
    &["disfavourers"],
    &["disfavourers"],
];

pub(crate) static ENTRY_DISFAVORER_10571638081997401701: VariantsMap = [
    &["disfavorer"],
    &["disfavourer"],
    &["disfavourer"],
    &["disfavourer"],
];

pub(crate) static ENTRY_DISFAVORING_16851499602444812970: VariantsMap = [
    &["disfavoring"],
    &["disfavouring"],
    &["disfavouring"],
    &["disfavouring"],
];

pub(crate) static ENTRY_DISFAVORS_15834201467329633407: VariantsMap = [
    &["disfavors"],
    &["disfavours"],
    &["disfavours"],
    &["disfavours"],
];

pub(crate) static ENTRY_DISFAVOR_10548525794143920697: VariantsMap = [
    &["disfavor"],
    &["disfavour"],
    &["disfavour"],
    &["disfavour"],
];

pub(crate) static ENTRY_DISHARMONIZED_4901310729391279975: VariantsMap = [
    &["disharmonized"],
    &["disharmonised"],
    &["disharmonized"],
    &["disharmonised"],
];

pub(crate) static ENTRY_DISHARMONIZES_6597311294304545400: VariantsMap = [
    &["disharmonizes"],
    &["disharmonises"],
    &["disharmonizes"],
    &["disharmonises"],
];

pub(crate) static ENTRY_DISHARMONIZE_14492960974540093828: VariantsMap = [
    &["disharmonize"],
    &["disharmonise"],
    &["disharmonize"],
    &["disharmonise"],
];

pub(crate) static ENTRY_DISHARMONIZING_15220607346038133749: VariantsMap = [
    &["disharmonizing"],
    &["disharmonising"],
    &["disharmonizing"],
    &["disharmonising"],
];

pub(crate) static ENTRY_DISHEVELED_4439055663190726624: VariantsMap = [
    &["disheveled"],
    &["dishevelled"],
    &["dishevelled"],
    &["dishevelled"],
];

pub(crate) static ENTRY_DISHEVELER_8621924881071797327: VariantsMap = [
    &["disheveler"],
    &["disheveller"],
    &["disheveller"],
    &["disheveller"],
];

pub(crate) static ENTRY_DISHEVELING_10590618683250803788: VariantsMap = [
    &["disheveling"],
    &["dishevelling"],
    &["dishevelling"],
    &["dishevelling"],
];

pub(crate) static ENTRY_DISHONORABLENESSES_11979409559133838321: VariantsMap = [
    &["dishonorablenesses"],
    &["dishonourablenesses"],
    &["dishonourablenesses"],
    &["dishonourablenesses"],
];

pub(crate) static ENTRY_DISHONORABLENESS_10647077411353658138: VariantsMap = [
    &["dishonorableness"],
    &["dishonourableness"],
    &["dishonourableness"],
    &["dishonourableness"],
];

pub(crate) static ENTRY_DISHONORABLER_3043788293690199279: VariantsMap = [
    &["dishonorabler"],
    &["dishonourabler"],
    &["dishonourabler"],
    &["dishonourabler"],
];

pub(crate) static ENTRY_DISHONORABLEST_3928567236277526991: VariantsMap = [
    &["dishonorablest"],
    &["dishonourablest"],
    &["dishonourablest"],
    &["dishonourablest"],
];

pub(crate) static ENTRY_DISHONORABLES_9899266461697606508: VariantsMap = [
    &["dishonorables"],
    &["dishonourables"],
    &["dishonourables"],
    &["dishonourables"],
];

pub(crate) static ENTRY_DISHONORABLE_6906558183452633549: VariantsMap = [
    &["dishonorable"],
    &["dishonourable"],
    &["dishonourable"],
    &["dishonourable"],
];

pub(crate) static ENTRY_DISHONORABLIER_8450606157745671431: VariantsMap = [
    &["dishonorablier"],
    &["dishonourablier"],
    &["dishonourablier"],
    &["dishonourablier"],
];

pub(crate) static ENTRY_DISHONORABLIEST_12463634118581290321: VariantsMap = [
    &["dishonorabliest"],
    &["dishonourabliest"],
    &["dishonourabliest"],
    &["dishonourabliest"],
];

pub(crate) static ENTRY_DISHONORABLIES_14942803523606691356: VariantsMap = [
    &["dishonorablies"],
    &["dishonourablies"],
    &["dishonourablies"],
    &["dishonourablies"],
];

pub(crate) static ENTRY_DISHONORABLY_16389408757341415026: VariantsMap = [
    &["dishonorably"],
    &["dishonourably"],
    &["dishonourably"],
    &["dishonourably"],
];

pub(crate) static ENTRY_DISHONORARY_7185175374757498337: VariantsMap = [
    &["dishonorary"],
    &["dishonourary"],
    &["dishonourary"],
    &["dishonourary"],
];

pub(crate) static ENTRY_DISHONORED_1979408375344629609: VariantsMap = [
    &["dishonored"],
    &["dishonoured"],
    &["dishonoured"],
    &["dishonoured"],
];

pub(crate) static ENTRY_DISHONORERS_16218792927597703675: VariantsMap = [
    &["dishonorers"],
    &["dishonourers"],
    &["dishonourers"],
    &["dishonourers"],
];

pub(crate) static ENTRY_DISHONORER_11600072711097852356: VariantsMap = [
    &["dishonorer"],
    &["dishonourer"],
    &["dishonourer"],
    &["dishonourer"],
];

pub(crate) static ENTRY_DISHONORING_16122094070164850675: VariantsMap = [
    &["dishonoring"],
    &["dishonouring"],
    &["dishonouring"],
    &["dishonouring"],
];

pub(crate) static ENTRY_DISHONORS_5828073138827677548: VariantsMap = [
    &["dishonors"],
    &["dishonours"],
    &["dishonours"],
    &["dishonours"],
];

pub(crate) static ENTRY_DISHONOR_16058760573294695856: VariantsMap = [
    &["dishonor"],
    &["dishonour"],
    &["dishonour"],
    &["dishonour"],
];

pub(crate) static ENTRY_DISHUMANIZES_11017789745964682172: VariantsMap = [
    &["dishumanizes"],
    &["dishumanises"],
    &["dishumanizes"],
    &["dishumanises"],
];

pub(crate) static ENTRY_DISHUMANIZE_2097256647850275480: VariantsMap = [
    &["dishumanize"],
    &["dishumanise"],
    &["dishumanize"],
    &["dishumanise"],
];

pub(crate) static ENTRY_DISHUMORED_2383879622247462959: VariantsMap = [
    &["dishumored"],
    &["dishumoured"],
    &["dishumoured"],
    &["dishumoured"],
];

pub(crate) static ENTRY_DISHUMORS_4122248585102919920: VariantsMap = [
    &["dishumors"],
    &["dishumours"],
    &["dishumours"],
    &["dishumours"],
];

pub(crate) static ENTRY_DISHUMOR_17351796049135318401: VariantsMap = [
    &["dishumor"],
    &["dishumour"],
    &["dishumour"],
    &["dishumour"],
];

pub(crate) static ENTRY_DISILLUSIONIZED_9985249129164082054: VariantsMap = [
    &["disillusionized"],
    &["disillusionised"],
    &["disillusionized"],
    &["disillusionised"],
];

pub(crate) static ENTRY_DISILLUSIONIZERS_3528478054985367590: VariantsMap = [
    &["disillusionizers"],
    &["disillusionisers"],
    &["disillusionizers"],
    &["disillusionisers"],
];

pub(crate) static ENTRY_DISILLUSIONIZER_7747439668540485853: VariantsMap = [
    &["disillusionizer"],
    &["disillusioniser"],
    &["disillusionizer"],
    &["disillusioniser"],
];

pub(crate) static ENTRY_DISILLUSIONIZES_12240679786185783886: VariantsMap = [
    &["disillusionizes"],
    &["disillusionises"],
    &["disillusionizes"],
    &["disillusionises"],
];

pub(crate) static ENTRY_DISILLUSIONIZE_6725876315510879655: VariantsMap = [
    &["disillusionize"],
    &["disillusionise"],
    &["disillusionize"],
    &["disillusionise"],
];

pub(crate) static ENTRY_DISILLUSIONIZING_7223559157676347916: VariantsMap = [
    &["disillusionizing"],
    &["disillusionising"],
    &["disillusionizing"],
    &["disillusionising"],
];

pub(crate) static ENTRY_DISINDIVIDUALIZED_2490609976879253784: VariantsMap = [
    &["disindividualized"],
    &["disindividualised"],
    &["disindividualized"],
    &["disindividualised"],
];

pub(crate) static ENTRY_DISINDIVIDUALIZES_3078349844192054680: VariantsMap = [
    &["disindividualizes"],
    &["disindividualises"],
    &["disindividualizes"],
    &["disindividualises"],
];

pub(crate) static ENTRY_DISINDIVIDUALIZE_5618805340357401608: VariantsMap = [
    &["disindividualize"],
    &["disindividualise"],
    &["disindividualize"],
    &["disindividualise"],
];

pub(crate) static ENTRY_DISINDIVIDUALIZING_6461619562502650122: VariantsMap = [
    &["disindividualizing"],
    &["disindividualising"],
    &["disindividualizing"],
    &["disindividualising"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZATIONS_12474625419721941228: VariantsMap = [
    &["disindustrializations"],
    &["disindustrialisations"],
    &["disindustrializations"],
    &["disindustrialisations"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZATION_11631925405929512766: VariantsMap = [
    &["disindustrialization"],
    &["disindustrialisation"],
    &["disindustrialization"],
    &["disindustrialisation"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZED_9116894414125815191: VariantsMap = [
    &["disindustrialized"],
    &["disindustrialised"],
    &["disindustrialized"],
    &["disindustrialised"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZES_11775441929762490304: VariantsMap = [
    &["disindustrializes"],
    &["disindustrialises"],
    &["disindustrializes"],
    &["disindustrialises"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZE_11677234080103658662: VariantsMap = [
    &["disindustrialize"],
    &["disindustrialise"],
    &["disindustrialize"],
    &["disindustrialise"],
];

pub(crate) static ENTRY_DISINDUSTRIALIZING_11227038092400551095: VariantsMap = [
    &["disindustrializing"],
    &["disindustrialising"],
    &["disindustrializing"],
    &["disindustrialising"],
];

pub(crate) static ENTRY_DISLUSTER_17318159058933817750: VariantsMap = [
    &["disluster"],
    &["dislustre"],
    &["dislustre"],
    &["dislustre"],
];

pub(crate) static ENTRY_DISMALIZES_15353135750014042755: VariantsMap = [
    &["dismalizes"],
    &["dismalises"],
    &["dismalizes"],
    &["dismalises"],
];

pub(crate) static ENTRY_DISMALIZE_10250151666987366777: VariantsMap = [
    &["dismalize"],
    &["dismalise"],
    &["dismalize"],
    &["dismalise"],
];

pub(crate) static ENTRY_DISNATURALIZATIONS_10342585743158502872: VariantsMap = [
    &["disnaturalizations"],
    &["disnaturalisations"],
    &["disnaturalizations"],
    &["disnaturalisations"],
];

pub(crate) static ENTRY_DISNATURALIZATION_11670344026850361488: VariantsMap = [
    &["disnaturalization"],
    &["disnaturalisation"],
    &["disnaturalization"],
    &["disnaturalisation"],
];

pub(crate) static ENTRY_DISNATURALIZED_5916107255821231797: VariantsMap = [
    &["disnaturalized"],
    &["disnaturalised"],
    &["disnaturalized"],
    &["disnaturalised"],
];

pub(crate) static ENTRY_DISNATURALIZES_559626355389259758: VariantsMap = [
    &["disnaturalizes"],
    &["disnaturalises"],
    &["disnaturalizes"],
    &["disnaturalises"],
];

pub(crate) static ENTRY_DISNATURALIZE_12307126110445937749: VariantsMap = [
    &["disnaturalize"],
    &["disnaturalise"],
    &["disnaturalize"],
    &["disnaturalise"],
];

pub(crate) static ENTRY_DISNATURALIZING_797893369591768933: VariantsMap = [
    &["disnaturalizing"],
    &["disnaturalising"],
    &["disnaturalizing"],
    &["disnaturalising"],
];

pub(crate) static ENTRY_DISORGANIZATIONS_14738569434179616840: VariantsMap = [
    &["disorganizations"],
    &["disorganisations"],
    &["disorganizations"],
    &["disorganisations"],
];

pub(crate) static ENTRY_DISORGANIZATION_16905278515917730708: VariantsMap = [
    &["disorganization"],
    &["disorganisation"],
    &["disorganization"],
    &["disorganisation"],
];

pub(crate) static ENTRY_DISORGANIZED_16082182829150319317: VariantsMap = [
    &["disorganized"],
    &["disorganised"],
    &["disorganized"],
    &["disorganised"],
];

pub(crate) static ENTRY_DISORGANIZERS_3700614044173779869: VariantsMap = [
    &["disorganizers"],
    &["disorganisers"],
    &["disorganizers"],
    &["disorganisers"],
];

pub(crate) static ENTRY_DISORGANIZER_13968612653185254007: VariantsMap = [
    &["disorganizer"],
    &["disorganiser"],
    &["disorganizer"],
    &["disorganiser"],
];

pub(crate) static ENTRY_DISORGANIZES_3148142030701826514: VariantsMap = [
    &["disorganizes"],
    &["disorganises"],
    &["disorganizes"],
    &["disorganises"],
];

pub(crate) static ENTRY_DISORGANIZE_11143780718836315842: VariantsMap = [
    &["disorganize"],
    &["disorganise"],
    &["disorganize"],
    &["disorganise"],
];

pub(crate) static ENTRY_DISORGANIZING_3512715266110397978: VariantsMap = [
    &["disorganizing"],
    &["disorganising"],
    &["disorganizing"],
    &["disorganising"],
];

pub(crate) static ENTRY_DISOZONIZES_12107113608008991830: VariantsMap = [
    &["disozonizes"],
    &["disozonises"],
    &["disozonizes"],
    &["disozonises"],
];

pub(crate) static ENTRY_DISOZONIZE_14151388182315461753: VariantsMap = [
    &["disozonize"],
    &["disozonise"],
    &["disozonize"],
    &["disozonise"],
];

pub(crate) static ENTRY_DISPAPALIZES_15889961525847775881: VariantsMap = [
    &["dispapalizes"],
    &["dispapalises"],
    &["dispapalizes"],
    &["dispapalises"],
];

pub(crate) static ENTRY_DISPAPALIZE_13165058594407425203: VariantsMap = [
    &["dispapalize"],
    &["dispapalise"],
    &["dispapalize"],
    &["dispapalise"],
];

pub(crate) static ENTRY_DISPATCHED_15382141028599285955: VariantsMap = [
    &["dispatched"],
    &["dispatched"],
    &["dispatched"],
    &["dispatched"],
];

pub(crate) static ENTRY_DISPATCHES_13572237410774142362: VariantsMap = [
    &["dispatches"],
    &["dispatches"],
    &["dispatches"],
    &["dispatches"],
];

pub(crate) static ENTRY_DISPATCHING_13590867743632657867: VariantsMap = [
    &["dispatching"],
    &["dispatching"],
    &["dispatching"],
    &["dispatching"],
];

pub(crate) static ENTRY_DISPATCH_4830799078943953115: VariantsMap =
    [&["dispatch"], &["dispatch"], &["dispatch"], &["dispatch"]];

pub(crate) static ENTRY_DISPAUPERIZED_12650677804830175257: VariantsMap = [
    &["dispauperized"],
    &["dispauperised"],
    &["dispauperized"],
    &["dispauperised"],
];

pub(crate) static ENTRY_DISPAUPERIZES_12194191945308397437: VariantsMap = [
    &["dispauperizes"],
    &["dispauperises"],
    &["dispauperizes"],
    &["dispauperises"],
];

pub(crate) static ENTRY_DISPAUPERIZE_4660569275468440176: VariantsMap = [
    &["dispauperize"],
    &["dispauperise"],
    &["dispauperize"],
    &["dispauperise"],
];

pub(crate) static ENTRY_DISPAUPERIZING_17043875401453982735: VariantsMap = [
    &["dispauperizing"],
    &["dispauperising"],
    &["dispauperizing"],
    &["dispauperising"],
];

pub(crate) static ENTRY_DISPERSONALIZES_16334720714201751331: VariantsMap = [
    &["dispersonalizes"],
    &["dispersonalises"],
    &["dispersonalizes"],
    &["dispersonalises"],
];

pub(crate) static ENTRY_DISPERSONALIZE_6396828987917605190: VariantsMap = [
    &["dispersonalize"],
    &["dispersonalise"],
    &["dispersonalize"],
    &["dispersonalise"],
];

pub(crate) static ENTRY_DISPOPULARIZES_3346222683675559134: VariantsMap = [
    &["dispopularizes"],
    &["dispopularises"],
    &["dispopularizes"],
    &["dispopularises"],
];

pub(crate) static ENTRY_DISPOPULARIZE_6744315358378905582: VariantsMap = [
    &["dispopularize"],
    &["dispopularise"],
    &["dispopularize"],
    &["dispopularise"],
];

pub(crate) static ENTRY_DISREALIZES_7034995371229494339: VariantsMap = [
    &["disrealizes"],
    &["disrealises"],
    &["disrealizes"],
    &["disrealises"],
];

pub(crate) static ENTRY_DISREALIZE_6886884802512895754: VariantsMap = [
    &["disrealize"],
    &["disrealise"],
    &["disrealize"],
    &["disrealise"],
];

pub(crate) static ENTRY_DISSCEPTERS_8501541001325274567: VariantsMap = [
    &["disscepters"],
    &["dissceptres"],
    &["dissceptres"],
    &["dissceptres"],
];

pub(crate) static ENTRY_DISSCEPTER_9219896270222345750: VariantsMap = [
    &["disscepter"],
    &["dissceptre"],
    &["dissceptre"],
    &["dissceptre"],
];

pub(crate) static ENTRY_DISSEIZED_9143200265660844579: VariantsMap = [
    &["disseized"],
    &["disseised"],
    &["disseized"],
    &["disseised"],
];

pub(crate) static ENTRY_DISSEIZEE_10324450713845414018: VariantsMap = [
    &["disseizee"],
    &["disseisee"],
    &["disseizee"],
    &["disseisee"],
];

pub(crate) static ENTRY_DISSEIZES_2475038653439253891: VariantsMap = [
    &["disseizes"],
    &["disseises"],
    &["disseizes"],
    &["disseises"],
];

pub(crate) static ENTRY_DISSEIZE_2220027749090213580: VariantsMap =
    [&["disseize"], &["disseise"], &["disseize"], &["disseise"]];

pub(crate) static ENTRY_DISSEIZING_10817480248875018424: VariantsMap = [
    &["disseizing"],
    &["disseising"],
    &["disseizing"],
    &["disseising"],
];

pub(crate) static ENTRY_DISSEIZINS_9611939215700895786: VariantsMap = [
    &["disseizins"],
    &["disseisins"],
    &["disseisins"],
    &["disseisins"],
];

pub(crate) static ENTRY_DISSEIZIN_14782548980677684377: VariantsMap = [
    &["disseizin"],
    &["disseisin"],
    &["disseisin"],
    &["disseisin"],
];

pub(crate) static ENTRY_DISSEIZORS_6099442410087886972: VariantsMap = [
    &["disseizors"],
    &["disseisors"],
    &["disseisors"],
    &["disseisors"],
];

pub(crate) static ENTRY_DISSEIZOR_13887745959308891534: VariantsMap = [
    &["disseizor"],
    &["disseisor"],
    &["disseisor"],
    &["disseisor"],
];

pub(crate) static ENTRY_DISSENSUALIZES_10730088086704898161: VariantsMap = [
    &["dissensualizes"],
    &["dissensualises"],
    &["dissensualizes"],
    &["dissensualises"],
];

pub(crate) static ENTRY_DISSENSUALIZE_6621544703464419271: VariantsMap = [
    &["dissensualize"],
    &["dissensualise"],
    &["dissensualize"],
    &["dissensualise"],
];

pub(crate) static ENTRY_DISSOCIALIZED_948976280000356279: VariantsMap = [
    &["dissocialized"],
    &["dissocialised"],
    &["dissocialized"],
    &["dissocialised"],
];

pub(crate) static ENTRY_DISSOCIALIZES_15997318284457012428: VariantsMap = [
    &["dissocializes"],
    &["dissocialises"],
    &["dissocializes"],
    &["dissocialises"],
];

pub(crate) static ENTRY_DISSOCIALIZE_15635530793606336711: VariantsMap = [
    &["dissocialize"],
    &["dissocialise"],
    &["dissocialize"],
    &["dissocialise"],
];

pub(crate) static ENTRY_DISSOCIALIZING_6928297824228630438: VariantsMap = [
    &["dissocializing"],
    &["dissocialising"],
    &["dissocializing"],
    &["dissocialising"],
];

pub(crate) static ENTRY_DISSYLLABIZED_17425272029213608821: VariantsMap = [
    &["dissyllabized"],
    &["dissyllabised"],
    &["dissyllabized"],
    &["dissyllabised"],
];

pub(crate) static ENTRY_DISSYLLABIZE_10272862471065893703: VariantsMap = [
    &["dissyllabize"],
    &["dissyllabise"],
    &["dissyllabize"],
    &["dissyllabise"],
];

pub(crate) static ENTRY_DISSYLLABIZING_7453400268342543405: VariantsMap = [
    &["dissyllabizing"],
    &["dissyllabising"],
    &["dissyllabizing"],
    &["dissyllabising"],
];

pub(crate) static ENTRY_DISSYMPATHIZES_11030202988485089450: VariantsMap = [
    &["dissympathizes"],
    &["dissympathises"],
    &["dissympathizes"],
    &["dissympathises"],
];

pub(crate) static ENTRY_DISSYMPATHIZE_4993319775705622084: VariantsMap = [
    &["dissympathize"],
    &["dissympathise"],
    &["dissympathize"],
    &["dissympathise"],
];

pub(crate) static ENTRY_DISTILLS_2389426309220426558: VariantsMap =
    [&["distills"], &["distils"], &["distills"], &["distils"]];

pub(crate) static ENTRY_DISTILL_15657274320458397213: VariantsMap =
    [&["distill"], &["distil"], &["distill"], &["distil"]];

pub(crate) static ENTRY_DISUTILIZES_8581123670870213073: VariantsMap = [
    &["disutilizes"],
    &["disutilises"],
    &["disutilizes"],
    &["disutilises"],
];

pub(crate) static ENTRY_DISUTILIZE_10973235722650343703: VariantsMap = [
    &["disutilize"],
    &["disutilise"],
    &["disutilize"],
    &["disutilise"],
];

pub(crate) static ENTRY_DIVERSICOLORED_651357966110994775: VariantsMap = [
    &["diversicolored"],
    &["diversicoloured"],
    &["diversicoloured"],
    &["diversicoloured"],
];

pub(crate) static ENTRY_DIVINISTER_6065276535238492048: VariantsMap = [
    &["divinister"],
    &["divinistre"],
    &["divinistre"],
    &["divinistre"],
];

pub(crate) static ENTRY_DIVINIZATIONS_4602312198214871584: VariantsMap = [
    &["divinizations"],
    &["divinisations"],
    &["divinizations"],
    &["divinisations"],
];

pub(crate) static ENTRY_DIVINIZATION_8790430811943080539: VariantsMap = [
    &["divinization"],
    &["divinisation"],
    &["divinization"],
    &["divinisation"],
];

pub(crate) static ENTRY_DIVINIZED_7849256710429601444: VariantsMap = [
    &["divinized"],
    &["divinised"],
    &["divinized"],
    &["divinised"],
];

pub(crate) static ENTRY_DIVINIZES_2478647172593491088: VariantsMap = [
    &["divinizes"],
    &["divinises"],
    &["divinizes"],
    &["divinises"],
];

pub(crate) static ENTRY_DIVINIZE_15517841088563999430: VariantsMap =
    [&["divinize"], &["divinise"], &["divinize"], &["divinise"]];

pub(crate) static ENTRY_DIVINIZING_3663245257392927615: VariantsMap = [
    &["divinizing"],
    &["divinising"],
    &["divinizing"],
    &["divinising"],
];

pub(crate) static ENTRY_DIVISIONALIZATIONS_5100962745240087520: VariantsMap = [
    &["divisionalizations"],
    &["divisionalisations"],
    &["divisionalizations"],
    &["divisionalisations"],
];

pub(crate) static ENTRY_DIVISIONALIZATION_12097639934213939942: VariantsMap = [
    &["divisionalization"],
    &["divisionalisation"],
    &["divisionalization"],
    &["divisionalisation"],
];

pub(crate) static ENTRY_DOCETE_9982236132390447888: VariantsMap =
    [&["docete"], &["docetae"], &["docetae"], &["docetae"]];

pub(crate) static ENTRY_DOCKIZATIONS_11682590158800904305: VariantsMap = [
    &["dockizations"],
    &["dockisations"],
    &["dockizations"],
    &["dockisations"],
];

pub(crate) static ENTRY_DOCKIZATION_1535416910054929275: VariantsMap = [
    &["dockization"],
    &["dockisation"],
    &["dockization"],
    &["dockisation"],
];

pub(crate) static ENTRY_DOCKIZED_11497882154286445931: VariantsMap =
    [&["dockized"], &["dockised"], &["dockized"], &["dockised"]];

pub(crate) static ENTRY_DOCKIZES_18122194512183460168: VariantsMap =
    [&["dockizes"], &["dockises"], &["dockizes"], &["dockises"]];

pub(crate) static ENTRY_DOCKIZE_7971946050616909881: VariantsMap =
    [&["dockize"], &["dockise"], &["dockize"], &["dockise"]];

pub(crate) static ENTRY_DOCKIZING_3734828908908895957: VariantsMap = [
    &["dockizing"],
    &["dockising"],
    &["dockizing"],
    &["dockising"],
];

pub(crate) static ENTRY_DOCTORIZATIONS_16822908416090304265: VariantsMap = [
    &["doctorizations"],
    &["doctorisations"],
    &["doctorizations"],
    &["doctorisations"],
];

pub(crate) static ENTRY_DOCTORIZATION_16033729298032621232: VariantsMap = [
    &["doctorization"],
    &["doctorisation"],
    &["doctorization"],
    &["doctorisation"],
];

pub(crate) static ENTRY_DOCTORIZES_5548640602945580448: VariantsMap = [
    &["doctorizes"],
    &["doctorises"],
    &["doctorizes"],
    &["doctorises"],
];

pub(crate) static ENTRY_DOCTORIZE_6755038590757730967: VariantsMap = [
    &["doctorize"],
    &["doctorise"],
    &["doctorize"],
    &["doctorise"],
];

pub(crate) static ENTRY_DOCTRINIZATIONS_15902219939645192582: VariantsMap = [
    &["doctrinizations"],
    &["doctrinisations"],
    &["doctrinizations"],
    &["doctrinisations"],
];

pub(crate) static ENTRY_DOCTRINIZATION_16019265374829905601: VariantsMap = [
    &["doctrinization"],
    &["doctrinisation"],
    &["doctrinization"],
    &["doctrinisation"],
];

pub(crate) static ENTRY_DOCTRINIZES_5935013749533049591: VariantsMap = [
    &["doctrinizes"],
    &["doctrinises"],
    &["doctrinizes"],
    &["doctrinises"],
];

pub(crate) static ENTRY_DOCTRINIZE_6295108165555928163: VariantsMap = [
    &["doctrinize"],
    &["doctrinise"],
    &["doctrinize"],
    &["doctrinise"],
];

pub(crate) static ENTRY_DOCUMENTARIZATIONS_10331155650038384543: VariantsMap = [
    &["documentarizations"],
    &["documentarisations"],
    &["documentarizations"],
    &["documentarisations"],
];

pub(crate) static ENTRY_DOCUMENTARIZATION_17974536989356012536: VariantsMap = [
    &["documentarization"],
    &["documentarisation"],
    &["documentarization"],
    &["documentarisation"],
];

pub(crate) static ENTRY_DOCUMENTARIZED_17052922427938453018: VariantsMap = [
    &["documentarized"],
    &["documentarised"],
    &["documentarized"],
    &["documentarised"],
];

pub(crate) static ENTRY_DOCUMENTARIZES_12258340263601716780: VariantsMap = [
    &["documentarizes"],
    &["documentarises"],
    &["documentarizes"],
    &["documentarises"],
];

pub(crate) static ENTRY_DOCUMENTARIZE_4613182909392922028: VariantsMap = [
    &["documentarize"],
    &["documentarise"],
    &["documentarize"],
    &["documentarise"],
];

pub(crate) static ENTRY_DOCUMENTARIZING_617029537042756884: VariantsMap = [
    &["documentarizing"],
    &["documentarising"],
    &["documentarizing"],
    &["documentarising"],
];

pub(crate) static ENTRY_DOCUMENTIZES_16197448875654270526: VariantsMap = [
    &["documentizes"],
    &["documentises"],
    &["documentizes"],
    &["documentises"],
];

pub(crate) static ENTRY_DOCUMENTIZE_8987269843659123718: VariantsMap = [
    &["documentize"],
    &["documentise"],
    &["documentize"],
    &["documentise"],
];

pub(crate) static ENTRY_DODONEAN_4865245390182893775: VariantsMap = [
    &["dodonean"],
    &["dodonaean"],
    &["dodonaean"],
    &["dodonaean"],
];

pub(crate) static ENTRY_DOGMATIZATIONS_16998792177218196465: VariantsMap = [
    &["dogmatizations"],
    &["dogmatisations"],
    &["dogmatizations"],
    &["dogmatisations"],
];

pub(crate) static ENTRY_DOGMATIZATION_9807437487276138631: VariantsMap = [
    &["dogmatization"],
    &["dogmatisation"],
    &["dogmatization"],
    &["dogmatisation"],
];

pub(crate) static ENTRY_DOGMATIZED_16841797752844209570: VariantsMap = [
    &["dogmatized"],
    &["dogmatised"],
    &["dogmatized"],
    &["dogmatised"],
];

pub(crate) static ENTRY_DOGMATIZERS_4399276900624905781: VariantsMap = [
    &["dogmatizers"],
    &["dogmatisers"],
    &["dogmatizers"],
    &["dogmatisers"],
];

pub(crate) static ENTRY_DOGMATIZER_12352899563923207585: VariantsMap = [
    &["dogmatizer"],
    &["dogmatiser"],
    &["dogmatizer"],
    &["dogmatiser"],
];

pub(crate) static ENTRY_DOGMATIZES_5834123085035176852: VariantsMap = [
    &["dogmatizes"],
    &["dogmatises"],
    &["dogmatizes"],
    &["dogmatises"],
];

pub(crate) static ENTRY_DOGMATIZE_17787716068922105181: VariantsMap = [
    &["dogmatize"],
    &["dogmatise"],
    &["dogmatize"],
    &["dogmatise"],
];

pub(crate) static ENTRY_DOGMATIZING_2447061813414873668: VariantsMap = [
    &["dogmatizing"],
    &["dogmatising"],
    &["dogmatizing"],
    &["dogmatising"],
];

pub(crate) static ENTRY_DOGNAPED_11073408213279300229: VariantsMap = [
    &["dognaped"],
    &["dognapped"],
    &["dognapped"],
    &["dognapped"],
];

pub(crate) static ENTRY_DOGNAPING_18285041110852582538: VariantsMap = [
    &["dognaping"],
    &["dognapping"],
    &["dognapping"],
    &["dognapping"],
];

pub(crate) static ENTRY_DOLLARIZATIONS_17625833038744269977: VariantsMap = [
    &["dollarizations"],
    &["dollarisations"],
    &["dollarizations"],
    &["dollarisations"],
];

pub(crate) static ENTRY_DOLLARIZATION_17756157301501272744: VariantsMap = [
    &["dollarization"],
    &["dollarisation"],
    &["dollarization"],
    &["dollarisation"],
];

pub(crate) static ENTRY_DOLOMITIZATIONS_14772713962775924448: VariantsMap = [
    &["dolomitizations"],
    &["dolomitisations"],
    &["dolomitizations"],
    &["dolomitisations"],
];

pub(crate) static ENTRY_DOLOMITIZATION_14933423504719929542: VariantsMap = [
    &["dolomitization"],
    &["dolomitisation"],
    &["dolomitization"],
    &["dolomitisation"],
];

pub(crate) static ENTRY_DOLOMITIZED_11692953153623694619: VariantsMap = [
    &["dolomitized"],
    &["dolomitised"],
    &["dolomitized"],
    &["dolomitised"],
];

pub(crate) static ENTRY_DOLOMITIZES_14363893600761024796: VariantsMap = [
    &["dolomitizes"],
    &["dolomitises"],
    &["dolomitizes"],
    &["dolomitises"],
];

pub(crate) static ENTRY_DOLOMITIZE_11040063579570529637: VariantsMap = [
    &["dolomitize"],
    &["dolomitise"],
    &["dolomitize"],
    &["dolomitise"],
];

pub(crate) static ENTRY_DOLOMITIZING_438564637284719498: VariantsMap = [
    &["dolomitizing"],
    &["dolomitising"],
    &["dolomitizing"],
    &["dolomitising"],
];

pub(crate) static ENTRY_DOLORS_14103590959031573361: VariantsMap =
    [&["dolors"], &["dolours"], &["dolours"], &["dolours"]];

pub(crate) static ENTRY_DOLOR_13331739895797537426: VariantsMap =
    [&["dolor"], &["dolour"], &["dolour"], &["dolour"]];

pub(crate) static ENTRY_DOMESTICIZED_942799913724257410: VariantsMap = [
    &["domesticized"],
    &["domesticised"],
    &["domesticized"],
    &["domesticised"],
];

pub(crate) static ENTRY_DOMESTICIZES_10740490321221958206: VariantsMap = [
    &["domesticizes"],
    &["domesticises"],
    &["domesticizes"],
    &["domesticises"],
];

pub(crate) static ENTRY_DOMESTICIZE_13328191379606735400: VariantsMap = [
    &["domesticize"],
    &["domesticise"],
    &["domesticize"],
    &["domesticise"],
];

pub(crate) static ENTRY_DOMESTICIZING_14826454957919135861: VariantsMap = [
    &["domesticizing"],
    &["domesticising"],
    &["domesticizing"],
    &["domesticising"],
];

pub(crate) static ENTRY_DOMINE_6107407794990069253: VariantsMap =
    [&["domine"], &["dominae"], &["dominae"], &["dominae"]];

pub(crate) static ENTRY_DORA_16140085300068073244: VariantsMap =
    [&["dora"], &["doura"], &["doura"], &["doura"]];

pub(crate) static ENTRY_DORICIZES_6267531821171799546: VariantsMap = [
    &["doricizes"],
    &["doricises"],
    &["doricizes"],
    &["doricises"],
];

pub(crate) static ENTRY_DORICIZE_6423501943985007435: VariantsMap =
    [&["doricize"], &["doricise"], &["doricize"], &["doricise"]];

pub(crate) static ENTRY_DORIZED_15641017864552407948: VariantsMap =
    [&["dorized"], &["dorised"], &["dorized"], &["dorised"]];

pub(crate) static ENTRY_DORIZES_2466661328762540129: VariantsMap =
    [&["dorizes"], &["dorises"], &["dorizes"], &["dorises"]];

pub(crate) static ENTRY_DORIZE_5375683295399571559: VariantsMap =
    [&["dorize"], &["dorise"], &["dorize"], &["dorise"]];

pub(crate) static ENTRY_DORIZING_8550740907826559833: VariantsMap =
    [&["dorizing"], &["dorising"], &["dorizing"], &["dorising"]];

pub(crate) static ENTRY_DORYLINE_13007837504764606022: VariantsMap = [
    &["doryline"],
    &["dorylinae"],
    &["dorylinae"],
    &["dorylinae"],
];

pub(crate) static ENTRY_DOUGHNUTS_2863778322372164342: VariantsMap = [
    &["doughnuts"],
    &["doughnuts"],
    &["doughnuts"],
    &["doughnuts"],
];

pub(crate) static ENTRY_DOUGHNUT_10730795230131641057: VariantsMap =
    [&["doughnut"], &["doughnut"], &["doughnut"], &["doughnut"]];

pub(crate) static ENTRY_DOWELED_3347505904680781852: VariantsMap =
    [&["doweled"], &["dowelled"], &["dowelled"], &["dowelled"]];

pub(crate) static ENTRY_DOWELER_14640077182615108914: VariantsMap =
    [&["doweler"], &["doweller"], &["doweller"], &["doweller"]];

pub(crate) static ENTRY_DOWELING_18059799987098176192: VariantsMap = [
    &["doweling"],
    &["dowelling"],
    &["dowelling"],
    &["dowelling"],
];

pub(crate) static ENTRY_DOWNDRAFT_9039488072887961853: VariantsMap = [
    &["downdraft"],
    &["downdraught"],
    &["downdraft"],
    &["downdraught"],
];

pub(crate) static ENTRY_DRACENACEAE_16212683568672807360: VariantsMap = [
    &["dracenaceae"],
    &["dracaenaceae"],
    &["dracaenaceae"],
    &["dracaenaceae"],
];

pub(crate) static ENTRY_DRACENAS_12510578936942457083: VariantsMap = [
    &["dracenas"],
    &["dracaenas"],
    &["dracaenas"],
    &["dracaenas"],
];

pub(crate) static ENTRY_DRACENA_6118539877770808902: VariantsMap =
    [&["dracena"], &["dracaena"], &["dracaena"], &["dracaena"]];

pub(crate) static ENTRY_DRAFTED_2613143638373081360: VariantsMap =
    [&["drafted"], &["drafted"], &["drafted"], &["drafted"]];

pub(crate) static ENTRY_DRAFTIER_9222724357623798327: VariantsMap = [
    &["draftier"],
    &["draughtier"],
    &["draftier"],
    &["draughtier"],
];

pub(crate) static ENTRY_DRAFTIEST_5259543064524205513: VariantsMap = [
    &["draftiest"],
    &["draughtiest"],
    &["draftiest"],
    &["draughtiest"],
];

pub(crate) static ENTRY_DRAFTILIER_6263136181960657686: VariantsMap = [
    &["draftilier"],
    &["draughtilier"],
    &["draftilier"],
    &["draughtilier"],
];

pub(crate) static ENTRY_DRAFTILIEST_12111711614227754883: VariantsMap = [
    &["draftiliest"],
    &["draughtiliest"],
    &["draftiliest"],
    &["draughtiliest"],
];

pub(crate) static ENTRY_DRAFTILY_3404853207703525148: VariantsMap = [
    &["draftily"],
    &["draughtily"],
    &["draftily"],
    &["draughtily"],
];

pub(crate) static ENTRY_DRAFTINESSES_2337311124395489337: VariantsMap = [
    &["draftinesses"],
    &["draughtinesses"],
    &["draftinesses"],
    &["draughtinesses"],
];

pub(crate) static ENTRY_DRAFTINESS_5050558803290260054: VariantsMap = [
    &["draftiness"],
    &["draughtiness"],
    &["draftiness"],
    &["draughtiness"],
];

pub(crate) static ENTRY_DRAFTING_8913342336646949258: VariantsMap =
    [&["drafting"], &["drafting"], &["drafting"], &["drafting"]];

pub(crate) static ENTRY_DRAFTSMANSHIPS_3009875565957915648: VariantsMap = [
    &["draftsmanships"],
    &["draughtsmanships"],
    &["draftsmanships"],
    &["draughtsmanships"],
];

pub(crate) static ENTRY_DRAFTSMANSHIP_14701669807878909941: VariantsMap = [
    &["draftsmanship"],
    &["draughtsmanship"],
    &["draftsmanship"],
    &["draughtsmanship"],
];

pub(crate) static ENTRY_DRAFTSMAN_2158426515502784003: VariantsMap = [
    &["draftsman"],
    &["draughtsman"],
    &["draftsman"],
    &["draughtsman"],
];

pub(crate) static ENTRY_DRAFTSMEN_11969721402571410341: VariantsMap = [
    &["draftsmen"],
    &["draughtsmen"],
    &["draftsmen"],
    &["draughtsmen"],
];

pub(crate) static ENTRY_DRAFTSPERSON_17252902994124085558: VariantsMap = [
    &["draftsperson"],
    &["draughtsperson"],
    &["draftsperson"],
    &["draughtsperson"],
];

pub(crate) static ENTRY_DRAFTSWOMAN_13749770471062736806: VariantsMap = [
    &["draftswoman"],
    &["draughtswoman"],
    &["draftswoman"],
    &["draughtswoman"],
];

pub(crate) static ENTRY_DRAFTSWOMEN_14692115605095290784: VariantsMap = [
    &["draftswomen"],
    &["draughtswomen"],
    &["draftswomen"],
    &["draughtswomen"],
];

pub(crate) static ENTRY_DRAFTY_11689082232746206984: VariantsMap =
    [&["drafty"], &["draughty"], &["drafty"], &["draughty"]];

pub(crate) static ENTRY_DRAGONIZED_13277720972691636848: VariantsMap = [
    &["dragonized"],
    &["dragonised"],
    &["dragonized"],
    &["dragonised"],
];

pub(crate) static ENTRY_DRAGONIZES_8370477046170548627: VariantsMap = [
    &["dragonizes"],
    &["dragonises"],
    &["dragonizes"],
    &["dragonises"],
];

pub(crate) static ENTRY_DRAGONIZE_14160202049023947793: VariantsMap = [
    &["dragonize"],
    &["dragonise"],
    &["dragonize"],
    &["dragonise"],
];

pub(crate) static ENTRY_DRAGONIZING_15675970912123878416: VariantsMap = [
    &["dragonizing"],
    &["dragonising"],
    &["dragonizing"],
    &["dragonising"],
];

pub(crate) static ENTRY_DRAMATIZABLER_14017923335901627289: VariantsMap = [
    &["dramatizabler"],
    &["dramatisabler"],
    &["dramatizabler"],
    &["dramatisabler"],
];

pub(crate) static ENTRY_DRAMATIZABLEST_11908506320782789726: VariantsMap = [
    &["dramatizablest"],
    &["dramatisablest"],
    &["dramatizablest"],
    &["dramatisablest"],
];

pub(crate) static ENTRY_DRAMATIZABLES_12929019439166166978: VariantsMap = [
    &["dramatizables"],
    &["dramatisables"],
    &["dramatizables"],
    &["dramatisables"],
];

pub(crate) static ENTRY_DRAMATIZABLE_114460072530125204: VariantsMap = [
    &["dramatizable"],
    &["dramatisable"],
    &["dramatizable"],
    &["dramatisable"],
];

pub(crate) static ENTRY_DRAMATIZATIONS_4872008295467161969: VariantsMap = [
    &["dramatizations"],
    &["dramatisations"],
    &["dramatizations"],
    &["dramatisations"],
];

pub(crate) static ENTRY_DRAMATIZATION_18352830060262048924: VariantsMap = [
    &["dramatization"],
    &["dramatisation"],
    &["dramatization"],
    &["dramatisation"],
];

pub(crate) static ENTRY_DRAMATIZED_2372982752652968078: VariantsMap = [
    &["dramatized"],
    &["dramatised"],
    &["dramatized"],
    &["dramatised"],
];

pub(crate) static ENTRY_DRAMATIZERS_17282413603035313323: VariantsMap = [
    &["dramatizers"],
    &["dramatisers"],
    &["dramatizers"],
    &["dramatisers"],
];

pub(crate) static ENTRY_DRAMATIZER_12312020267573769761: VariantsMap = [
    &["dramatizer"],
    &["dramatiser"],
    &["dramatizer"],
    &["dramatiser"],
];

pub(crate) static ENTRY_DRAMATIZES_14716282266966184426: VariantsMap = [
    &["dramatizes"],
    &["dramatises"],
    &["dramatizes"],
    &["dramatises"],
];

pub(crate) static ENTRY_DRAMATIZE_11024442299136514965: VariantsMap = [
    &["dramatize"],
    &["dramatise"],
    &["dramatize"],
    &["dramatise"],
];

pub(crate) static ENTRY_DRAMATIZING_14243240191823624849: VariantsMap = [
    &["dramatizing"],
    &["dramatising"],
    &["dramatizing"],
    &["dramatising"],
];

pub(crate) static ENTRY_DRAUGHTBOARDS_10338171604839828821: VariantsMap = [
    &["draughtboards"],
    &["draughtboards"],
    &["draughtboards"],
    &["draughtboards"],
];

pub(crate) static ENTRY_DRAUGHTBOARD_17601710064627669528: VariantsMap = [
    &["draughtboard"],
    &["draughtboard"],
    &["draughtboard"],
    &["draughtboard"],
];

pub(crate) static ENTRY_DREAMED_693371865095129101: VariantsMap = [
    &["dreamed"],
    &["dreamed", "dreamt"],
    &["dreamed", "dreamt"],
    &["dreamed", "dreamt"],
];

pub(crate) static ENTRY_DRIVELED_7030750316386626325: VariantsMap = [
    &["driveled"],
    &["drivelled"],
    &["drivelled"],
    &["drivelled"],
];

pub(crate) static ENTRY_DRIVELERS_719861811563082420: VariantsMap = [
    &["drivelers"],
    &["drivellers"],
    &["drivellers"],
    &["drivellers"],
];

pub(crate) static ENTRY_DRIVELER_13922515254126867061: VariantsMap = [
    &["driveler"],
    &["driveller"],
    &["driveller"],
    &["driveller"],
];

pub(crate) static ENTRY_DRIVELING_8695688524206031945: VariantsMap = [
    &["driveling"],
    &["drivelling"],
    &["drivelling"],
    &["drivelling"],
];

pub(crate) static ENTRY_DUALIZATIONS_1769778750613840808: VariantsMap = [
    &["dualizations"],
    &["dualisations"],
    &["dualizations"],
    &["dualisations"],
];

pub(crate) static ENTRY_DUALIZATION_297757979352720010: VariantsMap = [
    &["dualization"],
    &["dualisation"],
    &["dualization"],
    &["dualisation"],
];

pub(crate) static ENTRY_DUALIZES_6580630624039637450: VariantsMap =
    [&["dualizes"], &["dualises"], &["dualizes"], &["dualises"]];

pub(crate) static ENTRY_DUALIZE_14667812076587421504: VariantsMap =
    [&["dualize"], &["dualise"], &["dualize"], &["dualise"]];

pub(crate) static ENTRY_DUCTILIZES_8324019089066090944: VariantsMap = [
    &["ductilizes"],
    &["ductilises"],
    &["ductilizes"],
    &["ductilises"],
];

pub(crate) static ENTRY_DUCTILIZE_5117009823320979710: VariantsMap = [
    &["ductilize"],
    &["ductilise"],
    &["ductilize"],
    &["ductilise"],
];

pub(crate) static ENTRY_DUELED_14139003527020650904: VariantsMap =
    [&["dueled"], &["duelled"], &["duelled"], &["duelled"]];

pub(crate) static ENTRY_DUELERS_885313812620534811: VariantsMap =
    [&["duelers"], &["duellers"], &["duellers"], &["duellers"]];

pub(crate) static ENTRY_DUELER_17639225109776633494: VariantsMap =
    [&["dueler"], &["dueller"], &["dueller"], &["dueller"]];

pub(crate) static ENTRY_DUELINGS_14759091337280437276: VariantsMap = [
    &["duelings"],
    &["duellings"],
    &["duellings"],
    &["duellings"],
];

pub(crate) static ENTRY_DUELING_5778547651645125895: VariantsMap =
    [&["dueling"], &["duelling"], &["duelling"], &["duelling"]];

pub(crate) static ENTRY_DUELISTS_18258331536218201176: VariantsMap = [
    &["duelists"],
    &["duellists"],
    &["duellists"],
    &["duellists"],
];

pub(crate) static ENTRY_DUELIST_6970922052642565539: VariantsMap =
    [&["duelist"], &["duellist"], &["duellist"], &["duellist"]];

pub(crate) static ENTRY_DUER_2007337493238246122: VariantsMap =
    [&["duer"], &["dure"], &["dure"], &["dure"]];

pub(crate) static ENTRY_DYNAMIZED_11851467384344631451: VariantsMap = [
    &["dynamized"],
    &["dynamised"],
    &["dynamized"],
    &["dynamised"],
];

pub(crate) static ENTRY_DYNAMIZES_8572022122021418990: VariantsMap = [
    &["dynamizes"],
    &["dynamises"],
    &["dynamizes"],
    &["dynamises"],
];

pub(crate) static ENTRY_DYNAMIZE_16898679564021204348: VariantsMap =
    [&["dynamize"], &["dynamise"], &["dynamize"], &["dynamise"]];

pub(crate) static ENTRY_DYNAMIZING_15204260139319478124: VariantsMap = [
    &["dynamizing"],
    &["dynamising"],
    &["dynamizing"],
    &["dynamising"],
];

pub(crate) static ENTRY_DYSESTHESIA_10145261120272617451: VariantsMap = [
    &["dysesthesia"],
    &["dysaesthesia"],
    &["dysaesthesia"],
    &["dysaesthesia"],
];

pub(crate) static ENTRY_DYSESTHETIC_9985209311909479038: VariantsMap = [
    &["dysesthetic"],
    &["dysaesthetic"],
    &["dysaesthetic"],
    &["dysaesthetic"],
];

pub(crate) static ENTRY_DYSMENORRHEAL_3211916475354947561: VariantsMap = [
    &["dysmenorrheal"],
    &["dysmenorrhoeal"],
    &["dysmenorrhoeal"],
    &["dysmenorrhoeal"],
];

pub(crate) static ENTRY_DYSMENORRHEAS_8092414813964160172: VariantsMap = [
    &["dysmenorrheas"],
    &["dysmenorrhoeas"],
    &["dysmenorrhoeas"],
    &["dysmenorrhoeas"],
];

pub(crate) static ENTRY_DYSMENORRHEA_666903672534201582: VariantsMap = [
    &["dysmenorrhea"],
    &["dysmenorrhoea"],
    &["dysmenorrhoea"],
    &["dysmenorrhoea"],
];

pub(crate) static ENTRY_DYSMENORRHEIC_17754264387759129903: VariantsMap = [
    &["dysmenorrheic"],
    &["dysmenorrhoeic"],
    &["dysmenorrhoeic"],
    &["dysmenorrhoeic"],
];

pub(crate) static ENTRY_DYSPNEAL_4877333742970701237: VariantsMap = [
    &["dyspneal"],
    &["dyspnoeal"],
    &["dyspnoeal"],
    &["dyspnoeal"],
];

pub(crate) static ENTRY_DYSPNEAS_2665152845196591077: VariantsMap =
    [&["dyspneas"], &["dyspnoeas"], &["dyspneas"], &["dyspnoeas"]];

pub(crate) static ENTRY_DYSPNEA_3275451076579387530: VariantsMap =
    [&["dyspnea"], &["dyspnoea"], &["dyspnea"], &["dyspnoea"]];

pub(crate) static ENTRY_DYSPNEIC_8845859738600782802: VariantsMap = [
    &["dyspneic"],
    &["dyspnoeic"],
    &["dyspnoeic"],
    &["dyspnoeic"],
];

pub(crate) static ENTRY_EARLIERIZED_5951041999526558231: VariantsMap = [
    &["earlierized"],
    &["earlierised"],
    &["earlierized"],
    &["earlierised"],
];

pub(crate) static ENTRY_EARLIERIZES_5592536878851474631: VariantsMap = [
    &["earlierizes"],
    &["earlierises"],
    &["earlierizes"],
    &["earlierises"],
];

pub(crate) static ENTRY_EARLIERIZE_11997942640911832041: VariantsMap = [
    &["earlierize"],
    &["earlierise"],
    &["earlierize"],
    &["earlierise"],
];

pub(crate) static ENTRY_EARLIERIZING_8179681759986389983: VariantsMap = [
    &["earlierizing"],
    &["earlierising"],
    &["earlierizing"],
    &["earlierising"],
];

pub(crate) static ENTRY_EASTERNIZE_12013346158934132557: VariantsMap = [
    &["easternize"],
    &["easternise"],
    &["easternize"],
    &["easternise"],
];

pub(crate) static ENTRY_EBIONIZED_607134243617959572: VariantsMap = [
    &["ebionized"],
    &["ebionised"],
    &["ebionized"],
    &["ebionised"],
];

pub(crate) static ENTRY_EBIONIZES_4728139485714479539: VariantsMap = [
    &["ebionizes"],
    &["ebionises"],
    &["ebionizes"],
    &["ebionises"],
];

pub(crate) static ENTRY_EBIONIZE_14882150669745577807: VariantsMap =
    [&["ebionize"], &["ebionise"], &["ebionize"], &["ebionise"]];

pub(crate) static ENTRY_EBIONIZING_6877070461214793032: VariantsMap = [
    &["ebionizing"],
    &["ebionising"],
    &["ebionizing"],
    &["ebionising"],
];

pub(crate) static ENTRY_EBONIZATION_5157733486316868335: VariantsMap = [
    &["ebonization"],
    &["ebonisation"],
    &["ebonization"],
    &["ebonisation"],
];

pub(crate) static ENTRY_EBONIZED_3445883171941210725: VariantsMap =
    [&["ebonized"], &["ebonised"], &["ebonized"], &["ebonised"]];

pub(crate) static ENTRY_EBONIZES_7098552992016802268: VariantsMap =
    [&["ebonizes"], &["ebonises"], &["ebonizes"], &["ebonises"]];

pub(crate) static ENTRY_EBONIZE_8171442481512187913: VariantsMap =
    [&["ebonize"], &["ebonise"], &["ebonize"], &["ebonise"]];

pub(crate) static ENTRY_EBONIZING_1463384613006749087: VariantsMap = [
    &["ebonizing"],
    &["ebonising"],
    &["ebonizing"],
    &["ebonising"],
];

pub(crate) static ENTRY_ECCLESIASTICIZES_17947325437796182000: VariantsMap = [
    &["ecclesiasticizes"],
    &["ecclesiasticises"],
    &["ecclesiasticizes"],
    &["ecclesiasticises"],
];

pub(crate) static ENTRY_ECCLESIASTICIZE_5375790565507371661: VariantsMap = [
    &["ecclesiasticize"],
    &["ecclesiasticise"],
    &["ecclesiasticize"],
    &["ecclesiasticise"],
];

pub(crate) static ENTRY_ECHOIZED_6584344175654222383: VariantsMap =
    [&["echoized"], &["echoised"], &["echoized"], &["echoised"]];

pub(crate) static ENTRY_ECHOIZES_17651680927186205508: VariantsMap =
    [&["echoizes"], &["echoises"], &["echoizes"], &["echoises"]];

pub(crate) static ENTRY_ECHOIZE_9793911410527060783: VariantsMap =
    [&["echoize"], &["echoise"], &["echoize"], &["echoise"]];

pub(crate) static ENTRY_ECHOIZING_13817992796446083050: VariantsMap = [
    &["echoizing"],
    &["echoising"],
    &["echoizing"],
    &["echoising"],
];

pub(crate) static ENTRY_ECLECTICIZES_18162048424932631142: VariantsMap = [
    &["eclecticizes"],
    &["eclecticises"],
    &["eclecticizes"],
    &["eclecticises"],
];

pub(crate) static ENTRY_ECLECTICIZE_1537579377409875615: VariantsMap = [
    &["eclecticize"],
    &["eclecticise"],
    &["eclecticize"],
    &["eclecticise"],
];

pub(crate) static ENTRY_ECOID_15718380068289810443: VariantsMap =
    [&["ecoid"], &["oecoid"], &["oecoid"], &["oecoid"]];

pub(crate) static ENTRY_ECONOMIZATIONS_13677505030173502975: VariantsMap = [
    &["economizations"],
    &["economisations"],
    &["economizations"],
    &["economisations"],
];

pub(crate) static ENTRY_ECONOMIZATION_17236921042856233623: VariantsMap = [
    &["economization"],
    &["economisation"],
    &["economization"],
    &["economisation"],
];

pub(crate) static ENTRY_ECONOMIZED_18148417393969980009: VariantsMap = [
    &["economized"],
    &["economised"],
    &["economized"],
    &["economised"],
];

pub(crate) static ENTRY_ECONOMIZERS_12502480689214202445: VariantsMap = [
    &["economizers"],
    &["economisers"],
    &["economizers"],
    &["economisers"],
];

pub(crate) static ENTRY_ECONOMIZER_14737250670952641028: VariantsMap = [
    &["economizer"],
    &["economiser"],
    &["economizer"],
    &["economiser"],
];

pub(crate) static ENTRY_ECONOMIZES_12987737212565587737: VariantsMap = [
    &["economizes"],
    &["economises"],
    &["economizes"],
    &["economises"],
];

pub(crate) static ENTRY_ECONOMIZE_12358668986073235407: VariantsMap = [
    &["economize"],
    &["economise"],
    &["economize"],
    &["economise"],
];

pub(crate) static ENTRY_ECONOMIZING_11359270378553989667: VariantsMap = [
    &["economizing"],
    &["economising"],
    &["economizing"],
    &["economising"],
];

pub(crate) static ENTRY_ECOPHOBIA_3341542489768933704: VariantsMap = [
    &["ecophobia"],
    &["oecophobia"],
    &["oecophobia"],
    &["oecophobia"],
];

pub(crate) static ENTRY_ECSTASIZED_14433048399656133421: VariantsMap = [
    &["ecstasized"],
    &["ecstasised"],
    &["ecstasized"],
    &["ecstasised"],
];

pub(crate) static ENTRY_ECSTASIZES_4161308607604786330: VariantsMap = [
    &["ecstasizes"],
    &["ecstasises"],
    &["ecstasizes"],
    &["ecstasises"],
];

pub(crate) static ENTRY_ECSTASIZE_12478888629525898090: VariantsMap = [
    &["ecstasize"],
    &["ecstasise"],
    &["ecstasize"],
    &["ecstasise"],
];

pub(crate) static ENTRY_ECSTASIZING_2299211862700315587: VariantsMap = [
    &["ecstasizing"],
    &["ecstasising"],
    &["ecstasizing"],
    &["ecstasising"],
];

pub(crate) static ENTRY_ECSTATICIZES_12312353657798123304: VariantsMap = [
    &["ecstaticizes"],
    &["ecstaticises"],
    &["ecstaticizes"],
    &["ecstaticises"],
];

pub(crate) static ENTRY_ECSTATICIZE_10857806109758048478: VariantsMap = [
    &["ecstaticize"],
    &["ecstaticise"],
    &["ecstaticize"],
    &["ecstaticise"],
];

pub(crate) static ENTRY_ECTETHMOID_4932886455054265154: VariantsMap = [
    &["ectethmoid"],
    &["ectoethmoid"],
    &["ectoethmoid"],
    &["ectoethmoid"],
];

pub(crate) static ENTRY_ECTOCELIC_15109589632064964048: VariantsMap = [
    &["ectocelic"],
    &["ectocoelic"],
    &["ectocoelic"],
    &["ectocoelic"],
];

pub(crate) static ENTRY_ECUMENICALISM_9305909791330696513: VariantsMap = [
    &["ecumenicalism"],
    &["ecumenicalism"],
    &["ecumenicalism"],
    &["ecumenicalism"],
];

pub(crate) static ENTRY_ECUMENICITY_12254763938003713900: VariantsMap = [
    &["ecumenicity"],
    &["ecumenicity"],
    &["ecumenicity"],
    &["ecumenicity"],
];

pub(crate) static ENTRY_ECUMENIC_15780133217602967984: VariantsMap =
    [&["ecumenic"], &["ecumenic"], &["ecumenic"], &["ecumenic"]];

pub(crate) static ENTRY_ECUMENISM_18416002854149374979: VariantsMap = [
    &["ecumenism"],
    &["ecumenism"],
    &["ecumenism"],
    &["ecumenism"],
];

pub(crate) static ENTRY_ECUS_7337291910539278082: VariantsMap =
    [&["ecus"], &["oecus"], &["oecus"], &["oecus"]];

pub(crate) static ENTRY_EC_18369594411890017360: VariantsMap =
    [&["ec"], &["aec"], &["aec"], &["aec"]];

pub(crate) static ENTRY_EDEMAS_7742566514366737816: VariantsMap =
    [&["edemas"], &["oedemas"], &["edemas"], &["oedemas"]];

pub(crate) static ENTRY_EDEMATOSE_16851378643586465230: VariantsMap = [
    &["edematose"],
    &["oedematose"],
    &["edematose"],
    &["oedematose"],
];

pub(crate) static ENTRY_EDEMATOUS_2501565917049629990: VariantsMap = [
    &["edematous"],
    &["oedematous"],
    &["edematous"],
    &["oedematous"],
];

pub(crate) static ENTRY_EDEMA_6018744134424908364: VariantsMap =
    [&["edema"], &["oedema"], &["edema"], &["oedema"]];

pub(crate) static ENTRY_EDENIZATIONS_17717672445150358731: VariantsMap = [
    &["edenizations"],
    &["edenisations"],
    &["edenizations"],
    &["edenisations"],
];

pub(crate) static ENTRY_EDENIZATION_14877368160810371784: VariantsMap = [
    &["edenization"],
    &["edenisation"],
    &["edenization"],
    &["edenisation"],
];

pub(crate) static ENTRY_EDENIZES_13029714813212856027: VariantsMap =
    [&["edenizes"], &["edenises"], &["edenizes"], &["edenises"]];

pub(crate) static ENTRY_EDENIZE_4547310883249177007: VariantsMap =
    [&["edenize"], &["edenise"], &["edenize"], &["edenise"]];

pub(crate) static ENTRY_EDICULE_10918770642841249439: VariantsMap =
    [&["edicule"], &["aedicule"], &["aedicule"], &["aedicule"]];

pub(crate) static ENTRY_EDILITY_10658105135103528164: VariantsMap =
    [&["edility"], &["aedility"], &["aedility"], &["aedility"]];

pub(crate) static ENTRY_EDITORIALIZATIONS_12319328368566597913: VariantsMap = [
    &["editorializations"],
    &["editorialisations"],
    &["editorializations"],
    &["editorialisations"],
];

pub(crate) static ENTRY_EDITORIALIZATION_16653146908113662887: VariantsMap = [
    &["editorialization"],
    &["editorialisation"],
    &["editorialization"],
    &["editorialisation"],
];

pub(crate) static ENTRY_EDITORIALIZED_9618808155032869338: VariantsMap = [
    &["editorialized"],
    &["editorialised"],
    &["editorialized"],
    &["editorialised"],
];

pub(crate) static ENTRY_EDITORIALIZER_907841174282390671: VariantsMap = [
    &["editorializer"],
    &["editorialiser"],
    &["editorializer"],
    &["editorialiser"],
];

pub(crate) static ENTRY_EDITORIALIZES_3002090244472118034: VariantsMap = [
    &["editorializes"],
    &["editorialises"],
    &["editorializes"],
    &["editorialises"],
];

pub(crate) static ENTRY_EDITORIALIZE_425925589943067801: VariantsMap = [
    &["editorialize"],
    &["editorialise"],
    &["editorialize"],
    &["editorialise"],
];

pub(crate) static ENTRY_EDITORIALIZING_4056192079667477523: VariantsMap = [
    &["editorializing"],
    &["editorialising"],
    &["editorializing"],
    &["editorialising"],
];

pub(crate) static ENTRY_EETION_7506982938713093790: VariantsMap =
    [&["eetion"], &["eaetion"], &["eaetion"], &["eaetion"]];

pub(crate) static ENTRY_EFFECTUALIZES_5750997542764404732: VariantsMap = [
    &["effectualizes"],
    &["effectualises"],
    &["effectualizes"],
    &["effectualises"],
];

pub(crate) static ENTRY_EFFECTUALIZE_2854942339620949483: VariantsMap = [
    &["effectualize"],
    &["effectualise"],
    &["effectualize"],
    &["effectualise"],
];

pub(crate) static ENTRY_EFFEMINATIZES_10162259315067828496: VariantsMap = [
    &["effeminatizes"],
    &["effeminatises"],
    &["effeminatizes"],
    &["effeminatises"],
];

pub(crate) static ENTRY_EFFEMINATIZE_6301232153675654071: VariantsMap = [
    &["effeminatize"],
    &["effeminatise"],
    &["effeminatize"],
    &["effeminatise"],
];

pub(crate) static ENTRY_EFFEMINIZATION_3469570906021333989: VariantsMap = [
    &["effeminization"],
    &["effeminisation"],
    &["effeminization"],
    &["effeminisation"],
];

pub(crate) static ENTRY_EFFEMINIZED_2488051553108619858: VariantsMap = [
    &["effeminized"],
    &["effeminised"],
    &["effeminized"],
    &["effeminised"],
];

pub(crate) static ENTRY_EFFEMINIZES_1751738554568598255: VariantsMap = [
    &["effeminizes"],
    &["effeminises"],
    &["effeminizes"],
    &["effeminises"],
];

pub(crate) static ENTRY_EFFEMINIZE_3367646221923186814: VariantsMap = [
    &["effeminize"],
    &["effeminise"],
    &["effeminize"],
    &["effeminise"],
];

pub(crate) static ENTRY_EFFEMINIZING_14300719326884303630: VariantsMap = [
    &["effeminizing"],
    &["effeminising"],
    &["effeminizing"],
    &["effeminising"],
];

pub(crate) static ENTRY_EGER_3267279819185100866: VariantsMap =
    [&["eger"], &["egre"], &["egre"], &["egre"]];

pub(crate) static ENTRY_EGER_370209078151771517: VariantsMap =
    [&["eger"], &["aeger"], &["aeger"], &["aeger"]];

pub(crate) static ENTRY_EGILOPS_15304768767282746036: VariantsMap =
    [&["egilops"], &["aegilops"], &["aegilops"], &["aegilops"]];

pub(crate) static ENTRY_EGLOGUE_16104631981488511989: VariantsMap =
    [&["eglogue"], &["aeglogue"], &["aeglogue"], &["aeglogue"]];

pub(crate) static ENTRY_EGOIZERS_16599062205549549591: VariantsMap =
    [&["egoizers"], &["egoisers"], &["egoizers"], &["egoisers"]];

pub(crate) static ENTRY_EGOIZER_6042847438515593386: VariantsMap =
    [&["egoizer"], &["egoiser"], &["egoizer"], &["egoiser"]];

pub(crate) static ENTRY_EGOIZES_7296127181194814948: VariantsMap =
    [&["egoizes"], &["egoises"], &["egoizes"], &["egoises"]];

pub(crate) static ENTRY_EGOIZE_848168811919938232: VariantsMap =
    [&["egoize"], &["egoise"], &["egoize"], &["egoise"]];

pub(crate) static ENTRY_EGOPHONY_2012602110086773588: VariantsMap = [
    &["egophony"],
    &["aegophony"],
    &["aegophony"],
    &["aegophony"],
];

pub(crate) static ENTRY_EGOTIZED_14948617827289949091: VariantsMap =
    [&["egotized"], &["egotised"], &["egotized"], &["egotised"]];

pub(crate) static ENTRY_EGOTIZES_17356051654981309847: VariantsMap =
    [&["egotizes"], &["egotises"], &["egotizes"], &["egotises"]];

pub(crate) static ENTRY_EGOTIZE_10473969129670528822: VariantsMap =
    [&["egotize"], &["egotise"], &["egotize"], &["egotise"]];

pub(crate) static ENTRY_EGOTIZING_255552054661601129: VariantsMap = [
    &["egotizing"],
    &["egotising"],
    &["egotizing"],
    &["egotising"],
];

pub(crate) static ENTRY_EGRITUDE_9946971293935803579: VariantsMap = [
    &["egritude"],
    &["aegritude"],
    &["aegritude"],
    &["aegritude"],
];

pub(crate) static ENTRY_EGYPTIANIZATIONS_14876553018910189078: VariantsMap = [
    &["egyptianizations"],
    &["egyptianisations"],
    &["egyptianizations"],
    &["egyptianisations"],
];

pub(crate) static ENTRY_EGYPTIANIZATION_10487155187974848335: VariantsMap = [
    &["egyptianization"],
    &["egyptianisation"],
    &["egyptianization"],
    &["egyptianisation"],
];

pub(crate) static ENTRY_EGYPTIANIZED_16285206324460702808: VariantsMap = [
    &["egyptianized"],
    &["egyptianised"],
    &["egyptianized"],
    &["egyptianised"],
];

pub(crate) static ENTRY_EGYPTIANIZES_8703144950337739653: VariantsMap = [
    &["egyptianizes"],
    &["egyptianises"],
    &["egyptianizes"],
    &["egyptianises"],
];

pub(crate) static ENTRY_EGYPTIANIZE_3829453833375546559: VariantsMap = [
    &["egyptianize"],
    &["egyptianise"],
    &["egyptianize"],
    &["egyptianise"],
];

pub(crate) static ENTRY_EGYPTIANIZING_14447728275835277106: VariantsMap = [
    &["egyptianizing"],
    &["egyptianising"],
    &["egyptianizing"],
    &["egyptianising"],
];

pub(crate) static ENTRY_EGYPTIZES_9609036163136479870: VariantsMap = [
    &["egyptizes"],
    &["egyptises"],
    &["egyptizes"],
    &["egyptises"],
];

pub(crate) static ENTRY_EGYPTIZE_7334581701121422605: VariantsMap =
    [&["egyptize"], &["egyptise"], &["egyptize"], &["egyptise"]];

pub(crate) static ENTRY_ELASTICIZATION_15154020732606510926: VariantsMap = [
    &["elasticization"],
    &["elasticisation"],
    &["elasticization"],
    &["elasticisation"],
];

pub(crate) static ENTRY_ELASTICIZED_17571893237729540044: VariantsMap = [
    &["elasticized"],
    &["elasticised"],
    &["elasticized"],
    &["elasticised"],
];

pub(crate) static ENTRY_ELASTICIZERS_16095393649186847498: VariantsMap = [
    &["elasticizers"],
    &["elasticisers"],
    &["elasticizers"],
    &["elasticisers"],
];

pub(crate) static ENTRY_ELASTICIZER_15500813180956764351: VariantsMap = [
    &["elasticizer"],
    &["elasticiser"],
    &["elasticizer"],
    &["elasticiser"],
];

pub(crate) static ENTRY_ELASTICIZES_15507458752832878092: VariantsMap = [
    &["elasticizes"],
    &["elasticises"],
    &["elasticizes"],
    &["elasticises"],
];

pub(crate) static ENTRY_ELASTICIZE_6142699365245709219: VariantsMap = [
    &["elasticize"],
    &["elasticise"],
    &["elasticize"],
    &["elasticise"],
];

pub(crate) static ENTRY_ELASTICIZING_14323113355310943519: VariantsMap = [
    &["elasticizing"],
    &["elasticising"],
    &["elasticizing"],
    &["elasticising"],
];

pub(crate) static ENTRY_ELECTRICALIZES_11839544262325067272: VariantsMap = [
    &["electricalizes"],
    &["electricalises"],
    &["electricalizes"],
    &["electricalises"],
];

pub(crate) static ENTRY_ELECTRICALIZE_12653348063928720225: VariantsMap = [
    &["electricalize"],
    &["electricalise"],
    &["electricalize"],
    &["electricalise"],
];

pub(crate) static ENTRY_ELECTRICIZES_3929185044639312558: VariantsMap = [
    &["electricizes"],
    &["electricises"],
    &["electricizes"],
    &["electricises"],
];

pub(crate) static ENTRY_ELECTRICIZE_4911015515844771622: VariantsMap = [
    &["electricize"],
    &["electricise"],
    &["electricize"],
    &["electricise"],
];

pub(crate) static ENTRY_ELECTRIZATIONS_13976280743140547777: VariantsMap = [
    &["electrizations"],
    &["electrisations"],
    &["electrizations"],
    &["electrisations"],
];

pub(crate) static ENTRY_ELECTRIZATION_7597451149298731659: VariantsMap = [
    &["electrization"],
    &["electrisation"],
    &["electrization"],
    &["electrisation"],
];

pub(crate) static ENTRY_ELECTRIZED_14788122243236354566: VariantsMap = [
    &["electrized"],
    &["electrised"],
    &["electrized"],
    &["electrised"],
];

pub(crate) static ENTRY_ELECTRIZES_8739623266390445152: VariantsMap = [
    &["electrizes"],
    &["electrises"],
    &["electrizes"],
    &["electrises"],
];

pub(crate) static ENTRY_ELECTRIZE_7840311297044744924: VariantsMap = [
    &["electrize"],
    &["electrise"],
    &["electrize"],
    &["electrise"],
];

pub(crate) static ENTRY_ELECTRIZING_14822771639775450790: VariantsMap = [
    &["electrizing"],
    &["electrising"],
    &["electrizing"],
    &["electrising"],
];

pub(crate) static ENTRY_ELECTROANESTHESIAS_6303108604980733618: VariantsMap = [
    &["electroanesthesias"],
    &["electroanaesthesias"],
    &["electroanaesthesias"],
    &["electroanaesthesias"],
];

pub(crate) static ENTRY_ELECTROANESTHESIA_6580395617178938362: VariantsMap = [
    &["electroanesthesia"],
    &["electroanaesthesia"],
    &["electroanaesthesia"],
    &["electroanaesthesia"],
];

pub(crate) static ENTRY_ELECTROCAUTERIZATIONS_16892082350141619114: VariantsMap = [
    &["electrocauterizations"],
    &["electrocauterisations"],
    &["electrocauterizations"],
    &["electrocauterisations"],
];

pub(crate) static ENTRY_ELECTROCAUTERIZATION_16903094457115645430: VariantsMap = [
    &["electrocauterization"],
    &["electrocauterisation"],
    &["electrocauterization"],
    &["electrocauterisation"],
];

pub(crate) static ENTRY_ELECTRODIALYZERS_1528101750662982617: VariantsMap = [
    &["electrodialyzers"],
    &["electrodialysers"],
    &["electrodialysers"],
    &["electrodialysers"],
];

pub(crate) static ENTRY_ELECTRODIALYZER_12002873361469261764: VariantsMap = [
    &["electrodialyzer"],
    &["electrodialyser"],
    &["electrodialyser"],
    &["electrodialyser"],
];

pub(crate) static ENTRY_ELECTRODIALYZES_3747563092652406931: VariantsMap = [
    &["electrodialyzes"],
    &["electrodialyses"],
    &["electrodialyses"],
    &["electrodialyses"],
];

pub(crate) static ENTRY_ELECTRODIALYZE_2544367951940511335: VariantsMap = [
    &["electrodialyze"],
    &["electrodialyse"],
    &["electrodialyse"],
    &["electrodialyse"],
];

pub(crate) static ENTRY_ELECTROGALVANIZES_13557830902076339969: VariantsMap = [
    &["electrogalvanizes"],
    &["electrogalvanises"],
    &["electrogalvanizes"],
    &["electrogalvanises"],
];

pub(crate) static ENTRY_ELECTROGALVANIZE_10321474051524162337: VariantsMap = [
    &["electrogalvanize"],
    &["electrogalvanise"],
    &["electrogalvanize"],
    &["electrogalvanise"],
];

pub(crate) static ENTRY_ELECTROHOMEOPATHIES_17935525580469832451: VariantsMap = [
    &["electrohomeopathies"],
    &["electrohomeopathies"],
    &["electrohomeopathies"],
    &["electrohomeopathies"],
];

pub(crate) static ENTRY_ELECTROHOMEOPATHY_13185050690123434514: VariantsMap = [
    &["electrohomeopathy"],
    &["electrohomeopathy"],
    &["electrohomeopathy"],
    &["electrohomeopathy"],
];

pub(crate) static ENTRY_ELECTROLYZATION_9992320209908525657: VariantsMap = [
    &["electrolyzation"],
    &["electrolysation"],
    &["electrolyzation"],
    &["electrolysation"],
];

pub(crate) static ENTRY_ELECTROLYZED_8924003047140896401: VariantsMap = [
    &["electrolyzed"],
    &["electrolysed"],
    &["electrolysed"],
    &["electrolysed"],
];

pub(crate) static ENTRY_ELECTROLYZER_712384492117912586: VariantsMap = [
    &["electrolyzer"],
    &["electrolyser"],
    &["electrolyzer"],
    &["electrolyser"],
];

pub(crate) static ENTRY_ELECTROLYZES_11477690971732519647: VariantsMap = [
    &["electrolyzes"],
    &["electrolyses"],
    &["electrolyses"],
    &["electrolyses"],
];

pub(crate) static ENTRY_ELECTROLYZE_7508850835901837851: VariantsMap = [
    &["electrolyze"],
    &["electrolyse"],
    &["electrolyse"],
    &["electrolyse"],
];

pub(crate) static ENTRY_ELECTROLYZING_9315861603300473848: VariantsMap = [
    &["electrolyzing"],
    &["electrolysing"],
    &["electrolysing"],
    &["electrolysing"],
];

pub(crate) static ENTRY_ELECTROMAGNETIZABLE_9739565016268970696: VariantsMap = [
    &["electromagnetizable"],
    &["electromagnetisable"],
    &["electromagnetizable"],
    &["electromagnetisable"],
];

pub(crate) static ENTRY_ELECTROTONIZES_9465124994125319681: VariantsMap = [
    &["electrotonizes"],
    &["electrotonises"],
    &["electrotonizes"],
    &["electrotonises"],
];

pub(crate) static ENTRY_ELECTROTONIZE_16993410664382051345: VariantsMap = [
    &["electrotonize"],
    &["electrotonise"],
    &["electrotonize"],
    &["electrotonise"],
];

pub(crate) static ENTRY_ELEGIZED_234567674978394451: VariantsMap =
    [&["elegized"], &["elegised"], &["elegized"], &["elegised"]];

pub(crate) static ENTRY_ELEGIZES_10107353784266158156: VariantsMap =
    [&["elegizes"], &["elegises"], &["elegizes"], &["elegises"]];

pub(crate) static ENTRY_ELEGIZE_7937759892215576690: VariantsMap =
    [&["elegize"], &["elegise"], &["elegize"], &["elegise"]];

pub(crate) static ENTRY_ELEGIZING_3259872614184614593: VariantsMap = [
    &["elegizing"],
    &["elegising"],
    &["elegizing"],
    &["elegising"],
];

pub(crate) static ENTRY_ELEMENTALIZES_2940727419159689038: VariantsMap = [
    &["elementalizes"],
    &["elementalises"],
    &["elementalizes"],
    &["elementalises"],
];

pub(crate) static ENTRY_ELEMENTALIZE_4802665164184536596: VariantsMap = [
    &["elementalize"],
    &["elementalise"],
    &["elementalize"],
    &["elementalise"],
];

pub(crate) static ENTRY_ELEOBLAST_8021023369296032808: VariantsMap = [
    &["eleoblast"],
    &["elaeoblast"],
    &["elaeoblast"],
    &["elaeoblast"],
];

pub(crate) static ENTRY_ELEOLITE_8551744649156866087: VariantsMap = [
    &["eleolite"],
    &["elaeolite"],
    &["elaeolite"],
    &["elaeolite"],
];

pub(crate) static ENTRY_ELEOMARGARIC_16571690257823782694: VariantsMap = [
    &["eleomargaric"],
    &["elaeomargaric"],
    &["elaeomargaric"],
    &["elaeomargaric"],
];

pub(crate) static ENTRY_ELEOMETER_8406501550306573221: VariantsMap = [
    &["eleometer"],
    &["elaeometer"],
    &["elaeometer"],
    &["elaeometer"],
];

pub(crate) static ENTRY_ELEOPTENE_189677587011952998: VariantsMap = [
    &["eleoptene"],
    &["elaeoptene"],
    &["elaeoptene"],
    &["elaeoptene"],
];

pub(crate) static ENTRY_ELIZABETHANIZES_8429280681938858568: VariantsMap = [
    &["elizabethanizes"],
    &["elizabethanises"],
    &["elizabethanizes"],
    &["elizabethanises"],
];

pub(crate) static ENTRY_ELIZABETHANIZE_14863227819015951221: VariantsMap = [
    &["elizabethanize"],
    &["elizabethanise"],
    &["elizabethanize"],
    &["elizabethanise"],
];

pub(crate) static ENTRY_ELIZABETHVILLE_7585322377517108871: VariantsMap = [
    &["elizabethville"],
    &["elisabethville"],
    &["elizabethville"],
    &["elisabethville"],
];

pub(crate) static ENTRY_EMBEDMENTS_9605808427028077825: VariantsMap = [
    &["embedments"],
    &["embedments"],
    &["embedments"],
    &["embedments"],
];

pub(crate) static ENTRY_EMBEDMENT_2516420638791723000: VariantsMap = [
    &["embedment"],
    &["embedment"],
    &["embedment"],
    &["embedment"],
];

pub(crate) static ENTRY_EMBLEMATICIZES_1712964621674583121: VariantsMap = [
    &["emblematicizes"],
    &["emblematicises"],
    &["emblematicizes"],
    &["emblematicises"],
];

pub(crate) static ENTRY_EMBLEMATICIZE_5365410222867877084: VariantsMap = [
    &["emblematicize"],
    &["emblematicise"],
    &["emblematicize"],
    &["emblematicise"],
];

pub(crate) static ENTRY_EMBLEMATIZATION_3037774664990291578: VariantsMap = [
    &["emblematization"],
    &["emblematisation"],
    &["emblematization"],
    &["emblematisation"],
];

pub(crate) static ENTRY_EMBLEMATIZED_11833827530357489690: VariantsMap = [
    &["emblematized"],
    &["emblematised"],
    &["emblematized"],
    &["emblematised"],
];

pub(crate) static ENTRY_EMBLEMATIZES_2053946387275416277: VariantsMap = [
    &["emblematizes"],
    &["emblematises"],
    &["emblematizes"],
    &["emblematises"],
];

pub(crate) static ENTRY_EMBLEMATIZE_12296991017617416245: VariantsMap = [
    &["emblematize"],
    &["emblematise"],
    &["emblematize"],
    &["emblematise"],
];

pub(crate) static ENTRY_EMBLEMATIZING_15961105666979470386: VariantsMap = [
    &["emblematizing"],
    &["emblematising"],
    &["emblematizing"],
    &["emblematising"],
];

pub(crate) static ENTRY_EMBLEMIZED_10594160594841460386: VariantsMap = [
    &["emblemized"],
    &["emblemised"],
    &["emblemized"],
    &["emblemised"],
];

pub(crate) static ENTRY_EMBLEMIZES_4063063334401141759: VariantsMap = [
    &["emblemizes"],
    &["emblemises"],
    &["emblemizes"],
    &["emblemises"],
];

pub(crate) static ENTRY_EMBLEMIZE_1401519711379921201: VariantsMap = [
    &["emblemize"],
    &["emblemise"],
    &["emblemize"],
    &["emblemise"],
];

pub(crate) static ENTRY_EMBLEMIZING_10846409341438865894: VariantsMap = [
    &["emblemizing"],
    &["emblemising"],
    &["emblemizing"],
    &["emblemising"],
];

pub(crate) static ENTRY_EMBOLIZATION_11273543037803448058: VariantsMap = [
    &["embolization"],
    &["embolisation"],
    &["embolization"],
    &["embolisation"],
];

pub(crate) static ENTRY_EMBOWELED_4570354825435090850: VariantsMap = [
    &["emboweled"],
    &["embowelled"],
    &["embowelled"],
    &["embowelled"],
];

pub(crate) static ENTRY_EMBOWELING_2941434533991212942: VariantsMap = [
    &["emboweling"],
    &["embowelling"],
    &["embowelling"],
    &["embowelling"],
];

pub(crate) static ENTRY_EMOTIONALIZATIONS_8068177829901134213: VariantsMap = [
    &["emotionalizations"],
    &["emotionalisations"],
    &["emotionalizations"],
    &["emotionalisations"],
];

pub(crate) static ENTRY_EMOTIONALIZATION_8285067224344808560: VariantsMap = [
    &["emotionalization"],
    &["emotionalisation"],
    &["emotionalization"],
    &["emotionalisation"],
];

pub(crate) static ENTRY_EMOTIONALIZED_10357036420236281327: VariantsMap = [
    &["emotionalized"],
    &["emotionalised"],
    &["emotionalized"],
    &["emotionalised"],
];

pub(crate) static ENTRY_EMOTIONALIZES_3570691650798864535: VariantsMap = [
    &["emotionalizes"],
    &["emotionalises"],
    &["emotionalizes"],
    &["emotionalises"],
];

pub(crate) static ENTRY_EMOTIONALIZE_9595590056518240613: VariantsMap = [
    &["emotionalize"],
    &["emotionalise"],
    &["emotionalize"],
    &["emotionalise"],
];

pub(crate) static ENTRY_EMOTIONALIZING_18340248172153003025: VariantsMap = [
    &["emotionalizing"],
    &["emotionalising"],
    &["emotionalizing"],
    &["emotionalising"],
];

pub(crate) static ENTRY_EMOTIONIZES_4881347793120141643: VariantsMap = [
    &["emotionizes"],
    &["emotionises"],
    &["emotionizes"],
    &["emotionises"],
];

pub(crate) static ENTRY_EMOTIONIZE_15015605431088092781: VariantsMap = [
    &["emotionize"],
    &["emotionise"],
    &["emotionize"],
    &["emotionise"],
];

pub(crate) static ENTRY_EMPATHIZED_14314991802693364328: VariantsMap = [
    &["empathized"],
    &["empathised"],
    &["empathized"],
    &["empathised"],
];

pub(crate) static ENTRY_EMPATHIZES_3252518257724496702: VariantsMap = [
    &["empathizes"],
    &["empathises"],
    &["empathizes"],
    &["empathises"],
];

pub(crate) static ENTRY_EMPATHIZE_1626505131224915017: VariantsMap = [
    &["empathize"],
    &["empathise"],
    &["empathize"],
    &["empathise"],
];

pub(crate) static ENTRY_EMPATHIZING_137602655573298152: VariantsMap = [
    &["empathizing"],
    &["empathising"],
    &["empathizing"],
    &["empathising"],
];

pub(crate) static ENTRY_EMPERIZED_3609672014387585150: VariantsMap = [
    &["emperized"],
    &["emperised"],
    &["emperized"],
    &["emperised"],
];

pub(crate) static ENTRY_EMPERIZES_5086736676911735307: VariantsMap = [
    &["emperizes"],
    &["emperises"],
    &["emperizes"],
    &["emperises"],
];

pub(crate) static ENTRY_EMPERIZE_1384359766709835064: VariantsMap =
    [&["emperize"], &["emperise"], &["emperize"], &["emperise"]];

pub(crate) static ENTRY_EMPERIZING_6110004448635217910: VariantsMap = [
    &["emperizing"],
    &["emperising"],
    &["emperizing"],
    &["emperising"],
];

pub(crate) static ENTRY_EMPESTIC_14588541811997276042: VariantsMap = [
    &["empestic"],
    &["empaestic"],
    &["empaestic"],
    &["empaestic"],
];

pub(crate) static ENTRY_EMPHASIZED_649083867029832853: VariantsMap = [
    &["emphasized"],
    &["emphasised"],
    &["emphasized"],
    &["emphasised"],
];

pub(crate) static ENTRY_EMPHASIZERS_18309998515128705301: VariantsMap = [
    &["emphasizers"],
    &["emphasisers"],
    &["emphasizers"],
    &["emphasisers"],
];

pub(crate) static ENTRY_EMPHASIZER_11403370446466675303: VariantsMap = [
    &["emphasizer"],
    &["emphasiser"],
    &["emphasizer"],
    &["emphasiser"],
];

pub(crate) static ENTRY_EMPHASIZES_5772436931297938243: VariantsMap = [
    &["emphasizes"],
    &["emphasises"],
    &["emphasizes"],
    &["emphasises"],
];

pub(crate) static ENTRY_EMPHASIZE_15381357888908119930: VariantsMap = [
    &["emphasize"],
    &["emphasise"],
    &["emphasize"],
    &["emphasise"],
];

pub(crate) static ENTRY_EMPHASIZING_8877699404927600063: VariantsMap = [
    &["emphasizing"],
    &["emphasising"],
    &["emphasizing"],
    &["emphasising"],
];

pub(crate) static ENTRY_EMPLOYEES_5068613761389447671: VariantsMap = [
    &["employees"],
    &["employees"],
    &["employees"],
    &["employees"],
];

pub(crate) static ENTRY_EMPLOYEE_11669968157991382973: VariantsMap =
    [&["employee"], &["employee"], &["employee"], &["employee"]];

pub(crate) static ENTRY_EMPYREUMATIZED_15637035447882020628: VariantsMap = [
    &["empyreumatized"],
    &["empyreumatised"],
    &["empyreumatized"],
    &["empyreumatised"],
];

pub(crate) static ENTRY_EMPYREUMATIZES_9068196112099455402: VariantsMap = [
    &["empyreumatizes"],
    &["empyreumatises"],
    &["empyreumatizes"],
    &["empyreumatises"],
];

pub(crate) static ENTRY_EMPYREUMATIZE_15069068830093340604: VariantsMap = [
    &["empyreumatize"],
    &["empyreumatise"],
    &["empyreumatize"],
    &["empyreumatise"],
];

pub(crate) static ENTRY_EMPYREUMATIZING_2341701252050540041: VariantsMap = [
    &["empyreumatizing"],
    &["empyreumatising"],
    &["empyreumatizing"],
    &["empyreumatising"],
];

pub(crate) static ENTRY_EMULED_10357664319101512866: VariantsMap =
    [&["emuled"], &["aemuled"], &["aemuled"], &["aemuled"]];

pub(crate) static ENTRY_EMULES_6796003945794582963: VariantsMap =
    [&["emules"], &["aemules"], &["aemules"], &["aemules"]];

pub(crate) static ENTRY_EMULE_1972234654623253784: VariantsMap =
    [&["emule"], &["aemule"], &["aemule"], &["aemule"]];

pub(crate) static ENTRY_EMULING_11304283679719960362: VariantsMap =
    [&["emuling"], &["aemuling"], &["aemuling"], &["aemuling"]];

pub(crate) static ENTRY_EMULSIONIZED_16825639760819643474: VariantsMap = [
    &["emulsionized"],
    &["emulsionised"],
    &["emulsionized"],
    &["emulsionised"],
];

pub(crate) static ENTRY_EMULSIONIZES_16895497312962998295: VariantsMap = [
    &["emulsionizes"],
    &["emulsionises"],
    &["emulsionizes"],
    &["emulsionises"],
];

pub(crate) static ENTRY_EMULSIONIZE_7053945529955407436: VariantsMap = [
    &["emulsionize"],
    &["emulsionise"],
    &["emulsionize"],
    &["emulsionise"],
];

pub(crate) static ENTRY_EMULSIONIZING_10164290780298735348: VariantsMap = [
    &["emulsionizing"],
    &["emulsionising"],
    &["emulsionizing"],
    &["emulsionising"],
];

pub(crate) static ENTRY_ENAMELED_989404607221066133: VariantsMap = [
    &["enameled"],
    &["enamelled"],
    &["enamelled"],
    &["enamelled"],
];

pub(crate) static ENTRY_ENAMELERS_7855006556277285142: VariantsMap = [
    &["enamelers"],
    &["enamellers"],
    &["enamellers"],
    &["enamellers"],
];

pub(crate) static ENTRY_ENAMELER_14880476578662103007: VariantsMap = [
    &["enameler"],
    &["enameller"],
    &["enameller"],
    &["enameller"],
];

pub(crate) static ENTRY_ENAMELINGS_4169856245572563917: VariantsMap = [
    &["enamelings"],
    &["enamellings"],
    &["enamellings"],
    &["enamellings"],
];

pub(crate) static ENTRY_ENAMELING_651499017740975299: VariantsMap = [
    &["enameling"],
    &["enamelling"],
    &["enamelling"],
    &["enamelling"],
];

pub(crate) static ENTRY_ENAMELISTS_3600110159132815371: VariantsMap = [
    &["enamelists"],
    &["enamellists"],
    &["enamellists"],
    &["enamellists"],
];

pub(crate) static ENTRY_ENAMELIST_6556021724769945893: VariantsMap = [
    &["enamelist"],
    &["enamellist"],
    &["enamellist"],
    &["enamellist"],
];

pub(crate) static ENTRY_ENAMOREDNESSES_1348249767052969587: VariantsMap = [
    &["enamorednesses"],
    &["enamourednesses"],
    &["enamourednesses"],
    &["enamourednesses"],
];

pub(crate) static ENTRY_ENAMOREDNESS_10996665665818617331: VariantsMap = [
    &["enamoredness"],
    &["enamouredness"],
    &["enamouredness"],
    &["enamouredness"],
];

pub(crate) static ENTRY_ENAMOREDS_6301165412476267762: VariantsMap = [
    &["enamoreds"],
    &["enamoureds"],
    &["enamoureds"],
    &["enamoureds"],
];

pub(crate) static ENTRY_ENAMORED_16186178270973267134: VariantsMap = [
    &["enamored"],
    &["enamoured"],
    &["enamoured"],
    &["enamoured"],
];

pub(crate) static ENTRY_ENAMORING_17989678795134022497: VariantsMap = [
    &["enamoring"],
    &["enamouring"],
    &["enamouring"],
    &["enamouring"],
];

pub(crate) static ENTRY_ENAMORMENTS_13370005761506802640: VariantsMap = [
    &["enamorments"],
    &["enamourments"],
    &["enamourments"],
    &["enamourments"],
];

pub(crate) static ENTRY_ENAMORMENT_7471105087461120528: VariantsMap = [
    &["enamorment"],
    &["enamourment"],
    &["enamourment"],
    &["enamourment"],
];

pub(crate) static ENTRY_ENAMORS_9636937238080184741: VariantsMap =
    [&["enamors"], &["enamours"], &["enamours"], &["enamours"]];

pub(crate) static ENTRY_ENAMOR_2911879302324239036: VariantsMap =
    [&["enamor"], &["enamour"], &["enamour"], &["enamour"]];

pub(crate) static ENTRY_ENARBORS_8145891299588576620: VariantsMap = [
    &["enarbors"],
    &["enarbours"],
    &["enarbours"],
    &["enarbours"],
];

pub(crate) static ENTRY_ENARBOR_15915857770564812751: VariantsMap =
    [&["enarbor"], &["enarbour"], &["enarbour"], &["enarbour"]];

pub(crate) static ENTRY_ENCARNALIZATION_13214089082920950546: VariantsMap = [
    &["encarnalization"],
    &["encarnalisation"],
    &["encarnalization"],
    &["encarnalisation"],
];

pub(crate) static ENTRY_ENCARNALIZED_13979095018139018531: VariantsMap = [
    &["encarnalized"],
    &["encarnalised"],
    &["encarnalized"],
    &["encarnalised"],
];

pub(crate) static ENTRY_ENCARNALIZES_11369013563329530888: VariantsMap = [
    &["encarnalizes"],
    &["encarnalises"],
    &["encarnalizes"],
    &["encarnalises"],
];

pub(crate) static ENTRY_ENCARNALIZE_10850144919400996674: VariantsMap = [
    &["encarnalize"],
    &["encarnalise"],
    &["encarnalize"],
    &["encarnalise"],
];

pub(crate) static ENTRY_ENCARNALIZING_15767167372584376951: VariantsMap = [
    &["encarnalizing"],
    &["encarnalising"],
    &["encarnalizing"],
    &["encarnalising"],
];

pub(crate) static ENTRY_ENCEPHALOCELE_1084758429798248621: VariantsMap = [
    &["encephalocele"],
    &["encephalocoele"],
    &["encephalocoele"],
    &["encephalocoele"],
];

pub(crate) static ENTRY_ENCLOSED_13340347130367472311: VariantsMap =
    [&["enclosed"], &["enclosed"], &["enclosed"], &["enclosed"]];

pub(crate) static ENTRY_ENCLOSES_936921542023137950: VariantsMap =
    [&["encloses"], &["encloses"], &["encloses"], &["encloses"]];

pub(crate) static ENTRY_ENCLOSE_16455068235111751734: VariantsMap =
    [&["enclose"], &["enclose"], &["enclose"], &["enclose"]];

pub(crate) static ENTRY_ENCLOSING_8054071438169915028: VariantsMap = [
    &["enclosing"],
    &["enclosing"],
    &["enclosing"],
    &["enclosing"],
];

pub(crate) static ENTRY_ENCOLORED_4939538076917014241: VariantsMap = [
    &["encolored"],
    &["encoloured"],
    &["encoloured"],
    &["encoloured"],
];

pub(crate) static ENTRY_ENCOLORING_4183307079529327993: VariantsMap = [
    &["encoloring"],
    &["encolouring"],
    &["encolouring"],
    &["encolouring"],
];

pub(crate) static ENTRY_ENCOLORS_8551106713845336956: VariantsMap = [
    &["encolors"],
    &["encolours"],
    &["encolours"],
    &["encolours"],
];

pub(crate) static ENTRY_ENCOLOR_1492202587953686714: VariantsMap =
    [&["encolor"], &["encolour"], &["encolour"], &["encolour"]];

pub(crate) static ENTRY_ENDAMEBAE_7672591039700210017: VariantsMap = [
    &["endamebae"],
    &["endamoebae"],
    &["endamoebae"],
    &["endamoebae"],
];

pub(crate) static ENTRY_ENDAMEBAS_3894595978421412160: VariantsMap = [
    &["endamebas"],
    &["endamoebas"],
    &["endamoebas"],
    &["endamoebas"],
];

pub(crate) static ENTRY_ENDAMEBA_3674996897057489972: VariantsMap = [
    &["endameba"],
    &["endamoeba"],
    &["endamoeba"],
    &["endamoeba"],
];

pub(crate) static ENTRY_ENDAMEBIASIS_10526584886624559903: VariantsMap = [
    &["endamebiasis"],
    &["endamoebiasis"],
    &["endamoebiasis"],
    &["endamoebiasis"],
];

pub(crate) static ENTRY_ENDAMEBIC_7654343873984680949: VariantsMap = [
    &["endamebic"],
    &["endamoebic"],
    &["endamoebic"],
    &["endamoebic"],
];

pub(crate) static ENTRY_ENDEAVORED_12576902359096148689: VariantsMap = [
    &["endeavored"],
    &["endeavoured"],
    &["endeavoured"],
    &["endeavoured"],
];

pub(crate) static ENTRY_ENDEAVORERS_4264835563429458461: VariantsMap = [
    &["endeavorers"],
    &["endeavourers"],
    &["endeavourers"],
    &["endeavourers"],
];

pub(crate) static ENTRY_ENDEAVORER_10269034998374810670: VariantsMap = [
    &["endeavorer"],
    &["endeavourer"],
    &["endeavourer"],
    &["endeavourer"],
];

pub(crate) static ENTRY_ENDEAVORING_454178916350601958: VariantsMap = [
    &["endeavoring"],
    &["endeavouring"],
    &["endeavouring"],
    &["endeavouring"],
];

pub(crate) static ENTRY_ENDEAVORS_5789569016694167960: VariantsMap = [
    &["endeavors"],
    &["endeavours"],
    &["endeavours"],
    &["endeavours"],
];

pub(crate) static ENTRY_ENDEAVOR_1861674104846402447: VariantsMap = [
    &["endeavor"],
    &["endeavour"],
    &["endeavour"],
    &["endeavour"],
];

pub(crate) static ENTRY_ENDERS_14681940842455541593: VariantsMap =
    [&["enders"], &["endres"], &["endres"], &["endres"]];

pub(crate) static ENTRY_ENEID_5242893003172218406: VariantsMap =
    [&["eneid"], &["aeneid"], &["aeneid"], &["aeneid"]];

pub(crate) static ENTRY_ENERGIZATION_8281923071042553435: VariantsMap = [
    &["energization"],
    &["energisation"],
    &["energization"],
    &["energisation"],
];

pub(crate) static ENTRY_ENERGIZED_10338769724136607063: VariantsMap = [
    &["energized"],
    &["energised"],
    &["energized"],
    &["energised"],
];

pub(crate) static ENTRY_ENERGIZERS_10194438715562893992: VariantsMap = [
    &["energizers"],
    &["energisers"],
    &["energizers"],
    &["energisers"],
];

pub(crate) static ENTRY_ENERGIZER_449515490537378567: VariantsMap = [
    &["energizer"],
    &["energiser"],
    &["energizer"],
    &["energiser"],
];

pub(crate) static ENTRY_ENERGIZES_6958626290038298541: VariantsMap = [
    &["energizes"],
    &["energises"],
    &["energizes"],
    &["energises"],
];

pub(crate) static ENTRY_ENERGIZE_9040021254285160273: VariantsMap =
    [&["energize"], &["energise"], &["energize"], &["energise"]];

pub(crate) static ENTRY_ENERGIZING_17242100400597322517: VariantsMap = [
    &["energizing"],
    &["energising"],
    &["energizing"],
    &["energising"],
];

pub(crate) static ENTRY_ENGLISHIZES_18263651365586401449: VariantsMap = [
    &["englishizes"],
    &["englishises"],
    &["englishizes"],
    &["englishises"],
];

pub(crate) static ENTRY_ENGLISHIZE_16572744168284665334: VariantsMap = [
    &["englishize"],
    &["englishise"],
    &["englishize"],
    &["englishise"],
];

pub(crate) static ENTRY_ENGRANDIZEMENTS_4909257735302569491: VariantsMap = [
    &["engrandizements"],
    &["engrandisements"],
    &["engrandizements"],
    &["engrandisements"],
];

pub(crate) static ENTRY_ENGRANDIZEMENT_6175391937433585069: VariantsMap = [
    &["engrandizement"],
    &["engrandisement"],
    &["engrandizement"],
    &["engrandisement"],
];

pub(crate) static ENTRY_ENGRANDIZES_5787971542005976862: VariantsMap = [
    &["engrandizes"],
    &["engrandises"],
    &["engrandizes"],
    &["engrandises"],
];

pub(crate) static ENTRY_ENGRANDIZE_17642469822387491571: VariantsMap = [
    &["engrandize"],
    &["engrandise"],
    &["engrandize"],
    &["engrandise"],
];

pub(crate) static ENTRY_ENHARBOR_153070629897735018: VariantsMap = [
    &["enharbor"],
    &["enharbour"],
    &["enharbour"],
    &["enharbour"],
];

pub(crate) static ENTRY_ENHEMOSPORE_15543189487115046896: VariantsMap = [
    &["enhemospore"],
    &["enhaemospore"],
    &["enhaemospore"],
    &["enhaemospore"],
];

pub(crate) static ENTRY_ENHYPOSTATIZED_1834900422070850325: VariantsMap = [
    &["enhypostatized"],
    &["enhypostatised"],
    &["enhypostatized"],
    &["enhypostatised"],
];

pub(crate) static ENTRY_ENHYPOSTATIZES_11790227835392026149: VariantsMap = [
    &["enhypostatizes"],
    &["enhypostatises"],
    &["enhypostatizes"],
    &["enhypostatises"],
];

pub(crate) static ENTRY_ENHYPOSTATIZE_15302074165806361600: VariantsMap = [
    &["enhypostatize"],
    &["enhypostatise"],
    &["enhypostatize"],
    &["enhypostatise"],
];

pub(crate) static ENTRY_ENHYPOSTATIZING_13001414271119905921: VariantsMap = [
    &["enhypostatizing"],
    &["enhypostatising"],
    &["enhypostatizing"],
    &["enhypostatising"],
];

pub(crate) static ENTRY_ENIGMATIZED_17096479822940125639: VariantsMap = [
    &["enigmatized"],
    &["enigmatised"],
    &["enigmatized"],
    &["enigmatised"],
];

pub(crate) static ENTRY_ENIGMATIZES_13870261966778024845: VariantsMap = [
    &["enigmatizes"],
    &["enigmatises"],
    &["enigmatizes"],
    &["enigmatises"],
];

pub(crate) static ENTRY_ENIGMATIZE_10416979299826385433: VariantsMap = [
    &["enigmatize"],
    &["enigmatise"],
    &["enigmatize"],
    &["enigmatise"],
];

pub(crate) static ENTRY_ENIGMATIZING_7497242872817041134: VariantsMap = [
    &["enigmatizing"],
    &["enigmatising"],
    &["enigmatizing"],
    &["enigmatising"],
];

pub(crate) static ENTRY_ENOCYTE_5031071790616444705: VariantsMap =
    [&["enocyte"], &["oenocyte"], &["oenocyte"], &["oenocyte"]];

pub(crate) static ENTRY_ENOLIC_8677666364536262517: VariantsMap =
    [&["enolic"], &["oenolic"], &["oenolic"], &["oenolic"]];

pub(crate) static ENTRY_ENOLIZATIONS_15361842836817529123: VariantsMap = [
    &["enolizations"],
    &["enolisations"],
    &["enolizations"],
    &["enolisations"],
];

pub(crate) static ENTRY_ENOLIZATION_9705682977867724521: VariantsMap = [
    &["enolization"],
    &["enolisation"],
    &["enolization"],
    &["enolisation"],
];

pub(crate) static ENTRY_ENOLIZES_16347391140858353185: VariantsMap =
    [&["enolizes"], &["enolises"], &["enolizes"], &["enolises"]];

pub(crate) static ENTRY_ENOLIZE_5068170608685889108: VariantsMap =
    [&["enolize"], &["enolise"], &["enolize"], &["enolise"]];

pub(crate) static ENTRY_ENOLOGICAL_13435934594635959021: VariantsMap = [
    &["enological"],
    &["oenological"],
    &["oenological"],
    &["oenological"],
];

pub(crate) static ENTRY_ENOLOGISTS_17383228974239236048: VariantsMap = [
    &["enologists"],
    &["oenologists"],
    &["oenologists"],
    &["oenologists"],
];

pub(crate) static ENTRY_ENOLOGIST_7144439191139309152: VariantsMap = [
    &["enologist"],
    &["oenologist"],
    &["oenologist"],
    &["oenologist"],
];

pub(crate) static ENTRY_ENOMANIA_2005674743319272403: VariantsMap = [
    &["enomania"],
    &["oenomania"],
    &["oenomania"],
    &["oenomania"],
];

pub(crate) static ENTRY_ENROLLMENTS_9654042434029037164: VariantsMap = [
    &["enrollments"],
    &["enrolments"],
    &["enrolments"],
    &["enrolments"],
];

pub(crate) static ENTRY_ENROLLMENT_11988649571385805864: VariantsMap = [
    &["enrollment"],
    &["enrolment"],
    &["enrolment"],
    &["enrolment"],
];

pub(crate) static ENTRY_ENROLLS_13608920793429098761: VariantsMap =
    [&["enrolls"], &["enrols"], &["enrols"], &["enrols"]];

pub(crate) static ENTRY_ENROLL_1364506938148213622: VariantsMap =
    [&["enroll"], &["enrol"], &["enrol"], &["enrol"]];

pub(crate) static ENTRY_ENSEPULCHERRED_2215822898020041532: VariantsMap = [
    &["ensepulcherred"],
    &["ensepulchred"],
    &["ensepulchred"],
    &["ensepulchred"],
];

pub(crate) static ENTRY_ENSEPULCHERRING_16534463950868972468: VariantsMap = [
    &["ensepulcherring"],
    &["ensepulchring"],
    &["ensepulchring"],
    &["ensepulchring"],
];

pub(crate) static ENTRY_ENSEPULCHERS_15911081178953815823: VariantsMap = [
    &["ensepulchers"],
    &["ensepulchres"],
    &["ensepulchres"],
    &["ensepulchres"],
];

pub(crate) static ENTRY_ENSEPULCHER_18433050111369773849: VariantsMap = [
    &["ensepulcher"],
    &["ensepulchre"],
    &["ensepulchre"],
    &["ensepulchre"],
];

pub(crate) static ENTRY_ENSORCELED_12229416995193303781: VariantsMap = [
    &["ensorceled"],
    &["ensorcelled"],
    &["ensorcelled"],
    &["ensorcelled"],
];

pub(crate) static ENTRY_ENSORCELS_14124680308015897322: VariantsMap = [
    &["ensorcels"],
    &["ensorcells"],
    &["ensorcells"],
    &["ensorcells"],
];

pub(crate) static ENTRY_ENTAMEBAE_2341236739078532290: VariantsMap = [
    &["entamebae"],
    &["entamoebae"],
    &["entamoebae"],
    &["entamoebae"],
];

pub(crate) static ENTRY_ENTAMEBAS_2809555012037452245: VariantsMap = [
    &["entamebas"],
    &["entamoebas"],
    &["entamoebas"],
    &["entamoebas"],
];

pub(crate) static ENTRY_ENTAMEBA_11793706106302208785: VariantsMap = [
    &["entameba"],
    &["entamoeba"],
    &["entamoeba"],
    &["entamoeba"],
];

pub(crate) static ENTRY_ENTAMEBIC_8920229737132161042: VariantsMap = [
    &["entamebic"],
    &["entamoebic"],
    &["entamoebic"],
    &["entamoebic"],
];

pub(crate) static ENTRY_ENTENDERS_7310937866697087291: VariantsMap = [
    &["entenders"],
    &["entendres"],
    &["entendres"],
    &["entendres"],
];

pub(crate) static ENTRY_ENTENDER_17085849552645364509: VariantsMap =
    [&["entender"], &["entendre"], &["entendre"], &["entendre"]];

pub(crate) static ENTRY_ENTEROCELES_5370389164173622202: VariantsMap = [
    &["enteroceles"],
    &["enterocoeles"],
    &["enterocoeles"],
    &["enterocoeles"],
];

pub(crate) static ENTRY_ENTEROCELE_7421588424099714866: VariantsMap = [
    &["enterocele"],
    &["enterocoele"],
    &["enterocoele"],
    &["enterocoele"],
];

pub(crate) static ENTRY_ENTHRALLED_15327783804003895042: VariantsMap = [
    &["enthralled"],
    &["enthralled"],
    &["enthralled"],
    &["enthralled"],
];

pub(crate) static ENTRY_ENTHRALLING_13370984936544117104: VariantsMap = [
    &["enthralling"],
    &["enthralling"],
    &["enthralling"],
    &["enthralling"],
];

pub(crate) static ENTRY_ENTHRALLMENTS_16482738497663374563: VariantsMap = [
    &["enthrallments"],
    &["enthralments"],
    &["enthrallments"],
    &["enthralments"],
];

pub(crate) static ENTRY_ENTHRALLMENT_17889486799769196724: VariantsMap = [
    &["enthrallment"],
    &["enthralment"],
    &["enthrallment"],
    &["enthralment"],
];

pub(crate) static ENTRY_ENTHRALLS_4618745032526572838: VariantsMap =
    [&["enthralls"], &["enthrals"], &["enthralls"], &["enthrals"]];

pub(crate) static ENTRY_ENTHRALLS_6896071459165900179: VariantsMap =
    [&["enthralls"], &["enthrals"], &["enthralls"], &["enthrals"]];

pub(crate) static ENTRY_ENTHRALL_10463703031933500557: VariantsMap =
    [&["enthrall"], &["enthral"], &["enthrall"], &["enthral"]];

pub(crate) static ENTRY_ENTHRALL_16443508848218743746: VariantsMap =
    [&["enthrall"], &["enthral"], &["enthrall"], &["enthral"]];

pub(crate) static ENTRY_ENTHRONIZATIONS_17542858977423549781: VariantsMap = [
    &["enthronizations"],
    &["enthronisations"],
    &["enthronizations"],
    &["enthronisations"],
];

pub(crate) static ENTRY_ENTHRONIZATION_6974028193403231299: VariantsMap = [
    &["enthronization"],
    &["enthronisation"],
    &["enthronization"],
    &["enthronisation"],
];

pub(crate) static ENTRY_ENTHRONIZED_15570973078812509329: VariantsMap = [
    &["enthronized"],
    &["enthronised"],
    &["enthronized"],
    &["enthronised"],
];

pub(crate) static ENTRY_ENTHRONIZES_6728807480218746557: VariantsMap = [
    &["enthronizes"],
    &["enthronises"],
    &["enthronizes"],
    &["enthronises"],
];

pub(crate) static ENTRY_ENTHRONIZE_8479472121396981406: VariantsMap = [
    &["enthronize"],
    &["enthronise"],
    &["enthronize"],
    &["enthronise"],
];

pub(crate) static ENTRY_ENTHRONIZING_5022467519558443336: VariantsMap = [
    &["enthronizing"],
    &["enthronising"],
    &["enthronizing"],
    &["enthronising"],
];

pub(crate) static ENTRY_ENTOCELE_16862864757875933672: VariantsMap = [
    &["entocele"],
    &["entocoele"],
    &["entocoele"],
    &["entocoele"],
];

pub(crate) static ENTRY_ENTOMOLOGIZED_17180055652025722891: VariantsMap = [
    &["entomologized"],
    &["entomologised"],
    &["entomologized"],
    &["entomologised"],
];

pub(crate) static ENTRY_ENTOMOLOGIZES_14741971157180428511: VariantsMap = [
    &["entomologizes"],
    &["entomologises"],
    &["entomologizes"],
    &["entomologises"],
];

pub(crate) static ENTRY_ENTOMOLOGIZE_12930471317891860313: VariantsMap = [
    &["entomologize"],
    &["entomologise"],
    &["entomologize"],
    &["entomologise"],
];

pub(crate) static ENTRY_ENTOMOLOGIZING_541087590579894951: VariantsMap = [
    &["entomologizing"],
    &["entomologising"],
    &["entomologizing"],
    &["entomologising"],
];

pub(crate) static ENTRY_ENTRE_13397912193554137949: VariantsMap =
    [&["entre"], &["entrae"], &["entrae"], &["entrae"]];

pub(crate) static ENTRY_ENVAPORS_5110885845552232253: VariantsMap = [
    &["envapors"],
    &["envapours"],
    &["envapours"],
    &["envapours"],
];

pub(crate) static ENTRY_ENVAPOR_3613458891591634750: VariantsMap =
    [&["envapor"], &["envapour"], &["envapour"], &["envapour"]];

pub(crate) static ENTRY_ENVENOMIZATION_641743467429707201: VariantsMap = [
    &["envenomization"],
    &["envenomisation"],
    &["envenomization"],
    &["envenomisation"],
];

pub(crate) static ENTRY_EOLIC_690118974702284625: VariantsMap =
    [&["eolic"], &["aeolic"], &["aeolic"], &["aeolic"]];

pub(crate) static ENTRY_EOLIPILES_6469066293612545970: VariantsMap = [
    &["eolipiles"],
    &["aeolipiles"],
    &["aeolipiles"],
    &["aeolipiles"],
];

pub(crate) static ENTRY_EOLIPILE_11849651097249565492: VariantsMap = [
    &["eolipile"],
    &["aeolipile"],
    &["aeolipile"],
    &["aeolipile"],
];

pub(crate) static ENTRY_EOLOTROPIC_9928061474103766564: VariantsMap = [
    &["eolotropic"],
    &["aeolotropic"],
    &["aeolotropic"],
    &["aeolotropic"],
];

pub(crate) static ENTRY_EONIAN_2585817843108266796: VariantsMap =
    [&["eonian"], &["aeonian"], &["aeonian"], &["aeonian"]];

pub(crate) static ENTRY_EONISMS_13022437471464751142: VariantsMap =
    [&["eonisms"], &["aeonisms"], &["aeonisms"], &["aeonisms"]];

pub(crate) static ENTRY_EONISM_12314541365765950888: VariantsMap =
    [&["eonism"], &["aeonism"], &["aeonism"], &["aeonism"]];

pub(crate) static ENTRY_EOPALEOZOIC_13858730559448370168: VariantsMap = [
    &["eopaleozoic"],
    &["eopalaeozoic"],
    &["eopalaeozoic"],
    &["eopalaeozoic"],
];

pub(crate) static ENTRY_EPAULETS_16015840258717142271: VariantsMap = [
    &["epaulets"],
    &["epaulettes"],
    &["epaulettes"],
    &["epaulettes"],
];

pub(crate) static ENTRY_EPAULET_387424623527969944: VariantsMap =
    [&["epaulet"], &["epaulette"], &["epaulette"], &["epaulette"]];

pub(crate) static ENTRY_EPENETIC_4078091931289223174: VariantsMap = [
    &["epenetic"],
    &["epaenetic"],
    &["epaenetic"],
    &["epaenetic"],
];

pub(crate) static ENTRY_EPHETE_2596523211716991798: VariantsMap =
    [&["ephete"], &["ephetae"], &["ephetae"], &["ephetae"]];

pub(crate) static ENTRY_EPICELE_12455055708908810351: VariantsMap =
    [&["epicele"], &["epicoele"], &["epicoele"], &["epicoele"]];

pub(crate) static ENTRY_EPICENTERS_13863528771268891291: VariantsMap = [
    &["epicenters"],
    &["epicentres"],
    &["epicentres"],
    &["epicentres"],
];

pub(crate) static ENTRY_EPICENTER_16342724518099488548: VariantsMap = [
    &["epicenter"],
    &["epicentre"],
    &["epicentre"],
    &["epicentre"],
];

pub(crate) static ENTRY_EPICURIZED_8210844038944440883: VariantsMap = [
    &["epicurized"],
    &["epicurised"],
    &["epicurized"],
    &["epicurised"],
];

pub(crate) static ENTRY_EPICURIZES_604659561636523665: VariantsMap = [
    &["epicurizes"],
    &["epicurises"],
    &["epicurizes"],
    &["epicurises"],
];

pub(crate) static ENTRY_EPICURIZE_9792021232282849861: VariantsMap = [
    &["epicurize"],
    &["epicurise"],
    &["epicurize"],
    &["epicurise"],
];

pub(crate) static ENTRY_EPICURIZING_15655666870475102269: VariantsMap = [
    &["epicurizing"],
    &["epicurising"],
    &["epicurizing"],
    &["epicurising"],
];

pub(crate) static ENTRY_EPIDOTIZATIONS_17986813465862906948: VariantsMap = [
    &["epidotizations"],
    &["epidotisations"],
    &["epidotizations"],
    &["epidotisations"],
];

pub(crate) static ENTRY_EPIDOTIZATION_14022545118965805510: VariantsMap = [
    &["epidotization"],
    &["epidotisation"],
    &["epidotization"],
    &["epidotisation"],
];

pub(crate) static ENTRY_EPIDOTIZED_18043278384935210029: VariantsMap = [
    &["epidotized"],
    &["epidotised"],
    &["epidotized"],
    &["epidotised"],
];

pub(crate) static ENTRY_EPIGEAL_9418200985174229088: VariantsMap =
    [&["epigeal"], &["epigaeal"], &["epigaeal"], &["epigaeal"]];

pub(crate) static ENTRY_EPIGEAN_1067479460708884657: VariantsMap =
    [&["epigean"], &["epigaean"], &["epigaean"], &["epigaean"]];

pub(crate) static ENTRY_EPIGEOUS_2793155818327732975: VariantsMap = [
    &["epigeous"],
    &["epigaeous"],
    &["epigaeous"],
    &["epigaeous"],
];

pub(crate) static ENTRY_EPIGRAMMATIZATION_3435997769901871314: VariantsMap = [
    &["epigrammatization"],
    &["epigrammatisation"],
    &["epigrammatization"],
    &["epigrammatisation"],
];

pub(crate) static ENTRY_EPIGRAMMATIZED_3366561652151146715: VariantsMap = [
    &["epigrammatized"],
    &["epigrammatised"],
    &["epigrammatized"],
    &["epigrammatised"],
];

pub(crate) static ENTRY_EPIGRAMMATIZER_202382434686912143: VariantsMap = [
    &["epigrammatizer"],
    &["epigrammatiser"],
    &["epigrammatizer"],
    &["epigrammatiser"],
];

pub(crate) static ENTRY_EPIGRAMMATIZES_9870871179457908060: VariantsMap = [
    &["epigrammatizes"],
    &["epigrammatises"],
    &["epigrammatizes"],
    &["epigrammatises"],
];

pub(crate) static ENTRY_EPIGRAMMATIZE_13553329783728837308: VariantsMap = [
    &["epigrammatize"],
    &["epigrammatise"],
    &["epigrammatize"],
    &["epigrammatise"],
];

pub(crate) static ENTRY_EPIGRAMMATIZING_9925592242854198273: VariantsMap = [
    &["epigrammatizing"],
    &["epigrammatising"],
    &["epigrammatizing"],
    &["epigrammatising"],
];

pub(crate) static ENTRY_EPILOGIZED_13747207713324695603: VariantsMap = [
    &["epilogized"],
    &["epilogised"],
    &["epilogized"],
    &["epilogised"],
];

pub(crate) static ENTRY_EPILOGIZES_6060812301091580461: VariantsMap = [
    &["epilogizes"],
    &["epilogises"],
    &["epilogizes"],
    &["epilogises"],
];

pub(crate) static ENTRY_EPILOGIZE_5104820820812023953: VariantsMap = [
    &["epilogize"],
    &["epilogise"],
    &["epilogize"],
    &["epilogise"],
];

pub(crate) static ENTRY_EPILOGIZING_16045388830092914645: VariantsMap = [
    &["epilogizing"],
    &["epilogising"],
    &["epilogizing"],
    &["epilogising"],
];

pub(crate) static ENTRY_EPILOGUES_1045687645770537326: VariantsMap = [
    &["epilogues"],
    &["epilogues"],
    &["epilogues"],
    &["epilogues"],
];

pub(crate) static ENTRY_EPILOGUE_10590439015464966835: VariantsMap =
    [&["epilogue"], &["epilogue"], &["epilogue"], &["epilogue"]];

pub(crate) static ENTRY_EPILOGUIZED_12441365755453529023: VariantsMap = [
    &["epiloguized"],
    &["epiloguised"],
    &["epiloguized"],
    &["epiloguised"],
];

pub(crate) static ENTRY_EPILOGUIZES_2292690148409428255: VariantsMap = [
    &["epiloguizes"],
    &["epiloguises"],
    &["epiloguizes"],
    &["epiloguises"],
];

pub(crate) static ENTRY_EPILOGUIZE_689201102200555729: VariantsMap = [
    &["epiloguize"],
    &["epiloguise"],
    &["epiloguize"],
    &["epiloguise"],
];

pub(crate) static ENTRY_EPILOGUIZING_8986609211873957773: VariantsMap = [
    &["epiloguizing"],
    &["epiloguising"],
    &["epiloguizing"],
    &["epiloguising"],
];

pub(crate) static ENTRY_EPIMERIZED_14134076359123551022: VariantsMap = [
    &["epimerized"],
    &["epimerised"],
    &["epimerized"],
    &["epimerised"],
];

pub(crate) static ENTRY_EPIMERIZE_823465573203429173: VariantsMap = [
    &["epimerize"],
    &["epimerise"],
    &["epimerize"],
    &["epimerise"],
];

pub(crate) static ENTRY_EPIMERIZING_11872554676821586844: VariantsMap = [
    &["epimerizing"],
    &["epimerising"],
    &["epimerizing"],
    &["epimerising"],
];

pub(crate) static ENTRY_EPIPHANIZED_9129723971945803343: VariantsMap = [
    &["epiphanized"],
    &["epiphanised"],
    &["epiphanized"],
    &["epiphanised"],
];

pub(crate) static ENTRY_EPIPHANIZE_3444458754608259700: VariantsMap = [
    &["epiphanize"],
    &["epiphanise"],
    &["epiphanize"],
    &["epiphanise"],
];

pub(crate) static ENTRY_EPIPHANIZING_5611514449736046211: VariantsMap = [
    &["epiphanizing"],
    &["epiphanising"],
    &["epiphanizing"],
    &["epiphanising"],
];

pub(crate) static ENTRY_EPISCOPALIANIZES_14297906488956283731: VariantsMap = [
    &["episcopalianizes"],
    &["episcopalianises"],
    &["episcopalianizes"],
    &["episcopalianises"],
];

pub(crate) static ENTRY_EPISCOPALIANIZE_13601906048877534433: VariantsMap = [
    &["episcopalianize"],
    &["episcopalianise"],
    &["episcopalianize"],
    &["episcopalianise"],
];

pub(crate) static ENTRY_EPISCOPIZED_16650182802365832304: VariantsMap = [
    &["episcopized"],
    &["episcopised"],
    &["episcopized"],
    &["episcopised"],
];

pub(crate) static ENTRY_EPISCOPIZES_9627859512937099394: VariantsMap = [
    &["episcopizes"],
    &["episcopises"],
    &["episcopizes"],
    &["episcopises"],
];

pub(crate) static ENTRY_EPISCOPIZE_5941157562787933973: VariantsMap = [
    &["episcopize"],
    &["episcopise"],
    &["episcopize"],
    &["episcopise"],
];

pub(crate) static ENTRY_EPISCOPIZING_17988499911565815852: VariantsMap = [
    &["episcopizing"],
    &["episcopising"],
    &["episcopizing"],
    &["episcopising"],
];

pub(crate) static ENTRY_EPISTOLIZED_2534518570318818508: VariantsMap = [
    &["epistolized"],
    &["epistolised"],
    &["epistolized"],
    &["epistolised"],
];

pub(crate) static ENTRY_EPISTOLIZES_12529001542994955479: VariantsMap = [
    &["epistolizes"],
    &["epistolises"],
    &["epistolizes"],
    &["epistolises"],
];

pub(crate) static ENTRY_EPISTOLIZE_12798380956553546634: VariantsMap = [
    &["epistolize"],
    &["epistolise"],
    &["epistolize"],
    &["epistolise"],
];

pub(crate) static ENTRY_EPISTOLIZING_12184368088240887297: VariantsMap = [
    &["epistolizing"],
    &["epistolising"],
    &["epistolizing"],
    &["epistolising"],
];

pub(crate) static ENTRY_EPITAPHIZES_162759418609625372: VariantsMap = [
    &["epitaphizes"],
    &["epitaphises"],
    &["epitaphizes"],
    &["epitaphises"],
];

pub(crate) static ENTRY_EPITAPHIZE_13795478585860811984: VariantsMap = [
    &["epitaphize"],
    &["epitaphise"],
    &["epitaphize"],
    &["epitaphise"],
];

pub(crate) static ENTRY_EPITHETIZES_12815056524749670860: VariantsMap = [
    &["epithetizes"],
    &["epithetises"],
    &["epithetizes"],
    &["epithetises"],
];

pub(crate) static ENTRY_EPITHETIZE_14011874895566642629: VariantsMap = [
    &["epithetize"],
    &["epithetise"],
    &["epithetize"],
    &["epithetise"],
];

pub(crate) static ENTRY_EPITOMIZATIONS_16374827024040589670: VariantsMap = [
    &["epitomizations"],
    &["epitomisations"],
    &["epitomizations"],
    &["epitomisations"],
];

pub(crate) static ENTRY_EPITOMIZATION_16124019439482652962: VariantsMap = [
    &["epitomization"],
    &["epitomisation"],
    &["epitomization"],
    &["epitomisation"],
];

pub(crate) static ENTRY_EPITOMIZED_5424880168543124583: VariantsMap = [
    &["epitomized"],
    &["epitomised"],
    &["epitomized"],
    &["epitomised"],
];

pub(crate) static ENTRY_EPITOMIZERS_4593373083947475967: VariantsMap = [
    &["epitomizers"],
    &["epitomisers"],
    &["epitomizers"],
    &["epitomisers"],
];

pub(crate) static ENTRY_EPITOMIZER_8562118215235688018: VariantsMap = [
    &["epitomizer"],
    &["epitomiser"],
    &["epitomizer"],
    &["epitomiser"],
];

pub(crate) static ENTRY_EPITOMIZES_10955147197853926635: VariantsMap = [
    &["epitomizes"],
    &["epitomises"],
    &["epitomizes"],
    &["epitomises"],
];

pub(crate) static ENTRY_EPITOMIZE_13528530811124562195: VariantsMap = [
    &["epitomize"],
    &["epitomise"],
    &["epitomize"],
    &["epitomise"],
];

pub(crate) static ENTRY_EPITOMIZING_9913028102891579136: VariantsMap = [
    &["epitomizing"],
    &["epitomising"],
    &["epitomizing"],
    &["epitomising"],
];

pub(crate) static ENTRY_EQUALED_8356361230889842625: VariantsMap =
    [&["equaled"], &["equalled"], &["equalled"], &["equalled"]];

pub(crate) static ENTRY_EQUALING_76827185743864845: VariantsMap = [
    &["equaling"],
    &["equalling"],
    &["equalling"],
    &["equalling"],
];

pub(crate) static ENTRY_EQUALIZATIONS_682915140211915244: VariantsMap = [
    &["equalizations"],
    &["equalisations"],
    &["equalizations"],
    &["equalisations"],
];

pub(crate) static ENTRY_EQUALIZATION_417591381258528869: VariantsMap = [
    &["equalization"],
    &["equalisation"],
    &["equalization"],
    &["equalisation"],
];

pub(crate) static ENTRY_EQUALIZED_5400608554561448474: VariantsMap = [
    &["equalized"],
    &["equalised"],
    &["equalized"],
    &["equalised"],
];

pub(crate) static ENTRY_EQUALIZERS_11614687339668491001: VariantsMap = [
    &["equalizers"],
    &["equalisers"],
    &["equalizers"],
    &["equalisers"],
];

pub(crate) static ENTRY_EQUALIZER_2855584392309830652: VariantsMap = [
    &["equalizer"],
    &["equaliser"],
    &["equalizer"],
    &["equaliser"],
];

pub(crate) static ENTRY_EQUALIZES_1676516165012158279: VariantsMap = [
    &["equalizes"],
    &["equalises"],
    &["equalizes"],
    &["equalises"],
];

pub(crate) static ENTRY_EQUALIZE_6433971949536645353: VariantsMap =
    [&["equalize"], &["equalise"], &["equalize"], &["equalise"]];

pub(crate) static ENTRY_EQUALIZINGS_10284543548419639437: VariantsMap = [
    &["equalizings"],
    &["equalisings"],
    &["equalizings"],
    &["equalisings"],
];

pub(crate) static ENTRY_EQUALIZING_14679492934035290518: VariantsMap = [
    &["equalizing"],
    &["equalising"],
    &["equalizing"],
    &["equalising"],
];

pub(crate) static ENTRY_EQUESTRIANIZES_3846608224700022412: VariantsMap = [
    &["equestrianizes"],
    &["equestrianises"],
    &["equestrianizes"],
    &["equestrianises"],
];

pub(crate) static ENTRY_EQUESTRIANIZE_13136044868803266911: VariantsMap = [
    &["equestrianize"],
    &["equestrianise"],
    &["equestrianize"],
    &["equestrianise"],
];

pub(crate) static ENTRY_EQ_17801056412005353118: VariantsMap =
    [&["eq"], &["aeq"], &["aeq"], &["aeq"]];

pub(crate) static ENTRY_ERBIAS_7628332259520876430: VariantsMap =
    [&["erbias"], &["rebias"], &["rebias"], &["rebias"]];

pub(crate) static ENTRY_ERBIA_3590263034241709068: VariantsMap =
    [&["erbia"], &["rebia"], &["rebia"], &["rebia"]];

pub(crate) static ENTRY_ERGOTIZED_8120537335211967484: VariantsMap = [
    &["ergotized"],
    &["ergotised"],
    &["ergotized"],
    &["ergotised"],
];

pub(crate) static ENTRY_ERGOTIZES_2875829986652402100: VariantsMap = [
    &["ergotizes"],
    &["ergotises"],
    &["ergotizes"],
    &["ergotises"],
];

pub(crate) static ENTRY_ERGOTIZE_2413804013154734092: VariantsMap =
    [&["ergotize"], &["ergotise"], &["ergotize"], &["ergotise"]];

pub(crate) static ENTRY_ERGOTIZING_3389078505132496781: VariantsMap = [
    &["ergotizing"],
    &["ergotising"],
    &["ergotizing"],
    &["ergotising"],
];

pub(crate) static ENTRY_ERICAL_12478419361229949219: VariantsMap =
    [&["erical"], &["aerical"], &["aerical"], &["aerical"]];

pub(crate) static ENTRY_ERIC_7184163800386574200: VariantsMap =
    [&["eric"], &["aeric"], &["aeric"], &["aeric"]];

pub(crate) static ENTRY_ERKE_6039553976467525040: VariantsMap =
    [&["erke"], &["reke"], &["reke"], &["reke"]];

pub(crate) static ENTRY_ERNEST_2869565578515229588: VariantsMap =
    [&["ernest"], &["renest"], &["renest"], &["renest"]];

pub(crate) static ENTRY_ERNES_16282144925287112174: VariantsMap =
    [&["ernes"], &["renes"], &["renes"], &["renes"]];

pub(crate) static ENTRY_ERNS_11958672731540988082: VariantsMap =
    [&["erns"], &["rens"], &["rens"], &["rens"]];

pub(crate) static ENTRY_ERN_10092184086657301009: VariantsMap =
    [&["ern"], &["ren"], &["ren"], &["ren"]];

pub(crate) static ENTRY_EROGENESIS_4465855575040947833: VariantsMap = [
    &["erogenesis"],
    &["aerogenesis"],
    &["aerogenesis"],
    &["aerogenesis"],
];

pub(crate) static ENTRY_EROGENIC_3058184513432824304: VariantsMap = [
    &["erogenic"],
    &["aerogenic"],
    &["aerogenic"],
    &["aerogenic"],
];

pub(crate) static ENTRY_EROSE_5357559857770402424: VariantsMap =
    [&["erose"], &["aerose"], &["aerose"], &["aerose"]];

pub(crate) static ENTRY_EROS_265509765297093167: VariantsMap =
    [&["eros"], &["aeros"], &["aeros"], &["aeros"]];

pub(crate) static ENTRY_EROTICIZATION_2630432213360033255: VariantsMap = [
    &["eroticization"],
    &["eroticisation"],
    &["eroticization"],
    &["eroticisation"],
];

pub(crate) static ENTRY_EROTICIZED_13157811206734809042: VariantsMap = [
    &["eroticized"],
    &["eroticised"],
    &["eroticized"],
    &["eroticised"],
];

pub(crate) static ENTRY_EROTICIZES_4798707540088705022: VariantsMap = [
    &["eroticizes"],
    &["eroticises"],
    &["eroticizes"],
    &["eroticises"],
];

pub(crate) static ENTRY_EROTICIZE_10103435938228728741: VariantsMap = [
    &["eroticize"],
    &["eroticise"],
    &["eroticize"],
    &["eroticise"],
];

pub(crate) static ENTRY_EROTICIZING_7294701366490544040: VariantsMap = [
    &["eroticizing"],
    &["eroticising"],
    &["eroticizing"],
    &["eroticising"],
];

pub(crate) static ENTRY_ERSES_5709814492624908686: VariantsMap =
    [&["erses"], &["reses"], &["reses"], &["reses"]];

pub(crate) static ENTRY_ERSH_939187057767591954: VariantsMap =
    [&["ersh"], &["resh"], &["resh"], &["resh"]];

pub(crate) static ENTRY_ERT_3341098308248153715: VariantsMap =
    [&["ert"], &["ret"], &["ret"], &["ret"]];

pub(crate) static ENTRY_ERUGINOUS_5828853281772845437: VariantsMap = [
    &["eruginous"],
    &["aeruginous"],
    &["aeruginous"],
    &["aeruginous"],
];

pub(crate) static ENTRY_ERUGOS_15673647349394448977: VariantsMap =
    [&["erugos"], &["aerugos"], &["aerugos"], &["aerugos"]];

pub(crate) static ENTRY_ERUGO_17158132187061977414: VariantsMap =
    [&["erugo"], &["aerugo"], &["aerugo"], &["aerugo"]];

pub(crate) static ENTRY_ERVALENTAS_18174157063570728071: VariantsMap = [
    &["ervalentas"],
    &["revalentas"],
    &["revalentas"],
    &["revalentas"],
];

pub(crate) static ENTRY_ERVALENTA_10785450433515167284: VariantsMap = [
    &["ervalenta"],
    &["revalenta"],
    &["revalenta"],
    &["revalenta"],
];

pub(crate) static ENTRY_ERYTHREAN_10329526815525592119: VariantsMap = [
    &["erythrean"],
    &["erythraean"],
    &["erythraean"],
    &["erythraean"],
];

pub(crate) static ENTRY_ERYTHREMIA_836879494064020428: VariantsMap = [
    &["erythremia"],
    &["erythraemia"],
    &["erythraemia"],
    &["erythraemia"],
];

pub(crate) static ENTRY_ESCALADES_8447970127642962693: VariantsMap = [
    &["escalades"],
    &["escaladoes"],
    &["escaladoes"],
    &["escaladoes"],
];

pub(crate) static ENTRY_ESCHYNITE_18313041144585925088: VariantsMap = [
    &["eschynite"],
    &["aeschynite"],
    &["aeschynite"],
    &["aeschynite"],
];

pub(crate) static ENTRY_ESCULAPIAN_490183703265219666: VariantsMap = [
    &["esculapian"],
    &["aesculapian"],
    &["aesculapian"],
    &["aesculapian"],
];

pub(crate) static ENTRY_ESCULETIN_4799035190382857787: VariantsMap = [
    &["esculetin"],
    &["aesculetin"],
    &["aesculetin"],
    &["aesculetin"],
];

pub(crate) static ENTRY_ESCULIN_10740850830469064996: VariantsMap =
    [&["esculin"], &["aesculin"], &["aesculin"], &["aesculin"]];

pub(crate) static ENTRY_ESC_734356833349788703: VariantsMap =
    [&["esc"], &["aesc"], &["aesc"], &["aesc"]];

pub(crate) static ENTRY_ESKIMOIZEDS_8971879976387648671: VariantsMap = [
    &["eskimoizeds"],
    &["eskimoiseds"],
    &["eskimoizeds"],
    &["eskimoiseds"],
];

pub(crate) static ENTRY_ESKIMOIZED_4978095404438860814: VariantsMap = [
    &["eskimoized"],
    &["eskimoised"],
    &["eskimoized"],
    &["eskimoised"],
];

pub(crate) static ENTRY_ESOPHAGAL_17089437120427101379: VariantsMap = [
    &["esophagal"],
    &["oesophagal"],
    &["oesophagal"],
    &["oesophagal"],
];

pub(crate) static ENTRY_ESOPHAGEAN_1258506141459731259: VariantsMap = [
    &["esophagean"],
    &["oesophagean"],
    &["oesophagean"],
    &["oesophagean"],
];

pub(crate) static ENTRY_ESOPHAGISMUS_6650076607428716726: VariantsMap = [
    &["esophagismus"],
    &["oesophagismus"],
    &["oesophagismus"],
    &["oesophagismus"],
];

pub(crate) static ENTRY_ESOPHAGISM_11099656979396238835: VariantsMap = [
    &["esophagism"],
    &["oesophagism"],
    &["oesophagism"],
    &["oesophagism"],
];

pub(crate) static ENTRY_ESOPHAGITIS_2344628816303730914: VariantsMap = [
    &["esophagitis"],
    &["oesophagitis"],
    &["oesophagitis"],
    &["oesophagitis"],
];

pub(crate) static ENTRY_ESOPHAGI_16651245992122782472: VariantsMap =
    [&["esophagi"], &["oesophagi"], &["esophagi"], &["oesophagi"]];

pub(crate) static ENTRY_ESOPHAGUS_11192235604123814381: VariantsMap = [
    &["esophagus"],
    &["oesophagus"],
    &["oesophagus"],
    &["oesophagus"],
];

pub(crate) static ENTRY_ESOP_13490095149926411543: VariantsMap =
    [&["esop"], &["aesop"], &["aesop"], &["aesop"]];

pub(crate) static ENTRY_ESSENIZES_6228789074305241285: VariantsMap = [
    &["essenizes"],
    &["essenises"],
    &["essenizes"],
    &["essenises"],
];

pub(crate) static ENTRY_ESSENIZE_17352973219499483146: VariantsMap =
    [&["essenize"], &["essenise"], &["essenize"], &["essenise"]];

pub(crate) static ENTRY_ESSENTIALIZES_1314761290667427999: VariantsMap = [
    &["essentializes"],
    &["essentialises"],
    &["essentializes"],
    &["essentialises"],
];

pub(crate) static ENTRY_ESSENTIALIZE_6300653085008787820: VariantsMap = [
    &["essentialize"],
    &["essentialise"],
    &["essentialize"],
    &["essentialise"],
];

pub(crate) static ENTRY_ESTERIZATIONS_13064103908051692902: VariantsMap = [
    &["esterizations"],
    &["esterisations"],
    &["esterizations"],
    &["esterisations"],
];

pub(crate) static ENTRY_ESTERIZATION_1838643342430239163: VariantsMap = [
    &["esterization"],
    &["esterisation"],
    &["esterization"],
    &["esterisation"],
];

pub(crate) static ENTRY_ESTERIZES_1807746540502831909: VariantsMap = [
    &["esterizes"],
    &["esterises"],
    &["esterizes"],
    &["esterises"],
];

pub(crate) static ENTRY_ESTERIZE_14328305651236035983: VariantsMap =
    [&["esterize"], &["esterise"], &["esterize"], &["esterise"]];

pub(crate) static ENTRY_ESTHESES_16116389526306967239: VariantsMap = [
    &["estheses"],
    &["aestheses"],
    &["aestheses"],
    &["aestheses"],
];

pub(crate) static ENTRY_ESTHESIAS_5684600885047217053: VariantsMap = [
    &["esthesias"],
    &["aesthesias"],
    &["aesthesias"],
    &["aesthesias"],
];

pub(crate) static ENTRY_ESTHESIA_12451548753996008599: VariantsMap = [
    &["esthesia"],
    &["aesthesia"],
    &["aesthesia"],
    &["aesthesia"],
];

pub(crate) static ENTRY_ESTHESIOGENIC_8056723690025617876: VariantsMap = [
    &["esthesiogenic"],
    &["aesthesiogenic"],
    &["aesthesiogenic"],
    &["aesthesiogenic"],
];

pub(crate) static ENTRY_ESTHESIOGENS_8380315319153501054: VariantsMap = [
    &["esthesiogens"],
    &["aesthesiogens"],
    &["aesthesiogens"],
    &["aesthesiogens"],
];

pub(crate) static ENTRY_ESTHESIOGEN_10989515066374267030: VariantsMap = [
    &["esthesiogen"],
    &["aesthesiogen"],
    &["aesthesiogen"],
    &["aesthesiogen"],
];

pub(crate) static ENTRY_ESTHESIS_7143001285276086388: VariantsMap = [
    &["esthesis"],
    &["aesthesis"],
    &["aesthesis"],
    &["aesthesis"],
];

pub(crate) static ENTRY_ESTHETICAL_827198906307006506: VariantsMap = [
    &["esthetical"],
    &["aesthetical"],
    &["aesthetical"],
    &["aesthetical"],
];

pub(crate) static ENTRY_ESTHETICIANS_4428473313020471578: VariantsMap = [
    &["estheticians"],
    &["aestheticians"],
    &["aestheticians"],
    &["aestheticians"],
];

pub(crate) static ENTRY_ESTHETICIAN_4531333424171533067: VariantsMap = [
    &["esthetician"],
    &["aesthetician"],
    &["aesthetician"],
    &["aesthetician"],
];

pub(crate) static ENTRY_ESTIVAL_7252793851065540137: VariantsMap =
    [&["estival"], &["aestival"], &["aestival"], &["aestival"]];

pub(crate) static ENTRY_ESTIVATED_17659059957305359175: VariantsMap = [
    &["estivated"],
    &["aestivated"],
    &["aestivated"],
    &["aestivated"],
];

pub(crate) static ENTRY_ESTIVATES_15795900041274255113: VariantsMap = [
    &["estivates"],
    &["aestivates"],
    &["aestivates"],
    &["aestivates"],
];

pub(crate) static ENTRY_ESTIVATE_6682485567558262552: VariantsMap = [
    &["estivate"],
    &["aestivate"],
    &["aestivate"],
    &["aestivate"],
];

pub(crate) static ENTRY_ESTIVATING_3590628019702465357: VariantsMap = [
    &["estivating"],
    &["aestivating"],
    &["aestivating"],
    &["aestivating"],
];

pub(crate) static ENTRY_ESTIVATIONS_11925170250729275718: VariantsMap = [
    &["estivations"],
    &["aestivations"],
    &["aestivations"],
    &["aestivations"],
];

pub(crate) static ENTRY_ESTIVATION_970593505059854945: VariantsMap = [
    &["estivation"],
    &["aestivation"],
    &["aestivation"],
    &["aestivation"],
];

pub(crate) static ENTRY_ESTIVATOR_17192827254089360161: VariantsMap = [
    &["estivator"],
    &["aestivator"],
    &["aestivator"],
    &["aestivator"],
];

pub(crate) static ENTRY_ESTIVE_5420134362059951702: VariantsMap =
    [&["estive"], &["aestive"], &["aestive"], &["aestive"]];

pub(crate) static ENTRY_ESTRADIOLS_6587359583583660465: VariantsMap = [
    &["estradiols"],
    &["oestradiols"],
    &["oestradiols"],
    &["oestradiols"],
];

pub(crate) static ENTRY_ESTRADIOL_634787677538270649: VariantsMap = [
    &["estradiol"],
    &["oestradiol"],
    &["oestradiol"],
    &["oestradiol"],
];

pub(crate) static ENTRY_ESTRAL_250960197285450439: VariantsMap =
    [&["estral"], &["oestral"], &["oestral"], &["oestral"]];

pub(crate) static ENTRY_ESTRINS_11482863399944620630: VariantsMap =
    [&["estrins"], &["oestrins"], &["oestrins"], &["oestrins"]];

pub(crate) static ENTRY_ESTRIN_1271537042891040806: VariantsMap =
    [&["estrin"], &["oestrin"], &["oestrin"], &["oestrin"]];

pub(crate) static ENTRY_ESTRIOLS_15504531823851684601: VariantsMap = [
    &["estriols"],
    &["oestriols"],
    &["oestriols"],
    &["oestriols"],
];

pub(crate) static ENTRY_ESTRIOL_5700840801301268453: VariantsMap =
    [&["estriol"], &["oestriol"], &["oestriol"], &["oestriol"]];

pub(crate) static ENTRY_ESTROGENIC_9825757897324531986: VariantsMap = [
    &["estrogenic"],
    &["oestrogenic"],
    &["estrogenic"],
    &["oestrogenic"],
];

pub(crate) static ENTRY_ESTROGENS_13879624153768181446: VariantsMap = [
    &["estrogens"],
    &["oestrogens"],
    &["estrogens"],
    &["oestrogens"],
];

pub(crate) static ENTRY_ESTROGEN_9296702706992805950: VariantsMap =
    [&["estrogen"], &["oestrogen"], &["estrogen"], &["oestrogen"]];

pub(crate) static ENTRY_ESTRONES_396980696513423065: VariantsMap = [
    &["estrones"],
    &["oestrones"],
    &["oestrones"],
    &["oestrones"],
];

pub(crate) static ENTRY_ESTRONE_5235731124564419249: VariantsMap =
    [&["estrone"], &["oestrone"], &["oestrone"], &["oestrone"]];

pub(crate) static ENTRY_ESTROUS_3175557539569890653: VariantsMap =
    [&["estrous"], &["oestrous"], &["estrous"], &["oestrous"]];

pub(crate) static ENTRY_ESTRUAL_2760322156873020612: VariantsMap =
    [&["estrual"], &["oestrual"], &["oestrual"], &["oestrual"]];

pub(crate) static ENTRY_ESTRUATE_9742423605759945651: VariantsMap = [
    &["estruate"],
    &["oestruate"],
    &["oestruate"],
    &["oestruate"],
];

pub(crate) static ENTRY_ESTRUATION_528782982925379226: VariantsMap = [
    &["estruation"],
    &["oestruation"],
    &["oestruation"],
    &["oestruation"],
];

pub(crate) static ENTRY_ESTRUMS_13425140989742183588: VariantsMap =
    [&["estrums"], &["oestrums"], &["oestrums"], &["oestrums"]];

pub(crate) static ENTRY_ESTRUM_80713081920872301: VariantsMap =
    [&["estrum"], &["oestrum"], &["oestrum"], &["oestrum"]];

pub(crate) static ENTRY_ESTRUSES_10476871772114155317: VariantsMap =
    [&["estruses"], &["oestruses"], &["estruses"], &["oestruses"]];

pub(crate) static ENTRY_ESTRUS_12109407348878630371: VariantsMap =
    [&["estrus"], &["oestrus"], &["estrus"], &["oestrus"]];

pub(crate) static ENTRY_ESTUATE_7237204571723121927: VariantsMap =
    [&["estuate"], &["aestuate"], &["aestuate"], &["aestuate"]];

pub(crate) static ENTRY_ESTUOUS_15581034853542643799: VariantsMap =
    [&["estuous"], &["aestuous"], &["aestuous"], &["aestuous"]];

pub(crate) static ENTRY_ESTURE_3483676630062562550: VariantsMap =
    [&["esture"], &["aesture"], &["aesture"], &["aesture"]];

pub(crate) static ENTRY_ESTUS_10309034292162795617: VariantsMap =
    [&["estus"], &["aestus"], &["aestus"], &["aestus"]];

pub(crate) static ENTRY_ETERNALIZATIONS_1580610116895380250: VariantsMap = [
    &["eternalizations"],
    &["eternalisations"],
    &["eternalizations"],
    &["eternalisations"],
];

pub(crate) static ENTRY_ETERNALIZATION_3734495480513175198: VariantsMap = [
    &["eternalization"],
    &["eternalisation"],
    &["eternalization"],
    &["eternalisation"],
];

pub(crate) static ENTRY_ETERNALIZED_9585284058759840856: VariantsMap = [
    &["eternalized"],
    &["eternalised"],
    &["eternalized"],
    &["eternalised"],
];

pub(crate) static ENTRY_ETERNALIZES_4326233422849452608: VariantsMap = [
    &["eternalizes"],
    &["eternalises"],
    &["eternalizes"],
    &["eternalises"],
];

pub(crate) static ENTRY_ETERNALIZE_11131798101969437364: VariantsMap = [
    &["eternalize"],
    &["eternalise"],
    &["eternalize"],
    &["eternalise"],
];

pub(crate) static ENTRY_ETERNALIZING_14008573203681681715: VariantsMap = [
    &["eternalizing"],
    &["eternalising"],
    &["eternalizing"],
    &["eternalising"],
];

pub(crate) static ENTRY_ETERNIZATIONS_8586384193807168026: VariantsMap = [
    &["eternizations"],
    &["eternisations"],
    &["eternizations"],
    &["eternisations"],
];

pub(crate) static ENTRY_ETERNIZATION_2995449191647800002: VariantsMap = [
    &["eternization"],
    &["eternisation"],
    &["eternization"],
    &["eternisation"],
];

pub(crate) static ENTRY_ETERNIZED_803700093303685693: VariantsMap = [
    &["eternized"],
    &["eternised"],
    &["eternized"],
    &["eternised"],
];

pub(crate) static ENTRY_ETERNIZES_13889836130672451566: VariantsMap = [
    &["eternizes"],
    &["eternises"],
    &["eternizes"],
    &["eternises"],
];

pub(crate) static ENTRY_ETERNIZE_9225349190347066102: VariantsMap =
    [&["eternize"], &["eternise"], &["eternize"], &["eternise"]];

pub(crate) static ENTRY_ETERNIZING_10174905521874007767: VariantsMap = [
    &["eternizing"],
    &["eternising"],
    &["eternizing"],
    &["eternising"],
];

pub(crate) static ENTRY_ETHELING_7453000440584654761: VariantsMap = [
    &["etheling"],
    &["aetheling"],
    &["aetheling"],
    &["aetheling"],
];

pub(crate) static ENTRY_ETHEREALIZATIONS_2132392675240347392: VariantsMap = [
    &["etherealizations"],
    &["etherealisations"],
    &["etherealizations"],
    &["etherealisations"],
];

pub(crate) static ENTRY_ETHEREALIZATION_12734652389847905816: VariantsMap = [
    &["etherealization"],
    &["etherealisation"],
    &["etherealization"],
    &["etherealisation"],
];

pub(crate) static ENTRY_ETHEREALIZED_5421449992122948198: VariantsMap = [
    &["etherealized"],
    &["etherealised"],
    &["etherealized"],
    &["etherealised"],
];

pub(crate) static ENTRY_ETHEREALIZES_5231734843750416436: VariantsMap = [
    &["etherealizes"],
    &["etherealises"],
    &["etherealizes"],
    &["etherealises"],
];

pub(crate) static ENTRY_ETHEREALIZE_2065340124732116568: VariantsMap = [
    &["etherealize"],
    &["etherealise"],
    &["etherealize"],
    &["etherealise"],
];

pub(crate) static ENTRY_ETHEREALIZING_17209337922860403926: VariantsMap = [
    &["etherealizing"],
    &["etherealising"],
    &["etherealizing"],
    &["etherealising"],
];

pub(crate) static ENTRY_ETHERED_11737830389019716848: VariantsMap =
    [&["ethered"], &["aethered"], &["aethered"], &["aethered"]];

pub(crate) static ENTRY_ETHERIALIZATION_13934934240531358321: VariantsMap = [
    &["etherialization"],
    &["etherialisation"],
    &["etherialization"],
    &["etherialisation"],
];

pub(crate) static ENTRY_ETHERIALIZED_6425316747358472251: VariantsMap = [
    &["etherialized"],
    &["etherialised"],
    &["etherialized"],
    &["etherialised"],
];

pub(crate) static ENTRY_ETHERIALIZE_16410637034856874095: VariantsMap = [
    &["etherialize"],
    &["etherialise"],
    &["etherialize"],
    &["etherialise"],
];

pub(crate) static ENTRY_ETHERIALIZING_5420182430706962967: VariantsMap = [
    &["etherializing"],
    &["etherialising"],
    &["etherializing"],
    &["etherialising"],
];

pub(crate) static ENTRY_ETHERIC_14308840270744949246: VariantsMap =
    [&["etheric"], &["aetheric"], &["aetheric"], &["aetheric"]];

pub(crate) static ENTRY_ETHERIZATIONS_12592394080916973256: VariantsMap = [
    &["etherizations"],
    &["etherisations"],
    &["etherizations"],
    &["etherisations"],
];

pub(crate) static ENTRY_ETHERIZATION_2978885687909295823: VariantsMap = [
    &["etherization"],
    &["etherisation"],
    &["etherization"],
    &["etherisation"],
];

pub(crate) static ENTRY_ETHERIZED_13463455547519294082: VariantsMap = [
    &["etherized"],
    &["etherised"],
    &["etherized"],
    &["etherised"],
];

pub(crate) static ENTRY_ETHERIZERS_10538480316981131131: VariantsMap = [
    &["etherizers"],
    &["etherisers"],
    &["etherizers"],
    &["etherisers"],
];

pub(crate) static ENTRY_ETHERIZER_10217889819429808699: VariantsMap = [
    &["etherizer"],
    &["etheriser"],
    &["etherizer"],
    &["etheriser"],
];

pub(crate) static ENTRY_ETHERIZES_13469750050699304076: VariantsMap = [
    &["etherizes"],
    &["etherises"],
    &["etherizes"],
    &["etherises"],
];

pub(crate) static ENTRY_ETHERIZE_14089274929682497230: VariantsMap =
    [&["etherize"], &["etherise"], &["etherize"], &["etherise"]];

pub(crate) static ENTRY_ETHERIZING_5812365847799688656: VariantsMap = [
    &["etherizing"],
    &["etherising"],
    &["etherizing"],
    &["etherising"],
];

pub(crate) static ENTRY_ETHICIZATION_7982960618336992609: VariantsMap = [
    &["ethicization"],
    &["ethicisation"],
    &["ethicization"],
    &["ethicisation"],
];

pub(crate) static ENTRY_ETHICIZED_13298420094237367669: VariantsMap = [
    &["ethicized"],
    &["ethicised"],
    &["ethicized"],
    &["ethicised"],
];

pub(crate) static ENTRY_ETHICIZES_4425545207707744116: VariantsMap = [
    &["ethicizes"],
    &["ethicises"],
    &["ethicizes"],
    &["ethicises"],
];

pub(crate) static ENTRY_ETHICIZE_9319969408983326697: VariantsMap =
    [&["ethicize"], &["ethicise"], &["ethicize"], &["ethicise"]];

pub(crate) static ENTRY_ETHICIZING_13920935019894378060: VariantsMap = [
    &["ethicizing"],
    &["ethicising"],
    &["ethicizing"],
    &["ethicising"],
];

pub(crate) static ENTRY_ETHNICIZES_17717835002455612610: VariantsMap = [
    &["ethnicizes"],
    &["ethnicises"],
    &["ethnicizes"],
    &["ethnicises"],
];

pub(crate) static ENTRY_ETHNICIZE_9658075899558980564: VariantsMap = [
    &["ethnicize"],
    &["ethnicise"],
    &["ethnicize"],
    &["ethnicise"],
];

pub(crate) static ENTRY_ETIOGENIC_4607596180327733291: VariantsMap = [
    &["etiogenic"],
    &["aetiogenic"],
    &["aetiogenic"],
    &["aetiogenic"],
];

pub(crate) static ENTRY_ETIOLOGICALLY_16961054798674884692: VariantsMap = [
    &["etiologically"],
    &["aetiologically"],
    &["etiologically"],
    &["aetiologically"],
];

pub(crate) static ENTRY_ETIOLOGIST_11212980661305626571: VariantsMap = [
    &["etiologist"],
    &["aetiologist"],
    &["aetiologist"],
    &["aetiologist"],
];

pub(crate) static ENTRY_ETIOLOGUE_3427764260416926249: VariantsMap = [
    &["etiologue"],
    &["aetiologue"],
    &["aetiologue"],
    &["aetiologue"],
];

pub(crate) static ENTRY_ETIOLOGY_7123968270032580321: VariantsMap =
    [&["etiology"], &["aetiology"], &["etiology"], &["aetiology"]];

pub(crate) static ENTRY_ETIOPHYLLIN_9404514496968390932: VariantsMap = [
    &["etiophyllin"],
    &["aetiophyllin"],
    &["aetiophyllin"],
    &["aetiophyllin"],
];

pub(crate) static ENTRY_ETIOTROPICALLY_9902369940420748380: VariantsMap = [
    &["etiotropically"],
    &["aetiotropically"],
    &["aetiotropically"],
    &["aetiotropically"],
];

pub(crate) static ENTRY_ETIOTROPIC_17191333273430729692: VariantsMap = [
    &["etiotropic"],
    &["aetiotropic"],
    &["aetiotropic"],
    &["aetiotropic"],
];

pub(crate) static ENTRY_ETYMOLOGIZABLE_14324009501183818334: VariantsMap = [
    &["etymologizable"],
    &["etymologisable"],
    &["etymologizable"],
    &["etymologisable"],
];

pub(crate) static ENTRY_ETYMOLOGIZATION_6720014631573230453: VariantsMap = [
    &["etymologization"],
    &["etymologisation"],
    &["etymologization"],
    &["etymologisation"],
];

pub(crate) static ENTRY_ETYMOLOGIZED_9179162719754519975: VariantsMap = [
    &["etymologized"],
    &["etymologised"],
    &["etymologized"],
    &["etymologised"],
];

pub(crate) static ENTRY_ETYMOLOGIZES_18258268798885199036: VariantsMap = [
    &["etymologizes"],
    &["etymologises"],
    &["etymologizes"],
    &["etymologises"],
];

pub(crate) static ENTRY_ETYMOLOGIZE_9732898285094826377: VariantsMap = [
    &["etymologize"],
    &["etymologise"],
    &["etymologize"],
    &["etymologise"],
];

pub(crate) static ENTRY_ETYMOLOGIZING_10793154235770650022: VariantsMap = [
    &["etymologizing"],
    &["etymologising"],
    &["etymologizing"],
    &["etymologising"],
];

pub(crate) static ENTRY_ET_11650800039480951541: VariantsMap =
    [&["et"], &["aet"], &["aet"], &["aet"]];

pub(crate) static ENTRY_EUDEMONIA_8536611909974853285: VariantsMap = [
    &["eudemonia"],
    &["eudaemonia"],
    &["eudaemonia"],
    &["eudaemonia"],
];

pub(crate) static ENTRY_EUDEMONICS_11983069269785700336: VariantsMap = [
    &["eudemonics"],
    &["eudaemonics"],
    &["eudaemonics"],
    &["eudaemonics"],
];

pub(crate) static ENTRY_EUDEMONIC_10703096338080832052: VariantsMap = [
    &["eudemonic"],
    &["eudaemonic"],
    &["eudaemonic"],
    &["eudaemonic"],
];

pub(crate) static ENTRY_EUDEMONISMS_9663152886088963814: VariantsMap = [
    &["eudemonisms"],
    &["eudaemonisms"],
    &["eudaemonisms"],
    &["eudaemonisms"],
];

pub(crate) static ENTRY_EUDEMONISM_2030451125927147437: VariantsMap = [
    &["eudemonism"],
    &["eudaemonism"],
    &["eudaemonism"],
    &["eudaemonism"],
];

pub(crate) static ENTRY_EUDEMONISTICALLY_11557458762944374366: VariantsMap = [
    &["eudemonistically"],
    &["eudaemonistically"],
    &["eudaemonistically"],
    &["eudaemonistically"],
];

pub(crate) static ENTRY_EUDEMONISTICAL_5594575273383737360: VariantsMap = [
    &["eudemonistical"],
    &["eudaemonistical"],
    &["eudaemonistical"],
    &["eudaemonistical"],
];

pub(crate) static ENTRY_EUDEMONISTIC_4092483053014414870: VariantsMap = [
    &["eudemonistic"],
    &["eudaemonistic"],
    &["eudaemonistic"],
    &["eudaemonistic"],
];

pub(crate) static ENTRY_EUDEMONISTS_8607780052774605016: VariantsMap = [
    &["eudemonists"],
    &["eudaemonists"],
    &["eudaemonists"],
    &["eudaemonists"],
];

pub(crate) static ENTRY_EUDEMONIST_10437519314337880945: VariantsMap = [
    &["eudemonist"],
    &["eudaemonist"],
    &["eudaemonist"],
    &["eudaemonist"],
];

pub(crate) static ENTRY_EUDEMONS_619440478160622096: VariantsMap = [
    &["eudemons"],
    &["eudaemons"],
    &["eudaemons"],
    &["eudaemons"],
];

pub(crate) static ENTRY_EUDEMONY_7203436464418206960: VariantsMap = [
    &["eudemony"],
    &["eudaemony"],
    &["eudaemony"],
    &["eudaemony"],
];

pub(crate) static ENTRY_EUDEMON_11438303724932164772: VariantsMap =
    [&["eudemon"], &["eudaemon"], &["eudaemon"], &["eudaemon"]];

pub(crate) static ENTRY_EUHEMERIZED_13249306373968955924: VariantsMap = [
    &["euhemerized"],
    &["euhemerised"],
    &["euhemerized"],
    &["euhemerised"],
];

pub(crate) static ENTRY_EUHEMERIZES_2599757245144591712: VariantsMap = [
    &["euhemerizes"],
    &["euhemerises"],
    &["euhemerizes"],
    &["euhemerises"],
];

pub(crate) static ENTRY_EUHEMERIZE_10861960486485255136: VariantsMap = [
    &["euhemerize"],
    &["euhemerise"],
    &["euhemerize"],
    &["euhemerise"],
];

pub(crate) static ENTRY_EUHEMERIZING_9558743899414823460: VariantsMap = [
    &["euhemerizing"],
    &["euhemerising"],
    &["euhemerizing"],
    &["euhemerising"],
];

pub(crate) static ENTRY_EULOGIZATIONS_7636756562230100487: VariantsMap = [
    &["eulogizations"],
    &["eulogisations"],
    &["eulogizations"],
    &["eulogisations"],
];

pub(crate) static ENTRY_EULOGIZATION_10282426959041271101: VariantsMap = [
    &["eulogization"],
    &["eulogisation"],
    &["eulogization"],
    &["eulogisation"],
];

pub(crate) static ENTRY_EULOGIZED_2725015015260591952: VariantsMap = [
    &["eulogized"],
    &["eulogised"],
    &["eulogized"],
    &["eulogised"],
];

pub(crate) static ENTRY_EULOGIZERS_14136473823163628988: VariantsMap = [
    &["eulogizers"],
    &["eulogisers"],
    &["eulogizers"],
    &["eulogisers"],
];

pub(crate) static ENTRY_EULOGIZER_1964342767045376178: VariantsMap = [
    &["eulogizer"],
    &["eulogiser"],
    &["eulogizer"],
    &["eulogiser"],
];

pub(crate) static ENTRY_EULOGIZES_14586567692374933834: VariantsMap = [
    &["eulogizes"],
    &["eulogises"],
    &["eulogizes"],
    &["eulogises"],
];

pub(crate) static ENTRY_EULOGIZE_1653837351412814344: VariantsMap =
    [&["eulogize"], &["eulogise"], &["eulogize"], &["eulogise"]];

pub(crate) static ENTRY_EULOGIZING_12476629388826192151: VariantsMap = [
    &["eulogizing"],
    &["eulogising"],
    &["eulogizing"],
    &["eulogising"],
];

pub(crate) static ENTRY_EUNUCHIZED_13625235435443656462: VariantsMap = [
    &["eunuchized"],
    &["eunuchised"],
    &["eunuchized"],
    &["eunuchised"],
];

pub(crate) static ENTRY_EUNUCHIZES_13328477625215260244: VariantsMap = [
    &["eunuchizes"],
    &["eunuchises"],
    &["eunuchizes"],
    &["eunuchises"],
];

pub(crate) static ENTRY_EUNUCHIZE_15135167016143668512: VariantsMap = [
    &["eunuchize"],
    &["eunuchise"],
    &["eunuchize"],
    &["eunuchise"],
];

pub(crate) static ENTRY_EUNUCHIZING_1999758532637837177: VariantsMap = [
    &["eunuchizing"],
    &["eunuchising"],
    &["eunuchizing"],
    &["eunuchising"],
];

pub(crate) static ENTRY_EUPHEMIZATION_15897062775810681100: VariantsMap = [
    &["euphemization"],
    &["euphemisation"],
    &["euphemization"],
    &["euphemisation"],
];

pub(crate) static ENTRY_EUPHEMIZED_16524474124949436387: VariantsMap = [
    &["euphemized"],
    &["euphemised"],
    &["euphemized"],
    &["euphemised"],
];

pub(crate) static ENTRY_EUPHEMIZERS_14865306922922439267: VariantsMap = [
    &["euphemizers"],
    &["euphemisers"],
    &["euphemizers"],
    &["euphemisers"],
];

pub(crate) static ENTRY_EUPHEMIZER_3905220143608307778: VariantsMap = [
    &["euphemizer"],
    &["euphemiser"],
    &["euphemizer"],
    &["euphemiser"],
];

pub(crate) static ENTRY_EUPHEMIZES_13615629412067350528: VariantsMap = [
    &["euphemizes"],
    &["euphemises"],
    &["euphemizes"],
    &["euphemises"],
];

pub(crate) static ENTRY_EUPHEMIZE_6156608839130565166: VariantsMap = [
    &["euphemize"],
    &["euphemise"],
    &["euphemize"],
    &["euphemise"],
];

pub(crate) static ENTRY_EUPHEMIZING_14044452417298877788: VariantsMap = [
    &["euphemizing"],
    &["euphemising"],
    &["euphemizing"],
    &["euphemising"],
];

pub(crate) static ENTRY_EUPHONIZATION_8160800683971054658: VariantsMap = [
    &["euphonization"],
    &["euphonisation"],
    &["euphonization"],
    &["euphonisation"],
];

pub(crate) static ENTRY_EUPHONIZED_2332221337646658561: VariantsMap = [
    &["euphonized"],
    &["euphonised"],
    &["euphonized"],
    &["euphonised"],
];

pub(crate) static ENTRY_EUPHONIZES_10361394233532999333: VariantsMap = [
    &["euphonizes"],
    &["euphonises"],
    &["euphonizes"],
    &["euphonises"],
];

pub(crate) static ENTRY_EUPHONIZE_12154684566192054671: VariantsMap = [
    &["euphonize"],
    &["euphonise"],
    &["euphonize"],
    &["euphonise"],
];

pub(crate) static ENTRY_EUPHONIZING_12869225507816001400: VariantsMap = [
    &["euphonizing"],
    &["euphonising"],
    &["euphonizing"],
    &["euphonising"],
];

pub(crate) static ENTRY_EUPHUIZED_16530053689080256866: VariantsMap = [
    &["euphuized"],
    &["euphuised"],
    &["euphuized"],
    &["euphuised"],
];

pub(crate) static ENTRY_EUPHUIZES_1610646119362678571: VariantsMap = [
    &["euphuizes"],
    &["euphuises"],
    &["euphuizes"],
    &["euphuises"],
];

pub(crate) static ENTRY_EUPHUIZE_7719186029258614802: VariantsMap =
    [&["euphuize"], &["euphuise"], &["euphuize"], &["euphuise"]];

pub(crate) static ENTRY_EUPHUIZING_13793329409991103775: VariantsMap = [
    &["euphuizing"],
    &["euphuising"],
    &["euphuizing"],
    &["euphuising"],
];

pub(crate) static ENTRY_EUPNEAS_17113263914966538934: VariantsMap =
    [&["eupneas"], &["eupnoeas"], &["eupnoeas"], &["eupnoeas"]];

pub(crate) static ENTRY_EUPNEA_15696889609657452284: VariantsMap =
    [&["eupnea"], &["eupnoea"], &["eupnoea"], &["eupnoea"]];

pub(crate) static ENTRY_EUPNEIC_10760124621699958430: VariantsMap =
    [&["eupneic"], &["eupnoeic"], &["eupnoeic"], &["eupnoeic"]];

pub(crate) static ENTRY_EUROPEANIZATIONS_10170958288412142340: VariantsMap = [
    &["europeanizations"],
    &["europeanisations"],
    &["europeanizations"],
    &["europeanisations"],
];

pub(crate) static ENTRY_EUROPEANIZATION_1560895436028194898: VariantsMap = [
    &["europeanization"],
    &["europeanisation"],
    &["europeanization"],
    &["europeanisation"],
];

pub(crate) static ENTRY_EUROPEANIZED_4342167856841628431: VariantsMap = [
    &["europeanized"],
    &["europeanised"],
    &["europeanized"],
    &["europeanised"],
];

pub(crate) static ENTRY_EUROPEANIZES_12996997230914775868: VariantsMap = [
    &["europeanizes"],
    &["europeanises"],
    &["europeanizes"],
    &["europeanises"],
];

pub(crate) static ENTRY_EUROPEANIZE_9458498374082461253: VariantsMap = [
    &["europeanize"],
    &["europeanise"],
    &["europeanize"],
    &["europeanise"],
];

pub(crate) static ENTRY_EUROPEANIZING_17501868806425018896: VariantsMap = [
    &["europeanizing"],
    &["europeanising"],
    &["europeanizing"],
    &["europeanising"],
];

pub(crate) static ENTRY_EURYALE_4488395712087565374: VariantsMap =
    [&["euryale"], &["euryalae"], &["euryalae"], &["euryalae"]];

pub(crate) static ENTRY_EVANGELIZATIONS_14789777873996157817: VariantsMap = [
    &["evangelizations"],
    &["evangelisations"],
    &["evangelizations"],
    &["evangelisations"],
];

pub(crate) static ENTRY_EVANGELIZATION_4680427557456788664: VariantsMap = [
    &["evangelization"],
    &["evangelisation"],
    &["evangelization"],
    &["evangelisation"],
];

pub(crate) static ENTRY_EVANGELIZED_17876535001172708816: VariantsMap = [
    &["evangelized"],
    &["evangelised"],
    &["evangelized"],
    &["evangelised"],
];

pub(crate) static ENTRY_EVANGELIZERS_14546686203602221124: VariantsMap = [
    &["evangelizers"],
    &["evangelisers"],
    &["evangelizers"],
    &["evangelisers"],
];

pub(crate) static ENTRY_EVANGELIZER_23648629311545236: VariantsMap = [
    &["evangelizer"],
    &["evangeliser"],
    &["evangelizer"],
    &["evangeliser"],
];

pub(crate) static ENTRY_EVANGELIZES_1437826998377524710: VariantsMap = [
    &["evangelizes"],
    &["evangelises"],
    &["evangelizes"],
    &["evangelises"],
];

pub(crate) static ENTRY_EVANGELIZE_14654810833594718867: VariantsMap = [
    &["evangelize"],
    &["evangelise"],
    &["evangelize"],
    &["evangelise"],
];

pub(crate) static ENTRY_EVANGELIZING_16366309279292917989: VariantsMap = [
    &["evangelizing"],
    &["evangelising"],
    &["evangelizing"],
    &["evangelising"],
];

pub(crate) static ENTRY_EVENTUALIZED_6892945154115451414: VariantsMap = [
    &["eventualized"],
    &["eventualised"],
    &["eventualized"],
    &["eventualised"],
];

pub(crate) static ENTRY_EVENTUALIZES_2708156416876716226: VariantsMap = [
    &["eventualizes"],
    &["eventualises"],
    &["eventualizes"],
    &["eventualises"],
];

pub(crate) static ENTRY_EVENTUALIZE_367328542530437546: VariantsMap = [
    &["eventualize"],
    &["eventualise"],
    &["eventualize"],
    &["eventualise"],
];

pub(crate) static ENTRY_EVENTUALIZING_3264561079067185461: VariantsMap = [
    &["eventualizing"],
    &["eventualising"],
    &["eventualizing"],
    &["eventualising"],
];

pub(crate) static ENTRY_EVILER_16165460214642184499: VariantsMap =
    [&["eviler"], &["eviller"], &["eviller"], &["eviller"]];

pub(crate) static ENTRY_EVILEST_2003136876659939656: VariantsMap =
    [&["evilest"], &["evillest"], &["evillest"], &["evillest"]];

pub(crate) static ENTRY_EVITERNAL_11859651719653588022: VariantsMap = [
    &["eviternal"],
    &["aeviternal"],
    &["aeviternal"],
    &["aeviternal"],
];

pub(crate) static ENTRY_EVOLUTIONIZES_7496995105206806629: VariantsMap = [
    &["evolutionizes"],
    &["evolutionises"],
    &["evolutionizes"],
    &["evolutionises"],
];

pub(crate) static ENTRY_EVOLUTIONIZE_8517112820891861723: VariantsMap = [
    &["evolutionize"],
    &["evolutionise"],
    &["evolutionize"],
    &["evolutionise"],
];

pub(crate) static ENTRY_EXCURSIONIZED_1665688933464332989: VariantsMap = [
    &["excursionized"],
    &["excursionised"],
    &["excursionized"],
    &["excursionised"],
];

pub(crate) static ENTRY_EXCURSIONIZES_8190667252177395210: VariantsMap = [
    &["excursionizes"],
    &["excursionises"],
    &["excursionizes"],
    &["excursionises"],
];

pub(crate) static ENTRY_EXCURSIONIZE_6141947279836282456: VariantsMap = [
    &["excursionize"],
    &["excursionise"],
    &["excursionize"],
    &["excursionise"],
];

pub(crate) static ENTRY_EXCURSIONIZING_17254186462773543752: VariantsMap = [
    &["excursionizing"],
    &["excursionising"],
    &["excursionizing"],
    &["excursionising"],
];

pub(crate) static ENTRY_EXESTUATE_9637260798228903273: VariantsMap = [
    &["exestuate"],
    &["exaestuate"],
    &["exaestuate"],
    &["exaestuate"],
];

pub(crate) static ENTRY_EXHIBITIONIZES_9279135115141727061: VariantsMap = [
    &["exhibitionizes"],
    &["exhibitionises"],
    &["exhibitionizes"],
    &["exhibitionises"],
];

pub(crate) static ENTRY_EXHIBITIONIZE_8148713998545988736: VariantsMap = [
    &["exhibitionize"],
    &["exhibitionise"],
    &["exhibitionize"],
    &["exhibitionise"],
];

pub(crate) static ENTRY_EXISTENTIALIZES_8959667143883061799: VariantsMap = [
    &["existentializes"],
    &["existentialises"],
    &["existentializes"],
    &["existentialises"],
];

pub(crate) static ENTRY_EXISTENTIALIZE_7223214416858975418: VariantsMap = [
    &["existentialize"],
    &["existentialise"],
    &["existentialize"],
    &["existentialise"],
];

pub(crate) static ENTRY_EXORCISED_12908864464482354367: VariantsMap = [
    &["exorcised"],
    &["exorcised"],
    &["exorcised"],
    &["exorcised"],
];

pub(crate) static ENTRY_EXORCISES_3937603215249944418: VariantsMap = [
    &["exorcises"],
    &["exorcises"],
    &["exorcises"],
    &["exorcises"],
];

pub(crate) static ENTRY_EXORCISE_9017869478115489494: VariantsMap =
    [&["exorcise"], &["exorcise"], &["exorcise"], &["exorcise"]];

pub(crate) static ENTRY_EXORCISING_9037133836520531203: VariantsMap = [
    &["exorcising"],
    &["exorcising"],
    &["exorcising"],
    &["exorcising"],
];

pub(crate) static ENTRY_EXORCIZATION_7841196157883660249: VariantsMap = [
    &["exorcization"],
    &["exorcisation"],
    &["exorcization"],
    &["exorcisation"],
];

pub(crate) static ENTRY_EXORCIZEMENT_13755936147137266553: VariantsMap = [
    &["exorcizement"],
    &["exorcisement"],
    &["exorcizement"],
    &["exorcisement"],
];

pub(crate) static ENTRY_EXORCIZERS_15464358492441086034: VariantsMap = [
    &["exorcizers"],
    &["exorcisers"],
    &["exorcizers"],
    &["exorcisers"],
];

pub(crate) static ENTRY_EXORCIZER_10300614530359206460: VariantsMap = [
    &["exorcizer"],
    &["exorciser"],
    &["exorcizer"],
    &["exorciser"],
];

pub(crate) static ENTRY_EXPERIMENTALIZED_3235996828077232088: VariantsMap = [
    &["experimentalized"],
    &["experimentalised"],
    &["experimentalized"],
    &["experimentalised"],
];

pub(crate) static ENTRY_EXPERIMENTALIZES_17353857217605159387: VariantsMap = [
    &["experimentalizes"],
    &["experimentalises"],
    &["experimentalizes"],
    &["experimentalises"],
];

pub(crate) static ENTRY_EXPERIMENTALIZE_7321825952497189376: VariantsMap = [
    &["experimentalize"],
    &["experimentalise"],
    &["experimentalize"],
    &["experimentalise"],
];

pub(crate) static ENTRY_EXPERIMENTALIZING_8250407124148404694: VariantsMap = [
    &["experimentalizing"],
    &["experimentalising"],
    &["experimentalizing"],
    &["experimentalising"],
];

pub(crate) static ENTRY_EXPERIMENTIZES_9176567868167120281: VariantsMap = [
    &["experimentizes"],
    &["experimentises"],
    &["experimentizes"],
    &["experimentises"],
];

pub(crate) static ENTRY_EXPERIMENTIZE_12814319320920140623: VariantsMap = [
    &["experimentize"],
    &["experimentise"],
    &["experimentize"],
    &["experimentise"],
];

pub(crate) static ENTRY_EXPERTIZED_9523121825282850630: VariantsMap = [
    &["expertized"],
    &["expertised"],
    &["expertized"],
    &["expertised"],
];

pub(crate) static ENTRY_EXPERTIZING_14124314311673129338: VariantsMap = [
    &["expertizing"],
    &["expertising"],
    &["expertizing"],
    &["expertising"],
];

pub(crate) static ENTRY_EXSICCATE_17097371061751609281: VariantsMap = [
    &["exsiccate"],
    &["exsiccatae"],
    &["exsiccatae"],
    &["exsiccatae"],
];

pub(crate) static ENTRY_EXTEMPORIZATIONS_17970202292616391802: VariantsMap = [
    &["extemporizations"],
    &["extemporisations"],
    &["extemporizations"],
    &["extemporisations"],
];

pub(crate) static ENTRY_EXTEMPORIZATION_6498516717162293633: VariantsMap = [
    &["extemporization"],
    &["extemporisation"],
    &["extemporization"],
    &["extemporisation"],
];

pub(crate) static ENTRY_EXTEMPORIZED_8884254797509015457: VariantsMap = [
    &["extemporized"],
    &["extemporised"],
    &["extemporized"],
    &["extemporised"],
];

pub(crate) static ENTRY_EXTEMPORIZERS_10144332391226789510: VariantsMap = [
    &["extemporizers"],
    &["extemporisers"],
    &["extemporizers"],
    &["extemporisers"],
];

pub(crate) static ENTRY_EXTEMPORIZER_15042169661772082145: VariantsMap = [
    &["extemporizer"],
    &["extemporiser"],
    &["extemporizer"],
    &["extemporiser"],
];

pub(crate) static ENTRY_EXTEMPORIZES_10662898516430920590: VariantsMap = [
    &["extemporizes"],
    &["extemporises"],
    &["extemporizes"],
    &["extemporises"],
];

pub(crate) static ENTRY_EXTEMPORIZE_8490706080912375039: VariantsMap = [
    &["extemporize"],
    &["extemporise"],
    &["extemporize"],
    &["extemporise"],
];

pub(crate) static ENTRY_EXTEMPORIZING_10937023320075355586: VariantsMap = [
    &["extemporizing"],
    &["extemporising"],
    &["extemporizing"],
    &["extemporising"],
];

pub(crate) static ENTRY_EXTERIORIZATIONS_10258294511167010008: VariantsMap = [
    &["exteriorizations"],
    &["exteriorisations"],
    &["exteriorizations"],
    &["exteriorisations"],
];

pub(crate) static ENTRY_EXTERIORIZATION_8592258252267171531: VariantsMap = [
    &["exteriorization"],
    &["exteriorisation"],
    &["exteriorization"],
    &["exteriorisation"],
];

pub(crate) static ENTRY_EXTERIORIZED_2593224941672461767: VariantsMap = [
    &["exteriorized"],
    &["exteriorised"],
    &["exteriorized"],
    &["exteriorised"],
];

pub(crate) static ENTRY_EXTERIORIZES_10941715232314771538: VariantsMap = [
    &["exteriorizes"],
    &["exteriorises"],
    &["exteriorizes"],
    &["exteriorises"],
];

pub(crate) static ENTRY_EXTERIORIZE_6928562918919697659: VariantsMap = [
    &["exteriorize"],
    &["exteriorise"],
    &["exteriorize"],
    &["exteriorise"],
];

pub(crate) static ENTRY_EXTERIORIZING_3361516313097201672: VariantsMap = [
    &["exteriorizing"],
    &["exteriorising"],
    &["exteriorizing"],
    &["exteriorising"],
];

pub(crate) static ENTRY_EXTERNALIZATIONS_13981636890729920109: VariantsMap = [
    &["externalizations"],
    &["externalisations"],
    &["externalizations"],
    &["externalisations"],
];

pub(crate) static ENTRY_EXTERNALIZATION_5637241595479106962: VariantsMap = [
    &["externalization"],
    &["externalisation"],
    &["externalization"],
    &["externalisation"],
];

pub(crate) static ENTRY_EXTERNALIZED_595019063900238343: VariantsMap = [
    &["externalized"],
    &["externalised"],
    &["externalized"],
    &["externalised"],
];

pub(crate) static ENTRY_EXTERNALIZES_11960788314575642832: VariantsMap = [
    &["externalizes"],
    &["externalises"],
    &["externalizes"],
    &["externalises"],
];

pub(crate) static ENTRY_EXTERNALIZE_6421333850383600915: VariantsMap = [
    &["externalize"],
    &["externalise"],
    &["externalize"],
    &["externalise"],
];

pub(crate) static ENTRY_EXTERNALIZING_17289102227300964437: VariantsMap = [
    &["externalizing"],
    &["externalising"],
    &["externalizing"],
    &["externalising"],
];

pub(crate) static ENTRY_EXTOLS_435999545191713231: VariantsMap =
    [&["extols"], &["extols"], &["extols"], &["extols"]];

pub(crate) static ENTRY_EXTOL_17049600042027760409: VariantsMap =
    [&["extol"], &["extol"], &["extol"], &["extol"]];

pub(crate) static ENTRY_EXTROVERTED_9249661851858893561: VariantsMap = [
    &["extroverted"],
    &["extroverted"],
    &["extroverted"],
    &["extroverted"],
];

pub(crate) static ENTRY_EXTROVERTS_17343931619747038542: VariantsMap = [
    &["extroverts"],
    &["extroverts"],
    &["extroverts"],
    &["extroverts"],
];

pub(crate) static ENTRY_EXTROVERT_3459138457522989101: VariantsMap = [
    &["extrovert"],
    &["extrovert"],
    &["extrovert"],
    &["extrovert"],
];

pub(crate) static ENTRY_FABULIZED_7556454061259147422: VariantsMap = [
    &["fabulized"],
    &["fabulised"],
    &["fabulized"],
    &["fabulised"],
];

pub(crate) static ENTRY_FABULIZES_13117215117496144014: VariantsMap = [
    &["fabulizes"],
    &["fabulises"],
    &["fabulizes"],
    &["fabulises"],
];

pub(crate) static ENTRY_FABULIZE_6554520750007678638: VariantsMap =
    [&["fabulize"], &["fabulise"], &["fabulize"], &["fabulise"]];

pub(crate) static ENTRY_FABULIZING_8547130161556656861: VariantsMap = [
    &["fabulizing"],
    &["fabulising"],
    &["fabulizing"],
    &["fabulising"],
];

pub(crate) static ENTRY_FACSIMILIZES_13852505000433399295: VariantsMap = [
    &["facsimilizes"],
    &["facsimilises"],
    &["facsimilizes"],
    &["facsimilises"],
];

pub(crate) static ENTRY_FACSIMILIZE_9828221696654309927: VariantsMap = [
    &["facsimilize"],
    &["facsimilise"],
    &["facsimilize"],
    &["facsimilise"],
];

pub(crate) static ENTRY_FACTORIZATIONS_16583219313061102178: VariantsMap = [
    &["factorizations"],
    &["factorisations"],
    &["factorizations"],
    &["factorisations"],
];

pub(crate) static ENTRY_FACTORIZATION_3182572715959186659: VariantsMap = [
    &["factorization"],
    &["factorisation"],
    &["factorization"],
    &["factorisation"],
];

pub(crate) static ENTRY_FACTORIZED_15433924875237664508: VariantsMap = [
    &["factorized"],
    &["factorised"],
    &["factorized"],
    &["factorised"],
];

pub(crate) static ENTRY_FACTORIZES_7790021725855776528: VariantsMap = [
    &["factorizes"],
    &["factorises"],
    &["factorizes"],
    &["factorises"],
];

pub(crate) static ENTRY_FACTORIZE_8969914975304697583: VariantsMap = [
    &["factorize"],
    &["factorise"],
    &["factorize"],
    &["factorise"],
];

pub(crate) static ENTRY_FACTORIZING_6633915971235070053: VariantsMap = [
    &["factorizing"],
    &["factorising"],
    &["factorizing"],
    &["factorising"],
];

pub(crate) static ENTRY_FAENCE_6852965957276318244: VariantsMap =
    [&["faence"], &["faoence"], &["faoence"], &["faoence"]];

pub(crate) static ENTRY_FAGOTED_18130244201646636018: VariantsMap =
    [&["fagoted"], &["faggoted"], &["faggoted"], &["faggoted"]];

pub(crate) static ENTRY_FAGOTING_14091007799386400971: VariantsMap = [
    &["fagoting"],
    &["faggoting"],
    &["faggoting"],
    &["faggoting"],
];

pub(crate) static ENTRY_FAGOTS_13347829079007571091: VariantsMap = [
    &["faggots", "fagots"],
    &["faggots"],
    &["faggots"],
    &["faggots"],
];

pub(crate) static ENTRY_FAGOTS_9448080982481828615: VariantsMap =
    [&["fagots"], &["faggots"], &["faggots"], &["faggots"]];

pub(crate) static ENTRY_FAGOT_12511557487040804077: VariantsMap =
    [&["fagot"], &["faggot"], &["faggot"], &["faggot"]];

pub(crate) static ENTRY_FAGOT_2908150994909348842: VariantsMap =
    [&["faggot", "fagot"], &["faggot"], &["faggot"], &["faggot"]];

pub(crate) static ENTRY_FAITORS_16017382139132171207: VariantsMap =
    [&["faitors"], &["faitours"], &["faitours"], &["faitours"]];

pub(crate) static ENTRY_FAITOR_14739031312979666111: VariantsMap =
    [&["faitor"], &["faitour"], &["faitour"], &["faitour"]];

pub(crate) static ENTRY_FAMILIARIZATIONS_7744496085896785322: VariantsMap = [
    &["familiarizations"],
    &["familiarisations"],
    &["familiarizations"],
    &["familiarisations"],
];

pub(crate) static ENTRY_FAMILIARIZATION_7435436227522581935: VariantsMap = [
    &["familiarization"],
    &["familiarisation"],
    &["familiarization"],
    &["familiarisation"],
];

pub(crate) static ENTRY_FAMILIARIZED_9635879804250335511: VariantsMap = [
    &["familiarized"],
    &["familiarised"],
    &["familiarized"],
    &["familiarised"],
];

pub(crate) static ENTRY_FAMILIARIZERS_8503690372223478730: VariantsMap = [
    &["familiarizers"],
    &["familiarisers"],
    &["familiarizers"],
    &["familiarisers"],
];

pub(crate) static ENTRY_FAMILIARIZER_12769069348636773119: VariantsMap = [
    &["familiarizer"],
    &["familiariser"],
    &["familiarizer"],
    &["familiariser"],
];

pub(crate) static ENTRY_FAMILIARIZES_15552999136886444100: VariantsMap = [
    &["familiarizes"],
    &["familiarises"],
    &["familiarizes"],
    &["familiarises"],
];

pub(crate) static ENTRY_FAMILIARIZE_6458271230166262342: VariantsMap = [
    &["familiarize"],
    &["familiarise"],
    &["familiarize"],
    &["familiarise"],
];

pub(crate) static ENTRY_FAMILIARIZINGLY_17102975447523114031: VariantsMap = [
    &["familiarizingly"],
    &["familiarisingly"],
    &["familiarizingly"],
    &["familiarisingly"],
];

pub(crate) static ENTRY_FAMILIARIZING_3497704747397161180: VariantsMap = [
    &["familiarizing"],
    &["familiarising"],
    &["familiarizing"],
    &["familiarising"],
];

pub(crate) static ENTRY_FANATICIZED_5234463871342267005: VariantsMap = [
    &["fanaticized"],
    &["fanaticised"],
    &["fanaticized"],
    &["fanaticised"],
];

pub(crate) static ENTRY_FANATICIZES_11857074349260388346: VariantsMap = [
    &["fanaticizes"],
    &["fanaticises"],
    &["fanaticizes"],
    &["fanaticises"],
];

pub(crate) static ENTRY_FANATICIZE_175890918610710058: VariantsMap = [
    &["fanaticize"],
    &["fanaticise"],
    &["fanaticize"],
    &["fanaticise"],
];

pub(crate) static ENTRY_FANATICIZING_13797711926894006340: VariantsMap = [
    &["fanaticizing"],
    &["fanaticising"],
    &["fanaticizing"],
    &["fanaticising"],
];

pub(crate) static ENTRY_FANTASIZED_9815854138753209894: VariantsMap = [
    &["fantasized"],
    &["fantasised"],
    &["fantasized"],
    &["fantasised"],
];

pub(crate) static ENTRY_FANTASIZER_9698455867221961502: VariantsMap = [
    &["fantasizer"],
    &["fantasiser"],
    &["fantasizer"],
    &["fantasiser"],
];

pub(crate) static ENTRY_FANTASIZES_10834180084204721653: VariantsMap = [
    &["fantasizes"],
    &["fantasises"],
    &["fantasizes"],
    &["fantasises"],
];

pub(crate) static ENTRY_FANTASIZE_16667407006128337409: VariantsMap = [
    &["fantasize"],
    &["fantasise"],
    &["fantasize"],
    &["fantasise"],
];

pub(crate) static ENTRY_FANTASIZING_17657564354102329164: VariantsMap = [
    &["fantasizing"],
    &["fantasising"],
    &["fantasizing"],
    &["fantasising"],
];

pub(crate) static ENTRY_FARADIZATIONS_4526439476664692216: VariantsMap = [
    &["faradizations"],
    &["faradisations"],
    &["faradizations"],
    &["faradisations"],
];

pub(crate) static ENTRY_FARADIZATION_15891788669706277797: VariantsMap = [
    &["faradization"],
    &["faradisation"],
    &["faradization"],
    &["faradisation"],
];

pub(crate) static ENTRY_FARADIZED_2216631753438049544: VariantsMap = [
    &["faradized"],
    &["faradised"],
    &["faradized"],
    &["faradised"],
];

pub(crate) static ENTRY_FARADIZERS_96577301703372931: VariantsMap = [
    &["faradizers"],
    &["faradisers"],
    &["faradizers"],
    &["faradisers"],
];

pub(crate) static ENTRY_FARADIZER_12209074437517416364: VariantsMap = [
    &["faradizer"],
    &["faradiser"],
    &["faradizer"],
    &["faradiser"],
];

pub(crate) static ENTRY_FARADIZES_516381975059492431: VariantsMap = [
    &["faradizes"],
    &["faradises"],
    &["faradizes"],
    &["faradises"],
];

pub(crate) static ENTRY_FARADIZE_13316438844181300579: VariantsMap =
    [&["faradize"], &["faradise"], &["faradize"], &["faradise"]];

pub(crate) static ENTRY_FARADIZING_7236430722652054967: VariantsMap = [
    &["faradizing"],
    &["faradising"],
    &["faradizing"],
    &["faradising"],
];

pub(crate) static ENTRY_FASCIOLE_7639436908568338351: VariantsMap = [
    &["fasciole"],
    &["fasciolae"],
    &["fasciolae"],
    &["fasciolae"],
];

pub(crate) static ENTRY_FASCISTICIZATIONS_18053530396662800587: VariantsMap = [
    &["fascisticizations"],
    &["fascisticisations"],
    &["fascisticizations"],
    &["fascisticisations"],
];

pub(crate) static ENTRY_FASCISTICIZATION_4858667405774331216: VariantsMap = [
    &["fascisticization"],
    &["fascisticisation"],
    &["fascisticization"],
    &["fascisticisation"],
];

pub(crate) static ENTRY_FASCISTICIZES_5781725162251103852: VariantsMap = [
    &["fascisticizes"],
    &["fascisticises"],
    &["fascisticizes"],
    &["fascisticises"],
];

pub(crate) static ENTRY_FASCISTICIZE_8685639468575663113: VariantsMap = [
    &["fascisticize"],
    &["fascisticise"],
    &["fascisticize"],
    &["fascisticise"],
];

pub(crate) static ENTRY_FASCISTIZATIONS_3946675109662693253: VariantsMap = [
    &["fascistizations"],
    &["fascistisations"],
    &["fascistizations"],
    &["fascistisations"],
];

pub(crate) static ENTRY_FASCISTIZATION_6926224020620442283: VariantsMap = [
    &["fascistization"],
    &["fascistisation"],
    &["fascistization"],
    &["fascistisation"],
];

pub(crate) static ENTRY_FASCISTIZED_17858786995192876357: VariantsMap = [
    &["fascistized"],
    &["fascistised"],
    &["fascistized"],
    &["fascistised"],
];

pub(crate) static ENTRY_FASCISTIZES_10726309171561350516: VariantsMap = [
    &["fascistizes"],
    &["fascistises"],
    &["fascistizes"],
    &["fascistises"],
];

pub(crate) static ENTRY_FASCISTIZE_11043251862767140703: VariantsMap = [
    &["fascistize"],
    &["fascistise"],
    &["fascistize"],
    &["fascistise"],
];

pub(crate) static ENTRY_FASCISTIZING_14842848351094053038: VariantsMap = [
    &["fascistizing"],
    &["fascistising"],
    &["fascistizing"],
    &["fascistising"],
];

pub(crate) static ENTRY_FASHIONIZES_12948391454225982571: VariantsMap = [
    &["fashionizes"],
    &["fashionises"],
    &["fashionizes"],
    &["fashionises"],
];

pub(crate) static ENTRY_FASHIONIZE_9487132676031513779: VariantsMap = [
    &["fashionize"],
    &["fashionise"],
    &["fashionize"],
    &["fashionise"],
];

pub(crate) static ENTRY_FATALIZES_16154483171742069422: VariantsMap = [
    &["fatalizes"],
    &["fatalises"],
    &["fatalizes"],
    &["fatalises"],
];

pub(crate) static ENTRY_FATALIZE_5795723412936271094: VariantsMap =
    [&["fatalize"], &["fatalise"], &["fatalize"], &["fatalise"]];

pub(crate) static ENTRY_FAVORABLENESSES_7104998476741346696: VariantsMap = [
    &["favorablenesses"],
    &["favourablenesses"],
    &["favourablenesses"],
    &["favourablenesses"],
];

pub(crate) static ENTRY_FAVORABLENESS_15076889136273638786: VariantsMap = [
    &["favorableness"],
    &["favourableness"],
    &["favourableness"],
    &["favourableness"],
];

pub(crate) static ENTRY_FAVORABLER_7172677352588609327: VariantsMap = [
    &["favorabler"],
    &["favourabler"],
    &["favourabler"],
    &["favourabler"],
];

pub(crate) static ENTRY_FAVORABLEST_3654396515225860920: VariantsMap = [
    &["favorablest"],
    &["favourablest"],
    &["favourablest"],
    &["favourablest"],
];

pub(crate) static ENTRY_FAVORABLES_8653228504507516682: VariantsMap = [
    &["favorables"],
    &["favourables"],
    &["favourables"],
    &["favourables"],
];

pub(crate) static ENTRY_FAVORABLE_16585220116684679375: VariantsMap = [
    &["favorable"],
    &["favourable"],
    &["favourable"],
    &["favourable"],
];

pub(crate) static ENTRY_FAVORABLIER_7406446644901287938: VariantsMap = [
    &["favorablier"],
    &["favourablier"],
    &["favourablier"],
    &["favourablier"],
];

pub(crate) static ENTRY_FAVORABLIEST_13749538246766915905: VariantsMap = [
    &["favorabliest"],
    &["favourabliest"],
    &["favourabliest"],
    &["favourabliest"],
];

pub(crate) static ENTRY_FAVORABLY_8642546699578488365: VariantsMap = [
    &["favorably"],
    &["favourably"],
    &["favourably"],
    &["favourably"],
];

pub(crate) static ENTRY_FAVOREDLIER_5765865123462240199: VariantsMap = [
    &["favoredlier"],
    &["favouredlier"],
    &["favouredlier"],
    &["favouredlier"],
];

pub(crate) static ENTRY_FAVOREDLIEST_10832270749334107398: VariantsMap = [
    &["favoredliest"],
    &["favouredliest"],
    &["favouredliest"],
    &["favouredliest"],
];

pub(crate) static ENTRY_FAVOREDLY_18181324612001665281: VariantsMap = [
    &["favoredly"],
    &["favouredly"],
    &["favouredly"],
    &["favouredly"],
];

pub(crate) static ENTRY_FAVOREDNESSES_13201622995255558661: VariantsMap = [
    &["favorednesses"],
    &["favourednesses"],
    &["favourednesses"],
    &["favourednesses"],
];

pub(crate) static ENTRY_FAVOREDNESS_12375820644528192720: VariantsMap = [
    &["favoredness"],
    &["favouredness"],
    &["favouredness"],
    &["favouredness"],
];

pub(crate) static ENTRY_FAVOREDS_3475186581170652773: VariantsMap = [
    &["favoreds"],
    &["favoureds"],
    &["favoureds"],
    &["favoureds"],
];

pub(crate) static ENTRY_FAVORED_16162807193690319578: VariantsMap =
    [&["favored"], &["favoured"], &["favoured"], &["favoured"]];

pub(crate) static ENTRY_FAVORERS_12669438738558310747: VariantsMap = [
    &["favorers"],
    &["favourers"],
    &["favourers"],
    &["favourers"],
];

pub(crate) static ENTRY_FAVORER_14571533058900750983: VariantsMap =
    [&["favorer"], &["favourer"], &["favourer"], &["favourer"]];

pub(crate) static ENTRY_FAVORESS_10320527329712113257: VariantsMap = [
    &["favoress"],
    &["favouress"],
    &["favouress"],
    &["favouress"],
];

pub(crate) static ENTRY_FAVORINGLIER_13234382898335132498: VariantsMap = [
    &["favoringlier"],
    &["favouringlier"],
    &["favouringlier"],
    &["favouringlier"],
];

pub(crate) static ENTRY_FAVORINGLIEST_10272028216258766759: VariantsMap = [
    &["favoringliest"],
    &["favouringliest"],
    &["favouringliest"],
    &["favouringliest"],
];

pub(crate) static ENTRY_FAVORINGLY_11595619512304812227: VariantsMap = [
    &["favoringly"],
    &["favouringly"],
    &["favouringly"],
    &["favouringly"],
];

pub(crate) static ENTRY_FAVORINGS_8617057820176781510: VariantsMap = [
    &["favorings"],
    &["favourings"],
    &["favourings"],
    &["favourings"],
];

pub(crate) static ENTRY_FAVORING_2135325073071899230: VariantsMap = [
    &["favoring"],
    &["favouring"],
    &["favouring"],
    &["favouring"],
];

pub(crate) static ENTRY_FAVORITER_7692783527526236076: VariantsMap = [
    &["favoriter"],
    &["favouriter"],
    &["favouriter"],
    &["favouriter"],
];

pub(crate) static ENTRY_FAVORITEST_13292407585100266353: VariantsMap = [
    &["favoritest"],
    &["favouritest"],
    &["favouritest"],
    &["favouritest"],
];

pub(crate) static ENTRY_FAVORITES_2546901638617062205: VariantsMap = [
    &["favorites"],
    &["favourites"],
    &["favourites"],
    &["favourites"],
];

pub(crate) static ENTRY_FAVORITE_2808981011176955343: VariantsMap = [
    &["favorite"],
    &["favourite"],
    &["favourite"],
    &["favourite"],
];

pub(crate) static ENTRY_FAVORITISMS_11770976052678857781: VariantsMap = [
    &["favoritisms"],
    &["favouritisms"],
    &["favouritisms"],
    &["favouritisms"],
];

pub(crate) static ENTRY_FAVORITISM_14860734505967533306: VariantsMap = [
    &["favoritism"],
    &["favouritism"],
    &["favouritism"],
    &["favouritism"],
];

pub(crate) static ENTRY_FAVORLESSER_9070895795594476859: VariantsMap = [
    &["favorlesser"],
    &["favourlesser"],
    &["favourlesser"],
    &["favourlesser"],
];

pub(crate) static ENTRY_FAVORLESSEST_6458711572083420541: VariantsMap = [
    &["favorlessest"],
    &["favourlessest"],
    &["favourlessest"],
    &["favourlessest"],
];

pub(crate) static ENTRY_FAVORLESSES_8809391561835385510: VariantsMap = [
    &["favorlesses"],
    &["favourlesses"],
    &["favourlesses"],
    &["favourlesses"],
];

pub(crate) static ENTRY_FAVORLESS_5516474921410922467: VariantsMap = [
    &["favorless"],
    &["favourless"],
    &["favourless"],
    &["favourless"],
];

pub(crate) static ENTRY_FAVORS_12388610586480585674: VariantsMap =
    [&["favors"], &["favours"], &["favours"], &["favours"]];

pub(crate) static ENTRY_FAVOR_16174102806904091593: VariantsMap =
    [&["favor"], &["favour"], &["favour"], &["favour"]];

pub(crate) static ENTRY_FAYER_14342952204863965335: VariantsMap =
    [&["fayer"], &["fayre"], &["fayre"], &["fayre"]];

pub(crate) static ENTRY_FECALITH_1709239582298935153: VariantsMap =
    [&["fecalith"], &["faecalith"], &["fecalith"], &["faecalith"]];

pub(crate) static ENTRY_FECAL_14357706927402634040: VariantsMap =
    [&["fecal"], &["faecal"], &["fecal"], &["faecal"]];

pub(crate) static ENTRY_FECES_6588400696084582030: VariantsMap =
    [&["feces"], &["faeces"], &["feces"], &["faeces"]];

pub(crate) static ENTRY_FECULA_9980537314701284779: VariantsMap =
    [&["fecula"], &["faecula"], &["faecula"], &["faecula"]];

pub(crate) static ENTRY_FECULENCE_2631357115871198711: VariantsMap = [
    &["feculence"],
    &["faeculence"],
    &["faeculence"],
    &["faeculence"],
];

pub(crate) static ENTRY_FECUNDITATIS_17976813521315556327: VariantsMap = [
    &["fecunditatis"],
    &["foecunditatis"],
    &["foecunditatis"],
    &["foecunditatis"],
];

pub(crate) static ENTRY_FECUNDIZES_2678423876082081224: VariantsMap = [
    &["fecundizes"],
    &["fecundises"],
    &["fecundizes"],
    &["fecundises"],
];

pub(crate) static ENTRY_FECUNDIZE_13656177531635615400: VariantsMap = [
    &["fecundize"],
    &["fecundise"],
    &["fecundize"],
    &["fecundise"],
];

pub(crate) static ENTRY_FEDARIES_10652713739066961630: VariantsMap = [
    &["fedaries"],
    &["foedaries"],
    &["foedaries"],
    &["foedaries"],
];

pub(crate) static ENTRY_FEDARIE_6394349204716498948: VariantsMap =
    [&["fedarie"], &["foedarie"], &["foedarie"], &["foedarie"]];

pub(crate) static ENTRY_FEDERALIZATIONS_16597754848421860206: VariantsMap = [
    &["federalizations"],
    &["federalisations"],
    &["federalizations"],
    &["federalisations"],
];

pub(crate) static ENTRY_FEDERALIZATION_2999038236760622034: VariantsMap = [
    &["federalization"],
    &["federalisation"],
    &["federalization"],
    &["federalisation"],
];

pub(crate) static ENTRY_FEDERALIZED_4780345550916631576: VariantsMap = [
    &["federalized"],
    &["federalised"],
    &["federalized"],
    &["federalised"],
];

pub(crate) static ENTRY_FEDERALIZES_2587577566789708184: VariantsMap = [
    &["federalizes"],
    &["federalises"],
    &["federalizes"],
    &["federalises"],
];

pub(crate) static ENTRY_FEDERALIZE_15318475887938618914: VariantsMap = [
    &["federalize"],
    &["federalise"],
    &["federalize"],
    &["federalise"],
];

pub(crate) static ENTRY_FEDERALIZING_16718667241930274816: VariantsMap = [
    &["federalizing"],
    &["federalising"],
    &["federalizing"],
    &["federalising"],
];

pub(crate) static ENTRY_FEDOR_8887412529233148008: VariantsMap =
    [&["fedor"], &["faedor"], &["faedor"], &["faedor"]];

pub(crate) static ENTRY_FEERS_9816318192129301807: VariantsMap =
    [&["feers"], &["feres"], &["feres"], &["feres"]];

pub(crate) static ENTRY_FEER_11532652647843640304: VariantsMap =
    [&["feer"], &["fere"], &["fere"], &["fere"]];

pub(crate) static ENTRY_FEMALIZES_16947353395960099765: VariantsMap = [
    &["femalizes"],
    &["femalises"],
    &["femalizes"],
    &["femalises"],
];

pub(crate) static ENTRY_FEMALIZE_13901043989723708165: VariantsMap =
    [&["femalize"], &["femalise"], &["femalize"], &["femalise"]];

pub(crate) static ENTRY_FEMINIZATIONS_4574886318648206346: VariantsMap = [
    &["feminizations"],
    &["feminisations"],
    &["feminizations"],
    &["feminisations"],
];

pub(crate) static ENTRY_FEMINIZATION_8522419792968789128: VariantsMap = [
    &["feminization"],
    &["feminisation"],
    &["feminization"],
    &["feminisation"],
];

pub(crate) static ENTRY_FEMINIZED_8194884343298056834: VariantsMap = [
    &["feminized"],
    &["feminised"],
    &["feminized"],
    &["feminised"],
];

pub(crate) static ENTRY_FEMINIZES_7032574753251926864: VariantsMap = [
    &["feminizes"],
    &["feminises"],
    &["feminizes"],
    &["feminises"],
];

pub(crate) static ENTRY_FEMINIZE_6528476134483497288: VariantsMap =
    [&["feminize"], &["feminise"], &["feminize"], &["feminise"]];

pub(crate) static ENTRY_FEMINIZING_4796004961681233661: VariantsMap = [
    &["feminizing"],
    &["feminising"],
    &["feminizing"],
    &["feminising"],
];

pub(crate) static ENTRY_FEMTOMETER_10416943962185360317: VariantsMap = [
    &["femtometer"],
    &["femtometre"],
    &["femtometre"],
    &["femtometre"],
];

pub(crate) static ENTRY_FERALIZED_2129540690752206051: VariantsMap = [
    &["feralized"],
    &["feralised"],
    &["feralized"],
    &["feralised"],
];

pub(crate) static ENTRY_FERD_17290726529250186020: VariantsMap =
    [&["ferd"], &["fred"], &["fred"], &["fred"]];

pub(crate) static ENTRY_FERIE_16904944536625577586: VariantsMap =
    [&["ferie"], &["feriae"], &["feriae"], &["feriae"]];

pub(crate) static ENTRY_FERITY_4632811736178249944: VariantsMap =
    [&["ferity"], &["freity"], &["freity"], &["freity"]];

pub(crate) static ENTRY_FERNEAU_10155755211254630197: VariantsMap =
    [&["ferneau"], &["freneau"], &["freneau"], &["freneau"]];

pub(crate) static ENTRY_FERRELED_6636427247803722942: VariantsMap = [
    &["ferreled"],
    &["ferrelled"],
    &["ferrelled"],
    &["ferrelled"],
];

pub(crate) static ENTRY_FERRELING_4899567902997737912: VariantsMap = [
    &["ferreling"],
    &["ferrelling"],
    &["ferrelling"],
    &["ferrelling"],
];

pub(crate) static ENTRY_FERRITIZATIONS_18305080996112489502: VariantsMap = [
    &["ferritizations"],
    &["ferritisations"],
    &["ferritizations"],
    &["ferritisations"],
];

pub(crate) static ENTRY_FERRITIZATION_18074134739966612229: VariantsMap = [
    &["ferritization"],
    &["ferritisation"],
    &["ferritization"],
    &["ferritisation"],
];

pub(crate) static ENTRY_FERTILIZABILITY_5460980983219934852: VariantsMap = [
    &["fertilizability"],
    &["fertilisability"],
    &["fertilizability"],
    &["fertilisability"],
];

pub(crate) static ENTRY_FERTILIZABLER_17085580719524585364: VariantsMap = [
    &["fertilizabler"],
    &["fertilisabler"],
    &["fertilizabler"],
    &["fertilisabler"],
];

pub(crate) static ENTRY_FERTILIZABLEST_11600087757233912795: VariantsMap = [
    &["fertilizablest"],
    &["fertilisablest"],
    &["fertilizablest"],
    &["fertilisablest"],
];

pub(crate) static ENTRY_FERTILIZABLES_15426058595213862560: VariantsMap = [
    &["fertilizables"],
    &["fertilisables"],
    &["fertilizables"],
    &["fertilisables"],
];

pub(crate) static ENTRY_FERTILIZABLE_12448840079739843294: VariantsMap = [
    &["fertilizable"],
    &["fertilisable"],
    &["fertilizable"],
    &["fertilisable"],
];

pub(crate) static ENTRY_FERTILIZATIONALER_5809694016637303037: VariantsMap = [
    &["fertilizationaler"],
    &["fertilisationaler"],
    &["fertilizationaler"],
    &["fertilisationaler"],
];

pub(crate) static ENTRY_FERTILIZATIONALEST_1268407861451405565: VariantsMap = [
    &["fertilizationalest"],
    &["fertilisationalest"],
    &["fertilizationalest"],
    &["fertilisationalest"],
];

pub(crate) static ENTRY_FERTILIZATIONALS_5388571387610968490: VariantsMap = [
    &["fertilizationals"],
    &["fertilisationals"],
    &["fertilizationals"],
    &["fertilisationals"],
];

pub(crate) static ENTRY_FERTILIZATIONAL_6643363430121231287: VariantsMap = [
    &["fertilizational"],
    &["fertilisational"],
    &["fertilizational"],
    &["fertilisational"],
];

pub(crate) static ENTRY_FERTILIZATIONS_10565985675957455353: VariantsMap = [
    &["fertilizations"],
    &["fertilisations"],
    &["fertilizations"],
    &["fertilisations"],
];

pub(crate) static ENTRY_FERTILIZATION_17841696658117857659: VariantsMap = [
    &["fertilization"],
    &["fertilisation"],
    &["fertilization"],
    &["fertilisation"],
];

pub(crate) static ENTRY_FERTILIZED_3235991417813432465: VariantsMap = [
    &["fertilized"],
    &["fertilised"],
    &["fertilized"],
    &["fertilised"],
];

pub(crate) static ENTRY_FERTILIZERS_2400009978178899509: VariantsMap = [
    &["fertilizers"],
    &["fertilisers"],
    &["fertilizers"],
    &["fertilisers"],
];

pub(crate) static ENTRY_FERTILIZER_17245657864487752834: VariantsMap = [
    &["fertilizer"],
    &["fertiliser"],
    &["fertilizer"],
    &["fertiliser"],
];

pub(crate) static ENTRY_FERTILIZES_5502375627064483003: VariantsMap = [
    &["fertilizes"],
    &["fertilises"],
    &["fertilizes"],
    &["fertilises"],
];

pub(crate) static ENTRY_FERTILIZE_8254091234870358890: VariantsMap = [
    &["fertilize"],
    &["fertilise"],
    &["fertilize"],
    &["fertilise"],
];

pub(crate) static ENTRY_FERTILIZING_2726744554859969827: VariantsMap = [
    &["fertilizing"],
    &["fertilising"],
    &["fertilizing"],
    &["fertilising"],
];

pub(crate) static ENTRY_FERVORLESSES_13320651864382195163: VariantsMap = [
    &["fervorlesses"],
    &["fervourlesses"],
    &["fervourlesses"],
    &["fervourlesses"],
];

pub(crate) static ENTRY_FERVORLESS_4739772680862683322: VariantsMap = [
    &["fervorless"],
    &["fervourless"],
    &["fervourless"],
    &["fervourless"],
];

pub(crate) static ENTRY_FERVORS_4717213096370119384: VariantsMap =
    [&["fervors"], &["fervours"], &["fervours"], &["fervours"]];

pub(crate) static ENTRY_FERVOR_17743643839771539323: VariantsMap =
    [&["fervor"], &["fervour"], &["fervour"], &["fervour"]];

pub(crate) static ENTRY_FETALISM_13684319792675234496: VariantsMap =
    [&["fetalism"], &["fetalism"], &["fetalism"], &["fetalism"]];

pub(crate) static ENTRY_FETAL_17518999091217091154: VariantsMap =
    [&["fetal"], &["fetal"], &["fetal"], &["fetal"]];

pub(crate) static ENTRY_FETATION_5535322770903610684: VariantsMap =
    [&["fetation"], &["fetation"], &["fetation"], &["fetation"]];

pub(crate) static ENTRY_FETICHIZED_2364538138643524022: VariantsMap = [
    &["fetichized"],
    &["fetichised"],
    &["fetichized"],
    &["fetichised"],
];

pub(crate) static ENTRY_FETICHIZES_6929284398655519177: VariantsMap = [
    &["fetichizes"],
    &["fetichises"],
    &["fetichizes"],
    &["fetichises"],
];

pub(crate) static ENTRY_FETICHIZE_8516800402008488712: VariantsMap = [
    &["fetichize"],
    &["fetichise"],
    &["fetichize"],
    &["fetichise"],
];

pub(crate) static ENTRY_FETICHIZING_5672695629869318515: VariantsMap = [
    &["fetichizing"],
    &["fetichising"],
    &["fetichizing"],
    &["fetichising"],
];

pub(crate) static ENTRY_FETICIDAL_3234468490191462297: VariantsMap = [
    &["feticidal"],
    &["feticidal"],
    &["feticidal"],
    &["feticidal"],
];

pub(crate) static ENTRY_FETICIDES_13716695115962439528: VariantsMap = [
    &["feticides"],
    &["feticides"],
    &["feticides"],
    &["feticides"],
];

pub(crate) static ENTRY_FETICIDE_17603941273141945408: VariantsMap =
    [&["feticide"], &["feticide"], &["feticide"], &["feticide"]];

pub(crate) static ENTRY_FETIDER_5915159455988754255: VariantsMap =
    [&["fetider"], &["fetider"], &["fetider"], &["fetider"]];

pub(crate) static ENTRY_FETIDEST_17027395037056500217: VariantsMap =
    [&["fetidest"], &["fetidest"], &["fetidest"], &["fetidest"]];

pub(crate) static ENTRY_FETID_1081410302491831537: VariantsMap =
    [&["fetid"], &["fetid"], &["fetid"], &["fetid"]];

pub(crate) static ENTRY_FETIFEROUS_14513038138855763869: VariantsMap = [
    &["fetiferous"],
    &["foetiferous"],
    &["foetiferous"],
    &["foetiferous"],
];

pub(crate) static ENTRY_FETIPAROUS_7738738846683585946: VariantsMap = [
    &["fetiparous"],
    &["foetiparous"],
    &["foetiparous"],
    &["foetiparous"],
];

pub(crate) static ENTRY_FETISHES_16284953087435679568: VariantsMap =
    [&["fetishes"], &["fetishes"], &["fetishes"], &["fetishes"]];

pub(crate) static ENTRY_FETISHIZATIONS_16366493538042913498: VariantsMap = [
    &["fetishizations"],
    &["fetishisations"],
    &["fetishizations"],
    &["fetishisations"],
];

pub(crate) static ENTRY_FETISHIZATION_879526721515241266: VariantsMap = [
    &["fetishization"],
    &["fetishisation"],
    &["fetishization"],
    &["fetishisation"],
];

pub(crate) static ENTRY_FETISHIZED_5250641916695551285: VariantsMap = [
    &["fetishized"],
    &["fetishised"],
    &["fetishized"],
    &["fetishised"],
];

pub(crate) static ENTRY_FETISHIZES_1721613276947375571: VariantsMap = [
    &["fetishizes"],
    &["fetishises"],
    &["fetishizes"],
    &["fetishises"],
];

pub(crate) static ENTRY_FETISHIZE_16589623506909480927: VariantsMap = [
    &["fetishize"],
    &["fetishise"],
    &["fetishize"],
    &["fetishise"],
];

pub(crate) static ENTRY_FETISHIZING_13625208754682318629: VariantsMap = [
    &["fetishizing"],
    &["fetishising"],
    &["fetishizing"],
    &["fetishising"],
];

pub(crate) static ENTRY_FETISH_2114965296682700947: VariantsMap =
    [&["fetish"], &["fetish"], &["fetish"], &["fetish"]];

pub(crate) static ENTRY_FETORS_12891768447462956139: VariantsMap =
    [&["fetors"], &["foetors"], &["foetors"], &["foetors"]];

pub(crate) static ENTRY_FETOR_17434398877973743789: VariantsMap =
    [&["fetor"], &["foetor"], &["foetor"], &["foetor"]];

pub(crate) static ENTRY_FETOSCOPIES_10494050521017109189: VariantsMap = [
    &["fetoscopies"],
    &["foetoscopies"],
    &["foetoscopies"],
    &["foetoscopies"],
];

pub(crate) static ENTRY_FETOSCOPY_17563505119899523779: VariantsMap = [
    &["fetoscopy"],
    &["foetoscopy"],
    &["foetoscopy"],
    &["foetoscopy"],
];

pub(crate) static ENTRY_FETURE_14671868018697186605: VariantsMap =
    [&["feture"], &["foeture"], &["foeture"], &["foeture"]];

pub(crate) static ENTRY_FETUSES_1754409052194239428: VariantsMap =
    [&["fetuses"], &["fetuses"], &["fetuses"], &["fetuses"]];

pub(crate) static ENTRY_FETUS_14529005438973048712: VariantsMap =
    [&["fetus"], &["fetus"], &["fetus"], &["fetus"]];

pub(crate) static ENTRY_FEUDALIZABLES_10938382425763284765: VariantsMap = [
    &["feudalizables"],
    &["feudalisables"],
    &["feudalizables"],
    &["feudalisables"],
];

pub(crate) static ENTRY_FEUDALIZABLE_15718855955843354838: VariantsMap = [
    &["feudalizable"],
    &["feudalisable"],
    &["feudalizable"],
    &["feudalisable"],
];

pub(crate) static ENTRY_FEUDALIZATIONS_10450459550757796831: VariantsMap = [
    &["feudalizations"],
    &["feudalisations"],
    &["feudalizations"],
    &["feudalisations"],
];

pub(crate) static ENTRY_FEUDALIZATION_6620838161591814945: VariantsMap = [
    &["feudalization"],
    &["feudalisation"],
    &["feudalization"],
    &["feudalisation"],
];

pub(crate) static ENTRY_FEUDALIZED_3120776651742142949: VariantsMap = [
    &["feudalized"],
    &["feudalised"],
    &["feudalized"],
    &["feudalised"],
];

pub(crate) static ENTRY_FEUDALIZES_10374158201177897598: VariantsMap = [
    &["feudalizes"],
    &["feudalises"],
    &["feudalizes"],
    &["feudalises"],
];

pub(crate) static ENTRY_FEUDALIZE_17118096652700433458: VariantsMap = [
    &["feudalize"],
    &["feudalise"],
    &["feudalize"],
    &["feudalise"],
];

pub(crate) static ENTRY_FEUDALIZING_5894661627571637958: VariantsMap = [
    &["feudalizing"],
    &["feudalising"],
    &["feudalizing"],
    &["feudalising"],
];

pub(crate) static ENTRY_FEUTER_11733789004079348259: VariantsMap =
    [&["feuter"], &["feutre"], &["feutre"], &["feutre"]];

pub(crate) static ENTRY_FE_6412855417629126837: VariantsMap =
    [&["fe"], &["fae"], &["fae"], &["fae"]];

pub(crate) static ENTRY_FIBERBOARDS_269218288221177098: VariantsMap = [
    &["fiberboards"],
    &["fibreboards"],
    &["fibreboards"],
    &["fibreboards"],
];

pub(crate) static ENTRY_FIBERBOARD_10324118796464858065: VariantsMap = [
    &["fiberboard"],
    &["fibreboard"],
    &["fibreboard"],
    &["fibreboard"],
];

pub(crate) static ENTRY_FIBERED_14866184343878669662: VariantsMap =
    [&["fibered"], &["fibred"], &["fibred"], &["fibred"]];

pub(crate) static ENTRY_FIBERFILLS_10714754498813286510: VariantsMap = [
    &["fiberfills"],
    &["fibrefills"],
    &["fibrefills"],
    &["fibrefills"],
];

pub(crate) static ENTRY_FIBERFILL_15892338090700624301: VariantsMap = [
    &["fiberfill"],
    &["fibrefill"],
    &["fibrefill"],
    &["fibrefill"],
];

pub(crate) static ENTRY_FIBERGLASSES_9573599106910515750: VariantsMap = [
    &["fiberglasses"],
    &["fibreglasses"],
    &["fibreglasses"],
    &["fibreglasses"],
];

pub(crate) static ENTRY_FIBERGLASS_13840692803898764317: VariantsMap = [
    &["fiberglass"],
    &["fibreglass"],
    &["fibreglass"],
    &["fibreglass"],
];

pub(crate) static ENTRY_FIBERIZATION_9448789050279142343: VariantsMap = [
    &["fiberization"],
    &["fibrisation"],
    &["fibrization"],
    &["fibrisation"],
];

pub(crate) static ENTRY_FIBERIZED_16418419709512190847: VariantsMap =
    [&["fiberized"], &["fibrised"], &["fibrized"], &["fibrised"]];

pub(crate) static ENTRY_FIBERIZERS_11340645263185175813: VariantsMap = [
    &["fiberizers"],
    &["fibrisers"],
    &["fibrizers"],
    &["fibrisers"],
];

pub(crate) static ENTRY_FIBERIZER_2701702218944894305: VariantsMap =
    [&["fiberizer"], &["fibriser"], &["fibrizer"], &["fibriser"]];

pub(crate) static ENTRY_FIBERIZES_17105028343308432924: VariantsMap =
    [&["fiberizes"], &["fibrises"], &["fibrizes"], &["fibrises"]];

pub(crate) static ENTRY_FIBERIZE_10354491173153304112: VariantsMap =
    [&["fiberize"], &["fibrise"], &["fibrize"], &["fibrise"]];

pub(crate) static ENTRY_FIBERIZING_4344905904350693098: VariantsMap = [
    &["fiberizing"],
    &["fibrising"],
    &["fibrizing"],
    &["fibrising"],
];

pub(crate) static ENTRY_FIBERLESSER_10368335487999390386: VariantsMap = [
    &["fiberlesser"],
    &["fibrelesser"],
    &["fibrelesser"],
    &["fibrelesser"],
];

pub(crate) static ENTRY_FIBERLESSEST_6306196796958857387: VariantsMap = [
    &["fiberlessest"],
    &["fibrelessest"],
    &["fibrelessest"],
    &["fibrelessest"],
];

pub(crate) static ENTRY_FIBERLESSES_1834703312046091949: VariantsMap = [
    &["fiberlesses"],
    &["fibrelesses"],
    &["fibrelesses"],
    &["fibrelesses"],
];

pub(crate) static ENTRY_FIBERLESS_13606825025487113070: VariantsMap = [
    &["fiberless"],
    &["fibreless"],
    &["fibreless"],
    &["fibreless"],
];

pub(crate) static ENTRY_FIBERSCOPES_5722286864782871846: VariantsMap = [
    &["fiberscopes"],
    &["fibrescopes"],
    &["fibrescopes"],
    &["fibrescopes"],
];

pub(crate) static ENTRY_FIBERSCOPE_4051287012646069815: VariantsMap = [
    &["fiberscope"],
    &["fibrescope"],
    &["fibrescope"],
    &["fibrescope"],
];

pub(crate) static ENTRY_FIBERS_1624245329619960183: VariantsMap =
    [&["fibers"], &["fibres"], &["fibres"], &["fibres"]];

pub(crate) static ENTRY_FIBERWARE_17783914386673468694: VariantsMap = [
    &["fiberware"],
    &["fibreware"],
    &["fibreware"],
    &["fibreware"],
];

pub(crate) static ENTRY_FIBER_14507009441549378513: VariantsMap =
    [&["fiber"], &["fibre"], &["fibre"], &["fibre"]];

pub(crate) static ENTRY_FICTIONALIZATIONS_15175949905460110834: VariantsMap = [
    &["fictionalizations"],
    &["fictionalisations"],
    &["fictionalizations"],
    &["fictionalisations"],
];

pub(crate) static ENTRY_FICTIONALIZATION_11692879889381010340: VariantsMap = [
    &["fictionalization"],
    &["fictionalisation"],
    &["fictionalization"],
    &["fictionalisation"],
];

pub(crate) static ENTRY_FICTIONALIZED_12033706812575403958: VariantsMap = [
    &["fictionalized"],
    &["fictionalised"],
    &["fictionalized"],
    &["fictionalised"],
];

pub(crate) static ENTRY_FICTIONALIZES_9852400248787060636: VariantsMap = [
    &["fictionalizes"],
    &["fictionalises"],
    &["fictionalizes"],
    &["fictionalises"],
];

pub(crate) static ENTRY_FICTIONALIZE_14824190480215773487: VariantsMap = [
    &["fictionalize"],
    &["fictionalise"],
    &["fictionalize"],
    &["fictionalise"],
];

pub(crate) static ENTRY_FICTIONALIZING_783960443322171580: VariantsMap = [
    &["fictionalizing"],
    &["fictionalising"],
    &["fictionalizing"],
    &["fictionalising"],
];

pub(crate) static ENTRY_FICTIONIZATIONS_8973608411174529758: VariantsMap = [
    &["fictionizations"],
    &["fictionisations"],
    &["fictionizations"],
    &["fictionisations"],
];

pub(crate) static ENTRY_FICTIONIZATION_18268699499501030808: VariantsMap = [
    &["fictionization"],
    &["fictionisation"],
    &["fictionization"],
    &["fictionisation"],
];

pub(crate) static ENTRY_FICTIONIZED_653881811178594366: VariantsMap = [
    &["fictionized"],
    &["fictionised"],
    &["fictionized"],
    &["fictionised"],
];

pub(crate) static ENTRY_FICTIONIZES_10384497571420374630: VariantsMap = [
    &["fictionizes"],
    &["fictionises"],
    &["fictionizes"],
    &["fictionises"],
];

pub(crate) static ENTRY_FICTIONIZE_8954439194060631064: VariantsMap = [
    &["fictionize"],
    &["fictionise"],
    &["fictionize"],
    &["fictionise"],
];

pub(crate) static ENTRY_FICTIONIZING_8996574763647367439: VariantsMap = [
    &["fictionizing"],
    &["fictionising"],
    &["fictionizing"],
    &["fictionising"],
];

pub(crate) static ENTRY_FIGURIZES_6013645329552207900: VariantsMap = [
    &["figurizes"],
    &["figurises"],
    &["figurizes"],
    &["figurises"],
];

pub(crate) static ENTRY_FIGURIZE_7661939521561734817: VariantsMap =
    [&["figurize"], &["figurise"], &["figurize"], &["figurise"]];

pub(crate) static ENTRY_FILMIZES_15115815173662536994: VariantsMap =
    [&["filmizes"], &["filmises"], &["filmizes"], &["filmises"]];

pub(crate) static ENTRY_FILMIZE_7155150221464159291: VariantsMap =
    [&["filmize"], &["filmise"], &["filmize"], &["filmise"]];

pub(crate) static ENTRY_FINALIZATIONS_10467708361376087611: VariantsMap = [
    &["finalizations"],
    &["finalisations"],
    &["finalizations"],
    &["finalisations"],
];

pub(crate) static ENTRY_FINALIZATION_5389362780452251733: VariantsMap = [
    &["finalization"],
    &["finalisation"],
    &["finalization"],
    &["finalisation"],
];

pub(crate) static ENTRY_FINALIZED_17116867203523473286: VariantsMap = [
    &["finalized"],
    &["finalised"],
    &["finalized"],
    &["finalised"],
];

pub(crate) static ENTRY_FINALIZES_15580788945544450334: VariantsMap = [
    &["finalizes"],
    &["finalises"],
    &["finalizes"],
    &["finalises"],
];

pub(crate) static ENTRY_FINALIZE_7368891692414429008: VariantsMap =
    [&["finalize"], &["finalise"], &["finalize"], &["finalise"]];

pub(crate) static ENTRY_FINALIZING_12863153952708494256: VariantsMap = [
    &["finalizing"],
    &["finalising"],
    &["finalizing"],
    &["finalising"],
];

pub(crate) static ENTRY_FINLANDIZATIONS_6441501577080440734: VariantsMap = [
    &["finlandizations"],
    &["finlandisations"],
    &["finlandizations"],
    &["finlandisations"],
];

pub(crate) static ENTRY_FINLANDIZATION_8745466326361207485: VariantsMap = [
    &["finlandization"],
    &["finlandisation"],
    &["finlandization"],
    &["finlandisation"],
];

pub(crate) static ENTRY_FISCALIZATIONS_5487988177733166944: VariantsMap = [
    &["fiscalizations"],
    &["fiscalisations"],
    &["fiscalizations"],
    &["fiscalisations"],
];

pub(crate) static ENTRY_FISCALIZATION_3524679306286726467: VariantsMap = [
    &["fiscalization"],
    &["fiscalisation"],
    &["fiscalization"],
    &["fiscalisation"],
];

pub(crate) static ENTRY_FISCALIZES_16628961294565852240: VariantsMap = [
    &["fiscalizes"],
    &["fiscalises"],
    &["fiscalizes"],
    &["fiscalises"],
];

pub(crate) static ENTRY_FISCALIZE_7774689209313530004: VariantsMap = [
    &["fiscalize"],
    &["fiscalise"],
    &["fiscalize"],
    &["fiscalise"],
];

pub(crate) static ENTRY_FLAMBOYANTIZES_13178578745419937978: VariantsMap = [
    &["flamboyantizes"],
    &["flamboyantises"],
    &["flamboyantizes"],
    &["flamboyantises"],
];

pub(crate) static ENTRY_FLAMBOYANTIZE_10665310261460088576: VariantsMap = [
    &["flamboyantize"],
    &["flamboyantise"],
    &["flamboyantize"],
    &["flamboyantise"],
];

pub(crate) static ENTRY_FLANNELED_17580849639984803258: VariantsMap = [
    &["flanneled"],
    &["flannelled"],
    &["flannelled"],
    &["flannelled"],
];

pub(crate) static ENTRY_FLANNELETTE_17407058729842674548: VariantsMap = [
    &["flannelette"],
    &["flannelette"],
    &["flannelette"],
    &["flannelette"],
];

pub(crate) static ENTRY_FLANNELING_11086853821529088619: VariantsMap = [
    &["flanneling"],
    &["flannelling"],
    &["flannelling"],
    &["flannelling"],
];

pub(crate) static ENTRY_FLAVORED_525661928043886116: VariantsMap = [
    &["flavored"],
    &["flavoured"],
    &["flavoured"],
    &["flavoured"],
];

pub(crate) static ENTRY_FLAVORERS_8743617427163027351: VariantsMap = [
    &["flavorers"],
    &["flavourers"],
    &["flavourers"],
    &["flavourers"],
];

pub(crate) static ENTRY_FLAVORER_18085561157245164723: VariantsMap = [
    &["flavorer"],
    &["flavourer"],
    &["flavourer"],
    &["flavourer"],
];

pub(crate) static ENTRY_FLAVORFULER_15725987112799498805: VariantsMap = [
    &["flavorfuler"],
    &["flavourfuler"],
    &["flavourfuler"],
    &["flavourfuler"],
];

pub(crate) static ENTRY_FLAVORFULEST_4668841165513179755: VariantsMap = [
    &["flavorfulest"],
    &["flavourfulest"],
    &["flavourfulest"],
    &["flavourfulest"],
];

pub(crate) static ENTRY_FLAVORFULLIER_11289585236476375035: VariantsMap = [
    &["flavorfullier"],
    &["flavourfullier"],
    &["flavourfullier"],
    &["flavourfullier"],
];

pub(crate) static ENTRY_FLAVORFULLIEST_16131025075943257190: VariantsMap = [
    &["flavorfulliest"],
    &["flavourfulliest"],
    &["flavourfulliest"],
    &["flavourfulliest"],
];

pub(crate) static ENTRY_FLAVORFULLY_554851301589979567: VariantsMap = [
    &["flavorfully"],
    &["flavourfully"],
    &["flavourfully"],
    &["flavourfully"],
];

pub(crate) static ENTRY_FLAVORFUL_3364515868787360493: VariantsMap = [
    &["flavorful"],
    &["flavourful"],
    &["flavourful"],
    &["flavourful"],
];

pub(crate) static ENTRY_FLAVORIER_5245362258137267071: VariantsMap = [
    &["flavorier"],
    &["flavourier"],
    &["flavourier"],
    &["flavourier"],
];

pub(crate) static ENTRY_FLAVORIEST_6780248413885561418: VariantsMap = [
    &["flavoriest"],
    &["flavouriest"],
    &["flavouriest"],
    &["flavouriest"],
];

pub(crate) static ENTRY_FLAVORINGS_1645163762707862008: VariantsMap = [
    &["flavorings"],
    &["flavourings"],
    &["flavourings"],
    &["flavourings"],
];

pub(crate) static ENTRY_FLAVORING_1483810932321135411: VariantsMap = [
    &["flavoring"],
    &["flavouring"],
    &["flavouring"],
    &["flavouring"],
];

pub(crate) static ENTRY_FLAVORLESSER_12189097008069848011: VariantsMap = [
    &["flavorlesser"],
    &["flavourlesser"],
    &["flavourlesser"],
    &["flavourlesser"],
];

pub(crate) static ENTRY_FLAVORLESSEST_3238763211273729754: VariantsMap = [
    &["flavorlessest"],
    &["flavourlessest"],
    &["flavourlessest"],
    &["flavourlessest"],
];

pub(crate) static ENTRY_FLAVORLESSES_6887571633548882211: VariantsMap = [
    &["flavorlesses"],
    &["flavourlesses"],
    &["flavourlesses"],
    &["flavourlesses"],
];

pub(crate) static ENTRY_FLAVORLESS_254570914842921432: VariantsMap = [
    &["flavorless"],
    &["flavourless"],
    &["flavourless"],
    &["flavourless"],
];

pub(crate) static ENTRY_FLAVOROUS_4316380042967520904: VariantsMap = [
    &["flavorous"],
    &["flavorous"],
    &["flavorous"],
    &["flavorous"],
];

pub(crate) static ENTRY_FLAVORSOMER_14092054357849095537: VariantsMap = [
    &["flavorsomer"],
    &["flavoursomer"],
    &["flavoursomer"],
    &["flavoursomer"],
];

pub(crate) static ENTRY_FLAVORSOMEST_10683456501512121672: VariantsMap = [
    &["flavorsomest"],
    &["flavoursomest"],
    &["flavoursomest"],
    &["flavoursomest"],
];

pub(crate) static ENTRY_FLAVORSOME_16308753816531755807: VariantsMap = [
    &["flavorsome"],
    &["flavoursome"],
    &["flavoursome"],
    &["flavoursome"],
];

pub(crate) static ENTRY_FLAVORS_4210116483931656755: VariantsMap =
    [&["flavors"], &["flavours"], &["flavours"], &["flavours"]];

pub(crate) static ENTRY_FLAVORY_14845529741701932399: VariantsMap =
    [&["flavory"], &["flavoury"], &["flavoury"], &["flavoury"]];

pub(crate) static ENTRY_FLAVOR_5944890422119857447: VariantsMap =
    [&["flavor"], &["flavour"], &["flavour"], &["flavour"]];

pub(crate) static ENTRY_FLEDGLINGS_15894553198111159741: VariantsMap = [
    &["fledglings"],
    &["fledglings"],
    &["fledglings"],
    &["fledglings"],
];

pub(crate) static ENTRY_FLEDGLING_16171712275155767970: VariantsMap = [
    &["fledgling"],
    &["fledgling"],
    &["fledgling"],
    &["fledgling"],
];

pub(crate) static ENTRY_FLETCHERIZED_13084731314883103945: VariantsMap = [
    &["fletcherized"],
    &["fletcherised"],
    &["fletcherized"],
    &["fletcherised"],
];

pub(crate) static ENTRY_FLETCHERIZES_9045962588657153054: VariantsMap = [
    &["fletcherizes"],
    &["fletcherises"],
    &["fletcherizes"],
    &["fletcherises"],
];

pub(crate) static ENTRY_FLETCHERIZE_13571050359642201090: VariantsMap = [
    &["fletcherize"],
    &["fletcherise"],
    &["fletcherize"],
    &["fletcherise"],
];

pub(crate) static ENTRY_FLETCHERIZING_13648398213116551529: VariantsMap = [
    &["fletcherizing"],
    &["fletcherising"],
    &["fletcherizing"],
    &["fletcherising"],
];

pub(crate) static ENTRY_FLORALIZES_9204519605461520054: VariantsMap = [
    &["floralizes"],
    &["floralises"],
    &["floralizes"],
    &["floralises"],
];

pub(crate) static ENTRY_FLORALIZE_16091946751913584148: VariantsMap = [
    &["floralize"],
    &["floralise"],
    &["floralize"],
    &["floralise"],
];

pub(crate) static ENTRY_FLORAMOR_6523671428808024045: VariantsMap = [
    &["floramor"],
    &["floramour"],
    &["floramour"],
    &["floramour"],
];

pub(crate) static ENTRY_FLUIDIZATIONS_2883736667208171344: VariantsMap = [
    &["fluidizations"],
    &["fluidisations"],
    &["fluidizations"],
    &["fluidisations"],
];

pub(crate) static ENTRY_FLUIDIZATION_16411400305912346218: VariantsMap = [
    &["fluidization"],
    &["fluidisation"],
    &["fluidization"],
    &["fluidisation"],
];

pub(crate) static ENTRY_FLUIDIZED_4140228345030695002: VariantsMap = [
    &["fluidized"],
    &["fluidised"],
    &["fluidized"],
    &["fluidised"],
];

pub(crate) static ENTRY_FLUIDIZERS_1532884574807524059: VariantsMap = [
    &["fluidizers"],
    &["fluidisers"],
    &["fluidizers"],
    &["fluidisers"],
];

pub(crate) static ENTRY_FLUIDIZER_8317198903618780857: VariantsMap = [
    &["fluidizer"],
    &["fluidiser"],
    &["fluidizer"],
    &["fluidiser"],
];

pub(crate) static ENTRY_FLUIDIZES_15400536994754984208: VariantsMap = [
    &["fluidizes"],
    &["fluidises"],
    &["fluidizes"],
    &["fluidises"],
];

pub(crate) static ENTRY_FLUIDIZE_3228666754770451931: VariantsMap =
    [&["fluidize"], &["fluidise"], &["fluidize"], &["fluidise"]];

pub(crate) static ENTRY_FLUIDIZING_18408628175522942192: VariantsMap = [
    &["fluidizing"],
    &["fluidising"],
    &["fluidizing"],
    &["fluidising"],
];

pub(crate) static ENTRY_FLUORIDIZATIONS_8146935928129561754: VariantsMap = [
    &["fluoridizations"],
    &["fluoridisations"],
    &["fluoridizations"],
    &["fluoridisations"],
];

pub(crate) static ENTRY_FLUORIDIZATION_14827318202477553831: VariantsMap = [
    &["fluoridization"],
    &["fluoridisation"],
    &["fluoridization"],
    &["fluoridisation"],
];

pub(crate) static ENTRY_FLUORIDIZED_3488303050093414681: VariantsMap = [
    &["fluoridized"],
    &["fluoridised"],
    &["fluoridized"],
    &["fluoridised"],
];

pub(crate) static ENTRY_FLUORIDIZES_13091150879113382645: VariantsMap = [
    &["fluoridizes"],
    &["fluoridises"],
    &["fluoridizes"],
    &["fluoridises"],
];

pub(crate) static ENTRY_FLUORIDIZE_7749548833135664422: VariantsMap = [
    &["fluoridize"],
    &["fluoridise"],
    &["fluoridize"],
    &["fluoridise"],
];

pub(crate) static ENTRY_FLUORIDIZING_15655433412990428539: VariantsMap = [
    &["fluoridizing"],
    &["fluoridising"],
    &["fluoridizing"],
    &["fluoridising"],
];

pub(crate) static ENTRY_FLUTISTS_7891281533553389633: VariantsMap = [
    &["flutists"],
    &["flautists"],
    &["flautists", "flutists"],
    &["flautists"],
];

pub(crate) static ENTRY_FLUTIST_11416410543776393575: VariantsMap = [
    &["flutist"],
    &["flautist"],
    &["flautist", "flutist"],
    &["flautist"],
];

pub(crate) static ENTRY_FOCALIZATIONS_16231123162455166109: VariantsMap = [
    &["focalizations"],
    &["focalisations"],
    &["focalizations"],
    &["focalisations"],
];

pub(crate) static ENTRY_FOCALIZATION_17882330704863832560: VariantsMap = [
    &["focalization"],
    &["focalisation"],
    &["focalization"],
    &["focalisation"],
];

pub(crate) static ENTRY_FOCALIZED_5282149808777869906: VariantsMap = [
    &["focalized"],
    &["focalised"],
    &["focalized"],
    &["focalised"],
];

pub(crate) static ENTRY_FOCALIZES_17823194392580987761: VariantsMap = [
    &["focalizes"],
    &["focalises"],
    &["focalizes"],
    &["focalises"],
];

pub(crate) static ENTRY_FOCALIZE_10950232880240497629: VariantsMap =
    [&["focalize"], &["focalise"], &["focalize"], &["focalise"]];

pub(crate) static ENTRY_FOCALIZING_4851388567122001857: VariantsMap = [
    &["focalizing"],
    &["focalising"],
    &["focalizing"],
    &["focalising"],
];

pub(crate) static ENTRY_FOGIES_2124096126255173426: VariantsMap =
    [&["fogies"], &["fogeys"], &["fogeys"], &["fogeys"]];

pub(crate) static ENTRY_FOGY_8196900434631652171: VariantsMap =
    [&["fogy"], &["fogey"], &["fogey"], &["fogey"]];

pub(crate) static ENTRY_FONTANELS_12210678121288501630: VariantsMap = [
    &["fontanels"],
    &["fontanelles"],
    &["fontanelles"],
    &["fontanelles"],
];

pub(crate) static ENTRY_FONTANEL_7739265077938422568: VariantsMap = [
    &["fontanel"],
    &["fontanelle"],
    &["fontanelle"],
    &["fontanelle"],
];

pub(crate) static ENTRY_FOOLHARDIZED_17362186477311628401: VariantsMap = [
    &["foolhardized"],
    &["foolhardised"],
    &["foolhardized"],
    &["foolhardised"],
];

pub(crate) static ENTRY_FOOLHARDIZES_10067494006367806341: VariantsMap = [
    &["foolhardizes"],
    &["foolhardises"],
    &["foolhardizes"],
    &["foolhardises"],
];

pub(crate) static ENTRY_FOOLHARDIZE_5967520092159682639: VariantsMap = [
    &["foolhardize"],
    &["foolhardise"],
    &["foolhardize"],
    &["foolhardise"],
];

pub(crate) static ENTRY_FOOLHARDIZING_14970024232233507775: VariantsMap = [
    &["foolhardizing"],
    &["foolhardising"],
    &["foolhardizing"],
    &["foolhardising"],
];

pub(crate) static ENTRY_FORB_9679413672356101479: VariantsMap =
    [&["forb"], &["fourb"], &["fourb"], &["fourb"]];

pub(crate) static ENTRY_FORCHE_7953345641228779575: VariantsMap =
    [&["forche"], &["fourche"], &["fourche"], &["fourche"]];

pub(crate) static ENTRY_FOREIGNIZATIONS_1673640877548882914: VariantsMap = [
    &["foreignizations"],
    &["foreignisations"],
    &["foreignizations"],
    &["foreignisations"],
];

pub(crate) static ENTRY_FOREIGNIZATION_12772414430467369432: VariantsMap = [
    &["foreignization"],
    &["foreignisation"],
    &["foreignization"],
    &["foreignisation"],
];

pub(crate) static ENTRY_FOREIGNIZES_17287836650502268788: VariantsMap = [
    &["foreignizes"],
    &["foreignises"],
    &["foreignizes"],
    &["foreignises"],
];

pub(crate) static ENTRY_FOREIGNIZE_5421502222612225073: VariantsMap = [
    &["foreignize"],
    &["foreignise"],
    &["foreignize"],
    &["foreignise"],
];

pub(crate) static ENTRY_FOREJUDGMENTS_12337114003687174866: VariantsMap = [
    &["forejudgments"],
    &["forejudgements"],
    &["forejudgements"],
    &["forejudgements"],
];

pub(crate) static ENTRY_FOREJUDGMENT_18186411586344216775: VariantsMap = [
    &["forejudgment"],
    &["forejudgement"],
    &["forejudgement"],
    &["forejudgement"],
];

pub(crate) static ENTRY_FOREPRIZE_14829680777562161527: VariantsMap = [
    &["foreprize"],
    &["foreprise"],
    &["foreprize"],
    &["foreprise"],
];

pub(crate) static ENTRY_FORMALIZABLE_6664723737959773302: VariantsMap = [
    &["formalizable"],
    &["formalisable"],
    &["formalizable"],
    &["formalisable"],
];

pub(crate) static ENTRY_FORMALIZATIONS_4885129653293673852: VariantsMap = [
    &["formalizations"],
    &["formalisations"],
    &["formalizations"],
    &["formalisations"],
];

pub(crate) static ENTRY_FORMALIZATION_3676651268193150145: VariantsMap = [
    &["formalization"],
    &["formalisation"],
    &["formalization"],
    &["formalisation"],
];

pub(crate) static ENTRY_FORMALIZED_8942791564083823012: VariantsMap = [
    &["formalized"],
    &["formalised"],
    &["formalized"],
    &["formalised"],
];

pub(crate) static ENTRY_FORMALIZERS_2220190158856468837: VariantsMap = [
    &["formalizers"],
    &["formalisers"],
    &["formalizers"],
    &["formalisers"],
];

pub(crate) static ENTRY_FORMALIZER_12142743809421262488: VariantsMap = [
    &["formalizer"],
    &["formaliser"],
    &["formalizer"],
    &["formaliser"],
];

pub(crate) static ENTRY_FORMALIZES_15952411364716226248: VariantsMap = [
    &["formalizes"],
    &["formalises"],
    &["formalizes"],
    &["formalises"],
];

pub(crate) static ENTRY_FORMALIZE_2062294330762511135: VariantsMap = [
    &["formalize"],
    &["formalise"],
    &["formalize"],
    &["formalise"],
];

pub(crate) static ENTRY_FORMALIZING_14987435811550688603: VariantsMap = [
    &["formalizing"],
    &["formalising"],
    &["formalizing"],
    &["formalising"],
];

pub(crate) static ENTRY_FORME_17813592903189666121: VariantsMap =
    [&["forme"], &["formae"], &["formae"], &["formae"]];

pub(crate) static ENTRY_FORMICIDE_1909286592081562828: VariantsMap = [
    &["formicide"],
    &["formicidae"],
    &["formicidae"],
    &["formicidae"],
];

pub(crate) static ENTRY_FORMULARIZATIONS_14807438866090777526: VariantsMap = [
    &["formularizations"],
    &["formularisations"],
    &["formularizations"],
    &["formularisations"],
];

pub(crate) static ENTRY_FORMULARIZATION_12271501529394856515: VariantsMap = [
    &["formularization"],
    &["formularisation"],
    &["formularization"],
    &["formularisation"],
];

pub(crate) static ENTRY_FORMULARIZED_13568613489170427732: VariantsMap = [
    &["formularized"],
    &["formularised"],
    &["formularized"],
    &["formularised"],
];

pub(crate) static ENTRY_FORMULARIZERS_5289341589375736287: VariantsMap = [
    &["formularizers"],
    &["formularisers"],
    &["formularizers"],
    &["formularisers"],
];

pub(crate) static ENTRY_FORMULARIZER_6098631881104862148: VariantsMap = [
    &["formularizer"],
    &["formulariser"],
    &["formularizer"],
    &["formulariser"],
];

pub(crate) static ENTRY_FORMULARIZES_4653655791226941263: VariantsMap = [
    &["formularizes"],
    &["formularises"],
    &["formularizes"],
    &["formularises"],
];

pub(crate) static ENTRY_FORMULARIZE_13855848211751134881: VariantsMap = [
    &["formularize"],
    &["formularise"],
    &["formularize"],
    &["formularise"],
];

pub(crate) static ENTRY_FORMULARIZING_7416917489055476160: VariantsMap = [
    &["formularizing"],
    &["formularising"],
    &["formularizing"],
    &["formularising"],
];

pub(crate) static ENTRY_FORMULIZATIONS_5844779062261258067: VariantsMap = [
    &["formulizations"],
    &["formulisations"],
    &["formulizations"],
    &["formulisations"],
];

pub(crate) static ENTRY_FORMULIZATION_7090367550673650726: VariantsMap = [
    &["formulization"],
    &["formulisation"],
    &["formulization"],
    &["formulisation"],
];

pub(crate) static ENTRY_FORMULIZED_15428824740043784891: VariantsMap = [
    &["formulized"],
    &["formulised"],
    &["formulized"],
    &["formulised"],
];

pub(crate) static ENTRY_FORMULIZER_16549374471213376016: VariantsMap = [
    &["formulizer"],
    &["formuliser"],
    &["formulizer"],
    &["formuliser"],
];

pub(crate) static ENTRY_FORMULIZES_7344560378444034263: VariantsMap = [
    &["formulizes"],
    &["formulises"],
    &["formulizes"],
    &["formulises"],
];

pub(crate) static ENTRY_FORMULIZE_2914526413744900996: VariantsMap = [
    &["formulize"],
    &["formulise"],
    &["formulize"],
    &["formulise"],
];

pub(crate) static ENTRY_FORMULIZING_15115678763836572629: VariantsMap = [
    &["formulizing"],
    &["formulising"],
    &["formulizing"],
    &["formulising"],
];

pub(crate) static ENTRY_FORUMIZES_16506356693418413171: VariantsMap = [
    &["forumizes"],
    &["forumises"],
    &["forumizes"],
    &["forumises"],
];

pub(crate) static ENTRY_FORUMIZE_2328995390050560414: VariantsMap =
    [&["forumize"], &["forumise"], &["forumize"], &["forumise"]];

pub(crate) static ENTRY_FOSSE_13143491485595457015: VariantsMap =
    [&["fosse"], &["fossae"], &["fossae"], &["fossae"]];

pub(crate) static ENTRY_FOSSILED_6681230805038992201: VariantsMap = [
    &["fossiled"],
    &["fossilled"],
    &["fossilled"],
    &["fossilled"],
];

pub(crate) static ENTRY_FOSSILIZABLER_9629581083024138184: VariantsMap = [
    &["fossilizabler"],
    &["fossilisabler"],
    &["fossilizabler"],
    &["fossilisabler"],
];

pub(crate) static ENTRY_FOSSILIZABLEST_12458438397842223206: VariantsMap = [
    &["fossilizablest"],
    &["fossilisablest"],
    &["fossilizablest"],
    &["fossilisablest"],
];

pub(crate) static ENTRY_FOSSILIZABLES_850215141590149031: VariantsMap = [
    &["fossilizables"],
    &["fossilisables"],
    &["fossilizables"],
    &["fossilisables"],
];

pub(crate) static ENTRY_FOSSILIZABLE_16442685154631302293: VariantsMap = [
    &["fossilizable"],
    &["fossilisable"],
    &["fossilizable"],
    &["fossilisable"],
];

pub(crate) static ENTRY_FOSSILIZATIONS_5273119211786261405: VariantsMap = [
    &["fossilizations"],
    &["fossilisations"],
    &["fossilizations"],
    &["fossilisations"],
];

pub(crate) static ENTRY_FOSSILIZATION_18247511318058151007: VariantsMap = [
    &["fossilization"],
    &["fossilisation"],
    &["fossilization"],
    &["fossilisation"],
];

pub(crate) static ENTRY_FOSSILIZED_16904263175369675937: VariantsMap = [
    &["fossilized"],
    &["fossilised"],
    &["fossilized"],
    &["fossilised"],
];

pub(crate) static ENTRY_FOSSILIZES_16548112466000258743: VariantsMap = [
    &["fossilizes"],
    &["fossilises"],
    &["fossilizes"],
    &["fossilises"],
];

pub(crate) static ENTRY_FOSSILIZE_16499579356323869709: VariantsMap = [
    &["fossilize"],
    &["fossilise"],
    &["fossilize"],
    &["fossilise"],
];

pub(crate) static ENTRY_FOSSILIZING_3467552662674039049: VariantsMap = [
    &["fossilizing"],
    &["fossilising"],
    &["fossilizing"],
    &["fossilising"],
];

pub(crate) static ENTRY_FOSSULE_3767722355901060753: VariantsMap =
    [&["fossule"], &["fossulae"], &["fossulae"], &["fossulae"]];

pub(crate) static ENTRY_FOULDER_5820992871688859169: VariantsMap =
    [&["foulder"], &["fouldre"], &["fouldre"], &["fouldre"]];

pub(crate) static ENTRY_FOUTERS_6533881490801158798: VariantsMap =
    [&["fouters"], &["foutres"], &["foutres"], &["foutres"]];

pub(crate) static ENTRY_FOUTER_16408335415437635545: VariantsMap =
    [&["fouter"], &["foutre"], &["foutre"], &["foutre"]];

pub(crate) static ENTRY_FOVEOLE_11823716102342610928: VariantsMap =
    [&["foveole"], &["foveolae"], &["foveolae"], &["foveolae"]];

pub(crate) static ENTRY_FRACTIONALIZATIONS_8934904189796674249: VariantsMap = [
    &["fractionalizations"],
    &["fractionalisations"],
    &["fractionalizations"],
    &["fractionalisations"],
];

pub(crate) static ENTRY_FRACTIONALIZATION_8741548311534296932: VariantsMap = [
    &["fractionalization"],
    &["fractionalisation"],
    &["fractionalization"],
    &["fractionalisation"],
];

pub(crate) static ENTRY_FRACTIONALIZED_1638721305897569649: VariantsMap = [
    &["fractionalized"],
    &["fractionalised"],
    &["fractionalized"],
    &["fractionalised"],
];

pub(crate) static ENTRY_FRACTIONALIZES_5842077662678248264: VariantsMap = [
    &["fractionalizes"],
    &["fractionalises"],
    &["fractionalizes"],
    &["fractionalises"],
];

pub(crate) static ENTRY_FRACTIONALIZE_6994927438734081827: VariantsMap = [
    &["fractionalize"],
    &["fractionalise"],
    &["fractionalize"],
    &["fractionalise"],
];

pub(crate) static ENTRY_FRACTIONALIZING_5293926974627714004: VariantsMap = [
    &["fractionalizing"],
    &["fractionalising"],
    &["fractionalizing"],
    &["fractionalising"],
];

pub(crate) static ENTRY_FRACTIONIZATIONS_15392396968809874240: VariantsMap = [
    &["fractionizations"],
    &["fractionisations"],
    &["fractionizations"],
    &["fractionisations"],
];

pub(crate) static ENTRY_FRACTIONIZATION_15598581478527181020: VariantsMap = [
    &["fractionization"],
    &["fractionisation"],
    &["fractionization"],
    &["fractionisation"],
];

pub(crate) static ENTRY_FRACTIONIZED_10758840764680531186: VariantsMap = [
    &["fractionized"],
    &["fractionised"],
    &["fractionized"],
    &["fractionised"],
];

pub(crate) static ENTRY_FRACTIONIZES_4188934241716763343: VariantsMap = [
    &["fractionizes"],
    &["fractionises"],
    &["fractionizes"],
    &["fractionises"],
];

pub(crate) static ENTRY_FRACTIONIZE_2094786255743540739: VariantsMap = [
    &["fractionize"],
    &["fractionise"],
    &["fractionize"],
    &["fractionise"],
];

pub(crate) static ENTRY_FRACTIONIZING_15905405027559811921: VariantsMap = [
    &["fractionizing"],
    &["fractionising"],
    &["fractionizing"],
    &["fractionising"],
];

pub(crate) static ENTRY_FRAGMENTIZATION_13686229545603363988: VariantsMap = [
    &["fragmentization"],
    &["fragmentisation"],
    &["fragmentization"],
    &["fragmentisation"],
];

pub(crate) static ENTRY_FRAGMENTIZED_10911876725635952911: VariantsMap = [
    &["fragmentized"],
    &["fragmentised"],
    &["fragmentized"],
    &["fragmentised"],
];

pub(crate) static ENTRY_FRAGMENTIZER_7600451912254376830: VariantsMap = [
    &["fragmentizer"],
    &["fragmentiser"],
    &["fragmentizer"],
    &["fragmentiser"],
];

pub(crate) static ENTRY_FRAGMENTIZES_9129150506354302185: VariantsMap = [
    &["fragmentizes"],
    &["fragmentises"],
    &["fragmentizes"],
    &["fragmentises"],
];

pub(crate) static ENTRY_FRAGMENTIZE_7391127946985078106: VariantsMap = [
    &["fragmentize"],
    &["fragmentise"],
    &["fragmentize"],
    &["fragmentise"],
];

pub(crate) static ENTRY_FRAGMENTIZING_7217264286732775271: VariantsMap = [
    &["fragmentizing"],
    &["fragmentising"],
    &["fragmentizing"],
    &["fragmentising"],
];

pub(crate) static ENTRY_FRAMBESIAS_6675406155055169863: VariantsMap = [
    &["frambesias"],
    &["framboesias"],
    &["framboesias"],
    &["framboesias"],
];

pub(crate) static ENTRY_FRAMBESIA_3541343355805747476: VariantsMap = [
    &["frambesia"],
    &["framboesia"],
    &["framboesia"],
    &["framboesia"],
];

pub(crate) static ENTRY_FRANCIZES_12871352264589337299: VariantsMap = [
    &["francizes"],
    &["francises"],
    &["francizes"],
    &["francises"],
];

pub(crate) static ENTRY_FRANCIZE_124885689522532518: VariantsMap =
    [&["francize"], &["francise"], &["francize"], &["francise"]];

pub(crate) static ENTRY_FRANKLINIZATIONS_8001068711757005090: VariantsMap = [
    &["franklinizations"],
    &["franklinisations"],
    &["franklinizations"],
    &["franklinisations"],
];

pub(crate) static ENTRY_FRANKLINIZATION_6438755640265619569: VariantsMap = [
    &["franklinization"],
    &["franklinisation"],
    &["franklinization"],
    &["franklinisation"],
];

pub(crate) static ENTRY_FRATERNIZATIONS_14137130464047726144: VariantsMap = [
    &["fraternizations"],
    &["fraternisations"],
    &["fraternizations"],
    &["fraternisations"],
];

pub(crate) static ENTRY_FRATERNIZATION_12516017912114447659: VariantsMap = [
    &["fraternization"],
    &["fraternisation"],
    &["fraternization"],
    &["fraternisation"],
];

pub(crate) static ENTRY_FRATERNIZED_17667910852812961677: VariantsMap = [
    &["fraternized"],
    &["fraternised"],
    &["fraternized"],
    &["fraternised"],
];

pub(crate) static ENTRY_FRATERNIZERS_1812552429137645817: VariantsMap = [
    &["fraternizers"],
    &["fraternisers"],
    &["fraternizers"],
    &["fraternisers"],
];

pub(crate) static ENTRY_FRATERNIZER_11810525370100192642: VariantsMap = [
    &["fraternizer"],
    &["fraterniser"],
    &["fraternizer"],
    &["fraterniser"],
];

pub(crate) static ENTRY_FRATERNIZES_13101824246485565774: VariantsMap = [
    &["fraternizes"],
    &["fraternises"],
    &["fraternizes"],
    &["fraternises"],
];

pub(crate) static ENTRY_FRATERNIZE_10028051674996391984: VariantsMap = [
    &["fraternize"],
    &["fraternise"],
    &["fraternize"],
    &["fraternise"],
];

pub(crate) static ENTRY_FRATERNIZING_15346620157919397341: VariantsMap = [
    &["fraternizing"],
    &["fraternising"],
    &["fraternizing"],
    &["fraternising"],
];

pub(crate) static ENTRY_FRENA_5299955759546711915: VariantsMap =
    [&["frena"], &["fraena"], &["fraena"], &["fraena"]];

pub(crate) static ENTRY_FRENCHIZES_8275972422395013693: VariantsMap = [
    &["frenchizes"],
    &["frenchises"],
    &["frenchizes"],
    &["frenchises"],
];

pub(crate) static ENTRY_FRENCHIZE_9878626967854112935: VariantsMap = [
    &["frenchize"],
    &["frenchise"],
    &["frenchize"],
    &["frenchise"],
];

pub(crate) static ENTRY_FRENULAR_17354217019987840503: VariantsMap = [
    &["frenular"],
    &["fraenular"],
    &["fraenular"],
    &["fraenular"],
];

pub(crate) static ENTRY_FRENULA_10450628952852883483: VariantsMap =
    [&["frenula"], &["fraenula"], &["fraenula"], &["fraenula"]];

pub(crate) static ENTRY_FRENULUM_8351124618829742055: VariantsMap = [
    &["frenulum"],
    &["fraenulum"],
    &["fraenulum"],
    &["fraenulum"],
];

pub(crate) static ENTRY_FRENUMS_7693321222408886713: VariantsMap =
    [&["frenums"], &["fraenums"], &["fraenums"], &["fraenums"]];

pub(crate) static ENTRY_FRENUM_7603649563431435410: VariantsMap =
    [&["frenum"], &["fraenum"], &["fraenum"], &["fraenum"]];

pub(crate) static ENTRY_FRIBORG_4949505244575953624: VariantsMap =
    [&["friborg"], &["fribourg"], &["fribourg"], &["fribourg"]];

pub(crate) static ENTRY_FRICTIONIZES_13547838814049221356: VariantsMap = [
    &["frictionizes"],
    &["frictionises"],
    &["frictionizes"],
    &["frictionises"],
];

pub(crate) static ENTRY_FRICTIONIZE_8871056937955154076: VariantsMap = [
    &["frictionize"],
    &["frictionise"],
    &["frictionize"],
    &["frictionise"],
];

pub(crate) static ENTRY_FRIVOLED_6394892650858522123: VariantsMap = [
    &["frivoled"],
    &["frivolled"],
    &["frivolled"],
    &["frivolled"],
];

pub(crate) static ENTRY_FRIVOLERS_6222087214473089062: VariantsMap = [
    &["frivolers"],
    &["frivollers"],
    &["frivollers"],
    &["frivollers"],
];

pub(crate) static ENTRY_FRIVOLER_2732794850565415627: VariantsMap = [
    &["frivoler"],
    &["frivoller"],
    &["frivoller"],
    &["frivoller"],
];

pub(crate) static ENTRY_FRIVOLING_18278706907289454096: VariantsMap = [
    &["frivoling"],
    &["frivolling"],
    &["frivolling"],
    &["frivolling"],
];

pub(crate) static ENTRY_FRIZADO_2372790959778652776: VariantsMap =
    [&["frizado"], &["frisado"], &["frizado"], &["frisado"]];

pub(crate) static ENTRY_FRIZETTES_11347760157442901920: VariantsMap = [
    &["frizettes"],
    &["frisettes"],
    &["frizettes"],
    &["frisettes"],
];

pub(crate) static ENTRY_FRIZETTE_15044855804093147853: VariantsMap =
    [&["frizette"], &["frisette"], &["frizette"], &["frisette"]];

pub(crate) static ENTRY_FRIZE_5835366874549032177: VariantsMap =
    [&["frize"], &["frise"], &["frize"], &["frise"]];

pub(crate) static ENTRY_FUELED_17965004435497699778: VariantsMap =
    [&["fueled"], &["fuelled"], &["fuelled"], &["fuelled"]];

pub(crate) static ENTRY_FUELERS_1336950632325652930: VariantsMap =
    [&["fuelers"], &["fuellers"], &["fuellers"], &["fuellers"]];

pub(crate) static ENTRY_FUELER_6832234238493701204: VariantsMap =
    [&["fueler"], &["fueller"], &["fueller"], &["fueller"]];

pub(crate) static ENTRY_FUELING_16451678036489651807: VariantsMap =
    [&["fueling"], &["fuelling"], &["fuelling"], &["fuelling"]];

pub(crate) static ENTRY_FUELIZERS_9948040613184527499: VariantsMap = [
    &["fuelizers"],
    &["fuelisers"],
    &["fuelizers"],
    &["fuelisers"],
];

pub(crate) static ENTRY_FUELIZER_13619298163080844334: VariantsMap =
    [&["fuelizer"], &["fueliser"], &["fuelizer"], &["fueliser"]];

pub(crate) static ENTRY_FULFILLMENTS_6744331514311877547: VariantsMap = [
    &["fulfillments"],
    &["fulfilments"],
    &["fulfillments"],
    &["fulfilments"],
];

pub(crate) static ENTRY_FULFILLMENT_1403777125945191804: VariantsMap = [
    &["fulfillment"],
    &["fulfilment"],
    &["fulfillment"],
    &["fulfilment"],
];

pub(crate) static ENTRY_FULFILLS_6573936474908938280: VariantsMap =
    [&["fulfills"], &["fulfils"], &["fulfills"], &["fulfils"]];

pub(crate) static ENTRY_FULFILL_18191138303913847238: VariantsMap =
    [&["fulfill"], &["fulfil"], &["fulfill"], &["fulfil"]];

pub(crate) static ENTRY_FULGOROUS_16556587498459255650: VariantsMap = [
    &["fulgorous"],
    &["fulgourous"],
    &["fulgourous"],
    &["fulgourous"],
];

pub(crate) static ENTRY_FULGORS_5277629573271194326: VariantsMap =
    [&["fulgors"], &["fulgours"], &["fulgours"], &["fulgours"]];

pub(crate) static ENTRY_FULGOR_15723323666395416985: VariantsMap =
    [&["fulgor"], &["fulgour"], &["fulgour"], &["fulgour"]];

pub(crate) static ENTRY_FUNCTIONALIZES_6846988132021502765: VariantsMap = [
    &["functionalizes"],
    &["functionalises"],
    &["functionalizes"],
    &["functionalises"],
];

pub(crate) static ENTRY_FUNCTIONALIZE_5343336178576091473: VariantsMap = [
    &["functionalize"],
    &["functionalise"],
    &["functionalize"],
    &["functionalise"],
];

pub(crate) static ENTRY_FUNCTIONIZES_2783436360735686441: VariantsMap = [
    &["functionizes"],
    &["functionises"],
    &["functionizes"],
    &["functionises"],
];

pub(crate) static ENTRY_FUNCTIONIZE_14138434827093737545: VariantsMap = [
    &["functionize"],
    &["functionise"],
    &["functionize"],
    &["functionise"],
];

pub(crate) static ENTRY_FUNERALIZES_17860739737691518434: VariantsMap = [
    &["funeralizes"],
    &["funeralises"],
    &["funeralizes"],
    &["funeralises"],
];

pub(crate) static ENTRY_FUNERALIZE_16393341863187882210: VariantsMap = [
    &["funeralize"],
    &["funeralise"],
    &["funeralize"],
    &["funeralise"],
];

pub(crate) static ENTRY_FUNNELED_5447998884730678168: VariantsMap = [
    &["funneled"],
    &["funnelled"],
    &["funnelled"],
    &["funnelled"],
];

pub(crate) static ENTRY_FUNNELER_2628031221069632410: VariantsMap = [
    &["funneler"],
    &["funneller"],
    &["funneller"],
    &["funneller"],
];

pub(crate) static ENTRY_FUNNELING_7298662514265886848: VariantsMap = [
    &["funneling"],
    &["funnelling"],
    &["funnelling"],
    &["funnelling"],
];

pub(crate) static ENTRY_FURCULE_1236868035751287961: VariantsMap =
    [&["furcule"], &["furculae"], &["furculae"], &["furculae"]];

pub(crate) static ENTRY_FURIE_8435947989235934110: VariantsMap =
    [&["furie"], &["furiae"], &["furiae"], &["furiae"]];

pub(crate) static ENTRY_FURORS_10433443116205259945: VariantsMap =
    [&["furors"], &["furores"], &["furors"], &["furores"]];

pub(crate) static ENTRY_FUROR_15595174347085500171: VariantsMap =
    [&["furor"], &["furore"], &["furor"], &["furore"]];

pub(crate) static ENTRY_FUSED_1257081415466555403: VariantsMap =
    [&["fused"], &["fused"], &["fused"], &["fused"]];

pub(crate) static ENTRY_FUSES_9497075982077327392: VariantsMap =
    [&["fuses"], &["fuses"], &["fuses"], &["fuses"]];

pub(crate) static ENTRY_FUSE_893930905974771271: VariantsMap =
    [&["fuse"], &["fuse"], &["fuse"], &["fuse"]];

pub(crate) static ENTRY_FUSING_5104655535944150194: VariantsMap =
    [&["fusing"], &["fusing"], &["fusing"], &["fusing"]];

pub(crate) static ENTRY_FUSTIANIZED_9552600907569960981: VariantsMap = [
    &["fustianized"],
    &["fustianised"],
    &["fustianized"],
    &["fustianised"],
];

pub(crate) static ENTRY_FUSTIANIZES_8593570763530200647: VariantsMap = [
    &["fustianizes"],
    &["fustianises"],
    &["fustianizes"],
    &["fustianises"],
];

pub(crate) static ENTRY_FUSTIANIZE_10532729281019581804: VariantsMap = [
    &["fustianize"],
    &["fustianise"],
    &["fustianize"],
    &["fustianise"],
];

pub(crate) static ENTRY_FUSTIANIZING_51176411829303510: VariantsMap = [
    &["fustianizing"],
    &["fustianising"],
    &["fustianizing"],
    &["fustianising"],
];

pub(crate) static ENTRY_FUTILIZES_10238957534551686752: VariantsMap = [
    &["futilizes"],
    &["futilises"],
    &["futilizes"],
    &["futilises"],
];

pub(crate) static ENTRY_FUTILIZE_12137872016940583123: VariantsMap =
    [&["futilize"], &["futilise"], &["futilize"], &["futilise"]];

pub(crate) static ENTRY_FUTURIZES_17164339410840070834: VariantsMap = [
    &["futurizes"],
    &["futurises"],
    &["futurizes"],
    &["futurises"],
];

pub(crate) static ENTRY_FUTURIZE_7365851347469569206: VariantsMap =
    [&["futurize"], &["futurise"], &["futurize"], &["futurise"]];

pub(crate) static ENTRY_GAELICIZATIONS_10913123988645786103: VariantsMap = [
    &["gaelicizations"],
    &["gaelicisations"],
    &["gaelicizations"],
    &["gaelicisations"],
];

pub(crate) static ENTRY_GAELICIZATION_8229079546606253770: VariantsMap = [
    &["gaelicization"],
    &["gaelicisation"],
    &["gaelicization"],
    &["gaelicisation"],
];

pub(crate) static ENTRY_GAELICIZED_9134821684445081472: VariantsMap = [
    &["gaelicized"],
    &["gaelicised"],
    &["gaelicized"],
    &["gaelicised"],
];

pub(crate) static ENTRY_GAELICIZES_5628051894918807993: VariantsMap = [
    &["gaelicizes"],
    &["gaelicises"],
    &["gaelicizes"],
    &["gaelicises"],
];

pub(crate) static ENTRY_GAELICIZE_13150850139207150741: VariantsMap = [
    &["gaelicize"],
    &["gaelicise"],
    &["gaelicize"],
    &["gaelicise"],
];

pub(crate) static ENTRY_GAELICIZING_4239545936064142475: VariantsMap = [
    &["gaelicizing"],
    &["gaelicising"],
    &["gaelicizing"],
    &["gaelicising"],
];

pub(crate) static ENTRY_GALACTORRHEAS_2348752207273598936: VariantsMap = [
    &["galactorrheas"],
    &["galactorrhoeas"],
    &["galactorrhoeas"],
    &["galactorrhoeas"],
];

pub(crate) static ENTRY_GALACTORRHEA_8939201946132666128: VariantsMap = [
    &["galactorrhea"],
    &["galactorrhoea"],
    &["galactorrhoea"],
    &["galactorrhoea"],
];

pub(crate) static ENTRY_GALACTOSEMIAS_2689872380032083965: VariantsMap = [
    &["galactosemias"],
    &["galactosaemias"],
    &["galactosaemias"],
    &["galactosaemias"],
];

pub(crate) static ENTRY_GALACTOSEMIA_15356026729538488621: VariantsMap = [
    &["galactosemia"],
    &["galactosaemia"],
    &["galactosaemia"],
    &["galactosaemia"],
];

pub(crate) static ENTRY_GALEE_18295229614385569377: VariantsMap =
    [&["galee"], &["galeae"], &["galeae"], &["galeae"]];

pub(crate) static ENTRY_GALLANTIZES_4128021680900042331: VariantsMap = [
    &["gallantizes"],
    &["gallantises"],
    &["gallantizes"],
    &["gallantises"],
];

pub(crate) static ENTRY_GALLANTIZE_7623840749699418706: VariantsMap = [
    &["gallantize"],
    &["gallantise"],
    &["gallantize"],
    &["gallantise"],
];

pub(crate) static ENTRY_GALLIARDIZE_10773583765831320043: VariantsMap = [
    &["galliardize"],
    &["galliardise"],
    &["galliardize"],
    &["galliardise"],
];

pub(crate) static ENTRY_GALLICIZATIONS_12711889075161842819: VariantsMap = [
    &["gallicizations"],
    &["gallicisations"],
    &["gallicizations"],
    &["gallicisations"],
];

pub(crate) static ENTRY_GALLICIZATION_7390977763303794298: VariantsMap = [
    &["gallicization"],
    &["gallicisation"],
    &["gallicization"],
    &["gallicisation"],
];

pub(crate) static ENTRY_GALLICIZED_2318131892486296201: VariantsMap = [
    &["gallicized"],
    &["gallicised"],
    &["gallicized"],
    &["gallicised"],
];

pub(crate) static ENTRY_GALLICIZER_6758989856264558701: VariantsMap = [
    &["gallicizer"],
    &["galliciser"],
    &["gallicizer"],
    &["galliciser"],
];

pub(crate) static ENTRY_GALLICIZES_10712473299204337290: VariantsMap = [
    &["gallicizes"],
    &["gallicises"],
    &["gallicizes"],
    &["gallicises"],
];

pub(crate) static ENTRY_GALLICIZE_5782054308440267768: VariantsMap = [
    &["gallicize"],
    &["gallicise"],
    &["gallicize"],
    &["gallicise"],
];

pub(crate) static ENTRY_GALLICIZING_8856226220615441726: VariantsMap = [
    &["gallicizing"],
    &["gallicising"],
    &["gallicizing"],
    &["gallicising"],
];

pub(crate) static ENTRY_GALLISIZED_16338847595067555930: VariantsMap = [
    &["gallisized"],
    &["gallisised"],
    &["gallisized"],
    &["gallisised"],
];

pub(crate) static ENTRY_GALLISIZES_10805104078374630074: VariantsMap = [
    &["gallisizes"],
    &["gallisises"],
    &["gallisizes"],
    &["gallisises"],
];

pub(crate) static ENTRY_GALLISIZE_7892805864302635869: VariantsMap = [
    &["gallisize"],
    &["gallisise"],
    &["gallisize"],
    &["gallisise"],
];

pub(crate) static ENTRY_GALLISIZING_11425765967668875369: VariantsMap = [
    &["gallisizing"],
    &["gallisising"],
    &["gallisizing"],
    &["gallisising"],
];

pub(crate) static ENTRY_GALLIZED_7598224524799520474: VariantsMap =
    [&["gallized"], &["gallised"], &["gallized"], &["gallised"]];

pub(crate) static ENTRY_GALLIZES_5299390371661987813: VariantsMap =
    [&["gallizes"], &["gallises"], &["gallizes"], &["gallises"]];

pub(crate) static ENTRY_GALLIZE_13402144085043483688: VariantsMap =
    [&["gallize"], &["gallise"], &["gallize"], &["gallise"]];

pub(crate) static ENTRY_GALLIZING_18199311276947490914: VariantsMap = [
    &["gallizing"],
    &["gallising"],
    &["gallizing"],
    &["gallising"],
];

pub(crate) static ENTRY_GALVANIZATIONS_16208569109815481187: VariantsMap = [
    &["galvanizations"],
    &["galvanisations"],
    &["galvanizations"],
    &["galvanisations"],
];

pub(crate) static ENTRY_GALVANIZATION_5356855464894954705: VariantsMap = [
    &["galvanization"],
    &["galvanisation"],
    &["galvanization"],
    &["galvanisation"],
];

pub(crate) static ENTRY_GALVANIZED_7283862664171222860: VariantsMap = [
    &["galvanized"],
    &["galvanised"],
    &["galvanized"],
    &["galvanised"],
];

pub(crate) static ENTRY_GALVANIZERS_9514387945647000415: VariantsMap = [
    &["galvanizers"],
    &["galvanisers"],
    &["galvanizers"],
    &["galvanisers"],
];

pub(crate) static ENTRY_GALVANIZER_1389412242269095024: VariantsMap = [
    &["galvanizer"],
    &["galvaniser"],
    &["galvanizer"],
    &["galvaniser"],
];

pub(crate) static ENTRY_GALVANIZES_1489880893900166762: VariantsMap = [
    &["galvanizes"],
    &["galvanises"],
    &["galvanizes"],
    &["galvanises"],
];

pub(crate) static ENTRY_GALVANIZE_19760109166282156: VariantsMap = [
    &["galvanize"],
    &["galvanise"],
    &["galvanize"],
    &["galvanise"],
];

pub(crate) static ENTRY_GALVANIZING_12147310365523234397: VariantsMap = [
    &["galvanizing"],
    &["galvanising"],
    &["galvanizing"],
    &["galvanising"],
];

pub(crate) static ENTRY_GAMBADES_5475546338206383518: VariantsMap = [
    &["gambades"],
    &["gambadoes"],
    &["gambadoes"],
    &["gambadoes"],
];

pub(crate) static ENTRY_GAMBOLED_11853362628222994576: VariantsMap = [
    &["gamboled"],
    &["gambolled"],
    &["gambolled"],
    &["gambolled"],
];

pub(crate) static ENTRY_GAMBOLING_10784908367530707096: VariantsMap = [
    &["gamboling"],
    &["gambolling"],
    &["gambolling"],
    &["gambolling"],
];

pub(crate) static ENTRY_GARGARIZED_7909042564689432197: VariantsMap = [
    &["gargarized"],
    &["gargarised"],
    &["gargarized"],
    &["gargarised"],
];

pub(crate) static ENTRY_GARGARIZES_1914026990505406207: VariantsMap = [
    &["gargarizes"],
    &["gargarises"],
    &["gargarizes"],
    &["gargarises"],
];

pub(crate) static ENTRY_GARGARIZE_17950177829492366541: VariantsMap = [
    &["gargarize"],
    &["gargarise"],
    &["gargarize"],
    &["gargarise"],
];

pub(crate) static ENTRY_GARGARIZING_2729312478798944101: VariantsMap = [
    &["gargarizing"],
    &["gargarising"],
    &["gargarizing"],
    &["gargarising"],
];

pub(crate) static ENTRY_GARRULINE_2763058909710775755: VariantsMap = [
    &["garruline"],
    &["garrulinae"],
    &["garrulinae"],
    &["garrulinae"],
];

pub(crate) static ENTRY_GASES_7393603411853163261: VariantsMap =
    [&["gases"], &["gases"], &["gases"], &["gases"]];

pub(crate) static ENTRY_GASOLINES_15626523562905232226: VariantsMap = [
    &["gasolines"],
    &["gasolines"],
    &["gasolines"],
    &["gasolines"],
];

pub(crate) static ENTRY_GASOLINE_9743796479901328135: VariantsMap =
    [&["gasoline"], &["gasoline"], &["gasoline"], &["gasoline"]];

pub(crate) static ENTRY_GASTREAS_1400735590131613456: VariantsMap = [
    &["gastreas"],
    &["gastraeas"],
    &["gastraeas"],
    &["gastraeas"],
];

pub(crate) static ENTRY_GASTREA_17996449355628413865: VariantsMap =
    [&["gastrea"], &["gastraea"], &["gastraea"], &["gastraea"]];

pub(crate) static ENTRY_GASTROCELE_17796500068789968080: VariantsMap = [
    &["gastrocele"],
    &["gastrocoele"],
    &["gastrocoele"],
    &["gastrocoele"],
];

pub(crate) static ENTRY_GAUFERS_8535552125608729352: VariantsMap =
    [&["gaufers"], &["gaufres"], &["gaufres"], &["gaufres"]];

pub(crate) static ENTRY_GAUFER_8821271674575489008: VariantsMap =
    [&["gaufer"], &["gaufre"], &["gaufre"], &["gaufre"]];

pub(crate) static ENTRY_GAUFFER_971344940707830760: VariantsMap =
    [&["gauffer"], &["gauffre"], &["gauffre"], &["gauffre"]];

pub(crate) static ENTRY_GAVELED_9330937849179337117: VariantsMap =
    [&["gaveled"], &["gavelled"], &["gavelled"], &["gavelled"]];

pub(crate) static ENTRY_GAVELER_7497808590664149917: VariantsMap =
    [&["gaveler"], &["gaveller"], &["gaveller"], &["gaveller"]];

pub(crate) static ENTRY_GAVELING_8183429774339518895: VariantsMap = [
    &["gaveling"],
    &["gavelling"],
    &["gavelling"],
    &["gavelling"],
];

pub(crate) static ENTRY_GED_14965506371479666929: VariantsMap =
    [&["ged"], &["gaed"], &["gaed"], &["gaed"]];

pub(crate) static ENTRY_GELATINIZABILITIES_748271501802959782: VariantsMap = [
    &["gelatinizabilities"],
    &["gelatinisabilities"],
    &["gelatinizabilities"],
    &["gelatinisabilities"],
];

pub(crate) static ENTRY_GELATINIZABILITY_11867008106433996321: VariantsMap = [
    &["gelatinizability"],
    &["gelatinisability"],
    &["gelatinizability"],
    &["gelatinisability"],
];

pub(crate) static ENTRY_GELATINIZABLES_8035198156456837735: VariantsMap = [
    &["gelatinizables"],
    &["gelatinisables"],
    &["gelatinizables"],
    &["gelatinisables"],
];

pub(crate) static ENTRY_GELATINIZABLE_6328870207727669555: VariantsMap = [
    &["gelatinizable"],
    &["gelatinisable"],
    &["gelatinizable"],
    &["gelatinisable"],
];

pub(crate) static ENTRY_GELATINIZATIONS_16405129470904980935: VariantsMap = [
    &["gelatinizations"],
    &["gelatinisations"],
    &["gelatinizations"],
    &["gelatinisations"],
];

pub(crate) static ENTRY_GELATINIZATION_10324652004562240168: VariantsMap = [
    &["gelatinization"],
    &["gelatinisation"],
    &["gelatinization"],
    &["gelatinisation"],
];

pub(crate) static ENTRY_GELATINIZED_15612523973238289644: VariantsMap = [
    &["gelatinized"],
    &["gelatinised"],
    &["gelatinized"],
    &["gelatinised"],
];

pub(crate) static ENTRY_GELATINIZERS_376307577145206460: VariantsMap = [
    &["gelatinizers"],
    &["gelatinisers"],
    &["gelatinizers"],
    &["gelatinisers"],
];

pub(crate) static ENTRY_GELATINIZER_16640437269227566274: VariantsMap = [
    &["gelatinizer"],
    &["gelatiniser"],
    &["gelatinizer"],
    &["gelatiniser"],
];

pub(crate) static ENTRY_GELATINIZES_1595883472582938174: VariantsMap = [
    &["gelatinizes"],
    &["gelatinises"],
    &["gelatinizes"],
    &["gelatinises"],
];

pub(crate) static ENTRY_GELATINIZE_14320678590118078567: VariantsMap = [
    &["gelatinize"],
    &["gelatinise"],
    &["gelatinize"],
    &["gelatinise"],
];

pub(crate) static ENTRY_GELATINIZING_11893129576765756087: VariantsMap = [
    &["gelatinizing"],
    &["gelatinising"],
    &["gelatinizing"],
    &["gelatinising"],
];

pub(crate) static ENTRY_GELOFER_13059100954606393660: VariantsMap =
    [&["gelofer"], &["gelofre"], &["gelofre"], &["gelofre"]];

pub(crate) static ENTRY_GEMOLOGIES_213255465904446050: VariantsMap = [
    &["gemologies"],
    &["gemmologies"],
    &["gemologies"],
    &["gemmologies"],
];

pub(crate) static ENTRY_GEMOLOGY_1138665796390032600: VariantsMap =
    [&["gemology"], &["gemmology"], &["gemology"], &["gemmology"]];

pub(crate) static ENTRY_GENEALOGIZED_15135168981468576631: VariantsMap = [
    &["genealogized"],
    &["genealogised"],
    &["genealogized"],
    &["genealogised"],
];

pub(crate) static ENTRY_GENEALOGIZES_5856649031077446545: VariantsMap = [
    &["genealogizes"],
    &["genealogises"],
    &["genealogizes"],
    &["genealogises"],
];

pub(crate) static ENTRY_GENEALOGIZE_17112730041204882193: VariantsMap = [
    &["genealogize"],
    &["genealogise"],
    &["genealogize"],
    &["genealogise"],
];

pub(crate) static ENTRY_GENEALOGIZING_11925321824699543417: VariantsMap = [
    &["genealogizing"],
    &["genealogising"],
    &["genealogizing"],
    &["genealogising"],
];

pub(crate) static ENTRY_GENERALIZABILITY_9240080688246772673: VariantsMap = [
    &["generalizability"],
    &["generalisability"],
    &["generalizability"],
    &["generalisability"],
];

pub(crate) static ENTRY_GENERALIZABLER_8571039159263369925: VariantsMap = [
    &["generalizabler"],
    &["generalisabler"],
    &["generalizabler"],
    &["generalisabler"],
];

pub(crate) static ENTRY_GENERALIZABLEST_1782032942011166169: VariantsMap = [
    &["generalizablest"],
    &["generalisablest"],
    &["generalizablest"],
    &["generalisablest"],
];

pub(crate) static ENTRY_GENERALIZABLES_5230645008689603385: VariantsMap = [
    &["generalizables"],
    &["generalisables"],
    &["generalizables"],
    &["generalisables"],
];

pub(crate) static ENTRY_GENERALIZABLE_3955655563914794831: VariantsMap = [
    &["generalizable"],
    &["generalisable"],
    &["generalizable"],
    &["generalisable"],
];

pub(crate) static ENTRY_GENERALIZATIONAL_14098063634295023057: VariantsMap = [
    &["generalizational"],
    &["generalisational"],
    &["generalizational"],
    &["generalisational"],
];

pub(crate) static ENTRY_GENERALIZATIONS_1697442498275043901: VariantsMap = [
    &["generalizations"],
    &["generalisations"],
    &["generalizations"],
    &["generalisations"],
];

pub(crate) static ENTRY_GENERALIZATION_8859013031721640663: VariantsMap = [
    &["generalization"],
    &["generalisation"],
    &["generalization"],
    &["generalisation"],
];

pub(crate) static ENTRY_GENERALIZED_10792630556248421768: VariantsMap = [
    &["generalized"],
    &["generalised"],
    &["generalized"],
    &["generalised"],
];

pub(crate) static ENTRY_GENERALIZERS_2408957385743792554: VariantsMap = [
    &["generalizers"],
    &["generalisers"],
    &["generalizers"],
    &["generalisers"],
];

pub(crate) static ENTRY_GENERALIZER_4079171119694564254: VariantsMap = [
    &["generalizer"],
    &["generaliser"],
    &["generalizer"],
    &["generaliser"],
];

pub(crate) static ENTRY_GENERALIZES_3420734890670492638: VariantsMap = [
    &["generalizes"],
    &["generalises"],
    &["generalizes"],
    &["generalises"],
];

pub(crate) static ENTRY_GENERALIZE_13655318696543936715: VariantsMap = [
    &["generalize"],
    &["generalise"],
    &["generalize"],
    &["generalise"],
];

pub(crate) static ENTRY_GENERALIZING_14156289456455119636: VariantsMap = [
    &["generalizing"],
    &["generalising"],
    &["generalizing"],
    &["generalising"],
];

pub(crate) static ENTRY_GENIALIZED_324742209355172939: VariantsMap = [
    &["genialized"],
    &["genialised"],
    &["genialized"],
    &["genialised"],
];

pub(crate) static ENTRY_GENIALIZES_12942921211709985866: VariantsMap = [
    &["genializes"],
    &["genialises"],
    &["genializes"],
    &["genialises"],
];

pub(crate) static ENTRY_GENIALIZE_17059263283369696837: VariantsMap = [
    &["genialize"],
    &["genialise"],
    &["genialize"],
    &["genialise"],
];

pub(crate) static ENTRY_GENIALIZING_7362104883847556545: VariantsMap = [
    &["genializing"],
    &["genialising"],
    &["genializing"],
    &["genialising"],
];

pub(crate) static ENTRY_GENTEELIZED_5594609915067062644: VariantsMap = [
    &["genteelized"],
    &["genteelised"],
    &["genteelized"],
    &["genteelised"],
];

pub(crate) static ENTRY_GENTEELIZES_5600744917352856646: VariantsMap = [
    &["genteelizes"],
    &["genteelises"],
    &["genteelizes"],
    &["genteelises"],
];

pub(crate) static ENTRY_GENTEELIZE_14522302934582101081: VariantsMap = [
    &["genteelize"],
    &["genteelise"],
    &["genteelize"],
    &["genteelise"],
];

pub(crate) static ENTRY_GENTEELIZING_2357828715581131859: VariantsMap = [
    &["genteelizing"],
    &["genteelising"],
    &["genteelizing"],
    &["genteelising"],
];

pub(crate) static ENTRY_GENTILIZATIONS_13953898362386713218: VariantsMap = [
    &["gentilizations"],
    &["gentilisations"],
    &["gentilizations"],
    &["gentilisations"],
];

pub(crate) static ENTRY_GENTILIZATION_3445514503508341831: VariantsMap = [
    &["gentilization"],
    &["gentilisation"],
    &["gentilization"],
    &["gentilisation"],
];

pub(crate) static ENTRY_GENTILIZED_1215745904639546573: VariantsMap = [
    &["gentilized"],
    &["gentilised"],
    &["gentilized"],
    &["gentilised"],
];

pub(crate) static ENTRY_GENTILIZES_15090273186836336681: VariantsMap = [
    &["gentilizes"],
    &["gentilises"],
    &["gentilizes"],
    &["gentilises"],
];

pub(crate) static ENTRY_GENTILIZE_10418158534488896119: VariantsMap = [
    &["gentilize"],
    &["gentilise"],
    &["gentilize"],
    &["gentilise"],
];

pub(crate) static ENTRY_GENTILIZING_12868465986545165261: VariantsMap = [
    &["gentilizing"],
    &["gentilising"],
    &["gentilizing"],
    &["gentilising"],
];

pub(crate) static ENTRY_GENTLEMANIZES_387005180021803735: VariantsMap = [
    &["gentlemanizes"],
    &["gentlemanises"],
    &["gentlemanizes"],
    &["gentlemanises"],
];

pub(crate) static ENTRY_GENTLEMANIZE_15496358844070377790: VariantsMap = [
    &["gentlemanize"],
    &["gentlemanise"],
    &["gentlemanize"],
    &["gentlemanise"],
];

pub(crate) static ENTRY_GEODESIA_7909094250144256129: VariantsMap = [
    &["geodesia"],
    &["geodaesia"],
    &["geodaesia"],
    &["geodaesia"],
];

pub(crate) static ENTRY_GEOLOGIZED_7625975766262838426: VariantsMap = [
    &["geologized"],
    &["geologised"],
    &["geologized"],
    &["geologised"],
];

pub(crate) static ENTRY_GEOLOGIZES_9944756831526943986: VariantsMap = [
    &["geologizes"],
    &["geologises"],
    &["geologizes"],
    &["geologises"],
];

pub(crate) static ENTRY_GEOLOGIZE_1348394399033582028: VariantsMap = [
    &["geologize"],
    &["geologise"],
    &["geologize"],
    &["geologise"],
];

pub(crate) static ENTRY_GEOLOGIZING_1596141849146660093: VariantsMap = [
    &["geologizing"],
    &["geologising"],
    &["geologizing"],
    &["geologising"],
];

pub(crate) static ENTRY_GEOMETRICIZES_10361400394464768294: VariantsMap = [
    &["geometricizes"],
    &["geometricises"],
    &["geometricizes"],
    &["geometricises"],
];

pub(crate) static ENTRY_GEOMETRICIZE_13223434468003425706: VariantsMap = [
    &["geometricize"],
    &["geometricise"],
    &["geometricize"],
    &["geometricise"],
];

pub(crate) static ENTRY_GEOMETRIZATIONS_5268337436538042853: VariantsMap = [
    &["geometrizations"],
    &["geometrisations"],
    &["geometrizations"],
    &["geometrisations"],
];

pub(crate) static ENTRY_GEOMETRIZATION_1547434209754062568: VariantsMap = [
    &["geometrization"],
    &["geometrisation"],
    &["geometrization"],
    &["geometrisation"],
];

pub(crate) static ENTRY_GEOMETRIZED_2308132544249842146: VariantsMap = [
    &["geometrized"],
    &["geometrised"],
    &["geometrized"],
    &["geometrised"],
];

pub(crate) static ENTRY_GEOMETRIZES_1053479766754519420: VariantsMap = [
    &["geometrizes"],
    &["geometrises"],
    &["geometrizes"],
    &["geometrises"],
];

pub(crate) static ENTRY_GEOMETRIZE_16268499732063085651: VariantsMap = [
    &["geometrize"],
    &["geometrise"],
    &["geometrize"],
    &["geometrise"],
];

pub(crate) static ENTRY_GEOMETRIZING_16924051865978425252: VariantsMap = [
    &["geometrizing"],
    &["geometrising"],
    &["geometrizing"],
    &["geometrising"],
];

pub(crate) static ENTRY_GERENUK_11123017430709792003: VariantsMap =
    [&["gerenuk"], &["greenuk"], &["greenuk"], &["greenuk"]];

pub(crate) static ENTRY_GERMANIZATIONS_10792953229272520133: VariantsMap = [
    &["germanizations"],
    &["germanisations"],
    &["germanizations"],
    &["germanisations"],
];

pub(crate) static ENTRY_GERMANIZATION_13476131946585281058: VariantsMap = [
    &["germanization"],
    &["germanisation"],
    &["germanization"],
    &["germanisation"],
];

pub(crate) static ENTRY_GERMANIZED_17675668489240602495: VariantsMap = [
    &["germanized"],
    &["germanised"],
    &["germanized"],
    &["germanised"],
];

pub(crate) static ENTRY_GERMANIZERS_4983145568179588365: VariantsMap = [
    &["germanizers"],
    &["germanisers"],
    &["germanizers"],
    &["germanisers"],
];

pub(crate) static ENTRY_GERMANIZER_1963166703182074320: VariantsMap = [
    &["germanizer"],
    &["germaniser"],
    &["germanizer"],
    &["germaniser"],
];

pub(crate) static ENTRY_GERMANIZES_1350487394674561657: VariantsMap = [
    &["germanizes"],
    &["germanises"],
    &["germanizes"],
    &["germanises"],
];

pub(crate) static ENTRY_GERMANIZE_7257619738631033318: VariantsMap = [
    &["germanize"],
    &["germanise"],
    &["germanize"],
    &["germanise"],
];

pub(crate) static ENTRY_GERMANIZING_10332352803362198758: VariantsMap = [
    &["germanizing"],
    &["germanising"],
    &["germanizing"],
    &["germanising"],
];

pub(crate) static ENTRY_GERNE_10723705562317631976: VariantsMap =
    [&["gerne"], &["grene"], &["grene"], &["grene"]];

pub(crate) static ENTRY_GERS_2810213260239783007: VariantsMap =
    [&["gers"], &["gres"], &["gres"], &["gres"]];

pub(crate) static ENTRY_GER_10029915357597982133: VariantsMap =
    [&["ger"], &["gre"], &["gre"], &["gre"]];

pub(crate) static ENTRY_GESSED_3943057156251643468: VariantsMap =
    [&["gessed"], &["gessoed"], &["gessoed"], &["gessoed"]];

pub(crate) static ENTRY_GESSES_9447403161510644444: VariantsMap =
    [&["gesses"], &["gessoes"], &["gessoes"], &["gessoes"]];

pub(crate) static ENTRY_GESTE_7096843185027205462: VariantsMap =
    [&["geste"], &["gestae"], &["gestae"], &["gestae"]];

pub(crate) static ENTRY_GES_7892709255819401837: VariantsMap =
    [&["ges"], &["goes"], &["goes"], &["goes"]];

pub(crate) static ENTRY_GETAE_1718634175022590867: VariantsMap =
    [&["getae"], &["goetae"], &["goetae"], &["goetae"]];

pub(crate) static ENTRY_GETZVILLE_17657251283898385513: VariantsMap = [
    &["getzville"],
    &["goetzville"],
    &["goetzville"],
    &["goetzville"],
];

pub(crate) static ENTRY_GETZ_669206341459593812: VariantsMap =
    [&["getz"], &["goetz"], &["goetz"], &["goetz"]];

pub(crate) static ENTRY_GEY_16134682750611747069: VariantsMap =
    [&["gey"], &["goey"], &["goey"], &["goey"]];

pub(crate) static ENTRY_GE_12788931716494377180: VariantsMap =
    [&["ge"], &["gae"], &["gae"], &["gae"]];

pub(crate) static ENTRY_GE_2544027066948517700: VariantsMap =
    [&["ge"], &["goe"], &["goe"], &["goe"]];

pub(crate) static ENTRY_GHEBERS_8157544588744048409: VariantsMap =
    [&["ghebers"], &["ghebres"], &["ghebres"], &["ghebres"]];

pub(crate) static ENTRY_GHEBER_4914782193870428634: VariantsMap =
    [&["gheber"], &["ghebre"], &["ghebre"], &["ghebre"]];

pub(crate) static ENTRY_GHETTOIZATIONS_4010150485854957474: VariantsMap = [
    &["ghettoizations"],
    &["ghettoisations"],
    &["ghettoizations"],
    &["ghettoisations"],
];

pub(crate) static ENTRY_GHETTOIZATION_6096956430126090676: VariantsMap = [
    &["ghettoization"],
    &["ghettoisation"],
    &["ghettoization"],
    &["ghettoisation"],
];

pub(crate) static ENTRY_GHETTOIZED_6310643312381201018: VariantsMap = [
    &["ghettoized"],
    &["ghettoised"],
    &["ghettoized"],
    &["ghettoised"],
];

pub(crate) static ENTRY_GHETTOIZES_13127566176097583611: VariantsMap = [
    &["ghettoizes"],
    &["ghettoises"],
    &["ghettoizes"],
    &["ghettoises"],
];

pub(crate) static ENTRY_GHETTOIZE_8424380127281823491: VariantsMap = [
    &["ghettoize"],
    &["ghettoise"],
    &["ghettoize"],
    &["ghettoise"],
];

pub(crate) static ENTRY_GHETTOIZING_12012772692961443803: VariantsMap = [
    &["ghettoizing"],
    &["ghettoising"],
    &["ghettoizing"],
    &["ghettoising"],
];

pub(crate) static ENTRY_GIANTIZES_12359859620616821617: VariantsMap = [
    &["giantizes"],
    &["giantises"],
    &["giantizes"],
    &["giantises"],
];

pub(crate) static ENTRY_GIANTIZE_9114588567776629038: VariantsMap =
    [&["giantize"], &["giantise"], &["giantize"], &["giantise"]];

pub(crate) static ENTRY_GIMBALED_13438863350515119161: VariantsMap = [
    &["gimbaled"],
    &["gimballed"],
    &["gimballed"],
    &["gimballed"],
];

pub(crate) static ENTRY_GIMBALING_17481044329427103960: VariantsMap = [
    &["gimbaling"],
    &["gimballing"],
    &["gimballing"],
    &["gimballing"],
];

pub(crate) static ENTRY_GLACIALIZES_1227166762771762813: VariantsMap = [
    &["glacializes"],
    &["glacialises"],
    &["glacializes"],
    &["glacialises"],
];

pub(crate) static ENTRY_GLACIALIZE_702243778246280222: VariantsMap = [
    &["glacialize"],
    &["glacialise"],
    &["glacialize"],
    &["glacialise"],
];

pub(crate) static ENTRY_GLAMORIZATIONS_13386360280962328056: VariantsMap = [
    &["glamorizations"],
    &["glamorisations"],
    &["glamorizations"],
    &["glamorisations"],
];

pub(crate) static ENTRY_GLAMORIZATION_17627840945549800707: VariantsMap = [
    &["glamorization"],
    &["glamorisation"],
    &["glamorization"],
    &["glamorisation"],
];

pub(crate) static ENTRY_GLAMORIZED_7629491500086174456: VariantsMap = [
    &["glamorized"],
    &["glamorised"],
    &["glamorized"],
    &["glamorised"],
];

pub(crate) static ENTRY_GLAMORIZERS_4548388194452180185: VariantsMap = [
    &["glamorizers"],
    &["glamorisers"],
    &["glamorizers"],
    &["glamorisers"],
];

pub(crate) static ENTRY_GLAMORIZER_1273764306977330242: VariantsMap = [
    &["glamorizer"],
    &["glamoriser"],
    &["glamorizer"],
    &["glamoriser"],
];

pub(crate) static ENTRY_GLAMORIZES_13581885236350696198: VariantsMap = [
    &["glamorizes"],
    &["glamorises"],
    &["glamorizes"],
    &["glamorises"],
];

pub(crate) static ENTRY_GLAMORIZE_15623953511855635687: VariantsMap = [
    &["glamorize"],
    &["glamorise"],
    &["glamorize"],
    &["glamorise"],
];

pub(crate) static ENTRY_GLAMORIZING_13126163444695612437: VariantsMap = [
    &["glamorizing"],
    &["glamorising"],
    &["glamorizing"],
    &["glamorising"],
];

pub(crate) static ENTRY_GLAMORLESS_3213378030533857078: VariantsMap = [
    &["glamorless"],
    &["glamourless"],
    &["glamourless"],
    &["glamourless"],
];

pub(crate) static ENTRY_GLAMOROUSNESS_2689045081256261571: VariantsMap = [
    &["glamorousness"],
    &["glamorousness"],
    &["glamorousness"],
    &["glamorousness"],
];

pub(crate) static ENTRY_GLAMOROUS_12197747715827471126: VariantsMap = [
    &["glamorous"],
    &["glamorous"],
    &["glamorous"],
    &["glamorous"],
];

pub(crate) static ENTRY_GLAMOURED_11154619017989846487: VariantsMap = [
    &["glamoured"],
    &["glamoured"],
    &["glamoured"],
    &["glamoured"],
];

pub(crate) static ENTRY_GLAMOURING_6375193716164556692: VariantsMap = [
    &["glamouring"],
    &["glamouring"],
    &["glamouring"],
    &["glamouring"],
];

pub(crate) static ENTRY_GLAMOURS_12982136149572203520: VariantsMap =
    [&["glamours"], &["glamours"], &["glamours"], &["glamours"]];

pub(crate) static ENTRY_GLAMOUR_660428055727744225: VariantsMap =
    [&["glamour"], &["glamour"], &["glamour"], &["glamour"]];

pub(crate) static ENTRY_GLAUCONITIZATIONS_735392238221192579: VariantsMap = [
    &["glauconitizations"],
    &["glauconitisations"],
    &["glauconitizations"],
    &["glauconitisations"],
];

pub(crate) static ENTRY_GLAUCONITIZATION_7362785196117563859: VariantsMap = [
    &["glauconitization"],
    &["glauconitisation"],
    &["glauconitization"],
    &["glauconitisation"],
];

pub(crate) static ENTRY_GLEBE_8123454513306882083: VariantsMap =
    [&["glebe"], &["glebae"], &["glebae"], &["glebae"]];

pub(crate) static ENTRY_GLOBALIZATIONS_17494053183467714670: VariantsMap = [
    &["globalizations"],
    &["globalisations"],
    &["globalizations"],
    &["globalisations"],
];

pub(crate) static ENTRY_GLOBALIZATION_7581407957860146976: VariantsMap = [
    &["globalization"],
    &["globalisation"],
    &["globalization"],
    &["globalisation"],
];

pub(crate) static ENTRY_GLOBALIZED_11948697689508441693: VariantsMap = [
    &["globalized"],
    &["globalised"],
    &["globalized"],
    &["globalised"],
];

pub(crate) static ENTRY_GLOBALIZES_1812285942441846479: VariantsMap = [
    &["globalizes"],
    &["globalises"],
    &["globalizes"],
    &["globalises"],
];

pub(crate) static ENTRY_GLOBALIZE_11826473684785302147: VariantsMap = [
    &["globalize"],
    &["globalise"],
    &["globalize"],
    &["globalise"],
];

pub(crate) static ENTRY_GLOBALIZING_12872973526407105523: VariantsMap = [
    &["globalizing"],
    &["globalising"],
    &["globalizing"],
    &["globalising"],
];

pub(crate) static ENTRY_GLOBIGERINE_8558263536879852579: VariantsMap = [
    &["globigerine"],
    &["globigerinae"],
    &["globigerinae"],
    &["globigerinae"],
];

pub(crate) static ENTRY_GLOTTALIZATION_8617780925137236905: VariantsMap = [
    &["glottalization"],
    &["glottalisation"],
    &["glottalization"],
    &["glottalisation"],
];

pub(crate) static ENTRY_GLOTTALIZES_1521812381984608242: VariantsMap = [
    &["glottalizes"],
    &["glottalises"],
    &["glottalizes"],
    &["glottalises"],
];

pub(crate) static ENTRY_GLOTTALIZE_11936017486575639215: VariantsMap = [
    &["glottalize"],
    &["glottalise"],
    &["glottalize"],
    &["glottalise"],
];

pub(crate) static ENTRY_GLUCEMIA_16714227962549234650: VariantsMap = [
    &["glucemia"],
    &["glucaemia"],
    &["glucaemia"],
    &["glucaemia"],
];

pub(crate) static ENTRY_GLUCOSEMIA_10620016314334807991: VariantsMap = [
    &["glucosemia"],
    &["glucosaemia"],
    &["glucosaemia"],
    &["glucosaemia"],
];

pub(crate) static ENTRY_GLUTEAL_13945486219027643389: VariantsMap =
    [&["gluteal"], &["gluteal"], &["gluteal"], &["gluteal"]];

pub(crate) static ENTRY_GLUTEI_16791170565919408237: VariantsMap =
    [&["glutei"], &["glutaei"], &["glutaei"], &["glutaei"]];

pub(crate) static ENTRY_GLUTEUS_1051154314043721205: VariantsMap =
    [&["gluteus"], &["glutaeus"], &["glutaeus"], &["glutaeus"]];

pub(crate) static ENTRY_GLUTTONIZED_4146378212700912723: VariantsMap = [
    &["gluttonized"],
    &["gluttonised"],
    &["gluttonized"],
    &["gluttonised"],
];

pub(crate) static ENTRY_GLUTTONIZES_15763514001401508118: VariantsMap = [
    &["gluttonizes"],
    &["gluttonises"],
    &["gluttonizes"],
    &["gluttonises"],
];

pub(crate) static ENTRY_GLUTTONIZE_10450449431254721690: VariantsMap = [
    &["gluttonize"],
    &["gluttonise"],
    &["gluttonize"],
    &["gluttonise"],
];

pub(crate) static ENTRY_GLUTTONIZING_4580260495228977044: VariantsMap = [
    &["gluttonizing"],
    &["gluttonising"],
    &["gluttonizing"],
    &["gluttonising"],
];

pub(crate) static ENTRY_GLYCEMIA_11995000715174302478: VariantsMap = [
    &["glycemia"],
    &["glycaemia"],
    &["glycaemia"],
    &["glycaemia"],
];

pub(crate) static ENTRY_GLYCEMIC_11032815698109543693: VariantsMap = [
    &["glycemic"],
    &["glycaemic"],
    &["glycaemic"],
    &["glycaemic"],
];

pub(crate) static ENTRY_GLYCERINIZES_17601869911441127120: VariantsMap = [
    &["glycerinizes"],
    &["glycerinises"],
    &["glycerinizes"],
    &["glycerinises"],
];

pub(crate) static ENTRY_GLYCERINIZE_15525365444232192960: VariantsMap = [
    &["glycerinize"],
    &["glycerinise"],
    &["glycerinize"],
    &["glycerinise"],
];

pub(crate) static ENTRY_GLYCERINS_12602551092241423563: VariantsMap = [
    &["glycerins"],
    &["glycerines"],
    &["glycerines"],
    &["glycerines"],
];

pub(crate) static ENTRY_GLYCERIN_13570623165649901397: VariantsMap = [
    &["glycerin"],
    &["glycerine"],
    &["glycerine"],
    &["glycerine"],
];

pub(crate) static ENTRY_GLYCEROLIZED_835284803246529776: VariantsMap = [
    &["glycerolized"],
    &["glycerolised"],
    &["glycerolized"],
    &["glycerolised"],
];

pub(crate) static ENTRY_GLYCEROLIZES_16560265368755341391: VariantsMap = [
    &["glycerolizes"],
    &["glycerolises"],
    &["glycerolizes"],
    &["glycerolises"],
];

pub(crate) static ENTRY_GLYCEROLIZE_14402503186408445056: VariantsMap = [
    &["glycerolize"],
    &["glycerolise"],
    &["glycerolize"],
    &["glycerolise"],
];

pub(crate) static ENTRY_GLYCOGENIZES_8753992975266531652: VariantsMap = [
    &["glycogenizes"],
    &["glycogenises"],
    &["glycogenizes"],
    &["glycogenises"],
];

pub(crate) static ENTRY_GLYCOGENIZE_2541584719829339590: VariantsMap = [
    &["glycogenize"],
    &["glycogenise"],
    &["glycogenize"],
    &["glycogenise"],
];

pub(crate) static ENTRY_GLYCOHEMIA_5170811597574477308: VariantsMap = [
    &["glycohemia"],
    &["glycohaemia"],
    &["glycohaemia"],
    &["glycohaemia"],
];

pub(crate) static ENTRY_GLYCOSEMIA_9241245255757665402: VariantsMap = [
    &["glycosemia"],
    &["glycosaemia"],
    &["glycosaemia"],
    &["glycosaemia"],
];

pub(crate) static ENTRY_GNOSTICIZED_6607237294915929614: VariantsMap = [
    &["gnosticized"],
    &["gnosticised"],
    &["gnosticized"],
    &["gnosticised"],
];

pub(crate) static ENTRY_GNOSTICIZERS_6404772314227170997: VariantsMap = [
    &["gnosticizers"],
    &["gnosticisers"],
    &["gnosticizers"],
    &["gnosticisers"],
];

pub(crate) static ENTRY_GNOSTICIZER_12421398403440384920: VariantsMap = [
    &["gnosticizer"],
    &["gnosticiser"],
    &["gnosticizer"],
    &["gnosticiser"],
];

pub(crate) static ENTRY_GNOSTICIZES_14521008554147102135: VariantsMap = [
    &["gnosticizes"],
    &["gnosticises"],
    &["gnosticizes"],
    &["gnosticises"],
];

pub(crate) static ENTRY_GNOSTICIZE_11128074972430661057: VariantsMap = [
    &["gnosticize"],
    &["gnosticise"],
    &["gnosticize"],
    &["gnosticise"],
];

pub(crate) static ENTRY_GNOSTICIZING_16518069417018650782: VariantsMap = [
    &["gnosticizing"],
    &["gnosticising"],
    &["gnosticizing"],
    &["gnosticising"],
];

pub(crate) static ENTRY_GODDIZES_4605603392452105679: VariantsMap =
    [&["goddizes"], &["goddises"], &["goddizes"], &["goddises"]];

pub(crate) static ENTRY_GODDIZE_4286830355302335842: VariantsMap =
    [&["goddize"], &["goddise"], &["goddize"], &["goddise"]];

pub(crate) static ENTRY_GOITERS_9278089062698566328: VariantsMap =
    [&["goiters"], &["goitres"], &["goitres"], &["goitres"]];

pub(crate) static ENTRY_GOITER_17716281509178141747: VariantsMap =
    [&["goiter"], &["goitre"], &["goitre"], &["goitre"]];

pub(crate) static ENTRY_GOLE_9737246898983155612: VariantsMap =
    [&["gole"], &["goloe"], &["goloe"], &["goloe"]];

pub(crate) static ENTRY_GOLIATHIZED_12398672876213122059: VariantsMap = [
    &["goliathized"],
    &["goliathised"],
    &["goliathized"],
    &["goliathised"],
];

pub(crate) static ENTRY_GOLIATHIZES_5680945343906319918: VariantsMap = [
    &["goliathizes"],
    &["goliathises"],
    &["goliathizes"],
    &["goliathises"],
];

pub(crate) static ENTRY_GOLIATHIZE_9937408085419338264: VariantsMap = [
    &["goliathize"],
    &["goliathise"],
    &["goliathize"],
    &["goliathise"],
];

pub(crate) static ENTRY_GOLIATHIZING_4244029082966162435: VariantsMap = [
    &["goliathizing"],
    &["goliathising"],
    &["goliathizing"],
    &["goliathising"],
];

pub(crate) static ENTRY_GOLOSHES_13775493769643547174: VariantsMap = [
    &["goloshes"],
    &["goloshoes"],
    &["goloshoes"],
    &["goloshoes"],
];

pub(crate) static ENTRY_GONORRHEALER_7420289375074953561: VariantsMap = [
    &["gonorrhealer"],
    &["gonorrhoealer"],
    &["gonorrhealer"],
    &["gonorrhoealer"],
];

pub(crate) static ENTRY_GONORRHEALEST_7581818766613734397: VariantsMap = [
    &["gonorrhealest"],
    &["gonorrhoealest"],
    &["gonorrhealest"],
    &["gonorrhoealest"],
];

pub(crate) static ENTRY_GONORRHEAL_7680154103977443792: VariantsMap = [
    &["gonorrheal"],
    &["gonorrhoeal"],
    &["gonorrheal"],
    &["gonorrhoeal"],
];

pub(crate) static ENTRY_GONORRHEAS_7303597805840900864: VariantsMap = [
    &["gonorrheas"],
    &["gonorrhoeas"],
    &["gonorrheas"],
    &["gonorrhoeas"],
];

pub(crate) static ENTRY_GONORRHEA_16582247655129058477: VariantsMap = [
    &["gonorrhea"],
    &["gonorrhoea"],
    &["gonorrhea"],
    &["gonorrhoea"],
];

pub(crate) static ENTRY_GONORRHEIC_9854545577426970058: VariantsMap = [
    &["gonorrheic"],
    &["gonorrhoeic"],
    &["gonorrheic"],
    &["gonorrhoeic"],
];

pub(crate) static ENTRY_GOODBYES_1825161685740062266: VariantsMap =
    [&["goodbyes"], &["goodbyes"], &["goodbyes"], &["goodbyes"]];

pub(crate) static ENTRY_GOODBYE_14384898326063678406: VariantsMap =
    [&["goodbye"], &["goodbye"], &["goodbye"], &["goodbye"]];

pub(crate) static ENTRY_GORAMIES_15606246035840811431: VariantsMap = [
    &["goramies"],
    &["gouramies"],
    &["gouramies"],
    &["gouramies"],
];

pub(crate) static ENTRY_GORA_171264175942816577: VariantsMap =
    [&["gora"], &["goura"], &["goura"], &["goura"]];

pub(crate) static ENTRY_GORGONIZED_1752725026865323443: VariantsMap = [
    &["gorgonized"],
    &["gorgonised"],
    &["gorgonized"],
    &["gorgonised"],
];

pub(crate) static ENTRY_GORGONIZES_4219989310312833047: VariantsMap = [
    &["gorgonizes"],
    &["gorgonises"],
    &["gorgonizes"],
    &["gorgonises"],
];

pub(crate) static ENTRY_GORGONIZE_7879285325029434471: VariantsMap = [
    &["gorgonize"],
    &["gorgonise"],
    &["gorgonize"],
    &["gorgonise"],
];

pub(crate) static ENTRY_GORGONIZING_17245443610611935765: VariantsMap = [
    &["gorgonizing"],
    &["gorgonising"],
    &["gorgonizing"],
    &["gorgonising"],
];

pub(crate) static ENTRY_GORMANDISMS_2185039788447521753: VariantsMap = [
    &["gormandisms"],
    &["gourmandisms"],
    &["gourmandisms"],
    &["gourmandisms"],
];

pub(crate) static ENTRY_GORMANDISM_14784809580958247953: VariantsMap = [
    &["gormandism"],
    &["gourmandism"],
    &["gourmandism"],
    &["gourmandism"],
];

pub(crate) static ENTRY_GORMANDIZED_10731842314325530180: VariantsMap = [
    &["gormandized"],
    &["gormandised"],
    &["gormandized"],
    &["gormandised"],
];

pub(crate) static ENTRY_GORMANDIZERS_18411470761457014582: VariantsMap = [
    &["gormandizers"],
    &["gormandisers"],
    &["gormandizers"],
    &["gormandisers"],
];

pub(crate) static ENTRY_GORMANDIZER_6966761925725934534: VariantsMap = [
    &["gormandizer"],
    &["gormandiser"],
    &["gormandizer"],
    &["gormandiser"],
];

pub(crate) static ENTRY_GORMANDIZES_2590069975381378998: VariantsMap = [
    &["gormandizes"],
    &["gormandises"],
    &["gormandizes"],
    &["gormandises"],
];

pub(crate) static ENTRY_GORMANDIZE_13620361302078181878: VariantsMap = [
    &["gormandize"],
    &["gormandise"],
    &["gormandize"],
    &["gormandise"],
];

pub(crate) static ENTRY_GORMANDIZINGS_10921893709340323072: VariantsMap = [
    &["gormandizings"],
    &["gormandisings"],
    &["gormandizings"],
    &["gormandisings"],
];

pub(crate) static ENTRY_GORMANDIZING_2185616084567137: VariantsMap = [
    &["gormandizing"],
    &["gormandising"],
    &["gormandizing"],
    &["gormandising"],
];

pub(crate) static ENTRY_GOR_14093694443247898321: VariantsMap =
    [&["gor"], &["gour"], &["gour"], &["gour"]];

pub(crate) static ENTRY_GOSPELERS_15768484320655667045: VariantsMap = [
    &["gospelers"],
    &["gospellers"],
    &["gospellers"],
    &["gospellers"],
];

pub(crate) static ENTRY_GOSPELER_17427415273172338485: VariantsMap = [
    &["gospeler"],
    &["gospeller"],
    &["gospeller"],
    &["gospeller"],
];

pub(crate) static ENTRY_GOSPELIZED_8655666473040197182: VariantsMap = [
    &["gospelized"],
    &["gospelised"],
    &["gospelized"],
    &["gospelised"],
];

pub(crate) static ENTRY_GOSPELIZES_4662692098801017919: VariantsMap = [
    &["gospelizes"],
    &["gospelises"],
    &["gospelizes"],
    &["gospelises"],
];

pub(crate) static ENTRY_GOSPELIZE_17132485493253272517: VariantsMap = [
    &["gospelize"],
    &["gospelise"],
    &["gospelize"],
    &["gospelise"],
];

pub(crate) static ENTRY_GOSPELIZING_10127509527627836099: VariantsMap = [
    &["gospelizing"],
    &["gospelising"],
    &["gospelizing"],
    &["gospelising"],
];

pub(crate) static ENTRY_GOSPELLIZED_6528515629885778069: VariantsMap = [
    &["gospellized"],
    &["gospellised"],
    &["gospellized"],
    &["gospellised"],
];

pub(crate) static ENTRY_GOSPELLIZES_16267739496287009593: VariantsMap = [
    &["gospellizes"],
    &["gospellises"],
    &["gospellizes"],
    &["gospellises"],
];

pub(crate) static ENTRY_GOSPELLIZE_5327023394143893963: VariantsMap = [
    &["gospellize"],
    &["gospellise"],
    &["gospellize"],
    &["gospellise"],
];

pub(crate) static ENTRY_GOSPELLIZING_2085328678616691449: VariantsMap = [
    &["gospellizing"],
    &["gospellising"],
    &["gospellizing"],
    &["gospellising"],
];

pub(crate) static ENTRY_GOTHICIZED_7190788483793513766: VariantsMap = [
    &["gothicized"],
    &["gothicised"],
    &["gothicized"],
    &["gothicised"],
];

pub(crate) static ENTRY_GOTHICIZERS_14069671387176050924: VariantsMap = [
    &["gothicizers"],
    &["gothicisers"],
    &["gothicizers"],
    &["gothicisers"],
];

pub(crate) static ENTRY_GOTHICIZER_9662675332797265708: VariantsMap = [
    &["gothicizer"],
    &["gothiciser"],
    &["gothicizer"],
    &["gothiciser"],
];

pub(crate) static ENTRY_GOTHICIZES_16217191150519097315: VariantsMap = [
    &["gothicizes"],
    &["gothicises"],
    &["gothicizes"],
    &["gothicises"],
];

pub(crate) static ENTRY_GOTHICIZE_10579445493165443468: VariantsMap = [
    &["gothicize"],
    &["gothicise"],
    &["gothicize"],
    &["gothicise"],
];

pub(crate) static ENTRY_GOTHICIZING_955456591467188414: VariantsMap = [
    &["gothicizing"],
    &["gothicising"],
    &["gothicizing"],
    &["gothicising"],
];

pub(crate) static ENTRY_GOURMANDIZED_17217066519006720059: VariantsMap = [
    &["gourmandized"],
    &["gourmandised"],
    &["gourmandized"],
    &["gourmandised"],
];

pub(crate) static ENTRY_GOURMANDIZES_10961415197081735: VariantsMap = [
    &["gourmandizes"],
    &["gourmandises"],
    &["gourmandizes"],
    &["gourmandises"],
];

pub(crate) static ENTRY_GOURMANDIZE_9811561039675188095: VariantsMap = [
    &["gourmandize"],
    &["gourmandise"],
    &["gourmandize"],
    &["gourmandise"],
];

pub(crate) static ENTRY_GOURMANDIZING_9468056354440853097: VariantsMap = [
    &["gourmandizing"],
    &["gourmandising"],
    &["gourmandizing"],
    &["gourmandising"],
];

pub(crate) static ENTRY_GOVERNMENTALIZED_5332812387797598402: VariantsMap = [
    &["governmentalized"],
    &["governmentalised"],
    &["governmentalized"],
    &["governmentalised"],
];

pub(crate) static ENTRY_GOVERNMENTALIZES_15051032983194955811: VariantsMap = [
    &["governmentalizes"],
    &["governmentalises"],
    &["governmentalizes"],
    &["governmentalises"],
];

pub(crate) static ENTRY_GOVERNMENTALIZE_15026957532237481776: VariantsMap = [
    &["governmentalize"],
    &["governmentalise"],
    &["governmentalize"],
    &["governmentalise"],
];

pub(crate) static ENTRY_GOVERNMENTALIZING_17023477988958404775: VariantsMap = [
    &["governmentalizing"],
    &["governmentalising"],
    &["governmentalizing"],
    &["governmentalising"],
];

pub(crate) static ENTRY_GOYESQUE_6877829052939471298: VariantsMap = [
    &["goyesque"],
    &["goyaesque"],
    &["goyaesque"],
    &["goyaesque"],
];

pub(crate) static ENTRY_GRAECIZED_15484035342864386624: VariantsMap = [
    &["graecized"],
    &["graecised"],
    &["graecized"],
    &["graecised"],
];

pub(crate) static ENTRY_GRAECIZES_18067197401205415693: VariantsMap = [
    &["graecizes"],
    &["graecises"],
    &["graecizes"],
    &["graecises"],
];

pub(crate) static ENTRY_GRAECIZE_13205262082109545793: VariantsMap =
    [&["graecize"], &["graecise"], &["graecize"], &["graecise"]];

pub(crate) static ENTRY_GRAECIZING_4425395536860878106: VariantsMap = [
    &["graecizing"],
    &["graecising"],
    &["graecizing"],
    &["graecising"],
];

pub(crate) static ENTRY_GRAMMATICIZED_555586288585252490: VariantsMap = [
    &["grammaticized"],
    &["grammaticised"],
    &["grammaticized"],
    &["grammaticised"],
];

pub(crate) static ENTRY_GRAMMATICIZES_968607897093671885: VariantsMap = [
    &["grammaticizes"],
    &["grammaticises"],
    &["grammaticizes"],
    &["grammaticises"],
];

pub(crate) static ENTRY_GRAMMATICIZE_11757970532171038610: VariantsMap = [
    &["grammaticize"],
    &["grammaticise"],
    &["grammaticize"],
    &["grammaticise"],
];

pub(crate) static ENTRY_GRAMMATICIZING_11302051616654926337: VariantsMap = [
    &["grammaticizing"],
    &["grammaticising"],
    &["grammaticizing"],
    &["grammaticising"],
];

pub(crate) static ENTRY_GRAMS_8379840851265617318: VariantsMap =
    [&["grams"], &["grams"], &["grams"], &["grams"]];

pub(crate) static ENTRY_GRAM_9361867859862457841: VariantsMap =
    [&["gram"], &["gram"], &["gram"], &["gram"]];

pub(crate) static ENTRY_GRANGERIZATIONS_6041546144988435113: VariantsMap = [
    &["grangerizations"],
    &["grangerisations"],
    &["grangerizations"],
    &["grangerisations"],
];

pub(crate) static ENTRY_GRANGERIZATION_8011757954292583522: VariantsMap = [
    &["grangerization"],
    &["grangerisation"],
    &["grangerization"],
    &["grangerisation"],
];

pub(crate) static ENTRY_GRANGERIZED_11830731660884093072: VariantsMap = [
    &["grangerized"],
    &["grangerised"],
    &["grangerized"],
    &["grangerised"],
];

pub(crate) static ENTRY_GRANGERIZERS_7048768465888760391: VariantsMap = [
    &["grangerizers"],
    &["grangerisers"],
    &["grangerizers"],
    &["grangerisers"],
];

pub(crate) static ENTRY_GRANGERIZER_6895363933607390837: VariantsMap = [
    &["grangerizer"],
    &["grangeriser"],
    &["grangerizer"],
    &["grangeriser"],
];

pub(crate) static ENTRY_GRANGERIZES_13688800262712479914: VariantsMap = [
    &["grangerizes"],
    &["grangerises"],
    &["grangerizes"],
    &["grangerises"],
];

pub(crate) static ENTRY_GRANGERIZE_11685394624334929913: VariantsMap = [
    &["grangerize"],
    &["grangerise"],
    &["grangerize"],
    &["grangerise"],
];

pub(crate) static ENTRY_GRANGERIZING_12003554918644431898: VariantsMap = [
    &["grangerizing"],
    &["grangerising"],
    &["grangerizing"],
    &["grangerising"],
];

pub(crate) static ENTRY_GRANITIZATIONS_5916561325992415976: VariantsMap = [
    &["granitizations"],
    &["granitisations"],
    &["granitizations"],
    &["granitisations"],
];

pub(crate) static ENTRY_GRANITIZATION_4587984666842037739: VariantsMap = [
    &["granitization"],
    &["granitisation"],
    &["granitization"],
    &["granitisation"],
];

pub(crate) static ENTRY_GRANITIZED_9523467185555643497: VariantsMap = [
    &["granitized"],
    &["granitised"],
    &["granitized"],
    &["granitised"],
];

pub(crate) static ENTRY_GRANITIZES_5307213501352143475: VariantsMap = [
    &["granitizes"],
    &["granitises"],
    &["granitizes"],
    &["granitises"],
];

pub(crate) static ENTRY_GRANITIZE_6476105775849514242: VariantsMap = [
    &["granitize"],
    &["granitise"],
    &["granitize"],
    &["granitise"],
];

pub(crate) static ENTRY_GRANITIZING_12122977753813840228: VariantsMap = [
    &["granitizing"],
    &["granitising"],
    &["granitizing"],
    &["granitising"],
];

pub(crate) static ENTRY_GRANULITIZATIONS_1898739157771447082: VariantsMap = [
    &["granulitizations"],
    &["granulitisations"],
    &["granulitizations"],
    &["granulitisations"],
];

pub(crate) static ENTRY_GRANULITIZATION_1914830872838686250: VariantsMap = [
    &["granulitization"],
    &["granulitisation"],
    &["granulitization"],
    &["granulitisation"],
];

pub(crate) static ENTRY_GRANULIZES_14251558873025935098: VariantsMap = [
    &["granulizes"],
    &["granulises"],
    &["granulizes"],
    &["granulises"],
];

pub(crate) static ENTRY_GRANULIZE_106086847220442662: VariantsMap = [
    &["granulize"],
    &["granulise"],
    &["granulize"],
    &["granulise"],
];

pub(crate) static ENTRY_GRAPHITIZABLE_11399344742072531593: VariantsMap = [
    &["graphitizable"],
    &["graphitisable"],
    &["graphitizable"],
    &["graphitisable"],
];

pub(crate) static ENTRY_GRAPHITIZATIONS_16745769267548580130: VariantsMap = [
    &["graphitizations"],
    &["graphitisations"],
    &["graphitizations"],
    &["graphitisations"],
];

pub(crate) static ENTRY_GRAPHITIZATION_9119232042069892055: VariantsMap = [
    &["graphitization"],
    &["graphitisation"],
    &["graphitization"],
    &["graphitisation"],
];

pub(crate) static ENTRY_GRAPHITIZED_14900862347385247613: VariantsMap = [
    &["graphitized"],
    &["graphitised"],
    &["graphitized"],
    &["graphitised"],
];

pub(crate) static ENTRY_GRAPHITIZES_3949365548049490211: VariantsMap = [
    &["graphitizes"],
    &["graphitises"],
    &["graphitizes"],
    &["graphitises"],
];

pub(crate) static ENTRY_GRAPHITIZE_9940023022042490384: VariantsMap = [
    &["graphitize"],
    &["graphitise"],
    &["graphitize"],
    &["graphitise"],
];

pub(crate) static ENTRY_GRAPHITIZING_12925962006333789717: VariantsMap = [
    &["graphitizing"],
    &["graphitising"],
    &["graphitizing"],
    &["graphitising"],
];

pub(crate) static ENTRY_GRAVELED_6396856593557403791: VariantsMap = [
    &["graveled"],
    &["gravelled"],
    &["gravelled"],
    &["gravelled"],
];

pub(crate) static ENTRY_GRAVELING_11263938049794337387: VariantsMap = [
    &["graveling"],
    &["gravelling"],
    &["gravelling"],
    &["gravelling"],
];

pub(crate) static ENTRY_GRAYED_4224809419318876159: VariantsMap =
    [&["grayed"], &["greyed"], &["greyed"], &["greyed"]];

pub(crate) static ENTRY_GRAYER_13451385637628432933: VariantsMap =
    [&["grayer"], &["greyer"], &["greyer"], &["greyer"]];

pub(crate) static ENTRY_GRAYEST_8987957900625444290: VariantsMap =
    [&["grayest"], &["greyest"], &["greyest"], &["greyest"]];

pub(crate) static ENTRY_GRAYING_14737562961746036658: VariantsMap =
    [&["graying"], &["greying"], &["greying"], &["greying"]];

pub(crate) static ENTRY_GRAYISH_17428631159661807756: VariantsMap =
    [&["grayish"], &["greyish"], &["greyish"], &["greyish"]];

pub(crate) static ENTRY_GRAYNESS_3066378526993690701: VariantsMap =
    [&["grayness"], &["greyness"], &["greyness"], &["greyness"]];

pub(crate) static ENTRY_GRECIANIZES_14411759533003325711: VariantsMap = [
    &["grecianizes"],
    &["grecianises"],
    &["grecianizes"],
    &["grecianises"],
];

pub(crate) static ENTRY_GRECIANIZE_14716636147435581224: VariantsMap = [
    &["grecianize"],
    &["grecianise"],
    &["grecianize"],
    &["grecianise"],
];

pub(crate) static ENTRY_GRECIAN_417997226095522101: VariantsMap =
    [&["grecian"], &["graecian"], &["graecian"], &["graecian"]];

pub(crate) static ENTRY_GRECISED_3839763344180915513: VariantsMap = [
    &["grecised"],
    &["graecised"],
    &["graecised"],
    &["graecised"],
];

pub(crate) static ENTRY_GRECISE_14608473457893399178: VariantsMap =
    [&["grecise"], &["graecise"], &["graecise"], &["graecise"]];

pub(crate) static ENTRY_GRECISING_9235719733885081536: VariantsMap = [
    &["grecising"],
    &["graecising"],
    &["graecising"],
    &["graecising"],
];

pub(crate) static ENTRY_GRECISMS_7677508798544264651: VariantsMap = [
    &["grecisms"],
    &["graecisms"],
    &["graecisms"],
    &["graecisms"],
];

pub(crate) static ENTRY_GRECISM_16474963217213327368: VariantsMap =
    [&["grecism"], &["graecism"], &["graecism"], &["graecism"]];

pub(crate) static ENTRY_GRECIZED_16527564747404543915: VariantsMap =
    [&["grecized"], &["grecised"], &["grecized"], &["grecised"]];

pub(crate) static ENTRY_GRECIZES_7044331661038018107: VariantsMap =
    [&["grecizes"], &["grecises"], &["grecizes"], &["grecises"]];

pub(crate) static ENTRY_GRECIZE_4024125847440886583: VariantsMap =
    [&["grecize"], &["grecise"], &["grecize"], &["grecise"]];

pub(crate) static ENTRY_GRECIZING_12172207206377092378: VariantsMap = [
    &["grecizing"],
    &["grecising"],
    &["grecizing"],
    &["grecising"],
];

pub(crate) static ENTRY_GREEKIZES_3365945163605882813: VariantsMap = [
    &["greekizes"],
    &["greekises"],
    &["greekizes"],
    &["greekises"],
];

pub(crate) static ENTRY_GREEKIZE_15314566857028275164: VariantsMap =
    [&["greekize"], &["greekise"], &["greekize"], &["greekise"]];

pub(crate) static ENTRY_GREISENIZATIONS_4501697118968920476: VariantsMap = [
    &["greisenizations"],
    &["greisenisations"],
    &["greisenizations"],
    &["greisenisations"],
];

pub(crate) static ENTRY_GREISENIZATION_8128500031148376106: VariantsMap = [
    &["greisenization"],
    &["greisenisation"],
    &["greisenization"],
    &["greisenisation"],
];

pub(crate) static ENTRY_GREISENIZED_773775153096936260: VariantsMap = [
    &["greisenized"],
    &["greisenised"],
    &["greisenized"],
    &["greisenised"],
];

pub(crate) static ENTRY_GREISENIZES_10589439824485596475: VariantsMap = [
    &["greisenizes"],
    &["greisenises"],
    &["greisenizes"],
    &["greisenises"],
];

pub(crate) static ENTRY_GREISENIZE_15671456557302415783: VariantsMap = [
    &["greisenize"],
    &["greisenise"],
    &["greisenize"],
    &["greisenise"],
];

pub(crate) static ENTRY_GREISENIZING_7840207760010207004: VariantsMap = [
    &["greisenizing"],
    &["greisenising"],
    &["greisenizing"],
    &["greisenising"],
];

pub(crate) static ENTRY_GRIZARD_17063187695600909120: VariantsMap =
    [&["grizard"], &["grisard"], &["grizard"], &["grisard"]];

pub(crate) static ENTRY_GRIZES_12774403152381854793: VariantsMap =
    [&["grizes"], &["grises"], &["grizes"], &["grises"]];

pub(crate) static ENTRY_GRIZE_9453990615766627670: VariantsMap =
    [&["grize"], &["grise"], &["grize"], &["grise"]];

pub(crate) static ENTRY_GROINS_18359122734169972948: VariantsMap =
    [&["groins"], &["groynes"], &["groynes"], &["groynes"]];

pub(crate) static ENTRY_GROIN_18030282935737915420: VariantsMap =
    [&["groin"], &["groyne"], &["groyne"], &["groyne"]];

pub(crate) static ENTRY_GROVELED_2352401965482255212: VariantsMap = [
    &["groveled"],
    &["grovelled"],
    &["grovelled"],
    &["grovelled"],
];

pub(crate) static ENTRY_GROVELERS_17279766420386335679: VariantsMap = [
    &["grovelers"],
    &["grovellers"],
    &["grovellers"],
    &["grovellers"],
];

pub(crate) static ENTRY_GROVELER_9431310593606301755: VariantsMap = [
    &["groveler"],
    &["groveller"],
    &["groveller"],
    &["groveller"],
];

pub(crate) static ENTRY_GROVELINGLIER_9586931247280041422: VariantsMap = [
    &["grovelinglier"],
    &["grovellinglier"],
    &["grovellinglier"],
    &["grovellinglier"],
];

pub(crate) static ENTRY_GROVELINGLIEST_1087361846884407532: VariantsMap = [
    &["grovelingliest"],
    &["grovellingliest"],
    &["grovellingliest"],
    &["grovellingliest"],
];

pub(crate) static ENTRY_GROVELINGLY_4473860279449450164: VariantsMap = [
    &["grovelingly"],
    &["grovellingly"],
    &["grovellingly"],
    &["grovellingly"],
];

pub(crate) static ENTRY_GROVELING_1726744122250600972: VariantsMap = [
    &["groveling"],
    &["grovelling"],
    &["grovelling"],
    &["grovelling"],
];

pub(crate) static ENTRY_GRUELED_489064457355388373: VariantsMap =
    [&["grueled"], &["gruelled"], &["gruelled"], &["gruelled"]];

pub(crate) static ENTRY_GRUELERS_14251257235203443661: VariantsMap = [
    &["gruelers"],
    &["gruellers"],
    &["gruellers"],
    &["gruellers"],
];

pub(crate) static ENTRY_GRUELER_9855558082126824748: VariantsMap =
    [&["grueler"], &["grueller"], &["grueller"], &["grueller"]];

pub(crate) static ENTRY_GRUELINGLY_11060645752718216669: VariantsMap = [
    &["gruelingly"],
    &["gruellingly"],
    &["gruellingly"],
    &["gruellingly"],
];

pub(crate) static ENTRY_GRUELINGS_4182385732270423207: VariantsMap = [
    &["gruelings"],
    &["gruellings"],
    &["gruellings"],
    &["gruellings"],
];

pub(crate) static ENTRY_GRUELING_4646165576783322871: VariantsMap = [
    &["grueling"],
    &["gruelling"],
    &["gruelling"],
    &["gruelling"],
];

pub(crate) static ENTRY_GUEBERS_8470590757377245464: VariantsMap =
    [&["guebers"], &["guebres"], &["guebres"], &["guebres"]];

pub(crate) static ENTRY_GUEBER_11407604006203913521: VariantsMap =
    [&["gueber"], &["guebre"], &["guebre"], &["guebre"]];

pub(crate) static ENTRY_GUIZERS_14075758514368155583: VariantsMap =
    [&["guizers"], &["guisers"], &["guizers"], &["guisers"]];

pub(crate) static ENTRY_GUIZER_10053586555200196360: VariantsMap =
    [&["guizer"], &["guiser"], &["guizer"], &["guiser"]];

pub(crate) static ENTRY_GULE_17891121426939931319: VariantsMap =
    [&["gule"], &["gulae"], &["gulae"], &["gulae"]];

pub(crate) static ENTRY_GUTTE_3525764560995535296: VariantsMap =
    [&["gutte"], &["guttae"], &["guttae"], &["guttae"]];

pub(crate) static ENTRY_GUTTULE_6846811733996501915: VariantsMap =
    [&["guttule"], &["guttulae"], &["guttulae"], &["guttulae"]];

pub(crate) static ENTRY_GUTTURALIZATIONS_11653363940865133745: VariantsMap = [
    &["gutturalizations"],
    &["gutturalisations"],
    &["gutturalizations"],
    &["gutturalisations"],
];

pub(crate) static ENTRY_GUTTURALIZATION_8050117225444468225: VariantsMap = [
    &["gutturalization"],
    &["gutturalisation"],
    &["gutturalization"],
    &["gutturalisation"],
];

pub(crate) static ENTRY_GUTTURALIZED_193161462369494648: VariantsMap = [
    &["gutturalized"],
    &["gutturalised"],
    &["gutturalized"],
    &["gutturalised"],
];

pub(crate) static ENTRY_GUTTURALIZES_347774313307163504: VariantsMap = [
    &["gutturalizes"],
    &["gutturalises"],
    &["gutturalizes"],
    &["gutturalises"],
];

pub(crate) static ENTRY_GUTTURALIZE_4985183622837803583: VariantsMap = [
    &["gutturalize"],
    &["gutturalise"],
    &["gutturalize"],
    &["gutturalise"],
];

pub(crate) static ENTRY_GUTTURALIZING_8987075679515454610: VariantsMap = [
    &["gutturalizing"],
    &["gutturalising"],
    &["gutturalizing"],
    &["gutturalising"],
];

pub(crate) static ENTRY_GYNECIC_4612357248684171733: VariantsMap =
    [&["gynecic"], &["gynaecic"], &["gynaecic"], &["gynaecic"]];

pub(crate) static ENTRY_GYNECOCRACIES_6538377328563789775: VariantsMap = [
    &["gynecocracies"],
    &["gynaecocracies"],
    &["gynaecocracies"],
    &["gynaecocracies"],
];

pub(crate) static ENTRY_GYNECOCRACY_17315257345269411088: VariantsMap = [
    &["gynecocracy"],
    &["gynaecocracy"],
    &["gynaecocracy"],
    &["gynaecocracy"],
];

pub(crate) static ENTRY_GYNECOCRATICER_11110554799282310698: VariantsMap = [
    &["gynecocraticer"],
    &["gynaecocraticer"],
    &["gynaecocraticer"],
    &["gynaecocraticer"],
];

pub(crate) static ENTRY_GYNECOCRATICEST_9045896881169645560: VariantsMap = [
    &["gynecocraticest"],
    &["gynaecocraticest"],
    &["gynaecocraticest"],
    &["gynaecocraticest"],
];

pub(crate) static ENTRY_GYNECOCRATIC_4397270957142341610: VariantsMap = [
    &["gynecocratic"],
    &["gynaecocratic"],
    &["gynaecocratic"],
    &["gynaecocratic"],
];

pub(crate) static ENTRY_GYNECOCRATS_17242768922364343193: VariantsMap = [
    &["gynecocrats"],
    &["gynaecocrats"],
    &["gynaecocrats"],
    &["gynaecocrats"],
];

pub(crate) static ENTRY_GYNECOCRAT_13604809141318679905: VariantsMap = [
    &["gynecocrat"],
    &["gynaecocrat"],
    &["gynaecocrat"],
    &["gynaecocrat"],
];

pub(crate) static ENTRY_GYNECOID_2669421810154584267: VariantsMap = [
    &["gynecoid"],
    &["gynaecoid"],
    &["gynaecoid"],
    &["gynaecoid"],
];

pub(crate) static ENTRY_GYNECOLOGICALER_3649621888054805329: VariantsMap = [
    &["gynecologicaler"],
    &["gynaecologicaler"],
    &["gynecologicaler"],
    &["gynaecologicaler"],
];

pub(crate) static ENTRY_GYNECOLOGICALEST_11839192754845678028: VariantsMap = [
    &["gynecologicalest"],
    &["gynaecologicalest"],
    &["gynecologicalest"],
    &["gynaecologicalest"],
];

pub(crate) static ENTRY_GYNECOLOGICALS_12284377184405525261: VariantsMap = [
    &["gynecologicals"],
    &["gynaecologicals"],
    &["gynecologicals"],
    &["gynaecologicals"],
];

pub(crate) static ENTRY_GYNECOLOGICAL_8191486902731594424: VariantsMap = [
    &["gynecological"],
    &["gynaecological"],
    &["gynecological"],
    &["gynaecological"],
];

pub(crate) static ENTRY_GYNECOLOGICER_16168567216609951600: VariantsMap = [
    &["gynecologicer"],
    &["gynaecologicer"],
    &["gynaecologicer"],
    &["gynaecologicer"],
];

pub(crate) static ENTRY_GYNECOLOGICEST_11194585440590421999: VariantsMap = [
    &["gynecologicest"],
    &["gynaecologicest"],
    &["gynaecologicest"],
    &["gynaecologicest"],
];

pub(crate) static ENTRY_GYNECOLOGICS_15475065316407176832: VariantsMap = [
    &["gynecologics"],
    &["gynaecologics"],
    &["gynaecologics"],
    &["gynaecologics"],
];

pub(crate) static ENTRY_GYNECOLOGIC_7095414145443907048: VariantsMap = [
    &["gynecologic"],
    &["gynaecologic"],
    &["gynaecologic"],
    &["gynaecologic"],
];

pub(crate) static ENTRY_GYNECOLOGIES_16136091029849906426: VariantsMap = [
    &["gynecologies"],
    &["gynaecologies"],
    &["gynecologies"],
    &["gynaecologies"],
];

pub(crate) static ENTRY_GYNECOLOGISTS_1517096604835056713: VariantsMap = [
    &["gynecologists"],
    &["gynaecologists"],
    &["gynecologists"],
    &["gynaecologists"],
];

pub(crate) static ENTRY_GYNECOLOGIST_7391903546685130646: VariantsMap = [
    &["gynecologist"],
    &["gynaecologist"],
    &["gynecologist"],
    &["gynaecologist"],
];

pub(crate) static ENTRY_GYNECOLOGY_16692090121570341125: VariantsMap = [
    &["gynecology"],
    &["gynaecology"],
    &["gynecology"],
    &["gynaecology"],
];

pub(crate) static ENTRY_GYNECOL_9831784870183209183: VariantsMap =
    [&["gynecol"], &["gynaecol"], &["gynaecol"], &["gynaecol"]];

pub(crate) static ENTRY_GYNECOMASTIAS_3172803406961308705: VariantsMap = [
    &["gynecomastias"],
    &["gynaecomastias"],
    &["gynecomastias"],
    &["gynaecomastias"],
];

pub(crate) static ENTRY_GYNECOMASTIA_3933758254422394945: VariantsMap = [
    &["gynecomastia"],
    &["gynaecomastia"],
    &["gynecomastia"],
    &["gynaecomastia"],
];

pub(crate) static ENTRY_GYNECOMASTY_15555829153650441782: VariantsMap = [
    &["gynecomasty"],
    &["gynaecomasty"],
    &["gynaecomasty"],
    &["gynaecomasty"],
];

pub(crate) static ENTRY_GYNECOMORPHOUS_3257314395419567917: VariantsMap = [
    &["gynecomorphous"],
    &["gynaecomorphous"],
    &["gynaecomorphous"],
    &["gynaecomorphous"],
];

pub(crate) static ENTRY_GYNECONITIS_2677048082283197616: VariantsMap = [
    &["gyneconitis"],
    &["gynaeconitis"],
    &["gynaeconitis"],
    &["gynaeconitis"],
];

pub(crate) static ENTRY_GYNEOCRACY_7561546985644041769: VariantsMap = [
    &["gyneocracy"],
    &["gynaeocracy"],
    &["gynaeocracy"],
    &["gynaeocracy"],
];

pub(crate) static ENTRY_GYNEOLATER_7078383320128612624: VariantsMap = [
    &["gyneolater"],
    &["gynaeolater"],
    &["gynaeolater"],
    &["gynaeolater"],
];

pub(crate) static ENTRY_GYNEOLATRY_15965664026622146712: VariantsMap = [
    &["gyneolatry"],
    &["gynaeolatry"],
    &["gynaeolatry"],
    &["gynaeolatry"],
];

pub(crate) static ENTRY_GYNE_1219733555746359489: VariantsMap =
    [&["gyne"], &["gynae"], &["gynae"], &["gynae"]];

pub(crate) static ENTRY_GYNOMONECIOUS_14127738128183139919: VariantsMap = [
    &["gynomonecious"],
    &["gynomonoecious"],
    &["gynomonoecious"],
    &["gynomonoecious"],
];

pub(crate) static ENTRY_GYROSTABILIZATIONS_9084662166713279380: VariantsMap = [
    &["gyrostabilizations"],
    &["gyrostabilisations"],
    &["gyrostabilizations"],
    &["gyrostabilisations"],
];

pub(crate) static ENTRY_GYROSTABILIZATION_7444180417440707528: VariantsMap = [
    &["gyrostabilization"],
    &["gyrostabilisation"],
    &["gyrostabilization"],
    &["gyrostabilisation"],
];

pub(crate) static ENTRY_GYROSTABILIZERS_4574473259133787027: VariantsMap = [
    &["gyrostabilizers"],
    &["gyrostabilisers"],
    &["gyrostabilizers"],
    &["gyrostabilisers"],
];

pub(crate) static ENTRY_GYROSTABILIZER_14836570145756145064: VariantsMap = [
    &["gyrostabilizer"],
    &["gyrostabiliser"],
    &["gyrostabilizer"],
    &["gyrostabiliser"],
];

pub(crate) static ENTRY_HABITUALIZES_15369684171096748006: VariantsMap = [
    &["habitualizes"],
    &["habitualises"],
    &["habitualizes"],
    &["habitualises"],
];

pub(crate) static ENTRY_HABITUALIZE_1807450546975383265: VariantsMap = [
    &["habitualize"],
    &["habitualise"],
    &["habitualize"],
    &["habitualise"],
];

pub(crate) static ENTRY_HAMLETIZATIONS_7394464384934624017: VariantsMap = [
    &["hamletizations"],
    &["hamletisations"],
    &["hamletizations"],
    &["hamletisations"],
];

pub(crate) static ENTRY_HAMLETIZATION_5996454377141688911: VariantsMap = [
    &["hamletization"],
    &["hamletisation"],
    &["hamletization"],
    &["hamletisation"],
];

pub(crate) static ENTRY_HAMLETIZES_3332330520225481896: VariantsMap = [
    &["hamletizes"],
    &["hamletises"],
    &["hamletizes"],
    &["hamletises"],
];

pub(crate) static ENTRY_HAMLETIZE_576738953922217726: VariantsMap = [
    &["hamletize"],
    &["hamletise"],
    &["hamletize"],
    &["hamletise"],
];

pub(crate) static ENTRY_HANDSELED_4558617958729347581: VariantsMap = [
    &["handseled"],
    &["handselled"],
    &["handselled"],
    &["handselled"],
];

pub(crate) static ENTRY_HANDSELING_7816828783515165883: VariantsMap = [
    &["handseling"],
    &["handselling"],
    &["handselling"],
    &["handselling"],
];

pub(crate) static ENTRY_HANOVERIANIZES_14446304127834146718: VariantsMap = [
    &["hanoverianizes"],
    &["hanoverianises"],
    &["hanoverianizes"],
    &["hanoverianises"],
];

pub(crate) static ENTRY_HANOVERIANIZE_5334670887206094723: VariantsMap = [
    &["hanoverianize"],
    &["hanoverianise"],
    &["hanoverianize"],
    &["hanoverianise"],
];

pub(crate) static ENTRY_HANOVERIZES_4571999407649732424: VariantsMap = [
    &["hanoverizes"],
    &["hanoverises"],
    &["hanoverizes"],
    &["hanoverises"],
];

pub(crate) static ENTRY_HANOVERIZE_11360763386599500895: VariantsMap = [
    &["hanoverize"],
    &["hanoverise"],
    &["hanoverize"],
    &["hanoverise"],
];

pub(crate) static ENTRY_HANSARDIZED_14987634660702470913: VariantsMap = [
    &["hansardized"],
    &["hansardised"],
    &["hansardized"],
    &["hansardised"],
];

pub(crate) static ENTRY_HANSARDIZES_16469043666980648203: VariantsMap = [
    &["hansardizes"],
    &["hansardises"],
    &["hansardizes"],
    &["hansardises"],
];

pub(crate) static ENTRY_HANSARDIZE_14805346125270133932: VariantsMap = [
    &["hansardize"],
    &["hansardise"],
    &["hansardize"],
    &["hansardise"],
];

pub(crate) static ENTRY_HANSARDIZING_3110991711011733484: VariantsMap = [
    &["hansardizing"],
    &["hansardising"],
    &["hansardizing"],
    &["hansardising"],
];

pub(crate) static ENTRY_HANSELED_3944549000155682089: VariantsMap = [
    &["hanseled"],
    &["hanselled"],
    &["hanselled"],
    &["hanselled"],
];

pub(crate) static ENTRY_HANSELING_7080754228121990699: VariantsMap = [
    &["hanseling"],
    &["hanselling"],
    &["hanselling"],
    &["hanselling"],
];

pub(crate) static ENTRY_HARBORAGES_798940995174395851: VariantsMap = [
    &["harborages"],
    &["harbourages"],
    &["harbourages"],
    &["harbourages"],
];

pub(crate) static ENTRY_HARBORAGE_3550097433722182667: VariantsMap = [
    &["harborage"],
    &["harbourage"],
    &["harbourage"],
    &["harbourage"],
];

pub(crate) static ENTRY_HARBORED_7559176787853337330: VariantsMap = [
    &["harbored"],
    &["harboured"],
    &["harboured"],
    &["harboured"],
];

pub(crate) static ENTRY_HARBORERS_14405132928866064013: VariantsMap = [
    &["harborers"],
    &["harbourers"],
    &["harbourers"],
    &["harbourers"],
];

pub(crate) static ENTRY_HARBORER_17782355986829956224: VariantsMap = [
    &["harborer"],
    &["harbourer"],
    &["harbourer"],
    &["harbourer"],
];

pub(crate) static ENTRY_HARBORFUL_10848468655854650625: VariantsMap = [
    &["harborful"],
    &["harbourful"],
    &["harbourful"],
    &["harbourful"],
];

pub(crate) static ENTRY_HARBORING_8402517685558870632: VariantsMap = [
    &["harboring"],
    &["harbouring"],
    &["harbouring"],
    &["harbouring"],
];

pub(crate) static ENTRY_HARBORLESSER_9734324406563797455: VariantsMap = [
    &["harborlesser"],
    &["harbourlesser"],
    &["harbourlesser"],
    &["harbourlesser"],
];

pub(crate) static ENTRY_HARBORLESSEST_630061914736245442: VariantsMap = [
    &["harborlessest"],
    &["harbourlessest"],
    &["harbourlessest"],
    &["harbourlessest"],
];

pub(crate) static ENTRY_HARBORLESSES_12304255545984710354: VariantsMap = [
    &["harborlesses"],
    &["harbourlesses"],
    &["harbourlesses"],
    &["harbourlesses"],
];

pub(crate) static ENTRY_HARBORLESS_1184995738439778537: VariantsMap = [
    &["harborless"],
    &["harbourless"],
    &["harbourless"],
    &["harbourless"],
];

pub(crate) static ENTRY_HARBOROUS_5233500953165283102: VariantsMap = [
    &["harborous"],
    &["harbourous"],
    &["harbourous"],
    &["harbourous"],
];

pub(crate) static ENTRY_HARBORSIDE_15034063211426224574: VariantsMap = [
    &["harborside"],
    &["harbourside"],
    &["harbourside"],
    &["harbourside"],
];

pub(crate) static ENTRY_HARBORS_8699567614856953096: VariantsMap =
    [&["harbors"], &["harbours"], &["harbours"], &["harbours"]];

pub(crate) static ENTRY_HARBORWARD_15630040836906357036: VariantsMap = [
    &["harborward"],
    &["harbourward"],
    &["harbourward"],
    &["harbourward"],
];

pub(crate) static ENTRY_HARBOR_7684387603909099341: VariantsMap =
    [&["harbor"], &["harbour"], &["harbour"], &["harbour"]];

pub(crate) static ENTRY_HARMONIZABLER_784086214484258137: VariantsMap = [
    &["harmonizabler"],
    &["harmonisabler"],
    &["harmonizabler"],
    &["harmonisabler"],
];

pub(crate) static ENTRY_HARMONIZABLEST_2737362624785805248: VariantsMap = [
    &["harmonizablest"],
    &["harmonisablest"],
    &["harmonizablest"],
    &["harmonisablest"],
];

pub(crate) static ENTRY_HARMONIZABLES_12681674670896899721: VariantsMap = [
    &["harmonizables"],
    &["harmonisables"],
    &["harmonizables"],
    &["harmonisables"],
];

pub(crate) static ENTRY_HARMONIZABLE_3524685114296597734: VariantsMap = [
    &["harmonizable"],
    &["harmonisable"],
    &["harmonizable"],
    &["harmonisable"],
];

pub(crate) static ENTRY_HARMONIZATIONS_1390450432634590795: VariantsMap = [
    &["harmonizations"],
    &["harmonisations"],
    &["harmonizations"],
    &["harmonisations"],
];

pub(crate) static ENTRY_HARMONIZATION_3936035217464563683: VariantsMap = [
    &["harmonization"],
    &["harmonisation"],
    &["harmonization"],
    &["harmonisation"],
];

pub(crate) static ENTRY_HARMONIZED_1245910378210887216: VariantsMap = [
    &["harmonized"],
    &["harmonised"],
    &["harmonized"],
    &["harmonised"],
];

pub(crate) static ENTRY_HARMONIZERS_14760666922495363496: VariantsMap = [
    &["harmonizers"],
    &["harmonisers"],
    &["harmonizers"],
    &["harmonisers"],
];

pub(crate) static ENTRY_HARMONIZER_11079314650397597076: VariantsMap = [
    &["harmonizer"],
    &["harmoniser"],
    &["harmonizer"],
    &["harmoniser"],
];

pub(crate) static ENTRY_HARMONIZES_11148526706436473737: VariantsMap = [
    &["harmonizes"],
    &["harmonises"],
    &["harmonizes"],
    &["harmonises"],
];

pub(crate) static ENTRY_HARMONIZE_16537605792111248548: VariantsMap = [
    &["harmonize"],
    &["harmonise"],
    &["harmonize"],
    &["harmonise"],
];

pub(crate) static ENTRY_HARMONIZING_3276739627374116575: VariantsMap = [
    &["harmonizing"],
    &["harmonising"],
    &["harmonizing"],
    &["harmonising"],
];

pub(crate) static ENTRY_HARMOTHOE_15375280065469282042: VariantsMap = [
    &["harmothoe"],
    &["harmothoae"],
    &["harmothoae"],
    &["harmothoae"],
];

pub(crate) static ENTRY_HARVARDIZES_15120540188589580097: VariantsMap = [
    &["harvardizes"],
    &["harvardises"],
    &["harvardizes"],
    &["harvardises"],
];

pub(crate) static ENTRY_HARVARDIZE_17099717488981918243: VariantsMap = [
    &["harvardize"],
    &["harvardise"],
    &["harvardize"],
    &["harvardise"],
];

pub(crate) static ENTRY_HARVEYIZES_14473265147115327687: VariantsMap = [
    &["harveyizes"],
    &["harveyises"],
    &["harveyizes"],
    &["harveyises"],
];

pub(crate) static ENTRY_HARVEYIZE_8525712996046155627: VariantsMap = [
    &["harveyize"],
    &["harveyise"],
    &["harveyize"],
    &["harveyise"],
];

pub(crate) static ENTRY_HASIDEAN_7075843562757009121: VariantsMap = [
    &["hasidean"],
    &["hasidaean"],
    &["hasidaean"],
    &["hasidaean"],
];

pub(crate) static ENTRY_HASMONEANS_4264606967949907198: VariantsMap = [
    &["hasmoneans"],
    &["hasmonaeans"],
    &["hasmonaeans"],
    &["hasmonaeans"],
];

pub(crate) static ENTRY_HASMONEAN_8439032050688349426: VariantsMap = [
    &["hasmonean"],
    &["hasmonaean"],
    &["hasmonaean"],
    &["hasmonaean"],
];

pub(crate) static ENTRY_HATCHELED_833142746170795775: VariantsMap = [
    &["hatcheled"],
    &["hatchelled"],
    &["hatchelled"],
    &["hatchelled"],
];

pub(crate) static ENTRY_HATCHELING_2188593831667763850: VariantsMap = [
    &["hatcheling"],
    &["hatchelling"],
    &["hatchelling"],
    &["hatchelling"],
];

pub(crate) static ENTRY_HATTIZES_2400340849510871993: VariantsMap =
    [&["hattizes"], &["hattises"], &["hattizes"], &["hattises"]];

pub(crate) static ENTRY_HATTIZE_12381830723700612027: VariantsMap =
    [&["hattize"], &["hattise"], &["hattize"], &["hattise"]];

pub(crate) static ENTRY_HAUSSMANNIZATIONS_14174390069218345646: VariantsMap = [
    &["haussmannizations"],
    &["haussmannisations"],
    &["haussmannizations"],
    &["haussmannisations"],
];

pub(crate) static ENTRY_HAUSSMANNIZATION_11833307813821936803: VariantsMap = [
    &["haussmannization"],
    &["haussmannisation"],
    &["haussmannization"],
    &["haussmannisation"],
];

pub(crate) static ENTRY_HAUSSMANNIZED_16790530478703643375: VariantsMap = [
    &["haussmannized"],
    &["haussmannised"],
    &["haussmannized"],
    &["haussmannised"],
];

pub(crate) static ENTRY_HAUSSMANNIZES_10290035980633013808: VariantsMap = [
    &["haussmannizes"],
    &["haussmannises"],
    &["haussmannizes"],
    &["haussmannises"],
];

pub(crate) static ENTRY_HAUSSMANNIZE_1750956549415927085: VariantsMap = [
    &["haussmannize"],
    &["haussmannise"],
    &["haussmannize"],
    &["haussmannise"],
];

pub(crate) static ENTRY_HAUSSMANNIZING_7743598241365094927: VariantsMap = [
    &["haussmannizing"],
    &["haussmannising"],
    &["haussmannizing"],
    &["haussmannising"],
];

pub(crate) static ENTRY_HAVIORED_12864545760294288553: VariantsMap = [
    &["haviored"],
    &["havioured"],
    &["havioured"],
    &["havioured"],
];

pub(crate) static ENTRY_HAVIORS_7709423866676716486: VariantsMap =
    [&["haviors"], &["haviours"], &["haviours"], &["haviours"]];

pub(crate) static ENTRY_HAVIOR_9194418702489177973: VariantsMap =
    [&["havior"], &["haviour"], &["haviour"], &["haviour"]];

pub(crate) static ENTRY_HAZARDIZES_3621374866194883455: VariantsMap = [
    &["hazardizes"],
    &["hazardises"],
    &["hazardizes"],
    &["hazardises"],
];

pub(crate) static ENTRY_HAZARDIZE_16561989176363630666: VariantsMap = [
    &["hazardize"],
    &["hazardise"],
    &["hazardize"],
    &["hazardise"],
];

pub(crate) static ENTRY_HEATHENIZATION_4307661223767237492: VariantsMap = [
    &["heathenization"],
    &["heathenisation"],
    &["heathenization"],
    &["heathenisation"],
];

pub(crate) static ENTRY_HEATHENIZED_11565747380883958930: VariantsMap = [
    &["heathenized"],
    &["heathenised"],
    &["heathenized"],
    &["heathenised"],
];

pub(crate) static ENTRY_HEATHENIZES_11230758663043117117: VariantsMap = [
    &["heathenizes"],
    &["heathenises"],
    &["heathenizes"],
    &["heathenises"],
];

pub(crate) static ENTRY_HEATHENIZE_471060992603716901: VariantsMap = [
    &["heathenize"],
    &["heathenise"],
    &["heathenize"],
    &["heathenise"],
];

pub(crate) static ENTRY_HEATHENIZING_18393026372866732801: VariantsMap = [
    &["heathenizing"],
    &["heathenising"],
    &["heathenizing"],
    &["heathenising"],
];

pub(crate) static ENTRY_HEAVENIZES_16090084063510819598: VariantsMap = [
    &["heavenizes"],
    &["heavenises"],
    &["heavenizes"],
    &["heavenises"],
];

pub(crate) static ENTRY_HEAVENIZE_13257962880157202779: VariantsMap = [
    &["heavenize"],
    &["heavenise"],
    &["heavenize"],
    &["heavenise"],
];

pub(crate) static ENTRY_HEBRAICIZES_5673642863053082994: VariantsMap = [
    &["hebraicizes"],
    &["hebraicises"],
    &["hebraicizes"],
    &["hebraicises"],
];

pub(crate) static ENTRY_HEBRAICIZE_14258396906314719553: VariantsMap = [
    &["hebraicize"],
    &["hebraicise"],
    &["hebraicize"],
    &["hebraicise"],
];

pub(crate) static ENTRY_HEBRAIZATIONS_17267782356694125258: VariantsMap = [
    &["hebraizations"],
    &["hebraisations"],
    &["hebraizations"],
    &["hebraisations"],
];

pub(crate) static ENTRY_HEBRAIZATION_8649165272409155064: VariantsMap = [
    &["hebraization"],
    &["hebraisation"],
    &["hebraization"],
    &["hebraisation"],
];

pub(crate) static ENTRY_HEBRAIZED_2388987152857304653: VariantsMap = [
    &["hebraized"],
    &["hebraised"],
    &["hebraized"],
    &["hebraised"],
];

pub(crate) static ENTRY_HEBRAIZER_18227136059206047351: VariantsMap = [
    &["hebraizer"],
    &["hebraiser"],
    &["hebraizer"],
    &["hebraiser"],
];

pub(crate) static ENTRY_HEBRAIZES_14496726034063146653: VariantsMap = [
    &["hebraizes"],
    &["hebraises"],
    &["hebraizes"],
    &["hebraises"],
];

pub(crate) static ENTRY_HEBRAIZE_3305968178586478178: VariantsMap =
    [&["hebraize"], &["hebraise"], &["hebraize"], &["hebraise"]];

pub(crate) static ENTRY_HEBRAIZING_8562209306481252582: VariantsMap = [
    &["hebraizing"],
    &["hebraising"],
    &["hebraizing"],
    &["hebraising"],
];

pub(crate) static ENTRY_HECATEAN_15663949261116623377: VariantsMap = [
    &["hecatean"],
    &["hecataean"],
    &["hecataean"],
    &["hecataean"],
];

pub(crate) static ENTRY_HECTOGRAMS_2910260634951244882: VariantsMap = [
    &["hectograms"],
    &["hectograms"],
    &["hectograms"],
    &["hectograms"],
];

pub(crate) static ENTRY_HECTOGRAM_16008811031541342243: VariantsMap = [
    &["hectogram"],
    &["hectogram"],
    &["hectogram"],
    &["hectogram"],
];

pub(crate) static ENTRY_HECTOLITERS_63081804785897288: VariantsMap = [
    &["hectoliters"],
    &["hectolitres"],
    &["hectolitres"],
    &["hectolitres"],
];

pub(crate) static ENTRY_HECTOLITER_14135938994986629002: VariantsMap = [
    &["hectoliter"],
    &["hectolitre"],
    &["hectolitre"],
    &["hectolitre"],
];

pub(crate) static ENTRY_HECTOMETERS_14599131318366707062: VariantsMap = [
    &["hectometers"],
    &["hectometres"],
    &["hectometres"],
    &["hectometres"],
];

pub(crate) static ENTRY_HECTOMETER_5600234923988117994: VariantsMap = [
    &["hectometer"],
    &["hectometre"],
    &["hectometre"],
    &["hectometre"],
];

pub(crate) static ENTRY_HED_13866725514010411690: VariantsMap =
    [&["hed"], &["haed"], &["haed"], &["haed"]];

pub(crate) static ENTRY_HEGELIANIZES_12105617449412785322: VariantsMap = [
    &["hegelianizes"],
    &["hegelianises"],
    &["hegelianizes"],
    &["hegelianises"],
];

pub(crate) static ENTRY_HEGELIANIZE_7050861181716613923: VariantsMap = [
    &["hegelianize"],
    &["hegelianise"],
    &["hegelianize"],
    &["hegelianise"],
];

pub(crate) static ENTRY_HEKATEAN_17977682053451514832: VariantsMap = [
    &["hekatean"],
    &["hekataean"],
    &["hekataean"],
    &["hekataean"],
];

pub(crate) static ENTRY_HELE_15877226027490641560: VariantsMap =
    [&["hele"], &["heloe"], &["heloe"], &["heloe"]];

pub(crate) static ENTRY_HELLED_17922575627420769814: VariantsMap =
    [&["helled"], &["helloed"], &["helloed"], &["helloed"]];

pub(crate) static ENTRY_HELLENIZATIONS_16400001129419755934: VariantsMap = [
    &["hellenizations"],
    &["hellenisations"],
    &["hellenizations"],
    &["hellenisations"],
];

pub(crate) static ENTRY_HELLENIZATION_572299821795419581: VariantsMap = [
    &["hellenization"],
    &["hellenisation"],
    &["hellenization"],
    &["hellenisation"],
];

pub(crate) static ENTRY_HELLENIZED_1262240579030098003: VariantsMap = [
    &["hellenized"],
    &["hellenised"],
    &["hellenized"],
    &["hellenised"],
];

pub(crate) static ENTRY_HELLENIZER_5626782103778669758: VariantsMap = [
    &["hellenizer"],
    &["helleniser"],
    &["hellenizer"],
    &["helleniser"],
];

pub(crate) static ENTRY_HELLENIZES_11902572538272316091: VariantsMap = [
    &["hellenizes"],
    &["hellenises"],
    &["hellenizes"],
    &["hellenises"],
];

pub(crate) static ENTRY_HELLENIZE_423650469605584095: VariantsMap = [
    &["hellenize"],
    &["hellenise"],
    &["hellenize"],
    &["hellenise"],
];

pub(crate) static ENTRY_HELLENIZING_6274266325744186778: VariantsMap = [
    &["hellenizing"],
    &["hellenising"],
    &["hellenizing"],
    &["hellenising"],
];

pub(crate) static ENTRY_HEMACHROME_6418660628406537270: VariantsMap = [
    &["hemachrome"],
    &["haemachrome"],
    &["haemachrome"],
    &["haemachrome"],
];

pub(crate) static ENTRY_HEMACYTOMETER_10171050284277896358: VariantsMap = [
    &["hemacytometer"],
    &["haemacytometer"],
    &["haemacytometer"],
    &["haemacytometer"],
];

pub(crate) static ENTRY_HEMAD_13652123074339994243: VariantsMap =
    [&["hemad"], &["haemad"], &["haemad"], &["haemad"]];

pub(crate) static ENTRY_HEMAGGLUTINATED_847479788420217781: VariantsMap = [
    &["hemagglutinated"],
    &["haemagglutinated"],
    &["haemagglutinated"],
    &["haemagglutinated"],
];

pub(crate) static ENTRY_HEMAGGLUTINATE_16094833305901311560: VariantsMap = [
    &["hemagglutinate"],
    &["haemagglutinate"],
    &["haemagglutinate"],
    &["haemagglutinate"],
];

pub(crate) static ENTRY_HEMAGGLUTINATING_406171148269136925: VariantsMap = [
    &["hemagglutinating"],
    &["haemagglutinating"],
    &["haemagglutinating"],
    &["haemagglutinating"],
];

pub(crate) static ENTRY_HEMAGGLUTINATION_16199920820699607422: VariantsMap = [
    &["hemagglutination"],
    &["haemagglutination"],
    &["haemagglutination"],
    &["haemagglutination"],
];

pub(crate) static ENTRY_HEMAGGLUTINATIVE_12088266750522338367: VariantsMap = [
    &["hemagglutinative"],
    &["haemagglutinative"],
    &["haemagglutinative"],
    &["haemagglutinative"],
];

pub(crate) static ENTRY_HEMAGGLUTININ_1512122070828458386: VariantsMap = [
    &["hemagglutinin"],
    &["haemagglutinin"],
    &["haemagglutinin"],
    &["haemagglutinin"],
];

pub(crate) static ENTRY_HEMAGOGUE_7911863114412250688: VariantsMap = [
    &["hemagogue"],
    &["haemagogue"],
    &["haemagogue"],
    &["haemagogue"],
];

pub(crate) static ENTRY_HEMAL_8174621070613039824: VariantsMap =
    [&["hemal"], &["haemal"], &["haemal"], &["haemal"]];

pub(crate) static ENTRY_HEMAMEBA_3738470481791074652: VariantsMap = [
    &["hemameba"],
    &["hemamoeba"],
    &["hemamoeba"],
    &["hemamoeba"],
];

pub(crate) static ENTRY_HEMANGIOMAS_5403149239971967527: VariantsMap = [
    &["hemangiomas"],
    &["haemangiomas"],
    &["haemangiomas"],
    &["haemangiomas"],
];

pub(crate) static ENTRY_HEMANGIOMATA_17129056589733427049: VariantsMap = [
    &["hemangiomata"],
    &["haemangiomata"],
    &["haemangiomata"],
    &["haemangiomata"],
];

pub(crate) static ENTRY_HEMANGIOMATOSIS_6766889074360311777: VariantsMap = [
    &["hemangiomatosis"],
    &["haemangiomatosis"],
    &["haemangiomatosis"],
    &["haemangiomatosis"],
];

pub(crate) static ENTRY_HEMANGIOMA_4433290260611802687: VariantsMap = [
    &["hemangioma"],
    &["haemangioma"],
    &["haemangioma"],
    &["haemangioma"],
];

pub(crate) static ENTRY_HEMAPOPHYSIS_14410027549001408776: VariantsMap = [
    &["hemapophysis"],
    &["haemapophysis"],
    &["haemapophysis"],
    &["haemapophysis"],
];

pub(crate) static ENTRY_HEMASPECTROSCOPE_15636245578363276486: VariantsMap = [
    &["hemaspectroscope"],
    &["haemaspectroscope"],
    &["haemaspectroscope"],
    &["haemaspectroscope"],
];

pub(crate) static ENTRY_HEMATAL_7087036422270254482: VariantsMap =
    [&["hematal"], &["haematal"], &["haematal"], &["haematal"]];

pub(crate) static ENTRY_HEMATEIN_15736414880744516603: VariantsMap = [
    &["hematein"],
    &["haematein"],
    &["haematein"],
    &["haematein"],
];

pub(crate) static ENTRY_HEMATEMESIS_1150278158641123049: VariantsMap = [
    &["hematemesis"],
    &["haematemesis"],
    &["haematemesis"],
    &["haematemesis"],
];

pub(crate) static ENTRY_HEMATHERMAL_1873265424030054420: VariantsMap = [
    &["hemathermal"],
    &["haemathermal"],
    &["haemathermal"],
    &["haemathermal"],
];

pub(crate) static ENTRY_HEMATHERMOUS_15573027130540325878: VariantsMap = [
    &["hemathermous"],
    &["haemathermous"],
    &["haemathermous"],
    &["haemathermous"],
];

pub(crate) static ENTRY_HEMATHERM_5926070727779344344: VariantsMap = [
    &["hematherm"],
    &["haematherm"],
    &["haematherm"],
    &["haematherm"],
];

pub(crate) static ENTRY_HEMATICS_15442957672300497599: VariantsMap = [
    &["hematics"],
    &["haematics"],
    &["haematics"],
    &["haematics"],
];

pub(crate) static ENTRY_HEMATIC_12135656367189032895: VariantsMap =
    [&["hematic"], &["haematic"], &["haematic"], &["haematic"]];

pub(crate) static ENTRY_HEMATID_5688919815724817461: VariantsMap =
    [&["hematid"], &["haematid"], &["haematid"], &["haematid"]];

pub(crate) static ENTRY_HEMATINICS_14584691563755596573: VariantsMap = [
    &["hematinics"],
    &["haematinics"],
    &["haematinics"],
    &["haematinics"],
];

pub(crate) static ENTRY_HEMATINIC_13817867819850632982: VariantsMap = [
    &["hematinic"],
    &["haematinic"],
    &["haematinic"],
    &["haematinic"],
];

pub(crate) static ENTRY_HEMATINS_3508374996795413939: VariantsMap = [
    &["hematins"],
    &["haematins"],
    &["haematins"],
    &["haematins"],
];

pub(crate) static ENTRY_HEMATIN_7088374062718549777: VariantsMap =
    [&["hematin"], &["haematin"], &["haematin"], &["haematin"]];

pub(crate) static ENTRY_HEMATITES_16664996411162525513: VariantsMap = [
    &["hematites"],
    &["haematites"],
    &["hematites"],
    &["haematites"],
];

pub(crate) static ENTRY_HEMATITE_18189725537336168240: VariantsMap =
    [&["hematite"], &["haematite"], &["hematite"], &["haematite"]];

pub(crate) static ENTRY_HEMATITIC_6519641012406286441: VariantsMap = [
    &["hematitic"],
    &["haematitic"],
    &["haematitic"],
    &["haematitic"],
];

pub(crate) static ENTRY_HEMATOBLASTS_11740583065401144309: VariantsMap = [
    &["hematoblasts"],
    &["haematoblasts"],
    &["haematoblasts"],
    &["haematoblasts"],
];

pub(crate) static ENTRY_HEMATOBLAST_6156351493707158509: VariantsMap = [
    &["hematoblast"],
    &["haematoblast"],
    &["haematoblast"],
    &["haematoblast"],
];

pub(crate) static ENTRY_HEMATOBRANCHIATE_6724889294153595153: VariantsMap = [
    &["hematobranchiate"],
    &["haematobranchiate"],
    &["haematobranchiate"],
    &["haematobranchiate"],
];

pub(crate) static ENTRY_HEMATOCELE_14219451917679449221: VariantsMap = [
    &["hematocele"],
    &["haematocele"],
    &["hematocele"],
    &["haematocele"],
];

pub(crate) static ENTRY_HEMATOCRITS_11851859531643542564: VariantsMap = [
    &["hematocrits"],
    &["haematocrits"],
    &["haematocrits"],
    &["haematocrits"],
];

pub(crate) static ENTRY_HEMATOCRIT_6552226497838822276: VariantsMap = [
    &["hematocrit"],
    &["haematocrit"],
    &["haematocrit"],
    &["haematocrit"],
];

pub(crate) static ENTRY_HEMATOCRYAL_14432690073423033477: VariantsMap = [
    &["hematocryal"],
    &["haematocryal"],
    &["haematocryal"],
    &["haematocryal"],
];

pub(crate) static ENTRY_HEMATOCYSTIS_2331938888115761990: VariantsMap = [
    &["hematocystis"],
    &["haematocystis"],
    &["haematocystis"],
    &["haematocystis"],
];

pub(crate) static ENTRY_HEMATOCYST_17378437902553802108: VariantsMap = [
    &["hematocyst"],
    &["haematocyst"],
    &["haematocyst"],
    &["haematocyst"],
];

pub(crate) static ENTRY_HEMATOCYTE_14737318323778154918: VariantsMap = [
    &["hematocyte"],
    &["haematocyte"],
    &["haematocyte"],
    &["haematocyte"],
];

pub(crate) static ENTRY_HEMATOGENESES_13718226437830070782: VariantsMap = [
    &["hematogeneses"],
    &["haematogeneses"],
    &["haematogeneses"],
    &["haematogeneses"],
];

pub(crate) static ENTRY_HEMATOGENESIS_17338628845528835521: VariantsMap = [
    &["hematogenesis"],
    &["haematogenesis"],
    &["haematogenesis"],
    &["haematogenesis"],
];

pub(crate) static ENTRY_HEMATOGENOUS_251917998139736524: VariantsMap = [
    &["hematogenous"],
    &["haematogenous"],
    &["haematogenous"],
    &["haematogenous"],
];

pub(crate) static ENTRY_HEMATOIDIN_16093151429433672073: VariantsMap = [
    &["hematoidin"],
    &["haematoidin"],
    &["haematoidin"],
    &["haematoidin"],
];

pub(crate) static ENTRY_HEMATOID_4321558159204018583: VariantsMap = [
    &["hematoid"],
    &["haematoid"],
    &["haematoid"],
    &["haematoid"],
];

pub(crate) static ENTRY_HEMATOLOGICAL_2070290026293273654: VariantsMap = [
    &["hematological"],
    &["haematological"],
    &["hematological"],
    &["haematological"],
];

pub(crate) static ENTRY_HEMATOLOGIC_2423209455187409759: VariantsMap = [
    &["hematologic"],
    &["haematologic"],
    &["hematologic"],
    &["haematologic"],
];

pub(crate) static ENTRY_HEMATOLOGIES_13320136886151112131: VariantsMap = [
    &["hematologies"],
    &["haematologies"],
    &["hematologies"],
    &["haematologies"],
];

pub(crate) static ENTRY_HEMATOLOGISTS_4000147591809351359: VariantsMap = [
    &["hematologists"],
    &["haematologists"],
    &["hematologists"],
    &["haematologists"],
];

pub(crate) static ENTRY_HEMATOLOGIST_3249312009468893819: VariantsMap = [
    &["hematologist"],
    &["haematologist"],
    &["hematologist"],
    &["haematologist"],
];

pub(crate) static ENTRY_HEMATOLOGY_8202738283142709840: VariantsMap = [
    &["hematology"],
    &["haematology"],
    &["hematology"],
    &["haematology"],
];

pub(crate) static ENTRY_HEMATOLYSIS_17421425993349650821: VariantsMap = [
    &["hematolysis"],
    &["haematolysis"],
    &["haematolysis"],
    &["haematolysis"],
];

pub(crate) static ENTRY_HEMATOMAS_16695820346078382946: VariantsMap = [
    &["hematomas"],
    &["haematomas"],
    &["haematomas"],
    &["haematomas"],
];

pub(crate) static ENTRY_HEMATOMATA_6404648405816919402: VariantsMap = [
    &["hematomata"],
    &["haematomata"],
    &["haematomata"],
    &["haematomata"],
];

pub(crate) static ENTRY_HEMATOMA_13408617756828997822: VariantsMap = [
    &["hematoma"],
    &["haematoma"],
    &["haematoma"],
    &["haematoma"],
];

pub(crate) static ENTRY_HEMATOMETER_16112233482898382242: VariantsMap = [
    &["hematometer"],
    &["haematometer"],
    &["haematometer"],
    &["haematometer"],
];

pub(crate) static ENTRY_HEMATOPHYTE_16898559278123185799: VariantsMap = [
    &["hematophyte"],
    &["haematophyte"],
    &["haematophyte"],
    &["haematophyte"],
];

pub(crate) static ENTRY_HEMATOPOIESES_6523522757774558460: VariantsMap = [
    &["hematopoieses"],
    &["haematopoieses"],
    &["haematopoieses"],
    &["haematopoieses"],
];

pub(crate) static ENTRY_HEMATOPOIESIS_13051150701975906944: VariantsMap = [
    &["hematopoiesis"],
    &["haematopoiesis"],
    &["haematopoiesis"],
    &["haematopoiesis"],
];

pub(crate) static ENTRY_HEMATOPOIETIC_7321368675852188024: VariantsMap = [
    &["hematopoietic"],
    &["haematopoietic"],
    &["haematopoietic"],
    &["haematopoietic"],
];

pub(crate) static ENTRY_HEMATORRHACHIS_14809769741461008390: VariantsMap = [
    &["hematorrhachis"],
    &["haematorrhachis"],
    &["haematorrhachis"],
    &["haematorrhachis"],
];

pub(crate) static ENTRY_HEMATOSEPSIS_13675575187899218762: VariantsMap = [
    &["hematosepsis"],
    &["haematosepsis"],
    &["haematosepsis"],
    &["haematosepsis"],
];

pub(crate) static ENTRY_HEMATOSIN_5725284952839086511: VariantsMap = [
    &["hematosin"],
    &["haematosin"],
    &["haematosin"],
    &["haematosin"],
];

pub(crate) static ENTRY_HEMATOSIS_10551613893224734170: VariantsMap = [
    &["hematosis"],
    &["haematosis"],
    &["haematosis"],
    &["haematosis"],
];

pub(crate) static ENTRY_HEMATOTHERMAL_5757070152932847531: VariantsMap = [
    &["hematothermal"],
    &["haematothermal"],
    &["haematothermal"],
    &["haematothermal"],
];

pub(crate) static ENTRY_HEMATOXYLIC_8256186193967626317: VariantsMap = [
    &["hematoxylic"],
    &["haematoxylic"],
    &["haematoxylic"],
    &["haematoxylic"],
];

pub(crate) static ENTRY_HEMATOXYLINS_9008305718553626994: VariantsMap = [
    &["hematoxylins"],
    &["haematoxylins"],
    &["hematoxylins"],
    &["haematoxylins"],
];

pub(crate) static ENTRY_HEMATOXYLIN_3495797730607733321: VariantsMap = [
    &["hematoxylin"],
    &["haematoxylin"],
    &["hematoxylin"],
    &["haematoxylin"],
];

pub(crate) static ENTRY_HEMATOZOAL_15898976106203214908: VariantsMap = [
    &["hematozoal"],
    &["haematozoal"],
    &["haematozoal"],
    &["haematozoal"],
];

pub(crate) static ENTRY_HEMATOZOA_4614122145286367461: VariantsMap = [
    &["hematozoa"],
    &["haematozoa"],
    &["haematozoa"],
    &["haematozoa"],
];

pub(crate) static ENTRY_HEMATOZOIC_3178088775054807745: VariantsMap = [
    &["hematozoic"],
    &["haematozoic"],
    &["haematozoic"],
    &["haematozoic"],
];

pub(crate) static ENTRY_HEMATOZOON_5429660456895400780: VariantsMap = [
    &["hematozoon"],
    &["haematozoon"],
    &["haematozoon"],
    &["haematozoon"],
];

pub(crate) static ENTRY_HEMATOZZOA_10055676600204821827: VariantsMap = [
    &["hematozzoa"],
    &["haematozzoa"],
    &["haematozzoa"],
    &["haematozzoa"],
];

pub(crate) static ENTRY_HEMATURIAS_210214870880694336: VariantsMap = [
    &["hematurias"],
    &["haematurias"],
    &["hematurias"],
    &["haematurias"],
];

pub(crate) static ENTRY_HEMATURIA_4282384524379690883: VariantsMap = [
    &["hematuria"],
    &["haematuria"],
    &["hematuria"],
    &["haematuria"],
];

pub(crate) static ENTRY_HEMERYTHRIN_18297143920246755389: VariantsMap = [
    &["hemerythrin"],
    &["hemoerythrin"],
    &["hemoerythrin"],
    &["hemoerythrin"],
];

pub(crate) static ENTRY_HEME_3428853214083440122: VariantsMap =
    [&["heme"], &["haem"], &["haem"], &["haem"]];

pub(crate) static ENTRY_HEMIC_3956501241017708617: VariantsMap =
    [&["hemic"], &["haemic"], &["haemic"], &["haemic"]];

pub(crate) static ENTRY_HEMIHYPESTHESIA_15185944125713437083: VariantsMap = [
    &["hemihypesthesia"],
    &["hemihypoesthesia"],
    &["hemihypoesthesia"],
    &["hemihypoesthesia"],
];

pub(crate) static ENTRY_HEMINS_2205333871048481752: VariantsMap =
    [&["hemins"], &["haemins"], &["haemins"], &["haemins"]];

pub(crate) static ENTRY_HEMIN_2159475285525852130: VariantsMap =
    [&["hemin"], &["haemin"], &["haemin"], &["haemin"]];

pub(crate) static ENTRY_HEMOBLAST_1212952674211829865: VariantsMap = [
    &["hemoblast"],
    &["haemoblast"],
    &["haemoblast"],
    &["haemoblast"],
];

pub(crate) static ENTRY_HEMOCHROMATOSES_15366460809089499165: VariantsMap = [
    &["hemochromatoses"],
    &["haemochromatoses"],
    &["haemochromatoses"],
    &["haemochromatoses"],
];

pub(crate) static ENTRY_HEMOCHROMATOSIS_2585842551183947470: VariantsMap = [
    &["hemochromatosis"],
    &["haemochromatosis"],
    &["haemochromatosis"],
    &["haemochromatosis"],
];

pub(crate) static ENTRY_HEMOCHROME_2175430877481267405: VariantsMap = [
    &["hemochrome"],
    &["haemochrome"],
    &["haemochrome"],
    &["haemochrome"],
];

pub(crate) static ENTRY_HEMOCOELS_18362432535121397233: VariantsMap = [
    &["hemocoels"],
    &["haemocoels"],
    &["haemocoels"],
    &["haemocoels"],
];

pub(crate) static ENTRY_HEMOCOEL_13831278213168049606: VariantsMap = [
    &["hemocoel"],
    &["haemocoel"],
    &["haemocoel"],
    &["haemocoel"],
];

pub(crate) static ENTRY_HEMOCONCENTRATION_16358090763140109058: VariantsMap = [
    &["hemoconcentration"],
    &["haemoconcentration"],
    &["haemoconcentration"],
    &["haemoconcentration"],
];

pub(crate) static ENTRY_HEMOCONIA_16171119888057670146: VariantsMap = [
    &["hemoconia"],
    &["haemoconia"],
    &["haemoconia"],
    &["haemoconia"],
];

pub(crate) static ENTRY_HEMOCYANINS_17279027934588336382: VariantsMap = [
    &["hemocyanins"],
    &["haemocyanins"],
    &["haemocyanins"],
    &["haemocyanins"],
];

pub(crate) static ENTRY_HEMOCYANIN_12147015753804620517: VariantsMap = [
    &["hemocyanin"],
    &["haemocyanin"],
    &["haemocyanin"],
    &["haemocyanin"],
];

pub(crate) static ENTRY_HEMOCYTES_11990928088518685379: VariantsMap = [
    &["hemocytes"],
    &["haemocytes"],
    &["haemocytes"],
    &["haemocytes"],
];

pub(crate) static ENTRY_HEMOCYTE_15334672110474097892: VariantsMap = [
    &["hemocyte"],
    &["haemocyte"],
    &["haemocyte"],
    &["haemocyte"],
];

pub(crate) static ENTRY_HEMOCYTOBLASTIC_15757846276939616596: VariantsMap = [
    &["hemocytoblastic"],
    &["haemocytoblastic"],
    &["haemocytoblastic"],
    &["haemocytoblastic"],
];

pub(crate) static ENTRY_HEMOCYTOBLAST_8571898144164238141: VariantsMap = [
    &["hemocytoblast"],
    &["haemocytoblast"],
    &["haemocytoblast"],
    &["haemocytoblast"],
];

pub(crate) static ENTRY_HEMOCYTOMETER_12858869074539466859: VariantsMap = [
    &["hemocytometer"],
    &["haemocytometer"],
    &["haemocytometer"],
    &["haemocytometer"],
];

pub(crate) static ENTRY_HEMODIALYSES_11392463941635998019: VariantsMap = [
    &["hemodialyses"],
    &["haemodialyses"],
    &["hemodialyses"],
    &["haemodialyses"],
];

pub(crate) static ENTRY_HEMODIALYSIS_1163550974992047350: VariantsMap = [
    &["hemodialysis"],
    &["haemodialysis"],
    &["hemodialysis"],
    &["haemodialysis"],
];

pub(crate) static ENTRY_HEMODILUTION_11283430470235069221: VariantsMap = [
    &["hemodilution"],
    &["haemodilution"],
    &["haemodilution"],
    &["haemodilution"],
];

pub(crate) static ENTRY_HEMODYNAMICS_15802810674260006804: VariantsMap = [
    &["hemodynamics"],
    &["haemodynamics"],
    &["haemodynamics"],
    &["haemodynamics"],
];

pub(crate) static ENTRY_HEMODYNAMIC_7240703745835327386: VariantsMap = [
    &["hemodynamic"],
    &["haemodynamic"],
    &["haemodynamic"],
    &["haemodynamic"],
];

pub(crate) static ENTRY_HEMOFLAGELLATE_8230159863303274833: VariantsMap = [
    &["hemoflagellate"],
    &["haemoflagellate"],
    &["haemoflagellate"],
    &["haemoflagellate"],
];

pub(crate) static ENTRY_HEMOGLOBIC_14765854368021767231: VariantsMap = [
    &["hemoglobic"],
    &["haemoglobic"],
    &["haemoglobic"],
    &["haemoglobic"],
];

pub(crate) static ENTRY_HEMOGLOBINOPATHIES_17410196980417446786: VariantsMap = [
    &["hemoglobinopathies"],
    &["haemoglobinopathies"],
    &["haemoglobinopathies"],
    &["haemoglobinopathies"],
];

pub(crate) static ENTRY_HEMOGLOBINOPATHY_14568715325380669233: VariantsMap = [
    &["hemoglobinopathy"],
    &["haemoglobinopathy"],
    &["haemoglobinopathy"],
    &["haemoglobinopathy"],
];

pub(crate) static ENTRY_HEMOGLOBINOUS_5070767689092245762: VariantsMap = [
    &["hemoglobinous"],
    &["haemoglobinous"],
    &["haemoglobinous"],
    &["haemoglobinous"],
];

pub(crate) static ENTRY_HEMOGLOBINURIA_4853343125806894750: VariantsMap = [
    &["hemoglobinuria"],
    &["haemoglobinuria"],
    &["haemoglobinuria"],
    &["haemoglobinuria"],
];

pub(crate) static ENTRY_HEMOGLOBIN_6804726008880716957: VariantsMap = [
    &["hemoglobin"],
    &["haemoglobin"],
    &["hemoglobin"],
    &["haemoglobin"],
];

pub(crate) static ENTRY_HEMOGRAM_6271130824240485709: VariantsMap = [
    &["hemogram"],
    &["haemogram"],
    &["haemogram"],
    &["haemogram"],
];

pub(crate) static ENTRY_HEMOID_8415451507008006846: VariantsMap =
    [&["hemoid"], &["haemoid"], &["haemoid"], &["haemoid"]];

pub(crate) static ENTRY_HEMOLYSIN_1274334236242292741: VariantsMap = [
    &["hemolysin"],
    &["haemolysin"],
    &["haemolysin"],
    &["haemolysin"],
];

pub(crate) static ENTRY_HEMOLYSIS_12608987784718295390: VariantsMap = [
    &["hemolysis"],
    &["haemolysis"],
    &["hemolysis"],
    &["haemolysis"],
];

pub(crate) static ENTRY_HEMOLYTIC_16715121281784730995: VariantsMap = [
    &["hemolytic"],
    &["haemolytic"],
    &["haemolytic"],
    &["haemolytic"],
];

pub(crate) static ENTRY_HEMOMETER_6044885281478125261: VariantsMap = [
    &["hemometer"],
    &["haemometer"],
    &["haemometer"],
    &["haemometer"],
];

pub(crate) static ENTRY_HEMON_8613843011077669238: VariantsMap =
    [&["hemon"], &["haemon"], &["haemon"], &["haemon"]];

pub(crate) static ENTRY_HEMOPHILE_939872597781518278: VariantsMap = [
    &["hemophile"],
    &["haemophile"],
    &["haemophile"],
    &["haemophile"],
];

pub(crate) static ENTRY_HEMOPHILIACS_6189076765654799565: VariantsMap = [
    &["hemophiliacs"],
    &["haemophiliacs"],
    &["hemophiliacs"],
    &["haemophiliacs"],
];

pub(crate) static ENTRY_HEMOPHILIAC_6895884973735776837: VariantsMap = [
    &["hemophiliac"],
    &["haemophiliac"],
    &["hemophiliac"],
    &["haemophiliac"],
];

pub(crate) static ENTRY_HEMOPHILIA_438737295534097219: VariantsMap = [
    &["hemophilia"],
    &["haemophilia"],
    &["hemophilia"],
    &["haemophilia"],
];

pub(crate) static ENTRY_HEMOPHILIC_14204241671140169324: VariantsMap = [
    &["hemophilic"],
    &["haemophilic"],
    &["hemophilic"],
    &["haemophilic"],
];

pub(crate) static ENTRY_HEMOPOD_10686552211410032739: VariantsMap =
    [&["hemopod"], &["haemopod"], &["haemopod"], &["haemopod"]];

pub(crate) static ENTRY_HEMOPOIESIS_2722325828942122456: VariantsMap = [
    &["hemopoiesis"],
    &["haemopoiesis"],
    &["haemopoiesis"],
    &["haemopoiesis"],
];

pub(crate) static ENTRY_HEMOPTYSES_5361818757552462001: VariantsMap = [
    &["hemoptyses"],
    &["haemoptyses"],
    &["haemoptyses"],
    &["haemoptyses"],
];

pub(crate) static ENTRY_HEMOPTYSIS_4816059883591909702: VariantsMap = [
    &["hemoptysis"],
    &["haemoptysis"],
    &["haemoptysis"],
    &["haemoptysis"],
];

pub(crate) static ENTRY_HEMORRHAGED_4698265870788181194: VariantsMap = [
    &["hemorrhaged"],
    &["haemorrhaged"],
    &["hemorrhaged"],
    &["haemorrhaged"],
];

pub(crate) static ENTRY_HEMORRHAGES_12805262983424280799: VariantsMap = [
    &["hemorrhages"],
    &["haemorrhages"],
    &["hemorrhages"],
    &["haemorrhages"],
];

pub(crate) static ENTRY_HEMORRHAGE_9520986120225337113: VariantsMap = [
    &["hemorrhage"],
    &["haemorrhage"],
    &["hemorrhage"],
    &["haemorrhage"],
];

pub(crate) static ENTRY_HEMORRHAGING_17455703193968736621: VariantsMap = [
    &["hemorrhaging"],
    &["haemorrhaging"],
    &["hemorrhaging"],
    &["haemorrhaging"],
];

pub(crate) static ENTRY_HEMORRHOIDAL_8918031688638577890: VariantsMap = [
    &["hemorrhoidal"],
    &["haemorrhoidal"],
    &["hemorrhoidal"],
    &["haemorrhoidal"],
];

pub(crate) static ENTRY_HEMORRHOIDECTOMY_14512378041008423124: VariantsMap = [
    &["hemorrhoidectomy"],
    &["haemorrhoidectomy"],
    &["haemorrhoidectomy"],
    &["haemorrhoidectomy"],
];

pub(crate) static ENTRY_HEMORRHOIDS_7074206056862708793: VariantsMap = [
    &["hemorrhoids"],
    &["haemorrhoids"],
    &["hemorrhoids"],
    &["haemorrhoids"],
];

pub(crate) static ENTRY_HEMORRHOID_12305272210878568670: VariantsMap = [
    &["hemorrhoid"],
    &["haemorrhoid"],
    &["hemorrhoid"],
    &["haemorrhoid"],
];

pub(crate) static ENTRY_HEMOSPORIDIAN_12777425045521991692: VariantsMap = [
    &["hemosporidian"],
    &["haemosporidian"],
    &["haemosporidian"],
    &["haemosporidian"],
];

pub(crate) static ENTRY_HEMOSPORID_10539794951355089581: VariantsMap = [
    &["hemosporid"],
    &["haemosporid"],
    &["haemosporid"],
    &["haemosporid"],
];

pub(crate) static ENTRY_HEMOSTASES_12539643331032997430: VariantsMap = [
    &["hemostases"],
    &["haemostases"],
    &["haemostases"],
    &["haemostases"],
];

pub(crate) static ENTRY_HEMOSTASIA_2707018494480397353: VariantsMap = [
    &["hemostasia"],
    &["haemostasia"],
    &["haemostasia"],
    &["haemostasia"],
];

pub(crate) static ENTRY_HEMOSTASIS_13491292460836556551: VariantsMap = [
    &["hemostasis"],
    &["haemostasis"],
    &["haemostasis"],
    &["haemostasis"],
];

pub(crate) static ENTRY_HEMOSTATIC_16725641889932539790: VariantsMap = [
    &["hemostatic"],
    &["haemostatic"],
    &["haemostatic"],
    &["haemostatic"],
];

pub(crate) static ENTRY_HEMOTHORAX_9888985812399256510: VariantsMap = [
    &["hemothorax"],
    &["haemothorax"],
    &["haemothorax"],
    &["haemothorax"],
];

pub(crate) static ENTRY_HEMOTOXIC_15421781554160520339: VariantsMap = [
    &["hemotoxic"],
    &["haemotoxic"],
    &["haemotoxic"],
    &["haemotoxic"],
];

pub(crate) static ENTRY_HEMOTOXIN_15634750057214615777: VariantsMap = [
    &["hemotoxin"],
    &["haemotoxin"],
    &["haemotoxin"],
    &["haemotoxin"],
];

pub(crate) static ENTRY_HEPARINIZE_825464359295045447: VariantsMap = [
    &["heparinize"],
    &["heparinise"],
    &["heparinize"],
    &["heparinise"],
];

pub(crate) static ENTRY_HEPATIZATIONS_9429604348465734291: VariantsMap = [
    &["hepatizations"],
    &["hepatisations"],
    &["hepatizations"],
    &["hepatisations"],
];

pub(crate) static ENTRY_HEPATIZATION_18188813903715470881: VariantsMap = [
    &["hepatization"],
    &["hepatisation"],
    &["hepatization"],
    &["hepatisation"],
];

pub(crate) static ENTRY_HEPATIZED_16132157599205450670: VariantsMap = [
    &["hepatized"],
    &["hepatised"],
    &["hepatized"],
    &["hepatised"],
];

pub(crate) static ENTRY_HEPATIZES_13438718625424032453: VariantsMap = [
    &["hepatizes"],
    &["hepatises"],
    &["hepatizes"],
    &["hepatises"],
];

pub(crate) static ENTRY_HEPATIZE_9537992825882517878: VariantsMap =
    [&["hepatize"], &["hepatise"], &["hepatize"], &["hepatise"]];

pub(crate) static ENTRY_HEPATIZING_17190565875897655918: VariantsMap = [
    &["hepatizing"],
    &["hepatising"],
    &["hepatizing"],
    &["hepatising"],
];

pub(crate) static ENTRY_HEPATORRHEA_33783066209687899: VariantsMap = [
    &["hepatorrhea"],
    &["hepatorrhoea"],
    &["hepatorrhoea"],
    &["hepatorrhoea"],
];

pub(crate) static ENTRY_HERALDIZES_3427011486777293121: VariantsMap = [
    &["heraldizes"],
    &["heraldises"],
    &["heraldizes"],
    &["heraldises"],
];

pub(crate) static ENTRY_HERALDIZE_13245151934087390658: VariantsMap = [
    &["heraldize"],
    &["heraldise"],
    &["heraldize"],
    &["heraldise"],
];

pub(crate) static ENTRY_HERBORIZATIONS_3220427015154511891: VariantsMap = [
    &["herborizations"],
    &["herborisations"],
    &["herborizations"],
    &["herborisations"],
];

pub(crate) static ENTRY_HERBORIZATION_2180699383757200505: VariantsMap = [
    &["herborization"],
    &["herborisation"],
    &["herborization"],
    &["herborisation"],
];

pub(crate) static ENTRY_HERBORIZED_1986245296299390128: VariantsMap = [
    &["herborized"],
    &["herborised"],
    &["herborized"],
    &["herborised"],
];

pub(crate) static ENTRY_HERBORIZES_18049858840826246838: VariantsMap = [
    &["herborizes"],
    &["herborises"],
    &["herborizes"],
    &["herborises"],
];

pub(crate) static ENTRY_HERBORIZE_9236267314777430141: VariantsMap = [
    &["herborize"],
    &["herborise"],
    &["herborize"],
    &["herborise"],
];

pub(crate) static ENTRY_HERBORIZING_14418490249039027873: VariantsMap = [
    &["herborizing"],
    &["herborising"],
    &["herborizing"],
    &["herborising"],
];

pub(crate) static ENTRY_HEREDES_12466213351118710275: VariantsMap =
    [&["heredes"], &["haeredes"], &["haeredes"], &["haeredes"]];

pub(crate) static ENTRY_HERETICIZES_2989278302591587100: VariantsMap = [
    &["hereticizes"],
    &["hereticises"],
    &["hereticizes"],
    &["hereticises"],
];

pub(crate) static ENTRY_HERETICIZE_9737734736005533859: VariantsMap = [
    &["hereticize"],
    &["hereticise"],
    &["hereticize"],
    &["hereticise"],
];

pub(crate) static ENTRY_HEROINIZES_530036718996538373: VariantsMap = [
    &["heroinizes"],
    &["heroinises"],
    &["heroinizes"],
    &["heroinises"],
];

pub(crate) static ENTRY_HEROINIZE_7929779025273191656: VariantsMap = [
    &["heroinize"],
    &["heroinise"],
    &["heroinize"],
    &["heroinise"],
];

pub(crate) static ENTRY_HEROIZATIONS_17938260117292724826: VariantsMap = [
    &["heroizations"],
    &["heroisations"],
    &["heroizations"],
    &["heroisations"],
];

pub(crate) static ENTRY_HEROIZATION_13271943150165407572: VariantsMap = [
    &["heroization"],
    &["heroisation"],
    &["heroization"],
    &["heroisation"],
];

pub(crate) static ENTRY_HEROIZED_12288505910391777346: VariantsMap =
    [&["heroized"], &["heroised"], &["heroized"], &["heroised"]];

pub(crate) static ENTRY_HEROIZES_18377738024677746144: VariantsMap =
    [&["heroizes"], &["heroises"], &["heroizes"], &["heroises"]];

pub(crate) static ENTRY_HEROIZE_209937210303349791: VariantsMap =
    [&["heroize"], &["heroise"], &["heroize"], &["heroise"]];

pub(crate) static ENTRY_HEROIZING_15459599585497422378: VariantsMap = [
    &["heroizing"],
    &["heroising"],
    &["heroizing"],
    &["heroising"],
];

pub(crate) static ENTRY_HETERECIOUS_528818645302753522: VariantsMap = [
    &["heterecious"],
    &["heteroecious"],
    &["heteroecious"],
    &["heteroecious"],
];

pub(crate) static ENTRY_HETERIC_14927082686103953595: VariantsMap =
    [&["heteric"], &["hetaeric"], &["hetaeric"], &["hetaeric"]];

pub(crate) static ENTRY_HETERISM_629753888071252179: VariantsMap = [
    &["heterism"],
    &["hetaerism"],
    &["hetaerism"],
    &["hetaerism"],
];

pub(crate) static ENTRY_HETS_6749474741457650714: VariantsMap =
    [&["hets"], &["haets"], &["haets"], &["haets"]];

pub(crate) static ENTRY_HET_10103159752309740785: VariantsMap =
    [&["het"], &["haet"], &["haet"], &["haet"]];

pub(crate) static ENTRY_HEXACHLORETHANES_2079345014326674767: VariantsMap = [
    &["hexachlorethanes"],
    &["hexachloroethanes"],
    &["hexachloroethanes"],
    &["hexachloroethanes"],
];

pub(crate) static ENTRY_HEXACHLORETHANE_11021447419541267943: VariantsMap = [
    &["hexachlorethane"],
    &["hexachloroethane"],
    &["hexachloroethane"],
    &["hexachloroethane"],
];

pub(crate) static ENTRY_HEXAMETRIZED_3185164622729779957: VariantsMap = [
    &["hexametrized"],
    &["hexametrised"],
    &["hexametrized"],
    &["hexametrised"],
];

pub(crate) static ENTRY_HEXAMETRIZES_12751554074248898767: VariantsMap = [
    &["hexametrizes"],
    &["hexametrises"],
    &["hexametrizes"],
    &["hexametrises"],
];

pub(crate) static ENTRY_HEXAMETRIZE_14699250639166930630: VariantsMap = [
    &["hexametrize"],
    &["hexametrise"],
    &["hexametrize"],
    &["hexametrise"],
];

pub(crate) static ENTRY_HEXAMETRIZING_2426175730535979568: VariantsMap = [
    &["hexametrizing"],
    &["hexametrising"],
    &["hexametrizing"],
    &["hexametrising"],
];

pub(crate) static ENTRY_HEXESTROL_3904723358075993454: VariantsMap = [
    &["hexestrol"],
    &["hexoestrol"],
    &["hexoestrol"],
    &["hexoestrol"],
];

pub(crate) static ENTRY_HIBERNICIZED_17579936602226206872: VariantsMap = [
    &["hibernicized"],
    &["hibernicised"],
    &["hibernicized"],
    &["hibernicised"],
];

pub(crate) static ENTRY_HIBERNICIZES_4135316136924898775: VariantsMap = [
    &["hibernicizes"],
    &["hibernicises"],
    &["hibernicizes"],
    &["hibernicises"],
];

pub(crate) static ENTRY_HIBERNICIZE_17037881377750107736: VariantsMap = [
    &["hibernicize"],
    &["hibernicise"],
    &["hibernicize"],
    &["hibernicise"],
];

pub(crate) static ENTRY_HIBERNICIZING_14639684283522219260: VariantsMap = [
    &["hibernicizing"],
    &["hibernicising"],
    &["hibernicizing"],
    &["hibernicising"],
];

pub(crate) static ENTRY_HIBERNIZATIONS_2483818890865195275: VariantsMap = [
    &["hibernizations"],
    &["hibernisations"],
    &["hibernizations"],
    &["hibernisations"],
];

pub(crate) static ENTRY_HIBERNIZATION_13137120377558636657: VariantsMap = [
    &["hibernization"],
    &["hibernisation"],
    &["hibernization"],
    &["hibernisation"],
];

pub(crate) static ENTRY_HIBERNIZED_16125091806689100794: VariantsMap = [
    &["hibernized"],
    &["hibernised"],
    &["hibernized"],
    &["hibernised"],
];

pub(crate) static ENTRY_HIBERNIZES_11866751661595811204: VariantsMap = [
    &["hibernizes"],
    &["hibernises"],
    &["hibernizes"],
    &["hibernises"],
];

pub(crate) static ENTRY_HIBERNIZE_1545133711844580221: VariantsMap = [
    &["hibernize"],
    &["hibernise"],
    &["hibernize"],
    &["hibernise"],
];

pub(crate) static ENTRY_HIBERNIZING_9266995601950673715: VariantsMap = [
    &["hibernizing"],
    &["hibernising"],
    &["hibernizing"],
    &["hibernising"],
];

pub(crate) static ENTRY_HICCUPED_16748037414823767847: VariantsMap =
    [&["hiccuped"], &["hiccuped"], &["hiccuped"], &["hiccuped"]];

pub(crate) static ENTRY_HICCUPING_10532915601093689832: VariantsMap = [
    &["hiccuping"],
    &["hiccuping"],
    &["hiccuping"],
    &["hiccuping"],
];

pub(crate) static ENTRY_HIERARCHIZED_2434677209411391895: VariantsMap = [
    &["hierarchized"],
    &["hierarchised"],
    &["hierarchized"],
    &["hierarchised"],
];

pub(crate) static ENTRY_HIERARCHIZE_13167378612173910356: VariantsMap = [
    &["hierarchize"],
    &["hierarchise"],
    &["hierarchize"],
    &["hierarchise"],
];

pub(crate) static ENTRY_HIERARCHIZING_4483130984905685192: VariantsMap = [
    &["hierarchizing"],
    &["hierarchising"],
    &["hierarchizing"],
    &["hierarchising"],
];

pub(crate) static ENTRY_HILLOED_14622198878819481120: VariantsMap =
    [&["hilloed"], &["hilloaed"], &["hilloaed"], &["hilloaed"]];

pub(crate) static ENTRY_HINDUIZED_11895274507413844911: VariantsMap = [
    &["hinduized"],
    &["hinduised"],
    &["hinduized"],
    &["hinduised"],
];

pub(crate) static ENTRY_HINDUIZES_175867203024573544: VariantsMap = [
    &["hinduizes"],
    &["hinduises"],
    &["hinduizes"],
    &["hinduises"],
];

pub(crate) static ENTRY_HINDUIZE_8107305186736185273: VariantsMap =
    [&["hinduize"], &["hinduise"], &["hinduize"], &["hinduise"]];

pub(crate) static ENTRY_HINDUIZING_11790232298515925904: VariantsMap = [
    &["hinduizing"],
    &["hinduising"],
    &["hinduizing"],
    &["hinduising"],
];

pub(crate) static ENTRY_HIRSELED_6428358124306464688: VariantsMap = [
    &["hirseled"],
    &["hirselled"],
    &["hirselled"],
    &["hirselled"],
];

pub(crate) static ENTRY_HIRSELING_3208245182152685788: VariantsMap = [
    &["hirseling"],
    &["hirselling"],
    &["hirselling"],
    &["hirselling"],
];

pub(crate) static ENTRY_HISPANICIZATIONS_10358570653173988410: VariantsMap = [
    &["hispanicizations"],
    &["hispanicisations"],
    &["hispanicizations"],
    &["hispanicisations"],
];

pub(crate) static ENTRY_HISPANICIZATION_16683525730667710346: VariantsMap = [
    &["hispanicization"],
    &["hispanicisation"],
    &["hispanicization"],
    &["hispanicisation"],
];

pub(crate) static ENTRY_HISPANICIZED_12357862745153928252: VariantsMap = [
    &["hispanicized"],
    &["hispanicised"],
    &["hispanicized"],
    &["hispanicised"],
];

pub(crate) static ENTRY_HISPANICIZES_11390009193328514217: VariantsMap = [
    &["hispanicizes"],
    &["hispanicises"],
    &["hispanicizes"],
    &["hispanicises"],
];

pub(crate) static ENTRY_HISPANICIZE_1047337502816548436: VariantsMap = [
    &["hispanicize"],
    &["hispanicise"],
    &["hispanicize"],
    &["hispanicise"],
];

pub(crate) static ENTRY_HISPANICIZING_10297649593265523682: VariantsMap = [
    &["hispanicizing"],
    &["hispanicising"],
    &["hispanicizing"],
    &["hispanicising"],
];

pub(crate) static ENTRY_HISPANIOLIZED_17603705847587336285: VariantsMap = [
    &["hispaniolized"],
    &["hispaniolised"],
    &["hispaniolized"],
    &["hispaniolised"],
];

pub(crate) static ENTRY_HISPANIOLIZES_15865799872959107963: VariantsMap = [
    &["hispaniolizes"],
    &["hispaniolises"],
    &["hispaniolizes"],
    &["hispaniolises"],
];

pub(crate) static ENTRY_HISPANIOLIZE_12040635907161743907: VariantsMap = [
    &["hispaniolize"],
    &["hispaniolise"],
    &["hispaniolize"],
    &["hispaniolise"],
];

pub(crate) static ENTRY_HISPANIOLIZING_14719191412394590748: VariantsMap = [
    &["hispaniolizing"],
    &["hispaniolising"],
    &["hispaniolizing"],
    &["hispaniolising"],
];

pub(crate) static ENTRY_HISTORICIZED_15317036403172319970: VariantsMap = [
    &["historicized"],
    &["historicised"],
    &["historicized"],
    &["historicised"],
];

pub(crate) static ENTRY_HISTORICIZES_9252360923584277113: VariantsMap = [
    &["historicizes"],
    &["historicises"],
    &["historicizes"],
    &["historicises"],
];

pub(crate) static ENTRY_HISTORICIZE_787070662493754066: VariantsMap = [
    &["historicize"],
    &["historicise"],
    &["historicize"],
    &["historicise"],
];

pub(crate) static ENTRY_HISTORICIZING_15546207066252957575: VariantsMap = [
    &["historicizing"],
    &["historicising"],
    &["historicizing"],
    &["historicising"],
];

pub(crate) static ENTRY_HOLLYWOODIZED_13360580927430344074: VariantsMap = [
    &["hollywoodized"],
    &["hollywoodised"],
    &["hollywoodized"],
    &["hollywoodised"],
];

pub(crate) static ENTRY_HOLLYWOODIZES_4459914627860315265: VariantsMap = [
    &["hollywoodizes"],
    &["hollywoodises"],
    &["hollywoodizes"],
    &["hollywoodises"],
];

pub(crate) static ENTRY_HOLLYWOODIZE_4477243734441393330: VariantsMap = [
    &["hollywoodize"],
    &["hollywoodise"],
    &["hollywoodize"],
    &["hollywoodise"],
];

pub(crate) static ENTRY_HOLLYWOODIZING_7888024247300732070: VariantsMap = [
    &["hollywoodizing"],
    &["hollywoodising"],
    &["hollywoodizing"],
    &["hollywoodising"],
];

pub(crate) static ENTRY_HOMEOBLASTIC_6746209829258825772: VariantsMap = [
    &["homeoblastic"],
    &["homeoblastic"],
    &["homeoblastic"],
    &["homeoblastic"],
];

pub(crate) static ENTRY_HOMEOBOX_429210278928517870: VariantsMap =
    [&["homeobox"], &["homeobox"], &["homeobox"], &["homeobox"]];

pub(crate) static ENTRY_HOMEOCHROMATIC_11999475947164180492: VariantsMap = [
    &["homeochromatic"],
    &["homeochromatic"],
    &["homeochromatic"],
    &["homeochromatic"],
];

pub(crate) static ENTRY_HOMEOCHRONOUS_8014923555195616828: VariantsMap = [
    &["homeochronous"],
    &["homeochronous"],
    &["homeochronous"],
    &["homeochronous"],
];

pub(crate) static ENTRY_HOMEOCRYSTALLINE_16924542982654673284: VariantsMap = [
    &["homeocrystalline"],
    &["homeocrystalline"],
    &["homeocrystalline"],
    &["homeocrystalline"],
];

pub(crate) static ENTRY_HOMEOGENIC_9645370346333050697: VariantsMap = [
    &["homeogenic"],
    &["homeogenic"],
    &["homeogenic"],
    &["homeogenic"],
];

pub(crate) static ENTRY_HOMEOGENOUS_14853646215868318087: VariantsMap = [
    &["homeogenous"],
    &["homeogenous"],
    &["homeogenous"],
    &["homeogenous"],
];

pub(crate) static ENTRY_HOMEOID_1872912226240221334: VariantsMap =
    [&["homeoid"], &["homeoid"], &["homeoid"], &["homeoid"]];

pub(crate) static ENTRY_HOMEOKINESIS_6170969351054020797: VariantsMap = [
    &["homeokinesis"],
    &["homeokinesis"],
    &["homeokinesis"],
    &["homeokinesis"],
];

pub(crate) static ENTRY_HOMEOMERIC_3398859861466283325: VariantsMap = [
    &["homeomeric"],
    &["homeomeric"],
    &["homeomeric"],
    &["homeomeric"],
];

pub(crate) static ENTRY_HOMEOMERIES_11379170224465058869: VariantsMap = [
    &["homeomeries"],
    &["homeomeries"],
    &["homeomeries"],
    &["homeomeries"],
];

pub(crate) static ENTRY_HOMEOMEROUS_6218438835083612194: VariantsMap = [
    &["homeomerous"],
    &["homeomerous"],
    &["homeomerous"],
    &["homeomerous"],
];

pub(crate) static ENTRY_HOMEOMERY_5639570395337974043: VariantsMap = [
    &["homeomery"],
    &["homeomery"],
    &["homeomery"],
    &["homeomery"],
];

pub(crate) static ENTRY_HOMEOMORPHIC_1948628429205039039: VariantsMap = [
    &["homeomorphic"],
    &["homeomorphic"],
    &["homeomorphic"],
    &["homeomorphic"],
];

pub(crate) static ENTRY_HOMEOMORPHIES_14622240917714789970: VariantsMap = [
    &["homeomorphies"],
    &["homeomorphies"],
    &["homeomorphies"],
    &["homeomorphies"],
];

pub(crate) static ENTRY_HOMEOMORPHOUS_13335878237289387669: VariantsMap = [
    &["homeomorphous"],
    &["homeomorphous"],
    &["homeomorphous"],
    &["homeomorphous"],
];

pub(crate) static ENTRY_HOMEOMORPHS_16100106052531760213: VariantsMap = [
    &["homeomorphs"],
    &["homeomorphs"],
    &["homeomorphs"],
    &["homeomorphs"],
];

pub(crate) static ENTRY_HOMEOMORPHY_8107825719716227576: VariantsMap = [
    &["homeomorphy"],
    &["homeomorphy"],
    &["homeomorphy"],
    &["homeomorphy"],
];

pub(crate) static ENTRY_HOMEOMORPH_84773973062870875: VariantsMap = [
    &["homeomorph"],
    &["homeomorph"],
    &["homeomorph"],
    &["homeomorph"],
];

pub(crate) static ENTRY_HOMEOPATHICALLIER_1906322964795778344: VariantsMap = [
    &["homeopathicallier"],
    &["homeopathicallier"],
    &["homeopathicallier"],
    &["homeopathicallier"],
];

pub(crate) static ENTRY_HOMEOPATHICALLIEST_17712966541260034812: VariantsMap = [
    &["homeopathicalliest"],
    &["homeopathicalliest"],
    &["homeopathicalliest"],
    &["homeopathicalliest"],
];

pub(crate) static ENTRY_HOMEOPATHICALLY_14527514477064061578: VariantsMap = [
    &["homeopathically"],
    &["homeopathically"],
    &["homeopathically"],
    &["homeopathically"],
];

pub(crate) static ENTRY_HOMEOPATHICER_8555062855537875022: VariantsMap = [
    &["homeopathicer"],
    &["homeopathicer"],
    &["homeopathicer"],
    &["homeopathicer"],
];

pub(crate) static ENTRY_HOMEOPATHICEST_7501604706728812827: VariantsMap = [
    &["homeopathicest"],
    &["homeopathicest"],
    &["homeopathicest"],
    &["homeopathicest"],
];

pub(crate) static ENTRY_HOMEOPATHICIAN_20367417011957025: VariantsMap = [
    &["homeopathician"],
    &["homeopathician"],
    &["homeopathician"],
    &["homeopathician"],
];

pub(crate) static ENTRY_HOMEOPATHICITY_7965137265585164533: VariantsMap = [
    &["homeopathicity"],
    &["homeopathicity"],
    &["homeopathicity"],
    &["homeopathicity"],
];

pub(crate) static ENTRY_HOMEOPATHIC_2595837653280609646: VariantsMap = [
    &["homeopathic"],
    &["homeopathic"],
    &["homeopathic"],
    &["homeopathic"],
];

pub(crate) static ENTRY_HOMEOPATHIES_6130111446071821583: VariantsMap = [
    &["homeopathies"],
    &["homeopathies"],
    &["homeopathies"],
    &["homeopathies"],
];

pub(crate) static ENTRY_HOMEOPATHISTS_7529185235165580015: VariantsMap = [
    &["homeopathists"],
    &["homeopathists"],
    &["homeopathists"],
    &["homeopathists"],
];

pub(crate) static ENTRY_HOMEOPATHIST_13588025674470919172: VariantsMap = [
    &["homeopathist"],
    &["homeopathist"],
    &["homeopathist"],
    &["homeopathist"],
];

pub(crate) static ENTRY_HOMEOPATHS_11980413245885940279: VariantsMap = [
    &["homeopaths"],
    &["homeopaths"],
    &["homeopaths"],
    &["homeopaths"],
];

pub(crate) static ENTRY_HOMEOPATHY_15227637772904556345: VariantsMap = [
    &["homeopathy"],
    &["homeopathy"],
    &["homeopathy"],
    &["homeopathy"],
];

pub(crate) static ENTRY_HOMEOPATH_8050958568587536315: VariantsMap = [
    &["homeopath"],
    &["homeopath"],
    &["homeopath"],
    &["homeopath"],
];

pub(crate) static ENTRY_HOMEOPHONY_9154734443919559444: VariantsMap = [
    &["homeophony"],
    &["homeophony"],
    &["homeophony"],
    &["homeophony"],
];

pub(crate) static ENTRY_HOMEOPLASIA_3059803871019512419: VariantsMap = [
    &["homeoplasia"],
    &["homeoplasia"],
    &["homeoplasia"],
    &["homeoplasia"],
];

pub(crate) static ENTRY_HOMEOPLASTIC_17893015370456211967: VariantsMap = [
    &["homeoplastic"],
    &["homeoplastic"],
    &["homeoplastic"],
    &["homeoplastic"],
];

pub(crate) static ENTRY_HOMEOPLASY_4819557973925456326: VariantsMap = [
    &["homeoplasy"],
    &["homeoplasy"],
    &["homeoplasy"],
    &["homeoplasy"],
];

pub(crate) static ENTRY_HOMEOPOLAR_3145512571186875572: VariantsMap = [
    &["homeopolar"],
    &["homeopolar"],
    &["homeopolar"],
    &["homeopolar"],
];

pub(crate) static ENTRY_HOMEOSES_303789675254329178: VariantsMap =
    [&["homeoses"], &["homeoses"], &["homeoses"], &["homeoses"]];

pub(crate) static ENTRY_HOMEOSIS_11588213019930111450: VariantsMap =
    [&["homeosis"], &["homeosis"], &["homeosis"], &["homeosis"]];

pub(crate) static ENTRY_HOMEOSTASES_5173714139377093881: VariantsMap = [
    &["homeostases"],
    &["homeostases"],
    &["homeostases"],
    &["homeostases"],
];

pub(crate) static ENTRY_HOMEOSTASIS_4138793109351981017: VariantsMap = [
    &["homeostasis"],
    &["homeostasis"],
    &["homeostasis"],
    &["homeostasis"],
];

pub(crate) static ENTRY_HOMEOSTATIC_8960257562201062527: VariantsMap = [
    &["homeostatic"],
    &["homeostatic"],
    &["homeostatic"],
    &["homeostatic"],
];

pub(crate) static ENTRY_HOMEOTELEUTONS_4791090930087046081: VariantsMap = [
    &["homeoteleutons"],
    &["homeoteleutons"],
    &["homeoteleutons"],
    &["homeoteleutons"],
];

pub(crate) static ENTRY_HOMEOTELEUTON_16219979521219347957: VariantsMap = [
    &["homeoteleuton"],
    &["homeoteleuton"],
    &["homeoteleuton"],
    &["homeoteleuton"],
];

pub(crate) static ENTRY_HOMEOTHERMAL_12106163977771685441: VariantsMap = [
    &["homeothermal"],
    &["homeothermal"],
    &["homeothermal"],
    &["homeothermal"],
];

pub(crate) static ENTRY_HOMEOTHERMIC_3531598803017384948: VariantsMap = [
    &["homeothermic"],
    &["homeothermic"],
    &["homeothermic"],
    &["homeothermic"],
];

pub(crate) static ENTRY_HOMEOTHERMOUS_15284024759127648929: VariantsMap = [
    &["homeothermous"],
    &["homeothermous"],
    &["homeothermous"],
    &["homeothermous"],
];

pub(crate) static ENTRY_HOMEOTIC_7762310538628691725: VariantsMap =
    [&["homeotic"], &["homeotic"], &["homeotic"], &["homeotic"]];

pub(crate) static ENTRY_HOMEOTYPE_14898446616858101857: VariantsMap = [
    &["homeotype"],
    &["homeotype"],
    &["homeotype"],
    &["homeotype"],
];

pub(crate) static ENTRY_HOMEOTYPICAL_2867923706738058619: VariantsMap = [
    &["homeotypical"],
    &["homeotypical"],
    &["homeotypical"],
    &["homeotypical"],
];

pub(crate) static ENTRY_HOMEOTYPIC_16234822496573387731: VariantsMap = [
    &["homeotypic"],
    &["homeotypic"],
    &["homeotypic"],
    &["homeotypic"],
];

pub(crate) static ENTRY_HOMEOZOIC_10691139051307473852: VariantsMap = [
    &["homeozoic"],
    &["homeozoic"],
    &["homeozoic"],
    &["homeozoic"],
];

pub(crate) static ENTRY_HOMINIZATION_15453871557875181149: VariantsMap = [
    &["hominization"],
    &["hominisation"],
    &["hominization"],
    &["hominisation"],
];

pub(crate) static ENTRY_HOMINIZED_1937428321671242913: VariantsMap = [
    &["hominized"],
    &["hominised"],
    &["hominized"],
    &["hominised"],
];

pub(crate) static ENTRY_HOMOGENIZATIONS_6507363217080422658: VariantsMap = [
    &["homogenizations"],
    &["homogenisations"],
    &["homogenizations"],
    &["homogenisations"],
];

pub(crate) static ENTRY_HOMOGENIZATION_4656356242119525138: VariantsMap = [
    &["homogenization"],
    &["homogenisation"],
    &["homogenization"],
    &["homogenisation"],
];

pub(crate) static ENTRY_HOMOGENIZED_18397765472405266148: VariantsMap = [
    &["homogenized"],
    &["homogenised"],
    &["homogenized"],
    &["homogenised"],
];

pub(crate) static ENTRY_HOMOGENIZERS_10980385487255230065: VariantsMap = [
    &["homogenizers"],
    &["homogenisers"],
    &["homogenizers"],
    &["homogenisers"],
];

pub(crate) static ENTRY_HOMOGENIZER_6996925915876051690: VariantsMap = [
    &["homogenizer"],
    &["homogeniser"],
    &["homogenizer"],
    &["homogeniser"],
];

pub(crate) static ENTRY_HOMOGENIZES_8369010059050295552: VariantsMap = [
    &["homogenizes"],
    &["homogenises"],
    &["homogenizes"],
    &["homogenises"],
];

pub(crate) static ENTRY_HOMOGENIZE_7151746964336550590: VariantsMap = [
    &["homogenize"],
    &["homogenise"],
    &["homogenize"],
    &["homogenise"],
];

pub(crate) static ENTRY_HOMOGENIZING_14283963830585886911: VariantsMap = [
    &["homogenizing"],
    &["homogenising"],
    &["homogenizing"],
    &["homogenising"],
];

pub(crate) static ENTRY_HOMOLOGIZATION_2821144199023611743: VariantsMap = [
    &["homologization"],
    &["homologisation"],
    &["homologization"],
    &["homologisation"],
];

pub(crate) static ENTRY_HOMOLOGIZED_11005543793325536942: VariantsMap = [
    &["homologized"],
    &["homologised"],
    &["homologized"],
    &["homologised"],
];

pub(crate) static ENTRY_HOMOLOGIZERS_5981615810035626144: VariantsMap = [
    &["homologizers"],
    &["homologisers"],
    &["homologizers"],
    &["homologisers"],
];

pub(crate) static ENTRY_HOMOLOGIZER_7601894071386003883: VariantsMap = [
    &["homologizer"],
    &["homologiser"],
    &["homologizer"],
    &["homologiser"],
];

pub(crate) static ENTRY_HOMOLOGIZES_9606957905590841740: VariantsMap = [
    &["homologizes"],
    &["homologises"],
    &["homologizes"],
    &["homologises"],
];

pub(crate) static ENTRY_HOMOLOGIZE_16692911359990964362: VariantsMap = [
    &["homologize"],
    &["homologise"],
    &["homologize"],
    &["homologise"],
];

pub(crate) static ENTRY_HOMOLOGIZING_5163950846513087370: VariantsMap = [
    &["homologizing"],
    &["homologising"],
    &["homologizing"],
    &["homologising"],
];

pub(crate) static ENTRY_HOMOLOGUES_13017718427263208887: VariantsMap = [
    &["homologues"],
    &["homologues"],
    &["homologues"],
    &["homologues"],
];

pub(crate) static ENTRY_HOMOLOGUE_12262727764635293494: VariantsMap = [
    &["homologue"],
    &["homologue"],
    &["homologue"],
    &["homologue"],
];

pub(crate) static ENTRY_HONORABILITIES_17692403882040438215: VariantsMap = [
    &["honorabilities"],
    &["honourabilities"],
    &["honourabilities"],
    &["honourabilities"],
];

pub(crate) static ENTRY_HONORABILITY_12580589027472191611: VariantsMap = [
    &["honorability"],
    &["honourability"],
    &["honourability"],
    &["honourability"],
];

pub(crate) static ENTRY_HONORABLENESSES_5348711556750177695: VariantsMap = [
    &["honorablenesses"],
    &["honourablenesses"],
    &["honourablenesses"],
    &["honourablenesses"],
];

pub(crate) static ENTRY_HONORABLENESS_11259768724529598124: VariantsMap = [
    &["honorableness"],
    &["honourableness"],
    &["honourableness"],
    &["honourableness"],
];

pub(crate) static ENTRY_HONORABLER_1697067400290285301: VariantsMap = [
    &["honorabler"],
    &["honourabler"],
    &["honourabler"],
    &["honourabler"],
];

pub(crate) static ENTRY_HONORABLESHIPS_17263052691602698851: VariantsMap = [
    &["honorableships"],
    &["honourableships"],
    &["honourableships"],
    &["honourableships"],
];

pub(crate) static ENTRY_HONORABLESHIP_16239512951229580872: VariantsMap = [
    &["honorableship"],
    &["honourableship"],
    &["honourableship"],
    &["honourableship"],
];

pub(crate) static ENTRY_HONORABLEST_11244773893570663300: VariantsMap = [
    &["honorablest"],
    &["honourablest"],
    &["honourablest"],
    &["honourablest"],
];

pub(crate) static ENTRY_HONORABLES_2913554671346259853: VariantsMap = [
    &["honorables"],
    &["honourables"],
    &["honourables"],
    &["honourables"],
];

pub(crate) static ENTRY_HONORABLE_16346079154255994276: VariantsMap = [
    &["honorable"],
    &["honourable"],
    &["honourable"],
    &["honourable"],
];

pub(crate) static ENTRY_HONORABLIER_6904513272854009789: VariantsMap = [
    &["honorablier"],
    &["honourablier"],
    &["honourablier"],
    &["honourablier"],
];

pub(crate) static ENTRY_HONORABLIEST_11197357664137213595: VariantsMap = [
    &["honorabliest"],
    &["honourabliest"],
    &["honourabliest"],
    &["honourabliest"],
];

pub(crate) static ENTRY_HONORABLIES_12203013003442305559: VariantsMap = [
    &["honorablies"],
    &["honourablies"],
    &["honourablies"],
    &["honourablies"],
];

pub(crate) static ENTRY_HONORABLY_17038293500649165869: VariantsMap = [
    &["honorably"],
    &["honourably"],
    &["honourably"],
    &["honourably"],
];

pub(crate) static ENTRY_HONORED_16057015610203465375: VariantsMap =
    [&["honored"], &["honoured"], &["honoured"], &["honoured"]];

pub(crate) static ENTRY_HONOREES_18235412860085516031: VariantsMap = [
    &["honorees"],
    &["honourees"],
    &["honourees"],
    &["honourees"],
];

pub(crate) static ENTRY_HONOREE_16211612529520124524: VariantsMap =
    [&["honoree"], &["honouree"], &["honouree"], &["honouree"]];

pub(crate) static ENTRY_HONORERS_6333132769292360884: VariantsMap = [
    &["honorers"],
    &["honourers"],
    &["honourers"],
    &["honourers"],
];

pub(crate) static ENTRY_HONORER_1852924574530689208: VariantsMap =
    [&["honorer"], &["honourer"], &["honourer"], &["honourer"]];

pub(crate) static ENTRY_HONORING_6077083205656592738: VariantsMap = [
    &["honoring"],
    &["honouring"],
    &["honouring"],
    &["honouring"],
];

pub(crate) static ENTRY_HONORLESSER_8961804267410442314: VariantsMap = [
    &["honorlesser"],
    &["honourlesser"],
    &["honourlesser"],
    &["honourlesser"],
];

pub(crate) static ENTRY_HONORLESSEST_8580952947078616611: VariantsMap = [
    &["honorlessest"],
    &["honourlessest"],
    &["honourlessest"],
    &["honourlessest"],
];

pub(crate) static ENTRY_HONORLESSES_18009355419310607858: VariantsMap = [
    &["honorlesses"],
    &["honourlesses"],
    &["honourlesses"],
    &["honourlesses"],
];

pub(crate) static ENTRY_HONORLESS_5387528221786719947: VariantsMap = [
    &["honorless"],
    &["honourless"],
    &["honourless"],
    &["honourless"],
];

pub(crate) static ENTRY_HONORS_13638393746809061853: VariantsMap =
    [&["honors"], &["honours"], &["honours"], &["honours"]];

pub(crate) static ENTRY_HONOR_12284245170176182479: VariantsMap =
    [&["honor"], &["honour"], &["honour"], &["honour"]];

pub(crate) static ENTRY_HOODLUMIZES_2337314049834401492: VariantsMap = [
    &["hoodlumizes"],
    &["hoodlumises"],
    &["hoodlumizes"],
    &["hoodlumises"],
];

pub(crate) static ENTRY_HOODLUMIZE_1988199326490657618: VariantsMap = [
    &["hoodlumize"],
    &["hoodlumise"],
    &["hoodlumize"],
    &["hoodlumise"],
];

pub(crate) static ENTRY_HOOLIGANIZES_10378468821053779568: VariantsMap = [
    &["hooliganizes"],
    &["hooliganises"],
    &["hooliganizes"],
    &["hooliganises"],
];

pub(crate) static ENTRY_HOOLIGANIZE_17119619341142584244: VariantsMap = [
    &["hooliganize"],
    &["hooliganise"],
    &["hooliganize"],
    &["hooliganise"],
];

pub(crate) static ENTRY_HOOSIERIZES_3096818361317634282: VariantsMap = [
    &["hoosierizes"],
    &["hoosierises"],
    &["hoosierizes"],
    &["hoosierises"],
];

pub(crate) static ENTRY_HOOSIERIZE_1491277666553366678: VariantsMap = [
    &["hoosierize"],
    &["hoosierise"],
    &["hoosierize"],
    &["hoosierise"],
];

pub(crate) static ENTRY_HOOVERIZES_11190309671847930638: VariantsMap = [
    &["hooverizes"],
    &["hooverises"],
    &["hooverizes"],
    &["hooverises"],
];

pub(crate) static ENTRY_HOOVERIZE_12514395268479045206: VariantsMap = [
    &["hooverize"],
    &["hooverise"],
    &["hooverize"],
    &["hooverise"],
];

pub(crate) static ENTRY_HORE_240384164818754909: VariantsMap =
    [&["hore"], &["horae"], &["horae"], &["horae"]];

pub(crate) static ENTRY_HORIZONTALIZATIONS_12341881527322670940: VariantsMap = [
    &["horizontalizations"],
    &["horizontalisations"],
    &["horizontalizations"],
    &["horizontalisations"],
];

pub(crate) static ENTRY_HORIZONTALIZATION_5399738844710518132: VariantsMap = [
    &["horizontalization"],
    &["horizontalisation"],
    &["horizontalization"],
    &["horizontalisation"],
];

pub(crate) static ENTRY_HORIZONTALIZES_7733280569310807502: VariantsMap = [
    &["horizontalizes"],
    &["horizontalises"],
    &["horizontalizes"],
    &["horizontalises"],
];

pub(crate) static ENTRY_HORIZONTALIZE_7528617191591553093: VariantsMap = [
    &["horizontalize"],
    &["horizontalise"],
    &["horizontalize"],
    &["horizontalise"],
];

pub(crate) static ENTRY_HORMONIZES_5178751617646281462: VariantsMap = [
    &["hormonizes"],
    &["hormonises"],
    &["hormonizes"],
    &["hormonises"],
];

pub(crate) static ENTRY_HORMONIZE_16402712449126296970: VariantsMap = [
    &["hormonize"],
    &["hormonise"],
    &["hormonize"],
    &["hormonise"],
];

pub(crate) static ENTRY_HORRORIZES_17965582474215827942: VariantsMap = [
    &["horrorizes"],
    &["horrorises"],
    &["horrorizes"],
    &["horrorises"],
];

pub(crate) static ENTRY_HORRORIZE_1721568873445513652: VariantsMap = [
    &["horrorize"],
    &["horrorise"],
    &["horrorize"],
    &["horrorise"],
];

pub(crate) static ENTRY_HOSPITALIZATIONS_9565778561496260205: VariantsMap = [
    &["hospitalizations"],
    &["hospitalisations"],
    &["hospitalizations"],
    &["hospitalisations"],
];

pub(crate) static ENTRY_HOSPITALIZATION_6876754108770647316: VariantsMap = [
    &["hospitalization"],
    &["hospitalisation"],
    &["hospitalization"],
    &["hospitalisation"],
];

pub(crate) static ENTRY_HOSPITALIZED_14669852566244731121: VariantsMap = [
    &["hospitalized"],
    &["hospitalised"],
    &["hospitalized"],
    &["hospitalised"],
];

pub(crate) static ENTRY_HOSPITALIZES_15004904411392264424: VariantsMap = [
    &["hospitalizes"],
    &["hospitalises"],
    &["hospitalizes"],
    &["hospitalises"],
];

pub(crate) static ENTRY_HOSPITALIZE_6250395622105373650: VariantsMap = [
    &["hospitalize"],
    &["hospitalise"],
    &["hospitalize"],
    &["hospitalise"],
];

pub(crate) static ENTRY_HOSPITALIZING_13736882711613304855: VariantsMap = [
    &["hospitalizing"],
    &["hospitalising"],
    &["hospitalizing"],
    &["hospitalising"],
];

pub(crate) static ENTRY_HOSTILIZES_4822749923344907441: VariantsMap = [
    &["hostilizes"],
    &["hostilises"],
    &["hostilizes"],
    &["hostilises"],
];

pub(crate) static ENTRY_HOSTILIZE_13783071968481819947: VariantsMap = [
    &["hostilize"],
    &["hostilise"],
    &["hostilize"],
    &["hostilise"],
];

pub(crate) static ENTRY_HOTELIZATIONS_6794114000883410377: VariantsMap = [
    &["hotelizations"],
    &["hotelisations"],
    &["hotelizations"],
    &["hotelisations"],
];

pub(crate) static ENTRY_HOTELIZATION_11630362029882906887: VariantsMap = [
    &["hotelization"],
    &["hotelisation"],
    &["hotelization"],
    &["hotelisation"],
];

pub(crate) static ENTRY_HOTELIZES_8836454095068282095: VariantsMap = [
    &["hotelizes"],
    &["hotelises"],
    &["hotelizes"],
    &["hotelises"],
];

pub(crate) static ENTRY_HOTELIZE_10883646870902168688: VariantsMap =
    [&["hotelize"], &["hotelise"], &["hotelize"], &["hotelise"]];

pub(crate) static ENTRY_HOUSELED_11961205696401030035: VariantsMap = [
    &["houseled"],
    &["houselled"],
    &["houselled"],
    &["houselled"],
];

pub(crate) static ENTRY_HOUSELINGS_15578665640776341869: VariantsMap = [
    &["houselings"],
    &["housellings"],
    &["housellings"],
    &["housellings"],
];

pub(crate) static ENTRY_HOUSELING_9033251538610526455: VariantsMap = [
    &["houseling"],
    &["houselling"],
    &["houselling"],
    &["houselling"],
];

pub(crate) static ENTRY_HOVELED_12568330716779771103: VariantsMap =
    [&["hoveled"], &["hovelled"], &["hovelled"], &["hovelled"]];

pub(crate) static ENTRY_HOVELERS_13219825849431143741: VariantsMap = [
    &["hovelers"],
    &["hovellers"],
    &["hovellers"],
    &["hovellers"],
];

pub(crate) static ENTRY_HOVELER_1958268142806831894: VariantsMap =
    [&["hoveler"], &["hoveller"], &["hoveller"], &["hoveller"]];

pub(crate) static ENTRY_HOVELING_7298952268414160735: VariantsMap = [
    &["hoveling"],
    &["hovelling"],
    &["hovelling"],
    &["hovelling"],
];

pub(crate) static ENTRY_HUCKSTERIZES_8268659569338877880: VariantsMap = [
    &["hucksterizes"],
    &["hucksterises"],
    &["hucksterizes"],
    &["hucksterises"],
];

pub(crate) static ENTRY_HUCKSTERIZE_13308151300872354760: VariantsMap = [
    &["hucksterize"],
    &["hucksterise"],
    &["hucksterize"],
    &["hucksterise"],
];

pub(crate) static ENTRY_HUER_14814098217806996597: VariantsMap =
    [&["huer"], &["hure"], &["hure"], &["hure"]];

pub(crate) static ENTRY_HUMANITARIANIZES_18048535083732291734: VariantsMap = [
    &["humanitarianizes"],
    &["humanitarianises"],
    &["humanitarianizes"],
    &["humanitarianises"],
];

pub(crate) static ENTRY_HUMANITARIANIZE_10414962610230588177: VariantsMap = [
    &["humanitarianize"],
    &["humanitarianise"],
    &["humanitarianize"],
    &["humanitarianise"],
];

pub(crate) static ENTRY_HUMANIZATIONS_3865648289532969387: VariantsMap = [
    &["humanizations"],
    &["humanisations"],
    &["humanizations"],
    &["humanisations"],
];

pub(crate) static ENTRY_HUMANIZATION_5830695966920821886: VariantsMap = [
    &["humanization"],
    &["humanisation"],
    &["humanization"],
    &["humanisation"],
];

pub(crate) static ENTRY_HUMANIZED_15704417917952177815: VariantsMap = [
    &["humanized"],
    &["humanised"],
    &["humanized"],
    &["humanised"],
];

pub(crate) static ENTRY_HUMANIZERS_10409227793679563956: VariantsMap = [
    &["humanizers"],
    &["humanisers"],
    &["humanizers"],
    &["humanisers"],
];

pub(crate) static ENTRY_HUMANIZER_12017356498460139218: VariantsMap = [
    &["humanizer"],
    &["humaniser"],
    &["humanizer"],
    &["humaniser"],
];

pub(crate) static ENTRY_HUMANIZES_6273845182070294397: VariantsMap = [
    &["humanizes"],
    &["humanises"],
    &["humanizes"],
    &["humanises"],
];

pub(crate) static ENTRY_HUMANIZE_4044911342190458943: VariantsMap =
    [&["humanize"], &["humanise"], &["humanize"], &["humanise"]];

pub(crate) static ENTRY_HUMANIZING_15664126028277437903: VariantsMap = [
    &["humanizing"],
    &["humanising"],
    &["humanizing"],
    &["humanising"],
];

pub(crate) static ENTRY_HUMORAL_2853760863304111656: VariantsMap =
    [&["humoral"], &["humoral"], &["humoral"], &["humoral"]];

pub(crate) static ENTRY_HUMORED_11087443859021308864: VariantsMap =
    [&["humored"], &["humoured"], &["humoured"], &["humoured"]];

pub(crate) static ENTRY_HUMORERS_11361453604963756719: VariantsMap = [
    &["humorers"],
    &["humourers"],
    &["humourers"],
    &["humourers"],
];

pub(crate) static ENTRY_HUMORER_14321582164268398325: VariantsMap =
    [&["humorer"], &["humourer"], &["humourer"], &["humourer"]];

pub(crate) static ENTRY_HUMORFUL_15115567956635786701: VariantsMap = [
    &["humorful"],
    &["humourful"],
    &["humourful"],
    &["humourful"],
];

pub(crate) static ENTRY_HUMORING_14086332731556696553: VariantsMap = [
    &["humoring"],
    &["humouring"],
    &["humouring"],
    &["humouring"],
];

pub(crate) static ENTRY_HUMORIZES_3167907102560083410: VariantsMap = [
    &["humorizes"],
    &["humorises"],
    &["humorizes"],
    &["humorises"],
];

pub(crate) static ENTRY_HUMORIZE_7965858586505042691: VariantsMap =
    [&["humorize"], &["humorise"], &["humorize"], &["humorise"]];

pub(crate) static ENTRY_HUMORLESSER_16003980549488709473: VariantsMap = [
    &["humorlesser"],
    &["humourlesser"],
    &["humourlesser"],
    &["humourlesser"],
];

pub(crate) static ENTRY_HUMORLESSEST_11446149668669386608: VariantsMap = [
    &["humorlessest"],
    &["humourlessest"],
    &["humourlessest"],
    &["humourlessest"],
];

pub(crate) static ENTRY_HUMORLESSES_370612185245224252: VariantsMap = [
    &["humorlesses"],
    &["humourlesses"],
    &["humourlesses"],
    &["humourlesses"],
];

pub(crate) static ENTRY_HUMORLESSNESSES_17811424853582146815: VariantsMap = [
    &["humorlessnesses"],
    &["humourlessnesses"],
    &["humourlessnesses"],
    &["humourlessnesses"],
];

pub(crate) static ENTRY_HUMORLESSNESS_18219335685205775655: VariantsMap = [
    &["humorlessness"],
    &["humourlessness"],
    &["humourlessness"],
    &["humourlessness"],
];

pub(crate) static ENTRY_HUMORLESS_12186481528337453416: VariantsMap = [
    &["humorless"],
    &["humourless"],
    &["humourless"],
    &["humourless"],
];

pub(crate) static ENTRY_HUMORSOMENESS_10935035806711277523: VariantsMap = [
    &["humorsomeness"],
    &["humoursomeness"],
    &["humoursomeness"],
    &["humoursomeness"],
];

pub(crate) static ENTRY_HUMORSOME_8048377448291557893: VariantsMap = [
    &["humorsome"],
    &["humoursome"],
    &["humoursome"],
    &["humoursome"],
];

pub(crate) static ENTRY_HUMORS_5159689657032296642: VariantsMap =
    [&["humors"], &["humours"], &["humours"], &["humours"]];

pub(crate) static ENTRY_HUMOR_2121063190473553072: VariantsMap =
    [&["humor"], &["humour"], &["humour"], &["humour"]];

pub(crate) static ENTRY_HURRAHS_17087845443906118467: VariantsMap =
    [&["hurrahs"], &["hurrahs"], &["hurrahs"], &["hurrahs"]];

pub(crate) static ENTRY_HURRAH_2302953427822584414: VariantsMap =
    [&["hurrah"], &["hurrah"], &["hurrah"], &["hurrah"]];

pub(crate) static ENTRY_HURRICANIZES_14038183598909771719: VariantsMap = [
    &["hurricanizes"],
    &["hurricanises"],
    &["hurricanizes"],
    &["hurricanises"],
];

pub(crate) static ENTRY_HURRICANIZE_11443075877213865736: VariantsMap = [
    &["hurricanize"],
    &["hurricanise"],
    &["hurricanize"],
    &["hurricanise"],
];

pub(crate) static ENTRY_HYALINIZATIONS_5013187970535765431: VariantsMap = [
    &["hyalinizations"],
    &["hyalinisations"],
    &["hyalinizations"],
    &["hyalinisations"],
];

pub(crate) static ENTRY_HYALINIZATION_7110805105087800464: VariantsMap = [
    &["hyalinization"],
    &["hyalinisation"],
    &["hyalinization"],
    &["hyalinisation"],
];

pub(crate) static ENTRY_HYALINIZED_8648450487385096318: VariantsMap = [
    &["hyalinized"],
    &["hyalinised"],
    &["hyalinized"],
    &["hyalinised"],
];

pub(crate) static ENTRY_HYALINIZES_6068368648603328649: VariantsMap = [
    &["hyalinizes"],
    &["hyalinises"],
    &["hyalinizes"],
    &["hyalinises"],
];

pub(crate) static ENTRY_HYALINIZE_11908495486530243350: VariantsMap = [
    &["hyalinize"],
    &["hyalinise"],
    &["hyalinize"],
    &["hyalinise"],
];

pub(crate) static ENTRY_HYALINIZING_1451919180488822376: VariantsMap = [
    &["hyalinizing"],
    &["hyalinising"],
    &["hyalinizing"],
    &["hyalinising"],
];

pub(crate) static ENTRY_HYBRIDIZABLER_4007040412317588432: VariantsMap = [
    &["hybridizabler"],
    &["hybridisabler"],
    &["hybridizabler"],
    &["hybridisabler"],
];

pub(crate) static ENTRY_HYBRIDIZABLEST_373072217288267910: VariantsMap = [
    &["hybridizablest"],
    &["hybridisablest"],
    &["hybridizablest"],
    &["hybridisablest"],
];

pub(crate) static ENTRY_HYBRIDIZABLES_5241796645102016487: VariantsMap = [
    &["hybridizables"],
    &["hybridisables"],
    &["hybridizables"],
    &["hybridisables"],
];

pub(crate) static ENTRY_HYBRIDIZABLE_10574109574999308410: VariantsMap = [
    &["hybridizable"],
    &["hybridisable"],
    &["hybridizable"],
    &["hybridisable"],
];

pub(crate) static ENTRY_HYBRIDIZATIONS_15165179760111354303: VariantsMap = [
    &["hybridizations"],
    &["hybridisations"],
    &["hybridizations"],
    &["hybridisations"],
];

pub(crate) static ENTRY_HYBRIDIZATION_161986988115386392: VariantsMap = [
    &["hybridization"],
    &["hybridisation"],
    &["hybridization"],
    &["hybridisation"],
];

pub(crate) static ENTRY_HYBRIDIZED_2291718058649708615: VariantsMap = [
    &["hybridized"],
    &["hybridised"],
    &["hybridized"],
    &["hybridised"],
];

pub(crate) static ENTRY_HYBRIDIZERS_13820118558244742035: VariantsMap = [
    &["hybridizers"],
    &["hybridisers"],
    &["hybridizers"],
    &["hybridisers"],
];

pub(crate) static ENTRY_HYBRIDIZER_413649520934854910: VariantsMap = [
    &["hybridizer"],
    &["hybridiser"],
    &["hybridizer"],
    &["hybridiser"],
];

pub(crate) static ENTRY_HYBRIDIZES_47886802934099991: VariantsMap = [
    &["hybridizes"],
    &["hybridises"],
    &["hybridizes"],
    &["hybridises"],
];

pub(crate) static ENTRY_HYBRIDIZE_12739035965572292237: VariantsMap = [
    &["hybridize"],
    &["hybridise"],
    &["hybridize"],
    &["hybridise"],
];

pub(crate) static ENTRY_HYBRIDIZING_17601175295259958488: VariantsMap = [
    &["hybridizing"],
    &["hybridising"],
    &["hybridizing"],
    &["hybridising"],
];

pub(crate) static ENTRY_HYDREMIAS_5705396115596322771: VariantsMap = [
    &["hydremias"],
    &["hydraemias"],
    &["hydraemias"],
    &["hydraemias"],
];

pub(crate) static ENTRY_HYDREMIA_15737604061809105573: VariantsMap = [
    &["hydremia"],
    &["hydraemia"],
    &["hydraemia"],
    &["hydraemia"],
];

pub(crate) static ENTRY_HYDREMIC_7677276768554498277: VariantsMap = [
    &["hydremic"],
    &["hydraemic"],
    &["hydraemic"],
    &["hydraemic"],
];

pub(crate) static ENTRY_HYDROCELE_10742030391066081682: VariantsMap = [
    &["hydrocele"],
    &["hydrocoele"],
    &["hydrocoele"],
    &["hydrocoele"],
];

pub(crate) static ENTRY_HYDROGENIZATIONS_13526938534356803421: VariantsMap = [
    &["hydrogenizations"],
    &["hydrogenisations"],
    &["hydrogenizations"],
    &["hydrogenisations"],
];

pub(crate) static ENTRY_HYDROGENIZATION_1304003273128011350: VariantsMap = [
    &["hydrogenization"],
    &["hydrogenisation"],
    &["hydrogenization"],
    &["hydrogenisation"],
];

pub(crate) static ENTRY_HYDROGENIZED_10274497346817495654: VariantsMap = [
    &["hydrogenized"],
    &["hydrogenised"],
    &["hydrogenized"],
    &["hydrogenised"],
];

pub(crate) static ENTRY_HYDROGENIZES_15414612709209000503: VariantsMap = [
    &["hydrogenizes"],
    &["hydrogenises"],
    &["hydrogenizes"],
    &["hydrogenises"],
];

pub(crate) static ENTRY_HYDROGENIZE_3962922331531856094: VariantsMap = [
    &["hydrogenize"],
    &["hydrogenise"],
    &["hydrogenize"],
    &["hydrogenise"],
];

pub(crate) static ENTRY_HYDROGENIZING_14049891921794212990: VariantsMap = [
    &["hydrogenizing"],
    &["hydrogenising"],
    &["hydrogenizing"],
    &["hydrogenising"],
];

pub(crate) static ENTRY_HYDROLIZE_5796989920616720182: VariantsMap = [
    &["hydrolize"],
    &["hydrolise"],
    &["hydrolize"],
    &["hydrolise"],
];

pub(crate) static ENTRY_HYDROLYZABLER_12427972367765097514: VariantsMap = [
    &["hydrolyzabler"],
    &["hydrolysabler"],
    &["hydrolyzabler"],
    &["hydrolysabler"],
];

pub(crate) static ENTRY_HYDROLYZABLEST_9835789422025315722: VariantsMap = [
    &["hydrolyzablest"],
    &["hydrolysablest"],
    &["hydrolyzablest"],
    &["hydrolysablest"],
];

pub(crate) static ENTRY_HYDROLYZABLES_15919432710942584334: VariantsMap = [
    &["hydrolyzables"],
    &["hydrolysables"],
    &["hydrolyzables"],
    &["hydrolysables"],
];

pub(crate) static ENTRY_HYDROLYZABLE_8991197244785935669: VariantsMap = [
    &["hydrolyzable"],
    &["hydrolysable"],
    &["hydrolyzable"],
    &["hydrolysable"],
];

pub(crate) static ENTRY_HYDROLYZATES_1902626880371868391: VariantsMap = [
    &["hydrolyzates"],
    &["hydrolysates"],
    &["hydrolyzates"],
    &["hydrolysates"],
];

pub(crate) static ENTRY_HYDROLYZATE_7572075944447421858: VariantsMap = [
    &["hydrolyzate"],
    &["hydrolysate"],
    &["hydrolyzate"],
    &["hydrolysate"],
];

pub(crate) static ENTRY_HYDROLYZATION_5046652609416235138: VariantsMap = [
    &["hydrolyzation"],
    &["hydrolysation"],
    &["hydrolyzation"],
    &["hydrolysation"],
];

pub(crate) static ENTRY_HYDROLYZED_3791193711312452932: VariantsMap = [
    &["hydrolyzed"],
    &["hydrolysed"],
    &["hydrolyzed"],
    &["hydrolysed"],
];

pub(crate) static ENTRY_HYDROLYZER_7963252770617082917: VariantsMap = [
    &["hydrolyzer"],
    &["hydrolyser"],
    &["hydrolyzer"],
    &["hydrolyser"],
];

pub(crate) static ENTRY_HYDROLYZES_10792622190037744120: VariantsMap = [
    &["hydrolyzes"],
    &["hydrolyses"],
    &["hydrolyzes"],
    &["hydrolyses"],
];

pub(crate) static ENTRY_HYDROLYZE_14713911854595051121: VariantsMap = [
    &["hydrolyze"],
    &["hydrolyse"],
    &["hydrolyze"],
    &["hydrolyse"],
];

pub(crate) static ENTRY_HYDROLYZING_12759236550275710849: VariantsMap = [
    &["hydrolyzing"],
    &["hydrolysing"],
    &["hydrolyzing"],
    &["hydrolysing"],
];

pub(crate) static ENTRY_HYDRORRHEA_14755418364154758097: VariantsMap = [
    &["hydrorrhea"],
    &["hydrorrhoea"],
    &["hydrorrhoea"],
    &["hydrorrhoea"],
];

pub(crate) static ENTRY_HYDROXYLIZATIONS_9323455027499464587: VariantsMap = [
    &["hydroxylizations"],
    &["hydroxylisations"],
    &["hydroxylizations"],
    &["hydroxylisations"],
];

pub(crate) static ENTRY_HYDROXYLIZATION_11144096051800167199: VariantsMap = [
    &["hydroxylization"],
    &["hydroxylisation"],
    &["hydroxylization"],
    &["hydroxylisation"],
];

pub(crate) static ENTRY_HYDROXYLIZES_11433886242354117839: VariantsMap = [
    &["hydroxylizes"],
    &["hydroxylises"],
    &["hydroxylizes"],
    &["hydroxylises"],
];

pub(crate) static ENTRY_HYDROXYLIZE_6225544713210248934: VariantsMap = [
    &["hydroxylize"],
    &["hydroxylise"],
    &["hydroxylize"],
    &["hydroxylise"],
];

pub(crate) static ENTRY_HYENIC_15051336625087668416: VariantsMap =
    [&["hyenic"], &["hyaenic"], &["hyaenic"], &["hyaenic"]];

pub(crate) static ENTRY_HYGIENIZATIONS_6338160659202170314: VariantsMap = [
    &["hygienizations"],
    &["hygienisations"],
    &["hygienizations"],
    &["hygienisations"],
];

pub(crate) static ENTRY_HYGIENIZATION_625023551255960285: VariantsMap = [
    &["hygienization"],
    &["hygienisation"],
    &["hygienization"],
    &["hygienisation"],
];

pub(crate) static ENTRY_HYGIENIZES_17832600989781813895: VariantsMap = [
    &["hygienizes"],
    &["hygienises"],
    &["hygienizes"],
    &["hygienises"],
];

pub(crate) static ENTRY_HYGIENIZE_12397245127353122790: VariantsMap = [
    &["hygienize"],
    &["hygienise"],
    &["hygienize"],
    &["hygienise"],
];

pub(crate) static ENTRY_HYMENEAN_13932552305346136403: VariantsMap = [
    &["hymenean"],
    &["hymenaean"],
    &["hymenaean"],
    &["hymenaean"],
];

pub(crate) static ENTRY_HYPERBOLIZED_411978819565944419: VariantsMap = [
    &["hyperbolized"],
    &["hyperbolised"],
    &["hyperbolized"],
    &["hyperbolised"],
];

pub(crate) static ENTRY_HYPERBOLIZES_10753409068722265798: VariantsMap = [
    &["hyperbolizes"],
    &["hyperbolises"],
    &["hyperbolizes"],
    &["hyperbolises"],
];

pub(crate) static ENTRY_HYPERBOLIZE_17992431734514947864: VariantsMap = [
    &["hyperbolize"],
    &["hyperbolise"],
    &["hyperbolize"],
    &["hyperbolise"],
];

pub(crate) static ENTRY_HYPERBOLIZING_9551617205341066643: VariantsMap = [
    &["hyperbolizing"],
    &["hyperbolising"],
    &["hyperbolizing"],
    &["hyperbolising"],
];

pub(crate) static ENTRY_HYPERCALCEMIAS_11134033661726779455: VariantsMap = [
    &["hypercalcemias"],
    &["hypercalcaemias"],
    &["hypercalcaemias"],
    &["hypercalcaemias"],
];

pub(crate) static ENTRY_HYPERCALCEMIA_11420824230101269161: VariantsMap = [
    &["hypercalcemia"],
    &["hypercalcaemia"],
    &["hypercalcaemia"],
    &["hypercalcaemia"],
];

pub(crate) static ENTRY_HYPERCALCINEMIA_8023103474709621904: VariantsMap = [
    &["hypercalcinemia"],
    &["hypercalcinaemia"],
    &["hypercalcinaemia"],
    &["hypercalcinaemia"],
];

pub(crate) static ENTRY_HYPERCATHARSISES_2379400235584935479: VariantsMap = [
    &["hypercatharsises"],
    &["hypercatharses"],
    &["hypercatharses"],
    &["hypercatharses"],
];

pub(crate) static ENTRY_HYPERCHLOREMIA_7441395776225879415: VariantsMap = [
    &["hyperchloremia"],
    &["hyperchloraemia"],
    &["hyperchloraemia"],
    &["hyperchloraemia"],
];

pub(crate) static ENTRY_HYPERCHOLESTEROLEMIAS_10902398019851674783: VariantsMap = [
    &["hypercholesterolemias"],
    &["hypercholesterolaemias"],
    &["hypercholesterolaemias"],
    &["hypercholesterolaemias"],
];

pub(crate) static ENTRY_HYPERCHOLESTEROLEMIA_3478964180569604143: VariantsMap = [
    &["hypercholesterolemia"],
    &["hypercholesterolaemia"],
    &["hypercholesterolaemia"],
    &["hypercholesterolaemia"],
];

pub(crate) static ENTRY_HYPERCIVILIZATIONS_15211543891339482443: VariantsMap = [
    &["hypercivilizations"],
    &["hypercivilisations"],
    &["hypercivilizations"],
    &["hypercivilisations"],
];

pub(crate) static ENTRY_HYPERCIVILIZATION_13803153736151445143: VariantsMap = [
    &["hypercivilization"],
    &["hypercivilisation"],
    &["hypercivilization"],
    &["hypercivilisation"],
];

pub(crate) static ENTRY_HYPERCIVILIZEDS_8179865442803788169: VariantsMap = [
    &["hypercivilizeds"],
    &["hyperciviliseds"],
    &["hypercivilizeds"],
    &["hyperciviliseds"],
];

pub(crate) static ENTRY_HYPERCIVILIZED_4129945024296325999: VariantsMap = [
    &["hypercivilized"],
    &["hypercivilised"],
    &["hypercivilized"],
    &["hypercivilised"],
];

pub(crate) static ENTRY_HYPERCRITICIZED_16299270072259171288: VariantsMap = [
    &["hypercriticized"],
    &["hypercriticised"],
    &["hypercriticized"],
    &["hypercriticised"],
];

pub(crate) static ENTRY_HYPERCRITICIZES_17766772107445549296: VariantsMap = [
    &["hypercriticizes"],
    &["hypercriticises"],
    &["hypercriticizes"],
    &["hypercriticises"],
];

pub(crate) static ENTRY_HYPERCRITICIZE_7531870804381594430: VariantsMap = [
    &["hypercriticize"],
    &["hypercriticise"],
    &["hypercriticize"],
    &["hypercriticise"],
];

pub(crate) static ENTRY_HYPERCRITICIZING_11441741306039788542: VariantsMap = [
    &["hypercriticizing"],
    &["hypercriticising"],
    &["hypercriticizing"],
    &["hypercriticising"],
];

pub(crate) static ENTRY_HYPERCRYESTHESIA_16159941951842497999: VariantsMap = [
    &["hypercryesthesia"],
    &["hypercryaesthesia"],
    &["hypercryaesthesia"],
    &["hypercryaesthesia"],
];

pub(crate) static ENTRY_HYPEREMIAS_14973262707798439239: VariantsMap = [
    &["hyperemias"],
    &["hyperaemias"],
    &["hyperaemias"],
    &["hyperaemias"],
];

pub(crate) static ENTRY_HYPEREMIA_11403022388573074712: VariantsMap = [
    &["hyperemia"],
    &["hyperaemia"],
    &["hyperaemia"],
    &["hyperaemia"],
];

pub(crate) static ENTRY_HYPEREMIC_14808381080797019440: VariantsMap = [
    &["hyperemic"],
    &["hyperaemic"],
    &["hyperaemic"],
    &["hyperaemic"],
];

pub(crate) static ENTRY_HYPEREMPHASIZES_2256689383008575579: VariantsMap = [
    &["hyperemphasizes"],
    &["hyperemphasises"],
    &["hyperemphasizes"],
    &["hyperemphasises"],
];

pub(crate) static ENTRY_HYPEREMPHASIZE_7223152754553927293: VariantsMap = [
    &["hyperemphasize"],
    &["hyperemphasise"],
    &["hyperemphasize"],
    &["hyperemphasise"],
];

pub(crate) static ENTRY_HYPERESTHESIAS_4970829968815661247: VariantsMap = [
    &["hyperesthesias"],
    &["hyperaesthesias"],
    &["hyperaesthesias"],
    &["hyperaesthesias"],
];

pub(crate) static ENTRY_HYPERESTHESIA_3173626697674674219: VariantsMap = [
    &["hyperesthesia"],
    &["hyperaesthesia"],
    &["hyperaesthesia"],
    &["hyperaesthesia"],
];

pub(crate) static ENTRY_HYPERESTHETE_17327616943843185138: VariantsMap = [
    &["hyperesthete"],
    &["hyperaesthete"],
    &["hyperaesthete"],
    &["hyperaesthete"],
];

pub(crate) static ENTRY_HYPERESTHETICER_15328293772641718368: VariantsMap = [
    &["hyperestheticer"],
    &["hyperaestheticer"],
    &["hyperaestheticer"],
    &["hyperaestheticer"],
];

pub(crate) static ENTRY_HYPERESTHETICEST_10480488079230686661: VariantsMap = [
    &["hyperestheticest"],
    &["hyperaestheticest"],
    &["hyperaestheticest"],
    &["hyperaestheticest"],
];

pub(crate) static ENTRY_HYPERESTHETIC_13222558890179022448: VariantsMap = [
    &["hyperesthetic"],
    &["hyperaesthetic"],
    &["hyperaesthetic"],
    &["hyperaesthetic"],
];

pub(crate) static ENTRY_HYPERGLYCEMIC_2706228210156780391: VariantsMap = [
    &["hyperglycemic"],
    &["hyperglycaemic"],
    &["hyperglycaemic"],
    &["hyperglycaemic"],
];

pub(crate) static ENTRY_HYPERIMMUNIZATIONS_11646409859052189468: VariantsMap = [
    &["hyperimmunizations"],
    &["hyperimmunisations"],
    &["hyperimmunizations"],
    &["hyperimmunisations"],
];

pub(crate) static ENTRY_HYPERIMMUNIZATION_15847003636676248532: VariantsMap = [
    &["hyperimmunization"],
    &["hyperimmunisation"],
    &["hyperimmunization"],
    &["hyperimmunisation"],
];

pub(crate) static ENTRY_HYPERIMMUNIZES_18311239313571916578: VariantsMap = [
    &["hyperimmunizes"],
    &["hyperimmunises"],
    &["hyperimmunizes"],
    &["hyperimmunises"],
];

pub(crate) static ENTRY_HYPERIMMUNIZE_17424124507015070277: VariantsMap = [
    &["hyperimmunize"],
    &["hyperimmunise"],
    &["hyperimmunize"],
    &["hyperimmunise"],
];

pub(crate) static ENTRY_HYPERINSULINIZATIONS_10721167808286232537: VariantsMap = [
    &["hyperinsulinizations"],
    &["hyperinsulinisations"],
    &["hyperinsulinizations"],
    &["hyperinsulinisations"],
];

pub(crate) static ENTRY_HYPERINSULINIZATION_8367048383423792181: VariantsMap = [
    &["hyperinsulinization"],
    &["hyperinsulinisation"],
    &["hyperinsulinization"],
    &["hyperinsulinisation"],
];

pub(crate) static ENTRY_HYPERINSULINIZES_16582773226683393561: VariantsMap = [
    &["hyperinsulinizes"],
    &["hyperinsulinises"],
    &["hyperinsulinizes"],
    &["hyperinsulinises"],
];

pub(crate) static ENTRY_HYPERINSULINIZE_1640801475569483960: VariantsMap = [
    &["hyperinsulinize"],
    &["hyperinsulinise"],
    &["hyperinsulinize"],
    &["hyperinsulinise"],
];

pub(crate) static ENTRY_HYPERLIPEMIA_17019921749433845994: VariantsMap = [
    &["hyperlipemia"],
    &["hyperlipaemia"],
    &["hyperlipaemia"],
    &["hyperlipaemia"],
];

pub(crate) static ENTRY_HYPERLIPEMIC_14507717637329252900: VariantsMap = [
    &["hyperlipemic"],
    &["hyperlipaemic"],
    &["hyperlipaemic"],
    &["hyperlipaemic"],
];

pub(crate) static ENTRY_HYPERLIPIDEMIA_2777804776193284974: VariantsMap = [
    &["hyperlipidemia"],
    &["hyperlipidaemia"],
    &["hyperlipidaemia"],
    &["hyperlipidaemia"],
];

pub(crate) static ENTRY_HYPERNATREMIA_9942512727988845580: VariantsMap = [
    &["hypernatremia"],
    &["hypernatraemia"],
    &["hypernatraemia"],
    &["hypernatraemia"],
];

pub(crate) static ENTRY_HYPEROXYGENIZES_5991942787572964850: VariantsMap = [
    &["hyperoxygenizes"],
    &["hyperoxygenises"],
    &["hyperoxygenizes"],
    &["hyperoxygenises"],
];

pub(crate) static ENTRY_HYPEROXYGENIZE_14719478602723604195: VariantsMap = [
    &["hyperoxygenize"],
    &["hyperoxygenise"],
    &["hyperoxygenize"],
    &["hyperoxygenise"],
];

pub(crate) static ENTRY_HYPERPARASITIZES_18286520501846479011: VariantsMap = [
    &["hyperparasitizes"],
    &["hyperparasitises"],
    &["hyperparasitizes"],
    &["hyperparasitises"],
];

pub(crate) static ENTRY_HYPERPARASITIZE_7853126625657581368: VariantsMap = [
    &["hyperparasitize"],
    &["hyperparasitise"],
    &["hyperparasitize"],
    &["hyperparasitise"],
];

pub(crate) static ENTRY_HYPERPNEA_12342432255421507220: VariantsMap = [
    &["hyperpnea"],
    &["hyperpnoea"],
    &["hyperpnoea"],
    &["hyperpnoea"],
];

pub(crate) static ENTRY_HYPERREALIZES_6087084825849447883: VariantsMap = [
    &["hyperrealizes"],
    &["hyperrealises"],
    &["hyperrealizes"],
    &["hyperrealises"],
];

pub(crate) static ENTRY_HYPERREALIZE_18209108411522187070: VariantsMap = [
    &["hyperrealize"],
    &["hyperrealise"],
    &["hyperrealize"],
    &["hyperrealise"],
];

pub(crate) static ENTRY_HYPERSENSITIZATIONS_7563579891463645188: VariantsMap = [
    &["hypersensitizations"],
    &["hypersensitisations"],
    &["hypersensitizations"],
    &["hypersensitisations"],
];

pub(crate) static ENTRY_HYPERSENSITIZATION_11377085362616181909: VariantsMap = [
    &["hypersensitization"],
    &["hypersensitisation"],
    &["hypersensitization"],
    &["hypersensitisation"],
];

pub(crate) static ENTRY_HYPERSENSITIZED_3330978906246494687: VariantsMap = [
    &["hypersensitized"],
    &["hypersensitised"],
    &["hypersensitized"],
    &["hypersensitised"],
];

pub(crate) static ENTRY_HYPERSENSITIZES_11368790626933593739: VariantsMap = [
    &["hypersensitizes"],
    &["hypersensitises"],
    &["hypersensitizes"],
    &["hypersensitises"],
];

pub(crate) static ENTRY_HYPERSENSITIZE_11154923794098091939: VariantsMap = [
    &["hypersensitize"],
    &["hypersensitise"],
    &["hypersensitize"],
    &["hypersensitise"],
];

pub(crate) static ENTRY_HYPERSENSITIZING_6146233767758672273: VariantsMap = [
    &["hypersensitizing"],
    &["hypersensitising"],
    &["hypersensitizing"],
    &["hypersensitising"],
];

pub(crate) static ENTRY_HYPERSPIRITUALIZINGS_11634664580831934117: VariantsMap = [
    &["hyperspiritualizings"],
    &["hyperspiritualisings"],
    &["hyperspiritualizings"],
    &["hyperspiritualisings"],
];

pub(crate) static ENTRY_HYPERSPIRITUALIZING_5448619034968576987: VariantsMap = [
    &["hyperspiritualizing"],
    &["hyperspiritualising"],
    &["hyperspiritualizing"],
    &["hyperspiritualising"],
];

pub(crate) static ENTRY_HYPERTHYROIDIZATIONS_644639064305189453: VariantsMap = [
    &["hyperthyroidizations"],
    &["hyperthyroidisations"],
    &["hyperthyroidizations"],
    &["hyperthyroidisations"],
];

pub(crate) static ENTRY_HYPERTHYROIDIZATION_1460066134283167463: VariantsMap = [
    &["hyperthyroidization"],
    &["hyperthyroidisation"],
    &["hyperthyroidization"],
    &["hyperthyroidisation"],
];

pub(crate) static ENTRY_HYPERTHYROIDIZES_16533830875218158099: VariantsMap = [
    &["hyperthyroidizes"],
    &["hyperthyroidises"],
    &["hyperthyroidizes"],
    &["hyperthyroidises"],
];

pub(crate) static ENTRY_HYPERTHYROIDIZE_220125976519158472: VariantsMap = [
    &["hyperthyroidize"],
    &["hyperthyroidise"],
    &["hyperthyroidize"],
    &["hyperthyroidise"],
];

pub(crate) static ENTRY_HYPERVITALIZATIONS_16611523953783366472: VariantsMap = [
    &["hypervitalizations"],
    &["hypervitalisations"],
    &["hypervitalizations"],
    &["hypervitalisations"],
];

pub(crate) static ENTRY_HYPERVITALIZATION_372457073358759943: VariantsMap = [
    &["hypervitalization"],
    &["hypervitalisation"],
    &["hypervitalization"],
    &["hypervitalisation"],
];

pub(crate) static ENTRY_HYPERVITALIZES_11384012178375345224: VariantsMap = [
    &["hypervitalizes"],
    &["hypervitalises"],
    &["hypervitalizes"],
    &["hypervitalises"],
];

pub(crate) static ENTRY_HYPERVITALIZE_9679249450621626506: VariantsMap = [
    &["hypervitalize"],
    &["hypervitalise"],
    &["hypervitalize"],
    &["hypervitalise"],
];

pub(crate) static ENTRY_HYPESTHESIAS_4432727321640703024: VariantsMap = [
    &["hypesthesias"],
    &["hypaesthesias"],
    &["hypaesthesias"],
    &["hypaesthesias"],
];

pub(crate) static ENTRY_HYPESTHESIA_14564732207680543956: VariantsMap = [
    &["hypesthesia"],
    &["hypaesthesia"],
    &["hypaesthesia"],
    &["hypaesthesia"],
];

pub(crate) static ENTRY_HYPESTHESIC_1142742684373539307: VariantsMap = [
    &["hypesthesic"],
    &["hypaesthesic"],
    &["hypaesthesic"],
    &["hypaesthesic"],
];

pub(crate) static ENTRY_HYPETHRAL_16444817472811439978: VariantsMap = [
    &["hypethral"],
    &["hypaethral"],
    &["hypaethral"],
    &["hypaethral"],
];

pub(crate) static ENTRY_HYPHENIZATIONS_2352732446948213541: VariantsMap = [
    &["hyphenizations"],
    &["hyphenisations"],
    &["hyphenizations"],
    &["hyphenisations"],
];

pub(crate) static ENTRY_HYPHENIZATION_518047111423409166: VariantsMap = [
    &["hyphenization"],
    &["hyphenisation"],
    &["hyphenization"],
    &["hyphenisation"],
];

pub(crate) static ENTRY_HYPHENIZED_11632374625403992542: VariantsMap = [
    &["hyphenized"],
    &["hyphenised"],
    &["hyphenized"],
    &["hyphenised"],
];

pub(crate) static ENTRY_HYPHENIZES_15581224527134621804: VariantsMap = [
    &["hyphenizes"],
    &["hyphenises"],
    &["hyphenizes"],
    &["hyphenises"],
];

pub(crate) static ENTRY_HYPHENIZE_1355066745467653190: VariantsMap = [
    &["hyphenize"],
    &["hyphenise"],
    &["hyphenize"],
    &["hyphenise"],
];

pub(crate) static ENTRY_HYPHENIZING_17487608124210140279: VariantsMap = [
    &["hyphenizing"],
    &["hyphenising"],
    &["hyphenizing"],
    &["hyphenising"],
];

pub(crate) static ENTRY_HYPNOIDIZED_9319780668114784761: VariantsMap = [
    &["hypnoidized"],
    &["hypnoidised"],
    &["hypnoidized"],
    &["hypnoidised"],
];

pub(crate) static ENTRY_HYPNOIDIZES_17015057874529046063: VariantsMap = [
    &["hypnoidizes"],
    &["hypnoidises"],
    &["hypnoidizes"],
    &["hypnoidises"],
];

pub(crate) static ENTRY_HYPNOIDIZE_2850779439524391424: VariantsMap = [
    &["hypnoidize"],
    &["hypnoidise"],
    &["hypnoidize"],
    &["hypnoidise"],
];

pub(crate) static ENTRY_HYPNOIDIZING_13556905370183450835: VariantsMap = [
    &["hypnoidizing"],
    &["hypnoidising"],
    &["hypnoidizing"],
    &["hypnoidising"],
];

pub(crate) static ENTRY_HYPNOPEDIAS_2021280433174594462: VariantsMap = [
    &["hypnopedias"],
    &["hypnopaedias"],
    &["hypnopaedias"],
    &["hypnopaedias"],
];

pub(crate) static ENTRY_HYPNOPEDIA_16182744577342481603: VariantsMap = [
    &["hypnopedia"],
    &["hypnopaedia"],
    &["hypnopaedia"],
    &["hypnopaedia"],
];

pub(crate) static ENTRY_HYPNOTIZABILITIES_11128345419464903204: VariantsMap = [
    &["hypnotizabilities"],
    &["hypnotisabilities"],
    &["hypnotizabilities"],
    &["hypnotisabilities"],
];

pub(crate) static ENTRY_HYPNOTIZABILITY_4276821883858401715: VariantsMap = [
    &["hypnotizability"],
    &["hypnotisability"],
    &["hypnotizability"],
    &["hypnotisability"],
];

pub(crate) static ENTRY_HYPNOTIZABLER_17707987328116457331: VariantsMap = [
    &["hypnotizabler"],
    &["hypnotisabler"],
    &["hypnotizabler"],
    &["hypnotisabler"],
];

pub(crate) static ENTRY_HYPNOTIZABLEST_6467410254949884057: VariantsMap = [
    &["hypnotizablest"],
    &["hypnotisablest"],
    &["hypnotizablest"],
    &["hypnotisablest"],
];

pub(crate) static ENTRY_HYPNOTIZABLES_7101472140016331305: VariantsMap = [
    &["hypnotizables"],
    &["hypnotisables"],
    &["hypnotizables"],
    &["hypnotisables"],
];

pub(crate) static ENTRY_HYPNOTIZABLE_16992601341623152607: VariantsMap = [
    &["hypnotizable"],
    &["hypnotisable"],
    &["hypnotizable"],
    &["hypnotisable"],
];

pub(crate) static ENTRY_HYPNOTIZATIONS_12338000884893753831: VariantsMap = [
    &["hypnotizations"],
    &["hypnotisations"],
    &["hypnotizations"],
    &["hypnotisations"],
];

pub(crate) static ENTRY_HYPNOTIZATION_15666177504048422050: VariantsMap = [
    &["hypnotization"],
    &["hypnotisation"],
    &["hypnotization"],
    &["hypnotisation"],
];

pub(crate) static ENTRY_HYPNOTIZED_1649105222019656795: VariantsMap = [
    &["hypnotized"],
    &["hypnotised"],
    &["hypnotized"],
    &["hypnotised"],
];

pub(crate) static ENTRY_HYPNOTIZERS_13980343117375469027: VariantsMap = [
    &["hypnotizers"],
    &["hypnotisers"],
    &["hypnotizers"],
    &["hypnotisers"],
];

pub(crate) static ENTRY_HYPNOTIZER_13806710050342747653: VariantsMap = [
    &["hypnotizer"],
    &["hypnotiser"],
    &["hypnotizer"],
    &["hypnotiser"],
];

pub(crate) static ENTRY_HYPNOTIZES_18356635304308769334: VariantsMap = [
    &["hypnotizes"],
    &["hypnotises"],
    &["hypnotizes"],
    &["hypnotises"],
];

pub(crate) static ENTRY_HYPNOTIZE_31495543619220727: VariantsMap = [
    &["hypnotize"],
    &["hypnotise"],
    &["hypnotize"],
    &["hypnotise"],
];

pub(crate) static ENTRY_HYPNOTIZING_1791072609905298231: VariantsMap = [
    &["hypnotizing"],
    &["hypnotising"],
    &["hypnotizing"],
    &["hypnotising"],
];

pub(crate) static ENTRY_HYPOCENTERS_8535258706052045382: VariantsMap = [
    &["hypocenters"],
    &["hypocentres"],
    &["hypocentres"],
    &["hypocentres"],
];

pub(crate) static ENTRY_HYPOCENTER_10924617547082167348: VariantsMap = [
    &["hypocenter"],
    &["hypocentre"],
    &["hypocentre"],
    &["hypocentre"],
];

pub(crate) static ENTRY_HYPOGEAL_4214900613383499478: VariantsMap = [
    &["hypogeal"],
    &["hypogaeal"],
    &["hypogaeal"],
    &["hypogaeal"],
];

pub(crate) static ENTRY_HYPOGEAN_12254254837392880307: VariantsMap = [
    &["hypogean"],
    &["hypogaean"],
    &["hypogaean"],
    &["hypogaean"],
];

pub(crate) static ENTRY_HYPOGEA_5577040873155624794: VariantsMap =
    [&["hypogea"], &["hypogaea"], &["hypogaea"], &["hypogaea"]];

pub(crate) static ENTRY_HYPOGEIC_8668126381759058087: VariantsMap = [
    &["hypogeic"],
    &["hypogaeic"],
    &["hypogaeic"],
    &["hypogaeic"],
];

pub(crate) static ENTRY_HYPOGEOUS_12131139259918270129: VariantsMap = [
    &["hypogeous"],
    &["hypogaeous"],
    &["hypogaeous"],
    &["hypogaeous"],
];

pub(crate) static ENTRY_HYPOGEUM_4724680330192032314: VariantsMap = [
    &["hypogeum"],
    &["hypogaeum"],
    &["hypogaeum"],
    &["hypogaeum"],
];

pub(crate) static ENTRY_HYPOMAGNESEMIAS_14272891159396393964: VariantsMap = [
    &["hypomagnesemias"],
    &["hypomagnesaemias"],
    &["hypomagnesaemias"],
    &["hypomagnesaemias"],
];

pub(crate) static ENTRY_HYPOMAGNESEMIA_11350011491335743618: VariantsMap = [
    &["hypomagnesemia"],
    &["hypomagnesaemia"],
    &["hypomagnesaemia"],
    &["hypomagnesaemia"],
];

pub(crate) static ENTRY_HYPOMENORRHEAS_10501238150845360653: VariantsMap = [
    &["hypomenorrheas"],
    &["hypomenorrhoeas"],
    &["hypomenorrhoeas"],
    &["hypomenorrhoeas"],
];

pub(crate) static ENTRY_HYPOMENORRHEA_15862079214702615306: VariantsMap = [
    &["hypomenorrhea"],
    &["hypomenorrhoea"],
    &["hypomenorrhoea"],
    &["hypomenorrhoea"],
];

pub(crate) static ENTRY_HYPOPHYSECTOMIZED_16316479332714641237: VariantsMap = [
    &["hypophysectomized"],
    &["hypophysectomised"],
    &["hypophysectomized"],
    &["hypophysectomised"],
];

pub(crate) static ENTRY_HYPOPHYSECTOMIZE_7491760103755206752: VariantsMap = [
    &["hypophysectomize"],
    &["hypophysectomise"],
    &["hypophysectomize"],
    &["hypophysectomise"],
];

pub(crate) static ENTRY_HYPOPNEA_8190235472388790329: VariantsMap = [
    &["hypopnea"],
    &["hypopnoea"],
    &["hypopnoea"],
    &["hypopnoea"],
];

pub(crate) static ENTRY_HYPOSENSITIZATION_13169981854919292277: VariantsMap = [
    &["hyposensitization"],
    &["hyposensitisation"],
    &["hyposensitization"],
    &["hyposensitisation"],
];

pub(crate) static ENTRY_HYPOSENSITIZE_2895248881259272507: VariantsMap = [
    &["hyposensitize"],
    &["hyposensitise"],
    &["hyposensitize"],
    &["hyposensitise"],
];

pub(crate) static ENTRY_HYPOSTASIZED_14675743548250216380: VariantsMap = [
    &["hypostasized"],
    &["hypostasised"],
    &["hypostasized"],
    &["hypostasised"],
];

pub(crate) static ENTRY_HYPOSTASIZES_15212084710875560260: VariantsMap = [
    &["hypostasizes"],
    &["hypostasises"],
    &["hypostasizes"],
    &["hypostasises"],
];

pub(crate) static ENTRY_HYPOSTASIZE_11096004503705632835: VariantsMap = [
    &["hypostasize"],
    &["hypostasise"],
    &["hypostasize"],
    &["hypostasise"],
];

pub(crate) static ENTRY_HYPOSTASIZING_4036380769759199422: VariantsMap = [
    &["hypostasizing"],
    &["hypostasising"],
    &["hypostasizing"],
    &["hypostasising"],
];

pub(crate) static ENTRY_HYPOSTATIZATIONS_4580078961622780169: VariantsMap = [
    &["hypostatizations"],
    &["hypostatisations"],
    &["hypostatizations"],
    &["hypostatisations"],
];

pub(crate) static ENTRY_HYPOSTATIZATION_3087117275369319820: VariantsMap = [
    &["hypostatization"],
    &["hypostatisation"],
    &["hypostatization"],
    &["hypostatisation"],
];

pub(crate) static ENTRY_HYPOSTATIZED_12087439657646325061: VariantsMap = [
    &["hypostatized"],
    &["hypostatised"],
    &["hypostatized"],
    &["hypostatised"],
];

pub(crate) static ENTRY_HYPOSTATIZES_8600110126821695484: VariantsMap = [
    &["hypostatizes"],
    &["hypostatises"],
    &["hypostatizes"],
    &["hypostatises"],
];

pub(crate) static ENTRY_HYPOSTATIZE_1068205308830584989: VariantsMap = [
    &["hypostatize"],
    &["hypostatise"],
    &["hypostatize"],
    &["hypostatise"],
];

pub(crate) static ENTRY_HYPOSTATIZING_17172618075417547515: VariantsMap = [
    &["hypostatizing"],
    &["hypostatising"],
    &["hypostatizing"],
    &["hypostatising"],
];

pub(crate) static ENTRY_HYPOTHESIZED_7654092048334444056: VariantsMap = [
    &["hypothesized"],
    &["hypothesised"],
    &["hypothesized"],
    &["hypothesised"],
];

pub(crate) static ENTRY_HYPOTHESIZERS_603918477512076863: VariantsMap = [
    &["hypothesizers"],
    &["hypothesisers"],
    &["hypothesizers"],
    &["hypothesisers"],
];

pub(crate) static ENTRY_HYPOTHESIZER_12418298699515974202: VariantsMap = [
    &["hypothesizer"],
    &["hypothesiser"],
    &["hypothesizer"],
    &["hypothesiser"],
];

pub(crate) static ENTRY_HYPOTHESIZES_15615154634968472421: VariantsMap = [
    &["hypothesizes"],
    &["hypothesises"],
    &["hypothesizes"],
    &["hypothesises"],
];

pub(crate) static ENTRY_HYPOTHESIZE_9991606314621761423: VariantsMap = [
    &["hypothesize"],
    &["hypothesise"],
    &["hypothesize"],
    &["hypothesise"],
];

pub(crate) static ENTRY_HYPOTHESIZING_17752502848335912546: VariantsMap = [
    &["hypothesizing"],
    &["hypothesising"],
    &["hypothesizing"],
    &["hypothesising"],
];

pub(crate) static ENTRY_HYPOTHETIZED_5891619059003247329: VariantsMap = [
    &["hypothetized"],
    &["hypothetised"],
    &["hypothetized"],
    &["hypothetised"],
];

pub(crate) static ENTRY_HYPOTHETIZES_1892978940988731731: VariantsMap = [
    &["hypothetizes"],
    &["hypothetises"],
    &["hypothetizes"],
    &["hypothetises"],
];

pub(crate) static ENTRY_HYPOTHETIZE_9755880027223809632: VariantsMap = [
    &["hypothetize"],
    &["hypothetise"],
    &["hypothetize"],
    &["hypothetise"],
];

pub(crate) static ENTRY_HYPOTHETIZING_17356916950623118977: VariantsMap = [
    &["hypothetizing"],
    &["hypothetising"],
    &["hypothetizing"],
    &["hypothetising"],
];

pub(crate) static ENTRY_HYPOXEMIAS_16532743875103109491: VariantsMap = [
    &["hypoxemias"],
    &["hypoxaemias"],
    &["hypoxaemias"],
    &["hypoxaemias"],
];

pub(crate) static ENTRY_HYPOXEMIA_18278832485926696070: VariantsMap = [
    &["hypoxemia"],
    &["hypoxaemia"],
    &["hypoxaemia"],
    &["hypoxaemia"],
];

pub(crate) static ENTRY_HYPOXEMIC_548533936920854543: VariantsMap = [
    &["hypoxemic"],
    &["hypoxaemic"],
    &["hypoxaemic"],
    &["hypoxaemic"],
];

pub(crate) static ENTRY_HYSTERECTOMIZED_13349404234142869054: VariantsMap = [
    &["hysterectomized"],
    &["hysterectomised"],
    &["hysterectomized"],
    &["hysterectomised"],
];

pub(crate) static ENTRY_HYSTERECTOMIZES_7837017087019854209: VariantsMap = [
    &["hysterectomizes"],
    &["hysterectomises"],
    &["hysterectomizes"],
    &["hysterectomises"],
];

pub(crate) static ENTRY_HYSTERECTOMIZE_339019716389420307: VariantsMap = [
    &["hysterectomize"],
    &["hysterectomise"],
    &["hysterectomize"],
    &["hysterectomise"],
];

pub(crate) static ENTRY_HYSTERECTOMIZING_1803341574005543960: VariantsMap = [
    &["hysterectomizing"],
    &["hysterectomising"],
    &["hysterectomizing"],
    &["hysterectomising"],
];

pub(crate) static ENTRY_ICHNEUMONIZEDS_16408019083414202849: VariantsMap = [
    &["ichneumonizeds"],
    &["ichneumoniseds"],
    &["ichneumonizeds"],
    &["ichneumoniseds"],
];

pub(crate) static ENTRY_ICHNEUMONIZED_6378362117508680448: VariantsMap = [
    &["ichneumonized"],
    &["ichneumonised"],
    &["ichneumonized"],
    &["ichneumonised"],
];

pub(crate) static ENTRY_ICHORRHEA_14916867309701249088: VariantsMap = [
    &["ichorrhea"],
    &["ichorrhoea"],
    &["ichorrhoea"],
    &["ichorrhoea"],
];

pub(crate) static ENTRY_ICHORRHEMIA_13725064108367155360: VariantsMap = [
    &["ichorrhemia"],
    &["ichorrhaemia"],
    &["ichorrhaemia"],
    &["ichorrhaemia"],
];

pub(crate) static ENTRY_ICONIZED_9166522339758963505: VariantsMap =
    [&["iconized"], &["iconised"], &["iconized"], &["iconised"]];

pub(crate) static ENTRY_ICONIZES_7146786515616481266: VariantsMap =
    [&["iconizes"], &["iconises"], &["iconizes"], &["iconises"]];

pub(crate) static ENTRY_ICONIZE_1250698237284228147: VariantsMap =
    [&["iconize"], &["iconise"], &["iconize"], &["iconise"]];

pub(crate) static ENTRY_ICONIZING_4559448370943859169: VariantsMap = [
    &["iconizing"],
    &["iconising"],
    &["iconizing"],
    &["iconising"],
];

pub(crate) static ENTRY_IDEALIZATIONS_17706069873226328743: VariantsMap = [
    &["idealizations"],
    &["idealisations"],
    &["idealizations"],
    &["idealisations"],
];

pub(crate) static ENTRY_IDEALIZATION_8942077149848649531: VariantsMap = [
    &["idealization"],
    &["idealisation"],
    &["idealization"],
    &["idealisation"],
];

pub(crate) static ENTRY_IDEALIZED_14008500069022545339: VariantsMap = [
    &["idealized"],
    &["idealised"],
    &["idealized"],
    &["idealised"],
];

pub(crate) static ENTRY_IDEALIZERS_9984755113941497632: VariantsMap = [
    &["idealizers"],
    &["idealisers"],
    &["idealizers"],
    &["idealisers"],
];

pub(crate) static ENTRY_IDEALIZER_10372227838521078835: VariantsMap = [
    &["idealizer"],
    &["idealiser"],
    &["idealizer"],
    &["idealiser"],
];

pub(crate) static ENTRY_IDEALIZES_11364769940078887168: VariantsMap = [
    &["idealizes"],
    &["idealises"],
    &["idealizes"],
    &["idealises"],
];

pub(crate) static ENTRY_IDEALIZE_14123580326934520124: VariantsMap =
    [&["idealize"], &["idealise"], &["idealize"], &["idealise"]];

pub(crate) static ENTRY_IDEALIZING_11261011833401157832: VariantsMap = [
    &["idealizing"],
    &["idealising"],
    &["idealizing"],
    &["idealising"],
];

pub(crate) static ENTRY_IDEAN_9346667922217550026: VariantsMap =
    [&["idean"], &["idaean"], &["idaean"], &["idaean"]];

pub(crate) static ENTRY_IDEA_10731610012075090621: VariantsMap =
    [&["idea"], &["idaea"], &["idaea"], &["idaea"]];

pub(crate) static ENTRY_IDEOLOGIZED_14839820276752351313: VariantsMap = [
    &["ideologized"],
    &["ideologised"],
    &["ideologized"],
    &["ideologised"],
];

pub(crate) static ENTRY_IDEOLOGIZE_6184243847595357924: VariantsMap = [
    &["ideologize"],
    &["ideologise"],
    &["ideologize"],
    &["ideologise"],
];

pub(crate) static ENTRY_IDEOLOGIZING_5810490570451528116: VariantsMap = [
    &["ideologizing"],
    &["ideologising"],
    &["ideologizing"],
    &["ideologising"],
];

pub(crate) static ENTRY_IDIOTIZED_2823205485453867122: VariantsMap = [
    &["idiotized"],
    &["idiotised"],
    &["idiotized"],
    &["idiotised"],
];

pub(crate) static ENTRY_IDIOTIZES_7580197157055076168: VariantsMap = [
    &["idiotizes"],
    &["idiotises"],
    &["idiotizes"],
    &["idiotises"],
];

pub(crate) static ENTRY_IDIOTIZE_1684624828093976331: VariantsMap =
    [&["idiotize"], &["idiotise"], &["idiotize"], &["idiotise"]];

pub(crate) static ENTRY_IDIOTIZING_7163780928321635270: VariantsMap = [
    &["idiotizing"],
    &["idiotising"],
    &["idiotizing"],
    &["idiotising"],
];

pub(crate) static ENTRY_IDOLASTER_7266072593117643606: VariantsMap = [
    &["idolaster"],
    &["idolastre"],
    &["idolastre"],
    &["idolastre"],
];

pub(crate) static ENTRY_IDOLATRIZED_13594082497249773073: VariantsMap = [
    &["idolatrized"],
    &["idolatrised"],
    &["idolatrized"],
    &["idolatrised"],
];

pub(crate) static ENTRY_IDOLATRIZER_13466408337970930578: VariantsMap = [
    &["idolatrizer"],
    &["idolatriser"],
    &["idolatrizer"],
    &["idolatriser"],
];

pub(crate) static ENTRY_IDOLATRIZES_6460555645543616854: VariantsMap = [
    &["idolatrizes"],
    &["idolatrises"],
    &["idolatrizes"],
    &["idolatrises"],
];

pub(crate) static ENTRY_IDOLATRIZE_4656997284033474549: VariantsMap = [
    &["idolatrize"],
    &["idolatrise"],
    &["idolatrize"],
    &["idolatrise"],
];

pub(crate) static ENTRY_IDOLATRIZING_2845662815694741055: VariantsMap = [
    &["idolatrizing"],
    &["idolatrising"],
    &["idolatrizing"],
    &["idolatrising"],
];

pub(crate) static ENTRY_IDOLIZATIONS_9712598788540549768: VariantsMap = [
    &["idolizations"],
    &["idolisations"],
    &["idolizations"],
    &["idolisations"],
];

pub(crate) static ENTRY_IDOLIZATION_8632443878294442006: VariantsMap = [
    &["idolization"],
    &["idolisation"],
    &["idolization"],
    &["idolisation"],
];

pub(crate) static ENTRY_IDOLIZED_816557049996724188: VariantsMap =
    [&["idolized"], &["idolised"], &["idolized"], &["idolised"]];

pub(crate) static ENTRY_IDOLIZERS_1279817137520626890: VariantsMap = [
    &["idolizers"],
    &["idolisers"],
    &["idolizers"],
    &["idolisers"],
];

pub(crate) static ENTRY_IDOLIZER_9248020857005213110: VariantsMap =
    [&["idolizer"], &["idoliser"], &["idolizer"], &["idoliser"]];

pub(crate) static ENTRY_IDOLIZES_15045222501412845991: VariantsMap =
    [&["idolizes"], &["idolises"], &["idolizes"], &["idolises"]];

pub(crate) static ENTRY_IDOLIZE_2701460930995107542: VariantsMap =
    [&["idolize"], &["idolise"], &["idolize"], &["idolise"]];

pub(crate) static ENTRY_IDOLIZING_1591764180221977340: VariantsMap = [
    &["idolizing"],
    &["idolising"],
    &["idolizing"],
    &["idolising"],
];

pub(crate) static ENTRY_IDUMEANS_2701997562386323077: VariantsMap = [
    &["idumeans"],
    &["idumaeans"],
    &["idumaeans"],
    &["idumaeans"],
];

pub(crate) static ENTRY_IDUMEAN_10223482079508735346: VariantsMap =
    [&["idumean"], &["idumaean"], &["idumaean"], &["idumaean"]];

pub(crate) static ENTRY_IDUMEA_13980136124670779407: VariantsMap =
    [&["idumea"], &["idumaea"], &["idumaea"], &["idumaea"]];

pub(crate) static ENTRY_IER_8590173399354916659: VariantsMap =
    [&["ier"], &["ire"], &["ire"], &["ire"]];

pub(crate) static ENTRY_ILEOCECAL_16783306468594549177: VariantsMap = [
    &["ileocecal"],
    &["ileocaecal"],
    &["ileocaecal"],
    &["ileocaecal"],
];

pub(crate) static ENTRY_ILIADIZES_9101371657731138727: VariantsMap = [
    &["iliadizes"],
    &["iliadises"],
    &["iliadizes"],
    &["iliadises"],
];

pub(crate) static ENTRY_ILIADIZE_15127972838873373823: VariantsMap =
    [&["iliadize"], &["iliadise"], &["iliadize"], &["iliadise"]];

pub(crate) static ENTRY_ILLEGALIZATIONS_1156484598694873817: VariantsMap = [
    &["illegalizations"],
    &["illegalisations"],
    &["illegalizations"],
    &["illegalisations"],
];

pub(crate) static ENTRY_ILLEGALIZATION_4625157464834082989: VariantsMap = [
    &["illegalization"],
    &["illegalisation"],
    &["illegalization"],
    &["illegalisation"],
];

pub(crate) static ENTRY_ILLEGALIZED_484742681447604998: VariantsMap = [
    &["illegalized"],
    &["illegalised"],
    &["illegalized"],
    &["illegalised"],
];

pub(crate) static ENTRY_ILLEGALIZES_1428654024712106207: VariantsMap = [
    &["illegalizes"],
    &["illegalises"],
    &["illegalizes"],
    &["illegalises"],
];

pub(crate) static ENTRY_ILLEGALIZE_16625635604289115309: VariantsMap = [
    &["illegalize"],
    &["illegalise"],
    &["illegalize"],
    &["illegalise"],
];

pub(crate) static ENTRY_ILLEGALIZING_14859202189889876673: VariantsMap = [
    &["illegalizing"],
    &["illegalising"],
    &["illegalizing"],
    &["illegalising"],
];

pub(crate) static ENTRY_ILLEGITIMATIZED_9298797108128630594: VariantsMap = [
    &["illegitimatized"],
    &["illegitimatised"],
    &["illegitimatized"],
    &["illegitimatised"],
];

pub(crate) static ENTRY_ILLEGITIMATIZES_10871580308994962653: VariantsMap = [
    &["illegitimatizes"],
    &["illegitimatises"],
    &["illegitimatizes"],
    &["illegitimatises"],
];

pub(crate) static ENTRY_ILLEGITIMATIZE_14953959094151382508: VariantsMap = [
    &["illegitimatize"],
    &["illegitimatise"],
    &["illegitimatize"],
    &["illegitimatise"],
];

pub(crate) static ENTRY_ILLEGITIMATIZING_3130773918673655897: VariantsMap = [
    &["illegitimatizing"],
    &["illegitimatising"],
    &["illegitimatizing"],
    &["illegitimatising"],
];

pub(crate) static ENTRY_ILLIBERALIZED_2905951389427902439: VariantsMap = [
    &["illiberalized"],
    &["illiberalised"],
    &["illiberalized"],
    &["illiberalised"],
];

pub(crate) static ENTRY_ILLIBERALIZES_2675206746403840559: VariantsMap = [
    &["illiberalizes"],
    &["illiberalises"],
    &["illiberalizes"],
    &["illiberalises"],
];

pub(crate) static ENTRY_ILLIBERALIZE_16887752615283473950: VariantsMap = [
    &["illiberalize"],
    &["illiberalise"],
    &["illiberalize"],
    &["illiberalise"],
];

pub(crate) static ENTRY_ILLIBERALIZING_1093587366997831440: VariantsMap = [
    &["illiberalizing"],
    &["illiberalising"],
    &["illiberalizing"],
    &["illiberalising"],
];

pub(crate) static ENTRY_ILLUMINIZES_2269056124855197647: VariantsMap = [
    &["illuminizes"],
    &["illuminises"],
    &["illuminizes"],
    &["illuminises"],
];

pub(crate) static ENTRY_ILLUMINIZE_12083084487959333250: VariantsMap = [
    &["illuminize"],
    &["illuminise"],
    &["illuminize"],
    &["illuminise"],
];

pub(crate) static ENTRY_IMER_14870920039806180201: VariantsMap =
    [&["imer"], &["imre"], &["imre"], &["imre"]];

pub(crate) static ENTRY_IMMATERIALIZATION_6031031436477619826: VariantsMap = [
    &["immaterialization"],
    &["immaterialisation"],
    &["immaterialization"],
    &["immaterialisation"],
];

pub(crate) static ENTRY_IMMATERIALIZED_7515469749951851138: VariantsMap = [
    &["immaterialized"],
    &["immaterialised"],
    &["immaterialized"],
    &["immaterialised"],
];

pub(crate) static ENTRY_IMMATERIALIZES_14051931910265590173: VariantsMap = [
    &["immaterializes"],
    &["immaterialises"],
    &["immaterializes"],
    &["immaterialises"],
];

pub(crate) static ENTRY_IMMATERIALIZE_2608487643159689091: VariantsMap = [
    &["immaterialize"],
    &["immaterialise"],
    &["immaterialize"],
    &["immaterialise"],
];

pub(crate) static ENTRY_IMMATERIALIZING_10859489260752984597: VariantsMap = [
    &["immaterializing"],
    &["immaterialising"],
    &["immaterializing"],
    &["immaterialising"],
];

pub(crate) static ENTRY_IMMISERIZATIONS_4435664819116002162: VariantsMap = [
    &["immiserizations"],
    &["immiserisations"],
    &["immiserizations"],
    &["immiserisations"],
];

pub(crate) static ENTRY_IMMISERIZATION_14804280031319124390: VariantsMap = [
    &["immiserization"],
    &["immiserisation"],
    &["immiserization"],
    &["immiserisation"],
];

pub(crate) static ENTRY_IMMISERIZED_15690784954007838498: VariantsMap = [
    &["immiserized"],
    &["immiserised"],
    &["immiserized"],
    &["immiserised"],
];

pub(crate) static ENTRY_IMMISERIZES_3930721082718257837: VariantsMap = [
    &["immiserizes"],
    &["immiserises"],
    &["immiserizes"],
    &["immiserises"],
];

pub(crate) static ENTRY_IMMISERIZE_14280117300182154146: VariantsMap = [
    &["immiserize"],
    &["immiserise"],
    &["immiserize"],
    &["immiserise"],
];

pub(crate) static ENTRY_IMMISERIZING_7076021387262132556: VariantsMap = [
    &["immiserizing"],
    &["immiserising"],
    &["immiserizing"],
    &["immiserising"],
];

pub(crate) static ENTRY_IMMOBILIZATIONS_6872011870912376673: VariantsMap = [
    &["immobilizations"],
    &["immobilisations"],
    &["immobilizations"],
    &["immobilisations"],
];

pub(crate) static ENTRY_IMMOBILIZATION_14269365516868106061: VariantsMap = [
    &["immobilization"],
    &["immobilisation"],
    &["immobilization"],
    &["immobilisation"],
];

pub(crate) static ENTRY_IMMOBILIZED_6366288157273401051: VariantsMap = [
    &["immobilized"],
    &["immobilised"],
    &["immobilized"],
    &["immobilised"],
];

pub(crate) static ENTRY_IMMOBILIZERS_8902105516181595834: VariantsMap = [
    &["immobilizers"],
    &["immobilisers"],
    &["immobilizers"],
    &["immobilisers"],
];

pub(crate) static ENTRY_IMMOBILIZER_10527563302868891526: VariantsMap = [
    &["immobilizer"],
    &["immobiliser"],
    &["immobilizer"],
    &["immobiliser"],
];

pub(crate) static ENTRY_IMMOBILIZES_6192137487727370549: VariantsMap = [
    &["immobilizes"],
    &["immobilises"],
    &["immobilizes"],
    &["immobilises"],
];

pub(crate) static ENTRY_IMMOBILIZE_1538489296094287236: VariantsMap = [
    &["immobilize"],
    &["immobilise"],
    &["immobilize"],
    &["immobilise"],
];

pub(crate) static ENTRY_IMMOBILIZING_5171896597862510473: VariantsMap = [
    &["immobilizing"],
    &["immobilising"],
    &["immobilizing"],
    &["immobilising"],
];

pub(crate) static ENTRY_IMMORALIZED_8743847232919532242: VariantsMap = [
    &["immoralized"],
    &["immoralised"],
    &["immoralized"],
    &["immoralised"],
];

pub(crate) static ENTRY_IMMORALIZES_2840645599967765235: VariantsMap = [
    &["immoralizes"],
    &["immoralises"],
    &["immoralizes"],
    &["immoralises"],
];

pub(crate) static ENTRY_IMMORALIZE_12133461291897920761: VariantsMap = [
    &["immoralize"],
    &["immoralise"],
    &["immoralize"],
    &["immoralise"],
];

pub(crate) static ENTRY_IMMORALIZING_225651617588777573: VariantsMap = [
    &["immoralizing"],
    &["immoralising"],
    &["immoralizing"],
    &["immoralising"],
];

pub(crate) static ENTRY_IMMORTALIZABLER_564668294341461583: VariantsMap = [
    &["immortalizabler"],
    &["immortalisabler"],
    &["immortalizabler"],
    &["immortalisabler"],
];

pub(crate) static ENTRY_IMMORTALIZABLEST_7714158371330611954: VariantsMap = [
    &["immortalizablest"],
    &["immortalisablest"],
    &["immortalizablest"],
    &["immortalisablest"],
];

pub(crate) static ENTRY_IMMORTALIZABLES_4125528812325170114: VariantsMap = [
    &["immortalizables"],
    &["immortalisables"],
    &["immortalizables"],
    &["immortalisables"],
];

pub(crate) static ENTRY_IMMORTALIZABLE_15265716038811129100: VariantsMap = [
    &["immortalizable"],
    &["immortalisable"],
    &["immortalizable"],
    &["immortalisable"],
];

pub(crate) static ENTRY_IMMORTALIZATIONS_15664742949388054394: VariantsMap = [
    &["immortalizations"],
    &["immortalisations"],
    &["immortalizations"],
    &["immortalisations"],
];

pub(crate) static ENTRY_IMMORTALIZATION_4641698519464381352: VariantsMap = [
    &["immortalization"],
    &["immortalisation"],
    &["immortalization"],
    &["immortalisation"],
];

pub(crate) static ENTRY_IMMORTALIZED_12615514167775867804: VariantsMap = [
    &["immortalized"],
    &["immortalised"],
    &["immortalized"],
    &["immortalised"],
];

pub(crate) static ENTRY_IMMORTALIZERS_6443963380598843946: VariantsMap = [
    &["immortalizers"],
    &["immortalisers"],
    &["immortalizers"],
    &["immortalisers"],
];

pub(crate) static ENTRY_IMMORTALIZER_16932530946305699963: VariantsMap = [
    &["immortalizer"],
    &["immortaliser"],
    &["immortalizer"],
    &["immortaliser"],
];

pub(crate) static ENTRY_IMMORTALIZES_15825297845454086009: VariantsMap = [
    &["immortalizes"],
    &["immortalises"],
    &["immortalizes"],
    &["immortalises"],
];

pub(crate) static ENTRY_IMMORTALIZE_7365899919779412057: VariantsMap = [
    &["immortalize"],
    &["immortalise"],
    &["immortalize"],
    &["immortalise"],
];

pub(crate) static ENTRY_IMMORTALIZING_11881433655552032564: VariantsMap = [
    &["immortalizing"],
    &["immortalising"],
    &["immortalizing"],
    &["immortalising"],
];

pub(crate) static ENTRY_IMMUNIZATIONS_2659481680598819621: VariantsMap = [
    &["immunizations"],
    &["immunisations"],
    &["immunizations"],
    &["immunisations"],
];

pub(crate) static ENTRY_IMMUNIZATION_5538869136254922551: VariantsMap = [
    &["immunization"],
    &["immunisation"],
    &["immunization"],
    &["immunisation"],
];

pub(crate) static ENTRY_IMMUNIZED_12890937714947487224: VariantsMap = [
    &["immunized"],
    &["immunised"],
    &["immunized"],
    &["immunised"],
];

pub(crate) static ENTRY_IMMUNIZER_15479014044677441669: VariantsMap = [
    &["immunizer"],
    &["immuniser"],
    &["immunizer"],
    &["immuniser"],
];

pub(crate) static ENTRY_IMMUNIZES_5928407860363224635: VariantsMap = [
    &["immunizes"],
    &["immunises"],
    &["immunizes"],
    &["immunises"],
];

pub(crate) static ENTRY_IMMUNIZE_2664627276125231648: VariantsMap =
    [&["immunize"], &["immunise"], &["immunize"], &["immunise"]];

pub(crate) static ENTRY_IMMUNIZING_1565078017048661043: VariantsMap = [
    &["immunizing"],
    &["immunising"],
    &["immunizing"],
    &["immunising"],
];

pub(crate) static ENTRY_IMPACTIONIZES_426122654023138033: VariantsMap = [
    &["impactionizes"],
    &["impactionises"],
    &["impactionizes"],
    &["impactionises"],
];

pub(crate) static ENTRY_IMPACTIONIZE_2104051076866943054: VariantsMap = [
    &["impactionize"],
    &["impactionise"],
    &["impactionize"],
    &["impactionise"],
];

pub(crate) static ENTRY_IMPANELED_1167928814655817587: VariantsMap = [
    &["impaneled"],
    &["impanelled"],
    &["empanelled"],
    &["impanelled"],
];

pub(crate) static ENTRY_IMPANELING_8436697861195228668: VariantsMap = [
    &["impaneling"],
    &["impanelling"],
    &["empanelling"],
    &["impanelling"],
];

pub(crate) static ENTRY_IMPASTED_8815350397702761813: VariantsMap = [
    &["impasted"],
    &["impastoed"],
    &["impastoed"],
    &["impastoed"],
];

pub(crate) static ENTRY_IMPERIALIZATIONS_14083397381534560194: VariantsMap = [
    &["imperializations"],
    &["imperialisations"],
    &["imperializations"],
    &["imperialisations"],
];

pub(crate) static ENTRY_IMPERIALIZATION_809389970245717092: VariantsMap = [
    &["imperialization"],
    &["imperialisation"],
    &["imperialization"],
    &["imperialisation"],
];

pub(crate) static ENTRY_IMPERIALIZED_15090938406523631069: VariantsMap = [
    &["imperialized"],
    &["imperialised"],
    &["imperialized"],
    &["imperialised"],
];

pub(crate) static ENTRY_IMPERIALIZES_18231768259408025685: VariantsMap = [
    &["imperializes"],
    &["imperialises"],
    &["imperializes"],
    &["imperialises"],
];

pub(crate) static ENTRY_IMPERIALIZE_4481105644087115733: VariantsMap = [
    &["imperialize"],
    &["imperialise"],
    &["imperialize"],
    &["imperialise"],
];

pub(crate) static ENTRY_IMPERIALIZING_15786015724673840691: VariantsMap = [
    &["imperializing"],
    &["imperialising"],
    &["imperializing"],
    &["imperialising"],
];

pub(crate) static ENTRY_IMPERILED_1817411383008732803: VariantsMap = [
    &["imperiled"],
    &["imperilled"],
    &["imperilled"],
    &["imperilled"],
];

pub(crate) static ENTRY_IMPERILING_15623355054691084103: VariantsMap = [
    &["imperiling"],
    &["imperilling"],
    &["imperilling"],
    &["imperilling"],
];

pub(crate) static ENTRY_IMPERSCRIPTIBLE_2676593766088045954: VariantsMap = [
    &["imperscriptible"],
    &["imprescriptible"],
    &["imprescriptible"],
    &["imprescriptible"],
];

pub(crate) static ENTRY_IMPERSONALIZATIONS_6126721940741583599: VariantsMap = [
    &["impersonalizations"],
    &["impersonalisations"],
    &["impersonalizations"],
    &["impersonalisations"],
];

pub(crate) static ENTRY_IMPERSONALIZATION_11876381482371779340: VariantsMap = [
    &["impersonalization"],
    &["impersonalisation"],
    &["impersonalization"],
    &["impersonalisation"],
];

pub(crate) static ENTRY_IMPERSONALIZED_14013696750625247313: VariantsMap = [
    &["impersonalized"],
    &["impersonalised"],
    &["impersonalized"],
    &["impersonalised"],
];

pub(crate) static ENTRY_IMPERSONALIZES_10756220249571201643: VariantsMap = [
    &["impersonalizes"],
    &["impersonalises"],
    &["impersonalizes"],
    &["impersonalises"],
];

pub(crate) static ENTRY_IMPERSONALIZE_3918416555072155183: VariantsMap = [
    &["impersonalize"],
    &["impersonalise"],
    &["impersonalize"],
    &["impersonalise"],
];

pub(crate) static ENTRY_IMPERSONALIZING_8456593987165047413: VariantsMap = [
    &["impersonalizing"],
    &["impersonalising"],
    &["impersonalizing"],
    &["impersonalising"],
];

pub(crate) static ENTRY_IMPROVIZATORIZES_6258011353493362699: VariantsMap = [
    &["improvizatorizes"],
    &["improvisatorises"],
    &["improvisatorizes"],
    &["improvisatorises"],
];

pub(crate) static ENTRY_IMPROVIZATORIZE_10750757082424118716: VariantsMap = [
    &["improvizatorize"],
    &["improvisatorise"],
    &["improvisatorize"],
    &["improvisatorise"],
];

pub(crate) static ENTRY_INCARNALIZED_6333109739765414243: VariantsMap = [
    &["incarnalized"],
    &["incarnalised"],
    &["incarnalized"],
    &["incarnalised"],
];

pub(crate) static ENTRY_INCARNALIZE_7861142043845714587: VariantsMap = [
    &["incarnalize"],
    &["incarnalise"],
    &["incarnalize"],
    &["incarnalise"],
];

pub(crate) static ENTRY_INCARNALIZING_14863074476515763083: VariantsMap = [
    &["incarnalizing"],
    &["incarnalising"],
    &["incarnalizing"],
    &["incarnalising"],
];

pub(crate) static ENTRY_INCENTERS_16040338651220938626: VariantsMap = [
    &["incenters"],
    &["incentres"],
    &["incentres"],
    &["incentres"],
];

pub(crate) static ENTRY_INCENTER_9458973874644957428: VariantsMap =
    [&["incenter"], &["incentre"], &["incentre"], &["incentre"]];

pub(crate) static ENTRY_INCENTIVIZATIONS_14102392630691423740: VariantsMap = [
    &["incentivizations"],
    &["incentivisations"],
    &["incentivizations"],
    &["incentivisations"],
];

pub(crate) static ENTRY_INCENTIVIZATION_6332222872955507843: VariantsMap = [
    &["incentivization"],
    &["incentivisation"],
    &["incentivization"],
    &["incentivisation"],
];

pub(crate) static ENTRY_INCENTIVIZED_2383735849153336951: VariantsMap = [
    &["incentivized"],
    &["incentivised"],
    &["incentivized"],
    &["incentivised"],
];

pub(crate) static ENTRY_INCENTIVIZES_16584149161391523509: VariantsMap = [
    &["incentivizes"],
    &["incentivises"],
    &["incentivizes"],
    &["incentivises"],
];

pub(crate) static ENTRY_INCENTIVIZE_552070002375523113: VariantsMap = [
    &["incentivize"],
    &["incentivise"],
    &["incentivize"],
    &["incentivise"],
];

pub(crate) static ENTRY_INCENTIVIZING_15493171350741422018: VariantsMap = [
    &["incentivizing"],
    &["incentivising"],
    &["incentivizing"],
    &["incentivising"],
];

pub(crate) static ENTRY_INCERATE_15157256917180496396: VariantsMap =
    [&["incerate"], &["increate"], &["increate"], &["increate"]];

pub(crate) static ENTRY_INCOGNIZABLE_10607185097022859286: VariantsMap = [
    &["incognizable"],
    &["incognisable"],
    &["incognizable"],
    &["incognisable"],
];

pub(crate) static ENTRY_INCOGNIZANCES_17577781369104818851: VariantsMap = [
    &["incognizances"],
    &["incognisances"],
    &["incognizances"],
    &["incognisances"],
];

pub(crate) static ENTRY_INCOGNIZANCE_6248858370628163819: VariantsMap = [
    &["incognizance"],
    &["incognisance"],
    &["incognizance"],
    &["incognisance"],
];

pub(crate) static ENTRY_INCOGNIZANT_10246562813251688993: VariantsMap = [
    &["incognizant"],
    &["incognisant"],
    &["incognizant"],
    &["incognisant"],
];

pub(crate) static ENTRY_INDIANIZATION_16145413298304712165: VariantsMap = [
    &["indianization"],
    &["indianisation"],
    &["indianization"],
    &["indianisation"],
];

pub(crate) static ENTRY_INDIANIZED_6203878007785616549: VariantsMap = [
    &["indianized"],
    &["indianised"],
    &["indianized"],
    &["indianised"],
];

pub(crate) static ENTRY_INDIANIZES_5103097757150832367: VariantsMap = [
    &["indianizes"],
    &["indianises"],
    &["indianizes"],
    &["indianises"],
];

pub(crate) static ENTRY_INDIANIZE_11979657832545271268: VariantsMap = [
    &["indianize"],
    &["indianise"],
    &["indianize"],
    &["indianise"],
];

pub(crate) static ENTRY_INDIANIZING_10380881278589214058: VariantsMap = [
    &["indianizing"],
    &["indianising"],
    &["indianizing"],
    &["indianising"],
];

pub(crate) static ENTRY_INDIGENE_15049604537921582666: VariantsMap = [
    &["indigene"],
    &["indigenae"],
    &["indigenae"],
    &["indigenae"],
];

pub(crate) static ENTRY_INDIGENIZATIONS_13318481869437423349: VariantsMap = [
    &["indigenizations"],
    &["indigenisations"],
    &["indigenizations"],
    &["indigenisations"],
];

pub(crate) static ENTRY_INDIGENIZATION_7957795492779097437: VariantsMap = [
    &["indigenization"],
    &["indigenisation"],
    &["indigenization"],
    &["indigenisation"],
];

pub(crate) static ENTRY_INDIGENIZED_17113860080855467952: VariantsMap = [
    &["indigenized"],
    &["indigenised"],
    &["indigenized"],
    &["indigenised"],
];

pub(crate) static ENTRY_INDIGENIZES_8212488857174469274: VariantsMap = [
    &["indigenizes"],
    &["indigenises"],
    &["indigenizes"],
    &["indigenises"],
];

pub(crate) static ENTRY_INDIGENIZE_17958730421669576658: VariantsMap = [
    &["indigenize"],
    &["indigenise"],
    &["indigenize"],
    &["indigenise"],
];

pub(crate) static ENTRY_INDIGENIZING_5786616818049833426: VariantsMap = [
    &["indigenizing"],
    &["indigenising"],
    &["indigenizing"],
    &["indigenising"],
];

pub(crate) static ENTRY_INDIVIDUALIZATIONS_11118632820394117785: VariantsMap = [
    &["individualizations"],
    &["individualisations"],
    &["individualizations"],
    &["individualisations"],
];

pub(crate) static ENTRY_INDIVIDUALIZATION_649176936740988346: VariantsMap = [
    &["individualization"],
    &["individualisation"],
    &["individualization"],
    &["individualisation"],
];

pub(crate) static ENTRY_INDIVIDUALIZED_16128034337210456768: VariantsMap = [
    &["individualized"],
    &["individualised"],
    &["individualized"],
    &["individualised"],
];

pub(crate) static ENTRY_INDIVIDUALIZERS_15913845742563764251: VariantsMap = [
    &["individualizers"],
    &["individualisers"],
    &["individualizers"],
    &["individualisers"],
];

pub(crate) static ENTRY_INDIVIDUALIZER_4182762615893522554: VariantsMap = [
    &["individualizer"],
    &["individualiser"],
    &["individualizer"],
    &["individualiser"],
];

pub(crate) static ENTRY_INDIVIDUALIZES_10472470571311764620: VariantsMap = [
    &["individualizes"],
    &["individualises"],
    &["individualizes"],
    &["individualises"],
];

pub(crate) static ENTRY_INDIVIDUALIZE_13939176487047243121: VariantsMap = [
    &["individualize"],
    &["individualise"],
    &["individualize"],
    &["individualise"],
];

pub(crate) static ENTRY_INDIVIDUALIZINGLY_10770535701165712688: VariantsMap = [
    &["individualizingly"],
    &["individualisingly"],
    &["individualizingly"],
    &["individualisingly"],
];

pub(crate) static ENTRY_INDIVIDUALIZING_8929349970924125846: VariantsMap = [
    &["individualizing"],
    &["individualising"],
    &["individualizing"],
    &["individualising"],
];

pub(crate) static ENTRY_INDRAFTS_5585473109884484359: VariantsMap = [
    &["indrafts"],
    &["indraughts"],
    &["indrafts"],
    &["indraughts"],
];

pub(crate) static ENTRY_INDRAFT_906884386745118313: VariantsMap =
    [&["indraft"], &["indraught"], &["indraft"], &["indraught"]];

pub(crate) static ENTRY_INDUSTRIALIZATIONS_5781661892562457350: VariantsMap = [
    &["industrializations"],
    &["industrialisations"],
    &["industrializations"],
    &["industrialisations"],
];

pub(crate) static ENTRY_INDUSTRIALIZATION_3782509534748207782: VariantsMap = [
    &["industrialization"],
    &["industrialisation"],
    &["industrialization"],
    &["industrialisation"],
];

pub(crate) static ENTRY_INDUSTRIALIZED_2970036951077578679: VariantsMap = [
    &["industrialized"],
    &["industrialised"],
    &["industrialized"],
    &["industrialised"],
];

pub(crate) static ENTRY_INDUSTRIALIZES_108463817008379635: VariantsMap = [
    &["industrializes"],
    &["industrialises"],
    &["industrializes"],
    &["industrialises"],
];

pub(crate) static ENTRY_INDUSTRIALIZE_11802203695636303310: VariantsMap = [
    &["industrialize"],
    &["industrialise"],
    &["industrialize"],
    &["industrialise"],
];

pub(crate) static ENTRY_INDUSTRIALIZING_4108758435956044036: VariantsMap = [
    &["industrializing"],
    &["industrialising"],
    &["industrializing"],
    &["industrialising"],
];

pub(crate) static ENTRY_INESTHETIC_8618358610512556728: VariantsMap = [
    &["inesthetic"],
    &["inaesthetic"],
    &["inaesthetic"],
    &["inaesthetic"],
];

pub(crate) static ENTRY_INFAMIZED_8107492535730330362: VariantsMap = [
    &["infamized"],
    &["infamised"],
    &["infamized"],
    &["infamised"],
];

pub(crate) static ENTRY_INFAMIZES_13859908196515724665: VariantsMap = [
    &["infamizes"],
    &["infamises"],
    &["infamizes"],
    &["infamises"],
];

pub(crate) static ENTRY_INFAMIZE_9505936708834210302: VariantsMap =
    [&["infamize"], &["infamise"], &["infamize"], &["infamise"]];

pub(crate) static ENTRY_INFAMIZING_2418856263638143206: VariantsMap = [
    &["infamizing"],
    &["infamising"],
    &["infamizing"],
    &["infamising"],
];

pub(crate) static ENTRY_INFAMONIZED_12631432978176771320: VariantsMap = [
    &["infamonized"],
    &["infamonised"],
    &["infamonized"],
    &["infamonised"],
];

pub(crate) static ENTRY_INFAMONIZES_828661709748784693: VariantsMap = [
    &["infamonizes"],
    &["infamonises"],
    &["infamonizes"],
    &["infamonises"],
];

pub(crate) static ENTRY_INFAMONIZE_1912633598113446535: VariantsMap = [
    &["infamonize"],
    &["infamonise"],
    &["infamonize"],
    &["infamonise"],
];

pub(crate) static ENTRY_INFAMONIZING_3560185438718299549: VariantsMap = [
    &["infamonizing"],
    &["infamonising"],
    &["infamonizing"],
    &["infamonising"],
];

pub(crate) static ENTRY_INFERE_12081519587041032918: VariantsMap =
    [&["infere"], &["infree"], &["infree"], &["infree"]];

pub(crate) static ENTRY_INFERIORIZES_13851169502462205708: VariantsMap = [
    &["inferiorizes"],
    &["inferiorises"],
    &["inferiorizes"],
    &["inferiorises"],
];

pub(crate) static ENTRY_INFERIORIZE_18055626716137479185: VariantsMap = [
    &["inferiorize"],
    &["inferiorise"],
    &["inferiorize"],
    &["inferiorise"],
];

pub(crate) static ENTRY_INFERNALIZES_12015516847502853908: VariantsMap = [
    &["infernalizes"],
    &["infernalises"],
    &["infernalizes"],
    &["infernalises"],
];

pub(crate) static ENTRY_INFERNALIZE_271646759477051771: VariantsMap = [
    &["infernalize"],
    &["infernalise"],
    &["infernalize"],
    &["infernalise"],
];

pub(crate) static ENTRY_INFIDELIZES_9998852219255855475: VariantsMap = [
    &["infidelizes"],
    &["infidelises"],
    &["infidelizes"],
    &["infidelises"],
];

pub(crate) static ENTRY_INFIDELIZE_12024929451033396652: VariantsMap = [
    &["infidelize"],
    &["infidelise"],
    &["infidelize"],
    &["infidelise"],
];

pub(crate) static ENTRY_INFINITIZES_16900614083188680149: VariantsMap = [
    &["infinitizes"],
    &["infinitises"],
    &["infinitizes"],
    &["infinitises"],
];

pub(crate) static ENTRY_INFINITIZE_12913263953737511613: VariantsMap = [
    &["infinitize"],
    &["infinitise"],
    &["infinitize"],
    &["infinitise"],
];

pub(crate) static ENTRY_INFLECTIONS_3311441335165237996: VariantsMap = [
    &["inflections"],
    &["inflections", "inflexions"],
    &["inflections"],
    &["inflections", "inflexions"],
];

pub(crate) static ENTRY_INFLECTION_13441227020426228543: VariantsMap = [
    &["inflection"],
    &["inflection", "inflexion"],
    &["inflection"],
    &["inflection", "inflexion"],
];

pub(crate) static ENTRY_INFORMALIZES_10886097819718009126: VariantsMap = [
    &["informalizes"],
    &["informalises"],
    &["informalizes"],
    &["informalises"],
];

pub(crate) static ENTRY_INFORMALIZE_17826170607752662140: VariantsMap = [
    &["informalize"],
    &["informalise"],
    &["informalize"],
    &["informalise"],
];

pub(crate) static ENTRY_INGVEONIC_455635617998549394: VariantsMap = [
    &["ingveonic"],
    &["ingvaeonic"],
    &["ingvaeonic"],
    &["ingvaeonic"],
];

pub(crate) static ENTRY_INGWEONIC_3016657805432955135: VariantsMap = [
    &["ingweonic"],
    &["ingwaeonic"],
    &["ingwaeonic"],
    &["ingwaeonic"],
];

pub(crate) static ENTRY_INHUMANIZES_5657328343169490122: VariantsMap = [
    &["inhumanizes"],
    &["inhumanises"],
    &["inhumanizes"],
    &["inhumanises"],
];

pub(crate) static ENTRY_INHUMANIZE_1125531716586320140: VariantsMap = [
    &["inhumanize"],
    &["inhumanise"],
    &["inhumanize"],
    &["inhumanise"],
];

pub(crate) static ENTRY_INITIALED_1122623591354647527: VariantsMap = [
    &["initialed"],
    &["initialled"],
    &["initialled"],
    &["initialled"],
];

pub(crate) static ENTRY_INITIALERS_3062657226262961390: VariantsMap = [
    &["initialers"],
    &["initiallers"],
    &["initiallers"],
    &["initiallers"],
];

pub(crate) static ENTRY_INITIALER_6151200791899571202: VariantsMap = [
    &["initialer"],
    &["initialler"],
    &["initialler"],
    &["initialler"],
];

pub(crate) static ENTRY_INITIALING_14617210175952400635: VariantsMap = [
    &["initialing"],
    &["initialling"],
    &["initialling"],
    &["initialling"],
];

pub(crate) static ENTRY_INITIALIZABLE_7321355618285398649: VariantsMap = [
    &["initializable"],
    &["initialisable"],
    &["initializable"],
    &["initialisable"],
];

pub(crate) static ENTRY_INITIALIZATIONS_9980554775185315575: VariantsMap = [
    &["initializations"],
    &["initialisations"],
    &["initializations"],
    &["initialisations"],
];

pub(crate) static ENTRY_INITIALIZATION_13629327501468098349: VariantsMap = [
    &["initialization"],
    &["initialisation"],
    &["initialization"],
    &["initialisation"],
];

pub(crate) static ENTRY_INITIALIZED_7587168812809071543: VariantsMap = [
    &["initialized"],
    &["initialised"],
    &["initialized"],
    &["initialised"],
];

pub(crate) static ENTRY_INITIALIZERS_12398839316559453843: VariantsMap = [
    &["initializers"],
    &["initialisers"],
    &["initializers"],
    &["initialisers"],
];

pub(crate) static ENTRY_INITIALIZER_4018135888541909006: VariantsMap = [
    &["initializer"],
    &["initialiser"],
    &["initializer"],
    &["initialiser"],
];

pub(crate) static ENTRY_INITIALIZES_6563132601688087865: VariantsMap = [
    &["initializes"],
    &["initialises"],
    &["initializes"],
    &["initialises"],
];

pub(crate) static ENTRY_INITIALIZE_14137997308893047575: VariantsMap = [
    &["initialize"],
    &["initialise"],
    &["initialize"],
    &["initialise"],
];

pub(crate) static ENTRY_INITIALIZING_7489678212739024329: VariantsMap = [
    &["initializing"],
    &["initialising"],
    &["initializing"],
    &["initialising"],
];

pub(crate) static ENTRY_INORGANIZATIONS_3786296158259671895: VariantsMap = [
    &["inorganizations"],
    &["inorganisations"],
    &["inorganizations"],
    &["inorganisations"],
];

pub(crate) static ENTRY_INORGANIZATION_11855467122026486374: VariantsMap = [
    &["inorganization"],
    &["inorganisation"],
    &["inorganization"],
    &["inorganisation"],
];

pub(crate) static ENTRY_INORGANIZED_11175057158204772809: VariantsMap = [
    &["inorganized"],
    &["inorganised"],
    &["inorganized"],
    &["inorganised"],
];

pub(crate) static ENTRY_INQUIRED_13488148321304019081: VariantsMap = [
    &["inquired"],
    &["enquired", "inquired"],
    &["inquired"],
    &["enquired", "inquired"],
];

pub(crate) static ENTRY_INQUIRES_3832461159884672820: VariantsMap = [
    &["inquires"],
    &["enquires", "inquires"],
    &["inquires"],
    &["enquires", "inquires"],
];

pub(crate) static ENTRY_INQUIRE_13984560274152171356: VariantsMap = [
    &["inquire"],
    &["enquire", "inquire"],
    &["inquire"],
    &["enquire", "inquire"],
];

pub(crate) static ENTRY_INQUIRIES_9592346579573413198: VariantsMap = [
    &["inquiries"],
    &["enquiries", "inquiries"],
    &["inquiries"],
    &["enquiries", "inquiries"],
];

pub(crate) static ENTRY_INQUIRING_11670725526763123090: VariantsMap = [
    &["inquiring"],
    &["enquiring", "inquiring"],
    &["inquiring"],
    &["enquiring", "inquiring"],
];

pub(crate) static ENTRY_INQUIRY_3419756106654954762: VariantsMap = [
    &["inquiry"],
    &["enquiry", "inquiry"],
    &["inquiry"],
    &["enquiry", "inquiry"],
];

pub(crate) static ENTRY_INSOLUBILIZATION_2624933827226592167: VariantsMap = [
    &["insolubilization"],
    &["insolubilisation"],
    &["insolubilization"],
    &["insolubilisation"],
];

pub(crate) static ENTRY_INSOLUBILIZED_11559003470253032575: VariantsMap = [
    &["insolubilized"],
    &["insolubilised"],
    &["insolubilized"],
    &["insolubilised"],
];

pub(crate) static ENTRY_INSOLUBILIZES_2928855643803441236: VariantsMap = [
    &["insolubilizes"],
    &["insolubilises"],
    &["insolubilizes"],
    &["insolubilises"],
];

pub(crate) static ENTRY_INSOLUBILIZE_16190378805001128650: VariantsMap = [
    &["insolubilize"],
    &["insolubilise"],
    &["insolubilize"],
    &["insolubilise"],
];

pub(crate) static ENTRY_INSOLUBILIZING_17373219238380218554: VariantsMap = [
    &["insolubilizing"],
    &["insolubilising"],
    &["insolubilizing"],
    &["insolubilising"],
];

pub(crate) static ENTRY_INSTALLMENTS_6628253336902494309: VariantsMap = [
    &["installments"],
    &["instalments"],
    &["instalments"],
    &["instalments"],
];

pub(crate) static ENTRY_INSTALLMENT_15955257315912152068: VariantsMap = [
    &["installment"],
    &["instalment"],
    &["instalment"],
    &["instalment"],
];

pub(crate) static ENTRY_INSTALLS_10741039873860965951: VariantsMap =
    [&["installs"], &["installs"], &["installs"], &["installs"]];

pub(crate) static ENTRY_INSTALL_1232036630970101636: VariantsMap =
    [&["install"], &["install"], &["install"], &["install"]];

pub(crate) static ENTRY_INSTILLS_8131073218211206010: VariantsMap =
    [&["instills"], &["instils"], &["instills"], &["instils"]];

pub(crate) static ENTRY_INSTILL_12975407349726514336: VariantsMap =
    [&["instill"], &["instil"], &["instill"], &["instil"]];

pub(crate) static ENTRY_INSTITUTIONALIZATIONS_12755904320513262139: VariantsMap = [
    &["institutionalizations"],
    &["institutionalisations"],
    &["institutionalizations"],
    &["institutionalisations"],
];

pub(crate) static ENTRY_INSTITUTIONALIZATION_3187856750627910628: VariantsMap = [
    &["institutionalization"],
    &["institutionalisation"],
    &["institutionalization"],
    &["institutionalisation"],
];

pub(crate) static ENTRY_INSTITUTIONALIZED_662778395420998219: VariantsMap = [
    &["institutionalized"],
    &["institutionalised"],
    &["institutionalized"],
    &["institutionalised"],
];

pub(crate) static ENTRY_INSTITUTIONALIZES_12707267082253355926: VariantsMap = [
    &["institutionalizes"],
    &["institutionalises"],
    &["institutionalizes"],
    &["institutionalises"],
];

pub(crate) static ENTRY_INSTITUTIONALIZE_2368732057929198536: VariantsMap = [
    &["institutionalize"],
    &["institutionalise"],
    &["institutionalize"],
    &["institutionalise"],
];

pub(crate) static ENTRY_INSTITUTIONALIZING_5314493516630022554: VariantsMap = [
    &["institutionalizing"],
    &["institutionalising"],
    &["institutionalizing"],
    &["institutionalising"],
];

pub(crate) static ENTRY_INSTITUTIONIZES_10150724383117783571: VariantsMap = [
    &["institutionizes"],
    &["institutionises"],
    &["institutionizes"],
    &["institutionises"],
];

pub(crate) static ENTRY_INSTITUTIONIZE_10372940805349027641: VariantsMap = [
    &["institutionize"],
    &["institutionise"],
    &["institutionize"],
    &["institutionise"],
];

pub(crate) static ENTRY_INSTRUMENTALIZES_16506735465128047968: VariantsMap = [
    &["instrumentalizes"],
    &["instrumentalises"],
    &["instrumentalizes"],
    &["instrumentalises"],
];

pub(crate) static ENTRY_INSTRUMENTALIZE_14933680729070542221: VariantsMap = [
    &["instrumentalize"],
    &["instrumentalise"],
    &["instrumentalize"],
    &["instrumentalise"],
];

pub(crate) static ENTRY_INSULARIZES_6595980328038128413: VariantsMap = [
    &["insularizes"],
    &["insularises"],
    &["insularizes"],
    &["insularises"],
];

pub(crate) static ENTRY_INSULARIZE_9177745690473314239: VariantsMap = [
    &["insularize"],
    &["insularise"],
    &["insularize"],
    &["insularise"],
];

pub(crate) static ENTRY_INSURRECTIONIZED_9902157018267694954: VariantsMap = [
    &["insurrectionized"],
    &["insurrectionised"],
    &["insurrectionized"],
    &["insurrectionised"],
];

pub(crate) static ENTRY_INSURRECTIONIZES_15593571003663123617: VariantsMap = [
    &["insurrectionizes"],
    &["insurrectionises"],
    &["insurrectionizes"],
    &["insurrectionises"],
];

pub(crate) static ENTRY_INSURRECTIONIZE_13973633585951003277: VariantsMap = [
    &["insurrectionize"],
    &["insurrectionise"],
    &["insurrectionize"],
    &["insurrectionise"],
];

pub(crate) static ENTRY_INSURRECTIONIZING_9230576022597150453: VariantsMap = [
    &["insurrectionizing"],
    &["insurrectionising"],
    &["insurrectionizing"],
    &["insurrectionising"],
];

pub(crate) static ENTRY_INTEGRALIZATIONS_14841454090292389979: VariantsMap = [
    &["integralizations"],
    &["integralisations"],
    &["integralizations"],
    &["integralisations"],
];

pub(crate) static ENTRY_INTEGRALIZATION_14909799739781830655: VariantsMap = [
    &["integralization"],
    &["integralisation"],
    &["integralization"],
    &["integralisation"],
];

pub(crate) static ENTRY_INTEGRALIZES_16303894927038567041: VariantsMap = [
    &["integralizes"],
    &["integralises"],
    &["integralizes"],
    &["integralises"],
];

pub(crate) static ENTRY_INTEGRALIZE_4227561325105793311: VariantsMap = [
    &["integralize"],
    &["integralise"],
    &["integralize"],
    &["integralise"],
];

pub(crate) static ENTRY_INTELLECTUALIZATIONS_3199889427953063623: VariantsMap = [
    &["intellectualizations"],
    &["intellectualisations"],
    &["intellectualizations"],
    &["intellectualisations"],
];

pub(crate) static ENTRY_INTELLECTUALIZATION_5006098909718239143: VariantsMap = [
    &["intellectualization"],
    &["intellectualisation"],
    &["intellectualization"],
    &["intellectualisation"],
];

pub(crate) static ENTRY_INTELLECTUALIZED_8385887282030505172: VariantsMap = [
    &["intellectualized"],
    &["intellectualised"],
    &["intellectualized"],
    &["intellectualised"],
];

pub(crate) static ENTRY_INTELLECTUALIZERS_11392986022853877080: VariantsMap = [
    &["intellectualizers"],
    &["intellectualisers"],
    &["intellectualizers"],
    &["intellectualisers"],
];

pub(crate) static ENTRY_INTELLECTUALIZER_17482373382110935014: VariantsMap = [
    &["intellectualizer"],
    &["intellectualiser"],
    &["intellectualizer"],
    &["intellectualiser"],
];

pub(crate) static ENTRY_INTELLECTUALIZES_10524380563631063928: VariantsMap = [
    &["intellectualizes"],
    &["intellectualises"],
    &["intellectualizes"],
    &["intellectualises"],
];

pub(crate) static ENTRY_INTELLECTUALIZE_6007564803782987842: VariantsMap = [
    &["intellectualize"],
    &["intellectualise"],
    &["intellectualize"],
    &["intellectualise"],
];

pub(crate) static ENTRY_INTELLECTUALIZING_11856597360745053121: VariantsMap = [
    &["intellectualizing"],
    &["intellectualising"],
    &["intellectualizing"],
    &["intellectualising"],
];

pub(crate) static ENTRY_INTERCIVILIZATIONS_16686447883834461544: VariantsMap = [
    &["intercivilizations"],
    &["intercivilisations"],
    &["intercivilizations"],
    &["intercivilisations"],
];

pub(crate) static ENTRY_INTERCIVILIZATION_10438802679590964516: VariantsMap = [
    &["intercivilization"],
    &["intercivilisation"],
    &["intercivilization"],
    &["intercivilisation"],
];

pub(crate) static ENTRY_INTERCOLONIZATIONS_1193684945774928129: VariantsMap = [
    &["intercolonizations"],
    &["intercolonisations"],
    &["intercolonizations"],
    &["intercolonisations"],
];

pub(crate) static ENTRY_INTERCOLONIZATION_9529792773429446590: VariantsMap = [
    &["intercolonization"],
    &["intercolonisation"],
    &["intercolonization"],
    &["intercolonisation"],
];

pub(crate) static ENTRY_INTERCRYSTALLIZATIONS_15715918494142587543: VariantsMap = [
    &["intercrystallizations"],
    &["intercrystallisations"],
    &["intercrystallizations"],
    &["intercrystallisations"],
];

pub(crate) static ENTRY_INTERCRYSTALLIZATION_535306253275539668: VariantsMap = [
    &["intercrystallization"],
    &["intercrystallisation"],
    &["intercrystallization"],
    &["intercrystallisation"],
];

pub(crate) static ENTRY_INTERCRYSTALLIZES_13807609427203436454: VariantsMap = [
    &["intercrystallizes"],
    &["intercrystallises"],
    &["intercrystallizes"],
    &["intercrystallises"],
];

pub(crate) static ENTRY_INTERCRYSTALLIZE_7702248759277822441: VariantsMap = [
    &["intercrystallize"],
    &["intercrystallise"],
    &["intercrystallize"],
    &["intercrystallise"],
];

pub(crate) static ENTRY_INTERHEMAL_8069091550193247477: VariantsMap = [
    &["interhemal"],
    &["interhaemal"],
    &["interhaemal"],
    &["interhaemal"],
];

pub(crate) static ENTRY_INTERHYBRIDIZES_15088740729497120786: VariantsMap = [
    &["interhybridizes"],
    &["interhybridises"],
    &["interhybridizes"],
    &["interhybridises"],
];

pub(crate) static ENTRY_INTERHYBRIDIZE_11428419392867696597: VariantsMap = [
    &["interhybridize"],
    &["interhybridise"],
    &["interhybridize"],
    &["interhybridise"],
];

pub(crate) static ENTRY_INTERIORIZATION_13293072248187546000: VariantsMap = [
    &["interiorization"],
    &["interiorisation"],
    &["interiorization"],
    &["interiorisation"],
];

pub(crate) static ENTRY_INTERIORIZED_16350287523422070128: VariantsMap = [
    &["interiorized"],
    &["interiorised"],
    &["interiorized"],
    &["interiorised"],
];

pub(crate) static ENTRY_INTERIORIZES_17359761587243653961: VariantsMap = [
    &["interiorizes"],
    &["interiorises"],
    &["interiorizes"],
    &["interiorises"],
];

pub(crate) static ENTRY_INTERIORIZE_3609227527138000868: VariantsMap = [
    &["interiorize"],
    &["interiorise"],
    &["interiorize"],
    &["interiorise"],
];

pub(crate) static ENTRY_INTERIORIZING_4323238478406514613: VariantsMap = [
    &["interiorizing"],
    &["interiorising"],
    &["interiorizing"],
    &["interiorising"],
];

pub(crate) static ENTRY_INTERJECTIONALIZED_5045489232723081851: VariantsMap = [
    &["interjectionalized"],
    &["interjectionalised"],
    &["interjectionalized"],
    &["interjectionalised"],
];

pub(crate) static ENTRY_INTERJECTIONALIZES_13914305345512718530: VariantsMap = [
    &["interjectionalizes"],
    &["interjectionalises"],
    &["interjectionalizes"],
    &["interjectionalises"],
];

pub(crate) static ENTRY_INTERJECTIONALIZE_591313385604347967: VariantsMap = [
    &["interjectionalize"],
    &["interjectionalise"],
    &["interjectionalize"],
    &["interjectionalise"],
];

pub(crate) static ENTRY_INTERJECTIONALIZING_10094859053830302207: VariantsMap = [
    &["interjectionalizing"],
    &["interjectionalising"],
    &["interjectionalizing"],
    &["interjectionalising"],
];

pub(crate) static ENTRY_INTERJECTIONIZES_14093916347873886338: VariantsMap = [
    &["interjectionizes"],
    &["interjectionises"],
    &["interjectionizes"],
    &["interjectionises"],
];

pub(crate) static ENTRY_INTERJECTIONIZE_4980810915948512817: VariantsMap = [
    &["interjectionize"],
    &["interjectionise"],
    &["interjectionize"],
    &["interjectionise"],
];

pub(crate) static ENTRY_INTERJUDGMENTS_14759052647054024995: VariantsMap = [
    &["interjudgments"],
    &["interjudgements"],
    &["interjudgements"],
    &["interjudgements"],
];

pub(crate) static ENTRY_INTERJUDGMENT_8612456108918427681: VariantsMap = [
    &["interjudgment"],
    &["interjudgement"],
    &["interjudgement"],
    &["interjudgement"],
];

pub(crate) static ENTRY_INTERNALIZATIONS_3319603770245748552: VariantsMap = [
    &["internalizations"],
    &["internalisations"],
    &["internalizations"],
    &["internalisations"],
];

pub(crate) static ENTRY_INTERNALIZATION_159848461615772073: VariantsMap = [
    &["internalization"],
    &["internalisation"],
    &["internalization"],
    &["internalisation"],
];

pub(crate) static ENTRY_INTERNALIZED_17544531137085832812: VariantsMap = [
    &["internalized"],
    &["internalised"],
    &["internalized"],
    &["internalised"],
];

pub(crate) static ENTRY_INTERNALIZES_3719150015182585151: VariantsMap = [
    &["internalizes"],
    &["internalises"],
    &["internalizes"],
    &["internalises"],
];

pub(crate) static ENTRY_INTERNALIZE_9052410837903434140: VariantsMap = [
    &["internalize"],
    &["internalise"],
    &["internalize"],
    &["internalise"],
];

pub(crate) static ENTRY_INTERNALIZING_4943964155563804031: VariantsMap = [
    &["internalizing"],
    &["internalising"],
    &["internalizing"],
    &["internalising"],
];

pub(crate) static ENTRY_INTERNATIONALIZATIONS_11949350599612691638: VariantsMap = [
    &["internationalizations"],
    &["internationalisations"],
    &["internationalizations"],
    &["internationalisations"],
];

pub(crate) static ENTRY_INTERNATIONALIZATION_8109207030063572661: VariantsMap = [
    &["internationalization"],
    &["internationalisation"],
    &["internationalization"],
    &["internationalisation"],
];

pub(crate) static ENTRY_INTERNATIONALIZED_7366505194713879567: VariantsMap = [
    &["internationalized"],
    &["internationalised"],
    &["internationalized"],
    &["internationalised"],
];

pub(crate) static ENTRY_INTERNATIONALIZES_6120281846937694012: VariantsMap = [
    &["internationalizes"],
    &["internationalises"],
    &["internationalizes"],
    &["internationalises"],
];

pub(crate) static ENTRY_INTERNATIONALIZE_9450963003714748234: VariantsMap = [
    &["internationalize"],
    &["internationalise"],
    &["internationalize"],
    &["internationalise"],
];

pub(crate) static ENTRY_INTERNATIONALIZING_12026461136750240322: VariantsMap = [
    &["internationalizing"],
    &["internationalising"],
    &["internationalizing"],
    &["internationalising"],
];

pub(crate) static ENTRY_INTERORGANIZATIONAL_3810231326080050928: VariantsMap = [
    &["interorganizational"],
    &["interorganisational"],
    &["interorganizational"],
    &["interorganisational"],
];

pub(crate) static ENTRY_INTIME_16056492823113439440: VariantsMap =
    [&["intime"], &["intimae"], &["intimae"], &["intimae"]];

pub(crate) static ENTRY_INTRAORGANIZATIONS_1216554799512649042: VariantsMap = [
    &["intraorganizations"],
    &["intraorganisations"],
    &["intraorganizations"],
    &["intraorganisations"],
];

pub(crate) static ENTRY_INTRAORGANIZATION_8702660329036380979: VariantsMap = [
    &["intraorganization"],
    &["intraorganisation"],
    &["intraorganization"],
    &["intraorganisation"],
];

pub(crate) static ENTRY_INVIGOR_14173497971570465880: VariantsMap =
    [&["invigor"], &["invigour"], &["invigour"], &["invigour"]];

pub(crate) static ENTRY_IODIZATION_5586899596747043878: VariantsMap = [
    &["iodization"],
    &["iodisation"],
    &["iodization"],
    &["iodisation"],
];

pub(crate) static ENTRY_IODIZED_14153462304228484989: VariantsMap =
    [&["iodized"], &["iodised"], &["iodized"], &["iodised"]];

pub(crate) static ENTRY_IODIZERS_1602693425808401778: VariantsMap =
    [&["iodizers"], &["iodisers"], &["iodizers"], &["iodisers"]];

pub(crate) static ENTRY_IODIZER_5079398846400506402: VariantsMap =
    [&["iodizer"], &["iodiser"], &["iodizer"], &["iodiser"]];

pub(crate) static ENTRY_IODIZES_4704571112577733661: VariantsMap =
    [&["iodizes"], &["iodises"], &["iodizes"], &["iodises"]];

pub(crate) static ENTRY_IODIZE_6551505461584920010: VariantsMap =
    [&["iodize"], &["iodise"], &["iodize"], &["iodise"]];

pub(crate) static ENTRY_IODIZING_6412372743785816878: VariantsMap =
    [&["iodizing"], &["iodising"], &["iodizing"], &["iodising"]];

pub(crate) static ENTRY_IONICIZATIONS_15904942843642930835: VariantsMap = [
    &["ionicizations"],
    &["ionicisations"],
    &["ionicizations"],
    &["ionicisations"],
];

pub(crate) static ENTRY_IONICIZATION_14275328423202505280: VariantsMap = [
    &["ionicization"],
    &["ionicisation"],
    &["ionicization"],
    &["ionicisation"],
];

pub(crate) static ENTRY_IONICIZED_10169630711506345495: VariantsMap = [
    &["ionicized"],
    &["ionicised"],
    &["ionicized"],
    &["ionicised"],
];

pub(crate) static ENTRY_IONICIZES_5099927358201731442: VariantsMap = [
    &["ionicizes"],
    &["ionicises"],
    &["ionicizes"],
    &["ionicises"],
];

pub(crate) static ENTRY_IONICIZE_252607515789455611: VariantsMap =
    [&["ionicize"], &["ionicise"], &["ionicize"], &["ionicise"]];

pub(crate) static ENTRY_IONICIZING_16480798181970686021: VariantsMap = [
    &["ionicizing"],
    &["ionicising"],
    &["ionicizing"],
    &["ionicising"],
];

pub(crate) static ENTRY_IONIZABLER_13678850402565349390: VariantsMap = [
    &["ionizabler"],
    &["ionisabler"],
    &["ionizabler"],
    &["ionisabler"],
];

pub(crate) static ENTRY_IONIZABLEST_11616981145574633025: VariantsMap = [
    &["ionizablest"],
    &["ionisablest"],
    &["ionizablest"],
    &["ionisablest"],
];

pub(crate) static ENTRY_IONIZABLES_11104144020213787190: VariantsMap = [
    &["ionizables"],
    &["ionisables"],
    &["ionizables"],
    &["ionisables"],
];

pub(crate) static ENTRY_IONIZABLE_16754526582239461220: VariantsMap = [
    &["ionizable"],
    &["ionisable"],
    &["ionizable"],
    &["ionisable"],
];

pub(crate) static ENTRY_IONIZATIONS_2745402667451593899: VariantsMap = [
    &["ionizations"],
    &["ionisations"],
    &["ionizations"],
    &["ionisations"],
];

pub(crate) static ENTRY_IONIZATION_8977413361399661805: VariantsMap = [
    &["ionization"],
    &["ionisation"],
    &["ionization"],
    &["ionisation"],
];

pub(crate) static ENTRY_IONIZED_81144343905744698: VariantsMap =
    [&["ionized"], &["ionised"], &["ionized"], &["ionised"]];

pub(crate) static ENTRY_IONIZERS_14153461400591590929: VariantsMap =
    [&["ionizers"], &["ionizers"], &["ionizers"], &["ionizers"]];

pub(crate) static ENTRY_IONIZER_16564271588203588673: VariantsMap =
    [&["ionizer"], &["ionizer"], &["ionizer"], &["ionizer"]];

pub(crate) static ENTRY_IONIZES_18175490219979114523: VariantsMap =
    [&["ionizes"], &["ionises"], &["ionizes"], &["ionises"]];

pub(crate) static ENTRY_IONIZE_16475901568737754789: VariantsMap =
    [&["ionize"], &["ionise"], &["ionize"], &["ionise"]];

pub(crate) static ENTRY_IONIZINGS_1080850027408256472: VariantsMap = [
    &["ionizings"],
    &["ionisings"],
    &["ionizings"],
    &["ionisings"],
];

pub(crate) static ENTRY_IONIZING_1336169812778253456: VariantsMap =
    [&["ionizing"], &["ionising"], &["ionizing"], &["ionising"]];

pub(crate) static ENTRY_IONIZIONS_5183748198612010486: VariantsMap = [
    &["ionizions"],
    &["ionisions"],
    &["ionizions"],
    &["ionisions"],
];

pub(crate) static ENTRY_IONIZION_15367966732951664052: VariantsMap =
    [&["ionizion"], &["ionision"], &["ionizion"], &["ionision"]];

pub(crate) static ENTRY_IPHINOE_2249018876749228073: VariantsMap =
    [&["iphinoe"], &["iphinoae"], &["iphinoae"], &["iphinoae"]];

pub(crate) static ENTRY_IPOMEA_17942946379691060366: VariantsMap =
    [&["ipomea"], &["ipomoea"], &["ipomoea"], &["ipomoea"]];

pub(crate) static ENTRY_IRANIZES_14320284390344997490: VariantsMap =
    [&["iranizes"], &["iranises"], &["iranizes"], &["iranises"]];

pub(crate) static ENTRY_IRANIZE_14984518848921394539: VariantsMap =
    [&["iranize"], &["iranise"], &["iranize"], &["iranise"]];

pub(crate) static ENTRY_IRICIZED_11289808119115340522: VariantsMap =
    [&["iricized"], &["iricised"], &["iricized"], &["iricised"]];

pub(crate) static ENTRY_IRICIZE_5507636142851661219: VariantsMap =
    [&["iricize"], &["iricise"], &["iricize"], &["iricise"]];

pub(crate) static ENTRY_IRICIZING_6368473720803336644: VariantsMap = [
    &["iricizing"],
    &["iricising"],
    &["iricizing"],
    &["iricising"],
];

pub(crate) static ENTRY_IRIDECTOMIZED_3810752923190433476: VariantsMap = [
    &["iridectomized"],
    &["iridectomised"],
    &["iridectomized"],
    &["iridectomised"],
];

pub(crate) static ENTRY_IRIDECTOMIZE_86328183387103922: VariantsMap = [
    &["iridectomize"],
    &["iridectomise"],
    &["iridectomize"],
    &["iridectomise"],
];

pub(crate) static ENTRY_IRIDECTOMIZING_3730176016492424041: VariantsMap = [
    &["iridectomizing"],
    &["iridectomising"],
    &["iridectomizing"],
    &["iridectomising"],
];

pub(crate) static ENTRY_IRIDIZATIONS_17562951663224796668: VariantsMap = [
    &["iridizations"],
    &["iridisations"],
    &["iridizations"],
    &["iridisations"],
];

pub(crate) static ENTRY_IRIDIZATION_10092871928556164080: VariantsMap = [
    &["iridization"],
    &["iridisation"],
    &["iridization"],
    &["iridisation"],
];

pub(crate) static ENTRY_IRIDIZED_7355489127205562934: VariantsMap =
    [&["iridized"], &["iridised"], &["iridized"], &["iridised"]];

pub(crate) static ENTRY_IRIDIZES_17186722611356826762: VariantsMap =
    [&["iridizes"], &["iridises"], &["iridizes"], &["iridises"]];

pub(crate) static ENTRY_IRIDIZE_2104202158839307435: VariantsMap =
    [&["iridize"], &["iridise"], &["iridize"], &["iridise"]];

pub(crate) static ENTRY_IRIDIZING_18250467508898199333: VariantsMap = [
    &["iridizing"],
    &["iridising"],
    &["iridizing"],
    &["iridising"],
];

pub(crate) static ENTRY_IRISHIZED_7371087371918107959: VariantsMap = [
    &["irishized"],
    &["irishised"],
    &["irishized"],
    &["irishised"],
];

pub(crate) static ENTRY_IRISHIZES_13402990074273477360: VariantsMap = [
    &["irishizes"],
    &["irishises"],
    &["irishizes"],
    &["irishises"],
];

pub(crate) static ENTRY_IRISHIZE_16946666616811306545: VariantsMap =
    [&["irishize"], &["irishise"], &["irishize"], &["irishise"]];

pub(crate) static ENTRY_IRISHIZING_7496331717389209111: VariantsMap = [
    &["irishizing"],
    &["irishising"],
    &["irishizing"],
    &["irishising"],
];

pub(crate) static ENTRY_IRONIZED_17698114892762359021: VariantsMap =
    [&["ironized"], &["ironised"], &["ironized"], &["ironised"]];

pub(crate) static ENTRY_IRONIZES_17019087894237992930: VariantsMap =
    [&["ironizes"], &["ironises"], &["ironizes"], &["ironises"]];

pub(crate) static ENTRY_IRONIZE_18110787504657881641: VariantsMap =
    [&["ironize"], &["ironise"], &["ironize"], &["ironise"]];

pub(crate) static ENTRY_IRONIZING_11068082412043423659: VariantsMap = [
    &["ironizing"],
    &["ironising"],
    &["ironizing"],
    &["ironising"],
];

pub(crate) static ENTRY_IRRATIONALIZED_13246734682538802047: VariantsMap = [
    &["irrationalized"],
    &["irrationalised"],
    &["irrationalized"],
    &["irrationalised"],
];

pub(crate) static ENTRY_IRRATIONALIZES_8065254995992628819: VariantsMap = [
    &["irrationalizes"],
    &["irrationalises"],
    &["irrationalizes"],
    &["irrationalises"],
];

pub(crate) static ENTRY_IRRATIONALIZE_8845257735070876188: VariantsMap = [
    &["irrationalize"],
    &["irrationalise"],
    &["irrationalize"],
    &["irrationalise"],
];

pub(crate) static ENTRY_IRRATIONALIZING_11978922020771473408: VariantsMap = [
    &["irrationalizing"],
    &["irrationalising"],
    &["irrationalizing"],
    &["irrationalising"],
];

pub(crate) static ENTRY_IRREALIZABLE_6638234207162807349: VariantsMap = [
    &["irrealizable"],
    &["irrealisable"],
    &["irrealizable"],
    &["irrealisable"],
];

pub(crate) static ENTRY_IRRECOGNIZABLE_17719796395122033372: VariantsMap = [
    &["irrecognizable"],
    &["irrecognisable"],
    &["irrecognizable"],
    &["irrecognisable"],
];

pub(crate) static ENTRY_IRREGULARIZES_6852005375793762938: VariantsMap = [
    &["irregularizes"],
    &["irregularises"],
    &["irregularizes"],
    &["irregularises"],
];

pub(crate) static ENTRY_IRREGULARIZE_10956494208423895030: VariantsMap = [
    &["irregularize"],
    &["irregularise"],
    &["irregularize"],
    &["irregularise"],
];

pub(crate) static ENTRY_ISCHEMIAS_5196750807964195068: VariantsMap = [
    &["ischemias"],
    &["ischaemias"],
    &["ischemias"],
    &["ischaemias"],
];

pub(crate) static ENTRY_ISCHEMIA_4729777747896369761: VariantsMap =
    [&["ischemia"], &["ischaemia"], &["ischemia"], &["ischaemia"]];

pub(crate) static ENTRY_ISCHEMIC_14757992729373341279: VariantsMap =
    [&["ischemic"], &["ischaemic"], &["ischemic"], &["ischaemic"]];

pub(crate) static ENTRY_ISLAMICIZED_16429587923977697429: VariantsMap = [
    &["islamicized"],
    &["islamicised"],
    &["islamicized"],
    &["islamicised"],
];

pub(crate) static ENTRY_ISLAMICIZES_6389752952421773018: VariantsMap = [
    &["islamicizes"],
    &["islamicises"],
    &["islamicizes"],
    &["islamicises"],
];

pub(crate) static ENTRY_ISLAMICIZE_2949509590284400025: VariantsMap = [
    &["islamicize"],
    &["islamicise"],
    &["islamicize"],
    &["islamicise"],
];

pub(crate) static ENTRY_ISLAMICIZING_23850168929317726: VariantsMap = [
    &["islamicizing"],
    &["islamicising"],
    &["islamicizing"],
    &["islamicising"],
];

pub(crate) static ENTRY_ISLAMIZATIONS_7348486256618393812: VariantsMap = [
    &["islamizations"],
    &["islamisations"],
    &["islamizations"],
    &["islamisations"],
];

pub(crate) static ENTRY_ISLAMIZATION_4608858883195228793: VariantsMap = [
    &["islamization"],
    &["islamisation"],
    &["islamization"],
    &["islamisation"],
];

pub(crate) static ENTRY_ISLAMIZED_5471740521815167478: VariantsMap = [
    &["islamized"],
    &["islamised"],
    &["islamized"],
    &["islamised"],
];

pub(crate) static ENTRY_ISLAMIZES_6267509887106064680: VariantsMap = [
    &["islamizes"],
    &["islamises"],
    &["islamizes"],
    &["islamises"],
];

pub(crate) static ENTRY_ISLAMIZE_3716181323919679147: VariantsMap =
    [&["islamize"], &["islamise"], &["islamize"], &["islamise"]];

pub(crate) static ENTRY_ISLAMIZING_17686590495892593881: VariantsMap = [
    &["islamizing"],
    &["islamising"],
    &["islamizing"],
    &["islamising"],
];

pub(crate) static ENTRY_ISOCHRONIZATION_5455751798581610372: VariantsMap = [
    &["isochronization"],
    &["isochronisation"],
    &["isochronization"],
    &["isochronisation"],
];

pub(crate) static ENTRY_ISOCHRONIZED_6953711592892129564: VariantsMap = [
    &["isochronized"],
    &["isochronised"],
    &["isochronized"],
    &["isochronised"],
];

pub(crate) static ENTRY_ISOCHRONIZES_3749787773992422117: VariantsMap = [
    &["isochronizes"],
    &["isochronises"],
    &["isochronizes"],
    &["isochronises"],
];

pub(crate) static ENTRY_ISOCHRONIZE_2891882600957804109: VariantsMap = [
    &["isochronize"],
    &["isochronise"],
    &["isochronize"],
    &["isochronise"],
];

pub(crate) static ENTRY_ISOCHRONIZING_10087011436033155174: VariantsMap = [
    &["isochronizing"],
    &["isochronising"],
    &["isochronizing"],
    &["isochronising"],
];

pub(crate) static ENTRY_ISOIMMUNIZATIONS_5261136359759079737: VariantsMap = [
    &["isoimmunizations"],
    &["isoimmunisations"],
    &["isoimmunizations"],
    &["isoimmunisations"],
];

pub(crate) static ENTRY_ISOIMMUNIZATION_16129604172463725287: VariantsMap = [
    &["isoimmunization"],
    &["isoimmunisation"],
    &["isoimmunization"],
    &["isoimmunisation"],
];

pub(crate) static ENTRY_ISOIMMUNIZES_5630738645861994081: VariantsMap = [
    &["isoimmunizes"],
    &["isoimmunises"],
    &["isoimmunizes"],
    &["isoimmunises"],
];

pub(crate) static ENTRY_ISOIMMUNIZE_1925023617514416731: VariantsMap = [
    &["isoimmunize"],
    &["isoimmunise"],
    &["isoimmunize"],
    &["isoimmunise"],
];

pub(crate) static ENTRY_ISOMERIZATIONS_97375950389314089: VariantsMap = [
    &["isomerizations"],
    &["isomerisations"],
    &["isomerizations"],
    &["isomerisations"],
];

pub(crate) static ENTRY_ISOMERIZATION_5858048477967388064: VariantsMap = [
    &["isomerization"],
    &["isomerisation"],
    &["isomerization"],
    &["isomerisation"],
];

pub(crate) static ENTRY_ISOMERIZED_14764124884003792517: VariantsMap = [
    &["isomerized"],
    &["isomerised"],
    &["isomerized"],
    &["isomerised"],
];

pub(crate) static ENTRY_ISOMERIZES_10200929254514131243: VariantsMap = [
    &["isomerizes"],
    &["isomerises"],
    &["isomerizes"],
    &["isomerises"],
];

pub(crate) static ENTRY_ISOMERIZE_1321699050546721247: VariantsMap = [
    &["isomerize"],
    &["isomerise"],
    &["isomerize"],
    &["isomerise"],
];

pub(crate) static ENTRY_ISOMERIZING_13216788009796842004: VariantsMap = [
    &["isomerizing"],
    &["isomerising"],
    &["isomerizing"],
    &["isomerising"],
];

pub(crate) static ENTRY_ISRAELITIZES_405850961922469630: VariantsMap = [
    &["israelitizes"],
    &["israelitises"],
    &["israelitizes"],
    &["israelitises"],
];

pub(crate) static ENTRY_ISRAELITIZE_2547909155867308223: VariantsMap = [
    &["israelitize"],
    &["israelitise"],
    &["israelitize"],
    &["israelitise"],
];

pub(crate) static ENTRY_ITALIANIZATIONS_15182079831759741298: VariantsMap = [
    &["italianizations"],
    &["italianisations"],
    &["italianizations"],
    &["italianisations"],
];

pub(crate) static ENTRY_ITALIANIZATION_15289371753530527664: VariantsMap = [
    &["italianization"],
    &["italianisation"],
    &["italianization"],
    &["italianisation"],
];

pub(crate) static ENTRY_ITALIANIZED_9265937607616517099: VariantsMap = [
    &["italianized"],
    &["italianised"],
    &["italianized"],
    &["italianised"],
];

pub(crate) static ENTRY_ITALIANIZERS_7438679689208329079: VariantsMap = [
    &["italianizers"],
    &["italianisers"],
    &["italianizers"],
    &["italianisers"],
];

pub(crate) static ENTRY_ITALIANIZER_12425000559882305319: VariantsMap = [
    &["italianizer"],
    &["italianiser"],
    &["italianizer"],
    &["italianiser"],
];

pub(crate) static ENTRY_ITALIANIZES_8935485272412950845: VariantsMap = [
    &["italianizes"],
    &["italianises"],
    &["italianizes"],
    &["italianises"],
];

pub(crate) static ENTRY_ITALIANIZE_3435276594938806940: VariantsMap = [
    &["italianize"],
    &["italianise"],
    &["italianize"],
    &["italianise"],
];

pub(crate) static ENTRY_ITALIANIZING_6882200890707680467: VariantsMap = [
    &["italianizing"],
    &["italianising"],
    &["italianizing"],
    &["italianising"],
];

pub(crate) static ENTRY_ITALICIZATIONS_5819324693969518707: VariantsMap = [
    &["italicizations"],
    &["italicisations"],
    &["italicizations"],
    &["italicisations"],
];

pub(crate) static ENTRY_ITALICIZATION_11392681570163865096: VariantsMap = [
    &["italicization"],
    &["italicisation"],
    &["italicization"],
    &["italicisation"],
];

pub(crate) static ENTRY_ITALICIZED_17732755536256154944: VariantsMap = [
    &["italicized"],
    &["italicised"],
    &["italicized"],
    &["italicised"],
];

pub(crate) static ENTRY_ITALICIZES_15932887042285237466: VariantsMap = [
    &["italicizes"],
    &["italicises"],
    &["italicizes"],
    &["italicises"],
];

pub(crate) static ENTRY_ITALICIZE_9105109899179023320: VariantsMap = [
    &["italicize"],
    &["italicise"],
    &["italicize"],
    &["italicise"],
];

pub(crate) static ENTRY_ITALICIZING_14470630360119711166: VariantsMap = [
    &["italicizing"],
    &["italicising"],
    &["italicizing"],
    &["italicising"],
];

pub(crate) static ENTRY_ITEMIZATIONS_4501467912155184777: VariantsMap = [
    &["itemizations"],
    &["itemisations"],
    &["itemizations"],
    &["itemisations"],
];

pub(crate) static ENTRY_ITEMIZATION_1151183169051499453: VariantsMap = [
    &["itemization"],
    &["itemisation"],
    &["itemization"],
    &["itemisation"],
];

pub(crate) static ENTRY_ITEMIZED_14832736118651335171: VariantsMap =
    [&["itemized"], &["itemised"], &["itemized"], &["itemised"]];

pub(crate) static ENTRY_ITEMIZERS_11782059433108693632: VariantsMap = [
    &["itemizers"],
    &["itemisers"],
    &["itemizers"],
    &["itemisers"],
];

pub(crate) static ENTRY_ITEMIZER_16293437282164566897: VariantsMap =
    [&["itemizer"], &["itemiser"], &["itemizer"], &["itemiser"]];

pub(crate) static ENTRY_ITEMIZES_10919132215830907409: VariantsMap =
    [&["itemizes"], &["itemises"], &["itemizes"], &["itemises"]];

pub(crate) static ENTRY_ITEMIZE_8581418811802894000: VariantsMap =
    [&["itemize"], &["itemise"], &["itemize"], &["itemise"]];

pub(crate) static ENTRY_ITEMIZING_1853557894573485171: VariantsMap = [
    &["itemizing"],
    &["itemising"],
    &["itemizing"],
    &["itemising"],
];

pub(crate) static ENTRY_ITUREANS_17311638727147711544: VariantsMap = [
    &["itureans"],
    &["ituraeans"],
    &["ituraeans"],
    &["ituraeans"],
];

pub(crate) static ENTRY_ITUREAN_1579753874067258559: VariantsMap =
    [&["iturean"], &["ituraean"], &["ituraean"], &["ituraean"]];

pub(crate) static ENTRY_IZING_87221185939223267: VariantsMap =
    [&["izing"], &["ising"], &["izing"], &["ising"]];

pub(crate) static ENTRY_JACOBEAN_2306285500279605747: VariantsMap = [
    &["jacobean"],
    &["jacobaean"],
    &["jacobaean"],
    &["jacobaean"],
];

pub(crate) static ENTRY_JACOBINIZATION_13248835767295513863: VariantsMap = [
    &["jacobinization"],
    &["jacobinisation"],
    &["jacobinization"],
    &["jacobinisation"],
];

pub(crate) static ENTRY_JACOBINIZED_2692791121160783021: VariantsMap = [
    &["jacobinized"],
    &["jacobinised"],
    &["jacobinized"],
    &["jacobinised"],
];

pub(crate) static ENTRY_JACOBINIZES_13185057525743157466: VariantsMap = [
    &["jacobinizes"],
    &["jacobinises"],
    &["jacobinizes"],
    &["jacobinises"],
];

pub(crate) static ENTRY_JACOBINIZE_17126698061231713267: VariantsMap = [
    &["jacobinize"],
    &["jacobinise"],
    &["jacobinize"],
    &["jacobinise"],
];

pub(crate) static ENTRY_JACOBINIZING_17823010425672134088: VariantsMap = [
    &["jacobinizing"],
    &["jacobinising"],
    &["jacobinizing"],
    &["jacobinising"],
];

pub(crate) static ENTRY_JAILBIRDS_10419139708074863941: VariantsMap = [
    &["jailbirds"],
    &["jailbirds"],
    &["jailbirds"],
    &["jailbirds"],
];

pub(crate) static ENTRY_JAILBIRD_1273591597781321313: VariantsMap =
    [&["jailbird"], &["jailbird"], &["jailbird"], &["jailbird"]];

pub(crate) static ENTRY_JAILBREAKS_14725005275090937373: VariantsMap = [
    &["jailbreaks"],
    &["jailbreaks"],
    &["jailbreaks"],
    &["jailbreaks"],
];

pub(crate) static ENTRY_JAILBREAK_12440650553847734510: VariantsMap = [
    &["jailbreak"],
    &["jailbreak"],
    &["jailbreak"],
    &["jailbreak"],
];

pub(crate) static ENTRY_JAILED_10386460292544209566: VariantsMap =
    [&["jailed"], &["jailed"], &["jailed"], &["jailed"]];

pub(crate) static ENTRY_JAILERS_2346423461770093206: VariantsMap =
    [&["jailers"], &["jailers"], &["jailers"], &["jailers"]];

pub(crate) static ENTRY_JAILER_1369890010036246012: VariantsMap =
    [&["jailer"], &["jailer"], &["jailer"], &["jailer"]];

pub(crate) static ENTRY_JAILING_12075029104559606493: VariantsMap =
    [&["jailing"], &["jailing"], &["jailing"], &["jailing"]];

pub(crate) static ENTRY_JAILS_1981100286375396548: VariantsMap =
    [&["jails"], &["jails"], &["jails"], &["jails"]];

pub(crate) static ENTRY_JAIL_4946485521529004110: VariantsMap =
    [&["jail"], &["jail"], &["jail"], &["jail"]];

pub(crate) static ENTRY_JANIZARIES_16592241273420137044: VariantsMap = [
    &["janizaries"],
    &["janisaries"],
    &["janizaries"],
    &["janisaries"],
];

pub(crate) static ENTRY_JANIZARY_5645655583936688977: VariantsMap =
    [&["janizary"], &["janisary"], &["janizary"], &["janisary"]];

pub(crate) static ENTRY_JAPANIZATIONS_15480877777955755597: VariantsMap = [
    &["japanizations"],
    &["japanisations"],
    &["japanizations"],
    &["japanisations"],
];

pub(crate) static ENTRY_JAPANIZATION_3492735518315430155: VariantsMap = [
    &["japanization"],
    &["japanisation"],
    &["japanization"],
    &["japanisation"],
];

pub(crate) static ENTRY_JAPANIZED_16661943840791390096: VariantsMap = [
    &["japanized"],
    &["japanised"],
    &["japanized"],
    &["japanised"],
];

pub(crate) static ENTRY_JAPANIZES_17681743681143797110: VariantsMap = [
    &["japanizes"],
    &["japanises"],
    &["japanizes"],
    &["japanises"],
];

pub(crate) static ENTRY_JAPANIZE_16756105117360579347: VariantsMap =
    [&["japanize"], &["japanise"], &["japanize"], &["japanise"]];

pub(crate) static ENTRY_JAPANIZING_1684002847958973103: VariantsMap = [
    &["japanizing"],
    &["japanising"],
    &["japanizing"],
    &["japanising"],
];

pub(crate) static ENTRY_JARGONIZATIONS_3515989118992786878: VariantsMap = [
    &["jargonizations"],
    &["jargonisations"],
    &["jargonizations"],
    &["jargonisations"],
];

pub(crate) static ENTRY_JARGONIZATION_11704848459485664417: VariantsMap = [
    &["jargonization"],
    &["jargonisation"],
    &["jargonization"],
    &["jargonisation"],
];

pub(crate) static ENTRY_JARGONIZED_6560506332692694911: VariantsMap = [
    &["jargonized"],
    &["jargonised"],
    &["jargonized"],
    &["jargonised"],
];

pub(crate) static ENTRY_JARGONIZES_3262599751720795311: VariantsMap = [
    &["jargonizes"],
    &["jargonises"],
    &["jargonizes"],
    &["jargonises"],
];

pub(crate) static ENTRY_JARGONIZE_13312556972392736698: VariantsMap = [
    &["jargonize"],
    &["jargonise"],
    &["jargonize"],
    &["jargonise"],
];

pub(crate) static ENTRY_JARGONIZING_9271512143905465697: VariantsMap = [
    &["jargonizing"],
    &["jargonising"],
    &["jargonizing"],
    &["jargonising"],
];

pub(crate) static ENTRY_JASPERIZED_13935967158321795558: VariantsMap = [
    &["jasperized"],
    &["jasperised"],
    &["jasperized"],
    &["jasperised"],
];

pub(crate) static ENTRY_JASPERIZES_13853455828472448050: VariantsMap = [
    &["jasperizes"],
    &["jasperises"],
    &["jasperizes"],
    &["jasperises"],
];

pub(crate) static ENTRY_JASPERIZE_1843763799496517999: VariantsMap = [
    &["jasperize"],
    &["jasperise"],
    &["jasperize"],
    &["jasperise"],
];

pub(crate) static ENTRY_JASPERIZING_4150717268435548309: VariantsMap = [
    &["jasperizing"],
    &["jasperising"],
    &["jasperizing"],
    &["jasperising"],
];

pub(crate) static ENTRY_JEOPARDIZATION_2937859644534909830: VariantsMap = [
    &["jeopardization"],
    &["jeopardisation"],
    &["jeopardization"],
    &["jeopardisation"],
];

pub(crate) static ENTRY_JEOPARDIZED_14672030278188616555: VariantsMap = [
    &["jeopardized"],
    &["jeopardised"],
    &["jeopardized"],
    &["jeopardised"],
];

pub(crate) static ENTRY_JEOPARDIZES_14509182339781413876: VariantsMap = [
    &["jeopardizes"],
    &["jeopardises"],
    &["jeopardizes"],
    &["jeopardises"],
];

pub(crate) static ENTRY_JEOPARDIZE_17497435966470167065: VariantsMap = [
    &["jeopardize"],
    &["jeopardise"],
    &["jeopardize"],
    &["jeopardise"],
];

pub(crate) static ENTRY_JEOPARDIZING_17208030805715513372: VariantsMap = [
    &["jeopardizing"],
    &["jeopardising"],
    &["jeopardizing"],
    &["jeopardising"],
];

pub(crate) static ENTRY_JESUITIZATION_11570440961702593723: VariantsMap = [
    &["jesuitization"],
    &["jesuitisation"],
    &["jesuitization"],
    &["jesuitisation"],
];

pub(crate) static ENTRY_JESUITIZED_10458308548218113460: VariantsMap = [
    &["jesuitized"],
    &["jesuitised"],
    &["jesuitized"],
    &["jesuitised"],
];

pub(crate) static ENTRY_JESUITIZES_11157364826076346568: VariantsMap = [
    &["jesuitizes"],
    &["jesuitises"],
    &["jesuitizes"],
    &["jesuitises"],
];

pub(crate) static ENTRY_JESUITIZE_6000644968200136366: VariantsMap = [
    &["jesuitize"],
    &["jesuitise"],
    &["jesuitize"],
    &["jesuitise"],
];

pub(crate) static ENTRY_JESUITIZING_3038475298331527607: VariantsMap = [
    &["jesuitizing"],
    &["jesuitising"],
    &["jesuitizing"],
    &["jesuitising"],
];

pub(crate) static ENTRY_JES_3895759907664524295: VariantsMap =
    [&["jes"], &["joes"], &["joes"], &["joes"]];

pub(crate) static ENTRY_JEWELED_4326992812391453731: VariantsMap =
    [&["jeweled"], &["jewelled"], &["jewelled"], &["jewelled"]];

pub(crate) static ENTRY_JEWELERS_978463834027856886: VariantsMap = [
    &["jewelers"],
    &["jewellers"],
    &["jewellers"],
    &["jewellers"],
];

pub(crate) static ENTRY_JEWELER_5950808914837775836: VariantsMap =
    [&["jeweler"], &["jeweller"], &["jeweller"], &["jeweller"]];

pub(crate) static ENTRY_JEWELING_14303762198587690677: VariantsMap = [
    &["jeweling"],
    &["jewelling"],
    &["jewelling"],
    &["jewelling"],
];

pub(crate) static ENTRY_JEWELRY_4147223673886011898: VariantsMap =
    [&["jewelry"], &["jewellery"], &["jewellery"], &["jewellery"]];

pub(crate) static ENTRY_JOKEY_16351543528249851559: VariantsMap =
    [&["jokey"], &["jokey"], &["jokey"], &["jokey"]];

pub(crate) static ENTRY_JONATHANIZATIONS_7547805422547054800: VariantsMap = [
    &["jonathanizations"],
    &["jonathanisations"],
    &["jonathanizations"],
    &["jonathanisations"],
];

pub(crate) static ENTRY_JONATHANIZATION_2830579624043742887: VariantsMap = [
    &["jonathanization"],
    &["jonathanisation"],
    &["jonathanization"],
    &["jonathanisation"],
];

pub(crate) static ENTRY_JORS_11914557043762091913: VariantsMap =
    [&["jors"], &["jours"], &["jours"], &["jours"]];

pub(crate) static ENTRY_JOR_12696506718808280959: VariantsMap =
    [&["jor"], &["jour"], &["jour"], &["jour"]];

pub(crate) static ENTRY_JOURNALIZATIONS_15308350646861956682: VariantsMap = [
    &["journalizations"],
    &["journalisations"],
    &["journalizations"],
    &["journalisations"],
];

pub(crate) static ENTRY_JOURNALIZATION_359433808018629079: VariantsMap = [
    &["journalization"],
    &["journalisation"],
    &["journalization"],
    &["journalisation"],
];

pub(crate) static ENTRY_JOURNALIZED_9351999491366530812: VariantsMap = [
    &["journalized"],
    &["journalised"],
    &["journalized"],
    &["journalised"],
];

pub(crate) static ENTRY_JOURNALIZERS_4450356968219419478: VariantsMap = [
    &["journalizers"],
    &["journalisers"],
    &["journalizers"],
    &["journalisers"],
];

pub(crate) static ENTRY_JOURNALIZER_17240098793213073148: VariantsMap = [
    &["journalizer"],
    &["journaliser"],
    &["journalizer"],
    &["journaliser"],
];

pub(crate) static ENTRY_JOURNALIZES_413265712215135289: VariantsMap = [
    &["journalizes"],
    &["journalises"],
    &["journalizes"],
    &["journalises"],
];

pub(crate) static ENTRY_JOURNALIZE_6257923934967466362: VariantsMap = [
    &["journalize"],
    &["journalise"],
    &["journalize"],
    &["journalise"],
];

pub(crate) static ENTRY_JOURNALIZING_8770885116969361944: VariantsMap = [
    &["journalizing"],
    &["journalising"],
    &["journalizing"],
    &["journalising"],
];

pub(crate) static ENTRY_JOVIALIZES_15779794696747576301: VariantsMap = [
    &["jovializes"],
    &["jovialises"],
    &["jovializes"],
    &["jovialises"],
];

pub(crate) static ENTRY_JOVIALIZE_14909643151930429709: VariantsMap = [
    &["jovialize"],
    &["jovialise"],
    &["jovialize"],
    &["jovialise"],
];

pub(crate) static ENTRY_JUDAIZATION_2583288495658842253: VariantsMap = [
    &["judaization"],
    &["judaisation"],
    &["judaization"],
    &["judaisation"],
];

pub(crate) static ENTRY_JUDAIZED_5299369943429817200: VariantsMap =
    [&["judaized"], &["judaised"], &["judaized"], &["judaised"]];

pub(crate) static ENTRY_JUDAIZER_9583480883509645105: VariantsMap =
    [&["judaizer"], &["judaiser"], &["judaizer"], &["judaiser"]];

pub(crate) static ENTRY_JUDAIZE_1070374568908494373: VariantsMap =
    [&["judaize"], &["judaise"], &["judaize"], &["judaise"]];

pub(crate) static ENTRY_JUDAIZING_1306927867645370383: VariantsMap = [
    &["judaizing"],
    &["judaising"],
    &["judaizing"],
    &["judaising"],
];

pub(crate) static ENTRY_JUDEANS_10368783411253037037: VariantsMap =
    [&["judeans"], &["judaeans"], &["judaeans"], &["judaeans"]];

pub(crate) static ENTRY_JUDEAN_9802407929966548944: VariantsMap =
    [&["judean"], &["judaean"], &["judaean"], &["judaean"]];

pub(crate) static ENTRY_JUDEOPHOBIA_9347089286565730960: VariantsMap = [
    &["judeophobia"],
    &["judaeophobia"],
    &["judaeophobia"],
    &["judaeophobia"],
];

pub(crate) static ENTRY_JUDGMENTS_6714988350174691861: VariantsMap = [
    &["judgments"],
    &["judgements"],
    &["judgments"],
    &["judgements"],
];

pub(crate) static ENTRY_JUDGMENT_1564861960905688138: VariantsMap =
    [&["judgment"], &["judgement"], &["judgment"], &["judgement"]];

pub(crate) static ENTRY_JUDICIALIZES_7935109342064479052: VariantsMap = [
    &["judicializes"],
    &["judicialises"],
    &["judicializes"],
    &["judicialises"],
];

pub(crate) static ENTRY_JUDICIALIZE_7481303822478621055: VariantsMap = [
    &["judicialize"],
    &["judicialise"],
    &["judicialize"],
    &["judicialise"],
];

pub(crate) static ENTRY_JULIDE_12150077695995964173: VariantsMap =
    [&["julide"], &["julidae"], &["julidae"], &["julidae"]];

pub(crate) static ENTRY_JUMBOIZED_9650613673854154599: VariantsMap = [
    &["jumboized"],
    &["jumboised"],
    &["jumboized"],
    &["jumboised"],
];

pub(crate) static ENTRY_JUMBOIZES_14996632444752145143: VariantsMap = [
    &["jumboizes"],
    &["jumboises"],
    &["jumboizes"],
    &["jumboises"],
];

pub(crate) static ENTRY_JUMBOIZE_15138655937615465445: VariantsMap =
    [&["jumboize"], &["jumboise"], &["jumboize"], &["jumboise"]];

pub(crate) static ENTRY_JUMBOIZING_15027108879327530925: VariantsMap = [
    &["jumboizing"],
    &["jumboising"],
    &["jumboizing"],
    &["jumboising"],
];

pub(crate) static ENTRY_JUVENILIZES_429993400308407468: VariantsMap = [
    &["juvenilizes"],
    &["juvenilises"],
    &["juvenilizes"],
    &["juvenilises"],
];

pub(crate) static ENTRY_JUVENILIZE_2665032966818537333: VariantsMap = [
    &["juvenilize"],
    &["juvenilise"],
    &["juvenilize"],
    &["juvenilise"],
];

pub(crate) static ENTRY_KANE_4237037254996437783: VariantsMap =
    [&["kane"], &["kanae"], &["kanae"], &["kanae"]];

pub(crate) static ENTRY_KAOLINIZATIONS_1147736204566705803: VariantsMap = [
    &["kaolinizations"],
    &["kaolinisations"],
    &["kaolinizations"],
    &["kaolinisations"],
];

pub(crate) static ENTRY_KAOLINIZATION_7991448154248062501: VariantsMap = [
    &["kaolinization"],
    &["kaolinisation"],
    &["kaolinization"],
    &["kaolinisation"],
];

pub(crate) static ENTRY_KAOLINIZED_9549498899357684926: VariantsMap = [
    &["kaolinized"],
    &["kaolinised"],
    &["kaolinized"],
    &["kaolinised"],
];

pub(crate) static ENTRY_KAOLINIZES_6007210570575095960: VariantsMap = [
    &["kaolinizes"],
    &["kaolinises"],
    &["kaolinizes"],
    &["kaolinises"],
];

pub(crate) static ENTRY_KAOLINIZE_10919510675768301839: VariantsMap = [
    &["kaolinize"],
    &["kaolinise"],
    &["kaolinize"],
    &["kaolinise"],
];

pub(crate) static ENTRY_KAOLINIZING_10817594314873964583: VariantsMap = [
    &["kaolinizing"],
    &["kaolinising"],
    &["kaolinizing"],
    &["kaolinising"],
];

pub(crate) static ENTRY_KED_16330510442503716352: VariantsMap =
    [&["ked"], &["kaed"], &["kaed"], &["kaed"]];

pub(crate) static ENTRY_KEIZER_3905342153729010348: VariantsMap =
    [&["keizer"], &["keiser"], &["keizer"], &["keiser"]];

pub(crate) static ENTRY_KELLIA_2765963159143846358: VariantsMap =
    [&["kellia"], &["koellia"], &["koellia"], &["koellia"]];

pub(crate) static ENTRY_KEMBED_13707135129230712936: VariantsMap =
    [&["kembed"], &["kemboed"], &["kemboed"], &["kemboed"]];

pub(crate) static ENTRY_KENNELED_15298221936257378060: VariantsMap = [
    &["kenneled"],
    &["kennelled"],
    &["kennelled"],
    &["kennelled"],
];

pub(crate) static ENTRY_KENNELING_8348856211807242608: VariantsMap = [
    &["kenneling"],
    &["kennelling"],
    &["kennelling"],
    &["kennelling"],
];

pub(crate) static ENTRY_KEPPEL_3068696649582784651: VariantsMap =
    [&["keppel"], &["koeppel"], &["koeppel"], &["koeppel"]];

pub(crate) static ENTRY_KERATINIZATIONS_4745190074411978728: VariantsMap = [
    &["keratinizations"],
    &["keratinisations"],
    &["keratinizations"],
    &["keratinisations"],
];

pub(crate) static ENTRY_KERATINIZATION_2704569985907628734: VariantsMap = [
    &["keratinization"],
    &["keratinisation"],
    &["keratinization"],
    &["keratinisation"],
];

pub(crate) static ENTRY_KERATINIZED_584101825994418545: VariantsMap = [
    &["keratinized"],
    &["keratinised"],
    &["keratinized"],
    &["keratinised"],
];

pub(crate) static ENTRY_KERATINIZES_14523171164749310546: VariantsMap = [
    &["keratinizes"],
    &["keratinises"],
    &["keratinizes"],
    &["keratinises"],
];

pub(crate) static ENTRY_KERATINIZE_10404763732923491961: VariantsMap = [
    &["keratinize"],
    &["keratinise"],
    &["keratinize"],
    &["keratinise"],
];

pub(crate) static ENTRY_KERATINIZING_15375186798258678468: VariantsMap = [
    &["keratinizing"],
    &["keratinising"],
    &["keratinizing"],
    &["keratinising"],
];

pub(crate) static ENTRY_KERIN_12119680575777787053: VariantsMap =
    [&["kerin"], &["krein"], &["krein"], &["krein"]];

pub(crate) static ENTRY_KERNELED_8033424373821514977: VariantsMap = [
    &["kerneled"],
    &["kernelled"],
    &["kernelled"],
    &["kernelled"],
];

pub(crate) static ENTRY_KERNELING_1639558248042323198: VariantsMap = [
    &["kerneling"],
    &["kernelling"],
    &["kernelling"],
    &["kernelling"],
];

pub(crate) static ENTRY_KEROSENES_5578493978698306195: VariantsMap = [
    &["kerosenes"],
    &["kerosenes"],
    &["kerosenes"],
    &["kerosenes"],
];

pub(crate) static ENTRY_KEROSENE_11079706743383213665: VariantsMap =
    [&["kerosene"], &["kerosene"], &["kerosene"], &["kerosene"]];

pub(crate) static ENTRY_KETONEMIA_7553374988631718604: VariantsMap = [
    &["ketonemia"],
    &["ketonaemia"],
    &["ketonaemia"],
    &["ketonaemia"],
];

pub(crate) static ENTRY_KETONIZATIONS_14629309903383300671: VariantsMap = [
    &["ketonizations"],
    &["ketonisations"],
    &["ketonizations"],
    &["ketonisations"],
];

pub(crate) static ENTRY_KETONIZATION_10404300835427344597: VariantsMap = [
    &["ketonization"],
    &["ketonisation"],
    &["ketonization"],
    &["ketonisation"],
];

pub(crate) static ENTRY_KETONIZES_9616017976128138242: VariantsMap = [
    &["ketonizes"],
    &["ketonises"],
    &["ketonizes"],
    &["ketonises"],
];

pub(crate) static ENTRY_KETONIZE_17435606326783529410: VariantsMap =
    [&["ketonize"], &["ketonise"], &["ketonize"], &["ketonise"]];

pub(crate) static ENTRY_KIDNAPPED_8258006507287902376: VariantsMap = [
    &["kidnapped"],
    &["kidnapped"],
    &["kidnapped"],
    &["kidnapped"],
];

pub(crate) static ENTRY_KIDNAPPERS_7511485392866911549: VariantsMap = [
    &["kidnappers"],
    &["kidnappers"],
    &["kidnappers"],
    &["kidnappers"],
];

pub(crate) static ENTRY_KIDNAPPER_1975152379883548277: VariantsMap = [
    &["kidnapper"],
    &["kidnapper"],
    &["kidnapper"],
    &["kidnapper"],
];

pub(crate) static ENTRY_KIDNAPPING_8190098845650201253: VariantsMap = [
    &["kidnapping"],
    &["kidnapping"],
    &["kidnapping"],
    &["kidnapping"],
];

pub(crate) static ENTRY_KILOGRAMS_9413140926934099988: VariantsMap = [
    &["kilograms"],
    &["kilograms"],
    &["kilograms"],
    &["kilograms"],
];

pub(crate) static ENTRY_KILOGRAM_5464515871465238139: VariantsMap =
    [&["kilogram"], &["kilogram"], &["kilogram"], &["kilogram"]];

pub(crate) static ENTRY_KILOLITERS_9786627551420863989: VariantsMap = [
    &["kiloliters"],
    &["kilolitres"],
    &["kilolitres"],
    &["kilolitres"],
];

pub(crate) static ENTRY_KILOLITER_11151444382911560681: VariantsMap = [
    &["kiloliter"],
    &["kilolitre"],
    &["kilolitre"],
    &["kilolitre"],
];

pub(crate) static ENTRY_KILOMETERS_13128037988818073327: VariantsMap = [
    &["kilometers"],
    &["kilometres"],
    &["kilometres"],
    &["kilometres"],
];

pub(crate) static ENTRY_KILOMETER_6603317962568686055: VariantsMap = [
    &["kilometer"],
    &["kilometre"],
    &["kilometre"],
    &["kilometre"],
];

pub(crate) static ENTRY_KINDERGARTNERS_12743938718721034302: VariantsMap = [
    &["kindergartners"],
    &["kindergarteners"],
    &["kindergartners"],
    &["kindergarteners"],
];

pub(crate) static ENTRY_KINDERGARTNER_819228164485485087: VariantsMap = [
    &["kindergartner"],
    &["kindergartener"],
    &["kindergartner"],
    &["kindergartener"],
];

pub(crate) static ENTRY_KINESTHESES_5537328044553929564: VariantsMap = [
    &["kinestheses"],
    &["kinaestheses"],
    &["kinaestheses"],
    &["kinaestheses"],
];

pub(crate) static ENTRY_KINESTHESIAS_16830722998283755883: VariantsMap = [
    &["kinesthesias"],
    &["kinaesthesias"],
    &["kinesthesias"],
    &["kinaesthesias"],
];

pub(crate) static ENTRY_KINESTHESIA_4147711150901246528: VariantsMap = [
    &["kinesthesia"],
    &["kinaesthesia"],
    &["kinesthesia"],
    &["kinaesthesia"],
];

pub(crate) static ENTRY_KINESTHESIS_11584641061195125769: VariantsMap = [
    &["kinesthesis"],
    &["kinaesthesis"],
    &["kinaesthesis"],
    &["kinaesthesis"],
];

pub(crate) static ENTRY_KINESTHETICALLIER_15258389196130357542: VariantsMap = [
    &["kinestheticallier"],
    &["kinaestheticallier"],
    &["kinaestheticallier"],
    &["kinaestheticallier"],
];

pub(crate) static ENTRY_KINESTHETICALLIEST_4433069150068533408: VariantsMap = [
    &["kinestheticalliest"],
    &["kinaestheticalliest"],
    &["kinaestheticalliest"],
    &["kinaestheticalliest"],
];

pub(crate) static ENTRY_KINESTHETICALLY_3795807158430242904: VariantsMap = [
    &["kinesthetically"],
    &["kinaesthetically"],
    &["kinaesthetically"],
    &["kinaesthetically"],
];

pub(crate) static ENTRY_KINESTHETICER_1776286349748412373: VariantsMap = [
    &["kinestheticer"],
    &["kinaestheticer"],
    &["kinestheticer"],
    &["kinaestheticer"],
];

pub(crate) static ENTRY_KINESTHETICEST_17696742886422574314: VariantsMap = [
    &["kinestheticest"],
    &["kinaestheticest"],
    &["kinestheticest"],
    &["kinaestheticest"],
];

pub(crate) static ENTRY_KINESTHETICS_246684268615617993: VariantsMap = [
    &["kinesthetics"],
    &["kinaesthetics"],
    &["kinesthetics"],
    &["kinaesthetics"],
];

pub(crate) static ENTRY_KINESTHETIC_9525542020001536167: VariantsMap = [
    &["kinesthetic"],
    &["kinaesthetic"],
    &["kinesthetic"],
    &["kinaesthetic"],
];

pub(crate) static ENTRY_KOSSEAN_2643003562717992923: VariantsMap =
    [&["kossean"], &["kossaean"], &["kossaean"], &["kossaean"]];

pub(crate) static ENTRY_KYANIZED_9952343296250866459: VariantsMap =
    [&["kyanized"], &["kyanised"], &["kyanized"], &["kyanised"]];

pub(crate) static ENTRY_KYANIZES_3069029591103298866: VariantsMap =
    [&["kyanizes"], &["kyanises"], &["kyanizes"], &["kyanises"]];

pub(crate) static ENTRY_KYANIZE_9586519844157364012: VariantsMap =
    [&["kyanize"], &["kyanise"], &["kyanize"], &["kyanise"]];

pub(crate) static ENTRY_KYANIZING_652034703010533729: VariantsMap = [
    &["kyanizing"],
    &["kyanising"],
    &["kyanizing"],
    &["kyanising"],
];

pub(crate) static ENTRY_KYLES_14720795410762956774: VariantsMap =
    [&["kyles"], &["kyles"], &["kyles"], &["kyles"]];

pub(crate) static ENTRY_LABELABLE_7231451482507254318: VariantsMap = [
    &["labelable"],
    &["labellable"],
    &["labellable"],
    &["labellable"],
];

pub(crate) static ENTRY_LABELED_9725906430384443808: VariantsMap =
    [&["labeled"], &["labelled"], &["labelled"], &["labelled"]];

pub(crate) static ENTRY_LABELERS_13647403983724841259: VariantsMap = [
    &["labelers"],
    &["labellers"],
    &["labellers"],
    &["labellers"],
];

pub(crate) static ENTRY_LABELER_4326972748751944713: VariantsMap =
    [&["labeler"], &["labeller"], &["labeller"], &["labeller"]];

pub(crate) static ENTRY_LABELING_17477269265787703550: VariantsMap = [
    &["labeling"],
    &["labelling"],
    &["labelling"],
    &["labelling"],
];

pub(crate) static ENTRY_LABIALIZATIONS_11100103088554056674: VariantsMap = [
    &["labializations"],
    &["labialisations"],
    &["labializations"],
    &["labialisations"],
];

pub(crate) static ENTRY_LABIALIZATION_15293853718014014842: VariantsMap = [
    &["labialization"],
    &["labialisation"],
    &["labialization"],
    &["labialisation"],
];

pub(crate) static ENTRY_LABIALIZED_13581750401408636148: VariantsMap = [
    &["labialized"],
    &["labialised"],
    &["labialized"],
    &["labialised"],
];

pub(crate) static ENTRY_LABIALIZES_11166772539032438737: VariantsMap = [
    &["labializes"],
    &["labialises"],
    &["labializes"],
    &["labialises"],
];

pub(crate) static ENTRY_LABIALIZE_3849153743438926001: VariantsMap = [
    &["labialize"],
    &["labialise"],
    &["labialize"],
    &["labialise"],
];

pub(crate) static ENTRY_LABIALIZING_2747370128883717480: VariantsMap = [
    &["labializing"],
    &["labialising"],
    &["labializing"],
    &["labialising"],
];

pub(crate) static ENTRY_LABIATE_2435922924163128327: VariantsMap =
    [&["labiate"], &["labiatae"], &["labiatae"], &["labiatae"]];

pub(crate) static ENTRY_LABILIZATIONS_17617289251407409872: VariantsMap = [
    &["labilizations"],
    &["labilisations"],
    &["labilizations"],
    &["labilisations"],
];

pub(crate) static ENTRY_LABILIZATION_13451483296111886301: VariantsMap = [
    &["labilization"],
    &["labilisation"],
    &["labilization"],
    &["labilisation"],
];

pub(crate) static ENTRY_LABILIZES_18075918350625611168: VariantsMap = [
    &["labilizes"],
    &["labilises"],
    &["labilizes"],
    &["labilises"],
];

pub(crate) static ENTRY_LABILIZE_3216640543484180889: VariantsMap =
    [&["labilize"], &["labilise"], &["labilize"], &["labilise"]];

pub(crate) static ENTRY_LABIOVELARIZATION_7949527129202863262: VariantsMap = [
    &["labiovelarization"],
    &["labiovelarisation"],
    &["labiovelarization"],
    &["labiovelarisation"],
];

pub(crate) static ENTRY_LABIOVELARIZED_4381746274512287428: VariantsMap = [
    &["labiovelarized"],
    &["labiovelarised"],
    &["labiovelarized"],
    &["labiovelarised"],
];

pub(crate) static ENTRY_LABIOVELARIZE_5745583009360057266: VariantsMap = [
    &["labiovelarize"],
    &["labiovelarise"],
    &["labiovelarize"],
    &["labiovelarise"],
];

pub(crate) static ENTRY_LABIOVELARIZING_8054689548550433373: VariantsMap = [
    &["labiovelarizing"],
    &["labiovelarising"],
    &["labiovelarizing"],
    &["labiovelarising"],
];

pub(crate) static ENTRY_LABORABILITIES_7797372392120967556: VariantsMap = [
    &["laborabilities"],
    &["labourabilities"],
    &["labourabilities"],
    &["labourabilities"],
];

pub(crate) static ENTRY_LABORABILITY_15883644828666969797: VariantsMap = [
    &["laborability"],
    &["labourability"],
    &["labourability"],
    &["labourability"],
];

pub(crate) static ENTRY_LABORABLES_7918310557704162524: VariantsMap = [
    &["laborables"],
    &["labourables"],
    &["labourables"],
    &["labourables"],
];

pub(crate) static ENTRY_LABORABLE_4111449141966442266: VariantsMap = [
    &["laborable"],
    &["labourable"],
    &["labourable"],
    &["labourable"],
];

pub(crate) static ENTRY_LABORAGE_12473306859130967265: VariantsMap = [
    &["laborage"],
    &["labourage"],
    &["labourage"],
    &["labourage"],
];

pub(crate) static ENTRY_LABOREDLIER_233247574717297785: VariantsMap = [
    &["laboredlier"],
    &["labouredlier"],
    &["labouredlier"],
    &["labouredlier"],
];

pub(crate) static ENTRY_LABOREDLIEST_6121536727069717534: VariantsMap = [
    &["laboredliest"],
    &["labouredliest"],
    &["labouredliest"],
    &["labouredliest"],
];

pub(crate) static ENTRY_LABOREDLY_16392146890289378130: VariantsMap = [
    &["laboredly"],
    &["labouredly"],
    &["labouredly"],
    &["labouredly"],
];

pub(crate) static ENTRY_LABOREDNESSES_11687900312804126120: VariantsMap = [
    &["laborednesses"],
    &["labourednesses"],
    &["labourednesses"],
    &["labourednesses"],
];

pub(crate) static ENTRY_LABOREDNESS_7253397270172707072: VariantsMap = [
    &["laboredness"],
    &["labouredness"],
    &["labouredness"],
    &["labouredness"],
];

pub(crate) static ENTRY_LABORED_17978981141111186545: VariantsMap =
    [&["labored"], &["laboured"], &["laboured"], &["laboured"]];

pub(crate) static ENTRY_LABORERS_1891473305180927612: VariantsMap = [
    &["laborers"],
    &["labourers"],
    &["labourers"],
    &["labourers"],
];

pub(crate) static ENTRY_LABORER_15546004262725309585: VariantsMap =
    [&["laborer"], &["labourer"], &["labourer"], &["labourer"]];

pub(crate) static ENTRY_LABORESS_5168896427468795263: VariantsMap = [
    &["laboress"],
    &["labouress"],
    &["labouress"],
    &["labouress"],
];

pub(crate) static ENTRY_LABORHOODS_4554219923160158770: VariantsMap = [
    &["laborhoods"],
    &["labourhoods"],
    &["labourhoods"],
    &["labourhoods"],
];

pub(crate) static ENTRY_LABORHOOD_2858476689555142869: VariantsMap = [
    &["laborhood"],
    &["labourhood"],
    &["labourhood"],
    &["labourhood"],
];

pub(crate) static ENTRY_LABORINGLIER_13113382106188708192: VariantsMap = [
    &["laboringlier"],
    &["labouringlier"],
    &["labouringlier"],
    &["labouringlier"],
];

pub(crate) static ENTRY_LABORINGLIEST_6064343407107044289: VariantsMap = [
    &["laboringliest"],
    &["labouringliest"],
    &["labouringliest"],
    &["labouringliest"],
];

pub(crate) static ENTRY_LABORINGLY_7190288000401128860: VariantsMap = [
    &["laboringly"],
    &["labouringly"],
    &["labouringly"],
    &["labouringly"],
];

pub(crate) static ENTRY_LABORINGS_10460452481863076398: VariantsMap = [
    &["laborings"],
    &["labourings"],
    &["labourings"],
    &["labourings"],
];

pub(crate) static ENTRY_LABORING_9545557393231100138: VariantsMap = [
    &["laboring"],
    &["labouring"],
    &["labouring"],
    &["labouring"],
];

pub(crate) static ENTRY_LABORISMS_14951457899010464782: VariantsMap = [
    &["laborisms"],
    &["labourisms"],
    &["labourisms"],
    &["labourisms"],
];

pub(crate) static ENTRY_LABORISM_707643266519411033: VariantsMap = [
    &["laborism"],
    &["labourism"],
    &["labourism"],
    &["labourism"],
];

pub(crate) static ENTRY_LABORISTS_9984046093945823347: VariantsMap = [
    &["laborists"],
    &["labourists"],
    &["labourists"],
    &["labourists"],
];

pub(crate) static ENTRY_LABORIST_4404212966525177578: VariantsMap = [
    &["laborist"],
    &["labourist"],
    &["labourist"],
    &["labourist"],
];

pub(crate) static ENTRY_LABORITES_13847041128487303192: VariantsMap = [
    &["laborites"],
    &["labourites"],
    &["labourites"],
    &["labourites"],
];

pub(crate) static ENTRY_LABORITE_5420289708015536043: VariantsMap = [
    &["laborite"],
    &["labourite"],
    &["labourite"],
    &["labourite"],
];

pub(crate) static ENTRY_LABORLESSER_6950542026780244863: VariantsMap = [
    &["laborlesser"],
    &["labourlesser"],
    &["labourlesser"],
    &["labourlesser"],
];

pub(crate) static ENTRY_LABORLESSEST_4725263119506742775: VariantsMap = [
    &["laborlessest"],
    &["labourlessest"],
    &["labourlessest"],
    &["labourlessest"],
];

pub(crate) static ENTRY_LABORLESSES_3618662866437106672: VariantsMap = [
    &["laborlesses"],
    &["labourlesses"],
    &["labourlesses"],
    &["labourlesses"],
];

pub(crate) static ENTRY_LABORLESS_5333428303377019136: VariantsMap = [
    &["laborless"],
    &["labourless"],
    &["labourless"],
    &["labourless"],
];

pub(crate) static ENTRY_LABORSAVING_1003966555581027356: VariantsMap = [
    &["laborsaving"],
    &["laboursaving"],
    &["laboursaving"],
    &["laboursaving"],
];

pub(crate) static ENTRY_LABORSOMELY_14865352057256202178: VariantsMap = [
    &["laborsomely"],
    &["laboursomely"],
    &["laboursomely"],
    &["laboursomely"],
];

pub(crate) static ENTRY_LABORSOME_16467437286971490948: VariantsMap = [
    &["laborsome"],
    &["laboursome"],
    &["laboursome"],
    &["laboursome"],
];

pub(crate) static ENTRY_LABORS_12585701017364719611: VariantsMap =
    [&["labors"], &["labours"], &["labours"], &["labours"]];

pub(crate) static ENTRY_LABOR_6900748202033934783: VariantsMap =
    [&["labor"], &["labour"], &["labour"], &["labour"]];

pub(crate) static ENTRY_LACKLUSTERRER_10237849134270314093: VariantsMap = [
    &["lacklusterrer"],
    &["lacklustrer"],
    &["lacklustrer"],
    &["lacklustrer"],
];

pub(crate) static ENTRY_LACKLUSTERREST_17124785842338778470: VariantsMap = [
    &["lacklusterrest"],
    &["lacklustrest"],
    &["lacklustrest"],
    &["lacklustrest"],
];

pub(crate) static ENTRY_LACKLUSTERS_3942521351652409819: VariantsMap = [
    &["lacklusters"],
    &["lacklustres"],
    &["lacklustres"],
    &["lacklustres"],
];

pub(crate) static ENTRY_LACKLUSTER_2494503323799670808: VariantsMap = [
    &["lackluster"],
    &["lacklustre"],
    &["lacklustre"],
    &["lacklustre"],
];

pub(crate) static ENTRY_LACONIZED_11779313827476836680: VariantsMap = [
    &["laconized"],
    &["laconised"],
    &["laconized"],
    &["laconised"],
];

pub(crate) static ENTRY_LACONIZES_9093953536899310585: VariantsMap = [
    &["laconizes"],
    &["laconises"],
    &["laconizes"],
    &["laconises"],
];

pub(crate) static ENTRY_LACONIZE_9693633598752813366: VariantsMap =
    [&["laconize"], &["laconise"], &["laconize"], &["laconise"]];

pub(crate) static ENTRY_LACONIZING_15917635164362459543: VariantsMap = [
    &["laconizing"],
    &["laconising"],
    &["laconizing"],
    &["laconising"],
];

pub(crate) static ENTRY_LACTONIZED_13709635916917704116: VariantsMap = [
    &["lactonized"],
    &["lactonised"],
    &["lactonized"],
    &["lactonised"],
];

pub(crate) static ENTRY_LAICIZATIONS_6800567689500405023: VariantsMap = [
    &["laicizations"],
    &["laicisations"],
    &["laicizations"],
    &["laicisations"],
];

pub(crate) static ENTRY_LAICIZATION_6195007678259612522: VariantsMap = [
    &["laicization"],
    &["laicisation"],
    &["laicization"],
    &["laicisation"],
];

pub(crate) static ENTRY_LAICIZED_2509011185101191888: VariantsMap =
    [&["laicized"], &["laicised"], &["laicized"], &["laicised"]];

pub(crate) static ENTRY_LAICIZES_3370790220822496415: VariantsMap =
    [&["laicizes"], &["laicises"], &["laicizes"], &["laicises"]];

pub(crate) static ENTRY_LAICIZE_11308741029398318200: VariantsMap =
    [&["laicize"], &["laicise"], &["laicize"], &["laicise"]];

pub(crate) static ENTRY_LAICIZING_4716979153325135165: VariantsMap = [
    &["laicizing"],
    &["laicising"],
    &["laicizing"],
    &["laicising"],
];

pub(crate) static ENTRY_LAIRIZED_6580351855883704967: VariantsMap =
    [&["lairized"], &["lairised"], &["lairized"], &["lairised"]];

pub(crate) static ENTRY_LAIRIZES_16624623563786533004: VariantsMap =
    [&["lairizes"], &["lairises"], &["lairizes"], &["lairises"]];

pub(crate) static ENTRY_LAIRIZE_17048626001120383827: VariantsMap =
    [&["lairize"], &["lairise"], &["lairize"], &["lairise"]];

pub(crate) static ENTRY_LAIRIZING_4521292118527414337: VariantsMap = [
    &["lairizing"],
    &["lairising"],
    &["lairizing"],
    &["lairising"],
];

pub(crate) static ENTRY_LAMINARIZED_1016333654497584825: VariantsMap = [
    &["laminarized"],
    &["laminarised"],
    &["laminarized"],
    &["laminarised"],
];

pub(crate) static ENTRY_LAMINARIZES_14511387789417490165: VariantsMap = [
    &["laminarizes"],
    &["laminarises"],
    &["laminarizes"],
    &["laminarises"],
];

pub(crate) static ENTRY_LAMINARIZE_1889106193228655985: VariantsMap = [
    &["laminarize"],
    &["laminarise"],
    &["laminarize"],
    &["laminarise"],
];

pub(crate) static ENTRY_LAMINARIZING_13590610923176310804: VariantsMap = [
    &["laminarizing"],
    &["laminarising"],
    &["laminarizing"],
    &["laminarising"],
];

pub(crate) static ENTRY_LANDER_14344486190119467949: VariantsMap =
    [&["lander"], &["landre"], &["landre"], &["landre"]];

pub(crate) static ENTRY_LAOTHOE_7381095044467675447: VariantsMap =
    [&["laothoe"], &["laothoae"], &["laothoae"], &["laothoae"]];

pub(crate) static ENTRY_LAPELED_3965699421712198651: VariantsMap =
    [&["lapeled"], &["lapelled"], &["lapelled"], &["lapelled"]];

pub(crate) static ENTRY_LASAGNAS_17494101204628860125: VariantsMap =
    [&["lasagnas"], &["lasagnes"], &["lasagnes"], &["lasagnes"]];

pub(crate) static ENTRY_LASAGNA_12331136899588325414: VariantsMap =
    [&["lasagna"], &["lasagne"], &["lasagne"], &["lasagne"]];

pub(crate) static ENTRY_LASTER_5242258785041708124: VariantsMap =
    [&["laster"], &["lastre"], &["lastre"], &["lastre"]];

pub(crate) static ENTRY_LATENTIZES_7861370147610510510: VariantsMap = [
    &["latentizes"],
    &["latentises"],
    &["latentizes"],
    &["latentises"],
];

pub(crate) static ENTRY_LATENTIZE_5719415759703874116: VariantsMap = [
    &["latentize"],
    &["latentise"],
    &["latentize"],
    &["latentise"],
];

pub(crate) static ENTRY_LATERALIZATIONS_6289621742941669396: VariantsMap = [
    &["lateralizations"],
    &["lateralisations"],
    &["lateralizations"],
    &["lateralisations"],
];

pub(crate) static ENTRY_LATERALIZATION_8041407149896392073: VariantsMap = [
    &["lateralization"],
    &["lateralisation"],
    &["lateralization"],
    &["lateralisation"],
];

pub(crate) static ENTRY_LATERALIZES_7420128468824420970: VariantsMap = [
    &["lateralizes"],
    &["lateralises"],
    &["lateralizes"],
    &["lateralises"],
];

pub(crate) static ENTRY_LATERALIZE_2072178859776576442: VariantsMap = [
    &["lateralize"],
    &["lateralise"],
    &["lateralize"],
    &["lateralise"],
];

pub(crate) static ENTRY_LATERIZATIONS_7796215490525515758: VariantsMap = [
    &["laterizations"],
    &["laterisations"],
    &["laterizations"],
    &["laterisations"],
];

pub(crate) static ENTRY_LATERIZATION_5173633169061109866: VariantsMap = [
    &["laterization"],
    &["laterisation"],
    &["laterization"],
    &["laterisation"],
];

pub(crate) static ENTRY_LATINIZATIONS_3054889801589359637: VariantsMap = [
    &["latinizations"],
    &["latinisations"],
    &["latinizations"],
    &["latinisations"],
];

pub(crate) static ENTRY_LATINIZATION_13723120966984203012: VariantsMap = [
    &["latinization"],
    &["latinisation"],
    &["latinization"],
    &["latinisation"],
];

pub(crate) static ENTRY_LATINIZED_7003535688978595675: VariantsMap = [
    &["latinized"],
    &["latinised"],
    &["latinized"],
    &["latinised"],
];

pub(crate) static ENTRY_LATINIZERS_5843855516266216328: VariantsMap = [
    &["latinizers"],
    &["latinisers"],
    &["latinizers"],
    &["latinisers"],
];

pub(crate) static ENTRY_LATINIZER_2058053073644883801: VariantsMap = [
    &["latinizer"],
    &["latiniser"],
    &["latinizer"],
    &["latiniser"],
];

pub(crate) static ENTRY_LATINIZES_12697197510060274526: VariantsMap = [
    &["latinizes"],
    &["latinises"],
    &["latinizes"],
    &["latinises"],
];

pub(crate) static ENTRY_LATINIZE_3439115749934719092: VariantsMap =
    [&["latinize"], &["latinise"], &["latinize"], &["latinise"]];

pub(crate) static ENTRY_LATINIZING_2597326847289767095: VariantsMap = [
    &["latinizing"],
    &["latinising"],
    &["latinizing"],
    &["latinising"],
];

pub(crate) static ENTRY_LAURELED_11054307884791506795: VariantsMap = [
    &["laureled"],
    &["laurelled"],
    &["laurelled"],
    &["laurelled"],
];

pub(crate) static ENTRY_LAURELING_6770137311186276589: VariantsMap = [
    &["laureling"],
    &["laurelling"],
    &["laurelling"],
    &["laurelling"],
];

pub(crate) static ENTRY_LAURE_841157505029689756: VariantsMap =
    [&["laure"], &["laurae"], &["laurae"], &["laurae"]];

pub(crate) static ENTRY_LAVOLTED_5688164088762295019: VariantsMap = [
    &["lavolted"],
    &["lavoltaed"],
    &["lavoltaed"],
    &["lavoltaed"],
];

pub(crate) static ENTRY_LEARNED_3077939307038472575: VariantsMap = [
    &["learned"],
    &["learned", "learnt"],
    &["learned"],
    &["learned", "learnt"],
];

pub(crate) static ENTRY_LEATHERIZES_10078929234890753420: VariantsMap = [
    &["leatherizes"],
    &["leatherises"],
    &["leatherizes"],
    &["leatherises"],
];

pub(crate) static ENTRY_LEATHERIZE_17693739748797908774: VariantsMap = [
    &["leatherize"],
    &["leatherise"],
    &["leatherize"],
    &["leatherise"],
];

pub(crate) static ENTRY_LEGALIZATIONS_5135517055405810830: VariantsMap = [
    &["legalizations"],
    &["legalisations"],
    &["legalizations"],
    &["legalisations"],
];

pub(crate) static ENTRY_LEGALIZATION_1429633233340705019: VariantsMap = [
    &["legalization"],
    &["legalisation"],
    &["legalization"],
    &["legalisation"],
];

pub(crate) static ENTRY_LEGALIZED_12578108449353920177: VariantsMap = [
    &["legalized"],
    &["legalised"],
    &["legalized"],
    &["legalised"],
];

pub(crate) static ENTRY_LEGALIZES_8869300296267545710: VariantsMap = [
    &["legalizes"],
    &["legalises"],
    &["legalizes"],
    &["legalises"],
];

pub(crate) static ENTRY_LEGALIZE_6922384620678227608: VariantsMap =
    [&["legalize"], &["legalise"], &["legalize"], &["legalise"]];

pub(crate) static ENTRY_LEGALIZING_12535342459582465870: VariantsMap = [
    &["legalizing"],
    &["legalising"],
    &["legalizing"],
    &["legalising"],
];

pub(crate) static ENTRY_LEGGINGS_9393944049752516352: VariantsMap =
    [&["leggings"], &["leggings"], &["leggings"], &["leggings"]];

pub(crate) static ENTRY_LEGGING_2988486252228985931: VariantsMap =
    [&["legging"], &["legging"], &["legging"], &["legging"]];

pub(crate) static ENTRY_LEGITIMATIZED_9454437080445749766: VariantsMap = [
    &["legitimatized"],
    &["legitimatised"],
    &["legitimatized"],
    &["legitimatised"],
];

pub(crate) static ENTRY_LEGITIMATIZES_4219244495979276250: VariantsMap = [
    &["legitimatizes"],
    &["legitimatises"],
    &["legitimatizes"],
    &["legitimatises"],
];

pub(crate) static ENTRY_LEGITIMATIZE_14030890652940162105: VariantsMap = [
    &["legitimatize"],
    &["legitimatise"],
    &["legitimatize"],
    &["legitimatise"],
];

pub(crate) static ENTRY_LEGITIMATIZING_18056063115160381137: VariantsMap = [
    &["legitimatizing"],
    &["legitimatising"],
    &["legitimatizing"],
    &["legitimatising"],
];

pub(crate) static ENTRY_LEGITIMIZATIONS_3098730780220248274: VariantsMap = [
    &["legitimizations"],
    &["legitimisations"],
    &["legitimizations"],
    &["legitimisations"],
];

pub(crate) static ENTRY_LEGITIMIZATION_14065712783120219782: VariantsMap = [
    &["legitimization"],
    &["legitimisation"],
    &["legitimization"],
    &["legitimisation"],
];

pub(crate) static ENTRY_LEGITIMIZED_2017894209000906860: VariantsMap = [
    &["legitimized"],
    &["legitimised"],
    &["legitimized"],
    &["legitimised"],
];

pub(crate) static ENTRY_LEGITIMIZER_17472185937284492353: VariantsMap = [
    &["legitimizer"],
    &["legitimiser"],
    &["legitimizer"],
    &["legitimiser"],
];

pub(crate) static ENTRY_LEGITIMIZES_8915844240859951340: VariantsMap = [
    &["legitimizes"],
    &["legitimises"],
    &["legitimizes"],
    &["legitimises"],
];

pub(crate) static ENTRY_LEGITIMIZE_6363531271843865015: VariantsMap = [
    &["legitimize"],
    &["legitimise"],
    &["legitimize"],
    &["legitimise"],
];

pub(crate) static ENTRY_LEGITIMIZING_1120958333215572753: VariantsMap = [
    &["legitimizing"],
    &["legitimising"],
    &["legitimizing"],
    &["legitimising"],
];

pub(crate) static ENTRY_LEGUMINOSE_13351579956836938693: VariantsMap = [
    &["leguminose"],
    &["leguminosae"],
    &["leguminosae"],
    &["leguminosae"],
];

pub(crate) static ENTRY_LEMMATIZED_18039523576098850991: VariantsMap = [
    &["lemmatized"],
    &["lemmatised"],
    &["lemmatized"],
    &["lemmatised"],
];

pub(crate) static ENTRY_LEMMATIZES_9200074086732700201: VariantsMap = [
    &["lemmatizes"],
    &["lemmatises"],
    &["lemmatizes"],
    &["lemmatises"],
];

pub(crate) static ENTRY_LEMMATIZE_11040947247935760208: VariantsMap = [
    &["lemmatize"],
    &["lemmatise"],
    &["lemmatize"],
    &["lemmatise"],
];

pub(crate) static ENTRY_LEMMATIZING_9177369908160152532: VariantsMap = [
    &["lemmatizing"],
    &["lemmatising"],
    &["lemmatizing"],
    &["lemmatising"],
];

pub(crate) static ENTRY_LEPORIDE_16261088283625577770: VariantsMap = [
    &["leporide"],
    &["leporidae"],
    &["leporidae"],
    &["leporidae"],
];

pub(crate) static ENTRY_LEPTOSPIRE_8197818469635415334: VariantsMap = [
    &["leptospire"],
    &["leptospirae"],
    &["leptospirae"],
    &["leptospirae"],
];

pub(crate) static ENTRY_LERNEAN_14411886954119894826: VariantsMap =
    [&["lernean"], &["lernaean"], &["lernaean"], &["lernaean"]];

pub(crate) static ENTRY_LESSES_11253910437625016547: VariantsMap =
    [&["lesses"], &["loesses"], &["loesses"], &["loesses"]];

pub(crate) static ENTRY_LETHALIZES_134641715057728302: VariantsMap = [
    &["lethalizes"],
    &["lethalises"],
    &["lethalizes"],
    &["lethalises"],
];

pub(crate) static ENTRY_LETHALIZE_10150294278227484131: VariantsMap = [
    &["lethalize"],
    &["lethalise"],
    &["lethalize"],
    &["lethalise"],
];

pub(crate) static ENTRY_LETHARGIZED_4660767625773446412: VariantsMap = [
    &["lethargized"],
    &["lethargised"],
    &["lethargized"],
    &["lethargised"],
];

pub(crate) static ENTRY_LETHARGIZES_9871489060060101043: VariantsMap = [
    &["lethargizes"],
    &["lethargises"],
    &["lethargizes"],
    &["lethargises"],
];

pub(crate) static ENTRY_LETHARGIZE_16053857967216252311: VariantsMap = [
    &["lethargize"],
    &["lethargise"],
    &["lethargize"],
    &["lethargise"],
];

pub(crate) static ENTRY_LETHARGIZING_5842943436072891536: VariantsMap = [
    &["lethargizing"],
    &["lethargising"],
    &["lethargizing"],
    &["lethargising"],
];

pub(crate) static ENTRY_LEUCEMIAS_11620167304888335008: VariantsMap = [
    &["leucemias"],
    &["leucaemias"],
    &["leucaemias"],
    &["leucaemias"],
];

pub(crate) static ENTRY_LEUCEMIA_3591351451144568006: VariantsMap = [
    &["leucemia"],
    &["leucaemia"],
    &["leucaemia"],
    &["leucaemia"],
];

pub(crate) static ENTRY_LEUCEMIC_4805425255684968634: VariantsMap = [
    &["leucemic"],
    &["leucaemic"],
    &["leucaemic"],
    &["leucaemic"],
];

pub(crate) static ENTRY_LEUCHEMIA_17930526525127388484: VariantsMap = [
    &["leuchemia"],
    &["leuchaemia"],
    &["leuchaemia"],
    &["leuchaemia"],
];

pub(crate) static ENTRY_LEUCOCYTHEMIA_6949077817963406299: VariantsMap = [
    &["leucocythemia"],
    &["leucocythaemia"],
    &["leucocythaemia"],
    &["leucocythaemia"],
];

pub(crate) static ENTRY_LEUCOCYTHEMIC_10797182314528433809: VariantsMap = [
    &["leucocythemic"],
    &["leucocythaemic"],
    &["leucocythaemic"],
    &["leucocythaemic"],
];

pub(crate) static ENTRY_LEUCORRHEAL_2096260838462933156: VariantsMap = [
    &["leucorrheal"],
    &["leucorrhoeal"],
    &["leucorrhoeal"],
    &["leucorrhoeal"],
];

pub(crate) static ENTRY_LEUCORRHEAS_12147874623824130705: VariantsMap = [
    &["leucorrheas"],
    &["leucorrhoeas"],
    &["leucorrhoeas"],
    &["leucorrhoeas"],
];

pub(crate) static ENTRY_LEUCORRHEA_12491143111744908996: VariantsMap = [
    &["leucorrhea"],
    &["leucorrhoea"],
    &["leucorrhoea"],
    &["leucorrhoea"],
];

pub(crate) static ENTRY_LEUCOTHOE_11629376781492715609: VariantsMap = [
    &["leucothoe"],
    &["leucothoae"],
    &["leucothoae"],
    &["leucothoae"],
];

pub(crate) static ENTRY_LEUKEMIAS_18410750728698403884: VariantsMap = [
    &["leukemias"],
    &["leukaemias"],
    &["leukemias"],
    &["leukaemias"],
];

pub(crate) static ENTRY_LEUKEMIA_6916516802276369860: VariantsMap =
    [&["leukemia"], &["leukaemia"], &["leukemia"], &["leukaemia"]];

pub(crate) static ENTRY_LEUKEMOGENESES_2038159065666272579: VariantsMap = [
    &["leukemogeneses"],
    &["leukaemogeneses"],
    &["leukaemogeneses"],
    &["leukaemogeneses"],
];

pub(crate) static ENTRY_LEUKEMOGENESIS_10527747651487262766: VariantsMap = [
    &["leukemogenesis"],
    &["leukaemogenesis"],
    &["leukaemogenesis"],
    &["leukaemogenesis"],
];

pub(crate) static ENTRY_LEUKORRHEAL_14955176177356699707: VariantsMap = [
    &["leukorrheal"],
    &["leukorrhoeal"],
    &["leukorrhoeal"],
    &["leukorrhoeal"],
];

pub(crate) static ENTRY_LEUKORRHEA_13781381900549484928: VariantsMap = [
    &["leukorrhea"],
    &["leukorrhoea"],
    &["leukorrhoea"],
    &["leukorrhoea"],
];

pub(crate) static ENTRY_LEVELED_9665469910971131982: VariantsMap =
    [&["leveled"], &["levelled"], &["levelled"], &["levelled"]];

pub(crate) static ENTRY_LEVELERS_15007791514111643804: VariantsMap = [
    &["levelers"],
    &["levellers"],
    &["levellers"],
    &["levellers"],
];

pub(crate) static ENTRY_LEVELER_2582561187239213328: VariantsMap =
    [&["leveler"], &["leveller"], &["leveller"], &["leveller"]];

pub(crate) static ENTRY_LEVELEST_7275123473754767283: VariantsMap = [
    &["levelest"],
    &["levellest"],
    &["levellest"],
    &["levellest"],
];

pub(crate) static ENTRY_LEVELING_2449494232626797630: VariantsMap = [
    &["leveling"],
    &["levelling"],
    &["levelling"],
    &["levelling"],
];

pub(crate) static ENTRY_LEVIGATED_14877617934398376831: VariantsMap = [
    &["levigated"],
    &["laevigated"],
    &["laevigated"],
    &["laevigated"],
];

pub(crate) static ENTRY_LEVIGATES_16135071688652531978: VariantsMap = [
    &["levigates"],
    &["laevigates"],
    &["laevigates"],
    &["laevigates"],
];

pub(crate) static ENTRY_LEVIGATE_15789706620200322738: VariantsMap = [
    &["levigate"],
    &["laevigate"],
    &["laevigate"],
    &["laevigate"],
];

pub(crate) static ENTRY_LEVIGATING_1174558288799674979: VariantsMap = [
    &["levigating"],
    &["laevigating"],
    &["laevigating"],
    &["laevigating"],
];

pub(crate) static ENTRY_LEVODUCTION_2148814985181413340: VariantsMap = [
    &["levoduction"],
    &["laevoduction"],
    &["laevoduction"],
    &["laevoduction"],
];

pub(crate) static ENTRY_LEVOGYRATE_6763119482929043236: VariantsMap = [
    &["levogyrate"],
    &["laevogyrate"],
    &["laevogyrate"],
    &["laevogyrate"],
];

pub(crate) static ENTRY_LEVOGYRE_5734860870890360841: VariantsMap = [
    &["levogyre"],
    &["laevogyre"],
    &["laevogyre"],
    &["laevogyre"],
];

pub(crate) static ENTRY_LEVOGYROUS_6451272270897908077: VariantsMap = [
    &["levogyrous"],
    &["laevogyrous"],
    &["laevogyrous"],
    &["laevogyrous"],
];

pub(crate) static ENTRY_LEVOLACTIC_9857925753879522136: VariantsMap = [
    &["levolactic"],
    &["laevolactic"],
    &["laevolactic"],
    &["laevolactic"],
];

pub(crate) static ENTRY_LEVOROTATIONS_13418481525546457918: VariantsMap = [
    &["levorotations"],
    &["laevorotations"],
    &["laevorotations"],
    &["laevorotations"],
];

pub(crate) static ENTRY_LEVOROTATION_10477206558920364209: VariantsMap = [
    &["levorotation"],
    &["laevorotation"],
    &["laevorotation"],
    &["laevorotation"],
];

pub(crate) static ENTRY_LEVOROTATORY_10540472502808384816: VariantsMap = [
    &["levorotatory"],
    &["laevorotatory"],
    &["laevorotatory"],
    &["laevorotatory"],
];

pub(crate) static ENTRY_LEVOTARTARIC_11386421058271291462: VariantsMap = [
    &["levotartaric"],
    &["laevotartaric"],
    &["laevotartaric"],
    &["laevotartaric"],
];

pub(crate) static ENTRY_LEVOVERSION_15070501857515106835: VariantsMap = [
    &["levoversion"],
    &["laevoversion"],
    &["laevoversion"],
    &["laevoversion"],
];

pub(crate) static ENTRY_LEVO_14542258720001517914: VariantsMap =
    [&["levo"], &["laevo"], &["laevo"], &["laevo"]];

pub(crate) static ENTRY_LEVULIN_17574134793411636672: VariantsMap =
    [&["levulin"], &["laevulin"], &["laevulin"], &["laevulin"]];

pub(crate) static ENTRY_LEVULOSES_14491948310541911092: VariantsMap = [
    &["levuloses"],
    &["laevuloses"],
    &["laevuloses"],
    &["laevuloses"],
];

pub(crate) static ENTRY_LEVULOSE_15099852399033494000: VariantsMap = [
    &["levulose"],
    &["laevulose"],
    &["laevulose"],
    &["laevulose"],
];

pub(crate) static ENTRY_LEXICALIZATIONS_4279807953147321913: VariantsMap = [
    &["lexicalizations"],
    &["lexicalisations"],
    &["lexicalizations"],
    &["lexicalisations"],
];

pub(crate) static ENTRY_LEXICALIZATION_17354516794688165566: VariantsMap = [
    &["lexicalization"],
    &["lexicalisation"],
    &["lexicalization"],
    &["lexicalisation"],
];

pub(crate) static ENTRY_LEXICONIZES_9557853906422825830: VariantsMap = [
    &["lexiconizes"],
    &["lexiconises"],
    &["lexiconizes"],
    &["lexiconises"],
];

pub(crate) static ENTRY_LEXICONIZE_11609885077010802762: VariantsMap = [
    &["lexiconize"],
    &["lexiconise"],
    &["lexiconize"],
    &["lexiconise"],
];

pub(crate) static ENTRY_LIBELANTS_18272012151164220579: VariantsMap = [
    &["libelants"],
    &["libellants"],
    &["libellants"],
    &["libellants"],
];

pub(crate) static ENTRY_LIBELANT_18318555049160704401: VariantsMap = [
    &["libelant"],
    &["libellant"],
    &["libellant"],
    &["libellant"],
];

pub(crate) static ENTRY_LIBELED_4865225818350414783: VariantsMap =
    [&["libeled"], &["libelled"], &["libelled"], &["libelled"]];

pub(crate) static ENTRY_LIBELEES_18236853938926152502: VariantsMap = [
    &["libelees"],
    &["libellees"],
    &["libellees"],
    &["libellees"],
];

pub(crate) static ENTRY_LIBELEE_6476421574039775301: VariantsMap =
    [&["libelee"], &["libellee"], &["libellee"], &["libellee"]];

pub(crate) static ENTRY_LIBELERS_7579436350106243412: VariantsMap = [
    &["libelers"],
    &["libellers"],
    &["libellers"],
    &["libellers"],
];

pub(crate) static ENTRY_LIBELER_17085228261817297321: VariantsMap =
    [&["libeler"], &["libeller"], &["libeller"], &["libeller"]];

pub(crate) static ENTRY_LIBELING_8308337792295462824: VariantsMap = [
    &["libeling"],
    &["libelling"],
    &["libelling"],
    &["libelling"],
];

pub(crate) static ENTRY_LIBELOUSER_15753313718045269506: VariantsMap = [
    &["libelouser"],
    &["libellouser"],
    &["libellouser"],
    &["libellouser"],
];

pub(crate) static ENTRY_LIBELOUSEST_12981542005689062528: VariantsMap = [
    &["libelousest"],
    &["libellousest"],
    &["libellousest"],
    &["libellousest"],
];

pub(crate) static ENTRY_LIBELOUSLIER_9957797103251569597: VariantsMap = [
    &["libelouslier"],
    &["libellouslier"],
    &["libellouslier"],
    &["libellouslier"],
];

pub(crate) static ENTRY_LIBELOUSLIEST_16123024350035836990: VariantsMap = [
    &["libelousliest"],
    &["libellousliest"],
    &["libellousliest"],
    &["libellousliest"],
];

pub(crate) static ENTRY_LIBELOUSLY_5989552200231943704: VariantsMap = [
    &["libelously"],
    &["libellously"],
    &["libellously"],
    &["libellously"],
];

pub(crate) static ENTRY_LIBELOUS_13707976000878000987: VariantsMap = [
    &["libelous"],
    &["libellous"],
    &["libellous"],
    &["libellous"],
];

pub(crate) static ENTRY_LIBERALIZATIONS_13791189277975585532: VariantsMap = [
    &["liberalizations"],
    &["liberalisations"],
    &["liberalizations"],
    &["liberalisations"],
];

pub(crate) static ENTRY_LIBERALIZATION_17550369075193850663: VariantsMap = [
    &["liberalization"],
    &["liberalisation"],
    &["liberalization"],
    &["liberalisation"],
];

pub(crate) static ENTRY_LIBERALIZED_14395627173650056412: VariantsMap = [
    &["liberalized"],
    &["liberalised"],
    &["liberalized"],
    &["liberalised"],
];

pub(crate) static ENTRY_LIBERALIZERS_2604457956948553415: VariantsMap = [
    &["liberalizers"],
    &["liberalisers"],
    &["liberalizers"],
    &["liberalisers"],
];

pub(crate) static ENTRY_LIBERALIZER_12070318024950362610: VariantsMap = [
    &["liberalizer"],
    &["liberaliser"],
    &["liberalizer"],
    &["liberaliser"],
];

pub(crate) static ENTRY_LIBERALIZES_4445826847051855517: VariantsMap = [
    &["liberalizes"],
    &["liberalises"],
    &["liberalizes"],
    &["liberalises"],
];

pub(crate) static ENTRY_LIBERALIZE_18317297344527312130: VariantsMap = [
    &["liberalize"],
    &["liberalise"],
    &["liberalize"],
    &["liberalise"],
];

pub(crate) static ENTRY_LIBERALIZING_12962394088879054166: VariantsMap = [
    &["liberalizing"],
    &["liberalising"],
    &["liberalizing"],
    &["liberalising"],
];

pub(crate) static ENTRY_LICENSED_14395065230293106933: VariantsMap =
    [&["licensed"], &["licensed"], &["licensed"], &["licensed"]];

pub(crate) static ENTRY_LICENSELESSES_13483570119205630906: VariantsMap = [
    &["licenselesses"],
    &["licencelesses"],
    &["licencelesses"],
    &["licencelesses"],
];

pub(crate) static ENTRY_LICENSELESS_8185181790778718082: VariantsMap = [
    &["licenseless"],
    &["licenceless"],
    &["licenceless"],
    &["licenceless"],
];

pub(crate) static ENTRY_LICENSES_11713770293156064365: VariantsMap =
    [&["licenses"], &["licenses"], &["licenses"], &["licenses"]];

pub(crate) static ENTRY_LICENSES_9473213132468022469: VariantsMap =
    [&["licenses"], &["licences"], &["licences"], &["licences"]];

pub(crate) static ENTRY_LICENSE_13648883593492983919: VariantsMap =
    [&["license"], &["license"], &["license"], &["license"]];

pub(crate) static ENTRY_LICENSE_7596905334721482195: VariantsMap =
    [&["license"], &["licence"], &["licence"], &["licence"]];

pub(crate) static ENTRY_LICENSING_15278454752495763579: VariantsMap = [
    &["licensing"],
    &["licensing"],
    &["licensing"],
    &["licensing"],
];

pub(crate) static ENTRY_LICHENIZATIONS_229879429336509734: VariantsMap = [
    &["lichenizations"],
    &["lichenisations"],
    &["lichenizations"],
    &["lichenisations"],
];

pub(crate) static ENTRY_LICHENIZATION_15535665386017437615: VariantsMap = [
    &["lichenization"],
    &["lichenisation"],
    &["lichenization"],
    &["lichenisation"],
];

pub(crate) static ENTRY_LICHENIZED_9848778117506730557: VariantsMap = [
    &["lichenized"],
    &["lichenised"],
    &["lichenized"],
    &["lichenised"],
];

pub(crate) static ENTRY_LICHENIZES_10045103594318910049: VariantsMap = [
    &["lichenizes"],
    &["lichenises"],
    &["lichenizes"],
    &["lichenises"],
];

pub(crate) static ENTRY_LICHENIZE_1218523330923020826: VariantsMap = [
    &["lichenize"],
    &["lichenise"],
    &["lichenize"],
    &["lichenise"],
];

pub(crate) static ENTRY_LICHENIZING_4675116376139174902: VariantsMap = [
    &["lichenizing"],
    &["lichenising"],
    &["lichenizing"],
    &["lichenising"],
];

pub(crate) static ENTRY_LICORICE_6514036211352134052: VariantsMap =
    [&["licorice"], &["liquorice"], &["licorice"], &["licorice"]];

pub(crate) static ENTRY_LIGNITIZES_7337259783024163734: VariantsMap = [
    &["lignitizes"],
    &["lignitises"],
    &["lignitizes"],
    &["lignitises"],
];

pub(crate) static ENTRY_LIGNITIZE_1767530194184708816: VariantsMap = [
    &["lignitize"],
    &["lignitise"],
    &["lignitize"],
    &["lignitise"],
];

pub(crate) static ENTRY_LIGNOSE_12807960118794739477: VariantsMap =
    [&["lignose"], &["lignosae"], &["lignosae"], &["lignosae"]];

pub(crate) static ENTRY_LIGULE_14255542831609864406: VariantsMap =
    [&["ligule"], &["ligulae"], &["ligulae"], &["ligulae"]];

pub(crate) static ENTRY_LIKABILITIES_1914395607629735656: VariantsMap = [
    &["likabilities"],
    &["likeabilities"],
    &["likeabilities"],
    &["likeabilities"],
];

pub(crate) static ENTRY_LIKABILITY_17749543815120781481: VariantsMap = [
    &["likability"],
    &["likeability"],
    &["likeability"],
    &["likeability"],
];

pub(crate) static ENTRY_LIKABLENESSES_6855441341065426255: VariantsMap = [
    &["likablenesses"],
    &["likeablenesses"],
    &["likeablenesses"],
    &["likeablenesses"],
];

pub(crate) static ENTRY_LIKABLENESS_13673349450699272280: VariantsMap = [
    &["likableness"],
    &["likeableness"],
    &["likeableness"],
    &["likeableness"],
];

pub(crate) static ENTRY_LILLIPUTIANIZES_16811775630936201889: VariantsMap = [
    &["lilliputianizes"],
    &["lilliputianises"],
    &["lilliputianizes"],
    &["lilliputianises"],
];

pub(crate) static ENTRY_LILLIPUTIANIZE_11727867587474310781: VariantsMap = [
    &["lilliputianize"],
    &["lilliputianise"],
    &["lilliputianize"],
    &["lilliputianise"],
];

pub(crate) static ENTRY_LINEARIZABLE_18400360953531743213: VariantsMap = [
    &["linearizable"],
    &["linearisable"],
    &["linearizable"],
    &["linearisable"],
];

pub(crate) static ENTRY_LINEARIZATIONS_17748612167806095377: VariantsMap = [
    &["linearizations"],
    &["linearisations"],
    &["linearizations"],
    &["linearisations"],
];

pub(crate) static ENTRY_LINEARIZATION_9279263650346150967: VariantsMap = [
    &["linearization"],
    &["linearisation"],
    &["linearization"],
    &["linearisation"],
];

pub(crate) static ENTRY_LINEARIZED_2234489635191578422: VariantsMap = [
    &["linearized"],
    &["linearised"],
    &["linearized"],
    &["linearised"],
];

pub(crate) static ENTRY_LINEARIZES_9364491053382084700: VariantsMap = [
    &["linearizes"],
    &["linearises"],
    &["linearizes"],
    &["linearises"],
];

pub(crate) static ENTRY_LINEARIZE_7336841783934324744: VariantsMap = [
    &["linearize"],
    &["linearise"],
    &["linearize"],
    &["linearise"],
];

pub(crate) static ENTRY_LINEARIZING_10738882490325913802: VariantsMap = [
    &["linearizing"],
    &["linearising"],
    &["linearizing"],
    &["linearising"],
];

pub(crate) static ENTRY_LINEARIZION_15811782744897496386: VariantsMap = [
    &["linearizion"],
    &["linearision"],
    &["linearizion"],
    &["linearision"],
];

pub(crate) static ENTRY_LINENIZERS_17723432590290079521: VariantsMap = [
    &["linenizers"],
    &["linenisers"],
    &["linenizers"],
    &["linenisers"],
];

pub(crate) static ENTRY_LINENIZER_11892341743174422110: VariantsMap = [
    &["linenizer"],
    &["lineniser"],
    &["linenizer"],
    &["lineniser"],
];

pub(crate) static ENTRY_LINENIZES_13144713631494316074: VariantsMap = [
    &["linenizes"],
    &["linenises"],
    &["linenizes"],
    &["linenises"],
];

pub(crate) static ENTRY_LINENIZE_4255117013207072568: VariantsMap =
    [&["linenize"], &["linenise"], &["linenize"], &["linenise"]];

pub(crate) static ENTRY_LINGE_7553285674660467670: VariantsMap =
    [&["linge"], &["lingoe"], &["lingoe"], &["lingoe"]];

pub(crate) static ENTRY_LINGUALIZES_11625557214170052581: VariantsMap = [
    &["lingualizes"],
    &["lingualises"],
    &["lingualizes"],
    &["lingualises"],
];

pub(crate) static ENTRY_LINGUALIZE_1511015541496198186: VariantsMap = [
    &["lingualize"],
    &["lingualise"],
    &["lingualize"],
    &["lingualise"],
];

pub(crate) static ENTRY_LIONIZABLES_3283556562579171860: VariantsMap = [
    &["lionizables"],
    &["lionisables"],
    &["lionizables"],
    &["lionisables"],
];

pub(crate) static ENTRY_LIONIZABLE_8467501967425405420: VariantsMap = [
    &["lionizable"],
    &["lionisable"],
    &["lionizable"],
    &["lionisable"],
];

pub(crate) static ENTRY_LIONIZATIONS_6471589896326506860: VariantsMap = [
    &["lionizations"],
    &["lionisations"],
    &["lionizations"],
    &["lionisations"],
];

pub(crate) static ENTRY_LIONIZATION_1681225231313208851: VariantsMap = [
    &["lionization"],
    &["lionisation"],
    &["lionization"],
    &["lionisation"],
];

pub(crate) static ENTRY_LIONIZED_1114575847150322021: VariantsMap =
    [&["lionized"], &["lionised"], &["lionized"], &["lionised"]];

pub(crate) static ENTRY_LIONIZERS_8516239737072899840: VariantsMap = [
    &["lionizers"],
    &["lionisers"],
    &["lionizers"],
    &["lionisers"],
];

pub(crate) static ENTRY_LIONIZER_10735887263063669185: VariantsMap =
    [&["lionizer"], &["lioniser"], &["lionizer"], &["lioniser"]];

pub(crate) static ENTRY_LIONIZES_859661935731471597: VariantsMap =
    [&["lionizes"], &["lionises"], &["lionizes"], &["lionises"]];

pub(crate) static ENTRY_LIONIZE_6821818092678063880: VariantsMap =
    [&["lionize"], &["lionise"], &["lionize"], &["lionise"]];

pub(crate) static ENTRY_LIONIZING_10205945039497753785: VariantsMap = [
    &["lionizing"],
    &["lionising"],
    &["lionizing"],
    &["lionising"],
];

pub(crate) static ENTRY_LIPEMIA_15225486669219540679: VariantsMap =
    [&["lipemia"], &["lipaemia"], &["lipaemia"], &["lipaemia"]];

pub(crate) static ENTRY_LIPEMIC_10806335327474718728: VariantsMap =
    [&["lipemic"], &["lipaemic"], &["lipaemic"], &["lipaemic"]];

pub(crate) static ENTRY_LIPOIDEMIA_13270643093276922971: VariantsMap = [
    &["lipoidemia"],
    &["lipoidaemia"],
    &["lipoidaemia"],
    &["lipoidaemia"],
];

pub(crate) static ENTRY_LIQUEFIERS_9846252651053630322: VariantsMap = [
    &["liquefiers"],
    &["liquefiers"],
    &["liquefiers"],
    &["liquefiers"],
];

pub(crate) static ENTRY_LIQUEFIER_14101716175872998571: VariantsMap = [
    &["liquefier"],
    &["liquefier"],
    &["liquefier"],
    &["liquefier"],
];

pub(crate) static ENTRY_LIQUIDIZATION_13675074303920022173: VariantsMap = [
    &["liquidization"],
    &["liquidisation"],
    &["liquidization"],
    &["liquidisation"],
];

pub(crate) static ENTRY_LIQUIDIZED_5980678006594236599: VariantsMap = [
    &["liquidized"],
    &["liquidised"],
    &["liquidized"],
    &["liquidised"],
];

pub(crate) static ENTRY_LIQUIDIZERS_15740552531926766862: VariantsMap = [
    &["liquidizers"],
    &["liquidisers"],
    &["liquidizers"],
    &["liquidisers"],
];

pub(crate) static ENTRY_LIQUIDIZER_14433199094156660496: VariantsMap = [
    &["liquidizer"],
    &["liquidiser"],
    &["liquidizer"],
    &["liquidiser"],
];

pub(crate) static ENTRY_LIQUIDIZES_5754653035068200343: VariantsMap = [
    &["liquidizes"],
    &["liquidises"],
    &["liquidizes"],
    &["liquidises"],
];

pub(crate) static ENTRY_LIQUIDIZE_7779765250864902667: VariantsMap = [
    &["liquidize"],
    &["liquidise"],
    &["liquidize"],
    &["liquidise"],
];

pub(crate) static ENTRY_LIQUIDIZING_11026646695248605621: VariantsMap = [
    &["liquidizing"],
    &["liquidising"],
    &["liquidizing"],
    &["liquidising"],
];

pub(crate) static ENTRY_LISSOMENESSES_17321997662338443285: VariantsMap = [
    &["lissomenesses"],
    &["lissomnesses"],
    &["lissomenesses"],
    &["lissomnesses"],
];

pub(crate) static ENTRY_LISSOMENESS_10505356153447417142: VariantsMap = [
    &["lissomeness"],
    &["lissomness"],
    &["lissomeness"],
    &["lissomness"],
];

pub(crate) static ENTRY_LISTERIZED_2694194050509300683: VariantsMap = [
    &["listerized"],
    &["listerised"],
    &["listerized"],
    &["listerised"],
];

pub(crate) static ENTRY_LISTERIZES_6903942868385427615: VariantsMap = [
    &["listerizes"],
    &["listerises"],
    &["listerizes"],
    &["listerises"],
];

pub(crate) static ENTRY_LISTERIZE_1789669691755689663: VariantsMap = [
    &["listerize"],
    &["listerise"],
    &["listerize"],
    &["listerise"],
];

pub(crate) static ENTRY_LISTERIZING_15961483896286509040: VariantsMap = [
    &["listerizing"],
    &["listerising"],
    &["listerizing"],
    &["listerising"],
];

pub(crate) static ENTRY_LITERALIZATIONS_11027786126710213305: VariantsMap = [
    &["literalizations"],
    &["literalisations"],
    &["literalizations"],
    &["literalisations"],
];

pub(crate) static ENTRY_LITERALIZATION_16579057682189218971: VariantsMap = [
    &["literalization"],
    &["literalisation"],
    &["literalization"],
    &["literalisation"],
];

pub(crate) static ENTRY_LITERALIZED_17139448346953459594: VariantsMap = [
    &["literalized"],
    &["literalised"],
    &["literalized"],
    &["literalised"],
];

pub(crate) static ENTRY_LITERALIZERS_6657290223588440562: VariantsMap = [
    &["literalizers"],
    &["literalisers"],
    &["literalizers"],
    &["literalisers"],
];

pub(crate) static ENTRY_LITERALIZER_18413794030675395560: VariantsMap = [
    &["literalizer"],
    &["literaliser"],
    &["literalizer"],
    &["literaliser"],
];

pub(crate) static ENTRY_LITERALIZES_14783446531151201125: VariantsMap = [
    &["literalizes"],
    &["literalises"],
    &["literalizes"],
    &["literalises"],
];

pub(crate) static ENTRY_LITERALIZE_7488923076722768228: VariantsMap = [
    &["literalize"],
    &["literalise"],
    &["literalize"],
    &["literalise"],
];

pub(crate) static ENTRY_LITERALIZING_17176990014657786316: VariantsMap = [
    &["literalizing"],
    &["literalising"],
    &["literalizing"],
    &["literalising"],
];

pub(crate) static ENTRY_LITERS_12776695440733823940: VariantsMap =
    [&["liters"], &["litres"], &["litres"], &["litres"]];

pub(crate) static ENTRY_LITER_12446429543534900630: VariantsMap =
    [&["liter"], &["litre"], &["litre"], &["litre"]];

pub(crate) static ENTRY_LITHED_4192395907200130721: VariantsMap =
    [&["lithed"], &["lithoed"], &["lithoed"], &["lithoed"]];

pub(crate) static ENTRY_LITHEMIA_6379925803216421556: VariantsMap = [
    &["lithemia"],
    &["lithaemia"],
    &["lithaemia"],
    &["lithaemia"],
];

pub(crate) static ENTRY_LITHEMIC_7018748774788775749: VariantsMap = [
    &["lithemic"],
    &["lithaemic"],
    &["lithaemic"],
    &["lithaemic"],
];

pub(crate) static ENTRY_LITHOGRAPHIZES_3639204701426090508: VariantsMap = [
    &["lithographizes"],
    &["lithographises"],
    &["lithographizes"],
    &["lithographises"],
];

pub(crate) static ENTRY_LITHOGRAPHIZE_16656619554654866733: VariantsMap = [
    &["lithographize"],
    &["lithographise"],
    &["lithographize"],
    &["lithographise"],
];

pub(crate) static ENTRY_LITHOPEDION_18112524864351619969: VariantsMap = [
    &["lithopedion"],
    &["lithopaedion"],
    &["lithopaedion"],
    &["lithopaedion"],
];

pub(crate) static ENTRY_LITHOPEDIUM_8268761739996957556: VariantsMap = [
    &["lithopedium"],
    &["lithopaedium"],
    &["lithopaedium"],
    &["lithopaedium"],
];

pub(crate) static ENTRY_LITHOPHYSE_2447474686750604797: VariantsMap = [
    &["lithophyse"],
    &["lithophysae"],
    &["lithophysae"],
    &["lithophysae"],
];

pub(crate) static ENTRY_LITHOTRITIZED_16101279289408156476: VariantsMap = [
    &["lithotritized"],
    &["lithotritised"],
    &["lithotritized"],
    &["lithotritised"],
];

pub(crate) static ENTRY_LITHOTRITIZES_17793208890442211508: VariantsMap = [
    &["lithotritizes"],
    &["lithotritises"],
    &["lithotritizes"],
    &["lithotritises"],
];

pub(crate) static ENTRY_LITHOTRITIZE_5875367824474338869: VariantsMap = [
    &["lithotritize"],
    &["lithotritise"],
    &["lithotritize"],
    &["lithotritise"],
];

pub(crate) static ENTRY_LITHOTRITIZING_3557016990622667149: VariantsMap = [
    &["lithotritizing"],
    &["lithotritising"],
    &["lithotritizing"],
    &["lithotritising"],
];

pub(crate) static ENTRY_LIVABLE_3901248475092706490: VariantsMap =
    [&["livable"], &["liveable"], &["livable"], &["livable"]];

pub(crate) static ENTRY_LOBOTOMIZED_15930324383958788489: VariantsMap = [
    &["lobotomized"],
    &["lobotomised"],
    &["lobotomized"],
    &["lobotomised"],
];

pub(crate) static ENTRY_LOBOTOMIZES_16177974637639176057: VariantsMap = [
    &["lobotomizes"],
    &["lobotomises"],
    &["lobotomizes"],
    &["lobotomises"],
];

pub(crate) static ENTRY_LOBOTOMIZE_8157557484359506144: VariantsMap = [
    &["lobotomize"],
    &["lobotomise"],
    &["lobotomize"],
    &["lobotomise"],
];

pub(crate) static ENTRY_LOBOTOMIZING_2915569577636182986: VariantsMap = [
    &["lobotomizing"],
    &["lobotomising"],
    &["lobotomizing"],
    &["lobotomising"],
];

pub(crate) static ENTRY_LOCALIZABLER_5186192263224785623: VariantsMap = [
    &["localizabler"],
    &["localisabler"],
    &["localizabler"],
    &["localisabler"],
];

pub(crate) static ENTRY_LOCALIZABLEST_871745589087632617: VariantsMap = [
    &["localizablest"],
    &["localisablest"],
    &["localizablest"],
    &["localisablest"],
];

pub(crate) static ENTRY_LOCALIZABLES_12552472873910273687: VariantsMap = [
    &["localizables"],
    &["localisables"],
    &["localizables"],
    &["localisables"],
];

pub(crate) static ENTRY_LOCALIZABLE_5621481337891586601: VariantsMap = [
    &["localizable"],
    &["localisable"],
    &["localizable"],
    &["localisable"],
];

pub(crate) static ENTRY_LOCALIZATIONS_2073048544247751824: VariantsMap = [
    &["localizations"],
    &["localisations"],
    &["localizations"],
    &["localisations"],
];

pub(crate) static ENTRY_LOCALIZATION_1238475456869979060: VariantsMap = [
    &["localization"],
    &["localisation"],
    &["localization"],
    &["localisation"],
];

pub(crate) static ENTRY_LOCALIZED_7455385096278523226: VariantsMap = [
    &["localized"],
    &["localised"],
    &["localized"],
    &["localised"],
];

pub(crate) static ENTRY_LOCALIZERS_15025775966428286175: VariantsMap = [
    &["localizers"],
    &["localisers"],
    &["localizers"],
    &["localisers"],
];

pub(crate) static ENTRY_LOCALIZER_7157782650234430721: VariantsMap = [
    &["localizer"],
    &["localiser"],
    &["localizer"],
    &["localiser"],
];

pub(crate) static ENTRY_LOCALIZES_3870056311066884314: VariantsMap = [
    &["localizes"],
    &["localises"],
    &["localizes"],
    &["localises"],
];

pub(crate) static ENTRY_LOCALIZE_16099552228413639227: VariantsMap =
    [&["localize"], &["localise"], &["localize"], &["localise"]];

pub(crate) static ENTRY_LOCALIZING_13763510577796965626: VariantsMap = [
    &["localizing"],
    &["localising"],
    &["localizing"],
    &["localising"],
];

pub(crate) static ENTRY_LODICULE_12304146402971909793: VariantsMap = [
    &["lodicule"],
    &["lodiculae"],
    &["lodiculae"],
    &["lodiculae"],
];

pub(crate) static ENTRY_LOED_2853311868916521037: VariantsMap =
    [&["loed"], &["looed"], &["looed"], &["looed"]];

pub(crate) static ENTRY_LOGICALIZATIONS_11292099513888491109: VariantsMap = [
    &["logicalizations"],
    &["logicalisations"],
    &["logicalizations"],
    &["logicalisations"],
];

pub(crate) static ENTRY_LOGICALIZATION_12818715216393851906: VariantsMap = [
    &["logicalization"],
    &["logicalisation"],
    &["logicalization"],
    &["logicalisation"],
];

pub(crate) static ENTRY_LOGICALIZES_10430140462205373333: VariantsMap = [
    &["logicalizes"],
    &["logicalises"],
    &["logicalizes"],
    &["logicalises"],
];

pub(crate) static ENTRY_LOGICALIZE_2176872405258834372: VariantsMap = [
    &["logicalize"],
    &["logicalise"],
    &["logicalize"],
    &["logicalise"],
];

pub(crate) static ENTRY_LOGICIZED_2546846215835324757: VariantsMap = [
    &["logicized"],
    &["logicised"],
    &["logicized"],
    &["logicised"],
];

pub(crate) static ENTRY_LOGICIZES_3568589430640497383: VariantsMap = [
    &["logicizes"],
    &["logicises"],
    &["logicizes"],
    &["logicises"],
];

pub(crate) static ENTRY_LOGICIZE_15843613372926701720: VariantsMap =
    [&["logicize"], &["logicise"], &["logicize"], &["logicise"]];

pub(crate) static ENTRY_LOGICIZING_6614561759161636962: VariantsMap = [
    &["logicizing"],
    &["logicising"],
    &["logicizing"],
    &["logicising"],
];

pub(crate) static ENTRY_LOGOPEDICS_5579541352089166615: VariantsMap = [
    &["logopedics"],
    &["logopaedics"],
    &["logopaedics"],
    &["logopaedics"],
];

pub(crate) static ENTRY_LOGOPEDIC_2956934522226350209: VariantsMap = [
    &["logopedic"],
    &["logopaedic"],
    &["logopaedic"],
    &["logopaedic"],
];

pub(crate) static ENTRY_LOGORRHEAS_1216027759521800987: VariantsMap = [
    &["logorrheas"],
    &["logorrhoeas"],
    &["logorrheas"],
    &["logorrhoeas"],
];

pub(crate) static ENTRY_LOGORRHEA_1908810066516211712: VariantsMap = [
    &["logorrhea"],
    &["logorrhoea"],
    &["logorrhea"],
    &["logorrhoea"],
];

pub(crate) static ENTRY_LONDONIZATIONS_1889334259429879036: VariantsMap = [
    &["londonizations"],
    &["londonisations"],
    &["londonizations"],
    &["londonisations"],
];

pub(crate) static ENTRY_LONDONIZATION_200081076455131667: VariantsMap = [
    &["londonization"],
    &["londonisation"],
    &["londonization"],
    &["londonisation"],
];

pub(crate) static ENTRY_LONDONIZED_16299293806476488564: VariantsMap = [
    &["londonized"],
    &["londonised"],
    &["londonized"],
    &["londonised"],
];

pub(crate) static ENTRY_LONDONIZES_3901227594887662007: VariantsMap = [
    &["londonizes"],
    &["londonises"],
    &["londonizes"],
    &["londonises"],
];

pub(crate) static ENTRY_LONDONIZE_3238748388091982565: VariantsMap = [
    &["londonize"],
    &["londonise"],
    &["londonize"],
    &["londonise"],
];

pub(crate) static ENTRY_LONDONIZING_4059093782595442599: VariantsMap = [
    &["londonizing"],
    &["londonising"],
    &["londonizing"],
    &["londonising"],
];

pub(crate) static ENTRY_LONGEVAL_15368062473073605372: VariantsMap = [
    &["longeval"],
    &["longaeval"],
    &["longaeval"],
    &["longaeval"],
];

pub(crate) static ENTRY_LONGEVOUS_18025689925843224945: VariantsMap = [
    &["longevous"],
    &["longaevous"],
    &["longaevous"],
    &["longaevous"],
];

pub(crate) static ENTRY_LORDY_5781678477358659813: VariantsMap =
    [&["lordy"], &["lourdy"], &["lourdy"], &["lourdy"]];

pub(crate) static ENTRY_LORINGS_15139277523335794013: VariantsMap =
    [&["lorings"], &["lourings"], &["lourings"], &["lourings"]];

pub(crate) static ENTRY_LORY_5690223887549386793: VariantsMap =
    [&["lory"], &["loury"], &["loury"], &["loury"]];

pub(crate) static ENTRY_LOUTER_14462081307219571398: VariantsMap =
    [&["louter"], &["loutre"], &["loutre"], &["loutre"]];

pub(crate) static ENTRY_LOUVERED_645715404753463951: VariantsMap =
    [&["louvered"], &["louvred"], &["louvred"], &["louvred"]];

pub(crate) static ENTRY_LOUVERS_7007967065948552702: VariantsMap =
    [&["louvers"], &["louvres"], &["louvres"], &["louvres"]];

pub(crate) static ENTRY_LOUVER_4804716624330681765: VariantsMap =
    [&["louver"], &["louvre"], &["louvre"], &["louvre"]];

pub(crate) static ENTRY_LOVABILITY_8730410497494295106: VariantsMap = [
    &["lovability"],
    &["lovability"],
    &["lovability"],
    &["lovability"],
];

pub(crate) static ENTRY_LOVABLENESS_14732271905038073610: VariantsMap = [
    &["lovableness"],
    &["lovableness"],
    &["lovableness"],
    &["lovableness"],
];

pub(crate) static ENTRY_LOVABLY_6219831687533495276: VariantsMap =
    [&["lovably"], &["lovably"], &["lovably"], &["lovably"]];

pub(crate) static ENTRY_LOVES_4486785153621169721: VariantsMap =
    [&["loves"], &["loves"], &["loves"], &["loves"]];

pub(crate) static ENTRY_LOVE_16520323727787961615: VariantsMap =
    [&["love"], &["love"], &["love"], &["love"]];

pub(crate) static ENTRY_LOYALIZES_10039035262119911075: VariantsMap = [
    &["loyalizes"],
    &["loyalises"],
    &["loyalizes"],
    &["loyalises"],
];

pub(crate) static ENTRY_LOYALIZE_15988054747149521230: VariantsMap =
    [&["loyalize"], &["loyalise"], &["loyalize"], &["loyalise"]];

pub(crate) static ENTRY_LUMBARIZATIONS_9565306337604753000: VariantsMap = [
    &["lumbarizations"],
    &["lumbarisations"],
    &["lumbarizations"],
    &["lumbarisations"],
];

pub(crate) static ENTRY_LUMBARIZATION_14602498224971235802: VariantsMap = [
    &["lumbarization"],
    &["lumbarisation"],
    &["lumbarization"],
    &["lumbarisation"],
];

pub(crate) static ENTRY_LUNATIZES_1113492957066304386: VariantsMap = [
    &["lunatizes"],
    &["lunatises"],
    &["lunatizes"],
    &["lunatises"],
];

pub(crate) static ENTRY_LUNATIZE_7809892840688807347: VariantsMap =
    [&["lunatize"], &["lunatise"], &["lunatize"], &["lunatise"]];

pub(crate) static ENTRY_LUNULE_13057287095940975866: VariantsMap =
    [&["lunule"], &["lunulae"], &["lunulae"], &["lunulae"]];

pub(crate) static ENTRY_LUPINES_12557265007088872959: VariantsMap =
    [&["lupines"], &["lupins"], &["lupines"], &["lupins"]];

pub(crate) static ENTRY_LUSTERED_18386163894228820867: VariantsMap =
    [&["lustered"], &["lustred"], &["lustred"], &["lustred"]];

pub(crate) static ENTRY_LUSTERING_15456794957624815028: VariantsMap =
    [&["lustering"], &["lustring"], &["lustring"], &["lustring"]];

pub(crate) static ENTRY_LUSTERLESSER_7250450891961099005: VariantsMap = [
    &["lusterlesser"],
    &["lustrelesser"],
    &["lustrelesser"],
    &["lustrelesser"],
];

pub(crate) static ENTRY_LUSTERLESSEST_15709155643033799906: VariantsMap = [
    &["lusterlessest"],
    &["lustrelessest"],
    &["lustrelessest"],
    &["lustrelessest"],
];

pub(crate) static ENTRY_LUSTERLESS_5389478484187307315: VariantsMap = [
    &["lusterless"],
    &["lustreless"],
    &["lustreless"],
    &["lustreless"],
];

pub(crate) static ENTRY_LUSTERS_15623538067173334389: VariantsMap =
    [&["lusters"], &["lustres"], &["lustres"], &["lustres"]];

pub(crate) static ENTRY_LUSTERWARES_18360797893051456330: VariantsMap = [
    &["lusterwares"],
    &["lustrewares"],
    &["lustrewares"],
    &["lustrewares"],
];

pub(crate) static ENTRY_LUSTERWARE_7714995265583039919: VariantsMap = [
    &["lusterware"],
    &["lustreware"],
    &["lustreware"],
    &["lustreware"],
];

pub(crate) static ENTRY_LUSTER_11657857751959453572: VariantsMap =
    [&["luster"], &["lustre"], &["lustre"], &["lustre"]];

pub(crate) static ENTRY_LUTEINIZATIONS_2301336961919403024: VariantsMap = [
    &["luteinizations"],
    &["luteinisations"],
    &["luteinizations"],
    &["luteinisations"],
];

pub(crate) static ENTRY_LUTEINIZATION_10917420500003613570: VariantsMap = [
    &["luteinization"],
    &["luteinisation"],
    &["luteinization"],
    &["luteinisation"],
];

pub(crate) static ENTRY_LUTEINIZED_16548614593509361290: VariantsMap = [
    &["luteinized"],
    &["luteinised"],
    &["luteinized"],
    &["luteinised"],
];

pub(crate) static ENTRY_LUTEINIZES_6496313678658191078: VariantsMap = [
    &["luteinizes"],
    &["luteinises"],
    &["luteinizes"],
    &["luteinises"],
];

pub(crate) static ENTRY_LUTEINIZE_11955489358557604884: VariantsMap = [
    &["luteinize"],
    &["luteinise"],
    &["luteinize"],
    &["luteinise"],
];

pub(crate) static ENTRY_LUTEINIZING_12727551757461309338: VariantsMap = [
    &["luteinizing"],
    &["luteinising"],
    &["luteinizing"],
    &["luteinising"],
];

pub(crate) static ENTRY_LUTHERANIZERS_3104690288699234709: VariantsMap = [
    &["lutheranizers"],
    &["lutheranisers"],
    &["lutheranizers"],
    &["lutheranisers"],
];

pub(crate) static ENTRY_LUTHERANIZER_13007772553916013323: VariantsMap = [
    &["lutheranizer"],
    &["lutheraniser"],
    &["lutheranizer"],
    &["lutheraniser"],
];

pub(crate) static ENTRY_LUTHERANIZES_15371432198725795026: VariantsMap = [
    &["lutheranizes"],
    &["lutheranises"],
    &["lutheranizes"],
    &["lutheranises"],
];

pub(crate) static ENTRY_LUTHERANIZE_6443947515442607976: VariantsMap = [
    &["lutheranize"],
    &["lutheranise"],
    &["lutheranize"],
    &["lutheranise"],
];

pub(crate) static ENTRY_LUTRINE_1583093555111669623: VariantsMap =
    [&["lutrine"], &["lutrinae"], &["lutrinae"], &["lutrinae"]];

pub(crate) static ENTRY_LYMPHEDEMA_4096912347991238867: VariantsMap = [
    &["lymphedema"],
    &["lymphoedema"],
    &["lymphoedema"],
    &["lymphoedema"],
];

pub(crate) static ENTRY_LYMPHEMIA_5556164096475699134: VariantsMap = [
    &["lymphemia"],
    &["lymphaemia"],
    &["lymphaemia"],
    &["lymphaemia"],
];

pub(crate) static ENTRY_LYOPHILIZATIONS_15343691347805562266: VariantsMap = [
    &["lyophilizations"],
    &["lyophilisations"],
    &["lyophilizations"],
    &["lyophilisations"],
];

pub(crate) static ENTRY_LYOPHILIZATION_12426577891143807361: VariantsMap = [
    &["lyophilization"],
    &["lyophilisation"],
    &["lyophilization"],
    &["lyophilisation"],
];

pub(crate) static ENTRY_LYOPHILIZED_541457860358035146: VariantsMap = [
    &["lyophilized"],
    &["lyophilised"],
    &["lyophilized"],
    &["lyophilised"],
];

pub(crate) static ENTRY_LYOPHILIZER_3240181350199502588: VariantsMap = [
    &["lyophilizer"],
    &["lyophiliser"],
    &["lyophilizer"],
    &["lyophiliser"],
];

pub(crate) static ENTRY_LYOPHILIZES_17423281299656389223: VariantsMap = [
    &["lyophilizes"],
    &["lyophilises"],
    &["lyophilizes"],
    &["lyophilises"],
];

pub(crate) static ENTRY_LYOPHILIZE_4883245748865024235: VariantsMap = [
    &["lyophilize"],
    &["lyophilise"],
    &["lyophilize"],
    &["lyophilise"],
];

pub(crate) static ENTRY_LYOPHILIZING_17325205477536159774: VariantsMap = [
    &["lyophilizing"],
    &["lyophilising"],
    &["lyophilizing"],
    &["lyophilising"],
];

pub(crate) static ENTRY_LYRICIZATION_5227207079625028356: VariantsMap = [
    &["lyricization"],
    &["lyricisation"],
    &["lyricization"],
    &["lyricisation"],
];

pub(crate) static ENTRY_LYRICIZED_1377860939111837355: VariantsMap = [
    &["lyricized"],
    &["lyricised"],
    &["lyricized"],
    &["lyricised"],
];

pub(crate) static ENTRY_LYRICIZES_1087674100771642847: VariantsMap = [
    &["lyricizes"],
    &["lyricises"],
    &["lyricizes"],
    &["lyricises"],
];

pub(crate) static ENTRY_LYRICIZE_5679181090729686264: VariantsMap =
    [&["lyricize"], &["lyricise"], &["lyricize"], &["lyricise"]];

pub(crate) static ENTRY_LYRICIZING_16841414967163210794: VariantsMap = [
    &["lyricizing"],
    &["lyricising"],
    &["lyricizing"],
    &["lyricising"],
];

pub(crate) static ENTRY_LYSOGENIZATION_11026822618685223605: VariantsMap = [
    &["lysogenization"],
    &["lysogenisation"],
    &["lysogenization"],
    &["lysogenisation"],
];

pub(crate) static ENTRY_LYSOGENIZED_198501167500625979: VariantsMap = [
    &["lysogenized"],
    &["lysogenised"],
    &["lysogenized"],
    &["lysogenised"],
];

pub(crate) static ENTRY_LYSOGENIZES_1808661323485276222: VariantsMap = [
    &["lysogenizes"],
    &["lysogenises"],
    &["lysogenizes"],
    &["lysogenises"],
];

pub(crate) static ENTRY_LYSOGENIZE_4850978684783834586: VariantsMap = [
    &["lysogenize"],
    &["lysogenise"],
    &["lysogenize"],
    &["lysogenise"],
];

pub(crate) static ENTRY_LYSOGENIZING_8619281309327783502: VariantsMap = [
    &["lysogenizing"],
    &["lysogenising"],
    &["lysogenizing"],
    &["lysogenising"],
];

pub(crate) static ENTRY_MACADAMIZATIONS_13499950338218392948: VariantsMap = [
    &["macadamizations"],
    &["macadamisations"],
    &["macadamizations"],
    &["macadamisations"],
];

pub(crate) static ENTRY_MACADAMIZATION_10150094710685608161: VariantsMap = [
    &["macadamization"],
    &["macadamisation"],
    &["macadamization"],
    &["macadamisation"],
];

pub(crate) static ENTRY_MACADAMIZED_7938719006509938754: VariantsMap = [
    &["macadamized"],
    &["macadamised"],
    &["macadamized"],
    &["macadamised"],
];

pub(crate) static ENTRY_MACADAMIZES_17270116944727731447: VariantsMap = [
    &["macadamizes"],
    &["macadamises"],
    &["macadamizes"],
    &["macadamises"],
];

pub(crate) static ENTRY_MACADAMIZE_12591043180762607828: VariantsMap = [
    &["macadamize"],
    &["macadamise"],
    &["macadamize"],
    &["macadamise"],
];

pub(crate) static ENTRY_MACADAMIZING_13448491539296168208: VariantsMap = [
    &["macadamizing"],
    &["macadamising"],
    &["macadamizing"],
    &["macadamising"],
];

pub(crate) static ENTRY_MACARIZED_3181598146994569773: VariantsMap = [
    &["macarized"],
    &["macarised"],
    &["macarized"],
    &["macarised"],
];

pub(crate) static ENTRY_MACARIZES_7493607414497918990: VariantsMap = [
    &["macarizes"],
    &["macarises"],
    &["macarizes"],
    &["macarises"],
];

pub(crate) static ENTRY_MACARIZE_16257918071730252529: VariantsMap =
    [&["macarize"], &["macarise"], &["macarize"], &["macarise"]];

pub(crate) static ENTRY_MACARIZING_14614397680315741675: VariantsMap = [
    &["macarizing"],
    &["macarising"],
    &["macarizing"],
    &["macarising"],
];

pub(crate) static ENTRY_MACCABEAN_958654750140968533: VariantsMap = [
    &["maccabean"],
    &["maccabaean"],
    &["maccabaean"],
    &["maccabaean"],
];

pub(crate) static ENTRY_MACHINIZATIONS_1078950776046576014: VariantsMap = [
    &["machinizations"],
    &["machinisations"],
    &["machinizations"],
    &["machinisations"],
];

pub(crate) static ENTRY_MACHINIZATION_4606202379585370055: VariantsMap = [
    &["machinization"],
    &["machinisation"],
    &["machinization"],
    &["machinisation"],
];

pub(crate) static ENTRY_MACHINIZES_17958467964158304583: VariantsMap = [
    &["machinizes"],
    &["machinises"],
    &["machinizes"],
    &["machinises"],
];

pub(crate) static ENTRY_MACHINIZE_7203320845244735452: VariantsMap = [
    &["machinize"],
    &["machinise"],
    &["machinize"],
    &["machinise"],
];

pub(crate) static ENTRY_MACRANDER_9929126881067356727: VariantsMap = [
    &["macrander"],
    &["macrandre"],
    &["macrandre"],
    &["macrandre"],
];

pub(crate) static ENTRY_MACULE_3407035185388617437: VariantsMap =
    [&["macule"], &["maculae"], &["maculae"], &["maculae"]];

pub(crate) static ENTRY_MADERA_18034612090128136721: VariantsMap =
    [&["madera"], &["madoera"], &["madoera"], &["madoera"]];

pub(crate) static ENTRY_MADERIZATIONS_7073401233591816042: VariantsMap = [
    &["maderizations"],
    &["maderisations"],
    &["maderizations"],
    &["maderisations"],
];

pub(crate) static ENTRY_MADERIZATION_8101025765502996105: VariantsMap = [
    &["maderization"],
    &["maderisation"],
    &["maderization"],
    &["maderisation"],
];

pub(crate) static ENTRY_MADERIZED_7886331459527867042: VariantsMap = [
    &["maderized"],
    &["maderised"],
    &["maderized"],
    &["maderised"],
];

pub(crate) static ENTRY_MADERIZES_15055886479846917253: VariantsMap = [
    &["maderizes"],
    &["maderises"],
    &["maderizes"],
    &["maderises"],
];

pub(crate) static ENTRY_MADERIZE_2394704387037160176: VariantsMap =
    [&["maderize"], &["maderise"], &["maderize"], &["maderise"]];

pub(crate) static ENTRY_MADERIZING_15157153976270314707: VariantsMap = [
    &["maderizing"],
    &["maderising"],
    &["maderizing"],
    &["maderising"],
];

pub(crate) static ENTRY_MAED_5682712830527035893: VariantsMap =
    [&["maed"], &["maaed"], &["maaed"], &["maaed"]];

pub(crate) static ENTRY_MAENADIC_15288928011763831510: VariantsMap =
    [&["maenadic"], &["maenadic"], &["maenadic"], &["maenadic"]];

pub(crate) static ENTRY_MAENADS_7925698232866691077: VariantsMap =
    [&["maenads"], &["maenads"], &["maenads"], &["maenads"]];

pub(crate) static ENTRY_MAENAD_6687371101734029319: VariantsMap =
    [&["maenad"], &["maenad"], &["maenad"], &["maenad"]];

pub(crate) static ENTRY_MAGICALIZES_230667262651274489: VariantsMap = [
    &["magicalizes"],
    &["magicalises"],
    &["magicalizes"],
    &["magicalises"],
];

pub(crate) static ENTRY_MAGICALIZE_259845292582546245: VariantsMap = [
    &["magicalize"],
    &["magicalise"],
    &["magicalize"],
    &["magicalise"],
];

pub(crate) static ENTRY_MAGNETIZABILITIES_11043943833988980388: VariantsMap = [
    &["magnetizabilities"],
    &["magnetisabilities"],
    &["magnetizabilities"],
    &["magnetisabilities"],
];

pub(crate) static ENTRY_MAGNETIZABILITY_15941565557987915165: VariantsMap = [
    &["magnetizability"],
    &["magnetisability"],
    &["magnetizability"],
    &["magnetisability"],
];

pub(crate) static ENTRY_MAGNETIZABLES_10982571350353432456: VariantsMap = [
    &["magnetizables"],
    &["magnetisables"],
    &["magnetizables"],
    &["magnetisables"],
];

pub(crate) static ENTRY_MAGNETIZABLE_12538903182469509996: VariantsMap = [
    &["magnetizable"],
    &["magnetisable"],
    &["magnetizable"],
    &["magnetisable"],
];

pub(crate) static ENTRY_MAGNETIZATIONS_15259881805845075102: VariantsMap = [
    &["magnetizations"],
    &["magnetisations"],
    &["magnetizations"],
    &["magnetisations"],
];

pub(crate) static ENTRY_MAGNETIZATION_13418480630541927468: VariantsMap = [
    &["magnetization"],
    &["magnetisation"],
    &["magnetization"],
    &["magnetisation"],
];

pub(crate) static ENTRY_MAGNETIZED_329380509853608515: VariantsMap = [
    &["magnetized"],
    &["magnetised"],
    &["magnetized"],
    &["magnetised"],
];

pub(crate) static ENTRY_MAGNETIZERS_6402248007368372769: VariantsMap = [
    &["magnetizers"],
    &["magnetisers"],
    &["magnetizers"],
    &["magnetisers"],
];

pub(crate) static ENTRY_MAGNETIZER_10398668050557629386: VariantsMap = [
    &["magnetizer"],
    &["magnetiser"],
    &["magnetizer"],
    &["magnetiser"],
];

pub(crate) static ENTRY_MAGNETIZES_9519335950988318077: VariantsMap = [
    &["magnetizes"],
    &["magnetises"],
    &["magnetizes"],
    &["magnetises"],
];

pub(crate) static ENTRY_MAGNETIZE_6964246850033574939: VariantsMap = [
    &["magnetize"],
    &["magnetise"],
    &["magnetize"],
    &["magnetise"],
];

pub(crate) static ENTRY_MAGNETIZING_10233564042553328529: VariantsMap = [
    &["magnetizing"],
    &["magnetising"],
    &["magnetizing"],
    &["magnetising"],
];

pub(crate) static ENTRY_MAHOGANIZED_2137275005041857408: VariantsMap = [
    &["mahoganized"],
    &["mahoganised"],
    &["mahoganized"],
    &["mahoganised"],
];

pub(crate) static ENTRY_MAHOGANIZES_2959701861687031680: VariantsMap = [
    &["mahoganizes"],
    &["mahoganises"],
    &["mahoganizes"],
    &["mahoganises"],
];

pub(crate) static ENTRY_MAHOGANIZE_6685229242417344012: VariantsMap = [
    &["mahoganize"],
    &["mahoganise"],
    &["mahoganize"],
    &["mahoganise"],
];

pub(crate) static ENTRY_MAHOGANIZING_16063905374207361931: VariantsMap = [
    &["mahoganizing"],
    &["mahoganising"],
    &["mahoganizing"],
    &["mahoganising"],
];

pub(crate) static ENTRY_MAIGER_14271708748030342793: VariantsMap =
    [&["maiger"], &["maigre"], &["maigre"], &["maigre"]];

pub(crate) static ENTRY_MAINORS_1096950270219286282: VariantsMap =
    [&["mainors"], &["mainours"], &["mainours"], &["mainours"]];

pub(crate) static ENTRY_MAINOR_15155182871533443001: VariantsMap =
    [&["mainor"], &["mainour"], &["mainour"], &["mainour"]];

pub(crate) static ENTRY_MAINPRIZE_12476293352842703157: VariantsMap = [
    &["mainprize"],
    &["mainprise"],
    &["mainprize"],
    &["mainprise"],
];

pub(crate) static ENTRY_MAISTERS_169323063843277028: VariantsMap =
    [&["maisters"], &["maistres"], &["maistres"], &["maistres"]];

pub(crate) static ENTRY_MAIZE_1869902360661909236: VariantsMap =
    [&["maize"], &["maise"], &["maize"], &["maise"]];

pub(crate) static ENTRY_MAJORIZES_12441874624584501250: VariantsMap = [
    &["majorizes"],
    &["majorises"],
    &["majorizes"],
    &["majorises"],
];

pub(crate) static ENTRY_MAJORIZE_18190803152042070767: VariantsMap =
    [&["majorize"], &["majorise"], &["majorize"], &["majorise"]];

pub(crate) static ENTRY_MAJUSCULE_4389141979884550889: VariantsMap = [
    &["majuscule"],
    &["majusculae"],
    &["majusculae"],
    &["majusculae"],
];

pub(crate) static ENTRY_MALAYIZES_7101219180314967639: VariantsMap = [
    &["malayizes"],
    &["malayises"],
    &["malayizes"],
    &["malayises"],
];

pub(crate) static ENTRY_MALAYIZE_9503037103570804575: VariantsMap =
    [&["malayize"], &["malayise"], &["malayize"], &["malayise"]];

pub(crate) static ENTRY_MALLEABLIZES_2447853325264765807: VariantsMap = [
    &["malleablizes"],
    &["malleablises"],
    &["malleablizes"],
    &["malleablises"],
];

pub(crate) static ENTRY_MALLEABLIZE_13860404453532312118: VariantsMap = [
    &["malleablize"],
    &["malleablise"],
    &["malleablize"],
    &["malleablise"],
];

pub(crate) static ENTRY_MALODOROUSNESS_6015133417028203806: VariantsMap = [
    &["malodorousness"],
    &["malodourousness"],
    &["malodourousness"],
    &["malodourousness"],
];

pub(crate) static ENTRY_MALODORS_9161213875879462130: VariantsMap = [
    &["malodors"],
    &["malodours"],
    &["malodours"],
    &["malodours"],
];

pub(crate) static ENTRY_MALODOR_1230117012999961238: VariantsMap =
    [&["malodor"], &["malodour"], &["malodour"], &["malodour"]];

pub(crate) static ENTRY_MANDARINIZES_3405712212187872515: VariantsMap = [
    &["mandarinizes"],
    &["mandarinises"],
    &["mandarinizes"],
    &["mandarinises"],
];

pub(crate) static ENTRY_MANDARINIZE_5395269118667728168: VariantsMap = [
    &["mandarinize"],
    &["mandarinise"],
    &["mandarinize"],
    &["mandarinise"],
];

pub(crate) static ENTRY_MANDEANS_7824922763371535662: VariantsMap = [
    &["mandeans"],
    &["mandaeans"],
    &["mandaeans"],
    &["mandaeans"],
];

pub(crate) static ENTRY_MANDEAN_2244043166169147585: VariantsMap =
    [&["mandean"], &["mandaean"], &["mandaean"], &["mandaean"]];

pub(crate) static ENTRY_MANDOER_1848218089972389391: VariantsMap =
    [&["mandoer"], &["mandore"], &["mandore"], &["mandore"]];

pub(crate) static ENTRY_MANEUVERABILITIES_4377566838265267604: VariantsMap = [
    &["maneuverabilities"],
    &["manoeuvrabilities"],
    &["manoeuvrabilities"],
    &["manoeuvrabilities"],
];

pub(crate) static ENTRY_MANEUVERABILITY_9991738727964618746: VariantsMap = [
    &["maneuverability"],
    &["manoeuvrability"],
    &["manoeuvrability"],
    &["manoeuvrability"],
];

pub(crate) static ENTRY_MANEUVERABLER_16242571769731852453: VariantsMap = [
    &["maneuverabler"],
    &["manoeuvrabler"],
    &["manoeuvrabler"],
    &["manoeuvrabler"],
];

pub(crate) static ENTRY_MANEUVERABLEST_12615804687818900918: VariantsMap = [
    &["maneuverablest"],
    &["manoeuvrablest"],
    &["manoeuvrablest"],
    &["manoeuvrablest"],
];

pub(crate) static ENTRY_MANEUVERABLE_9241543220534916637: VariantsMap = [
    &["maneuverable"],
    &["manoeuvrable"],
    &["manoeuvrable"],
    &["manoeuvrable"],
];

pub(crate) static ENTRY_MANEUVERED_12933808223126942130: VariantsMap = [
    &["maneuvered"],
    &["manoeuvred"],
    &["manoeuvred"],
    &["manoeuvred"],
];

pub(crate) static ENTRY_MANEUVERERS_15934664270324741768: VariantsMap = [
    &["maneuverers"],
    &["manoeuvrers"],
    &["manoeuvrers"],
    &["manoeuvrers"],
];

pub(crate) static ENTRY_MANEUVERER_11024318686818982966: VariantsMap = [
    &["maneuverer"],
    &["manoeuvrer"],
    &["manoeuvrer"],
    &["manoeuvrer"],
];

pub(crate) static ENTRY_MANEUVERINGS_16913311735858326454: VariantsMap = [
    &["maneuverings"],
    &["manoeuvrings"],
    &["manoeuvrings"],
    &["manoeuvrings"],
];

pub(crate) static ENTRY_MANEUVERING_11412530305974280098: VariantsMap = [
    &["maneuvering"],
    &["manoeuvring"],
    &["manoeuvring"],
    &["manoeuvring"],
];

pub(crate) static ENTRY_MANEUVERS_610807745803336129: VariantsMap = [
    &["maneuvers"],
    &["manoeuvres"],
    &["manoeuvres"],
    &["manoeuvres"],
];

pub(crate) static ENTRY_MANEUVER_5387054599640837575: VariantsMap = [
    &["maneuver"],
    &["manoeuvre"],
    &["manoeuvre"],
    &["manoeuvre"],
];

pub(crate) static ENTRY_MANHATTANIZES_11664594499184406647: VariantsMap = [
    &["manhattanizes"],
    &["manhattanises"],
    &["manhattanizes"],
    &["manhattanises"],
];

pub(crate) static ENTRY_MANHATTANIZE_6316984002770135780: VariantsMap = [
    &["manhattanize"],
    &["manhattanise"],
    &["manhattanize"],
    &["manhattanise"],
];

pub(crate) static ENTRY_MANICHEANISM_5295642406319230193: VariantsMap = [
    &["manicheanism"],
    &["manichaeanism"],
    &["manichaeanism"],
    &["manichaeanism"],
];

pub(crate) static ENTRY_MANICHEANS_7059235818280734780: VariantsMap = [
    &["manicheans"],
    &["manichaeans"],
    &["manichaeans"],
    &["manichaeans"],
];

pub(crate) static ENTRY_MANICHEISMS_6305433274391716123: VariantsMap = [
    &["manicheisms"],
    &["manichaeisms"],
    &["manichaeisms"],
    &["manichaeisms"],
];

pub(crate) static ENTRY_MANICHEISM_492395297356386441: VariantsMap = [
    &["manicheism"],
    &["manichaeism"],
    &["manichaeism"],
    &["manichaeism"],
];

pub(crate) static ENTRY_MANICHEUS_2161632630177466302: VariantsMap = [
    &["manicheus"],
    &["manichaeus"],
    &["manichaeus"],
    &["manichaeus"],
];

pub(crate) static ENTRY_MANNERIZES_11335051494000116458: VariantsMap = [
    &["mannerizes"],
    &["mannerises"],
    &["mannerizes"],
    &["mannerises"],
];

pub(crate) static ENTRY_MANNERIZE_17494010187806672576: VariantsMap = [
    &["mannerize"],
    &["mannerise"],
    &["mannerize"],
    &["mannerise"],
];

pub(crate) static ENTRY_MANTES_9814453001954994214: VariantsMap =
    [&["mantes"], &["mantoes"], &["mantoes"], &["mantoes"]];

pub(crate) static ENTRY_MARBLEIZED_4437604505512174882: VariantsMap = [
    &["marbleized"],
    &["marbleised"],
    &["marbleized"],
    &["marbleised"],
];

pub(crate) static ENTRY_MARBLEIZES_4834327648631783601: VariantsMap = [
    &["marbleizes"],
    &["marbleises"],
    &["marbleizes"],
    &["marbleises"],
];

pub(crate) static ENTRY_MARBLEIZE_10560158210625088553: VariantsMap = [
    &["marbleize"],
    &["marbleise"],
    &["marbleize"],
    &["marbleise"],
];

pub(crate) static ENTRY_MARBLEIZING_12106644630219217184: VariantsMap = [
    &["marbleizing"],
    &["marbleising"],
    &["marbleizing"],
    &["marbleising"],
];

pub(crate) static ENTRY_MARGARITE_1356877265318483793: VariantsMap = [
    &["margarite"],
    &["margaritae"],
    &["margaritae"],
    &["margaritae"],
];

pub(crate) static ENTRY_MARGINALIZATION_1233702880571492640: VariantsMap = [
    &["marginalization"],
    &["marginalisation"],
    &["marginalization"],
    &["marginalisation"],
];

pub(crate) static ENTRY_MARGINALIZED_2250429301168529865: VariantsMap = [
    &["marginalized"],
    &["marginalised"],
    &["marginalized"],
    &["marginalised"],
];

pub(crate) static ENTRY_MARGINALIZES_18154888411839614068: VariantsMap = [
    &["marginalizes"],
    &["marginalises"],
    &["marginalizes"],
    &["marginalises"],
];

pub(crate) static ENTRY_MARGINALIZE_5790484722094120614: VariantsMap = [
    &["marginalize"],
    &["marginalise"],
    &["marginalize"],
    &["marginalise"],
];

pub(crate) static ENTRY_MARGINALIZING_7021233111114059911: VariantsMap = [
    &["marginalizing"],
    &["marginalising"],
    &["marginalizing"],
    &["marginalising"],
];

pub(crate) static ENTRY_MARMARIZED_4375398795551807227: VariantsMap = [
    &["marmarized"],
    &["marmarised"],
    &["marmarized"],
    &["marmarised"],
];

pub(crate) static ENTRY_MARMARIZES_15375966147001754735: VariantsMap = [
    &["marmarizes"],
    &["marmarises"],
    &["marmarizes"],
    &["marmarises"],
];

pub(crate) static ENTRY_MARMARIZE_13936404510552809323: VariantsMap = [
    &["marmarize"],
    &["marmarise"],
    &["marmarize"],
    &["marmarise"],
];

pub(crate) static ENTRY_MARMARIZING_3793569524149852443: VariantsMap = [
    &["marmarizing"],
    &["marmarising"],
    &["marmarizing"],
    &["marmarising"],
];

pub(crate) static ENTRY_MARMELIZED_12473285779423633628: VariantsMap = [
    &["marmelized"],
    &["marmelised"],
    &["marmelized"],
    &["marmelised"],
];

pub(crate) static ENTRY_MARMELIZES_8910323184633820900: VariantsMap = [
    &["marmelizes"],
    &["marmelises"],
    &["marmelizes"],
    &["marmelises"],
];

pub(crate) static ENTRY_MARMELIZE_16707250168612411670: VariantsMap = [
    &["marmelize"],
    &["marmelise"],
    &["marmelize"],
    &["marmelise"],
];

pub(crate) static ENTRY_MARMELIZING_5395951919003314838: VariantsMap = [
    &["marmelizing"],
    &["marmelising"],
    &["marmelizing"],
    &["marmelising"],
];

pub(crate) static ENTRY_MARSHALED_14436567244270856596: VariantsMap = [
    &["marshaled"],
    &["marshalled"],
    &["marshalled"],
    &["marshalled"],
];

pub(crate) static ENTRY_MARSHALING_16452448580048913285: VariantsMap = [
    &["marshaling"],
    &["marshalling"],
    &["marshalling"],
    &["marshalling"],
];

pub(crate) static ENTRY_MARSUPIALIZATIONS_131817236626667525: VariantsMap = [
    &["marsupializations"],
    &["marsupialisations"],
    &["marsupializations"],
    &["marsupialisations"],
];

pub(crate) static ENTRY_MARSUPIALIZATION_8918810560002724439: VariantsMap = [
    &["marsupialization"],
    &["marsupialisation"],
    &["marsupialization"],
    &["marsupialisation"],
];

pub(crate) static ENTRY_MARSUPIALIZED_7333631687362051594: VariantsMap = [
    &["marsupialized"],
    &["marsupialised"],
    &["marsupialized"],
    &["marsupialised"],
];

pub(crate) static ENTRY_MARSUPIALIZES_14629605414761888268: VariantsMap = [
    &["marsupializes"],
    &["marsupialises"],
    &["marsupializes"],
    &["marsupialises"],
];

pub(crate) static ENTRY_MARSUPIALIZE_1726851296480687486: VariantsMap = [
    &["marsupialize"],
    &["marsupialise"],
    &["marsupialize"],
    &["marsupialise"],
];

pub(crate) static ENTRY_MARSUPIALIZING_11802531571659940556: VariantsMap = [
    &["marsupializing"],
    &["marsupialising"],
    &["marsupializing"],
    &["marsupialising"],
];

pub(crate) static ENTRY_MARTE_115900376362314851: VariantsMap =
    [&["marte"], &["martae"], &["martae"], &["martae"]];

pub(crate) static ENTRY_MARTIALIZATIONS_11697709318054313125: VariantsMap = [
    &["martializations"],
    &["martialisations"],
    &["martializations"],
    &["martialisations"],
];

pub(crate) static ENTRY_MARTIALIZATION_12970020243892509428: VariantsMap = [
    &["martialization"],
    &["martialisation"],
    &["martialization"],
    &["martialisation"],
];

pub(crate) static ENTRY_MARTIALIZES_16237113673507263901: VariantsMap = [
    &["martializes"],
    &["martialises"],
    &["martializes"],
    &["martialises"],
];

pub(crate) static ENTRY_MARTIALIZE_16160203135661407439: VariantsMap = [
    &["martialize"],
    &["martialise"],
    &["martialize"],
    &["martialise"],
];

pub(crate) static ENTRY_MARTYRIZATIONS_16966157062728825533: VariantsMap = [
    &["martyrizations"],
    &["martyrisations"],
    &["martyrizations"],
    &["martyrisations"],
];

pub(crate) static ENTRY_MARTYRIZATION_6155264151450173537: VariantsMap = [
    &["martyrization"],
    &["martyrisation"],
    &["martyrization"],
    &["martyrisation"],
];

pub(crate) static ENTRY_MARTYRIZED_4832114212229439073: VariantsMap = [
    &["martyrized"],
    &["martyrised"],
    &["martyrized"],
    &["martyrised"],
];

pub(crate) static ENTRY_MARTYRIZERS_8288377886330052956: VariantsMap = [
    &["martyrizers"],
    &["martyrisers"],
    &["martyrizers"],
    &["martyrisers"],
];

pub(crate) static ENTRY_MARTYRIZER_8947475097586440969: VariantsMap = [
    &["martyrizer"],
    &["martyriser"],
    &["martyrizer"],
    &["martyriser"],
];

pub(crate) static ENTRY_MARTYRIZES_16597254749503837013: VariantsMap = [
    &["martyrizes"],
    &["martyrises"],
    &["martyrizes"],
    &["martyrises"],
];

pub(crate) static ENTRY_MARTYRIZE_18186520872862732817: VariantsMap = [
    &["martyrize"],
    &["martyrise"],
    &["martyrize"],
    &["martyrise"],
];

pub(crate) static ENTRY_MARTYRIZING_7504180782954747537: VariantsMap = [
    &["martyrizing"],
    &["martyrising"],
    &["martyrizing"],
    &["martyrising"],
];

pub(crate) static ENTRY_MARVELED_13640251601440341072: VariantsMap = [
    &["marveled"],
    &["marvelled"],
    &["marvelled"],
    &["marvelled"],
];

pub(crate) static ENTRY_MARVELER_5290759214700539442: VariantsMap = [
    &["marveler"],
    &["marveller"],
    &["marveller"],
    &["marveller"],
];

pub(crate) static ENTRY_MARVELING_17712338885593648087: VariantsMap = [
    &["marveling"],
    &["marvelling"],
    &["marvelling"],
    &["marvelling"],
];

pub(crate) static ENTRY_MARVELOUSER_9300773522759351631: VariantsMap = [
    &["marvelouser"],
    &["marvellouser"],
    &["marvellouser"],
    &["marvellouser"],
];

pub(crate) static ENTRY_MARVELOUSEST_4909905498549424330: VariantsMap = [
    &["marvelousest"],
    &["marvellousest"],
    &["marvellousest"],
    &["marvellousest"],
];

pub(crate) static ENTRY_MARVELOUSLIER_15522555805023104308: VariantsMap = [
    &["marvelouslier"],
    &["marvellouslier"],
    &["marvellouslier"],
    &["marvellouslier"],
];

pub(crate) static ENTRY_MARVELOUSLIEST_787848875312131772: VariantsMap = [
    &["marvelousliest"],
    &["marvellousliest"],
    &["marvellousliest"],
    &["marvellousliest"],
];

pub(crate) static ENTRY_MARVELOUSLY_9085447356318740108: VariantsMap = [
    &["marvelously"],
    &["marvellously"],
    &["marvellously"],
    &["marvellously"],
];

pub(crate) static ENTRY_MARVELOUSNESSES_15463361151017896116: VariantsMap = [
    &["marvelousnesses"],
    &["marvellousnesses"],
    &["marvellousnesses"],
    &["marvellousnesses"],
];

pub(crate) static ENTRY_MARVELOUSNESS_7406444444223070939: VariantsMap = [
    &["marvelousness"],
    &["marvellousness"],
    &["marvellousness"],
    &["marvellousness"],
];

pub(crate) static ENTRY_MARVELOUS_12913405657225800048: VariantsMap = [
    &["marvelous"],
    &["marvellous"],
    &["marvellous"],
    &["marvellous"],
];

pub(crate) static ENTRY_MASCULINIZATIONS_1451484167256544517: VariantsMap = [
    &["masculinizations"],
    &["masculinisations"],
    &["masculinizations"],
    &["masculinisations"],
];

pub(crate) static ENTRY_MASCULINIZATION_7323122115632941475: VariantsMap = [
    &["masculinization"],
    &["masculinisation"],
    &["masculinization"],
    &["masculinisation"],
];

pub(crate) static ENTRY_MASCULINIZED_4130985713898111785: VariantsMap = [
    &["masculinized"],
    &["masculinised"],
    &["masculinized"],
    &["masculinised"],
];

pub(crate) static ENTRY_MASCULINIZES_8331218415317018409: VariantsMap = [
    &["masculinizes"],
    &["masculinises"],
    &["masculinizes"],
    &["masculinises"],
];

pub(crate) static ENTRY_MASCULINIZE_8705445680236042472: VariantsMap = [
    &["masculinize"],
    &["masculinise"],
    &["masculinize"],
    &["masculinise"],
];

pub(crate) static ENTRY_MASCULINIZING_5615550210892317542: VariantsMap = [
    &["masculinizing"],
    &["masculinising"],
    &["masculinizing"],
    &["masculinising"],
];

pub(crate) static ENTRY_MATERIALIZATIONS_17630215875011801689: VariantsMap = [
    &["materializations"],
    &["materialisations"],
    &["materializations"],
    &["materialisations"],
];

pub(crate) static ENTRY_MATERIALIZATION_5296659211080369904: VariantsMap = [
    &["materialization"],
    &["materialisation"],
    &["materialization"],
    &["materialisation"],
];

pub(crate) static ENTRY_MATERIALIZED_4701762194516141918: VariantsMap = [
    &["materialized"],
    &["materialised"],
    &["materialized"],
    &["materialised"],
];

pub(crate) static ENTRY_MATERIALIZERS_6264608460867840474: VariantsMap = [
    &["materializers"],
    &["materialisers"],
    &["materializers"],
    &["materialisers"],
];

pub(crate) static ENTRY_MATERIALIZER_13633659159147435019: VariantsMap = [
    &["materializer"],
    &["materialiser"],
    &["materializer"],
    &["materialiser"],
];

pub(crate) static ENTRY_MATERIALIZES_2541163433716035330: VariantsMap = [
    &["materializes"],
    &["materialises"],
    &["materializes"],
    &["materialises"],
];

pub(crate) static ENTRY_MATERIALIZE_9377213878887487379: VariantsMap = [
    &["materialize"],
    &["materialise"],
    &["materialize"],
    &["materialise"],
];

pub(crate) static ENTRY_MATERIALIZING_3756046117234473798: VariantsMap = [
    &["materializing"],
    &["materialising"],
    &["materializing"],
    &["materialising"],
];

pub(crate) static ENTRY_MATERNALIZED_14227156040020017965: VariantsMap = [
    &["maternalized"],
    &["maternalised"],
    &["maternalized"],
    &["maternalised"],
];

pub(crate) static ENTRY_MATERNALIZES_12888734571883158030: VariantsMap = [
    &["maternalizes"],
    &["maternalises"],
    &["maternalizes"],
    &["maternalises"],
];

pub(crate) static ENTRY_MATERNALIZE_7041307337797140902: VariantsMap = [
    &["maternalize"],
    &["maternalise"],
    &["maternalize"],
    &["maternalise"],
];

pub(crate) static ENTRY_MATERNALIZING_9640631765141610049: VariantsMap = [
    &["maternalizing"],
    &["maternalising"],
    &["maternalizing"],
    &["maternalising"],
];

pub(crate) static ENTRY_MATERS_3979439194038338784: VariantsMap =
    [&["maters"], &["matres"], &["matres"], &["matres"]];

pub(crate) static ENTRY_MATHEMATICIZED_2954775980735308228: VariantsMap = [
    &["mathematicized"],
    &["mathematicised"],
    &["mathematicized"],
    &["mathematicised"],
];

pub(crate) static ENTRY_MATHEMATICIZES_17239793732172029302: VariantsMap = [
    &["mathematicizes"],
    &["mathematicises"],
    &["mathematicizes"],
    &["mathematicises"],
];

pub(crate) static ENTRY_MATHEMATICIZE_7017138034488316601: VariantsMap = [
    &["mathematicize"],
    &["mathematicise"],
    &["mathematicize"],
    &["mathematicise"],
];

pub(crate) static ENTRY_MATHEMATICIZING_18356289396973675487: VariantsMap = [
    &["mathematicizing"],
    &["mathematicising"],
    &["mathematicizing"],
    &["mathematicising"],
];

pub(crate) static ENTRY_MATHEMATIZATIONS_5363665293954590339: VariantsMap = [
    &["mathematizations"],
    &["mathematisations"],
    &["mathematizations"],
    &["mathematisations"],
];

pub(crate) static ENTRY_MATHEMATIZATION_11635475143822716979: VariantsMap = [
    &["mathematization"],
    &["mathematisation"],
    &["mathematization"],
    &["mathematisation"],
];

pub(crate) static ENTRY_MATHEMATIZED_10141209090401217221: VariantsMap = [
    &["mathematized"],
    &["mathematised"],
    &["mathematized"],
    &["mathematised"],
];

pub(crate) static ENTRY_MATHEMATIZES_17426361020400634879: VariantsMap = [
    &["mathematizes"],
    &["mathematises"],
    &["mathematizes"],
    &["mathematises"],
];

pub(crate) static ENTRY_MATHEMATIZE_15749632280370319229: VariantsMap = [
    &["mathematize"],
    &["mathematise"],
    &["mathematize"],
    &["mathematise"],
];

pub(crate) static ENTRY_MATHEMATIZING_7031390654186090211: VariantsMap = [
    &["mathematizing"],
    &["mathematising"],
    &["mathematizing"],
    &["mathematising"],
];

pub(crate) static ENTRY_MATH_11175287041460200362: VariantsMap =
    [&["math"], &["maths"], &["math"], &["maths"]];

pub(crate) static ENTRY_MATRONIZED_8674819809422970452: VariantsMap = [
    &["matronized"],
    &["matronised"],
    &["matronized"],
    &["matronised"],
];

pub(crate) static ENTRY_MATRONIZES_15227868328935007900: VariantsMap = [
    &["matronizes"],
    &["matronises"],
    &["matronizes"],
    &["matronises"],
];

pub(crate) static ENTRY_MATRONIZE_16335366679027459825: VariantsMap = [
    &["matronize"],
    &["matronise"],
    &["matronize"],
    &["matronise"],
];

pub(crate) static ENTRY_MATRONIZING_12987677453307989351: VariantsMap = [
    &["matronizing"],
    &["matronising"],
    &["matronizing"],
    &["matronising"],
];

pub(crate) static ENTRY_MATS_9463160410734197553: VariantsMap = [
    &["mats", "mattes", "matts"],
    &["matts"],
    &["mattes"],
    &["matts"],
];

pub(crate) static ENTRY_MATTHEAN_2316545087345878827: VariantsMap = [
    &["matthean"],
    &["matthaean"],
    &["matthaean"],
    &["matthaean"],
];

pub(crate) static ENTRY_MAUDLINIZES_6015159066732084897: VariantsMap = [
    &["maudlinizes"],
    &["maudlinises"],
    &["maudlinizes"],
    &["maudlinises"],
];

pub(crate) static ENTRY_MAUDLINIZE_10546890191792171390: VariantsMap = [
    &["maudlinize"],
    &["maudlinise"],
    &["maudlinize"],
    &["maudlinise"],
];

pub(crate) static ENTRY_MAUGER_2687308112141368893: VariantsMap =
    [&["mauger"], &["maugre"], &["maugre"], &["maugre"]];

pub(crate) static ENTRY_MAXIMIZATIONS_12790030751333652900: VariantsMap = [
    &["maximizations"],
    &["maximisations"],
    &["maximizations"],
    &["maximisations"],
];

pub(crate) static ENTRY_MAXIMIZATION_17686901393811165015: VariantsMap = [
    &["maximization"],
    &["maximisation"],
    &["maximization"],
    &["maximisation"],
];

pub(crate) static ENTRY_MAXIMIZED_6250109018079854572: VariantsMap = [
    &["maximized"],
    &["maximised"],
    &["maximized"],
    &["maximised"],
];

pub(crate) static ENTRY_MAXIMIZERS_8260289730206734033: VariantsMap = [
    &["maximizers"],
    &["maximisers"],
    &["maximizers"],
    &["maximisers"],
];

pub(crate) static ENTRY_MAXIMIZER_17946247253592585241: VariantsMap = [
    &["maximizer"],
    &["maximiser"],
    &["maximizer"],
    &["maximiser"],
];

pub(crate) static ENTRY_MAXIMIZES_3401038828375121966: VariantsMap = [
    &["maximizes"],
    &["maximises"],
    &["maximizes"],
    &["maximises"],
];

pub(crate) static ENTRY_MAXIMIZE_14091219846433103895: VariantsMap =
    [&["maximize"], &["maximise"], &["maximize"], &["maximise"]];

pub(crate) static ENTRY_MAXIMIZING_14134060054459323774: VariantsMap = [
    &["maximizing"],
    &["maximising"],
    &["maximizing"],
    &["maximising"],
];

pub(crate) static ENTRY_MEAGERRER_1795995436389544325: VariantsMap =
    [&["meagerrer"], &["meagrer"], &["meagrer"], &["meagrer"]];

pub(crate) static ENTRY_MEAGERREST_12190905609167997105: VariantsMap =
    [&["meagerrest"], &["meagrest"], &["meagrest"], &["meagrest"]];

pub(crate) static ENTRY_MEAGER_7974525186540147476: VariantsMap =
    [&["meager"], &["meagre"], &["meagre"], &["meagre"]];

pub(crate) static ENTRY_MEANDRINE_15281745123487615934: VariantsMap = [
    &["meandrine"],
    &["maeandrine"],
    &["maeandrine"],
    &["maeandrine"],
];

pub(crate) static ENTRY_MEANDRINIFORM_8185091047283393921: VariantsMap = [
    &["meandriniform"],
    &["maeandriniform"],
    &["maeandriniform"],
    &["maeandriniform"],
];

pub(crate) static ENTRY_MECHANICALIZATIONS_17519748869411038519: VariantsMap = [
    &["mechanicalizations"],
    &["mechanicalisations"],
    &["mechanicalizations"],
    &["mechanicalisations"],
];

pub(crate) static ENTRY_MECHANICALIZATION_13195949433368378540: VariantsMap = [
    &["mechanicalization"],
    &["mechanicalisation"],
    &["mechanicalization"],
    &["mechanicalisation"],
];

pub(crate) static ENTRY_MECHANICALIZES_11069973531634237808: VariantsMap = [
    &["mechanicalizes"],
    &["mechanicalises"],
    &["mechanicalizes"],
    &["mechanicalises"],
];

pub(crate) static ENTRY_MECHANICALIZE_12176998180861896123: VariantsMap = [
    &["mechanicalize"],
    &["mechanicalise"],
    &["mechanicalize"],
    &["mechanicalise"],
];

pub(crate) static ENTRY_MECHANIZABLE_4433487534726381759: VariantsMap = [
    &["mechanizable"],
    &["mechanisable"],
    &["mechanizable"],
    &["mechanisable"],
];

pub(crate) static ENTRY_MECHANIZATIONS_16698691905505593378: VariantsMap = [
    &["mechanizations"],
    &["mechanisations"],
    &["mechanizations"],
    &["mechanisations"],
];

pub(crate) static ENTRY_MECHANIZATION_15363685468899666275: VariantsMap = [
    &["mechanization"],
    &["mechanisation"],
    &["mechanization"],
    &["mechanisation"],
];

pub(crate) static ENTRY_MECHANIZED_12614146981841365583: VariantsMap = [
    &["mechanized"],
    &["mechanised"],
    &["mechanized"],
    &["mechanised"],
];

pub(crate) static ENTRY_MECHANIZERS_4315044385466386260: VariantsMap = [
    &["mechanizers"],
    &["mechanisers"],
    &["mechanizers"],
    &["mechanisers"],
];

pub(crate) static ENTRY_MECHANIZER_1668821815609902700: VariantsMap = [
    &["mechanizer"],
    &["mechaniser"],
    &["mechanizer"],
    &["mechaniser"],
];

pub(crate) static ENTRY_MECHANIZES_15199857738602551511: VariantsMap = [
    &["mechanizes"],
    &["mechanises"],
    &["mechanizes"],
    &["mechanises"],
];

pub(crate) static ENTRY_MECHANIZE_14053959373358803371: VariantsMap = [
    &["mechanize"],
    &["mechanise"],
    &["mechanize"],
    &["mechanise"],
];

pub(crate) static ENTRY_MECHANIZING_15496014639333728081: VariantsMap = [
    &["mechanizing"],
    &["mechanising"],
    &["mechanizing"],
    &["mechanising"],
];

pub(crate) static ENTRY_MECK_5443554356343726238: VariantsMap =
    [&["meck"], &["moeck"], &["moeck"], &["moeck"]];

pub(crate) static ENTRY_MEDALED_9329802324825433304: VariantsMap =
    [&["medaled"], &["medalled"], &["medalled"], &["medalled"]];

pub(crate) static ENTRY_MEDALING_15272839155813995206: VariantsMap = [
    &["medaling"],
    &["medalling"],
    &["medalling"],
    &["medalling"],
];

pub(crate) static ENTRY_MEDALISTS_14543293296180708193: VariantsMap = [
    &["medalists"],
    &["medallists"],
    &["medallists"],
    &["medallists"],
];

pub(crate) static ENTRY_MEDALIST_3813713439469975305: VariantsMap = [
    &["medalist"],
    &["medallist"],
    &["medallist"],
    &["medallist"],
];

pub(crate) static ENTRY_MEDALIZES_8369354423782443921: VariantsMap = [
    &["medalizes"],
    &["medalises"],
    &["medalizes"],
    &["medalises"],
];

pub(crate) static ENTRY_MEDALIZE_6428378184574445930: VariantsMap =
    [&["medalize"], &["medalise"], &["medalize"], &["medalise"]];

pub(crate) static ENTRY_MEDIALIZATIONS_9266737235252383366: VariantsMap = [
    &["medializations"],
    &["medialisations"],
    &["medializations"],
    &["medialisations"],
];

pub(crate) static ENTRY_MEDIALIZATION_11201086450154584377: VariantsMap = [
    &["medialization"],
    &["medialisation"],
    &["medialization"],
    &["medialisation"],
];

pub(crate) static ENTRY_MEDIALIZES_9158496365414473522: VariantsMap = [
    &["medializes"],
    &["medialises"],
    &["medializes"],
    &["medialises"],
];

pub(crate) static ENTRY_MEDIALIZE_15964854162951169156: VariantsMap = [
    &["medialize"],
    &["medialise"],
    &["medialize"],
    &["medialise"],
];

pub(crate) static ENTRY_MEDIATIZATIONS_16197242107778706785: VariantsMap = [
    &["mediatizations"],
    &["mediatisations"],
    &["mediatizations"],
    &["mediatisations"],
];

pub(crate) static ENTRY_MEDIATIZATION_13943602012568749747: VariantsMap = [
    &["mediatization"],
    &["mediatisation"],
    &["mediatization"],
    &["mediatisation"],
];

pub(crate) static ENTRY_MEDIATIZED_16310994672212204317: VariantsMap = [
    &["mediatized"],
    &["mediatised"],
    &["mediatized"],
    &["mediatised"],
];

pub(crate) static ENTRY_MEDIATIZES_945460647564073412: VariantsMap = [
    &["mediatizes"],
    &["mediatises"],
    &["mediatizes"],
    &["mediatises"],
];

pub(crate) static ENTRY_MEDIATIZE_14921357820800349052: VariantsMap = [
    &["mediatize"],
    &["mediatise"],
    &["mediatize"],
    &["mediatise"],
];

pub(crate) static ENTRY_MEDIATIZING_3100095196162520920: VariantsMap = [
    &["mediatizing"],
    &["mediatising"],
    &["mediatizing"],
    &["mediatising"],
];

pub(crate) static ENTRY_MEDICALIZATIONS_16089901682373921411: VariantsMap = [
    &["medicalizations"],
    &["medicalisations"],
    &["medicalizations"],
    &["medicalisations"],
];

pub(crate) static ENTRY_MEDICALIZATION_2111892448928052093: VariantsMap = [
    &["medicalization"],
    &["medicalisation"],
    &["medicalization"],
    &["medicalisation"],
];

pub(crate) static ENTRY_MEDICALIZED_10409251504127363635: VariantsMap = [
    &["medicalized"],
    &["medicalised"],
    &["medicalized"],
    &["medicalised"],
];

pub(crate) static ENTRY_MEDICALIZES_10125506143660647869: VariantsMap = [
    &["medicalizes"],
    &["medicalises"],
    &["medicalizes"],
    &["medicalises"],
];

pub(crate) static ENTRY_MEDICALIZE_17606487197661150257: VariantsMap = [
    &["medicalize"],
    &["medicalise"],
    &["medicalize"],
    &["medicalise"],
];

pub(crate) static ENTRY_MEDICALIZING_4417395695056553530: VariantsMap = [
    &["medicalizing"],
    &["medicalising"],
    &["medicalizing"],
    &["medicalising"],
];

pub(crate) static ENTRY_MEDIEVALISMS_13648693867116920259: VariantsMap = [
    &["medievalisms"],
    &["mediaevalisms"],
    &["mediaevalisms"],
    &["mediaevalisms"],
];

pub(crate) static ENTRY_MEDIEVALISM_7626307190061100596: VariantsMap = [
    &["medievalism"],
    &["mediaevalism"],
    &["mediaevalism"],
    &["mediaevalism"],
];

pub(crate) static ENTRY_MEDIEVALLY_4074376096099201747: VariantsMap = [
    &["medievally"],
    &["mediaevally"],
    &["mediaevally"],
    &["mediaevally"],
];

pub(crate) static ENTRY_MEDIEVALS_13173357713744728823: VariantsMap = [
    &["medievals"],
    &["medievals"],
    &["medievals"],
    &["medievals"],
];

pub(crate) static ENTRY_MEDIEVAL_1008732004874495105: VariantsMap =
    [&["medieval"], &["medieval"], &["medieval"], &["medieval"]];

pub(crate) static ENTRY_MEDITERRANEANIZATIONS_14143064455240736635: VariantsMap = [
    &["mediterraneanizations"],
    &["mediterraneanisations"],
    &["mediterraneanizations"],
    &["mediterraneanisations"],
];

pub(crate) static ENTRY_MEDITERRANEANIZATION_14068923875498088797: VariantsMap = [
    &["mediterraneanization"],
    &["mediterraneanisation"],
    &["mediterraneanization"],
    &["mediterraneanisation"],
];

pub(crate) static ENTRY_MEDITERRANEANIZES_4936465023428726899: VariantsMap = [
    &["mediterraneanizes"],
    &["mediterraneanises"],
    &["mediterraneanizes"],
    &["mediterraneanises"],
];

pub(crate) static ENTRY_MEDITERRANEANIZE_3216295787007797019: VariantsMap = [
    &["mediterraneanize"],
    &["mediterraneanise"],
    &["mediterraneanize"],
    &["mediterraneanise"],
];

pub(crate) static ENTRY_MEDIUMIZATIONS_9700104300417877036: VariantsMap = [
    &["mediumizations"],
    &["mediumisations"],
    &["mediumizations"],
    &["mediumisations"],
];

pub(crate) static ENTRY_MEDIUMIZATION_13781773160846845668: VariantsMap = [
    &["mediumization"],
    &["mediumisation"],
    &["mediumization"],
    &["mediumisation"],
];

pub(crate) static ENTRY_MEDIUMIZES_13996371956875882510: VariantsMap = [
    &["mediumizes"],
    &["mediumises"],
    &["mediumizes"],
    &["mediumises"],
];

pub(crate) static ENTRY_MEDIUMIZE_3727858729697566964: VariantsMap = [
    &["mediumize"],
    &["mediumise"],
    &["mediumize"],
    &["mediumise"],
];

pub(crate) static ENTRY_MED_5581722660439194258: VariantsMap =
    [&["med"], &["moed"], &["moed"], &["moed"]];

pub(crate) static ENTRY_MEGAMETER_1943008536807311428: VariantsMap = [
    &["megameter"],
    &["megametre"],
    &["megametre"],
    &["megametre"],
];

pub(crate) static ENTRY_MEGBOTE_6305017947026218797: VariantsMap =
    [&["megbote"], &["maegbote"], &["maegbote"], &["maegbote"]];

pub(crate) static ENTRY_MEGERG_17050520432197903681: VariantsMap =
    [&["megerg"], &["megaerg"], &["megaerg"], &["megaerg"]];

pub(crate) static ENTRY_MELANEMIA_3627025763487786313: VariantsMap = [
    &["melanemia"],
    &["melanaemia"],
    &["melanaemia"],
    &["melanaemia"],
];

pub(crate) static ENTRY_MELANEMIC_13613605974584449832: VariantsMap = [
    &["melanemic"],
    &["melanaemic"],
    &["melanaemic"],
    &["melanaemic"],
];

pub(crate) static ENTRY_MELANIZATION_4310350431255787228: VariantsMap = [
    &["melanization"],
    &["melanisation"],
    &["melanization"],
    &["melanisation"],
];

pub(crate) static ENTRY_MELANIZED_5005801037460172353: VariantsMap = [
    &["melanized"],
    &["melanised"],
    &["melanized"],
    &["melanised"],
];

pub(crate) static ENTRY_MELANIZES_4272022967769484050: VariantsMap = [
    &["melanizes"],
    &["melanises"],
    &["melanizes"],
    &["melanises"],
];

pub(crate) static ENTRY_MELANIZE_7849072016729938941: VariantsMap =
    [&["melanize"], &["melanise"], &["melanize"], &["melanise"]];

pub(crate) static ENTRY_MELANIZING_874608171361269844: VariantsMap = [
    &["melanizing"],
    &["melanising"],
    &["melanizing"],
    &["melanising"],
];

pub(crate) static ENTRY_MELENA_17340470388387299570: VariantsMap =
    [&["melena"], &["melaena"], &["melaena"], &["melaena"]];

pub(crate) static ENTRY_MELENIC_2894828040941053782: VariantsMap =
    [&["melenic"], &["melaenic"], &["melaenic"], &["melaenic"]];

pub(crate) static ENTRY_MELE_14922314763041738254: VariantsMap =
    [&["mele"], &["meloe"], &["meloe"], &["meloe"]];

pub(crate) static ENTRY_MELIE_11824537289201512564: VariantsMap =
    [&["melie"], &["meliae"], &["meliae"], &["meliae"]];

pub(crate) static ENTRY_MELINE_10641747453274309529: VariantsMap =
    [&["meline"], &["melinae"], &["melinae"], &["melinae"]];

pub(crate) static ENTRY_MELITEMIA_2708409562640762486: VariantsMap = [
    &["melitemia"],
    &["melitaemia"],
    &["melitaemia"],
    &["melitaemia"],
];

pub(crate) static ENTRY_MELITHEMIA_7590421864945761846: VariantsMap = [
    &["melithemia"],
    &["melithaemia"],
    &["melithaemia"],
    &["melithaemia"],
];

pub(crate) static ENTRY_MELLON_391954139899810285: VariantsMap =
    [&["mellon"], &["moellon"], &["moellon"], &["moellon"]];

pub(crate) static ENTRY_MELODIZATION_7432583061443164587: VariantsMap = [
    &["melodization"],
    &["melodisation"],
    &["melodization"],
    &["melodisation"],
];

pub(crate) static ENTRY_MELODIZED_7315404446965573837: VariantsMap = [
    &["melodized"],
    &["melodised"],
    &["melodized"],
    &["melodised"],
];

pub(crate) static ENTRY_MELODIZER_17176341135857748154: VariantsMap = [
    &["melodizer"],
    &["melodiser"],
    &["melodizer"],
    &["melodiser"],
];

pub(crate) static ENTRY_MELODIZES_355127131421165026: VariantsMap = [
    &["melodizes"],
    &["melodises"],
    &["melodizes"],
    &["melodises"],
];

pub(crate) static ENTRY_MELODIZE_7738216678825813559: VariantsMap =
    [&["melodize"], &["melodise"], &["melodize"], &["melodise"]];

pub(crate) static ENTRY_MELODIZING_13910918430639522337: VariantsMap = [
    &["melodizing"],
    &["melodising"],
    &["melodizing"],
    &["melodising"],
];

pub(crate) static ENTRY_MELODRAMATIZATION_17884213093816048338: VariantsMap = [
    &["melodramatization"],
    &["melodramatisation"],
    &["melodramatization"],
    &["melodramatisation"],
];

pub(crate) static ENTRY_MELODRAMATIZED_4520313047331582327: VariantsMap = [
    &["melodramatized"],
    &["melodramatised"],
    &["melodramatized"],
    &["melodramatised"],
];

pub(crate) static ENTRY_MELODRAMATIZES_1590401015443283848: VariantsMap = [
    &["melodramatizes"],
    &["melodramatises"],
    &["melodramatizes"],
    &["melodramatises"],
];

pub(crate) static ENTRY_MELODRAMATIZE_3695641167123938020: VariantsMap = [
    &["melodramatize"],
    &["melodramatise"],
    &["melodramatize"],
    &["melodramatise"],
];

pub(crate) static ENTRY_MELODRAMATIZING_11653694285687179428: VariantsMap = [
    &["melodramatizing"],
    &["melodramatising"],
    &["melodramatizing"],
    &["melodramatising"],
];

pub(crate) static ENTRY_MEMORIALIZATIONS_15285671033015235264: VariantsMap = [
    &["memorializations"],
    &["memorialisations"],
    &["memorializations"],
    &["memorialisations"],
];

pub(crate) static ENTRY_MEMORIALIZATION_8125433852548617131: VariantsMap = [
    &["memorialization"],
    &["memorialisation"],
    &["memorialization"],
    &["memorialisation"],
];

pub(crate) static ENTRY_MEMORIALIZED_11248998509134482621: VariantsMap = [
    &["memorialized"],
    &["memorialised"],
    &["memorialized"],
    &["memorialised"],
];

pub(crate) static ENTRY_MEMORIALIZERS_3516900229786026104: VariantsMap = [
    &["memorializers"],
    &["memorialisers"],
    &["memorializers"],
    &["memorialisers"],
];

pub(crate) static ENTRY_MEMORIALIZER_188024871039509941: VariantsMap = [
    &["memorializer"],
    &["memorialiser"],
    &["memorializer"],
    &["memorialiser"],
];

pub(crate) static ENTRY_MEMORIALIZES_15034789887931696988: VariantsMap = [
    &["memorializes"],
    &["memorialises"],
    &["memorializes"],
    &["memorialises"],
];

pub(crate) static ENTRY_MEMORIALIZE_12843972171438242442: VariantsMap = [
    &["memorialize"],
    &["memorialise"],
    &["memorialize"],
    &["memorialise"],
];

pub(crate) static ENTRY_MEMORIALIZING_4629190360507969042: VariantsMap = [
    &["memorializing"],
    &["memorialising"],
    &["memorializing"],
    &["memorialising"],
];

pub(crate) static ENTRY_MEMORIZABLES_17876290914617649824: VariantsMap = [
    &["memorizables"],
    &["memorisables"],
    &["memorizables"],
    &["memorisables"],
];

pub(crate) static ENTRY_MEMORIZABLE_11352668762729937122: VariantsMap = [
    &["memorizable"],
    &["memorisable"],
    &["memorizable"],
    &["memorisable"],
];

pub(crate) static ENTRY_MEMORIZATIONS_17836564012509783241: VariantsMap = [
    &["memorizations"],
    &["memorisations"],
    &["memorizations"],
    &["memorisations"],
];

pub(crate) static ENTRY_MEMORIZATION_11518051927242789602: VariantsMap = [
    &["memorization"],
    &["memorisation"],
    &["memorization"],
    &["memorisation"],
];

pub(crate) static ENTRY_MEMORIZED_18012206033008846662: VariantsMap = [
    &["memorized"],
    &["memorised"],
    &["memorized"],
    &["memorised"],
];

pub(crate) static ENTRY_MEMORIZERS_5910795194513615614: VariantsMap = [
    &["memorizers"],
    &["memorisers"],
    &["memorizers"],
    &["memorisers"],
];

pub(crate) static ENTRY_MEMORIZER_3044267375638741545: VariantsMap = [
    &["memorizer"],
    &["memoriser"],
    &["memorizer"],
    &["memoriser"],
];

pub(crate) static ENTRY_MEMORIZES_6598457048183240033: VariantsMap = [
    &["memorizes"],
    &["memorises"],
    &["memorizes"],
    &["memorises"],
];

pub(crate) static ENTRY_MEMORIZE_3326918095136387049: VariantsMap =
    [&["memorize"], &["memorise"], &["memorize"], &["memorise"]];

pub(crate) static ENTRY_MEMORIZING_10196488108085766880: VariantsMap = [
    &["memorizing"],
    &["memorising"],
    &["memorizing"],
    &["memorising"],
];

pub(crate) static ENTRY_MENDELIZES_11591249054331616238: VariantsMap = [
    &["mendelizes"],
    &["mendelises"],
    &["mendelizes"],
    &["mendelises"],
];

pub(crate) static ENTRY_MENDELIZE_13155598837739586689: VariantsMap = [
    &["mendelize"],
    &["mendelise"],
    &["mendelize"],
    &["mendelise"],
];

pub(crate) static ENTRY_MENINGORRHEA_2384221611932253259: VariantsMap = [
    &["meningorrhea"],
    &["meningorrhoea"],
    &["meningorrhoea"],
    &["meningorrhoea"],
];

pub(crate) static ENTRY_MENORRHEAS_2672863015361396457: VariantsMap = [
    &["menorrheas"],
    &["menorrhoeas"],
    &["menorrhoeas"],
    &["menorrhoeas"],
];

pub(crate) static ENTRY_MENORRHEA_7798588011650236994: VariantsMap = [
    &["menorrhea"],
    &["menorrhoea"],
    &["menorrhoea"],
    &["menorrhoea"],
];

pub(crate) static ENTRY_MENORRHEIC_7610022187186673774: VariantsMap = [
    &["menorrheic"],
    &["menorrhoeic"],
    &["menorrhoeic"],
    &["menorrhoeic"],
];

pub(crate) static ENTRY_MENSE_16673844012933097881: VariantsMap =
    [&["mense"], &["mensae"], &["mensae"], &["mensae"]];

pub(crate) static ENTRY_MENTALIZATIONS_14912536060408920277: VariantsMap = [
    &["mentalizations"],
    &["mentalisations"],
    &["mentalizations"],
    &["mentalisations"],
];

pub(crate) static ENTRY_MENTALIZATION_6058534137827415789: VariantsMap = [
    &["mentalization"],
    &["mentalisation"],
    &["mentalization"],
    &["mentalisation"],
];

pub(crate) static ENTRY_MENTALIZES_12647784615922375764: VariantsMap = [
    &["mentalizes"],
    &["mentalises"],
    &["mentalizes"],
    &["mentalises"],
];

pub(crate) static ENTRY_MENTALIZE_1038523375536757780: VariantsMap = [
    &["mentalize"],
    &["mentalise"],
    &["mentalize"],
    &["mentalise"],
];

pub(crate) static ENTRY_MEOWED_15719981813416166348: VariantsMap =
    [&["meowed"], &["miaowed"], &["meowed"], &["miaowed"]];

pub(crate) static ENTRY_MEOWING_11150494275483966586: VariantsMap =
    [&["meowing"], &["miaowing"], &["meowing"], &["miaowing"]];

pub(crate) static ENTRY_MEOWS_11643488271672592790: VariantsMap =
    [&["meows"], &["miaows"], &["meows"], &["miaows"]];

pub(crate) static ENTRY_MEOW_13843661663170128965: VariantsMap =
    [&["meow"], &["miaow"], &["meow"], &["miaow"]];

pub(crate) static ENTRY_MEPHITINE_5769700321158530059: VariantsMap = [
    &["mephitine"],
    &["mephitinae"],
    &["mephitinae"],
    &["mephitinae"],
];

pub(crate) static ENTRY_MERA_2238379545822097898: VariantsMap =
    [&["mera"], &["maera"], &["maera"], &["maera"]];

pub(crate) static ENTRY_MERCERIZATIONS_12875656223878026724: VariantsMap = [
    &["mercerizations"],
    &["mercerisations"],
    &["mercerizations"],
    &["mercerisations"],
];

pub(crate) static ENTRY_MERCERIZATION_14891932795764931552: VariantsMap = [
    &["mercerization"],
    &["mercerisation"],
    &["mercerization"],
    &["mercerisation"],
];

pub(crate) static ENTRY_MERCERIZED_12441200842633397226: VariantsMap = [
    &["mercerized"],
    &["mercerised"],
    &["mercerized"],
    &["mercerised"],
];

pub(crate) static ENTRY_MERCERIZERS_231878388937737223: VariantsMap = [
    &["mercerizers"],
    &["mercerisers"],
    &["mercerizers"],
    &["mercerisers"],
];

pub(crate) static ENTRY_MERCERIZER_2628289242439953198: VariantsMap = [
    &["mercerizer"],
    &["merceriser"],
    &["mercerizer"],
    &["merceriser"],
];

pub(crate) static ENTRY_MERCERIZES_11625551039561273101: VariantsMap = [
    &["mercerizes"],
    &["mercerises"],
    &["mercerizes"],
    &["mercerises"],
];

pub(crate) static ENTRY_MERCERIZE_15182792491441059447: VariantsMap = [
    &["mercerize"],
    &["mercerise"],
    &["mercerize"],
    &["mercerise"],
];

pub(crate) static ENTRY_MERCERIZING_12341499939260844341: VariantsMap = [
    &["mercerizing"],
    &["mercerising"],
    &["mercerizing"],
    &["mercerising"],
];

pub(crate) static ENTRY_MERCURIALIZATIONS_12336168913360947002: VariantsMap = [
    &["mercurializations"],
    &["mercurialisations"],
    &["mercurializations"],
    &["mercurialisations"],
];

pub(crate) static ENTRY_MERCURIALIZATION_12125945095948399146: VariantsMap = [
    &["mercurialization"],
    &["mercurialisation"],
    &["mercurialization"],
    &["mercurialisation"],
];

pub(crate) static ENTRY_MERCURIALIZED_6385834004082463546: VariantsMap = [
    &["mercurialized"],
    &["mercurialised"],
    &["mercurialized"],
    &["mercurialised"],
];

pub(crate) static ENTRY_MERCURIALIZES_1343259582893080731: VariantsMap = [
    &["mercurializes"],
    &["mercurialises"],
    &["mercurializes"],
    &["mercurialises"],
];

pub(crate) static ENTRY_MERCURIALIZE_3364801806643879631: VariantsMap = [
    &["mercurialize"],
    &["mercurialise"],
    &["mercurialize"],
    &["mercurialise"],
];

pub(crate) static ENTRY_MERCURIALIZING_10236574536722882122: VariantsMap = [
    &["mercurializing"],
    &["mercurialising"],
    &["mercurializing"],
    &["mercurialising"],
];

pub(crate) static ENTRY_MERCURIZED_4260915582458843031: VariantsMap = [
    &["mercurized"],
    &["mercurised"],
    &["mercurized"],
    &["mercurised"],
];

pub(crate) static ENTRY_MERCURIZES_1462619783730817794: VariantsMap = [
    &["mercurizes"],
    &["mercurises"],
    &["mercurizes"],
    &["mercurises"],
];

pub(crate) static ENTRY_MERCURIZE_17518451926892582183: VariantsMap = [
    &["mercurize"],
    &["mercurise"],
    &["mercurize"],
    &["mercurise"],
];

pub(crate) static ENTRY_MERCURIZING_13905940081457194303: VariantsMap = [
    &["mercurizing"],
    &["mercurising"],
    &["mercurizing"],
    &["mercurising"],
];

pub(crate) static ENTRY_MEROE_450227222285392193: VariantsMap =
    [&["meroe"], &["meroae"], &["meroae"], &["meroae"]];

pub(crate) static ENTRY_MESMERIZABILITIES_2235333359977552261: VariantsMap = [
    &["mesmerizabilities"],
    &["mesmerisabilities"],
    &["mesmerizabilities"],
    &["mesmerisabilities"],
];

pub(crate) static ENTRY_MESMERIZABILITY_10832984732093003313: VariantsMap = [
    &["mesmerizability"],
    &["mesmerisability"],
    &["mesmerizability"],
    &["mesmerisability"],
];

pub(crate) static ENTRY_MESMERIZABLES_18311050620178554784: VariantsMap = [
    &["mesmerizables"],
    &["mesmerisables"],
    &["mesmerizables"],
    &["mesmerisables"],
];

pub(crate) static ENTRY_MESMERIZABLE_1707311909740579070: VariantsMap = [
    &["mesmerizable"],
    &["mesmerisable"],
    &["mesmerizable"],
    &["mesmerisable"],
];

pub(crate) static ENTRY_MESMERIZATIONS_7650562438007026759: VariantsMap = [
    &["mesmerizations"],
    &["mesmerisations"],
    &["mesmerizations"],
    &["mesmerisations"],
];

pub(crate) static ENTRY_MESMERIZATION_8961271965340064710: VariantsMap = [
    &["mesmerization"],
    &["mesmerisation"],
    &["mesmerization"],
    &["mesmerisation"],
];

pub(crate) static ENTRY_MESMERIZED_14030290228729285174: VariantsMap = [
    &["mesmerized"],
    &["mesmerised"],
    &["mesmerized"],
    &["mesmerised"],
];

pub(crate) static ENTRY_MESMERIZERS_2175164108172756867: VariantsMap = [
    &["mesmerizers"],
    &["mesmerisers"],
    &["mesmerizers"],
    &["mesmerisers"],
];

pub(crate) static ENTRY_MESMERIZER_12079073180184450954: VariantsMap = [
    &["mesmerizer"],
    &["mesmeriser"],
    &["mesmerizer"],
    &["mesmeriser"],
];

pub(crate) static ENTRY_MESMERIZES_3470825852692700157: VariantsMap = [
    &["mesmerizes"],
    &["mesmerises"],
    &["mesmerizes"],
    &["mesmerises"],
];

pub(crate) static ENTRY_MESMERIZE_8247464516832987079: VariantsMap = [
    &["mesmerize"],
    &["mesmerise"],
    &["mesmerize"],
    &["mesmerise"],
];

pub(crate) static ENTRY_MESMERIZING_9747635351758180951: VariantsMap = [
    &["mesmerizing"],
    &["mesmerising"],
    &["mesmerizing"],
    &["mesmerising"],
];

pub(crate) static ENTRY_MESOGLEAL_1179622660000981537: VariantsMap = [
    &["mesogleal"],
    &["mesogloeal"],
    &["mesogloeal"],
    &["mesogloeal"],
];

pub(crate) static ENTRY_MESOGLEAS_15641828554859977983: VariantsMap = [
    &["mesogleas"],
    &["mesogloeas"],
    &["mesogloeas"],
    &["mesogloeas"],
];

pub(crate) static ENTRY_MESOGLEA_18368820102082494563: VariantsMap = [
    &["mesoglea"],
    &["mesogloea"],
    &["mesogloea"],
    &["mesogloea"],
];

pub(crate) static ENTRY_MESPRIZES_634955430244876338: VariantsMap = [
    &["mesprizes"],
    &["mesprises"],
    &["mesprizes"],
    &["mesprises"],
];

pub(crate) static ENTRY_MESPRIZE_626385901018439636: VariantsMap =
    [&["mesprize"], &["mesprise"], &["mesprize"], &["mesprise"]];

pub(crate) static ENTRY_METABOLIZABLES_10614491304432551547: VariantsMap = [
    &["metabolizables"],
    &["metabolisables"],
    &["metabolizables"],
    &["metabolisables"],
];

pub(crate) static ENTRY_METABOLIZABLE_9746555623918169812: VariantsMap = [
    &["metabolizable"],
    &["metabolisable"],
    &["metabolizable"],
    &["metabolisable"],
];

pub(crate) static ENTRY_METABOLIZED_13396525183658045150: VariantsMap = [
    &["metabolized"],
    &["metabolised"],
    &["metabolized"],
    &["metabolised"],
];

pub(crate) static ENTRY_METABOLIZES_9009933951399545406: VariantsMap = [
    &["metabolizes"],
    &["metabolises"],
    &["metabolizes"],
    &["metabolises"],
];

pub(crate) static ENTRY_METABOLIZE_12396682712077398162: VariantsMap = [
    &["metabolize"],
    &["metabolise"],
    &["metabolize"],
    &["metabolise"],
];

pub(crate) static ENTRY_METABOLIZING_16268020869626432724: VariantsMap = [
    &["metabolizing"],
    &["metabolising"],
    &["metabolizing"],
    &["metabolising"],
];

pub(crate) static ENTRY_METACENTERS_10602862670736052985: VariantsMap = [
    &["metacenters"],
    &["metacentres"],
    &["metacentres"],
    &["metacentres"],
];

pub(crate) static ENTRY_METACENTER_12861464410788453410: VariantsMap = [
    &["metacenter"],
    &["metacentre"],
    &["metacentre"],
    &["metacentre"],
];

pub(crate) static ENTRY_METAGRABOLIZED_13543497967392033141: VariantsMap = [
    &["metagrabolized"],
    &["metagrabolised"],
    &["metagrabolized"],
    &["metagrabolised"],
];

pub(crate) static ENTRY_METAGRABOLIZES_14921829028195999540: VariantsMap = [
    &["metagrabolizes"],
    &["metagrabolises"],
    &["metagrabolizes"],
    &["metagrabolises"],
];

pub(crate) static ENTRY_METAGRABOLIZE_4339239122760344200: VariantsMap = [
    &["metagrabolize"],
    &["metagrabolise"],
    &["metagrabolize"],
    &["metagrabolise"],
];

pub(crate) static ENTRY_METAGRABOLIZING_10957957182586459380: VariantsMap = [
    &["metagrabolizing"],
    &["metagrabolising"],
    &["metagrabolizing"],
    &["metagrabolising"],
];

pub(crate) static ENTRY_METAGROBOLIZED_7134519687053222286: VariantsMap = [
    &["metagrobolized"],
    &["metagrobolised"],
    &["metagrobolized"],
    &["metagrobolised"],
];

pub(crate) static ENTRY_METAGROBOLIZES_10659207287620041997: VariantsMap = [
    &["metagrobolizes"],
    &["metagrobolises"],
    &["metagrobolizes"],
    &["metagrobolises"],
];

pub(crate) static ENTRY_METAGROBOLIZE_3274575390383359935: VariantsMap = [
    &["metagrobolize"],
    &["metagrobolise"],
    &["metagrobolize"],
    &["metagrobolise"],
];

pub(crate) static ENTRY_METAGROBOLIZING_16754461244152950181: VariantsMap = [
    &["metagrobolizing"],
    &["metagrobolising"],
    &["metagrobolizing"],
    &["metagrobolising"],
];

pub(crate) static ENTRY_METALED_11411260958286166568: VariantsMap =
    [&["metaled"], &["metalled"], &["metalled"], &["metalled"]];

pub(crate) static ENTRY_METALING_10131130132844817603: VariantsMap = [
    &["metaling"],
    &["metalling"],
    &["metalling"],
    &["metalling"],
];

pub(crate) static ENTRY_METALIZATIONS_12814245870584390497: VariantsMap = [
    &["metalizations"],
    &["metallisations"],
    &["metallizations"],
    &["metallisations"],
];

pub(crate) static ENTRY_METALIZATION_2737656944192418067: VariantsMap = [
    &["metalization"],
    &["metallisation"],
    &["metallization"],
    &["metallisation"],
];

pub(crate) static ENTRY_METALIZED_13873262702122532833: VariantsMap = [
    &["metalized"],
    &["metallised"],
    &["metallized"],
    &["metallised"],
];

pub(crate) static ENTRY_METALIZES_15413109627770746740: VariantsMap = [
    &["metalizes"],
    &["metallises"],
    &["metallizes"],
    &["metallises"],
];

pub(crate) static ENTRY_METALIZE_10265648959816292880: VariantsMap = [
    &["metalize"],
    &["metallise"],
    &["metallize"],
    &["metallise"],
];

pub(crate) static ENTRY_METALIZING_10340234665862306631: VariantsMap = [
    &["metalizing"],
    &["metallising"],
    &["metallizing"],
    &["metallising"],
];

pub(crate) static ENTRY_METAMERIZATIONS_613063263580719403: VariantsMap = [
    &["metamerizations"],
    &["metamerisations"],
    &["metamerizations"],
    &["metamerisations"],
];

pub(crate) static ENTRY_METAMERIZATION_2147110593558933265: VariantsMap = [
    &["metamerization"],
    &["metamerisation"],
    &["metamerization"],
    &["metamerisation"],
];

pub(crate) static ENTRY_METAMERIZEDS_4467995640688317236: VariantsMap = [
    &["metamerizeds"],
    &["metameriseds"],
    &["metamerizeds"],
    &["metameriseds"],
];

pub(crate) static ENTRY_METAMERIZED_10579453458080805856: VariantsMap = [
    &["metamerized"],
    &["metamerised"],
    &["metamerized"],
    &["metamerised"],
];

pub(crate) static ENTRY_METAPHONIZES_10502975870853971385: VariantsMap = [
    &["metaphonizes"],
    &["metaphonises"],
    &["metaphonizes"],
    &["metaphonises"],
];

pub(crate) static ENTRY_METAPHONIZE_957416918868098710: VariantsMap = [
    &["metaphonize"],
    &["metaphonise"],
    &["metaphonize"],
    &["metaphonise"],
];

pub(crate) static ENTRY_METAPHORIZES_12240673682831942337: VariantsMap = [
    &["metaphorizes"],
    &["metaphorises"],
    &["metaphorizes"],
    &["metaphorises"],
];

pub(crate) static ENTRY_METAPHORIZE_4064664541866675399: VariantsMap = [
    &["metaphorize"],
    &["metaphorise"],
    &["metaphorize"],
    &["metaphorise"],
];

pub(crate) static ENTRY_METAPHYSICIZES_8743324838290261598: VariantsMap = [
    &["metaphysicizes"],
    &["metaphysicises"],
    &["metaphysicizes"],
    &["metaphysicises"],
];

pub(crate) static ENTRY_METAPHYSICIZE_2295151515066980674: VariantsMap = [
    &["metaphysicize"],
    &["metaphysicise"],
    &["metaphysicize"],
    &["metaphysicise"],
];

pub(crate) static ENTRY_METASTASIZED_7988308203364783556: VariantsMap = [
    &["metastasized"],
    &["metastasised"],
    &["metastasized"],
    &["metastasised"],
];

pub(crate) static ENTRY_METASTASIZES_14097418011255033225: VariantsMap = [
    &["metastasizes"],
    &["metastasises"],
    &["metastasizes"],
    &["metastasises"],
];

pub(crate) static ENTRY_METASTASIZE_14424064478553972270: VariantsMap = [
    &["metastasize"],
    &["metastasise"],
    &["metastasize"],
    &["metastasise"],
];

pub(crate) static ENTRY_METASTASIZING_4346860356285509431: VariantsMap = [
    &["metastasizing"],
    &["metastasising"],
    &["metastasizing"],
    &["metastasising"],
];

pub(crate) static ENTRY_METATHESIZED_8943865811121602848: VariantsMap = [
    &["metathesized"],
    &["metathesised"],
    &["metathesized"],
    &["metathesised"],
];

pub(crate) static ENTRY_METATHESIZES_8073648188585933262: VariantsMap = [
    &["metathesizes"],
    &["metathesises"],
    &["metathesizes"],
    &["metathesises"],
];

pub(crate) static ENTRY_METATHESIZE_7314132290356926964: VariantsMap = [
    &["metathesize"],
    &["metathesise"],
    &["metathesize"],
    &["metathesise"],
];

pub(crate) static ENTRY_METATHESIZING_6771620324906770468: VariantsMap = [
    &["metathesizing"],
    &["metathesising"],
    &["metathesizing"],
    &["metathesising"],
];

pub(crate) static ENTRY_METEORIZATIONS_15135490425317605435: VariantsMap = [
    &["meteorizations"],
    &["meteorisations"],
    &["meteorizations"],
    &["meteorisations"],
];

pub(crate) static ENTRY_METEORIZATION_14474673158367138477: VariantsMap = [
    &["meteorization"],
    &["meteorisation"],
    &["meteorization"],
    &["meteorisation"],
];

pub(crate) static ENTRY_METEORIZES_5350547156830180970: VariantsMap = [
    &["meteorizes"],
    &["meteorises"],
    &["meteorizes"],
    &["meteorises"],
];

pub(crate) static ENTRY_METEORIZE_15789282159199256879: VariantsMap = [
    &["meteorize"],
    &["meteorise"],
    &["meteorize"],
    &["meteorise"],
];

pub(crate) static ENTRY_METERGRAM_1724413366267016112: VariantsMap = [
    &["metergram"],
    &["metregram"],
    &["metregram"],
    &["metregram"],
];

pub(crate) static ENTRY_METERLESS_17184210016380634977: VariantsMap = [
    &["meterless"],
    &["metreless"],
    &["metreless"],
    &["metreless"],
];

pub(crate) static ENTRY_METERSHIP_12369315169127590637: VariantsMap = [
    &["metership"],
    &["metreship"],
    &["metreship"],
    &["metreship"],
];

pub(crate) static ENTRY_METERS_17916328899664667470: VariantsMap =
    [&["meters"], &["metres"], &["metres"], &["metres"]];

pub(crate) static ENTRY_METER_16566716494062015891: VariantsMap =
    [&["meter"], &["metre"], &["metre"], &["metre"]];

pub(crate) static ENTRY_METESTRUS_11103578253154514948: VariantsMap = [
    &["metestrus"],
    &["metoestrus"],
    &["metoestrus"],
    &["metoestrus"],
];

pub(crate) static ENTRY_METHEMOGLOBIN_17726338295789945777: VariantsMap = [
    &["methemoglobin"],
    &["methaemoglobin"],
    &["methaemoglobin"],
    &["methaemoglobin"],
];

pub(crate) static ENTRY_METHODIZATIONS_17570359377170798664: VariantsMap = [
    &["methodizations"],
    &["methodisations"],
    &["methodizations"],
    &["methodisations"],
];

pub(crate) static ENTRY_METHODIZATION_9510256614122744050: VariantsMap = [
    &["methodization"],
    &["methodisation"],
    &["methodization"],
    &["methodisation"],
];

pub(crate) static ENTRY_METHODIZED_418361387379361383: VariantsMap = [
    &["methodized"],
    &["methodised"],
    &["methodized"],
    &["methodised"],
];

pub(crate) static ENTRY_METHODIZERS_11335706115632934821: VariantsMap = [
    &["methodizers"],
    &["methodisers"],
    &["methodizers"],
    &["methodisers"],
];

pub(crate) static ENTRY_METHODIZER_14823424149101284464: VariantsMap = [
    &["methodizer"],
    &["methodiser"],
    &["methodizer"],
    &["methodiser"],
];

pub(crate) static ENTRY_METHODIZES_12827878129958986497: VariantsMap = [
    &["methodizes"],
    &["methodises"],
    &["methodizes"],
    &["methodises"],
];

pub(crate) static ENTRY_METHODIZE_18133455300099242110: VariantsMap = [
    &["methodize"],
    &["methodise"],
    &["methodize"],
    &["methodise"],
];

pub(crate) static ENTRY_METHODIZING_12934705350925516475: VariantsMap = [
    &["methodizing"],
    &["methodising"],
    &["methodizing"],
    &["methodising"],
];

pub(crate) static ENTRY_METOPE_13902530583208981134: VariantsMap =
    [&["metope"], &["metopae"], &["metopae"], &["metopae"]];

pub(crate) static ENTRY_METRICIZED_6875699536327305118: VariantsMap = [
    &["metricized"],
    &["metricised"],
    &["metricized"],
    &["metricised"],
];

pub(crate) static ENTRY_METRICIZES_12116163869340692775: VariantsMap = [
    &["metricizes"],
    &["metricises"],
    &["metricizes"],
    &["metricises"],
];

pub(crate) static ENTRY_METRICIZE_11822854746535929298: VariantsMap = [
    &["metricize"],
    &["metricise"],
    &["metricize"],
    &["metricise"],
];

pub(crate) static ENTRY_METRICIZING_2068512533974319795: VariantsMap = [
    &["metricizing"],
    &["metricising"],
    &["metricizing"],
    &["metricising"],
];

pub(crate) static ENTRY_METRIZE_15001229744107948253: VariantsMap =
    [&["metrize"], &["metrise"], &["metrize"], &["metrise"]];

pub(crate) static ENTRY_METROPOLITANIZATION_1438949631637766421: VariantsMap = [
    &["metropolitanization"],
    &["metropolitanisation"],
    &["metropolitanization"],
    &["metropolitanisation"],
];

pub(crate) static ENTRY_METROPOLITANIZED_17050622815392025985: VariantsMap = [
    &["metropolitanized"],
    &["metropolitanised"],
    &["metropolitanized"],
    &["metropolitanised"],
];

pub(crate) static ENTRY_METROPOLITANIZES_9226183384925850337: VariantsMap = [
    &["metropolitanizes"],
    &["metropolitanises"],
    &["metropolitanizes"],
    &["metropolitanises"],
];

pub(crate) static ENTRY_METROPOLITANIZE_289702428142359755: VariantsMap = [
    &["metropolitanize"],
    &["metropolitanise"],
    &["metropolitanize"],
    &["metropolitanise"],
];

pub(crate) static ENTRY_METROPOLITANIZING_7898407017719054595: VariantsMap = [
    &["metropolitanizing"],
    &["metropolitanising"],
    &["metropolitanizing"],
    &["metropolitanising"],
];

pub(crate) static ENTRY_MEXICANIZES_17616790503217011839: VariantsMap = [
    &["mexicanizes"],
    &["mexicanises"],
    &["mexicanizes"],
    &["mexicanises"],
];

pub(crate) static ENTRY_MEXICANIZE_15398963488252123589: VariantsMap = [
    &["mexicanize"],
    &["mexicanise"],
    &["mexicanize"],
    &["mexicanise"],
];

pub(crate) static ENTRY_MICELLE_16974791499278810684: VariantsMap =
    [&["micelle"], &["micellae"], &["micellae"], &["micellae"]];

pub(crate) static ENTRY_MICRESTHETE_13540257889635101070: VariantsMap = [
    &["micresthete"],
    &["micraesthete"],
    &["micraesthete"],
    &["micraesthete"],
];

pub(crate) static ENTRY_MICROCOLORIMETER_9779301620192455553: VariantsMap = [
    &["microcolorimeter"],
    &["microcolourimeter"],
    &["microcolourimeter"],
    &["microcolourimeter"],
];

pub(crate) static ENTRY_MICROCOLORIMETRICALLY_642505822013488513: VariantsMap = [
    &["microcolorimetrically"],
    &["microcolourimetrically"],
    &["microcolourimetrically"],
    &["microcolourimetrically"],
];

pub(crate) static ENTRY_MICROCOLORIMETRIC_16293154471196561257: VariantsMap = [
    &["microcolorimetric"],
    &["microcolourimetric"],
    &["microcolourimetric"],
    &["microcolourimetric"],
];

pub(crate) static ENTRY_MICROCOLORIMETRY_4008745178077342383: VariantsMap = [
    &["microcolorimetry"],
    &["microcolourimetry"],
    &["microcolourimetry"],
    &["microcolourimetry"],
];

pub(crate) static ENTRY_MICROLITERS_4102248640329342657: VariantsMap = [
    &["microliters"],
    &["microlitres"],
    &["microlitres"],
    &["microlitres"],
];

pub(crate) static ENTRY_MICROLITER_10382843459472870945: VariantsMap = [
    &["microliter"],
    &["microlitre"],
    &["microlitre"],
    &["microlitre"],
];

pub(crate) static ENTRY_MICROMETERS_5540877797236666596: VariantsMap = [
    &["micrometers"],
    &["micrometres"],
    &["micrometres"],
    &["micrometres"],
];

pub(crate) static ENTRY_MICROMETER_15592109948820978579: VariantsMap = [
    &["micrometer"],
    &["micrometre"],
    &["micrometre"],
    &["micrometre"],
];

pub(crate) static ENTRY_MICROMILLIMETERS_3079930143003610243: VariantsMap = [
    &["micromillimeters"],
    &["micromillimetres"],
    &["micromillimetres"],
    &["micromillimetres"],
];

pub(crate) static ENTRY_MICROMILLIMETER_10473316398408026315: VariantsMap = [
    &["micromillimeter"],
    &["micromillimetre"],
    &["micromillimetre"],
    &["micromillimetre"],
];

pub(crate) static ENTRY_MICROMINIATURIZATIONS_13306479844907705540: VariantsMap = [
    &["microminiaturizations"],
    &["microminiaturisations"],
    &["microminiaturizations"],
    &["microminiaturisations"],
];

pub(crate) static ENTRY_MICROMINIATURIZATION_5346373952330274164: VariantsMap = [
    &["microminiaturization"],
    &["microminiaturisation"],
    &["microminiaturization"],
    &["microminiaturisation"],
];

pub(crate) static ENTRY_MICROMINIATURIZED_17716034338321519125: VariantsMap = [
    &["microminiaturized"],
    &["microminiaturised"],
    &["microminiaturized"],
    &["microminiaturised"],
];

pub(crate) static ENTRY_MICROMINIATURIZERS_16112810702387401879: VariantsMap = [
    &["microminiaturizers"],
    &["microminiaturisers"],
    &["microminiaturizers"],
    &["microminiaturisers"],
];

pub(crate) static ENTRY_MICROMINIATURIZER_9056244455912922848: VariantsMap = [
    &["microminiaturizer"],
    &["microminiaturiser"],
    &["microminiaturizer"],
    &["microminiaturiser"],
];

pub(crate) static ENTRY_MICROMINIATURIZES_7333398841442349207: VariantsMap = [
    &["microminiaturizes"],
    &["microminiaturises"],
    &["microminiaturizes"],
    &["microminiaturises"],
];

pub(crate) static ENTRY_MICROMINIATURIZE_9621429765821925702: VariantsMap = [
    &["microminiaturize"],
    &["microminiaturise"],
    &["microminiaturize"],
    &["microminiaturise"],
];

pub(crate) static ENTRY_MICROMINIATURIZING_9157788742498342217: VariantsMap = [
    &["microminiaturizing"],
    &["microminiaturising"],
    &["microminiaturizing"],
    &["microminiaturising"],
];

pub(crate) static ENTRY_MICRONIZATIONS_14323368720092109048: VariantsMap = [
    &["micronizations"],
    &["micronisations"],
    &["micronizations"],
    &["micronisations"],
];

pub(crate) static ENTRY_MICRONIZATION_14140336681875685306: VariantsMap = [
    &["micronization"],
    &["micronisation"],
    &["micronization"],
    &["micronisation"],
];

pub(crate) static ENTRY_MICRONIZES_11026427189011331369: VariantsMap = [
    &["micronizes"],
    &["micronises"],
    &["micronizes"],
    &["micronises"],
];

pub(crate) static ENTRY_MICRONIZE_17244565019586455413: VariantsMap = [
    &["micronize"],
    &["micronise"],
    &["micronize"],
    &["micronise"],
];

pub(crate) static ENTRY_MICROPALEONTOLOGIES_15673084178324778221: VariantsMap = [
    &["micropaleontologies"],
    &["micropalaeontologies"],
    &["micropalaeontologies"],
    &["micropalaeontologies"],
];

pub(crate) static ENTRY_MICROPALEONTOLOGISTS_9981502590596153564: VariantsMap = [
    &["micropaleontologists"],
    &["micropalaeontologists"],
    &["micropalaeontologists"],
    &["micropalaeontologists"],
];

pub(crate) static ENTRY_MICROPALEONTOLOGIST_10484705778286496383: VariantsMap = [
    &["micropaleontologist"],
    &["micropalaeontologist"],
    &["micropalaeontologist"],
    &["micropalaeontologist"],
];

pub(crate) static ENTRY_MICROPALEONTOLOGY_12524199822545327475: VariantsMap = [
    &["micropaleontology"],
    &["micropalaeontology"],
    &["micropalaeontology"],
    &["micropalaeontology"],
];

pub(crate) static ENTRY_MICROPOLARIZATIONS_1657538137031140510: VariantsMap = [
    &["micropolarizations"],
    &["micropolarisations"],
    &["micropolarizations"],
    &["micropolarisations"],
];

pub(crate) static ENTRY_MICROPOLARIZATION_7875633180146454277: VariantsMap = [
    &["micropolarization"],
    &["micropolarisation"],
    &["micropolarization"],
    &["micropolarisation"],
];

pub(crate) static ENTRY_MICROSCOPIZES_9765068257112932239: VariantsMap = [
    &["microscopizes"],
    &["microscopises"],
    &["microscopizes"],
    &["microscopises"],
];

pub(crate) static ENTRY_MICROSCOPIZE_9785839938855486861: VariantsMap = [
    &["microscopize"],
    &["microscopise"],
    &["microscopize"],
    &["microscopise"],
];

pub(crate) static ENTRY_MICROSPHERIC_5773029873068865214: VariantsMap = [
    &["microspheric"],
    &["microsphaeric"],
    &["microsphaeric"],
    &["microsphaeric"],
];

pub(crate) static ENTRY_MIDLANDIZES_6424533152072180816: VariantsMap = [
    &["midlandizes"],
    &["midlandises"],
    &["midlandizes"],
    &["midlandises"],
];

pub(crate) static ENTRY_MIDLANDIZE_3510194189738166244: VariantsMap = [
    &["midlandize"],
    &["midlandise"],
    &["midlandize"],
    &["midlandise"],
];

pub(crate) static ENTRY_MIGNIARDIZE_4590904890151973573: VariantsMap = [
    &["migniardize"],
    &["migniardise"],
    &["migniardize"],
    &["migniardise"],
];

pub(crate) static ENTRY_MILITARIZATIONS_16041396934802500390: VariantsMap = [
    &["militarizations"],
    &["militarisations"],
    &["militarizations"],
    &["militarisations"],
];

pub(crate) static ENTRY_MILITARIZATION_554898038906981603: VariantsMap = [
    &["militarization"],
    &["militarisation"],
    &["militarization"],
    &["militarisation"],
];

pub(crate) static ENTRY_MILITARIZED_11151514891666757640: VariantsMap = [
    &["militarized"],
    &["militarised"],
    &["militarized"],
    &["militarised"],
];

pub(crate) static ENTRY_MILITARIZES_5992491948437878542: VariantsMap = [
    &["militarizes"],
    &["militarises"],
    &["militarizes"],
    &["militarises"],
];

pub(crate) static ENTRY_MILITARIZE_8711049019051151425: VariantsMap = [
    &["militarize"],
    &["militarise"],
    &["militarize"],
    &["militarise"],
];

pub(crate) static ENTRY_MILITARIZING_17081897557386742850: VariantsMap = [
    &["militarizing"],
    &["militarising"],
    &["militarizing"],
    &["militarising"],
];

pub(crate) static ENTRY_MILLIGRAMS_7781869386637459768: VariantsMap = [
    &["milligrams"],
    &["milligrams"],
    &["milligrams"],
    &["milligrams"],
];

pub(crate) static ENTRY_MILLIGRAM_16796984474169779303: VariantsMap = [
    &["milligram"],
    &["milligram"],
    &["milligram"],
    &["milligram"],
];

pub(crate) static ENTRY_MILLILITERS_3119249389919852365: VariantsMap = [
    &["milliliters"],
    &["millilitres"],
    &["millilitres"],
    &["millilitres"],
];

pub(crate) static ENTRY_MILLILITER_12944386636303269905: VariantsMap = [
    &["milliliter"],
    &["millilitre"],
    &["millilitre"],
    &["millilitre"],
];

pub(crate) static ENTRY_MILLIMETERS_5241583042561099229: VariantsMap = [
    &["millimeters"],
    &["millimetres"],
    &["millimetres"],
    &["millimetres"],
];

pub(crate) static ENTRY_MILLIMETER_987431015131963906: VariantsMap = [
    &["millimeter"],
    &["millimetre"],
    &["millimetre"],
    &["millimetre"],
];

pub(crate) static ENTRY_MILLIONIZES_14672317174442674555: VariantsMap = [
    &["millionizes"],
    &["millionises"],
    &["millionizes"],
    &["millionises"],
];

pub(crate) static ENTRY_MILLIONIZE_7107796536009410307: VariantsMap = [
    &["millionize"],
    &["millionise"],
    &["millionize"],
    &["millionise"],
];

pub(crate) static ENTRY_MILTONIZED_881674982771846921: VariantsMap = [
    &["miltonized"],
    &["miltonised"],
    &["miltonized"],
    &["miltonised"],
];

pub(crate) static ENTRY_MILTONIZES_10249327127226251005: VariantsMap = [
    &["miltonizes"],
    &["miltonises"],
    &["miltonizes"],
    &["miltonises"],
];

pub(crate) static ENTRY_MILTONIZE_2990759727618280610: VariantsMap = [
    &["miltonize"],
    &["miltonise"],
    &["miltonize"],
    &["miltonise"],
];

pub(crate) static ENTRY_MILTONIZING_57382712508205881: VariantsMap = [
    &["miltonizing"],
    &["miltonising"],
    &["miltonizing"],
    &["miltonising"],
];

pub(crate) static ENTRY_MINERALIZABLES_4251810902045295819: VariantsMap = [
    &["mineralizables"],
    &["mineralisables"],
    &["mineralizables"],
    &["mineralisables"],
];

pub(crate) static ENTRY_MINERALIZABLE_14273899251330384981: VariantsMap = [
    &["mineralizable"],
    &["mineralisable"],
    &["mineralizable"],
    &["mineralisable"],
];

pub(crate) static ENTRY_MINERALIZATIONS_12229839998070627902: VariantsMap = [
    &["mineralizations"],
    &["mineralisations"],
    &["mineralizations"],
    &["mineralisations"],
];

pub(crate) static ENTRY_MINERALIZATION_3564945156895387848: VariantsMap = [
    &["mineralization"],
    &["mineralisation"],
    &["mineralization"],
    &["mineralisation"],
];

pub(crate) static ENTRY_MINERALIZED_15703772425518702501: VariantsMap = [
    &["mineralized"],
    &["mineralised"],
    &["mineralized"],
    &["mineralised"],
];

pub(crate) static ENTRY_MINERALIZERS_10953203791829252058: VariantsMap = [
    &["mineralizers"],
    &["mineralisers"],
    &["mineralizers"],
    &["mineralisers"],
];

pub(crate) static ENTRY_MINERALIZER_17761278028415775424: VariantsMap = [
    &["mineralizer"],
    &["mineraliser"],
    &["mineralizer"],
    &["mineraliser"],
];

pub(crate) static ENTRY_MINERALIZES_4329461307318398064: VariantsMap = [
    &["mineralizes"],
    &["mineralises"],
    &["mineralizes"],
    &["mineralises"],
];

pub(crate) static ENTRY_MINERALIZE_1571843507697484066: VariantsMap = [
    &["mineralize"],
    &["mineralise"],
    &["mineralize"],
    &["mineralise"],
];

pub(crate) static ENTRY_MINERALIZING_2370850438844276958: VariantsMap = [
    &["mineralizing"],
    &["mineralising"],
    &["mineralizing"],
    &["mineralising"],
];

pub(crate) static ENTRY_MINERALOGIZED_17528204496484253594: VariantsMap = [
    &["mineralogized"],
    &["mineralogised"],
    &["mineralogized"],
    &["mineralogised"],
];

pub(crate) static ENTRY_MINERALOGIZES_6295241220342366538: VariantsMap = [
    &["mineralogizes"],
    &["mineralogises"],
    &["mineralogizes"],
    &["mineralogises"],
];

pub(crate) static ENTRY_MINERALOGIZE_3875128191048540734: VariantsMap = [
    &["mineralogize"],
    &["mineralogise"],
    &["mineralogize"],
    &["mineralogise"],
];

pub(crate) static ENTRY_MINERALOGIZING_8320404481105461267: VariantsMap = [
    &["mineralogizing"],
    &["mineralogising"],
    &["mineralogizing"],
    &["mineralogising"],
];

pub(crate) static ENTRY_MINIATURIZATIONS_16792332801073740235: VariantsMap = [
    &["miniaturizations"],
    &["miniaturisations"],
    &["miniaturizations"],
    &["miniaturisations"],
];

pub(crate) static ENTRY_MINIATURIZATION_931417921282710006: VariantsMap = [
    &["miniaturization"],
    &["miniaturisation"],
    &["miniaturization"],
    &["miniaturisation"],
];

pub(crate) static ENTRY_MINIATURIZED_2523726741957158389: VariantsMap = [
    &["miniaturized"],
    &["miniaturised"],
    &["miniaturized"],
    &["miniaturised"],
];

pub(crate) static ENTRY_MINIATURIZES_16030635425775930230: VariantsMap = [
    &["miniaturizes"],
    &["miniaturises"],
    &["miniaturizes"],
    &["miniaturises"],
];

pub(crate) static ENTRY_MINIATURIZE_10753419860525211240: VariantsMap = [
    &["miniaturize"],
    &["miniaturise"],
    &["miniaturize"],
    &["miniaturise"],
];

pub(crate) static ENTRY_MINIATURIZING_9528377556061969785: VariantsMap = [
    &["miniaturizing"],
    &["miniaturising"],
    &["miniaturizing"],
    &["miniaturising"],
];

pub(crate) static ENTRY_MINIBUSES_14356738777892083785: VariantsMap = [
    &["minibuses"],
    &["minibuses"],
    &["minibuses"],
    &["minibuses"],
];

pub(crate) static ENTRY_MINIMIZATIONS_9759567247144361189: VariantsMap = [
    &["minimizations"],
    &["minimisations"],
    &["minimizations"],
    &["minimisations"],
];

pub(crate) static ENTRY_MINIMIZATION_351034506335182236: VariantsMap = [
    &["minimization"],
    &["minimisation"],
    &["minimization"],
    &["minimisation"],
];

pub(crate) static ENTRY_MINIMIZED_3517153139897541686: VariantsMap = [
    &["minimized"],
    &["minimised"],
    &["minimized"],
    &["minimised"],
];

pub(crate) static ENTRY_MINIMIZERS_3982433450924782557: VariantsMap = [
    &["minimizers"],
    &["minimisers"],
    &["minimizers"],
    &["minimisers"],
];

pub(crate) static ENTRY_MINIMIZER_10298751688725307286: VariantsMap = [
    &["minimizer"],
    &["minimiser"],
    &["minimizer"],
    &["minimiser"],
];

pub(crate) static ENTRY_MINIMIZES_11720225532340588601: VariantsMap = [
    &["minimizes"],
    &["minimises"],
    &["minimizes"],
    &["minimises"],
];

pub(crate) static ENTRY_MINIMIZE_3707349867421055069: VariantsMap =
    [&["minimize"], &["minimise"], &["minimize"], &["minimise"]];

pub(crate) static ENTRY_MINIMIZING_6587400313450683054: VariantsMap = [
    &["minimizing"],
    &["minimising"],
    &["minimizing"],
    &["minimising"],
];

pub(crate) static ENTRY_MIRACULIZED_6177671402487877323: VariantsMap = [
    &["miraculized"],
    &["miraculised"],
    &["miraculized"],
    &["miraculised"],
];

pub(crate) static ENTRY_MIRACULIZES_1343333849395320346: VariantsMap = [
    &["miraculizes"],
    &["miraculises"],
    &["miraculizes"],
    &["miraculises"],
];

pub(crate) static ENTRY_MIRACULIZE_1182386821971852529: VariantsMap = [
    &["miraculize"],
    &["miraculise"],
    &["miraculize"],
    &["miraculise"],
];

pub(crate) static ENTRY_MIRACULIZING_8288198734632161015: VariantsMap = [
    &["miraculizing"],
    &["miraculising"],
    &["miraculizing"],
    &["miraculising"],
];

pub(crate) static ENTRY_MIRRORIZES_5236007942143840949: VariantsMap = [
    &["mirrorizes"],
    &["mirrorises"],
    &["mirrorizes"],
    &["mirrorises"],
];

pub(crate) static ENTRY_MIRRORIZE_11945337347676406290: VariantsMap = [
    &["mirrorize"],
    &["mirrorise"],
    &["mirrorize"],
    &["mirrorise"],
];

pub(crate) static ENTRY_MISADVIZE_16409133113491535237: VariantsMap = [
    &["misadvize"],
    &["misadvise"],
    &["misadvize"],
    &["misadvise"],
];

pub(crate) static ENTRY_MISALPHABETIZES_16788559393069866256: VariantsMap = [
    &["misalphabetizes"],
    &["misalphabetises"],
    &["misalphabetizes"],
    &["misalphabetises"],
];

pub(crate) static ENTRY_MISALPHABETIZE_11925476407502455282: VariantsMap = [
    &["misalphabetize"],
    &["misalphabetise"],
    &["misalphabetize"],
    &["misalphabetise"],
];

pub(crate) static ENTRY_MISANTHROPIZED_11727139559415514846: VariantsMap = [
    &["misanthropized"],
    &["misanthropised"],
    &["misanthropized"],
    &["misanthropised"],
];

pub(crate) static ENTRY_MISANTHROPIZES_3973773355167530030: VariantsMap = [
    &["misanthropizes"],
    &["misanthropises"],
    &["misanthropizes"],
    &["misanthropises"],
];

pub(crate) static ENTRY_MISANTHROPIZE_1922550089268916167: VariantsMap = [
    &["misanthropize"],
    &["misanthropise"],
    &["misanthropize"],
    &["misanthropise"],
];

pub(crate) static ENTRY_MISANTHROPIZING_17542823159662397794: VariantsMap = [
    &["misanthropizing"],
    &["misanthropising"],
    &["misanthropizing"],
    &["misanthropising"],
];

pub(crate) static ENTRY_MISAUTHORIZATIONS_18193977628681315405: VariantsMap = [
    &["misauthorizations"],
    &["misauthorisations"],
    &["misauthorizations"],
    &["misauthorisations"],
];

pub(crate) static ENTRY_MISAUTHORIZATION_3255527742163937042: VariantsMap = [
    &["misauthorization"],
    &["misauthorisation"],
    &["misauthorization"],
    &["misauthorisation"],
];

pub(crate) static ENTRY_MISAUTHORIZES_15338039315356738476: VariantsMap = [
    &["misauthorizes"],
    &["misauthorises"],
    &["misauthorizes"],
    &["misauthorises"],
];

pub(crate) static ENTRY_MISAUTHORIZE_3226310660966698523: VariantsMap = [
    &["misauthorize"],
    &["misauthorise"],
    &["misauthorize"],
    &["misauthorise"],
];

pub(crate) static ENTRY_MISBAPTIZES_7471355898746773980: VariantsMap = [
    &["misbaptizes"],
    &["misbaptises"],
    &["misbaptizes"],
    &["misbaptises"],
];

pub(crate) static ENTRY_MISBAPTIZE_3680575039131375475: VariantsMap = [
    &["misbaptize"],
    &["misbaptise"],
    &["misbaptize"],
    &["misbaptise"],
];

pub(crate) static ENTRY_MISBEHAVIORS_5196208905035156615: VariantsMap = [
    &["misbehaviors"],
    &["misbehaviours"],
    &["misbehaviours"],
    &["misbehaviours"],
];

pub(crate) static ENTRY_MISBEHAVIOR_540636700073252665: VariantsMap = [
    &["misbehavior"],
    &["misbehaviour"],
    &["misbehaviour"],
    &["misbehaviour"],
];

pub(crate) static ENTRY_MISCANONIZES_3620605581508255824: VariantsMap = [
    &["miscanonizes"],
    &["miscanonises"],
    &["miscanonizes"],
    &["miscanonises"],
];

pub(crate) static ENTRY_MISCANONIZE_9609660140189549896: VariantsMap = [
    &["miscanonize"],
    &["miscanonise"],
    &["miscanonize"],
    &["miscanonise"],
];

pub(crate) static ENTRY_MISCHARACTERIZATIONS_9820262910491559476: VariantsMap = [
    &["mischaracterizations"],
    &["mischaracterisations"],
    &["mischaracterizations"],
    &["mischaracterisations"],
];

pub(crate) static ENTRY_MISCHARACTERIZATION_2446223644330426559: VariantsMap = [
    &["mischaracterization"],
    &["mischaracterisation"],
    &["mischaracterization"],
    &["mischaracterisation"],
];

pub(crate) static ENTRY_MISCHARACTERIZES_6539624896226097074: VariantsMap = [
    &["mischaracterizes"],
    &["mischaracterises"],
    &["mischaracterizes"],
    &["mischaracterises"],
];

pub(crate) static ENTRY_MISCHARACTERIZE_14909915885126227137: VariantsMap = [
    &["mischaracterize"],
    &["mischaracterise"],
    &["mischaracterize"],
    &["mischaracterise"],
];

pub(crate) static ENTRY_MISCOLORATION_6928531033755254197: VariantsMap = [
    &["miscoloration"],
    &["miscolouration"],
    &["miscolouration"],
    &["miscolouration"],
];

pub(crate) static ENTRY_MISCOLORED_6650096186765477181: VariantsMap = [
    &["miscolored"],
    &["miscoloured"],
    &["miscoloured"],
    &["miscoloured"],
];

pub(crate) static ENTRY_MISCOLORING_12066623990129129026: VariantsMap = [
    &["miscoloring"],
    &["miscolouring"],
    &["miscolouring"],
    &["miscolouring"],
];

pub(crate) static ENTRY_MISCOLORS_6442863367431484314: VariantsMap = [
    &["miscolors"],
    &["miscolours"],
    &["miscolours"],
    &["miscolours"],
];

pub(crate) static ENTRY_MISCOLOR_18269855271059857487: VariantsMap = [
    &["miscolor"],
    &["miscolour"],
    &["miscolour"],
    &["miscolour"],
];

pub(crate) static ENTRY_MISDEMEANORS_16426839555682853683: VariantsMap = [
    &["misdemeanors"],
    &["misdemeanours"],
    &["misdemeanours"],
    &["misdemeanours"],
];

pub(crate) static ENTRY_MISDEMEANOR_12584005266066485554: VariantsMap = [
    &["misdemeanor"],
    &["misdemeanour"],
    &["misdemeanour"],
    &["misdemeanour"],
];

pub(crate) static ENTRY_MISEMPHASIZES_16801626349198066449: VariantsMap = [
    &["misemphasizes"],
    &["misemphasises"],
    &["misemphasizes"],
    &["misemphasises"],
];

pub(crate) static ENTRY_MISEMPHASIZE_8403241665905587325: VariantsMap = [
    &["misemphasize"],
    &["misemphasise"],
    &["misemphasize"],
    &["misemphasise"],
];

pub(crate) static ENTRY_MISJUDGMENTS_15088301739266707294: VariantsMap = [
    &["misjudgments"],
    &["misjudgements"],
    &["misjudgments"],
    &["misjudgements"],
];

pub(crate) static ENTRY_MISJUDGMENT_7815182386368600232: VariantsMap = [
    &["misjudgment"],
    &["misjudgement"],
    &["misjudgment"],
    &["misjudgement"],
];

pub(crate) static ENTRY_MISLABELED_11561074022001091176: VariantsMap = [
    &["mislabeled"],
    &["mislabelled"],
    &["mislabelled"],
    &["mislabelled"],
];

pub(crate) static ENTRY_MISLABELING_6355454506170956328: VariantsMap = [
    &["mislabeling"],
    &["mislabelling"],
    &["mislabelling"],
    &["mislabelling"],
];

pub(crate) static ENTRY_MISLABORED_11357890207265877782: VariantsMap = [
    &["mislabored"],
    &["mislaboured"],
    &["mislaboured"],
    &["mislaboured"],
];

pub(crate) static ENTRY_MISLABORING_3935355170149150597: VariantsMap = [
    &["mislaboring"],
    &["mislabouring"],
    &["mislabouring"],
    &["mislabouring"],
];

pub(crate) static ENTRY_MISLABORS_12989629945052355383: VariantsMap = [
    &["mislabors"],
    &["mislabours"],
    &["mislabours"],
    &["mislabours"],
];

pub(crate) static ENTRY_MISLABOR_2521634739502370747: VariantsMap = [
    &["mislabor"],
    &["mislabour"],
    &["mislabour"],
    &["mislabour"],
];

pub(crate) static ENTRY_MISOPEDIA_7178332077163005269: VariantsMap = [
    &["misopedia"],
    &["misopaedia"],
    &["misopaedia"],
    &["misopaedia"],
];

pub(crate) static ENTRY_MISOPEDISM_6542233660865950036: VariantsMap = [
    &["misopedism"],
    &["misopaedism"],
    &["misopaedism"],
    &["misopaedism"],
];

pub(crate) static ENTRY_MISOPEDIST_6283172222250787222: VariantsMap = [
    &["misopedist"],
    &["misopaedist"],
    &["misopaedist"],
    &["misopaedist"],
];

pub(crate) static ENTRY_MISORGANIZATIONS_15826994608931053543: VariantsMap = [
    &["misorganizations"],
    &["misorganisations"],
    &["misorganizations"],
    &["misorganisations"],
];

pub(crate) static ENTRY_MISORGANIZATION_424938788016993526: VariantsMap = [
    &["misorganization"],
    &["misorganisation"],
    &["misorganization"],
    &["misorganisation"],
];

pub(crate) static ENTRY_MISORGANIZES_15277883172814079121: VariantsMap = [
    &["misorganizes"],
    &["misorganises"],
    &["misorganizes"],
    &["misorganises"],
];

pub(crate) static ENTRY_MISORGANIZE_5050999531140182922: VariantsMap = [
    &["misorganize"],
    &["misorganise"],
    &["misorganize"],
    &["misorganise"],
];

pub(crate) static ENTRY_MISPRIZAL_9950323538351898149: VariantsMap = [
    &["misprizal"],
    &["misprisal"],
    &["misprizal"],
    &["misprisal"],
];

pub(crate) static ENTRY_MISPRIZED_201951729530329597: VariantsMap = [
    &["misprized"],
    &["misprized"],
    &["misprized"],
    &["misprized"],
];

pub(crate) static ENTRY_MISPRIZER_14657854399118585515: VariantsMap = [
    &["misprizer"],
    &["mispriser"],
    &["misprizer"],
    &["mispriser"],
];

pub(crate) static ENTRY_MISPRIZES_12171617639005381197: VariantsMap = [
    &["misprizes"],
    &["misprizes"],
    &["misprizes"],
    &["misprizes"],
];

pub(crate) static ENTRY_MISPRIZE_3879577188385927221: VariantsMap =
    [&["misprize"], &["misprize"], &["misprize"], &["misprize"]];

pub(crate) static ENTRY_MISPRIZING_8754659322217023153: VariantsMap = [
    &["misprizing"],
    &["misprizing"],
    &["misprizing"],
    &["misprizing"],
];

pub(crate) static ENTRY_MISREALIZES_6455083844071414450: VariantsMap = [
    &["misrealizes"],
    &["misrealises"],
    &["misrealizes"],
    &["misrealises"],
];

pub(crate) static ENTRY_MISREALIZE_3770533395070542679: VariantsMap = [
    &["misrealize"],
    &["misrealise"],
    &["misrealize"],
    &["misrealise"],
];

pub(crate) static ENTRY_MISRECOGNIZES_18195281488073038600: VariantsMap = [
    &["misrecognizes"],
    &["misrecognises"],
    &["misrecognizes"],
    &["misrecognises"],
];

pub(crate) static ENTRY_MISRECOGNIZE_7512259793232915009: VariantsMap = [
    &["misrecognize"],
    &["misrecognise"],
    &["misrecognize"],
    &["misrecognise"],
];

pub(crate) static ENTRY_MISROUTING_16866807267371825983: VariantsMap = [
    &["misrouting"],
    &["misrouteing"],
    &["misrouteing"],
    &["misrouteing"],
];

pub(crate) static ENTRY_MISSIONARIZED_7112814104506945817: VariantsMap = [
    &["missionarized"],
    &["missionarised"],
    &["missionarized"],
    &["missionarised"],
];

pub(crate) static ENTRY_MISSIONARIZES_13632702496680971142: VariantsMap = [
    &["missionarizes"],
    &["missionarises"],
    &["missionarizes"],
    &["missionarises"],
];

pub(crate) static ENTRY_MISSIONARIZE_9166622119973962629: VariantsMap = [
    &["missionarize"],
    &["missionarise"],
    &["missionarize"],
    &["missionarise"],
];

pub(crate) static ENTRY_MISSIONARIZING_15494487339870146163: VariantsMap = [
    &["missionarizing"],
    &["missionarising"],
    &["missionarizing"],
    &["missionarising"],
];

pub(crate) static ENTRY_MISSIONIZATION_3188593491464992438: VariantsMap = [
    &["missionization"],
    &["missionisation"],
    &["missionization"],
    &["missionisation"],
];

pub(crate) static ENTRY_MISSIONIZED_17672523180481949130: VariantsMap = [
    &["missionized"],
    &["missionised"],
    &["missionized"],
    &["missionised"],
];

pub(crate) static ENTRY_MISSIONIZERS_9999401875646897234: VariantsMap = [
    &["missionizers"],
    &["missionisers"],
    &["missionizers"],
    &["missionisers"],
];

pub(crate) static ENTRY_MISSIONIZER_16128334848487303471: VariantsMap = [
    &["missionizer"],
    &["missioniser"],
    &["missionizer"],
    &["missioniser"],
];

pub(crate) static ENTRY_MISSIONIZES_14585446178899362762: VariantsMap = [
    &["missionizes"],
    &["missionises"],
    &["missionizes"],
    &["missionises"],
];

pub(crate) static ENTRY_MISSIONIZE_4938980905954929367: VariantsMap = [
    &["missionize"],
    &["missionise"],
    &["missionize"],
    &["missionise"],
];

pub(crate) static ENTRY_MISSIONIZING_7220648756581988180: VariantsMap = [
    &["missionizing"],
    &["missionising"],
    &["missionizing"],
    &["missionising"],
];

pub(crate) static ENTRY_MITERED_5787585051744125345: VariantsMap =
    [&["mitered"], &["mitred"], &["mitred"], &["mitred"]];

pub(crate) static ENTRY_MITERER_825284550887492153: VariantsMap =
    [&["miterer"], &["mitrer"], &["mitrer"], &["mitrer"]];

pub(crate) static ENTRY_MITERFLOWER_5319553020008949441: VariantsMap = [
    &["miterflower"],
    &["mitreflower"],
    &["mitreflower"],
    &["mitreflower"],
];

pub(crate) static ENTRY_MITERING_4790682826218652875: VariantsMap =
    [&["mitering"], &["mitring"], &["mitring"], &["mitring"]];

pub(crate) static ENTRY_MITERS_14490210158644236688: VariantsMap =
    [&["miters"], &["mitres"], &["mitres"], &["mitres"]];

pub(crate) static ENTRY_MITERWORTS_2595793822662820807: VariantsMap = [
    &["miterworts"],
    &["mitreworts"],
    &["mitreworts"],
    &["mitreworts"],
];

pub(crate) static ENTRY_MITERWORT_1811552736091417438: VariantsMap = [
    &["miterwort"],
    &["mitrewort"],
    &["mitrewort"],
    &["mitrewort"],
];

pub(crate) static ENTRY_MITER_5926274060174606640: VariantsMap =
    [&["miter"], &["mitre"], &["mitre"], &["mitre"]];

pub(crate) static ENTRY_MITHRIDATIZED_11801964586289066812: VariantsMap = [
    &["mithridatized"],
    &["mithridatised"],
    &["mithridatized"],
    &["mithridatised"],
];

pub(crate) static ENTRY_MITHRIDATIZES_10858785786810308998: VariantsMap = [
    &["mithridatizes"],
    &["mithridatises"],
    &["mithridatizes"],
    &["mithridatises"],
];

pub(crate) static ENTRY_MITHRIDATIZE_10215083672393880782: VariantsMap = [
    &["mithridatize"],
    &["mithridatise"],
    &["mithridatize"],
    &["mithridatise"],
];

pub(crate) static ENTRY_MITHRIDATIZING_9625317964263865406: VariantsMap = [
    &["mithridatizing"],
    &["mithridatising"],
    &["mithridatizing"],
    &["mithridatising"],
];

pub(crate) static ENTRY_MIZE_2563563095806882396: VariantsMap =
    [&["mize"], &["mise"], &["mize"], &["mise"]];

pub(crate) static ENTRY_MOBILIZABLER_10904297470856896702: VariantsMap = [
    &["mobilizabler"],
    &["mobilisabler"],
    &["mobilizabler"],
    &["mobilisabler"],
];

pub(crate) static ENTRY_MOBILIZABLEST_15444054356148134406: VariantsMap = [
    &["mobilizablest"],
    &["mobilisablest"],
    &["mobilizablest"],
    &["mobilisablest"],
];

pub(crate) static ENTRY_MOBILIZABLES_4178976069735614840: VariantsMap = [
    &["mobilizables"],
    &["mobilisables"],
    &["mobilizables"],
    &["mobilisables"],
];

pub(crate) static ENTRY_MOBILIZABLE_12252941647214817128: VariantsMap = [
    &["mobilizable"],
    &["mobilisable"],
    &["mobilizable"],
    &["mobilisable"],
];

pub(crate) static ENTRY_MOBILIZATIONS_2426490826167845431: VariantsMap = [
    &["mobilizations"],
    &["mobilisations"],
    &["mobilizations"],
    &["mobilisations"],
];

pub(crate) static ENTRY_MOBILIZATION_12561905628389471063: VariantsMap = [
    &["mobilization"],
    &["mobilisation"],
    &["mobilization"],
    &["mobilisation"],
];

pub(crate) static ENTRY_MOBILIZED_13415546459102928772: VariantsMap = [
    &["mobilized"],
    &["mobilised"],
    &["mobilized"],
    &["mobilised"],
];

pub(crate) static ENTRY_MOBILIZERS_13019397665994940764: VariantsMap = [
    &["mobilizers"],
    &["mobilisers"],
    &["mobilizers"],
    &["mobilisers"],
];

pub(crate) static ENTRY_MOBILIZER_12434984457191425108: VariantsMap = [
    &["mobilizer"],
    &["mobiliser"],
    &["mobilizer"],
    &["mobiliser"],
];

pub(crate) static ENTRY_MOBILIZES_17265459453729317116: VariantsMap = [
    &["mobilizes"],
    &["mobilises"],
    &["mobilizes"],
    &["mobilises"],
];

pub(crate) static ENTRY_MOBILIZE_4102809031800805050: VariantsMap =
    [&["mobilize"], &["mobilise"], &["mobilize"], &["mobilise"]];

pub(crate) static ENTRY_MOBILIZING_1050354789096204914: VariantsMap = [
    &["mobilizing"],
    &["mobilising"],
    &["mobilizing"],
    &["mobilising"],
];

pub(crate) static ENTRY_MODALIZES_16162099476273051141: VariantsMap = [
    &["modalizes"],
    &["modalises"],
    &["modalizes"],
    &["modalises"],
];

pub(crate) static ENTRY_MODALIZE_5407143044061821916: VariantsMap =
    [&["modalize"], &["modalise"], &["modalize"], &["modalise"]];

pub(crate) static ENTRY_MODELED_11484485171487146129: VariantsMap =
    [&["modeled"], &["modelled"], &["modelled"], &["modelled"]];

pub(crate) static ENTRY_MODELERS_1650738308079465867: VariantsMap = [
    &["modelers"],
    &["modellers"],
    &["modellers"],
    &["modellers"],
];

pub(crate) static ENTRY_MODELER_15810368749048552373: VariantsMap =
    [&["modeler"], &["modeller"], &["modeller"], &["modeller"]];

pub(crate) static ENTRY_MODELINGS_7972192595739783612: VariantsMap = [
    &["modelings"],
    &["modellings"],
    &["modellings"],
    &["modellings"],
];

pub(crate) static ENTRY_MODELING_16661180513183857784: VariantsMap = [
    &["modeling"],
    &["modelling"],
    &["modelling"],
    &["modelling"],
];

pub(crate) static ENTRY_MODERNIZABLES_10916683662176279423: VariantsMap = [
    &["modernizables"],
    &["modernisables"],
    &["modernizables"],
    &["modernisables"],
];

pub(crate) static ENTRY_MODERNIZABLE_18104998027667857415: VariantsMap = [
    &["modernizable"],
    &["modernisable"],
    &["modernizable"],
    &["modernisable"],
];

pub(crate) static ENTRY_MODERNIZATIONS_3434518085505458555: VariantsMap = [
    &["modernizations"],
    &["modernisations"],
    &["modernizations"],
    &["modernisations"],
];

pub(crate) static ENTRY_MODERNIZATION_12042012760824050298: VariantsMap = [
    &["modernization"],
    &["modernisation"],
    &["modernization"],
    &["modernisation"],
];

pub(crate) static ENTRY_MODERNIZED_2831927114827207033: VariantsMap = [
    &["modernized"],
    &["modernised"],
    &["modernized"],
    &["modernised"],
];

pub(crate) static ENTRY_MODERNIZERS_7055005025004923190: VariantsMap = [
    &["modernizers"],
    &["modernisers"],
    &["modernizers"],
    &["modernisers"],
];

pub(crate) static ENTRY_MODERNIZER_18085383743865602462: VariantsMap = [
    &["modernizer"],
    &["moderniser"],
    &["modernizer"],
    &["moderniser"],
];

pub(crate) static ENTRY_MODERNIZES_9697284314317925697: VariantsMap = [
    &["modernizes"],
    &["modernises"],
    &["modernizes"],
    &["modernises"],
];

pub(crate) static ENTRY_MODERNIZE_16764604267655437202: VariantsMap = [
    &["modernize"],
    &["modernise"],
    &["modernize"],
    &["modernise"],
];

pub(crate) static ENTRY_MODERNIZING_12238279341877582234: VariantsMap = [
    &["modernizing"],
    &["modernising"],
    &["modernizing"],
    &["modernising"],
];

pub(crate) static ENTRY_MODULARIZATION_3680687403533449721: VariantsMap = [
    &["modularization"],
    &["modularisation"],
    &["modularization"],
    &["modularisation"],
];

pub(crate) static ENTRY_MODULARIZED_13090071993675981622: VariantsMap = [
    &["modularized"],
    &["modularised"],
    &["modularized"],
    &["modularised"],
];

pub(crate) static ENTRY_MODULARIZES_734923478071063897: VariantsMap = [
    &["modularizes"],
    &["modularises"],
    &["modularizes"],
    &["modularises"],
];

pub(crate) static ENTRY_MODULARIZE_7661020760191995153: VariantsMap = [
    &["modularize"],
    &["modularise"],
    &["modularize"],
    &["modularise"],
];

pub(crate) static ENTRY_MODULARIZING_15219616854242753285: VariantsMap = [
    &["modularizing"],
    &["modularising"],
    &["modularizing"],
    &["modularising"],
];

pub(crate) static ENTRY_MOGGY_579730209646920518: VariantsMap =
    [&["moggy"], &["moggie"], &["moggie"], &["moggie"]];

pub(crate) static ENTRY_MOHAMMEDANIZATIONS_4617417514155359733: VariantsMap = [
    &["mohammedanizations"],
    &["mohammedanisations"],
    &["mohammedanizations"],
    &["mohammedanisations"],
];

pub(crate) static ENTRY_MOHAMMEDANIZATION_4942477043569377601: VariantsMap = [
    &["mohammedanization"],
    &["mohammedanisation"],
    &["mohammedanization"],
    &["mohammedanisation"],
];

pub(crate) static ENTRY_MOHAMMEDANIZED_9776130510036028314: VariantsMap = [
    &["mohammedanized"],
    &["mohammedanised"],
    &["mohammedanized"],
    &["mohammedanised"],
];

pub(crate) static ENTRY_MOHAMMEDANIZES_18373426896542622891: VariantsMap = [
    &["mohammedanizes"],
    &["mohammedanises"],
    &["mohammedanizes"],
    &["mohammedanises"],
];

pub(crate) static ENTRY_MOHAMMEDANIZE_2941075096626155541: VariantsMap = [
    &["mohammedanize"],
    &["mohammedanise"],
    &["mohammedanize"],
    &["mohammedanise"],
];

pub(crate) static ENTRY_MOHAMMEDANIZING_1483796922327274666: VariantsMap = [
    &["mohammedanizing"],
    &["mohammedanising"],
    &["mohammedanizing"],
    &["mohammedanising"],
];

pub(crate) static ENTRY_MOISTURIZATION_14359328382639845392: VariantsMap = [
    &["moisturization"],
    &["moisturisation"],
    &["moisturization"],
    &["moisturisation"],
];

pub(crate) static ENTRY_MOISTURIZED_3672738717919459176: VariantsMap = [
    &["moisturized"],
    &["moisturised"],
    &["moisturized"],
    &["moisturised"],
];

pub(crate) static ENTRY_MOISTURIZERS_3778922692605477146: VariantsMap = [
    &["moisturizers"],
    &["moisturisers"],
    &["moisturizers"],
    &["moisturisers"],
];

pub(crate) static ENTRY_MOISTURIZER_15515955640030709734: VariantsMap = [
    &["moisturizer"],
    &["moisturiser"],
    &["moisturizer"],
    &["moisturiser"],
];

pub(crate) static ENTRY_MOISTURIZES_12009510094905479817: VariantsMap = [
    &["moisturizes"],
    &["moisturises"],
    &["moisturizes"],
    &["moisturises"],
];

pub(crate) static ENTRY_MOISTURIZE_7565680035125417251: VariantsMap = [
    &["moisturize"],
    &["moisturise"],
    &["moisturize"],
    &["moisturise"],
];

pub(crate) static ENTRY_MOISTURIZING_13406294210722157217: VariantsMap = [
    &["moisturizing"],
    &["moisturising"],
    &["moisturizing"],
    &["moisturising"],
];

pub(crate) static ENTRY_MOLARIZATIONS_12398118473905254189: VariantsMap = [
    &["molarizations"],
    &["molarisations"],
    &["molarizations"],
    &["molarisations"],
];

pub(crate) static ENTRY_MOLARIZATION_17680920592577594623: VariantsMap = [
    &["molarization"],
    &["molarisation"],
    &["molarization"],
    &["molarisation"],
];

pub(crate) static ENTRY_MOLDED_4867396599674557897: VariantsMap =
    [&["molded"], &["moulded"], &["moulded"], &["moulded"]];

pub(crate) static ENTRY_MOLDERED_13806811290362462856: VariantsMap = [
    &["moldered"],
    &["mouldered"],
    &["mouldered"],
    &["mouldered"],
];

pub(crate) static ENTRY_MOLDERING_761432945987723341: VariantsMap = [
    &["moldering"],
    &["mouldering"],
    &["mouldering"],
    &["mouldering"],
];

pub(crate) static ENTRY_MOLDERS_10624195404241411222: VariantsMap =
    [&["molders"], &["moulders"], &["moulders"], &["moulders"]];

pub(crate) static ENTRY_MOLDER_5468513924454038075: VariantsMap =
    [&["molder"], &["moulder"], &["moulder"], &["moulder"]];

pub(crate) static ENTRY_MOLDIER_17925953827043179593: VariantsMap =
    [&["moldier"], &["mouldier"], &["mouldier"], &["mouldier"]];

pub(crate) static ENTRY_MOLDIEST_11552700490364540702: VariantsMap = [
    &["moldiest"],
    &["mouldiest"],
    &["mouldiest"],
    &["mouldiest"],
];

pub(crate) static ENTRY_MOLDINGS_11877581157093154122: VariantsMap = [
    &["moldings"],
    &["mouldings"],
    &["mouldings"],
    &["mouldings"],
];

pub(crate) static ENTRY_MOLDING_16972516311440379476: VariantsMap =
    [&["molding"], &["moulding"], &["moulding"], &["moulding"]];

pub(crate) static ENTRY_MOLDS_209402696956725647: VariantsMap =
    [&["molds"], &["moulds"], &["moulds"], &["moulds"]];

pub(crate) static ENTRY_MOLDY_15469792360276639207: VariantsMap =
    [&["moldy"], &["mouldy"], &["mouldy"], &["mouldy"]];

pub(crate) static ENTRY_MOLD_4204617930046953090: VariantsMap =
    [&["mold"], &["mould"], &["mould"], &["mould"]];

pub(crate) static ENTRY_MOLLUSCAN_1214531649444858741: VariantsMap = [
    &["molluscan"],
    &["molluscan"],
    &["molluscan"],
    &["molluscan"],
];

pub(crate) static ENTRY_MOLLUSKS_7855528336644805045: VariantsMap =
    [&["mollusks"], &["molluscs"], &["molluscs"], &["molluscs"]];

pub(crate) static ENTRY_MOLLUSK_11723969351177528383: VariantsMap =
    [&["mollusk"], &["mollusc"], &["mollusc"], &["mollusc"]];

pub(crate) static ENTRY_MOLOCHIZED_9592437975186863992: VariantsMap = [
    &["molochized"],
    &["molochised"],
    &["molochized"],
    &["molochised"],
];

pub(crate) static ENTRY_MOLOCHIZES_5328704096373944300: VariantsMap = [
    &["molochizes"],
    &["molochises"],
    &["molochizes"],
    &["molochises"],
];

pub(crate) static ENTRY_MOLOCHIZE_10281963447149464183: VariantsMap = [
    &["molochize"],
    &["molochise"],
    &["molochize"],
    &["molochise"],
];

pub(crate) static ENTRY_MOLOCHIZING_4942125478827957915: VariantsMap = [
    &["molochizing"],
    &["molochising"],
    &["molochizing"],
    &["molochising"],
];

pub(crate) static ENTRY_MOLTED_13851575492873022320: VariantsMap =
    [&["molted"], &["moulted"], &["moulted"], &["moulted"]];

pub(crate) static ENTRY_MOLTING_8969305985716783845: VariantsMap =
    [&["molting"], &["moulting"], &["moulting"], &["moulting"]];

pub(crate) static ENTRY_MOLTS_10499278002715999239: VariantsMap =
    [&["molts"], &["moults"], &["moults"], &["moults"]];

pub(crate) static ENTRY_MOLT_13673484917001179046: VariantsMap =
    [&["molt"], &["moult"], &["moult"], &["moult"]];

pub(crate) static ENTRY_MOMS_301669076590401125: VariantsMap =
    [&["moms"], &["mums"], &["moms"], &["mums"]];

pub(crate) static ENTRY_MOM_1933585215034313561: VariantsMap =
    [&["mom"], &["mum"], &["mom"], &["mum"]];

pub(crate) static ENTRY_MONARCHIZED_5463371092470864555: VariantsMap = [
    &["monarchized"],
    &["monarchised"],
    &["monarchized"],
    &["monarchised"],
];

pub(crate) static ENTRY_MONARCHIZERS_16942324140335093566: VariantsMap = [
    &["monarchizers"],
    &["monarchisers"],
    &["monarchizers"],
    &["monarchisers"],
];

pub(crate) static ENTRY_MONARCHIZER_855097092908696109: VariantsMap = [
    &["monarchizer"],
    &["monarchiser"],
    &["monarchizer"],
    &["monarchiser"],
];

pub(crate) static ENTRY_MONARCHIZES_6119101542364042858: VariantsMap = [
    &["monarchizes"],
    &["monarchises"],
    &["monarchizes"],
    &["monarchises"],
];

pub(crate) static ENTRY_MONARCHIZE_15594788008045550047: VariantsMap = [
    &["monarchize"],
    &["monarchise"],
    &["monarchize"],
    &["monarchise"],
];

pub(crate) static ENTRY_MONARCHIZING_8557056119920625430: VariantsMap = [
    &["monarchizing"],
    &["monarchising"],
    &["monarchizing"],
    &["monarchising"],
];

pub(crate) static ENTRY_MONASTICIZES_11754670453138255334: VariantsMap = [
    &["monasticizes"],
    &["monasticises"],
    &["monasticizes"],
    &["monasticises"],
];

pub(crate) static ENTRY_MONASTICIZE_5086142104694058939: VariantsMap = [
    &["monasticize"],
    &["monasticise"],
    &["monasticize"],
    &["monasticise"],
];

pub(crate) static ENTRY_MONECIAN_4879335142867519038: VariantsMap = [
    &["monecian"],
    &["monoecian"],
    &["monoecian"],
    &["monoecian"],
];

pub(crate) static ENTRY_MONESTROUS_18265353223508436919: VariantsMap = [
    &["monestrous"],
    &["monoestrous"],
    &["monoestrous"],
    &["monoestrous"],
];

pub(crate) static ENTRY_MONETIZATIONS_17875812136896605805: VariantsMap = [
    &["monetizations"],
    &["monetisations"],
    &["monetizations"],
    &["monetisations"],
];

pub(crate) static ENTRY_MONETIZATION_14707832132850700848: VariantsMap = [
    &["monetization"],
    &["monetisation"],
    &["monetization"],
    &["monetisation"],
];

pub(crate) static ENTRY_MONETIZED_16824817034586571013: VariantsMap = [
    &["monetized"],
    &["monetised"],
    &["monetized"],
    &["monetised"],
];

pub(crate) static ENTRY_MONETIZES_10634709768412203424: VariantsMap = [
    &["monetizes"],
    &["monetises"],
    &["monetizes"],
    &["monetises"],
];

pub(crate) static ENTRY_MONETIZE_11872297589880053114: VariantsMap =
    [&["monetize"], &["monetise"], &["monetize"], &["monetise"]];

pub(crate) static ENTRY_MONETIZING_15158826539636538785: VariantsMap = [
    &["monetizing"],
    &["monetising"],
    &["monetizing"],
    &["monetising"],
];

pub(crate) static ENTRY_MONGOLIZED_7180490123154768644: VariantsMap = [
    &["mongolized"],
    &["mongolised"],
    &["mongolized"],
    &["mongolised"],
];

pub(crate) static ENTRY_MONGOLIZES_14233973300159557786: VariantsMap = [
    &["mongolizes"],
    &["mongolises"],
    &["mongolizes"],
    &["mongolises"],
];

pub(crate) static ENTRY_MONGOLIZE_3876217931633008306: VariantsMap = [
    &["mongolize"],
    &["mongolise"],
    &["mongolize"],
    &["mongolise"],
];

pub(crate) static ENTRY_MONGOLIZING_316291781280258543: VariantsMap = [
    &["mongolizing"],
    &["mongolising"],
    &["mongolizing"],
    &["mongolising"],
];

pub(crate) static ENTRY_MONGRELIZATIONS_4344310052877835528: VariantsMap = [
    &["mongrelizations"],
    &["mongrelisations"],
    &["mongrelizations"],
    &["mongrelisations"],
];

pub(crate) static ENTRY_MONGRELIZATION_4498531267273755020: VariantsMap = [
    &["mongrelization"],
    &["mongrelisation"],
    &["mongrelization"],
    &["mongrelisation"],
];

pub(crate) static ENTRY_MONGRELIZED_337807322341455274: VariantsMap = [
    &["mongrelized"],
    &["mongrelised"],
    &["mongrelized"],
    &["mongrelised"],
];

pub(crate) static ENTRY_MONGRELIZER_820251071432420034: VariantsMap = [
    &["mongrelizer"],
    &["mongreliser"],
    &["mongrelizer"],
    &["mongreliser"],
];

pub(crate) static ENTRY_MONGRELIZES_12163647302918101422: VariantsMap = [
    &["mongrelizes"],
    &["mongrelises"],
    &["mongrelizes"],
    &["mongrelises"],
];

pub(crate) static ENTRY_MONGRELIZE_9330914540755997377: VariantsMap = [
    &["mongrelize"],
    &["mongrelise"],
    &["mongrelize"],
    &["mongrelise"],
];

pub(crate) static ENTRY_MONGRELIZING_3846168385938703815: VariantsMap = [
    &["mongrelizing"],
    &["mongrelising"],
    &["mongrelizing"],
    &["mongrelising"],
];

pub(crate) static ENTRY_MONOCHORDIZES_3579118842327693619: VariantsMap = [
    &["monochordizes"],
    &["monochordises"],
    &["monochordizes"],
    &["monochordises"],
];

pub(crate) static ENTRY_MONOCHORDIZE_16797802444325265589: VariantsMap = [
    &["monochordize"],
    &["monochordise"],
    &["monochordize"],
    &["monochordise"],
];

pub(crate) static ENTRY_MONOECIOUS_16926061790085197953: VariantsMap = [
    &["monoecious"],
    &["monoecious"],
    &["monoecious"],
    &["monoecious"],
];

pub(crate) static ENTRY_MONOLOGIZED_213349531977540597: VariantsMap = [
    &["monologized"],
    &["monologised"],
    &["monologized"],
    &["monologised"],
];

pub(crate) static ENTRY_MONOLOGIZES_1530471276833382712: VariantsMap = [
    &["monologizes"],
    &["monologises"],
    &["monologizes"],
    &["monologises"],
];

pub(crate) static ENTRY_MONOLOGIZE_4785562031381064606: VariantsMap = [
    &["monologize"],
    &["monologise"],
    &["monologize"],
    &["monologise"],
];

pub(crate) static ENTRY_MONOLOGIZING_12574433078846769687: VariantsMap = [
    &["monologizing"],
    &["monologising"],
    &["monologizing"],
    &["monologising"],
];

pub(crate) static ENTRY_MONOLOGUES_14056042492962235985: VariantsMap = [
    &["monologues"],
    &["monologues"],
    &["monologues"],
    &["monologues"],
];

pub(crate) static ENTRY_MONOLOGUE_817979629647456661: VariantsMap = [
    &["monologue"],
    &["monologue"],
    &["monologue"],
    &["monologue"],
];

pub(crate) static ENTRY_MONOLOGUIZED_12070685860799121235: VariantsMap = [
    &["monologuized"],
    &["monologuised"],
    &["monologuized"],
    &["monologuised"],
];

pub(crate) static ENTRY_MONOLOGUIZES_8634308732447205916: VariantsMap = [
    &["monologuizes"],
    &["monologuises"],
    &["monologuizes"],
    &["monologuises"],
];

pub(crate) static ENTRY_MONOLOGUIZE_7317088988238212245: VariantsMap = [
    &["monologuize"],
    &["monologuise"],
    &["monologuize"],
    &["monologuise"],
];

pub(crate) static ENTRY_MONOLOGUIZING_4287361179938192317: VariantsMap = [
    &["monologuizing"],
    &["monologuising"],
    &["monologuizing"],
    &["monologuising"],
];

pub(crate) static ENTRY_MONOMETALISM_8091416002209379789: VariantsMap = [
    &["monometalism"],
    &["monometallism"],
    &["monometallism"],
    &["monometallism"],
];

pub(crate) static ENTRY_MONOMETALIST_5609217238808194836: VariantsMap = [
    &["monometalist"],
    &["monometallist"],
    &["monometallist"],
    &["monometallist"],
];

pub(crate) static ENTRY_MONOPHTHONGIZED_4506738263874777552: VariantsMap = [
    &["monophthongized"],
    &["monophthongised"],
    &["monophthongized"],
    &["monophthongised"],
];

pub(crate) static ENTRY_MONOPHTHONGIZES_3173126843603137132: VariantsMap = [
    &["monophthongizes"],
    &["monophthongises"],
    &["monophthongizes"],
    &["monophthongises"],
];

pub(crate) static ENTRY_MONOPHTHONGIZE_15612903189375621340: VariantsMap = [
    &["monophthongize"],
    &["monophthongise"],
    &["monophthongize"],
    &["monophthongise"],
];

pub(crate) static ENTRY_MONOPHTHONGIZING_14459102910824259938: VariantsMap = [
    &["monophthongizing"],
    &["monophthongising"],
    &["monophthongizing"],
    &["monophthongising"],
];

pub(crate) static ENTRY_MONOPOLIZABLES_12699234714582217629: VariantsMap = [
    &["monopolizables"],
    &["monopolisables"],
    &["monopolizables"],
    &["monopolisables"],
];

pub(crate) static ENTRY_MONOPOLIZABLE_1632547963531180162: VariantsMap = [
    &["monopolizable"],
    &["monopolisable"],
    &["monopolizable"],
    &["monopolisable"],
];

pub(crate) static ENTRY_MONOPOLIZATIONS_6331549890119342959: VariantsMap = [
    &["monopolizations"],
    &["monopolisations"],
    &["monopolizations"],
    &["monopolisations"],
];

pub(crate) static ENTRY_MONOPOLIZATION_1307231799538469152: VariantsMap = [
    &["monopolization"],
    &["monopolisation"],
    &["monopolization"],
    &["monopolisation"],
];

pub(crate) static ENTRY_MONOPOLIZED_10461001871096365991: VariantsMap = [
    &["monopolized"],
    &["monopolised"],
    &["monopolized"],
    &["monopolised"],
];

pub(crate) static ENTRY_MONOPOLIZERS_10073312732774245724: VariantsMap = [
    &["monopolizers"],
    &["monopolisers"],
    &["monopolizers"],
    &["monopolisers"],
];

pub(crate) static ENTRY_MONOPOLIZER_4531543055588283266: VariantsMap = [
    &["monopolizer"],
    &["monopoliser"],
    &["monopolizer"],
    &["monopoliser"],
];

pub(crate) static ENTRY_MONOPOLIZES_6838092214769726019: VariantsMap = [
    &["monopolizes"],
    &["monopolises"],
    &["monopolizes"],
    &["monopolises"],
];

pub(crate) static ENTRY_MONOPOLIZE_8487708636905491508: VariantsMap = [
    &["monopolize"],
    &["monopolise"],
    &["monopolize"],
    &["monopolise"],
];

pub(crate) static ENTRY_MONOPOLIZING_13178768662367110962: VariantsMap = [
    &["monopolizing"],
    &["monopolising"],
    &["monopolizing"],
    &["monopolising"],
];

pub(crate) static ENTRY_MONOTONIZES_771494355341239370: VariantsMap = [
    &["monotonizes"],
    &["monotonises"],
    &["monotonizes"],
    &["monotonises"],
];

pub(crate) static ENTRY_MONOTONIZE_4339817040805963103: VariantsMap = [
    &["monotonize"],
    &["monotonise"],
    &["monotonize"],
    &["monotonise"],
];

pub(crate) static ENTRY_MONUMENTALIZATIONS_14017609465373541851: VariantsMap = [
    &["monumentalizations"],
    &["monumentalisations"],
    &["monumentalizations"],
    &["monumentalisations"],
];

pub(crate) static ENTRY_MONUMENTALIZATION_121908154863154321: VariantsMap = [
    &["monumentalization"],
    &["monumentalisation"],
    &["monumentalization"],
    &["monumentalisation"],
];

pub(crate) static ENTRY_MONUMENTALIZED_10548767854996105071: VariantsMap = [
    &["monumentalized"],
    &["monumentalised"],
    &["monumentalized"],
    &["monumentalised"],
];

pub(crate) static ENTRY_MONUMENTALIZES_5130414847256959479: VariantsMap = [
    &["monumentalizes"],
    &["monumentalises"],
    &["monumentalizes"],
    &["monumentalises"],
];

pub(crate) static ENTRY_MONUMENTALIZE_2877387938202021398: VariantsMap = [
    &["monumentalize"],
    &["monumentalise"],
    &["monumentalize"],
    &["monumentalise"],
];

pub(crate) static ENTRY_MONUMENTALIZING_8178737988254793694: VariantsMap = [
    &["monumentalizing"],
    &["monumentalising"],
    &["monumentalizing"],
    &["monumentalising"],
];

pub(crate) static ENTRY_MORALIZATIONS_8810473373046257875: VariantsMap = [
    &["moralizations"],
    &["moralisations"],
    &["moralizations"],
    &["moralisations"],
];

pub(crate) static ENTRY_MORALIZATION_10080916313324833740: VariantsMap = [
    &["moralization"],
    &["moralisation"],
    &["moralization"],
    &["moralisation"],
];

pub(crate) static ENTRY_MORALIZED_2663438308555906556: VariantsMap = [
    &["moralized"],
    &["moralised"],
    &["moralized"],
    &["moralised"],
];

pub(crate) static ENTRY_MORALIZERS_3365413932300602681: VariantsMap = [
    &["moralizers"],
    &["moralisers"],
    &["moralizers"],
    &["moralisers"],
];

pub(crate) static ENTRY_MORALIZER_4648462715987842582: VariantsMap = [
    &["moralizer"],
    &["moraliser"],
    &["moralizer"],
    &["moraliser"],
];

pub(crate) static ENTRY_MORALIZES_9224440599258696137: VariantsMap = [
    &["moralizes"],
    &["moralises"],
    &["moralizes"],
    &["moralises"],
];

pub(crate) static ENTRY_MORALIZE_18364245712417706650: VariantsMap =
    [&["moralize"], &["moralise"], &["moralize"], &["moralise"]];

pub(crate) static ENTRY_MORALIZINGLIES_10462617487774496885: VariantsMap = [
    &["moralizinglies"],
    &["moralisinglies"],
    &["moralizinglies"],
    &["moralisinglies"],
];

pub(crate) static ENTRY_MORALIZINGLY_16347045591954328801: VariantsMap = [
    &["moralizingly"],
    &["moralisingly"],
    &["moralizingly"],
    &["moralisingly"],
];

pub(crate) static ENTRY_MORALIZING_3926799554184116665: VariantsMap = [
    &["moralizing"],
    &["moralising"],
    &["moralizing"],
    &["moralising"],
];

pub(crate) static ENTRY_MORAVIANIZEDS_787565801428409365: VariantsMap = [
    &["moravianizeds"],
    &["moravianiseds"],
    &["moravianizeds"],
    &["moravianiseds"],
];

pub(crate) static ENTRY_MORAVIANIZED_5701551634682247117: VariantsMap = [
    &["moravianized"],
    &["moravianised"],
    &["moravianized"],
    &["moravianised"],
];

pub(crate) static ENTRY_MORBIDIZES_2796191092499149016: VariantsMap = [
    &["morbidizes"],
    &["morbidises"],
    &["morbidizes"],
    &["morbidises"],
];

pub(crate) static ENTRY_MORBIDIZE_4422039069430263560: VariantsMap = [
    &["morbidize"],
    &["morbidise"],
    &["morbidize"],
    &["morbidise"],
];

pub(crate) static ENTRY_MOREA_13514469338224390305: VariantsMap =
    [&["morea"], &["moraea"], &["moraea"], &["moraea"]];

pub(crate) static ENTRY_MORNE_17753311726489354450: VariantsMap =
    [&["morne"], &["mourne"], &["mourne"], &["mourne"]];

pub(crate) static ENTRY_MORNINGLY_14399084090041736439: VariantsMap = [
    &["morningly"],
    &["mourningly"],
    &["mourningly"],
    &["mourningly"],
];

pub(crate) static ENTRY_MORPHINIZATIONS_1979094451135743390: VariantsMap = [
    &["morphinizations"],
    &["morphinisations"],
    &["morphinizations"],
    &["morphinisations"],
];

pub(crate) static ENTRY_MORPHINIZATION_11750424731639276917: VariantsMap = [
    &["morphinization"],
    &["morphinisation"],
    &["morphinization"],
    &["morphinisation"],
];

pub(crate) static ENTRY_MORPHINIZES_16172356110250914168: VariantsMap = [
    &["morphinizes"],
    &["morphinises"],
    &["morphinizes"],
    &["morphinises"],
];

pub(crate) static ENTRY_MORPHINIZE_6910565647915854125: VariantsMap = [
    &["morphinize"],
    &["morphinise"],
    &["morphinize"],
    &["morphinise"],
];

pub(crate) static ENTRY_MORSELED_6287732670299985987: VariantsMap = [
    &["morseled"],
    &["morselled"],
    &["morselled"],
    &["morselled"],
];

pub(crate) static ENTRY_MORSELING_3778440818761410189: VariantsMap = [
    &["morseling"],
    &["morselling"],
    &["morselling"],
    &["morselling"],
];

pub(crate) static ENTRY_MORSELIZATIONS_13741092004731619491: VariantsMap = [
    &["morselizations"],
    &["morselisations"],
    &["morselizations"],
    &["morselisations"],
];

pub(crate) static ENTRY_MORSELIZATION_2667568239096574036: VariantsMap = [
    &["morselization"],
    &["morselisation"],
    &["morselization"],
    &["morselisation"],
];

pub(crate) static ENTRY_MORSELIZES_1717809719310113488: VariantsMap = [
    &["morselizes"],
    &["morselises"],
    &["morselizes"],
    &["morselises"],
];

pub(crate) static ENTRY_MORSELIZE_737147545384494790: VariantsMap = [
    &["morselize"],
    &["morselise"],
    &["morselize"],
    &["morselise"],
];

pub(crate) static ENTRY_MORTALIZED_16634602645317905204: VariantsMap = [
    &["mortalized"],
    &["mortalised"],
    &["mortalized"],
    &["mortalised"],
];

pub(crate) static ENTRY_MORTALIZES_1136538908901890872: VariantsMap = [
    &["mortalizes"],
    &["mortalises"],
    &["mortalizes"],
    &["mortalises"],
];

pub(crate) static ENTRY_MORTALIZE_9043410404777963563: VariantsMap = [
    &["mortalize"],
    &["mortalise"],
    &["mortalize"],
    &["mortalise"],
];

pub(crate) static ENTRY_MORTALIZING_13683327146873296741: VariantsMap = [
    &["mortalizing"],
    &["mortalising"],
    &["mortalizing"],
    &["mortalising"],
];

pub(crate) static ENTRY_MORTARIZES_9581033940816475263: VariantsMap = [
    &["mortarizes"],
    &["mortarises"],
    &["mortarizes"],
    &["mortarises"],
];

pub(crate) static ENTRY_MORTARIZE_7482329915364487009: VariantsMap = [
    &["mortarize"],
    &["mortarise"],
    &["mortarize"],
    &["mortarise"],
];

pub(crate) static ENTRY_MORULE_2744607879952026701: VariantsMap =
    [&["morule"], &["morulae"], &["morulae"], &["morulae"]];

pub(crate) static ENTRY_MOSLEMIZES_18082869512875046805: VariantsMap = [
    &["moslemizes"],
    &["moslemises"],
    &["moslemizes"],
    &["moslemises"],
];

pub(crate) static ENTRY_MOSLEMIZE_16249209972322086947: VariantsMap = [
    &["moslemize"],
    &["moslemise"],
    &["moslemize"],
    &["moslemise"],
];

pub(crate) static ENTRY_MOTORIZATIONS_3171453995120539506: VariantsMap = [
    &["motorizations"],
    &["motorisations"],
    &["motorizations"],
    &["motorisations"],
];

pub(crate) static ENTRY_MOTORIZATION_117868153865960407: VariantsMap = [
    &["motorization"],
    &["motorisation"],
    &["motorization"],
    &["motorisation"],
];

pub(crate) static ENTRY_MOTORIZED_15195580542726305660: VariantsMap = [
    &["motorized"],
    &["motorised"],
    &["motorized"],
    &["motorised"],
];

pub(crate) static ENTRY_MOTORIZES_4685593754649773687: VariantsMap = [
    &["motorizes"],
    &["motorises"],
    &["motorizes"],
    &["motorises"],
];

pub(crate) static ENTRY_MOTORIZE_9953616205839376436: VariantsMap =
    [&["motorize"], &["motorise"], &["motorize"], &["motorise"]];

pub(crate) static ENTRY_MOTORIZING_6409716101426652084: VariantsMap = [
    &["motorizing"],
    &["motorising"],
    &["motorizing"],
    &["motorising"],
];

pub(crate) static ENTRY_MOVABILITY_11870011406697694199: VariantsMap = [
    &["movability"],
    &["movability"],
    &["movability"],
    &["movability"],
];

pub(crate) static ENTRY_MUCORRHEA_8295999192288067270: VariantsMap = [
    &["mucorrhea"],
    &["mucorrhoea"],
    &["mucorrhoea"],
    &["mucorrhoea"],
];

pub(crate) static ENTRY_MUCOSE_11672488603107743330: VariantsMap =
    [&["mucose"], &["mucosae"], &["mucosae"], &["mucosae"]];

pub(crate) static ENTRY_MULTICOLOREDDER_3341008599097650171: VariantsMap = [
    &["multicoloredder"],
    &["multicolouredder"],
    &["multicolouredder"],
    &["multicolouredder"],
];

pub(crate) static ENTRY_MULTICOLOREDDEST_7461907494166966856: VariantsMap = [
    &["multicoloreddest"],
    &["multicoloureddest"],
    &["multicoloureddest"],
    &["multicoloureddest"],
];

pub(crate) static ENTRY_MULTICOLORED_1099974154350113974: VariantsMap = [
    &["multicolored"],
    &["multicoloured"],
    &["multicoloured"],
    &["multicoloured"],
];

pub(crate) static ENTRY_MULTICOLOROUS_6201278565370964976: VariantsMap = [
    &["multicolorous"],
    &["multicolourous"],
    &["multicolourous"],
    &["multicolourous"],
];

pub(crate) static ENTRY_MULTICOLORS_2420068264028973832: VariantsMap = [
    &["multicolors"],
    &["multicolours"],
    &["multicolours"],
    &["multicolours"],
];

pub(crate) static ENTRY_MULTICOLOR_784422909619173390: VariantsMap = [
    &["multicolor"],
    &["multicolour"],
    &["multicolour"],
    &["multicolour"],
];

pub(crate) static ENTRY_MULTIFIBEREDS_5927344967497839466: VariantsMap = [
    &["multifibereds"],
    &["multifibreds"],
    &["multifibreds"],
    &["multifibreds"],
];

pub(crate) static ENTRY_MULTIFIBERED_7572219282880475426: VariantsMap = [
    &["multifibered"],
    &["multifibred"],
    &["multifibred"],
    &["multifibred"],
];

pub(crate) static ENTRY_MULTILEVELED_7194174376853857456: VariantsMap = [
    &["multileveled"],
    &["multilevelled"],
    &["multilevelled"],
    &["multilevelled"],
];

pub(crate) static ENTRY_MUNICIPALIZATIONS_6370526343367980395: VariantsMap = [
    &["municipalizations"],
    &["municipalisations"],
    &["municipalizations"],
    &["municipalisations"],
];

pub(crate) static ENTRY_MUNICIPALIZATION_9575521026368095408: VariantsMap = [
    &["municipalization"],
    &["municipalisation"],
    &["municipalization"],
    &["municipalisation"],
];

pub(crate) static ENTRY_MUNICIPALIZED_13952457825214732598: VariantsMap = [
    &["municipalized"],
    &["municipalised"],
    &["municipalized"],
    &["municipalised"],
];

pub(crate) static ENTRY_MUNICIPALIZERS_15756045224107050768: VariantsMap = [
    &["municipalizers"],
    &["municipalisers"],
    &["municipalizers"],
    &["municipalisers"],
];

pub(crate) static ENTRY_MUNICIPALIZER_5812211793259788814: VariantsMap = [
    &["municipalizer"],
    &["municipaliser"],
    &["municipalizer"],
    &["municipaliser"],
];

pub(crate) static ENTRY_MUNICIPALIZES_14135230958620370966: VariantsMap = [
    &["municipalizes"],
    &["municipalises"],
    &["municipalizes"],
    &["municipalises"],
];

pub(crate) static ENTRY_MUNICIPALIZE_1907378831809176828: VariantsMap = [
    &["municipalize"],
    &["municipalise"],
    &["municipalize"],
    &["municipalise"],
];

pub(crate) static ENTRY_MUNICIPALIZING_3968102490959965181: VariantsMap = [
    &["municipalizing"],
    &["municipalising"],
    &["municipalizing"],
    &["municipalising"],
];

pub(crate) static ENTRY_MURENAS_6329923349315548065: VariantsMap =
    [&["murenas"], &["muraenas"], &["muraenas"], &["muraenas"]];

pub(crate) static ENTRY_MURENA_18139482623728905615: VariantsMap =
    [&["murena"], &["muraena"], &["muraena"], &["muraena"]];

pub(crate) static ENTRY_MUSCULARIZES_10614722597220369532: VariantsMap = [
    &["muscularizes"],
    &["muscularises"],
    &["muscularizes"],
    &["muscularises"],
];

pub(crate) static ENTRY_MUSCULARIZE_398052939754954428: VariantsMap = [
    &["muscularize"],
    &["muscularise"],
    &["muscularize"],
    &["muscularise"],
];

pub(crate) static ENTRY_MUSEUMIZES_14658763738317667704: VariantsMap = [
    &["museumizes"],
    &["museumises"],
    &["museumizes"],
    &["museumises"],
];

pub(crate) static ENTRY_MUSEUMIZE_7842047323081517378: VariantsMap = [
    &["museumize"],
    &["museumise"],
    &["museumize"],
    &["museumise"],
];

pub(crate) static ENTRY_MUSICALIZATIONS_8007008082374895856: VariantsMap = [
    &["musicalizations"],
    &["musicalisations"],
    &["musicalizations"],
    &["musicalisations"],
];

pub(crate) static ENTRY_MUSICALIZATION_5418765001607453254: VariantsMap = [
    &["musicalization"],
    &["musicalisation"],
    &["musicalization"],
    &["musicalisation"],
];

pub(crate) static ENTRY_MUSICALIZED_1534933012029862697: VariantsMap = [
    &["musicalized"],
    &["musicalised"],
    &["musicalized"],
    &["musicalised"],
];

pub(crate) static ENTRY_MUSICALIZES_15122018268806895726: VariantsMap = [
    &["musicalizes"],
    &["musicalises"],
    &["musicalizes"],
    &["musicalises"],
];

pub(crate) static ENTRY_MUSICALIZE_14105870209904150736: VariantsMap = [
    &["musicalize"],
    &["musicalise"],
    &["musicalize"],
    &["musicalise"],
];

pub(crate) static ENTRY_MUSICALIZING_5444115698838018843: VariantsMap = [
    &["musicalizing"],
    &["musicalising"],
    &["musicalizing"],
    &["musicalising"],
];

pub(crate) static ENTRY_MUSTACHED_2206075060724165943: VariantsMap = [
    &["mustached"],
    &["moustached"],
    &["moustached"],
    &["moustached"],
];

pub(crate) static ENTRY_MUSTACHES_16686627673297841138: VariantsMap = [
    &["mustaches"],
    &["moustaches"],
    &["moustaches"],
    &["moustaches"],
];

pub(crate) static ENTRY_MUSTACHE_10319903289050174029: VariantsMap = [
    &["mustache"],
    &["moustache"],
    &["moustache"],
    &["moustache"],
];

pub(crate) static ENTRY_MUTAGENIZED_11416012132208663302: VariantsMap = [
    &["mutagenized"],
    &["mutagenised"],
    &["mutagenized"],
    &["mutagenised"],
];

pub(crate) static ENTRY_MUTAGENIZES_12316350538332027237: VariantsMap = [
    &["mutagenizes"],
    &["mutagenises"],
    &["mutagenizes"],
    &["mutagenises"],
];

pub(crate) static ENTRY_MUTAGENIZE_13512560099179859556: VariantsMap = [
    &["mutagenize"],
    &["mutagenise"],
    &["mutagenize"],
    &["mutagenise"],
];

pub(crate) static ENTRY_MUTAGENIZING_94769575082965039: VariantsMap = [
    &["mutagenizing"],
    &["mutagenising"],
    &["mutagenizing"],
    &["mutagenising"],
];

pub(crate) static ENTRY_MUTUALIZATIONS_8022089842546520715: VariantsMap = [
    &["mutualizations"],
    &["mutualisations"],
    &["mutualizations"],
    &["mutualisations"],
];

pub(crate) static ENTRY_MUTUALIZATION_148927225642760299: VariantsMap = [
    &["mutualization"],
    &["mutualisation"],
    &["mutualization"],
    &["mutualisation"],
];

pub(crate) static ENTRY_MUTUALIZED_16677934514596854802: VariantsMap = [
    &["mutualized"],
    &["mutualised"],
    &["mutualized"],
    &["mutualised"],
];

pub(crate) static ENTRY_MUTUALIZES_12491858123359748428: VariantsMap = [
    &["mutualizes"],
    &["mutualises"],
    &["mutualizes"],
    &["mutualises"],
];

pub(crate) static ENTRY_MUTUALIZE_9884428022614368321: VariantsMap = [
    &["mutualize"],
    &["mutualise"],
    &["mutualize"],
    &["mutualise"],
];

pub(crate) static ENTRY_MUTUALIZING_5941204778850827823: VariantsMap = [
    &["mutualizing"],
    &["mutualising"],
    &["mutualizing"],
    &["mutualising"],
];

pub(crate) static ENTRY_MYCOHEMIA_14011500395634142073: VariantsMap = [
    &["mycohemia"],
    &["mycohaemia"],
    &["mycohaemia"],
    &["mycohaemia"],
];

pub(crate) static ENTRY_MYELINIZATIONS_969486317082261560: VariantsMap = [
    &["myelinizations"],
    &["myelinisations"],
    &["myelinizations"],
    &["myelinisations"],
];

pub(crate) static ENTRY_MYELINIZATION_13458271670402434224: VariantsMap = [
    &["myelinization"],
    &["myelinisation"],
    &["myelinization"],
    &["myelinisation"],
];

pub(crate) static ENTRY_MYELOCELE_11426053315237704792: VariantsMap = [
    &["myelocele"],
    &["myelocoele"],
    &["myelocoele"],
    &["myelocoele"],
];

pub(crate) static ENTRY_MYELOCYTHEMIA_1216815045707461282: VariantsMap = [
    &["myelocythemia"],
    &["myelocythaemia"],
    &["myelocythaemia"],
    &["myelocythaemia"],
];

pub(crate) static ENTRY_MYLONITIZATIONS_8987230193080175923: VariantsMap = [
    &["mylonitizations"],
    &["mylonitisations"],
    &["mylonitizations"],
    &["mylonitisations"],
];

pub(crate) static ENTRY_MYLONITIZATION_14207571191895224414: VariantsMap = [
    &["mylonitization"],
    &["mylonitisation"],
    &["mylonitization"],
    &["mylonitisation"],
];

pub(crate) static ENTRY_MYLONITIZED_1836771186609206852: VariantsMap = [
    &["mylonitized"],
    &["mylonitised"],
    &["mylonitized"],
    &["mylonitised"],
];

pub(crate) static ENTRY_MYLONITIZES_9054608438172135078: VariantsMap = [
    &["mylonitizes"],
    &["mylonitises"],
    &["mylonitizes"],
    &["mylonitises"],
];

pub(crate) static ENTRY_MYLONITIZE_8331820604780621489: VariantsMap = [
    &["mylonitize"],
    &["mylonitise"],
    &["mylonitize"],
    &["mylonitise"],
];

pub(crate) static ENTRY_MYLONITIZING_10075181248707997045: VariantsMap = [
    &["mylonitizing"],
    &["mylonitising"],
    &["mylonitizing"],
    &["mylonitising"],
];

pub(crate) static ENTRY_MYOCELE_6155543281988825635: VariantsMap =
    [&["myocele"], &["myocoele"], &["myocoele"], &["myocoele"]];

pub(crate) static ENTRY_MYOHEMATIN_7139519405799594952: VariantsMap = [
    &["myohematin"],
    &["myohaematin"],
    &["myohaematin"],
    &["myohaematin"],
];

pub(crate) static ENTRY_MYRIALITER_6139987841651830761: VariantsMap = [
    &["myrialiter"],
    &["myrialitre"],
    &["myrialitre"],
    &["myrialitre"],
];

pub(crate) static ENTRY_MYRIAMETER_284114791865990119: VariantsMap = [
    &["myriameter"],
    &["myriametre"],
    &["myriametre"],
    &["myriametre"],
];

pub(crate) static ENTRY_MYSTICIZES_13649076160811622608: VariantsMap = [
    &["mysticizes"],
    &["mysticises"],
    &["mysticizes"],
    &["mysticises"],
];

pub(crate) static ENTRY_MYSTICIZE_9971453281076771770: VariantsMap = [
    &["mysticize"],
    &["mysticise"],
    &["mysticize"],
    &["mysticise"],
];

pub(crate) static ENTRY_MYTHICIZATION_4467730647442451023: VariantsMap = [
    &["mythicization"],
    &["mythicisation"],
    &["mythicization"],
    &["mythicisation"],
];

pub(crate) static ENTRY_MYTHICIZED_4137264042093387147: VariantsMap = [
    &["mythicized"],
    &["mythicised"],
    &["mythicized"],
    &["mythicised"],
];

pub(crate) static ENTRY_MYTHICIZERS_10056546919744418175: VariantsMap = [
    &["mythicizers"],
    &["mythicisers"],
    &["mythicizers"],
    &["mythicisers"],
];

pub(crate) static ENTRY_MYTHICIZER_17943353036856898639: VariantsMap = [
    &["mythicizer"],
    &["mythiciser"],
    &["mythicizer"],
    &["mythiciser"],
];

pub(crate) static ENTRY_MYTHICIZES_1828039457047215420: VariantsMap = [
    &["mythicizes"],
    &["mythicises"],
    &["mythicizes"],
    &["mythicises"],
];

pub(crate) static ENTRY_MYTHICIZE_994451185735413970: VariantsMap = [
    &["mythicize"],
    &["mythicise"],
    &["mythicize"],
    &["mythicise"],
];

pub(crate) static ENTRY_MYTHICIZING_8980222790322037836: VariantsMap = [
    &["mythicizing"],
    &["mythicising"],
    &["mythicizing"],
    &["mythicising"],
];

pub(crate) static ENTRY_MYTHIZED_17571926043024947437: VariantsMap =
    [&["mythized"], &["mythised"], &["mythized"], &["mythised"]];

pub(crate) static ENTRY_MYTHIZES_1545681173644864391: VariantsMap =
    [&["mythizes"], &["mythises"], &["mythizes"], &["mythises"]];

pub(crate) static ENTRY_MYTHIZE_9908305862028630928: VariantsMap =
    [&["mythize"], &["mythise"], &["mythize"], &["mythise"]];

pub(crate) static ENTRY_MYTHIZING_10503929080533408341: VariantsMap = [
    &["mythizing"],
    &["mythising"],
    &["mythizing"],
    &["mythising"],
];

pub(crate) static ENTRY_MYTHOLOGIZATIONS_3274680051911037587: VariantsMap = [
    &["mythologizations"],
    &["mythologisations"],
    &["mythologizations"],
    &["mythologisations"],
];

pub(crate) static ENTRY_MYTHOLOGIZATION_13010847986648537402: VariantsMap = [
    &["mythologization"],
    &["mythologisation"],
    &["mythologization"],
    &["mythologisation"],
];

pub(crate) static ENTRY_MYTHOLOGIZED_7891244640375123566: VariantsMap = [
    &["mythologized"],
    &["mythologised"],
    &["mythologized"],
    &["mythologised"],
];

pub(crate) static ENTRY_MYTHOLOGIZERS_14789426233370867155: VariantsMap = [
    &["mythologizers"],
    &["mythologisers"],
    &["mythologizers"],
    &["mythologisers"],
];

pub(crate) static ENTRY_MYTHOLOGIZER_5433148033004398505: VariantsMap = [
    &["mythologizer"],
    &["mythologiser"],
    &["mythologizer"],
    &["mythologiser"],
];

pub(crate) static ENTRY_MYTHOLOGIZES_7585510101718085489: VariantsMap = [
    &["mythologizes"],
    &["mythologises"],
    &["mythologizes"],
    &["mythologises"],
];

pub(crate) static ENTRY_MYTHOLOGIZE_934719101789293180: VariantsMap = [
    &["mythologize"],
    &["mythologise"],
    &["mythologize"],
    &["mythologise"],
];

pub(crate) static ENTRY_MYTHOLOGIZING_13752169083408188946: VariantsMap = [
    &["mythologizing"],
    &["mythologising"],
    &["mythologizing"],
    &["mythologising"],
];

pub(crate) static ENTRY_MYTHOPEIC_5553162771527570838: VariantsMap = [
    &["mythopeic"],
    &["mythopoeic"],
    &["mythopoeic"],
    &["mythopoeic"],
];

pub(crate) static ENTRY_MYTHOPEIST_2404759549078344350: VariantsMap = [
    &["mythopeist"],
    &["mythopoeist"],
    &["mythopoeist"],
    &["mythopoeist"],
];

pub(crate) static ENTRY_MYTHOPOETIZED_10722688976092427157: VariantsMap = [
    &["mythopoetized"],
    &["mythopoetised"],
    &["mythopoetized"],
    &["mythopoetised"],
];

pub(crate) static ENTRY_MYTHOPOETIZE_812399287360499791: VariantsMap = [
    &["mythopoetize"],
    &["mythopoetise"],
    &["mythopoetize"],
    &["mythopoetise"],
];

pub(crate) static ENTRY_MYTHOPOETIZING_9650923068555803994: VariantsMap = [
    &["mythopoetizing"],
    &["mythopoetising"],
    &["mythopoetizing"],
    &["mythopoetising"],
];

pub(crate) static ENTRY_MYXAMEBA_3121975824630761163: VariantsMap = [
    &["myxameba"],
    &["myxamoeba"],
    &["myxamoeba"],
    &["myxamoeba"],
];

pub(crate) static ENTRY_MYXEDEMAS_2503279100646867910: VariantsMap = [
    &["myxedemas"],
    &["myxoedemas"],
    &["myxedemas"],
    &["myxoedemas"],
];

pub(crate) static ENTRY_MYXEDEMATOUS_11999883566777710815: VariantsMap = [
    &["myxedematous"],
    &["myxoedematous"],
    &["myxoedematous"],
    &["myxoedematous"],
];

pub(crate) static ENTRY_MYXEDEMA_16077318576777540086: VariantsMap =
    [&["myxedema"], &["myxoedema"], &["myxedema"], &["myxoedema"]];

pub(crate) static ENTRY_MYXEDEMIC_2015128688140769365: VariantsMap = [
    &["myxedemic"],
    &["myxoedemic"],
    &["myxoedemic"],
    &["myxoedemic"],
];

pub(crate) static ENTRY_MYXEMIA_10745005304996222059: VariantsMap =
    [&["myxemia"], &["myxaemia"], &["myxaemia"], &["myxaemia"]];

pub(crate) static ENTRY_NABATEANS_3600480999719306802: VariantsMap = [
    &["nabateans"],
    &["nabataeans"],
    &["nabataeans"],
    &["nabataeans"],
];

pub(crate) static ENTRY_NABATHEAN_18347716128449108020: VariantsMap = [
    &["nabathean"],
    &["nabathaean"],
    &["nabathaean"],
    &["nabathaean"],
];

pub(crate) static ENTRY_NAKEDIZES_2791254265493929089: VariantsMap = [
    &["nakedizes"],
    &["nakedises"],
    &["nakedizes"],
    &["nakedises"],
];

pub(crate) static ENTRY_NAKEDIZE_4521587020024219245: VariantsMap =
    [&["nakedize"], &["nakedise"], &["nakedize"], &["nakedise"]];

pub(crate) static ENTRY_NANIZATIONS_11464371774336189159: VariantsMap = [
    &["nanizations"],
    &["nanisations"],
    &["nanizations"],
    &["nanisations"],
];

pub(crate) static ENTRY_NANIZATION_8428761032922909057: VariantsMap = [
    &["nanization"],
    &["nanisation"],
    &["nanization"],
    &["nanisation"],
];

pub(crate) static ENTRY_NANOGRAMS_9429141690600922745: VariantsMap = [
    &["nanograms"],
    &["nanogrammes"],
    &["nanograms"],
    &["nanogrammes"],
];

pub(crate) static ENTRY_NANOGRAM_4215530022714871260: VariantsMap = [
    &["nanogram"],
    &["nanogramme"],
    &["nanogram"],
    &["nanogramme"],
];

pub(crate) static ENTRY_NANOMETERS_11762757652710548689: VariantsMap = [
    &["nanometers"],
    &["nanometres"],
    &["nanometres"],
    &["nanometres"],
];

pub(crate) static ENTRY_NANOMETER_17796927790461720149: VariantsMap = [
    &["nanometer"],
    &["nanometre"],
    &["nanometre"],
    &["nanometre"],
];

pub(crate) static ENTRY_NAPEA_2703553051209012323: VariantsMap =
    [&["napea"], &["napaea"], &["napaea"], &["napaea"]];

pub(crate) static ENTRY_NAPHTHALIZED_8961699346078499371: VariantsMap = [
    &["naphthalized"],
    &["naphthalised"],
    &["naphthalized"],
    &["naphthalised"],
];

pub(crate) static ENTRY_NAPHTHALIZES_9924625418222001512: VariantsMap = [
    &["naphthalizes"],
    &["naphthalises"],
    &["naphthalizes"],
    &["naphthalises"],
];

pub(crate) static ENTRY_NAPHTHALIZE_645547962499339602: VariantsMap = [
    &["naphthalize"],
    &["naphthalise"],
    &["naphthalize"],
    &["naphthalise"],
];

pub(crate) static ENTRY_NAPHTHALIZING_11494531894116033269: VariantsMap = [
    &["naphthalizing"],
    &["naphthalising"],
    &["naphthalizing"],
    &["naphthalising"],
];

pub(crate) static ENTRY_NAPOLEONIZES_12197992751496441870: VariantsMap = [
    &["napoleonizes"],
    &["napoleonises"],
    &["napoleonizes"],
    &["napoleonises"],
];

pub(crate) static ENTRY_NAPOLEONIZE_13711321813606941055: VariantsMap = [
    &["napoleonize"],
    &["napoleonise"],
    &["napoleonize"],
    &["napoleonise"],
];

pub(crate) static ENTRY_NARCOTIZATIONS_7260107127336221603: VariantsMap = [
    &["narcotizations"],
    &["narcotisations"],
    &["narcotizations"],
    &["narcotisations"],
];

pub(crate) static ENTRY_NARCOTIZATION_3430955045881256247: VariantsMap = [
    &["narcotization"],
    &["narcotisation"],
    &["narcotization"],
    &["narcotisation"],
];

pub(crate) static ENTRY_NARCOTIZED_1310082531152390964: VariantsMap = [
    &["narcotized"],
    &["narcotised"],
    &["narcotized"],
    &["narcotised"],
];

pub(crate) static ENTRY_NARCOTIZES_4192091924295649919: VariantsMap = [
    &["narcotizes"],
    &["narcotises"],
    &["narcotizes"],
    &["narcotises"],
];

pub(crate) static ENTRY_NARCOTIZE_13643890971498648567: VariantsMap = [
    &["narcotize"],
    &["narcotise"],
    &["narcotize"],
    &["narcotise"],
];

pub(crate) static ENTRY_NARCOTIZING_5620876720588895066: VariantsMap = [
    &["narcotizing"],
    &["narcotising"],
    &["narcotizing"],
    &["narcotising"],
];

pub(crate) static ENTRY_NASALIZATIONS_6303999372164951387: VariantsMap = [
    &["nasalizations"],
    &["nasalisations"],
    &["nasalizations"],
    &["nasalisations"],
];

pub(crate) static ENTRY_NASALIZATION_2558206430420024353: VariantsMap = [
    &["nasalization"],
    &["nasalisation"],
    &["nasalization"],
    &["nasalisation"],
];

pub(crate) static ENTRY_NASALIZED_1174190894841693819: VariantsMap = [
    &["nasalized"],
    &["nasalised"],
    &["nasalized"],
    &["nasalised"],
];

pub(crate) static ENTRY_NASALIZES_10310087698573638162: VariantsMap = [
    &["nasalizes"],
    &["nasalises"],
    &["nasalizes"],
    &["nasalises"],
];

pub(crate) static ENTRY_NASALIZE_15126394964863135289: VariantsMap =
    [&["nasalize"], &["nasalise"], &["nasalize"], &["nasalise"]];

pub(crate) static ENTRY_NASALIZING_6931257761484940459: VariantsMap = [
    &["nasalizing"],
    &["nasalising"],
    &["nasalizing"],
    &["nasalising"],
];

pub(crate) static ENTRY_NATIONALIZATIONS_14362871039185775397: VariantsMap = [
    &["nationalizations"],
    &["nationalisations"],
    &["nationalizations"],
    &["nationalisations"],
];

pub(crate) static ENTRY_NATIONALIZATION_5030239828494323305: VariantsMap = [
    &["nationalization"],
    &["nationalisation"],
    &["nationalization"],
    &["nationalisation"],
];

pub(crate) static ENTRY_NATIONALIZED_15312908113627604965: VariantsMap = [
    &["nationalized"],
    &["nationalised"],
    &["nationalized"],
    &["nationalised"],
];

pub(crate) static ENTRY_NATIONALIZERS_9687329251077026772: VariantsMap = [
    &["nationalizers"],
    &["nationalisers"],
    &["nationalizers"],
    &["nationalisers"],
];

pub(crate) static ENTRY_NATIONALIZER_456791214714633888: VariantsMap = [
    &["nationalizer"],
    &["nationaliser"],
    &["nationalizer"],
    &["nationaliser"],
];

pub(crate) static ENTRY_NATIONALIZES_7334356969812316358: VariantsMap = [
    &["nationalizes"],
    &["nationalises"],
    &["nationalizes"],
    &["nationalises"],
];

pub(crate) static ENTRY_NATIONALIZE_3677566152660435624: VariantsMap = [
    &["nationalize"],
    &["nationalise"],
    &["nationalize"],
    &["nationalise"],
];

pub(crate) static ENTRY_NATIONALIZING_17435368859041352405: VariantsMap = [
    &["nationalizing"],
    &["nationalising"],
    &["nationalizing"],
    &["nationalising"],
];

pub(crate) static ENTRY_NATURALIZATIONS_15254179979354541579: VariantsMap = [
    &["naturalizations"],
    &["naturalisations"],
    &["naturalizations"],
    &["naturalisations"],
];

pub(crate) static ENTRY_NATURALIZATION_13649717526845265802: VariantsMap = [
    &["naturalization"],
    &["naturalisation"],
    &["naturalization"],
    &["naturalisation"],
];

pub(crate) static ENTRY_NATURALIZED_4933991430461897776: VariantsMap = [
    &["naturalized"],
    &["naturalised"],
    &["naturalized"],
    &["naturalised"],
];

pub(crate) static ENTRY_NATURALIZERS_3438182303380931640: VariantsMap = [
    &["naturalizers"],
    &["naturalisers"],
    &["naturalizers"],
    &["naturalisers"],
];

pub(crate) static ENTRY_NATURALIZER_8651942411110778048: VariantsMap = [
    &["naturalizer"],
    &["naturaliser"],
    &["naturalizer"],
    &["naturaliser"],
];

pub(crate) static ENTRY_NATURALIZES_11977053730621144210: VariantsMap = [
    &["naturalizes"],
    &["naturalises"],
    &["naturalizes"],
    &["naturalises"],
];

pub(crate) static ENTRY_NATURALIZE_9796455531783123727: VariantsMap = [
    &["naturalize"],
    &["naturalise"],
    &["naturalize"],
    &["naturalise"],
];

pub(crate) static ENTRY_NATURALIZING_3716716428508245601: VariantsMap = [
    &["naturalizing"],
    &["naturalising"],
    &["naturalizing"],
    &["naturalising"],
];

pub(crate) static ENTRY_NATURIZES_9658576256155624005: VariantsMap = [
    &["naturizes"],
    &["naturises"],
    &["naturizes"],
    &["naturises"],
];

pub(crate) static ENTRY_NATURIZE_5972806093795696733: VariantsMap =
    [&["naturize"], &["naturise"], &["naturize"], &["naturise"]];

pub(crate) static ENTRY_NEBULARIZATIONS_1344096708238928724: VariantsMap = [
    &["nebularizations"],
    &["nebularisations"],
    &["nebularizations"],
    &["nebularisations"],
];

pub(crate) static ENTRY_NEBULARIZATION_1442476582031071023: VariantsMap = [
    &["nebularization"],
    &["nebularisation"],
    &["nebularization"],
    &["nebularisation"],
];

pub(crate) static ENTRY_NEBULARIZES_8057540089264214439: VariantsMap = [
    &["nebularizes"],
    &["nebularises"],
    &["nebularizes"],
    &["nebularises"],
];

pub(crate) static ENTRY_NEBULARIZE_17777801976084935302: VariantsMap = [
    &["nebularize"],
    &["nebularise"],
    &["nebularize"],
    &["nebularise"],
];

pub(crate) static ENTRY_NEBULIZATIONS_14508912644751833294: VariantsMap = [
    &["nebulizations"],
    &["nebulisations"],
    &["nebulizations"],
    &["nebulisations"],
];

pub(crate) static ENTRY_NEBULIZATION_7326585684837997543: VariantsMap = [
    &["nebulization"],
    &["nebulisation"],
    &["nebulization"],
    &["nebulisation"],
];

pub(crate) static ENTRY_NEBULIZED_12800682353119589181: VariantsMap = [
    &["nebulized"],
    &["nebulised"],
    &["nebulized"],
    &["nebulised"],
];

pub(crate) static ENTRY_NEBULIZERS_5318245889291026270: VariantsMap = [
    &["nebulizers"],
    &["nebulisers"],
    &["nebulizers"],
    &["nebulisers"],
];

pub(crate) static ENTRY_NEBULIZER_7516977077379919232: VariantsMap = [
    &["nebulizer"],
    &["nebuliser"],
    &["nebulizer"],
    &["nebuliser"],
];

pub(crate) static ENTRY_NEBULIZES_12715200246675490972: VariantsMap = [
    &["nebulizes"],
    &["nebulises"],
    &["nebulizes"],
    &["nebulises"],
];

pub(crate) static ENTRY_NEBULIZE_7330295268077282680: VariantsMap =
    [&["nebulize"], &["nebulise"], &["nebulize"], &["nebulise"]];

pub(crate) static ENTRY_NEBULIZING_7453907449334963722: VariantsMap = [
    &["nebulizing"],
    &["nebulising"],
    &["nebulizing"],
    &["nebulising"],
];

pub(crate) static ENTRY_NECREMIA_8881652998895232422: VariantsMap = [
    &["necremia"],
    &["necraemia"],
    &["necraemia"],
    &["necraemia"],
];

pub(crate) static ENTRY_NECROTIZED_8062669837805248834: VariantsMap = [
    &["necrotized"],
    &["necrotised"],
    &["necrotized"],
    &["necrotised"],
];

pub(crate) static ENTRY_NECROTIZES_4216987069255944678: VariantsMap = [
    &["necrotizes"],
    &["necrotises"],
    &["necrotizes"],
    &["necrotises"],
];

pub(crate) static ENTRY_NECROTIZE_299626418760955858: VariantsMap = [
    &["necrotize"],
    &["necrotise"],
    &["necrotize"],
    &["necrotise"],
];

pub(crate) static ENTRY_NECROTIZING_3362205721608894420: VariantsMap = [
    &["necrotizing"],
    &["necrotising"],
    &["necrotizing"],
    &["necrotising"],
];

pub(crate) static ENTRY_NECTARIZED_7371569570789937934: VariantsMap = [
    &["nectarized"],
    &["nectarised"],
    &["nectarized"],
    &["nectarised"],
];

pub(crate) static ENTRY_NECTARIZES_1030386415882779696: VariantsMap = [
    &["nectarizes"],
    &["nectarises"],
    &["nectarizes"],
    &["nectarises"],
];

pub(crate) static ENTRY_NECTARIZE_9385124234314658628: VariantsMap = [
    &["nectarize"],
    &["nectarise"],
    &["nectarize"],
    &["nectarise"],
];

pub(crate) static ENTRY_NECTARIZING_4549880248278053146: VariantsMap = [
    &["nectarizing"],
    &["nectarising"],
    &["nectarizing"],
    &["nectarising"],
];

pub(crate) static ENTRY_NEEBOR_16062401850643862888: VariantsMap =
    [&["neebor"], &["neebour"], &["neebour"], &["neebour"]];

pub(crate) static ENTRY_NEENCEPHALON_14187652725536427083: VariantsMap = [
    &["neencephalon"],
    &["neoencephalon"],
    &["neoencephalon"],
    &["neoencephalon"],
];

pub(crate) static ENTRY_NEER_16355605982802851825: VariantsMap =
    [&["neer"], &["nere"], &["nere"], &["nere"]];

pub(crate) static ENTRY_NEGLIGEES_10333702368994566972: VariantsMap = [
    &["negligees"],
    &["negligees"],
    &["negligees"],
    &["negligees"],
];

pub(crate) static ENTRY_NEGLIGEE_14354404705992424135: VariantsMap =
    [&["negligee"], &["negligee"], &["negligee"], &["negligee"]];

pub(crate) static ENTRY_NEGRITIZED_10107617084750061015: VariantsMap = [
    &["negritized"],
    &["negritised"],
    &["negritized"],
    &["negritised"],
];

pub(crate) static ENTRY_NEGRITIZE_11369199419932636812: VariantsMap = [
    &["negritize"],
    &["negritise"],
    &["negritize"],
    &["negritise"],
];

pub(crate) static ENTRY_NEGRITIZING_9349037264957140834: VariantsMap = [
    &["negritizing"],
    &["negritising"],
    &["negritizing"],
    &["negritising"],
];

pub(crate) static ENTRY_NEGROIZATIONS_3358353493795107975: VariantsMap = [
    &["negroizations"],
    &["negroisations"],
    &["negroizations"],
    &["negroisations"],
];

pub(crate) static ENTRY_NEGROIZATION_8048386169561232415: VariantsMap = [
    &["negroization"],
    &["negroisation"],
    &["negroization"],
    &["negroisation"],
];

pub(crate) static ENTRY_NEGROIZED_16504978671697700797: VariantsMap = [
    &["negroized"],
    &["negroised"],
    &["negroized"],
    &["negroised"],
];

pub(crate) static ENTRY_NEGROIZES_17958324040947623577: VariantsMap = [
    &["negroizes"],
    &["negroises"],
    &["negroizes"],
    &["negroises"],
];

pub(crate) static ENTRY_NEGROIZE_17106092591780439486: VariantsMap =
    [&["negroize"], &["negroise"], &["negroize"], &["negroise"]];

pub(crate) static ENTRY_NEGROIZING_13585645509887530683: VariantsMap = [
    &["negroizing"],
    &["negroising"],
    &["negroizing"],
    &["negroising"],
];

pub(crate) static ENTRY_NEIGHBORED_2912814830482160893: VariantsMap = [
    &["neighbored"],
    &["neighboured"],
    &["neighboured"],
    &["neighboured"],
];

pub(crate) static ENTRY_NEIGHBORERS_12831530063051977068: VariantsMap = [
    &["neighborers"],
    &["neighbourers"],
    &["neighbourers"],
    &["neighbourers"],
];

pub(crate) static ENTRY_NEIGHBORER_17586595116108205470: VariantsMap = [
    &["neighborer"],
    &["neighbourer"],
    &["neighbourer"],
    &["neighbourer"],
];

pub(crate) static ENTRY_NEIGHBORESS_15381332977975372239: VariantsMap = [
    &["neighboress"],
    &["neighbouress"],
    &["neighbouress"],
    &["neighbouress"],
];

pub(crate) static ENTRY_NEIGHBORHOODS_4358229838170310740: VariantsMap = [
    &["neighborhoods"],
    &["neighbourhoods"],
    &["neighbourhoods"],
    &["neighbourhoods"],
];

pub(crate) static ENTRY_NEIGHBORHOOD_6116964286671033961: VariantsMap = [
    &["neighborhood"],
    &["neighbourhood"],
    &["neighbourhood"],
    &["neighbourhood"],
];

pub(crate) static ENTRY_NEIGHBORINGS_8765293309645015940: VariantsMap = [
    &["neighborings"],
    &["neighbourings"],
    &["neighbourings"],
    &["neighbourings"],
];

pub(crate) static ENTRY_NEIGHBORING_9395767208036463789: VariantsMap = [
    &["neighboring"],
    &["neighbouring"],
    &["neighbouring"],
    &["neighbouring"],
];

pub(crate) static ENTRY_NEIGHBORLESSER_3537443539054487075: VariantsMap = [
    &["neighborlesser"],
    &["neighbourlesser"],
    &["neighbourlesser"],
    &["neighbourlesser"],
];

pub(crate) static ENTRY_NEIGHBORLESSEST_12407898951734692417: VariantsMap = [
    &["neighborlessest"],
    &["neighbourlessest"],
    &["neighbourlessest"],
    &["neighbourlessest"],
];

pub(crate) static ENTRY_NEIGHBORLESSES_10894054956429025321: VariantsMap = [
    &["neighborlesses"],
    &["neighbourlesses"],
    &["neighbourlesses"],
    &["neighbourlesses"],
];

pub(crate) static ENTRY_NEIGHBORLESS_72307819983757150: VariantsMap = [
    &["neighborless"],
    &["neighbourless"],
    &["neighbourless"],
    &["neighbourless"],
];

pub(crate) static ENTRY_NEIGHBORLIER_16947297940053670257: VariantsMap = [
    &["neighborlier"],
    &["neighbourlier"],
    &["neighbourlier"],
    &["neighbourlier"],
];

pub(crate) static ENTRY_NEIGHBORLIEST_494551750304702586: VariantsMap = [
    &["neighborliest"],
    &["neighbourliest"],
    &["neighbourliest"],
    &["neighbourliest"],
];

pub(crate) static ENTRY_NEIGHBORLIKES_6802496983970655984: VariantsMap = [
    &["neighborlikes"],
    &["neighbourlikes"],
    &["neighbourlikes"],
    &["neighbourlikes"],
];

pub(crate) static ENTRY_NEIGHBORLIKE_6526293139640864889: VariantsMap = [
    &["neighborlike"],
    &["neighbourlike"],
    &["neighbourlike"],
    &["neighbourlike"],
];

pub(crate) static ENTRY_NEIGHBORLINESSES_9492824420251662178: VariantsMap = [
    &["neighborlinesses"],
    &["neighbourlinesses"],
    &["neighbourlinesses"],
    &["neighbourlinesses"],
];

pub(crate) static ENTRY_NEIGHBORLINESS_10350752649415350302: VariantsMap = [
    &["neighborliness"],
    &["neighbourliness"],
    &["neighbourliness"],
    &["neighbourliness"],
];

pub(crate) static ENTRY_NEIGHBORLY_3913130996486820034: VariantsMap = [
    &["neighborly"],
    &["neighbourly"],
    &["neighbourly"],
    &["neighbourly"],
];

pub(crate) static ENTRY_NEIGHBORSHIPS_16234487844856724822: VariantsMap = [
    &["neighborships"],
    &["neighbourships"],
    &["neighbourships"],
    &["neighbourships"],
];

pub(crate) static ENTRY_NEIGHBORSHIP_7342829838404157081: VariantsMap = [
    &["neighborship"],
    &["neighbourship"],
    &["neighbourship"],
    &["neighbourship"],
];

pub(crate) static ENTRY_NEIGHBORS_7906396218629885032: VariantsMap = [
    &["neighbors"],
    &["neighbours"],
    &["neighbours"],
    &["neighbours"],
];

pub(crate) static ENTRY_NEIGHBOR_15130524761824710478: VariantsMap = [
    &["neighbor"],
    &["neighbour"],
    &["neighbour"],
    &["neighbour"],
];

pub(crate) static ENTRY_NEOGEAL_9764750913530112822: VariantsMap =
    [&["neogeal"], &["neogaeal"], &["neogaeal"], &["neogaeal"]];

pub(crate) static ENTRY_NEOGEAN_16331008238049777934: VariantsMap =
    [&["neogean"], &["neogaean"], &["neogaean"], &["neogaean"]];

pub(crate) static ENTRY_NEOGEA_9787783155573130223: VariantsMap =
    [&["neogea"], &["neogaea"], &["neogaea"], &["neogaea"]];

pub(crate) static ENTRY_NEOGEIC_15111494082202179702: VariantsMap =
    [&["neogeic"], &["neogaeic"], &["neogaeic"], &["neogaeic"]];

pub(crate) static ENTRY_NEOLOGIZATION_6696109817982643101: VariantsMap = [
    &["neologization"],
    &["neologisation"],
    &["neologization"],
    &["neologisation"],
];

pub(crate) static ENTRY_NEOLOGIZED_5268649546982345213: VariantsMap = [
    &["neologized"],
    &["neologised"],
    &["neologized"],
    &["neologised"],
];

pub(crate) static ENTRY_NEOLOGIZES_6887678104239943468: VariantsMap = [
    &["neologizes"],
    &["neologises"],
    &["neologizes"],
    &["neologises"],
];

pub(crate) static ENTRY_NEOLOGIZE_10244910510400951586: VariantsMap = [
    &["neologize"],
    &["neologise"],
    &["neologize"],
    &["neologise"],
];

pub(crate) static ENTRY_NEOLOGIZING_11083245698014675505: VariantsMap = [
    &["neologizing"],
    &["neologising"],
    &["neologizing"],
    &["neologising"],
];

pub(crate) static ENTRY_NEOPAGANIZED_4855624186586381064: VariantsMap = [
    &["neopaganized"],
    &["neopaganised"],
    &["neopaganized"],
    &["neopaganised"],
];

pub(crate) static ENTRY_NEOPAGANIZES_10627781041046310586: VariantsMap = [
    &["neopaganizes"],
    &["neopaganises"],
    &["neopaganizes"],
    &["neopaganises"],
];

pub(crate) static ENTRY_NEOPAGANIZE_11390513205223371956: VariantsMap = [
    &["neopaganize"],
    &["neopaganise"],
    &["neopaganize"],
    &["neopaganise"],
];

pub(crate) static ENTRY_NEOPAGANIZING_13517084271492557770: VariantsMap = [
    &["neopaganizing"],
    &["neopaganising"],
    &["neopaganizing"],
    &["neopaganising"],
];

pub(crate) static ENTRY_NEOTERIZED_8566631801629908756: VariantsMap = [
    &["neoterized"],
    &["neoterised"],
    &["neoterized"],
    &["neoterised"],
];

pub(crate) static ENTRY_NEOTERIZES_11131918151181201147: VariantsMap = [
    &["neoterizes"],
    &["neoterises"],
    &["neoterizes"],
    &["neoterises"],
];

pub(crate) static ENTRY_NEOTERIZE_18178784763221053575: VariantsMap = [
    &["neoterize"],
    &["neoterise"],
    &["neoterize"],
    &["neoterise"],
];

pub(crate) static ENTRY_NEOTERIZING_1718278886797679099: VariantsMap = [
    &["neoterizing"],
    &["neoterising"],
    &["neoterizing"],
    &["neoterising"],
];

pub(crate) static ENTRY_NEPHRECTOMIZED_14132201559620241794: VariantsMap = [
    &["nephrectomized"],
    &["nephrectomised"],
    &["nephrectomized"],
    &["nephrectomised"],
];

pub(crate) static ENTRY_NEPHRECTOMIZE_6279842878206648888: VariantsMap = [
    &["nephrectomize"],
    &["nephrectomise"],
    &["nephrectomize"],
    &["nephrectomise"],
];

pub(crate) static ENTRY_NEPHRECTOMIZING_3756994676330441516: VariantsMap = [
    &["nephrectomizing"],
    &["nephrectomising"],
    &["nephrectomizing"],
    &["nephrectomising"],
];

pub(crate) static ENTRY_NEPHROCELE_10380393167970214732: VariantsMap = [
    &["nephrocele"],
    &["nephrocoele"],
    &["nephrocoele"],
    &["nephrocoele"],
];

pub(crate) static ENTRY_NEPHROTOMIZE_710864125503808530: VariantsMap = [
    &["nephrotomize"],
    &["nephrotomise"],
    &["nephrotomize"],
    &["nephrotomise"],
];

pub(crate) static ENTRY_NESSLERIZED_1142327510849274666: VariantsMap = [
    &["nesslerized"],
    &["nesslerised"],
    &["nesslerized"],
    &["nesslerised"],
];

pub(crate) static ENTRY_NESSLERIZE_6021492543047774975: VariantsMap = [
    &["nesslerize"],
    &["nesslerise"],
    &["nesslerize"],
    &["nesslerise"],
];

pub(crate) static ENTRY_NESSLERIZING_15229221485702009447: VariantsMap = [
    &["nesslerizing"],
    &["nesslerising"],
    &["nesslerizing"],
    &["nesslerising"],
];

pub(crate) static ENTRY_NETS_4660053216118079303: VariantsMap =
    [&["nets"], &["nets"], &["nets"], &["nets"]];

pub(crate) static ENTRY_NET_6832594804491488620: VariantsMap =
    [&["net"], &["net"], &["net"], &["net"]];

pub(crate) static ENTRY_NEUREPITHELIUM_14522596466559359420: VariantsMap = [
    &["neurepithelium"],
    &["neuroepithelium"],
    &["neuroepithelium"],
    &["neuroepithelium"],
];

pub(crate) static ENTRY_NEUROCELE_2114330714669438819: VariantsMap = [
    &["neurocele"],
    &["neurocoele"],
    &["neurocoele"],
    &["neurocoele"],
];

pub(crate) static ENTRY_NEUROCELIAN_15377871369214360497: VariantsMap = [
    &["neurocelian"],
    &["neurocoelian"],
    &["neurocoelian"],
    &["neurocoelian"],
];

pub(crate) static ENTRY_NEUROTICIZES_10740992291539730077: VariantsMap = [
    &["neuroticizes"],
    &["neuroticises"],
    &["neuroticizes"],
    &["neuroticises"],
];

pub(crate) static ENTRY_NEUROTICIZE_466460899480966122: VariantsMap = [
    &["neuroticize"],
    &["neuroticise"],
    &["neuroticize"],
    &["neuroticise"],
];

pub(crate) static ENTRY_NEUTRALIZATIONS_11864407426607384673: VariantsMap = [
    &["neutralizations"],
    &["neutralisations"],
    &["neutralizations"],
    &["neutralisations"],
];

pub(crate) static ENTRY_NEUTRALIZATION_13307816516042724010: VariantsMap = [
    &["neutralization"],
    &["neutralisation"],
    &["neutralization"],
    &["neutralisation"],
];

pub(crate) static ENTRY_NEUTRALIZED_7515753592094537387: VariantsMap = [
    &["neutralized"],
    &["neutralised"],
    &["neutralized"],
    &["neutralised"],
];

pub(crate) static ENTRY_NEUTRALIZERS_12980250547097955526: VariantsMap = [
    &["neutralizers"],
    &["neutralisers"],
    &["neutralizers"],
    &["neutralisers"],
];

pub(crate) static ENTRY_NEUTRALIZER_5629768343757464420: VariantsMap = [
    &["neutralizer"],
    &["neutraliser"],
    &["neutralizer"],
    &["neutraliser"],
];

pub(crate) static ENTRY_NEUTRALIZES_9070000728487662463: VariantsMap = [
    &["neutralizes"],
    &["neutralises"],
    &["neutralizes"],
    &["neutralises"],
];

pub(crate) static ENTRY_NEUTRALIZE_9266551307665544200: VariantsMap = [
    &["neutralize"],
    &["neutralise"],
    &["neutralize"],
    &["neutralise"],
];

pub(crate) static ENTRY_NEUTRALIZING_13668110192955702906: VariantsMap = [
    &["neutralizing"],
    &["neutralising"],
    &["neutralizing"],
    &["neutralising"],
];

pub(crate) static ENTRY_NEVES_16616131966640754583: VariantsMap =
    [&["neves"], &["naeves"], &["naeves"], &["naeves"]];

pub(crate) static ENTRY_NEVOID_9949690720573904750: VariantsMap =
    [&["nevoid"], &["naevoid"], &["naevoid"], &["naevoid"]];

pub(crate) static ENTRY_NEWMANIZED_4174574011419796555: VariantsMap = [
    &["newmanized"],
    &["newmanised"],
    &["newmanized"],
    &["newmanised"],
];

pub(crate) static ENTRY_NEWMANIZES_2270185545274776704: VariantsMap = [
    &["newmanizes"],
    &["newmanises"],
    &["newmanizes"],
    &["newmanises"],
];

pub(crate) static ENTRY_NEWMANIZE_16791511810220024252: VariantsMap = [
    &["newmanize"],
    &["newmanise"],
    &["newmanize"],
    &["newmanise"],
];

pub(crate) static ENTRY_NEWMANIZING_13785785322413856: VariantsMap = [
    &["newmanizing"],
    &["newmanising"],
    &["newmanizing"],
    &["newmanising"],
];

pub(crate) static ENTRY_NEWSPAPERIZEDS_15846237086308072144: VariantsMap = [
    &["newspaperizeds"],
    &["newspaperiseds"],
    &["newspaperizeds"],
    &["newspaperiseds"],
];

pub(crate) static ENTRY_NEWSPAPERIZED_11230142060641724740: VariantsMap = [
    &["newspaperized"],
    &["newspaperised"],
    &["newspaperized"],
    &["newspaperised"],
];

pub(crate) static ENTRY_NICKELED_79394617530411001: VariantsMap = [
    &["nickeled"],
    &["nickelled"],
    &["nickelled"],
    &["nickelled"],
];

pub(crate) static ENTRY_NICKELING_16355800754604695372: VariantsMap = [
    &["nickeling"],
    &["nickelling"],
    &["nickelling"],
    &["nickelling"],
];

pub(crate) static ENTRY_NICKELIZATIONS_12072034603175460493: VariantsMap = [
    &["nickelizations"],
    &["nickelisations"],
    &["nickelizations"],
    &["nickelisations"],
];

pub(crate) static ENTRY_NICKELIZATION_7986732926112090831: VariantsMap = [
    &["nickelization"],
    &["nickelisation"],
    &["nickelization"],
    &["nickelisation"],
];

pub(crate) static ENTRY_NICKELIZED_8559493918735882579: VariantsMap = [
    &["nickelized"],
    &["nickelised"],
    &["nickelized"],
    &["nickelised"],
];

pub(crate) static ENTRY_NICKELIZES_2249308293478484590: VariantsMap = [
    &["nickelizes"],
    &["nickelises"],
    &["nickelizes"],
    &["nickelises"],
];

pub(crate) static ENTRY_NICKELIZE_1630536975440683928: VariantsMap = [
    &["nickelize"],
    &["nickelise"],
    &["nickelize"],
    &["nickelise"],
];

pub(crate) static ENTRY_NICKELIZING_6984381739697155028: VariantsMap = [
    &["nickelizing"],
    &["nickelising"],
    &["nickelizing"],
    &["nickelising"],
];

pub(crate) static ENTRY_NICOTINIZED_3516805459803022861: VariantsMap = [
    &["nicotinized"],
    &["nicotinised"],
    &["nicotinized"],
    &["nicotinised"],
];

pub(crate) static ENTRY_NICOTINIZES_10178848077465194416: VariantsMap = [
    &["nicotinizes"],
    &["nicotinises"],
    &["nicotinizes"],
    &["nicotinises"],
];

pub(crate) static ENTRY_NICOTINIZE_3100679005969423604: VariantsMap = [
    &["nicotinize"],
    &["nicotinise"],
    &["nicotinize"],
    &["nicotinise"],
];

pub(crate) static ENTRY_NICOTINIZING_4147158847775395200: VariantsMap = [
    &["nicotinizing"],
    &["nicotinising"],
    &["nicotinizing"],
    &["nicotinising"],
];

pub(crate) static ENTRY_NIELLED_8727132034411172563: VariantsMap =
    [&["nielled"], &["nielloed"], &["nielloed"], &["nielloed"]];

pub(crate) static ENTRY_NIGER_16049018308884616636: VariantsMap =
    [&["niger"], &["nigre"], &["nigre"], &["nigre"]];

pub(crate) static ENTRY_NIGGARDIZED_4556331947580220081: VariantsMap = [
    &["niggardized"],
    &["niggardised"],
    &["niggardized"],
    &["niggardised"],
];

pub(crate) static ENTRY_NIGGARDIZES_9198874245006328236: VariantsMap = [
    &["niggardizes"],
    &["niggardises"],
    &["niggardizes"],
    &["niggardises"],
];

pub(crate) static ENTRY_NIGGARDIZE_9495324465695451733: VariantsMap = [
    &["niggardize"],
    &["niggardise"],
    &["niggardize"],
    &["niggardise"],
];

pub(crate) static ENTRY_NIGGARDIZING_16355093388438094971: VariantsMap = [
    &["niggardizing"],
    &["niggardising"],
    &["niggardizing"],
    &["niggardising"],
];

pub(crate) static ENTRY_NIGHTINGALIZES_17007067660163973561: VariantsMap = [
    &["nightingalizes"],
    &["nightingalises"],
    &["nightingalizes"],
    &["nightingalises"],
];

pub(crate) static ENTRY_NIGHTINGALIZE_16413718384136912486: VariantsMap = [
    &["nightingalize"],
    &["nightingalise"],
    &["nightingalize"],
    &["nightingalise"],
];

pub(crate) static ENTRY_NIGHTS_5649998703829678181: VariantsMap =
    [&["nights"], &["nights"], &["nights"], &["nights"]];

pub(crate) static ENTRY_NIGHT_14987521283100092371: VariantsMap =
    [&["night"], &["night"], &["night"], &["night"]];

pub(crate) static ENTRY_NIPPONIZES_10653241792290236524: VariantsMap = [
    &["nipponizes"],
    &["nipponises"],
    &["nipponizes"],
    &["nipponises"],
];

pub(crate) static ENTRY_NIPPONIZE_12246878098196982084: VariantsMap = [
    &["nipponize"],
    &["nipponise"],
    &["nipponize"],
    &["nipponise"],
];

pub(crate) static ENTRY_NITERS_16573156181732403678: VariantsMap =
    [&["niters"], &["nitres"], &["nitres"], &["nitres"]];

pub(crate) static ENTRY_NITER_4595235793148205687: VariantsMap =
    [&["niter"], &["nitre"], &["nitre"], &["nitre"]];

pub(crate) static ENTRY_NITRIDIZATIONS_14592567393639183415: VariantsMap = [
    &["nitridizations"],
    &["nitridisations"],
    &["nitridizations"],
    &["nitridisations"],
];

pub(crate) static ENTRY_NITRIDIZATION_918307471678159167: VariantsMap = [
    &["nitridization"],
    &["nitridisation"],
    &["nitridization"],
    &["nitridisation"],
];

pub(crate) static ENTRY_NITRIDIZES_12957996406667120411: VariantsMap = [
    &["nitridizes"],
    &["nitridises"],
    &["nitridizes"],
    &["nitridises"],
];

pub(crate) static ENTRY_NITRIDIZE_3954957349928071706: VariantsMap = [
    &["nitridize"],
    &["nitridise"],
    &["nitridize"],
    &["nitridise"],
];

pub(crate) static ENTRY_NITROGENIZATIONS_13338438366989347773: VariantsMap = [
    &["nitrogenizations"],
    &["nitrogenisations"],
    &["nitrogenizations"],
    &["nitrogenisations"],
];

pub(crate) static ENTRY_NITROGENIZATION_6151589440794972943: VariantsMap = [
    &["nitrogenization"],
    &["nitrogenisation"],
    &["nitrogenization"],
    &["nitrogenisation"],
];

pub(crate) static ENTRY_NITROGENIZED_663379866855711530: VariantsMap = [
    &["nitrogenized"],
    &["nitrogenised"],
    &["nitrogenized"],
    &["nitrogenised"],
];

pub(crate) static ENTRY_NITROGENIZES_10797847040215921780: VariantsMap = [
    &["nitrogenizes"],
    &["nitrogenises"],
    &["nitrogenizes"],
    &["nitrogenises"],
];

pub(crate) static ENTRY_NITROGENIZE_16291478229609855163: VariantsMap = [
    &["nitrogenize"],
    &["nitrogenise"],
    &["nitrogenize"],
    &["nitrogenise"],
];

pub(crate) static ENTRY_NITROGENIZING_10415054578773246298: VariantsMap = [
    &["nitrogenizing"],
    &["nitrogenising"],
    &["nitrogenizing"],
    &["nitrogenising"],
];

pub(crate) static ENTRY_NITROGLYCERINS_9899854160405414012: VariantsMap = [
    &["nitroglycerins"],
    &["nitroglycerines"],
    &["nitroglycerines"],
    &["nitroglycerines"],
];

pub(crate) static ENTRY_NITROGLYCERIN_4194108955596109456: VariantsMap = [
    &["nitroglycerin"],
    &["nitroglycerine"],
    &["nitroglycerine"],
    &["nitroglycerine"],
];

pub(crate) static ENTRY_NODALIZED_3309145199722035721: VariantsMap = [
    &["nodalized"],
    &["nodalised"],
    &["nodalized"],
    &["nodalised"],
];

pub(crate) static ENTRY_NODALIZES_4523050365791573110: VariantsMap = [
    &["nodalizes"],
    &["nodalises"],
    &["nodalizes"],
    &["nodalises"],
];

pub(crate) static ENTRY_NODALIZE_12159557011270389807: VariantsMap =
    [&["nodalize"], &["nodalise"], &["nodalize"], &["nodalise"]];

pub(crate) static ENTRY_NODALIZING_594971843591353653: VariantsMap = [
    &["nodalizing"],
    &["nodalising"],
    &["nodalizing"],
    &["nodalising"],
];

pub(crate) static ENTRY_NODULIZES_15781173051962781870: VariantsMap = [
    &["nodulizes"],
    &["nodulises"],
    &["nodulizes"],
    &["nodulises"],
];

pub(crate) static ENTRY_NODULIZE_15512444632148288619: VariantsMap =
    [&["nodulize"], &["nodulise"], &["nodulize"], &["nodulise"]];

pub(crate) static ENTRY_NOEMON_4394201647553814248: VariantsMap =
    [&["noemon"], &["noaemon"], &["noaemon"], &["noaemon"]];

pub(crate) static ENTRY_NOMADIZATIONS_1532482483093905182: VariantsMap = [
    &["nomadizations"],
    &["nomadisations"],
    &["nomadizations"],
    &["nomadisations"],
];

pub(crate) static ENTRY_NOMADIZATION_5090523635235285740: VariantsMap = [
    &["nomadization"],
    &["nomadisation"],
    &["nomadization"],
    &["nomadisation"],
];

pub(crate) static ENTRY_NOMADIZED_3822219892599792814: VariantsMap = [
    &["nomadized"],
    &["nomadised"],
    &["nomadized"],
    &["nomadised"],
];

pub(crate) static ENTRY_NOMADIZES_3777017109817176072: VariantsMap = [
    &["nomadizes"],
    &["nomadises"],
    &["nomadizes"],
    &["nomadises"],
];

pub(crate) static ENTRY_NOMADIZE_5598669829068348168: VariantsMap =
    [&["nomadize"], &["nomadise"], &["nomadize"], &["nomadise"]];

pub(crate) static ENTRY_NOMADIZING_7146960705248823561: VariantsMap = [
    &["nomadizing"],
    &["nomadising"],
    &["nomadizing"],
    &["nomadising"],
];

pub(crate) static ENTRY_NOMINALIZATIONS_16075171424950015123: VariantsMap = [
    &["nominalizations"],
    &["nominalisations"],
    &["nominalizations"],
    &["nominalisations"],
];

pub(crate) static ENTRY_NOMINALIZATION_7373401604669335356: VariantsMap = [
    &["nominalization"],
    &["nominalisation"],
    &["nominalization"],
    &["nominalisation"],
];

pub(crate) static ENTRY_NOMINALIZED_2433981011225381934: VariantsMap = [
    &["nominalized"],
    &["nominalised"],
    &["nominalized"],
    &["nominalised"],
];

pub(crate) static ENTRY_NOMINALIZES_11706660389598219223: VariantsMap = [
    &["nominalizes"],
    &["nominalises"],
    &["nominalizes"],
    &["nominalises"],
];

pub(crate) static ENTRY_NOMINALIZE_18405230656463200401: VariantsMap = [
    &["nominalize"],
    &["nominalise"],
    &["nominalize"],
    &["nominalise"],
];

pub(crate) static ENTRY_NOMINALIZING_5020709823407382402: VariantsMap = [
    &["nominalizing"],
    &["nominalising"],
    &["nominalizing"],
    &["nominalising"],
];

pub(crate) static ENTRY_NONACKNOWLEDGMENTS_6963033554085365688: VariantsMap = [
    &["nonacknowledgments"],
    &["nonacknowledgements"],
    &["nonacknowledgements"],
    &["nonacknowledgements"],
];

pub(crate) static ENTRY_NONACKNOWLEDGMENT_17338469733725282328: VariantsMap = [
    &["nonacknowledgment"],
    &["nonacknowledgement"],
    &["nonacknowledgement"],
    &["nonacknowledgement"],
];

pub(crate) static ENTRY_NONANEMIC_973581033440143676: VariantsMap = [
    &["nonanemic"],
    &["nonanaemic"],
    &["nonanaemic"],
    &["nonanaemic"],
];

pub(crate) static ENTRY_NONANESTHETIZED_12181903245888735253: VariantsMap = [
    &["nonanesthetized"],
    &["nonanaesthetised"],
    &["nonanaesthetized"],
    &["nonanaesthetised"],
];

pub(crate) static ENTRY_NONAPOSTATIZINGS_11913102920540330783: VariantsMap = [
    &["nonapostatizings"],
    &["nonapostatisings"],
    &["nonapostatizings"],
    &["nonapostatisings"],
];

pub(crate) static ENTRY_NONAPOSTATIZING_13854890087671968811: VariantsMap = [
    &["nonapostatizing"],
    &["nonapostatising"],
    &["nonapostatizing"],
    &["nonapostatising"],
];

pub(crate) static ENTRY_NONCANONIZATIONS_2832925098301127962: VariantsMap = [
    &["noncanonizations"],
    &["noncanonisations"],
    &["noncanonizations"],
    &["noncanonisations"],
];

pub(crate) static ENTRY_NONCANONIZATION_9329656712506044964: VariantsMap = [
    &["noncanonization"],
    &["noncanonisation"],
    &["noncanonization"],
    &["noncanonisation"],
];

pub(crate) static ENTRY_NONCARTELIZEDS_6224481369445744702: VariantsMap = [
    &["noncartelizeds"],
    &["noncarteliseds"],
    &["noncartelizeds"],
    &["noncarteliseds"],
];

pub(crate) static ENTRY_NONCARTELIZED_17883347662972154558: VariantsMap = [
    &["noncartelized"],
    &["noncartelised"],
    &["noncartelized"],
    &["noncartelised"],
];

pub(crate) static ENTRY_NONCATECHIZABLES_1199579288294266838: VariantsMap = [
    &["noncatechizables"],
    &["noncatechisables"],
    &["noncatechizables"],
    &["noncatechisables"],
];

pub(crate) static ENTRY_NONCATECHIZABLE_6818147642459223938: VariantsMap = [
    &["noncatechizable"],
    &["noncatechisable"],
    &["noncatechizable"],
    &["noncatechisable"],
];

pub(crate) static ENTRY_NONCIVILIZEDS_17407321793870403443: VariantsMap = [
    &["noncivilizeds"],
    &["nonciviliseds"],
    &["noncivilizeds"],
    &["nonciviliseds"],
];

pub(crate) static ENTRY_NONCIVILIZED_13516038359663624972: VariantsMap = [
    &["noncivilized"],
    &["noncivilised"],
    &["noncivilized"],
    &["noncivilised"],
];

pub(crate) static ENTRY_NONCOLORABILITIES_5039233789889736316: VariantsMap = [
    &["noncolorabilities"],
    &["noncolourabilities"],
    &["noncolourabilities"],
    &["noncolourabilities"],
];

pub(crate) static ENTRY_NONCOLORABILITY_7944763850740895408: VariantsMap = [
    &["noncolorability"],
    &["noncolourability"],
    &["noncolourability"],
    &["noncolourability"],
];

pub(crate) static ENTRY_NONCOLORABLENESS_1350486861839326465: VariantsMap = [
    &["noncolorableness"],
    &["noncolourableness"],
    &["noncolourableness"],
    &["noncolourableness"],
];

pub(crate) static ENTRY_NONCOLORABLES_7325099716303232276: VariantsMap = [
    &["noncolorables"],
    &["noncolourables"],
    &["noncolourables"],
    &["noncolourables"],
];

pub(crate) static ENTRY_NONCOLORABLE_12376456308958823880: VariantsMap = [
    &["noncolorable"],
    &["noncolourable"],
    &["noncolourable"],
    &["noncolourable"],
];

pub(crate) static ENTRY_NONCOLORABLIES_17005629715844099167: VariantsMap = [
    &["noncolorablies"],
    &["noncolourablies"],
    &["noncolourablies"],
    &["noncolourablies"],
];

pub(crate) static ENTRY_NONCOLORABLY_11724968183544783704: VariantsMap = [
    &["noncolorably"],
    &["noncolourably"],
    &["noncolourably"],
    &["noncolourably"],
];

pub(crate) static ENTRY_NONCOLORED_18370430231269037309: VariantsMap = [
    &["noncolored"],
    &["noncoloured"],
    &["noncoloured"],
    &["noncoloured"],
];

pub(crate) static ENTRY_NONCOLORERS_17289446610135868746: VariantsMap = [
    &["noncolorers"],
    &["noncolourers"],
    &["noncolourers"],
    &["noncolourers"],
];

pub(crate) static ENTRY_NONCOLORER_12435033179338868994: VariantsMap = [
    &["noncolorer"],
    &["noncolourer"],
    &["noncolourer"],
    &["noncolourer"],
];

pub(crate) static ENTRY_NONCOLORFAST_12713143494448033510: VariantsMap = [
    &["noncolorfast"],
    &["noncolourfast"],
    &["noncolourfast"],
    &["noncolourfast"],
];

pub(crate) static ENTRY_NONCOLORINGS_10202008108226728546: VariantsMap = [
    &["noncolorings"],
    &["noncolourings"],
    &["noncolourings"],
    &["noncolourings"],
];

pub(crate) static ENTRY_NONCOLORING_2794432948648709598: VariantsMap = [
    &["noncoloring"],
    &["noncolouring"],
    &["noncolouring"],
    &["noncolouring"],
];

pub(crate) static ENTRY_NONCOLORS_4340941599912184140: VariantsMap = [
    &["noncolors"],
    &["noncolours"],
    &["noncolours"],
    &["noncolours"],
];

pub(crate) static ENTRY_NONCOLOR_5467547533211492252: VariantsMap = [
    &["noncolor"],
    &["noncolour"],
    &["noncolour"],
    &["noncolour"],
];

pub(crate) static ENTRY_NONCRYSTALLIZABLES_14085684766217602758: VariantsMap = [
    &["noncrystallizables"],
    &["noncrystallisables"],
    &["noncrystallizables"],
    &["noncrystallisables"],
];

pub(crate) static ENTRY_NONCRYSTALLIZABLE_18330324258416108892: VariantsMap = [
    &["noncrystallizable"],
    &["noncrystallisable"],
    &["noncrystallizable"],
    &["noncrystallisable"],
];

pub(crate) static ENTRY_NONCRYSTALLIZEDS_15212825180251803633: VariantsMap = [
    &["noncrystallizeds"],
    &["noncrystalliseds"],
    &["noncrystallizeds"],
    &["noncrystalliseds"],
];

pub(crate) static ENTRY_NONCRYSTALLIZED_6387561216013434881: VariantsMap = [
    &["noncrystallized"],
    &["noncrystallised"],
    &["noncrystallized"],
    &["noncrystallised"],
];

pub(crate) static ENTRY_NONCRYSTALLIZINGS_12541253564548752834: VariantsMap = [
    &["noncrystallizings"],
    &["noncrystallisings"],
    &["noncrystallizings"],
    &["noncrystallisings"],
];

pub(crate) static ENTRY_NONCRYSTALLIZING_12893893992637420505: VariantsMap = [
    &["noncrystallizing"],
    &["noncrystallising"],
    &["noncrystallizing"],
    &["noncrystallising"],
];

pub(crate) static ENTRY_NONDEMOBILIZATIONS_15395019710602216415: VariantsMap = [
    &["nondemobilizations"],
    &["nondemobilisations"],
    &["nondemobilizations"],
    &["nondemobilisations"],
];

pub(crate) static ENTRY_NONDEMOBILIZATION_6660513033343601101: VariantsMap = [
    &["nondemobilization"],
    &["nondemobilisation"],
    &["nondemobilization"],
    &["nondemobilisation"],
];

pub(crate) static ENTRY_NONDIALYZINGS_1819109722847384802: VariantsMap = [
    &["nondialyzings"],
    &["nondialysings"],
    &["nondialysings"],
    &["nondialysings"],
];

pub(crate) static ENTRY_NONDIALYZING_12492599878535719323: VariantsMap = [
    &["nondialyzing"],
    &["nondialysing"],
    &["nondialysing"],
    &["nondialysing"],
];

pub(crate) static ENTRY_NONDIMENSIONALIZED_585813489289304634: VariantsMap = [
    &["nondimensionalized"],
    &["nondimensionalised"],
    &["nondimensionalized"],
    &["nondimensionalised"],
];

pub(crate) static ENTRY_NONDIMENSIONALIZE_272579664848581202: VariantsMap = [
    &["nondimensionalize"],
    &["nondimensionalise"],
    &["nondimensionalize"],
    &["nondimensionalise"],
];

pub(crate) static ENTRY_NONECUMENICAL_6555547964120384081: VariantsMap = [
    &["nonecumenical"],
    &["nonoecumenical"],
    &["nonoecumenical"],
    &["nonoecumenical"],
];

pub(crate) static ENTRY_NONECUMENIC_10430255235079746866: VariantsMap = [
    &["nonecumenic"],
    &["nonoecumenic"],
    &["nonoecumenic"],
    &["nonoecumenic"],
];

pub(crate) static ENTRY_NONESTHETICALLY_7037140941147025824: VariantsMap = [
    &["nonesthetically"],
    &["nonaesthetically"],
    &["nonaesthetically"],
    &["nonaesthetically"],
];

pub(crate) static ENTRY_NONESTHETICAL_10970138491194760413: VariantsMap = [
    &["nonesthetical"],
    &["nonaesthetical"],
    &["nonaesthetical"],
    &["nonaesthetical"],
];

pub(crate) static ENTRY_NONESTHETIC_1208061013275115321: VariantsMap = [
    &["nonesthetic"],
    &["nonaesthetic"],
    &["nonaesthetic"],
    &["nonaesthetic"],
];

pub(crate) static ENTRY_NONFAVORITES_1106515722402356082: VariantsMap = [
    &["nonfavorites"],
    &["nonfavourites"],
    &["nonfavourites"],
    &["nonfavourites"],
];

pub(crate) static ENTRY_NONFAVORITE_11831237877072163638: VariantsMap = [
    &["nonfavorite"],
    &["nonfavourite"],
    &["nonfavourite"],
    &["nonfavourite"],
];

pub(crate) static ENTRY_NONFLAVORED_13086896565836313808: VariantsMap = [
    &["nonflavored"],
    &["nonflavoured"],
    &["nonflavoured"],
    &["nonflavoured"],
];

pub(crate) static ENTRY_NONFULFILLMENTS_14148076271287069943: VariantsMap = [
    &["nonfulfillments"],
    &["nonfulfilments"],
    &["nonfulfilments"],
    &["nonfulfilments"],
];

pub(crate) static ENTRY_NONFULFILLMENT_18150430088534928286: VariantsMap = [
    &["nonfulfillment"],
    &["nonfulfilment"],
    &["nonfulfilment"],
    &["nonfulfilment"],
];

pub(crate) static ENTRY_NONGALVANIZEDS_3586524971953185452: VariantsMap = [
    &["nongalvanizeds"],
    &["nongalvaniseds"],
    &["nongalvanizeds"],
    &["nongalvaniseds"],
];

pub(crate) static ENTRY_NONGALVANIZED_1528399467041152337: VariantsMap = [
    &["nongalvanized"],
    &["nongalvanised"],
    &["nongalvanized"],
    &["nongalvanised"],
];

pub(crate) static ENTRY_NONGELATINIZINGS_14282185464661271575: VariantsMap = [
    &["nongelatinizings"],
    &["nongelatinisings"],
    &["nongelatinizings"],
    &["nongelatinisings"],
];

pub(crate) static ENTRY_NONGELATINIZING_14740547367338230024: VariantsMap = [
    &["nongelatinizing"],
    &["nongelatinising"],
    &["nongelatinizing"],
    &["nongelatinising"],
];

pub(crate) static ENTRY_NONHYDROLYZABLES_6397422113685878077: VariantsMap = [
    &["nonhydrolyzables"],
    &["nonhydrolysables"],
    &["nonhydrolysables"],
    &["nonhydrolysables"],
];

pub(crate) static ENTRY_NONHYDROLYZABLE_17480379980066317514: VariantsMap = [
    &["nonhydrolyzable"],
    &["nonhydrolysable"],
    &["nonhydrolysable"],
    &["nonhydrolysable"],
];

pub(crate) static ENTRY_NONIMMUNIZEDS_17055826925642342411: VariantsMap = [
    &["nonimmunizeds"],
    &["nonimmuniseds"],
    &["nonimmunizeds"],
    &["nonimmuniseds"],
];

pub(crate) static ENTRY_NONIMMUNIZED_11380625262117673144: VariantsMap = [
    &["nonimmunized"],
    &["nonimmunised"],
    &["nonimmunized"],
    &["nonimmunised"],
];

pub(crate) static ENTRY_NONIONIZEDS_15814635301210610227: VariantsMap = [
    &["nonionizeds"],
    &["nonioniseds"],
    &["nonionizeds"],
    &["nonioniseds"],
];

pub(crate) static ENTRY_NONIONIZED_5664164987361120441: VariantsMap = [
    &["nonionized"],
    &["nonionised"],
    &["nonionized"],
    &["nonionised"],
];

pub(crate) static ENTRY_NONIONIZINGS_5445645829414525604: VariantsMap = [
    &["nonionizings"],
    &["nonionisings"],
    &["nonionizings"],
    &["nonionisings"],
];

pub(crate) static ENTRY_NONIONIZING_13410823671297408563: VariantsMap = [
    &["nonionizing"],
    &["nonionising"],
    &["nonionizing"],
    &["nonionising"],
];

pub(crate) static ENTRY_NONLOCALIZEDS_12719123077518106411: VariantsMap = [
    &["nonlocalizeds"],
    &["nonlocaliseds"],
    &["nonlocalizeds"],
    &["nonlocaliseds"],
];

pub(crate) static ENTRY_NONLOCALIZED_11579777543530255255: VariantsMap = [
    &["nonlocalized"],
    &["nonlocalised"],
    &["nonlocalized"],
    &["nonlocalised"],
];

pub(crate) static ENTRY_NONMAGNETIZABLES_2331502932397989651: VariantsMap = [
    &["nonmagnetizables"],
    &["nonmagnetisables"],
    &["nonmagnetizables"],
    &["nonmagnetisables"],
];

pub(crate) static ENTRY_NONMAGNETIZABLE_8373745056323317633: VariantsMap = [
    &["nonmagnetizable"],
    &["nonmagnetisable"],
    &["nonmagnetizable"],
    &["nonmagnetisable"],
];

pub(crate) static ENTRY_NONNITROGENIZEDS_725125946102913048: VariantsMap = [
    &["nonnitrogenizeds"],
    &["nonnitrogeniseds"],
    &["nonnitrogenizeds"],
    &["nonnitrogeniseds"],
];

pub(crate) static ENTRY_NONNITROGENIZED_17798299881762861324: VariantsMap = [
    &["nonnitrogenized"],
    &["nonnitrogenised"],
    &["nonnitrogenized"],
    &["nonnitrogenised"],
];

pub(crate) static ENTRY_NONORGANIZATIONS_12226603628664503880: VariantsMap = [
    &["nonorganizations"],
    &["nonorganisations"],
    &["nonorganizations"],
    &["nonorganisations"],
];

pub(crate) static ENTRY_NONORGANIZATION_5772986496320930609: VariantsMap = [
    &["nonorganization"],
    &["nonorganisation"],
    &["nonorganization"],
    &["nonorganisation"],
];

pub(crate) static ENTRY_NONOXIDIZABLES_9151331804972643676: VariantsMap = [
    &["nonoxidizables"],
    &["nonoxidisables"],
    &["nonoxidizables"],
    &["nonoxidisables"],
];

pub(crate) static ENTRY_NONOXIDIZABLE_17473608806098821507: VariantsMap = [
    &["nonoxidizable"],
    &["nonoxidisable"],
    &["nonoxidizable"],
    &["nonoxidisable"],
];

pub(crate) static ENTRY_NONOXIDIZINGS_14072069622049297509: VariantsMap = [
    &["nonoxidizings"],
    &["nonoxidisings"],
    &["nonoxidizings"],
    &["nonoxidisings"],
];

pub(crate) static ENTRY_NONOXIDIZING_16594445364457308574: VariantsMap = [
    &["nonoxidizing"],
    &["nonoxidising"],
    &["nonoxidizing"],
    &["nonoxidising"],
];

pub(crate) static ENTRY_NONPARLORS_3253504681695686847: VariantsMap = [
    &["nonparlors"],
    &["nonparlours"],
    &["nonparlours"],
    &["nonparlours"],
];

pub(crate) static ENTRY_NONPARLOR_3613237573216443639: VariantsMap = [
    &["nonparlor"],
    &["nonparlour"],
    &["nonparlour"],
    &["nonparlour"],
];

pub(crate) static ENTRY_NONPENALIZEDS_9532498621715242902: VariantsMap = [
    &["nonpenalizeds"],
    &["nonpenaliseds"],
    &["nonpenalizeds"],
    &["nonpenaliseds"],
];

pub(crate) static ENTRY_NONPENALIZED_15326313494103509289: VariantsMap = [
    &["nonpenalized"],
    &["nonpenalised"],
    &["nonpenalized"],
    &["nonpenalised"],
];

pub(crate) static ENTRY_NONPHOSPHORIZEDS_14940949194406297295: VariantsMap = [
    &["nonphosphorizeds"],
    &["nonphosphoriseds"],
    &["nonphosphorizeds"],
    &["nonphosphoriseds"],
];

pub(crate) static ENTRY_NONPHOSPHORIZED_3297546196819705879: VariantsMap = [
    &["nonphosphorized"],
    &["nonphosphorised"],
    &["nonphosphorized"],
    &["nonphosphorised"],
];

pub(crate) static ENTRY_NONPOLARIZABLES_1893837066131069642: VariantsMap = [
    &["nonpolarizables"],
    &["nonpolarisables"],
    &["nonpolarizables"],
    &["nonpolarisables"],
];

pub(crate) static ENTRY_NONPOLARIZABLE_6616943736631357468: VariantsMap = [
    &["nonpolarizable"],
    &["nonpolarisable"],
    &["nonpolarizable"],
    &["nonpolarisable"],
];

pub(crate) static ENTRY_NONPOLARIZED_15305247587913084726: VariantsMap = [
    &["nonpolarized"],
    &["nonpolarised"],
    &["nonpolarized"],
    &["nonpolarised"],
];

pub(crate) static ENTRY_NONPOLARIZINGS_945000682506770397: VariantsMap = [
    &["nonpolarizings"],
    &["nonpolarisings"],
    &["nonpolarizings"],
    &["nonpolarisings"],
];

pub(crate) static ENTRY_NONPOLARIZING_12712477465510092876: VariantsMap = [
    &["nonpolarizing"],
    &["nonpolarising"],
    &["nonpolarizing"],
    &["nonpolarising"],
];

pub(crate) static ENTRY_NONRATIONALIZEDS_18331202286549559702: VariantsMap = [
    &["nonrationalizeds"],
    &["nonrationaliseds"],
    &["nonrationalizeds"],
    &["nonrationaliseds"],
];

pub(crate) static ENTRY_NONRATIONALIZED_3893321469385259750: VariantsMap = [
    &["nonrationalized"],
    &["nonrationalised"],
    &["nonrationalized"],
    &["nonrationalised"],
];

pub(crate) static ENTRY_NONREALIZATIONS_9898578985931514825: VariantsMap = [
    &["nonrealizations"],
    &["nonrealisations"],
    &["nonrealizations"],
    &["nonrealisations"],
];

pub(crate) static ENTRY_NONREALIZATION_13773240133730516692: VariantsMap = [
    &["nonrealization"],
    &["nonrealisation"],
    &["nonrealization"],
    &["nonrealisation"],
];

pub(crate) static ENTRY_NONRECOGNIZEDS_16936479754167964125: VariantsMap = [
    &["nonrecognizeds"],
    &["nonrecogniseds"],
    &["nonrecognizeds"],
    &["nonrecogniseds"],
];

pub(crate) static ENTRY_NONRECOGNIZED_5921644831413253839: VariantsMap = [
    &["nonrecognized"],
    &["nonrecognised"],
    &["nonrecognized"],
    &["nonrecognised"],
];

pub(crate) static ENTRY_NONSCHEMATIZEDS_8661436143168603744: VariantsMap = [
    &["nonschematizeds"],
    &["nonschematiseds"],
    &["nonschematizeds"],
    &["nonschematiseds"],
];

pub(crate) static ENTRY_NONSCHEMATIZED_3994267052359659886: VariantsMap = [
    &["nonschematized"],
    &["nonschematised"],
    &["nonschematized"],
    &["nonschematised"],
];

pub(crate) static ENTRY_NONSENSITIZEDS_6789040092514022355: VariantsMap = [
    &["nonsensitizeds"],
    &["nonsensitiseds"],
    &["nonsensitizeds"],
    &["nonsensitiseds"],
];

pub(crate) static ENTRY_NONSENSITIZED_16877012909978131488: VariantsMap = [
    &["nonsensitized"],
    &["nonsensitised"],
    &["nonsensitized"],
    &["nonsensitised"],
];

pub(crate) static ENTRY_NONSPECIALIZEDS_13994167169575510057: VariantsMap = [
    &["nonspecializeds"],
    &["nonspecialiseds"],
    &["nonspecializeds"],
    &["nonspecialiseds"],
];

pub(crate) static ENTRY_NONSPECIALIZED_8228165017120418839: VariantsMap = [
    &["nonspecialized"],
    &["nonspecialised"],
    &["nonspecialized"],
    &["nonspecialised"],
];

pub(crate) static ENTRY_NONSTANDARDIZEDS_108664461173603772: VariantsMap = [
    &["nonstandardizeds"],
    &["nonstandardiseds"],
    &["nonstandardizeds"],
    &["nonstandardiseds"],
];

pub(crate) static ENTRY_NONSTANDARDIZED_10229344405930170027: VariantsMap = [
    &["nonstandardized"],
    &["nonstandardised"],
    &["nonstandardized"],
    &["nonstandardised"],
];

pub(crate) static ENTRY_NONSTYLIZEDS_10458605700653930018: VariantsMap = [
    &["nonstylizeds"],
    &["nonstyliseds"],
    &["nonstylizeds"],
    &["nonstyliseds"],
];

pub(crate) static ENTRY_NONSTYLIZED_11878483916633075909: VariantsMap = [
    &["nonstylized"],
    &["nonstylised"],
    &["nonstylized"],
    &["nonstylised"],
];

pub(crate) static ENTRY_NONSUCCOR_1588594977500462039: VariantsMap = [
    &["nonsuccor"],
    &["nonsuccour"],
    &["nonsuccour"],
    &["nonsuccour"],
];

pub(crate) static ENTRY_NONSYMPATHIZERS_17703989460577560108: VariantsMap = [
    &["nonsympathizers"],
    &["nonsympathisers"],
    &["nonsympathizers"],
    &["nonsympathisers"],
];

pub(crate) static ENTRY_NONSYMPATHIZER_10483044256492595530: VariantsMap = [
    &["nonsympathizer"],
    &["nonsympathiser"],
    &["nonsympathizer"],
    &["nonsympathiser"],
];

pub(crate) static ENTRY_NONSYNTHESIZEDS_16944487649499471214: VariantsMap = [
    &["nonsynthesizeds"],
    &["nonsynthesiseds"],
    &["nonsynthesizeds"],
    &["nonsynthesiseds"],
];

pub(crate) static ENTRY_NONSYNTHESIZED_1042593700062664928: VariantsMap = [
    &["nonsynthesized"],
    &["nonsynthesised"],
    &["nonsynthesized"],
    &["nonsynthesised"],
];

pub(crate) static ENTRY_NONTEMPORIZINGS_10874940771787214104: VariantsMap = [
    &["nontemporizings"],
    &["nontemporisings"],
    &["nontemporizings"],
    &["nontemporisings"],
];

pub(crate) static ENTRY_NONTEMPORIZING_14055181193950301881: VariantsMap = [
    &["nontemporizing"],
    &["nontemporising"],
    &["nontemporizing"],
    &["nontemporising"],
];

pub(crate) static ENTRY_NONUTILIZEDS_12596659071225395484: VariantsMap = [
    &["nonutilizeds"],
    &["nonutiliseds"],
    &["nonutilizeds"],
    &["nonutiliseds"],
];

pub(crate) static ENTRY_NONUTILIZED_10968594570869729046: VariantsMap = [
    &["nonutilized"],
    &["nonutilised"],
    &["nonutilized"],
    &["nonutilised"],
];

pub(crate) static ENTRY_NONVISUALIZEDS_12906625611904739389: VariantsMap = [
    &["nonvisualizeds"],
    &["nonvisualiseds"],
    &["nonvisualizeds"],
    &["nonvisualiseds"],
];

pub(crate) static ENTRY_NONVISUALIZED_6861453340497684108: VariantsMap = [
    &["nonvisualized"],
    &["nonvisualised"],
    &["nonvisualized"],
    &["nonvisualised"],
];

pub(crate) static ENTRY_NONVOLATILIZEDS_5921558007608409082: VariantsMap = [
    &["nonvolatilizeds"],
    &["nonvolatiliseds"],
    &["nonvolatilizeds"],
    &["nonvolatiliseds"],
];

pub(crate) static ENTRY_NONVOLATILIZED_16762619793860124905: VariantsMap = [
    &["nonvolatilized"],
    &["nonvolatilised"],
    &["nonvolatilized"],
    &["nonvolatilised"],
];

pub(crate) static ENTRY_NONVULCANIZABLES_11079865157105755134: VariantsMap = [
    &["nonvulcanizables"],
    &["nonvulcanisables"],
    &["nonvulcanizables"],
    &["nonvulcanisables"],
];

pub(crate) static ENTRY_NONVULCANIZABLE_12072046253771095022: VariantsMap = [
    &["nonvulcanizable"],
    &["nonvulcanisable"],
    &["nonvulcanizable"],
    &["nonvulcanisable"],
];

pub(crate) static ENTRY_NORICE_7719373850762953271: VariantsMap =
    [&["norice"], &["nourice"], &["nourice"], &["nourice"]];

pub(crate) static ENTRY_NORMALIZABLE_12714814257299821976: VariantsMap = [
    &["normalizable"],
    &["normalisable"],
    &["normalizable"],
    &["normalisable"],
];

pub(crate) static ENTRY_NORMALIZATIONS_7144083295462081278: VariantsMap = [
    &["normalizations"],
    &["normalisations"],
    &["normalizations"],
    &["normalisations"],
];

pub(crate) static ENTRY_NORMALIZATION_17734536842587852393: VariantsMap = [
    &["normalization"],
    &["normalisation"],
    &["normalization"],
    &["normalisation"],
];

pub(crate) static ENTRY_NORMALIZED_3189571370237847522: VariantsMap = [
    &["normalized"],
    &["normalised"],
    &["normalized"],
    &["normalised"],
];

pub(crate) static ENTRY_NORMALIZERS_3883605235812540174: VariantsMap = [
    &["normalizers"],
    &["normalisers"],
    &["normalizers"],
    &["normalisers"],
];

pub(crate) static ENTRY_NORMALIZER_18084708139145944342: VariantsMap = [
    &["normalizer"],
    &["normaliser"],
    &["normalizer"],
    &["normaliser"],
];

pub(crate) static ENTRY_NORMALIZES_7325443769699672094: VariantsMap = [
    &["normalizes"],
    &["normalises"],
    &["normalizes"],
    &["normalises"],
];

pub(crate) static ENTRY_NORMALIZE_10079721671041412822: VariantsMap = [
    &["normalize"],
    &["normalise"],
    &["normalize"],
    &["normalise"],
];

pub(crate) static ENTRY_NORMALIZING_9186993296151327414: VariantsMap = [
    &["normalizing"],
    &["normalising"],
    &["normalizing"],
    &["normalising"],
];

pub(crate) static ENTRY_NORMANIZATIONS_14581317840430300825: VariantsMap = [
    &["normanizations"],
    &["normanisations"],
    &["normanizations"],
    &["normanisations"],
];

pub(crate) static ENTRY_NORMANIZATION_16947119225150381222: VariantsMap = [
    &["normanization"],
    &["normanisation"],
    &["normanization"],
    &["normanisation"],
];

pub(crate) static ENTRY_NORMANIZED_530025651553675599: VariantsMap = [
    &["normanized"],
    &["normanised"],
    &["normanized"],
    &["normanised"],
];

pub(crate) static ENTRY_NORMANIZERS_15592258832173314813: VariantsMap = [
    &["normanizers"],
    &["normanisers"],
    &["normanizers"],
    &["normanisers"],
];

pub(crate) static ENTRY_NORMANIZER_6483132356324999352: VariantsMap = [
    &["normanizer"],
    &["normaniser"],
    &["normanizer"],
    &["normaniser"],
];

pub(crate) static ENTRY_NORMANIZES_6751150550632176492: VariantsMap = [
    &["normanizes"],
    &["normanises"],
    &["normanizes"],
    &["normanises"],
];

pub(crate) static ENTRY_NORMANIZE_16686796116216318913: VariantsMap = [
    &["normanize"],
    &["normanise"],
    &["normanize"],
    &["normanise"],
];

pub(crate) static ENTRY_NORMANIZING_4320211489087339112: VariantsMap = [
    &["normanizing"],
    &["normanising"],
    &["normanizing"],
    &["normanising"],
];

pub(crate) static ENTRY_NORTHERNIZED_10171965562670427336: VariantsMap = [
    &["northernized"],
    &["northernised"],
    &["northernized"],
    &["northernised"],
];

pub(crate) static ENTRY_NORTHERNIZES_10191844020334839487: VariantsMap = [
    &["northernizes"],
    &["northernises"],
    &["northernizes"],
    &["northernises"],
];

pub(crate) static ENTRY_NORTHERNIZE_17423654317310933748: VariantsMap = [
    &["northernize"],
    &["northernise"],
    &["northernize"],
    &["northernise"],
];

pub(crate) static ENTRY_NORTHERNIZING_6205710759762367279: VariantsMap = [
    &["northernizing"],
    &["northernising"],
    &["northernizing"],
    &["northernising"],
];

pub(crate) static ENTRY_NOSIES_3207226487419150754: VariantsMap =
    [&["nosies"], &["nosies"], &["nosies"], &["nosies"]];

pub(crate) static ENTRY_NOSIZE_17677768185590899897: VariantsMap =
    [&["nosize"], &["nosise"], &["nosize"], &["nosise"]];

pub(crate) static ENTRY_NOSOHEMIA_14803479550852669947: VariantsMap = [
    &["nosohemia"],
    &["nosohaemia"],
    &["nosohaemia"],
    &["nosohaemia"],
];

pub(crate) static ENTRY_NOSY_12701039924678011332: VariantsMap =
    [&["nosy"], &["nosy"], &["nosy"], &["nosy"]];

pub(crate) static ENTRY_NOTARIZATIONS_13448734109191848651: VariantsMap = [
    &["notarizations"],
    &["notarisations"],
    &["notarizations"],
    &["notarisations"],
];

pub(crate) static ENTRY_NOTARIZATION_17527694196005011234: VariantsMap = [
    &["notarization"],
    &["notarisation"],
    &["notarization"],
    &["notarisation"],
];

pub(crate) static ENTRY_NOTARIZED_2113894921750376734: VariantsMap = [
    &["notarized"],
    &["notarised"],
    &["notarized"],
    &["notarised"],
];

pub(crate) static ENTRY_NOTARIZES_16852590610679722458: VariantsMap = [
    &["notarizes"],
    &["notarises"],
    &["notarizes"],
    &["notarises"],
];

pub(crate) static ENTRY_NOTARIZE_9890063397301391140: VariantsMap =
    [&["notarize"], &["notarise"], &["notarize"], &["notarise"]];

pub(crate) static ENTRY_NOTARIZING_9414320864175848283: VariantsMap = [
    &["notarizing"],
    &["notarising"],
    &["notarizing"],
    &["notarising"],
];

pub(crate) static ENTRY_NOTER_15452359787871882248: VariantsMap =
    [&["noter"], &["notre"], &["notre"], &["notre"]];

pub(crate) static ENTRY_NOTHINGIZES_14027925412325072532: VariantsMap = [
    &["nothingizes"],
    &["nothingises"],
    &["nothingizes"],
    &["nothingises"],
];

pub(crate) static ENTRY_NOTHINGIZE_17529460741124691591: VariantsMap = [
    &["nothingize"],
    &["nothingise"],
    &["nothingize"],
    &["nothingise"],
];

pub(crate) static ENTRY_NOTOGEA_12966682888446062914: VariantsMap =
    [&["notogea"], &["notogaea"], &["notogaea"], &["notogaea"]];

pub(crate) static ENTRY_NOUNIZES_10999252613540238861: VariantsMap =
    [&["nounizes"], &["nounises"], &["nounizes"], &["nounises"]];

pub(crate) static ENTRY_NOUNIZE_14880574386923956271: VariantsMap =
    [&["nounize"], &["nounise"], &["nounize"], &["nounise"]];

pub(crate) static ENTRY_NOVELIZATIONS_10468098323494499586: VariantsMap = [
    &["novelizations"],
    &["novelisations"],
    &["novelizations"],
    &["novelisations"],
];

pub(crate) static ENTRY_NOVELIZATION_8956602949054590888: VariantsMap = [
    &["novelization"],
    &["novelisation"],
    &["novelization"],
    &["novelisation"],
];

pub(crate) static ENTRY_NOVELIZED_15369631902763073587: VariantsMap = [
    &["novelized"],
    &["novelised"],
    &["novelized"],
    &["novelised"],
];

pub(crate) static ENTRY_NOVELIZERS_4056848164252264083: VariantsMap = [
    &["novelizers"],
    &["novelisers"],
    &["novelizers"],
    &["novelisers"],
];

pub(crate) static ENTRY_NOVELIZER_16608816919992566365: VariantsMap = [
    &["novelizer"],
    &["noveliser"],
    &["novelizer"],
    &["noveliser"],
];

pub(crate) static ENTRY_NOVELIZES_6422920218071722529: VariantsMap = [
    &["novelizes"],
    &["novelises"],
    &["novelizes"],
    &["novelises"],
];

pub(crate) static ENTRY_NOVELIZE_9212839077174855051: VariantsMap =
    [&["novelize"], &["novelise"], &["novelize"], &["novelise"]];

pub(crate) static ENTRY_NOVELIZING_17848834665214118176: VariantsMap = [
    &["novelizing"],
    &["novelising"],
    &["novelizing"],
    &["novelising"],
];

pub(crate) static ENTRY_NOVENE_2924055121197444180: VariantsMap =
    [&["novene"], &["novenae"], &["novenae"], &["novenae"]];

pub(crate) static ENTRY_NUCLEARIZATIONS_6750475977451359321: VariantsMap = [
    &["nuclearizations"],
    &["nuclearisations"],
    &["nuclearizations"],
    &["nuclearisations"],
];

pub(crate) static ENTRY_NUCLEARIZATION_3118454623052463273: VariantsMap = [
    &["nuclearization"],
    &["nuclearisation"],
    &["nuclearization"],
    &["nuclearisation"],
];

pub(crate) static ENTRY_NUCLEARIZED_3730672147144693200: VariantsMap = [
    &["nuclearized"],
    &["nuclearised"],
    &["nuclearized"],
    &["nuclearised"],
];

pub(crate) static ENTRY_NUCLEARIZES_11938247015587300181: VariantsMap = [
    &["nuclearizes"],
    &["nuclearises"],
    &["nuclearizes"],
    &["nuclearises"],
];

pub(crate) static ENTRY_NUCLEARIZE_16199083117905670972: VariantsMap = [
    &["nuclearize"],
    &["nuclearise"],
    &["nuclearize"],
    &["nuclearise"],
];

pub(crate) static ENTRY_NUCLEARIZING_8881830408497767903: VariantsMap = [
    &["nuclearizing"],
    &["nuclearising"],
    &["nuclearizing"],
    &["nuclearising"],
];

pub(crate) static ENTRY_NUPTIALIZES_6702953704988138928: VariantsMap = [
    &["nuptializes"],
    &["nuptialises"],
    &["nuptializes"],
    &["nuptialises"],
];

pub(crate) static ENTRY_NUPTIALIZE_260057599291493188: VariantsMap = [
    &["nuptialize"],
    &["nuptialise"],
    &["nuptialize"],
    &["nuptialise"],
];

pub(crate) static ENTRY_NYMPHEUM_10481976698848445627: VariantsMap = [
    &["nympheum"],
    &["nymphaeum"],
    &["nymphaeum"],
    &["nymphaeum"],
];

pub(crate) static ENTRY_OBELIZED_8713779244189302123: VariantsMap =
    [&["obelized"], &["obelised"], &["obelized"], &["obelised"]];

pub(crate) static ENTRY_OBELIZES_12711583286840300362: VariantsMap =
    [&["obelizes"], &["obelises"], &["obelizes"], &["obelises"]];

pub(crate) static ENTRY_OBELIZE_13327573059995603775: VariantsMap =
    [&["obelize"], &["obelise"], &["obelize"], &["obelise"]];

pub(crate) static ENTRY_OBELIZING_10540895735990622314: VariantsMap = [
    &["obelizing"],
    &["obelising"],
    &["obelizing"],
    &["obelising"],
];

pub(crate) static ENTRY_OBE_3387122031217898278: VariantsMap =
    [&["obe"], &["oboe"], &["oboe"], &["oboe"]];

pub(crate) static ENTRY_OBJECTIVIZED_5569615171626387785: VariantsMap = [
    &["objectivized"],
    &["objectivised"],
    &["objectivized"],
    &["objectivised"],
];

pub(crate) static ENTRY_OBJECTIVIZES_9154527217307669621: VariantsMap = [
    &["objectivizes"],
    &["objectivises"],
    &["objectivizes"],
    &["objectivises"],
];

pub(crate) static ENTRY_OBJECTIVIZE_11255072833982793370: VariantsMap = [
    &["objectivize"],
    &["objectivise"],
    &["objectivize"],
    &["objectivise"],
];

pub(crate) static ENTRY_OBJECTIVIZING_13183716323700619199: VariantsMap = [
    &["objectivizing"],
    &["objectivising"],
    &["objectivizing"],
    &["objectivising"],
];

pub(crate) static ENTRY_OBJECTIZATIONS_6401266830241310518: VariantsMap = [
    &["objectizations"],
    &["objectisations"],
    &["objectizations"],
    &["objectisations"],
];

pub(crate) static ENTRY_OBJECTIZATION_1275857172671417186: VariantsMap = [
    &["objectization"],
    &["objectisation"],
    &["objectization"],
    &["objectisation"],
];

pub(crate) static ENTRY_OBJECTIZES_6620023301989924349: VariantsMap = [
    &["objectizes"],
    &["objectises"],
    &["objectizes"],
    &["objectises"],
];

pub(crate) static ENTRY_OBJECTIZE_15875934894636197705: VariantsMap = [
    &["objectize"],
    &["objectise"],
    &["objectize"],
    &["objectise"],
];

pub(crate) static ENTRY_OBLIVIONIZES_1391399085902087900: VariantsMap = [
    &["oblivionizes"],
    &["oblivionises"],
    &["oblivionizes"],
    &["oblivionises"],
];

pub(crate) static ENTRY_OBLIVIONIZE_12722654593806151859: VariantsMap = [
    &["oblivionize"],
    &["oblivionise"],
    &["oblivionize"],
    &["oblivionise"],
];

pub(crate) static ENTRY_OCCIDENTALIZATIONS_8738201873109640995: VariantsMap = [
    &["occidentalizations"],
    &["occidentalisations"],
    &["occidentalizations"],
    &["occidentalisations"],
];

pub(crate) static ENTRY_OCCIDENTALIZATION_3769379737658488415: VariantsMap = [
    &["occidentalization"],
    &["occidentalisation"],
    &["occidentalization"],
    &["occidentalisation"],
];

pub(crate) static ENTRY_OCCIDENTALIZED_10700323340151304771: VariantsMap = [
    &["occidentalized"],
    &["occidentalised"],
    &["occidentalized"],
    &["occidentalised"],
];

pub(crate) static ENTRY_OCCIDENTALIZES_11790781010835271497: VariantsMap = [
    &["occidentalizes"],
    &["occidentalises"],
    &["occidentalizes"],
    &["occidentalises"],
];

pub(crate) static ENTRY_OCCIDENTALIZE_14982167974023633691: VariantsMap = [
    &["occidentalize"],
    &["occidentalise"],
    &["occidentalize"],
    &["occidentalise"],
];

pub(crate) static ENTRY_OCCIDENTALIZING_7464247317028861929: VariantsMap = [
    &["occidentalizing"],
    &["occidentalising"],
    &["occidentalizing"],
    &["occidentalising"],
];

pub(crate) static ENTRY_OCHERED_16209295361742850766: VariantsMap =
    [&["ochered"], &["ochred"], &["ochred"], &["ochred"]];

pub(crate) static ENTRY_OCHERING_9981492660913249632: VariantsMap =
    [&["ochering"], &["ochring"], &["ochring"], &["ochring"]];

pub(crate) static ENTRY_OCHERISH_13974738456690891637: VariantsMap =
    [&["ocherish"], &["ochreish"], &["ochreish"], &["ochreish"]];

pub(crate) static ENTRY_OCHEROUSER_5814846539343037272: VariantsMap = [
    &["ocherouser"],
    &["ochreouser"],
    &["ochreouser"],
    &["ochreouser"],
];

pub(crate) static ENTRY_OCHEROUSEST_12442913746853846797: VariantsMap = [
    &["ocherousest"],
    &["ochreousest"],
    &["ochreousest"],
    &["ochreousest"],
];

pub(crate) static ENTRY_OCHEROUS_12471251094160085620: VariantsMap =
    [&["ocherous"], &["ochreous"], &["ochreous"], &["ochreous"]];

pub(crate) static ENTRY_OCHERRER_17558493090638662388: VariantsMap =
    [&["ocherrer"], &["ochrer"], &["ochrer"], &["ochrer"]];

pub(crate) static ENTRY_OCHERREST_9858563234413281789: VariantsMap =
    [&["ocherrest"], &["ochrest"], &["ochrest"], &["ochrest"]];

pub(crate) static ENTRY_OCHERS_10191929869929788169: VariantsMap =
    [&["ochers"], &["ochres"], &["ochres"], &["ochres"]];

pub(crate) static ENTRY_OCHERY_11959809883617627023: VariantsMap =
    [&["ochery"], &["ochrey"], &["ochrey"], &["ochrey"]];

pub(crate) static ENTRY_OCHER_18444668755403044757: VariantsMap =
    [&["ocher"], &["ochre"], &["ochre"], &["ochre"]];

pub(crate) static ENTRY_OCYRRHOE_15586534960542914241: VariantsMap = [
    &["ocyrrhoe"],
    &["ocyrrhoae"],
    &["ocyrrhoae"],
    &["ocyrrhoae"],
];

pub(crate) static ENTRY_ODORED_2252339375387177943: VariantsMap =
    [&["odored"], &["odoured"], &["odoured"], &["odoured"]];

pub(crate) static ENTRY_ODORFULLER_13616470430206634220: VariantsMap = [
    &["odorfuller"],
    &["odourfuller"],
    &["odourfuller"],
    &["odourfuller"],
];

pub(crate) static ENTRY_ODORFULLEST_17115559072799533041: VariantsMap = [
    &["odorfullest"],
    &["odourfullest"],
    &["odourfullest"],
    &["odourfullest"],
];

pub(crate) static ENTRY_ODORFUL_16899196923808811198: VariantsMap =
    [&["odorful"], &["odourful"], &["odourful"], &["odourful"]];

pub(crate) static ENTRY_ODORIZED_12401728499096074253: VariantsMap =
    [&["odorized"], &["odorised"], &["odorized"], &["odorised"]];

pub(crate) static ENTRY_ODORIZER_9703276154089227183: VariantsMap =
    [&["odorizer"], &["odoriser"], &["odorizer"], &["odoriser"]];

pub(crate) static ENTRY_ODORIZES_14078045785775136097: VariantsMap =
    [&["odorizes"], &["odorises"], &["odorizes"], &["odorises"]];

pub(crate) static ENTRY_ODORIZE_9626934429537178470: VariantsMap =
    [&["odorize"], &["odorise"], &["odorize"], &["odorise"]];

pub(crate) static ENTRY_ODORIZING_15240114282647188255: VariantsMap = [
    &["odorizing"],
    &["odorising"],
    &["odorizing"],
    &["odorising"],
];

pub(crate) static ENTRY_ODORLESSER_17075792343165727224: VariantsMap = [
    &["odorlesser"],
    &["odourlesser"],
    &["odourlesser"],
    &["odourlesser"],
];

pub(crate) static ENTRY_ODORLESSEST_1630943358374016605: VariantsMap = [
    &["odorlessest"],
    &["odourlessest"],
    &["odourlessest"],
    &["odourlessest"],
];

pub(crate) static ENTRY_ODORLESSES_1268415129329322072: VariantsMap = [
    &["odorlesses"],
    &["odourlesses"],
    &["odourlesses"],
    &["odourlesses"],
];

pub(crate) static ENTRY_ODORLESS_8490769064796870183: VariantsMap = [
    &["odorless"],
    &["odourless"],
    &["odourless"],
    &["odourless"],
];

pub(crate) static ENTRY_ODORS_372602031562404386: VariantsMap =
    [&["odors"], &["odours"], &["odours"], &["odours"]];

pub(crate) static ENTRY_ODOR_14195116284871916349: VariantsMap =
    [&["odor"], &["odour"], &["odour"], &["odour"]];

pub(crate) static ENTRY_OFFENSELESSER_8750322905944062314: VariantsMap = [
    &["offenselesser"],
    &["offencelesser"],
    &["offencelesser"],
    &["offencelesser"],
];

pub(crate) static ENTRY_OFFENSELESSEST_15069248455544272907: VariantsMap = [
    &["offenselessest"],
    &["offencelessest"],
    &["offencelessest"],
    &["offencelessest"],
];

pub(crate) static ENTRY_OFFENSELESSES_9194933418994630180: VariantsMap = [
    &["offenselesses"],
    &["offencelesses"],
    &["offencelesses"],
    &["offencelesses"],
];

pub(crate) static ENTRY_OFFENSELESSLY_8614532241535438605: VariantsMap = [
    &["offenselessly"],
    &["offencelessly"],
    &["offencelessly"],
    &["offencelessly"],
];

pub(crate) static ENTRY_OFFENSELESS_13868538846119764327: VariantsMap = [
    &["offenseless"],
    &["offenceless"],
    &["offenceless"],
    &["offenceless"],
];

pub(crate) static ENTRY_OFFENSES_17067991581389456500: VariantsMap =
    [&["offenses"], &["offences"], &["offences"], &["offences"]];

pub(crate) static ENTRY_OFFENSE_7665506159023341249: VariantsMap =
    [&["offense"], &["offence"], &["offence"], &["offence"]];

pub(crate) static ENTRY_OFFICIALIZATIONS_16572881069026493160: VariantsMap = [
    &["officializations"],
    &["officialisations"],
    &["officializations"],
    &["officialisations"],
];

pub(crate) static ENTRY_OFFICIALIZATION_12282151738176992879: VariantsMap = [
    &["officialization"],
    &["officialisation"],
    &["officialization"],
    &["officialisation"],
];

pub(crate) static ENTRY_OFFICIALIZES_6105548396173328182: VariantsMap = [
    &["officializes"],
    &["officialises"],
    &["officializes"],
    &["officialises"],
];

pub(crate) static ENTRY_OFFICIALIZE_3115747240724358934: VariantsMap = [
    &["officialize"],
    &["officialise"],
    &["officialize"],
    &["officialise"],
];

pub(crate) static ENTRY_OLIGEMIA_10907380054389841551: VariantsMap = [
    &["oligemia"],
    &["oligaemia"],
    &["oligaemia"],
    &["oligaemia"],
];

pub(crate) static ENTRY_OLIGOCYTHEMIA_4447810723170322323: VariantsMap = [
    &["oligocythemia"],
    &["oligocythaemia"],
    &["oligocythaemia"],
    &["oligocythaemia"],
];

pub(crate) static ENTRY_OLPE_12607327020570739475: VariantsMap =
    [&["olpe"], &["olpae"], &["olpae"], &["olpae"]];

pub(crate) static ENTRY_OLYMPIANIZES_15338190775391482293: VariantsMap = [
    &["olympianizes"],
    &["olympianises"],
    &["olympianizes"],
    &["olympianises"],
];

pub(crate) static ENTRY_OLYMPIANIZE_16666030921906448094: VariantsMap = [
    &["olympianize"],
    &["olympianise"],
    &["olympianize"],
    &["olympianise"],
];

pub(crate) static ENTRY_OMBERS_15554244962838841551: VariantsMap =
    [&["ombers"], &["ombres"], &["ombres"], &["ombres"]];

pub(crate) static ENTRY_OMBER_3695322023364981830: VariantsMap =
    [&["omber"], &["ombre"], &["ombre"], &["ombre"]];

pub(crate) static ENTRY_OMELETS_1159437164748315894: VariantsMap =
    [&["omelets"], &["omelettes"], &["omelettes"], &["omelettes"]];

pub(crate) static ENTRY_OMELET_7824462662732690545: VariantsMap =
    [&["omelet"], &["omelette"], &["omelette"], &["omelette"]];

pub(crate) static ENTRY_ONEYERS_732051306964839428: VariantsMap =
    [&["oneyers"], &["oneyres"], &["oneyres"], &["oneyres"]];

pub(crate) static ENTRY_ONEYER_3113456979455149502: VariantsMap =
    [&["oneyer"], &["oneyre"], &["oneyre"], &["oneyre"]];

pub(crate) static ENTRY_ONIONIZEDS_14087702405815459001: VariantsMap = [
    &["onionizeds"],
    &["onioniseds"],
    &["onionizeds"],
    &["onioniseds"],
];

pub(crate) static ENTRY_ONIONIZED_13175316651387656071: VariantsMap = [
    &["onionized"],
    &["onionised"],
    &["onionized"],
    &["onionised"],
];

pub(crate) static ENTRY_ONTOLOGIZE_16171100816417470761: VariantsMap = [
    &["ontologize"],
    &["ontologise"],
    &["ontologize"],
    &["ontologise"],
];

pub(crate) static ENTRY_OOGLEA_4797962690992465162: VariantsMap =
    [&["ooglea"], &["oogloea"], &["oogloea"], &["oogloea"]];

pub(crate) static ENTRY_OOPHORECTOMIZED_9646531786514422937: VariantsMap = [
    &["oophorectomized"],
    &["oophorectomised"],
    &["oophorectomized"],
    &["oophorectomised"],
];

pub(crate) static ENTRY_OOPHORECTOMIZES_149709679714797903: VariantsMap = [
    &["oophorectomizes"],
    &["oophorectomises"],
    &["oophorectomizes"],
    &["oophorectomises"],
];

pub(crate) static ENTRY_OOPHORECTOMIZE_6120142783855584835: VariantsMap = [
    &["oophorectomize"],
    &["oophorectomise"],
    &["oophorectomize"],
    &["oophorectomise"],
];

pub(crate) static ENTRY_OOPHORECTOMIZING_6744915085700528874: VariantsMap = [
    &["oophorectomizing"],
    &["oophorectomising"],
    &["oophorectomizing"],
    &["oophorectomising"],
];

pub(crate) static ENTRY_OPALED_11788692301205754513: VariantsMap =
    [&["opaled"], &["opalled"], &["opalled"], &["opalled"]];

pub(crate) static ENTRY_OPALIZED_13663629834424998715: VariantsMap =
    [&["opalized"], &["opalised"], &["opalized"], &["opalised"]];

pub(crate) static ENTRY_OPALIZES_13162100843006512376: VariantsMap =
    [&["opalizes"], &["opalises"], &["opalizes"], &["opalises"]];

pub(crate) static ENTRY_OPALIZE_13284386352819052954: VariantsMap =
    [&["opalize"], &["opalise"], &["opalize"], &["opalise"]];

pub(crate) static ENTRY_OPERATIONALIZATIONS_15714273084107805159: VariantsMap = [
    &["operationalizations"],
    &["operationalisations"],
    &["operationalizations"],
    &["operationalisations"],
];

pub(crate) static ENTRY_OPERATIONALIZATION_16110043926870456437: VariantsMap = [
    &["operationalization"],
    &["operationalisation"],
    &["operationalization"],
    &["operationalisation"],
];

pub(crate) static ENTRY_OPERATIONALIZED_10694005742106318769: VariantsMap = [
    &["operationalized"],
    &["operationalised"],
    &["operationalized"],
    &["operationalised"],
];

pub(crate) static ENTRY_OPERATIONALIZE_2692806162887915024: VariantsMap = [
    &["operationalize"],
    &["operationalise"],
    &["operationalize"],
    &["operationalise"],
];

pub(crate) static ENTRY_OPERATIZED_5105704374145792138: VariantsMap = [
    &["operatized"],
    &["operatised"],
    &["operatized"],
    &["operatised"],
];

pub(crate) static ENTRY_OPERATIZES_4708799086455482533: VariantsMap = [
    &["operatizes"],
    &["operatises"],
    &["operatizes"],
    &["operatises"],
];

pub(crate) static ENTRY_OPERATIZE_3052027238656154731: VariantsMap = [
    &["operatize"],
    &["operatise"],
    &["operatize"],
    &["operatise"],
];

pub(crate) static ENTRY_OPERATIZING_8904168123042897096: VariantsMap = [
    &["operatizing"],
    &["operatising"],
    &["operatizing"],
    &["operatising"],
];

pub(crate) static ENTRY_OPINIASTER_1982100576920314323: VariantsMap = [
    &["opiniaster"],
    &["opiniastre"],
    &["opiniastre"],
    &["opiniastre"],
];

pub(crate) static ENTRY_OPINIATER_8121394919829508808: VariantsMap = [
    &["opiniater"],
    &["opiniatre"],
    &["opiniatre"],
    &["opiniatre"],
];

pub(crate) static ENTRY_OPTIMALIZATIONS_14704077527785732577: VariantsMap = [
    &["optimalizations"],
    &["optimalisations"],
    &["optimalizations"],
    &["optimalisations"],
];

pub(crate) static ENTRY_OPTIMALIZATION_17508577542812465721: VariantsMap = [
    &["optimalization"],
    &["optimalisation"],
    &["optimalization"],
    &["optimalisation"],
];

pub(crate) static ENTRY_OPTIMALIZED_7555891306105308389: VariantsMap = [
    &["optimalized"],
    &["optimalised"],
    &["optimalized"],
    &["optimalised"],
];

pub(crate) static ENTRY_OPTIMALIZES_3228782827219559495: VariantsMap = [
    &["optimalizes"],
    &["optimalises"],
    &["optimalizes"],
    &["optimalises"],
];

pub(crate) static ENTRY_OPTIMALIZE_12220685864866355750: VariantsMap = [
    &["optimalize"],
    &["optimalise"],
    &["optimalize"],
    &["optimalise"],
];

pub(crate) static ENTRY_OPTIMALIZING_12458824693754631504: VariantsMap = [
    &["optimalizing"],
    &["optimalising"],
    &["optimalizing"],
    &["optimalising"],
];

pub(crate) static ENTRY_OPTIMIZATIONS_1194472855170942155: VariantsMap = [
    &["optimizations"],
    &["optimisations"],
    &["optimizations"],
    &["optimisations"],
];

pub(crate) static ENTRY_OPTIMIZATION_13814783904890834134: VariantsMap = [
    &["optimization"],
    &["optimisation"],
    &["optimization"],
    &["optimisation"],
];

pub(crate) static ENTRY_OPTIMIZED_8242242244633121729: VariantsMap = [
    &["optimized"],
    &["optimised"],
    &["optimized"],
    &["optimised"],
];

pub(crate) static ENTRY_OPTIMIZERS_15572959853505310715: VariantsMap = [
    &["optimizers"],
    &["optimisers"],
    &["optimizers"],
    &["optimisers"],
];

pub(crate) static ENTRY_OPTIMIZER_520050784414587313: VariantsMap = [
    &["optimizer"],
    &["optimiser"],
    &["optimizer"],
    &["optimiser"],
];

pub(crate) static ENTRY_OPTIMIZES_12957185612694058626: VariantsMap = [
    &["optimizes"],
    &["optimises"],
    &["optimizes"],
    &["optimises"],
];

pub(crate) static ENTRY_OPTIMIZE_1313335540043097536: VariantsMap =
    [&["optimize"], &["optimise"], &["optimize"], &["optimise"]];

pub(crate) static ENTRY_OPTIMIZING_11401875964281836448: VariantsMap = [
    &["optimizing"],
    &["optimising"],
    &["optimizing"],
    &["optimising"],
];

pub(crate) static ENTRY_OPTIONALIZES_17211623898421470779: VariantsMap = [
    &["optionalizes"],
    &["optionalises"],
    &["optionalizes"],
    &["optionalises"],
];

pub(crate) static ENTRY_OPTIONALIZE_17761516814714768422: VariantsMap = [
    &["optionalize"],
    &["optionalise"],
    &["optionalize"],
    &["optionalise"],
];

pub(crate) static ENTRY_ORALIZATIONS_8167551586215783500: VariantsMap = [
    &["oralizations"],
    &["oralisations"],
    &["oralizations"],
    &["oralisations"],
];

pub(crate) static ENTRY_ORALIZATION_14381971273730025874: VariantsMap = [
    &["oralization"],
    &["oralisation"],
    &["oralization"],
    &["oralisation"],
];

pub(crate) static ENTRY_ORALIZES_13092540530518911479: VariantsMap =
    [&["oralizes"], &["oralises"], &["oralizes"], &["oralises"]];

pub(crate) static ENTRY_ORALIZE_323213378900609037: VariantsMap =
    [&["oralize"], &["oralise"], &["oralize"], &["oralise"]];

pub(crate) static ENTRY_ORANGIZES_6766010016440987313: VariantsMap = [
    &["orangizes"],
    &["orangises"],
    &["orangizes"],
    &["orangises"],
];

pub(crate) static ENTRY_ORANGIZE_8695259728466009401: VariantsMap =
    [&["orangize"], &["orangise"], &["orangize"], &["orangise"]];

pub(crate) static ENTRY_ORANGS_6364282221462306169: VariantsMap =
    [&["orangs"], &["orangs"], &["orangs"], &["orangs"]];

pub(crate) static ENTRY_ORANG_14748066994966584311: VariantsMap =
    [&["orang"], &["orang"], &["orang"], &["orang"]];

pub(crate) static ENTRY_ORATORIZES_7819252335974566625: VariantsMap = [
    &["oratorizes"],
    &["oratorises"],
    &["oratorizes"],
    &["oratorises"],
];

pub(crate) static ENTRY_ORATORIZE_10763244403747894729: VariantsMap = [
    &["oratorize"],
    &["oratorise"],
    &["oratorize"],
    &["oratorise"],
];

pub(crate) static ENTRY_ORCHESTER_3438543331406974215: VariantsMap = [
    &["orchester"],
    &["orchestre"],
    &["orchestre"],
    &["orchestre"],
];

pub(crate) static ENTRY_ORGANDY_17377013850024153081: VariantsMap =
    [&["organdy"], &["organdie"], &["organdy"], &["organdie"]];

pub(crate) static ENTRY_ORGANIZABILITIES_17928216122597123749: VariantsMap = [
    &["organizabilities"],
    &["organisabilities"],
    &["organizabilities"],
    &["organisabilities"],
];

pub(crate) static ENTRY_ORGANIZABILITY_11606263519927125050: VariantsMap = [
    &["organizability"],
    &["organisability"],
    &["organizability"],
    &["organisability"],
];

pub(crate) static ENTRY_ORGANIZABLER_16730726147732418422: VariantsMap = [
    &["organizabler"],
    &["organisabler"],
    &["organizabler"],
    &["organisabler"],
];

pub(crate) static ENTRY_ORGANIZABLEST_95216295824098143: VariantsMap = [
    &["organizablest"],
    &["organisablest"],
    &["organizablest"],
    &["organisablest"],
];

pub(crate) static ENTRY_ORGANIZABLES_3895944364193703180: VariantsMap = [
    &["organizables"],
    &["organisables"],
    &["organizables"],
    &["organisables"],
];

pub(crate) static ENTRY_ORGANIZABLE_8071054869331386545: VariantsMap = [
    &["organizable"],
    &["organisable"],
    &["organizable"],
    &["organisable"],
];

pub(crate) static ENTRY_ORGANIZATIONALER_6873530680939021849: VariantsMap = [
    &["organizationaler"],
    &["organisationaler"],
    &["organizationaler"],
    &["organisationaler"],
];

pub(crate) static ENTRY_ORGANIZATIONALEST_13609364841796570141: VariantsMap = [
    &["organizationalest"],
    &["organisationalest"],
    &["organizationalest"],
    &["organisationalest"],
];

pub(crate) static ENTRY_ORGANIZATIONALLIER_5244336690983254999: VariantsMap = [
    &["organizationallier"],
    &["organisationallier"],
    &["organizationallier"],
    &["organisationallier"],
];

pub(crate) static ENTRY_ORGANIZATIONALLIEST_5857114456710165646: VariantsMap = [
    &["organizationalliest"],
    &["organisationalliest"],
    &["organizationalliest"],
    &["organisationalliest"],
];

pub(crate) static ENTRY_ORGANIZATIONALLY_3853665432127949386: VariantsMap = [
    &["organizationally"],
    &["organisationally"],
    &["organizationally"],
    &["organisationally"],
];

pub(crate) static ENTRY_ORGANIZATIONALS_10559236366326509118: VariantsMap = [
    &["organizationals"],
    &["organisationals"],
    &["organizationals"],
    &["organisationals"],
];

pub(crate) static ENTRY_ORGANIZATIONAL_11623270165270540295: VariantsMap = [
    &["organizational"],
    &["organisational"],
    &["organizational"],
    &["organisational"],
];

pub(crate) static ENTRY_ORGANIZATIONISTS_17058096744384947274: VariantsMap = [
    &["organizationists"],
    &["organisationists"],
    &["organizationists"],
    &["organisationists"],
];

pub(crate) static ENTRY_ORGANIZATIONIST_7224361965665550626: VariantsMap = [
    &["organizationist"],
    &["organisationist"],
    &["organizationist"],
    &["organisationist"],
];

pub(crate) static ENTRY_ORGANIZATIONS_18209440244615759048: VariantsMap = [
    &["organizations"],
    &["organisations"],
    &["organizations"],
    &["organisations"],
];

pub(crate) static ENTRY_ORGANIZATION_1183056542960920892: VariantsMap = [
    &["organization"],
    &["organisation"],
    &["organization"],
    &["organisation"],
];

pub(crate) static ENTRY_ORGANIZED_12748056748294699226: VariantsMap = [
    &["organized"],
    &["organised"],
    &["organized"],
    &["organised"],
];

pub(crate) static ENTRY_ORGANIZERS_3523554258367195869: VariantsMap = [
    &["organizers"],
    &["organisers"],
    &["organizers"],
    &["organisers"],
];

pub(crate) static ENTRY_ORGANIZER_15132700960835020128: VariantsMap = [
    &["organizer"],
    &["organiser"],
    &["organizer"],
    &["organiser"],
];

pub(crate) static ENTRY_ORGANIZES_5740513370384106221: VariantsMap = [
    &["organizes"],
    &["organises"],
    &["organizes"],
    &["organises"],
];

pub(crate) static ENTRY_ORGANIZE_12183139167602281526: VariantsMap =
    [&["organize"], &["organise"], &["organize"], &["organise"]];

pub(crate) static ENTRY_ORGANIZING_15958036800031360134: VariantsMap = [
    &["organizing"],
    &["organising"],
    &["organizing"],
    &["organising"],
];

pub(crate) static ENTRY_ORIENTALIZATIONS_11663753413845884425: VariantsMap = [
    &["orientalizations"],
    &["orientalisations"],
    &["orientalizations"],
    &["orientalisations"],
];

pub(crate) static ENTRY_ORIENTALIZATION_16408076822380414996: VariantsMap = [
    &["orientalization"],
    &["orientalisation"],
    &["orientalization"],
    &["orientalisation"],
];

pub(crate) static ENTRY_ORIENTALIZED_12632548807615689147: VariantsMap = [
    &["orientalized"],
    &["orientalised"],
    &["orientalized"],
    &["orientalised"],
];

pub(crate) static ENTRY_ORIENTALIZES_16600052414672173758: VariantsMap = [
    &["orientalizes"],
    &["orientalises"],
    &["orientalizes"],
    &["orientalises"],
];

pub(crate) static ENTRY_ORIENTALIZE_15033142611450893882: VariantsMap = [
    &["orientalize"],
    &["orientalise"],
    &["orientalize"],
    &["orientalise"],
];

pub(crate) static ENTRY_ORIENTALIZING_13577294125296985019: VariantsMap = [
    &["orientalizing"],
    &["orientalising"],
    &["orientalizing"],
    &["orientalising"],
];

pub(crate) static ENTRY_ORIENTIZATIONS_10754218882392069685: VariantsMap = [
    &["orientizations"],
    &["orientisations"],
    &["orientizations"],
    &["orientisations"],
];

pub(crate) static ENTRY_ORIENTIZATION_15927365675673893265: VariantsMap = [
    &["orientization"],
    &["orientisation"],
    &["orientization"],
    &["orientisation"],
];

pub(crate) static ENTRY_ORIENTIZES_11330269575495931584: VariantsMap = [
    &["orientizes"],
    &["orientises"],
    &["orientizes"],
    &["orientises"],
];

pub(crate) static ENTRY_ORIENTIZE_6500583041683891917: VariantsMap = [
    &["orientize"],
    &["orientise"],
    &["orientize"],
    &["orientise"],
];

pub(crate) static ENTRY_ORNAMENTALIZES_17286281591371268395: VariantsMap = [
    &["ornamentalizes"],
    &["ornamentalises"],
    &["ornamentalizes"],
    &["ornamentalises"],
];

pub(crate) static ENTRY_ORNAMENTALIZE_11798404068766485269: VariantsMap = [
    &["ornamentalize"],
    &["ornamentalise"],
    &["ornamentalize"],
    &["ornamentalise"],
];

pub(crate) static ENTRY_OROLOGIES_4057377307180654251: VariantsMap = [
    &["orologies"],
    &["ourologies"],
    &["ourologies"],
    &["ourologies"],
];

pub(crate) static ENTRY_OROLOGY_12237949646354810674: VariantsMap =
    [&["orology"], &["ourology"], &["ourology"], &["ourology"]];

pub(crate) static ENTRY_ORPHANIZES_9097669333806624580: VariantsMap = [
    &["orphanizes"],
    &["orphanises"],
    &["orphanizes"],
    &["orphanises"],
];

pub(crate) static ENTRY_ORPHANIZE_11588568553833781059: VariantsMap = [
    &["orphanize"],
    &["orphanise"],
    &["orphanize"],
    &["orphanise"],
];

pub(crate) static ENTRY_ORSEL_8592125767374023328: VariantsMap =
    [&["orsel"], &["oursel"], &["oursel"], &["oursel"]];

pub(crate) static ENTRY_ORTHOCENTERS_3251720815245763229: VariantsMap = [
    &["orthocenters"],
    &["orthocentres"],
    &["orthocentres"],
    &["orthocentres"],
];

pub(crate) static ENTRY_ORTHOCENTER_9905926170374681677: VariantsMap = [
    &["orthocenter"],
    &["orthocentre"],
    &["orthocentre"],
    &["orthocentre"],
];

pub(crate) static ENTRY_ORTHOGONALIZATION_4179399411066144174: VariantsMap = [
    &["orthogonalization"],
    &["orthogonalisation"],
    &["orthogonalization"],
    &["orthogonalisation"],
];

pub(crate) static ENTRY_ORTHOGONALIZED_11695907609311865979: VariantsMap = [
    &["orthogonalized"],
    &["orthogonalised"],
    &["orthogonalized"],
    &["orthogonalised"],
];

pub(crate) static ENTRY_ORTHOGONALIZES_15773663260089545240: VariantsMap = [
    &["orthogonalizes"],
    &["orthogonalises"],
    &["orthogonalizes"],
    &["orthogonalises"],
];

pub(crate) static ENTRY_ORTHOGONALIZE_14210745318503216217: VariantsMap = [
    &["orthogonalize"],
    &["orthogonalise"],
    &["orthogonalize"],
    &["orthogonalise"],
];

pub(crate) static ENTRY_ORTHOGONALIZING_5565358582316743636: VariantsMap = [
    &["orthogonalizing"],
    &["orthogonalising"],
    &["orthogonalizing"],
    &["orthogonalising"],
];

pub(crate) static ENTRY_ORTHOGRAPHIZED_15841004195944273148: VariantsMap = [
    &["orthographized"],
    &["orthographised"],
    &["orthographized"],
    &["orthographised"],
];

pub(crate) static ENTRY_ORTHOGRAPHIZE_8119365633244588200: VariantsMap = [
    &["orthographize"],
    &["orthographise"],
    &["orthographize"],
    &["orthographise"],
];

pub(crate) static ENTRY_ORTHOGRAPHIZING_12654761895220839085: VariantsMap = [
    &["orthographizing"],
    &["orthographising"],
    &["orthographizing"],
    &["orthographising"],
];

pub(crate) static ENTRY_ORTHOPEDIA_18262137889307359495: VariantsMap = [
    &["orthopedia"],
    &["orthopaedia"],
    &["orthopaedia"],
    &["orthopaedia"],
];

pub(crate) static ENTRY_ORTHOPEDICALLIER_14511187540003790188: VariantsMap = [
    &["orthopedicallier"],
    &["orthopaedicallier"],
    &["orthopaedicallier"],
    &["orthopaedicallier"],
];

pub(crate) static ENTRY_ORTHOPEDICALLIEST_17074628747614047566: VariantsMap = [
    &["orthopedicalliest"],
    &["orthopaedicalliest"],
    &["orthopaedicalliest"],
    &["orthopaedicalliest"],
];

pub(crate) static ENTRY_ORTHOPEDICALLY_2903115659825739595: VariantsMap = [
    &["orthopedically"],
    &["orthopaedically"],
    &["orthopaedically"],
    &["orthopaedically"],
];

pub(crate) static ENTRY_ORTHOPEDICAL_14906990439117593315: VariantsMap = [
    &["orthopedical"],
    &["orthopaedical"],
    &["orthopaedical"],
    &["orthopaedical"],
];

pub(crate) static ENTRY_ORTHOPEDICER_8700148210587724397: VariantsMap = [
    &["orthopedicer"],
    &["orthopaedicer"],
    &["orthopaedicer"],
    &["orthopaedicer"],
];

pub(crate) static ENTRY_ORTHOPEDICEST_17143688116649480026: VariantsMap = [
    &["orthopedicest"],
    &["orthopaedicest"],
    &["orthopaedicest"],
    &["orthopaedicest"],
];

pub(crate) static ENTRY_ORTHOPEDICS_5644296881757016383: VariantsMap = [
    &["orthopedics"],
    &["orthopaedics"],
    &["orthopaedics"],
    &["orthopaedics"],
];

pub(crate) static ENTRY_ORTHOPEDIC_9135417791155998491: VariantsMap = [
    &["orthopedic"],
    &["orthopaedic"],
    &["orthopaedic"],
    &["orthopaedic"],
];

pub(crate) static ENTRY_ORTHOPEDIES_7682512558854583643: VariantsMap = [
    &["orthopedies"],
    &["orthopaedies"],
    &["orthopaedies"],
    &["orthopaedies"],
];

pub(crate) static ENTRY_ORTHOPEDISTS_10438971882131588623: VariantsMap = [
    &["orthopedists"],
    &["orthopaedists"],
    &["orthopaedists"],
    &["orthopaedists"],
];

pub(crate) static ENTRY_ORTHOPEDIST_5359875151039183204: VariantsMap = [
    &["orthopedist"],
    &["orthopaedist"],
    &["orthopaedist"],
    &["orthopaedist"],
];

pub(crate) static ENTRY_ORTHOPEDY_3242137379321021471: VariantsMap = [
    &["orthopedy"],
    &["orthopaedy"],
    &["orthopaedy"],
    &["orthopaedy"],
];

pub(crate) static ENTRY_ORTHOPNEA_11714074503904128615: VariantsMap = [
    &["orthopnea"],
    &["orthopnoea"],
    &["orthopnoea"],
    &["orthopnoea"],
];

pub(crate) static ENTRY_ORTHOPNEIC_8403241060873536790: VariantsMap = [
    &["orthopneic"],
    &["orthopnoeic"],
    &["orthopnoeic"],
    &["orthopnoeic"],
];

pub(crate) static ENTRY_OSTEOPEDION_12694520751355978541: VariantsMap = [
    &["osteopedion"],
    &["osteopaedion"],
    &["osteopaedion"],
    &["osteopaedion"],
];

pub(crate) static ENTRY_OSTRACIZABLES_8680285522090921467: VariantsMap = [
    &["ostracizables"],
    &["ostracisables"],
    &["ostracizables"],
    &["ostracisables"],
];

pub(crate) static ENTRY_OSTRACIZABLE_14526333713080172694: VariantsMap = [
    &["ostracizable"],
    &["ostracisable"],
    &["ostracizable"],
    &["ostracisable"],
];

pub(crate) static ENTRY_OSTRACIZATIONS_16496082549877562752: VariantsMap = [
    &["ostracizations"],
    &["ostracisations"],
    &["ostracizations"],
    &["ostracisations"],
];

pub(crate) static ENTRY_OSTRACIZATION_10262904227601137622: VariantsMap = [
    &["ostracization"],
    &["ostracisation"],
    &["ostracization"],
    &["ostracisation"],
];

pub(crate) static ENTRY_OSTRACIZED_7612075679406147400: VariantsMap = [
    &["ostracized"],
    &["ostracised"],
    &["ostracized"],
    &["ostracised"],
];

pub(crate) static ENTRY_OSTRACIZERS_6019099123580735229: VariantsMap = [
    &["ostracizers"],
    &["ostracisers"],
    &["ostracizers"],
    &["ostracisers"],
];

pub(crate) static ENTRY_OSTRACIZER_17846167188643762430: VariantsMap = [
    &["ostracizer"],
    &["ostraciser"],
    &["ostracizer"],
    &["ostraciser"],
];

pub(crate) static ENTRY_OSTRACIZES_8432128811814349904: VariantsMap = [
    &["ostracizes"],
    &["ostracises"],
    &["ostracizes"],
    &["ostracises"],
];

pub(crate) static ENTRY_OSTRACIZE_17085330350778372244: VariantsMap = [
    &["ostracize"],
    &["ostracise"],
    &["ostracize"],
    &["ostracise"],
];

pub(crate) static ENTRY_OSTRACIZING_15420091366101928007: VariantsMap = [
    &["ostracizing"],
    &["ostracising"],
    &["ostracizing"],
    &["ostracising"],
];

pub(crate) static ENTRY_OTHEMATOMA_4021430710484496451: VariantsMap = [
    &["othematoma"],
    &["othaematoma"],
    &["othaematoma"],
    &["othaematoma"],
];

pub(crate) static ENTRY_OTORRHEA_2158661830949996618: VariantsMap = [
    &["otorrhea"],
    &["otorrhoea"],
    &["otorrhoea"],
    &["otorrhoea"],
];

pub(crate) static ENTRY_OTTOMANIZATIONS_3775785848664183204: VariantsMap = [
    &["ottomanizations"],
    &["ottomanisations"],
    &["ottomanizations"],
    &["ottomanisations"],
];

pub(crate) static ENTRY_OTTOMANIZATION_17741266954268865266: VariantsMap = [
    &["ottomanization"],
    &["ottomanisation"],
    &["ottomanization"],
    &["ottomanisation"],
];

pub(crate) static ENTRY_OTTOMANIZES_15974697179327608437: VariantsMap = [
    &["ottomanizes"],
    &["ottomanises"],
    &["ottomanizes"],
    &["ottomanises"],
];

pub(crate) static ENTRY_OTTOMANIZE_159832188922701678: VariantsMap = [
    &["ottomanize"],
    &["ottomanise"],
    &["ottomanize"],
    &["ottomanise"],
];

pub(crate) static ENTRY_OUTCAVILED_12328360919318201558: VariantsMap = [
    &["outcaviled"],
    &["outcavilled"],
    &["outcavilled"],
    &["outcavilled"],
];

pub(crate) static ENTRY_OUTCAVILING_15276360952144069881: VariantsMap = [
    &["outcaviling"],
    &["outcavilling"],
    &["outcavilling"],
    &["outcavilling"],
];

pub(crate) static ENTRY_OUTCLAMORS_11021687703035987388: VariantsMap = [
    &["outclamors"],
    &["outclamours"],
    &["outclamours"],
    &["outclamours"],
];

pub(crate) static ENTRY_OUTCLAMOR_12156695162252037981: VariantsMap = [
    &["outclamor"],
    &["outclamour"],
    &["outclamour"],
    &["outclamour"],
];

pub(crate) static ENTRY_OUTERNESS_5998443012461676237: VariantsMap = [
    &["outerness"],
    &["outreness"],
    &["outreness"],
    &["outreness"],
];

pub(crate) static ENTRY_OUTHUMORED_5540858708658054473: VariantsMap = [
    &["outhumored"],
    &["outhumoured"],
    &["outhumoured"],
    &["outhumoured"],
];

pub(crate) static ENTRY_OUTHUMORING_1785217446120505648: VariantsMap = [
    &["outhumoring"],
    &["outhumouring"],
    &["outhumouring"],
    &["outhumouring"],
];

pub(crate) static ENTRY_OUTHUMORS_12478246544150481705: VariantsMap = [
    &["outhumors"],
    &["outhumours"],
    &["outhumours"],
    &["outhumours"],
];

pub(crate) static ENTRY_OUTHUMOR_5098392887011091131: VariantsMap = [
    &["outhumor"],
    &["outhumour"],
    &["outhumour"],
    &["outhumour"],
];

pub(crate) static ENTRY_OUTHYPERBOLIZES_10913122944201521464: VariantsMap = [
    &["outhyperbolizes"],
    &["outhyperbolises"],
    &["outhyperbolizes"],
    &["outhyperbolises"],
];

pub(crate) static ENTRY_OUTHYPERBOLIZE_3971022545298044678: VariantsMap = [
    &["outhyperbolize"],
    &["outhyperbolise"],
    &["outhyperbolize"],
    &["outhyperbolise"],
];

pub(crate) static ENTRY_OUTLABORS_12800850946437857772: VariantsMap = [
    &["outlabors"],
    &["outlabours"],
    &["outlabours"],
    &["outlabours"],
];

pub(crate) static ENTRY_OUTLABOR_550919659652857953: VariantsMap = [
    &["outlabor"],
    &["outlabour"],
    &["outlabour"],
    &["outlabour"],
];

pub(crate) static ENTRY_OUTLUSTER_2880546633398900610: VariantsMap = [
    &["outluster"],
    &["outlustre"],
    &["outlustre"],
    &["outlustre"],
];

pub(crate) static ENTRY_OUTMANEUVERED_13287238199156602214: VariantsMap = [
    &["outmaneuvered"],
    &["outmanoeuvred"],
    &["outmanoeuvred"],
    &["outmanoeuvred"],
];

pub(crate) static ENTRY_OUTMANEUVERING_13195408381106573303: VariantsMap = [
    &["outmaneuvering"],
    &["outmanoeuvring"],
    &["outmanoeuvring"],
    &["outmanoeuvring"],
];

pub(crate) static ENTRY_OUTMANEUVERS_5720663247945549588: VariantsMap = [
    &["outmaneuvers"],
    &["outmanoeuvres"],
    &["outmanoeuvres"],
    &["outmanoeuvres"],
];

pub(crate) static ENTRY_OUTMANEUVER_7848671220965370292: VariantsMap = [
    &["outmaneuver"],
    &["outmanoeuvre"],
    &["outmanoeuvre"],
    &["outmanoeuvre"],
];

pub(crate) static ENTRY_OUTRIVALED_6741916464318823957: VariantsMap = [
    &["outrivaled"],
    &["outrivalled"],
    &["outrivalled"],
    &["outrivalled"],
];

pub(crate) static ENTRY_OUTRIVALING_1537376247789926348: VariantsMap = [
    &["outrivaling"],
    &["outrivalling"],
    &["outrivalling"],
    &["outrivalling"],
];

pub(crate) static ENTRY_OUTSAVORING_18392288826685392376: VariantsMap = [
    &["outsavoring"],
    &["outsavouring"],
    &["outsavouring"],
    &["outsavouring"],
];

pub(crate) static ENTRY_OUTSAVORS_2256724312665537907: VariantsMap = [
    &["outsavors"],
    &["outsavours"],
    &["outsavours"],
    &["outsavours"],
];

pub(crate) static ENTRY_OUTSAVOR_6310574424152508054: VariantsMap = [
    &["outsavor"],
    &["outsavour"],
    &["outsavour"],
    &["outsavour"],
];

pub(crate) static ENTRY_OUTSPLENDORS_8648344191546891056: VariantsMap = [
    &["outsplendors"],
    &["outsplendours"],
    &["outsplendours"],
    &["outsplendours"],
];

pub(crate) static ENTRY_OUTSPLENDOR_16970752322673709554: VariantsMap = [
    &["outsplendor"],
    &["outsplendour"],
    &["outsplendour"],
    &["outsplendour"],
];

pub(crate) static ENTRY_OUTTYRANNIZES_2960809863014622911: VariantsMap = [
    &["outtyrannizes"],
    &["outtyrannises"],
    &["outtyrannizes"],
    &["outtyrannises"],
];

pub(crate) static ENTRY_OUTTYRANNIZE_4884886326342063919: VariantsMap = [
    &["outtyrannize"],
    &["outtyrannise"],
    &["outtyrannize"],
    &["outtyrannise"],
];

pub(crate) static ENTRY_OVALIZATIONS_18438883105748297633: VariantsMap = [
    &["ovalizations"],
    &["ovalisations"],
    &["ovalizations"],
    &["ovalisations"],
];

pub(crate) static ENTRY_OVALIZATION_9544511535270367142: VariantsMap = [
    &["ovalization"],
    &["ovalisation"],
    &["ovalization"],
    &["ovalisation"],
];

pub(crate) static ENTRY_OVALIZES_17889836495909704940: VariantsMap =
    [&["ovalizes"], &["ovalises"], &["ovalizes"], &["ovalises"]];

pub(crate) static ENTRY_OVALIZE_5734650805819339558: VariantsMap =
    [&["ovalize"], &["ovalise"], &["ovalize"], &["ovalise"]];

pub(crate) static ENTRY_OVARIECTOMIZED_11885776630981991118: VariantsMap = [
    &["ovariectomized"],
    &["ovariectomised"],
    &["ovariectomized"],
    &["ovariectomised"],
];

pub(crate) static ENTRY_OVERAGONIZES_8549625565440966790: VariantsMap = [
    &["overagonizes"],
    &["overagonises"],
    &["overagonizes"],
    &["overagonises"],
];

pub(crate) static ENTRY_OVERAGONIZE_5802299208135124812: VariantsMap = [
    &["overagonize"],
    &["overagonise"],
    &["overagonize"],
    &["overagonise"],
];

pub(crate) static ENTRY_OVERANALYZES_8889145236404032723: VariantsMap = [
    &["overanalyzes"],
    &["overanalyses"],
    &["overanalyzes"],
    &["overanalyses"],
];

pub(crate) static ENTRY_OVERANALYZE_9859872370805897006: VariantsMap = [
    &["overanalyze"],
    &["overanalyse"],
    &["overanalyze"],
    &["overanalyse"],
];

pub(crate) static ENTRY_OVERBRUTALIZES_9064339525061788720: VariantsMap = [
    &["overbrutalizes"],
    &["overbrutalises"],
    &["overbrutalizes"],
    &["overbrutalises"],
];

pub(crate) static ENTRY_OVERBRUTALIZE_4691228052029488558: VariantsMap = [
    &["overbrutalize"],
    &["overbrutalise"],
    &["overbrutalize"],
    &["overbrutalise"],
];

pub(crate) static ENTRY_OVERCAPITALIZATIONS_9484255788644671052: VariantsMap = [
    &["overcapitalizations"],
    &["overcapitalisations"],
    &["overcapitalizations"],
    &["overcapitalisations"],
];

pub(crate) static ENTRY_OVERCAPITALIZATION_1715510714642089999: VariantsMap = [
    &["overcapitalization"],
    &["overcapitalisation"],
    &["overcapitalization"],
    &["overcapitalisation"],
];

pub(crate) static ENTRY_OVERCAPITALIZED_15472336958201224118: VariantsMap = [
    &["overcapitalized"],
    &["overcapitalised"],
    &["overcapitalized"],
    &["overcapitalised"],
];

pub(crate) static ENTRY_OVERCAPITALIZES_12752896418006053471: VariantsMap = [
    &["overcapitalizes"],
    &["overcapitalises"],
    &["overcapitalizes"],
    &["overcapitalises"],
];

pub(crate) static ENTRY_OVERCAPITALIZE_2424125715885515013: VariantsMap = [
    &["overcapitalize"],
    &["overcapitalise"],
    &["overcapitalize"],
    &["overcapitalise"],
];

pub(crate) static ENTRY_OVERCAPITALIZING_3902235346884105289: VariantsMap = [
    &["overcapitalizing"],
    &["overcapitalising"],
    &["overcapitalizing"],
    &["overcapitalising"],
];

pub(crate) static ENTRY_OVERCENTRALIZATIONS_13210816604166532536: VariantsMap = [
    &["overcentralizations"],
    &["overcentralisations"],
    &["overcentralizations"],
    &["overcentralisations"],
];

pub(crate) static ENTRY_OVERCENTRALIZATION_7417308276149240356: VariantsMap = [
    &["overcentralization"],
    &["overcentralisation"],
    &["overcentralization"],
    &["overcentralisation"],
];

pub(crate) static ENTRY_OVERCENTRALIZES_6657866211820141951: VariantsMap = [
    &["overcentralizes"],
    &["overcentralises"],
    &["overcentralizes"],
    &["overcentralises"],
];

pub(crate) static ENTRY_OVERCENTRALIZE_3364160969428038703: VariantsMap = [
    &["overcentralize"],
    &["overcentralise"],
    &["overcentralize"],
    &["overcentralise"],
];

pub(crate) static ENTRY_OVERCIVILIZATIONS_7279117740363755118: VariantsMap = [
    &["overcivilizations"],
    &["overcivilisations"],
    &["overcivilizations"],
    &["overcivilisations"],
];

pub(crate) static ENTRY_OVERCIVILIZATION_1403057627715817017: VariantsMap = [
    &["overcivilization"],
    &["overcivilisation"],
    &["overcivilization"],
    &["overcivilisation"],
];

pub(crate) static ENTRY_OVERCIVILIZES_6686378897410983044: VariantsMap = [
    &["overcivilizes"],
    &["overcivilises"],
    &["overcivilizes"],
    &["overcivilises"],
];

pub(crate) static ENTRY_OVERCIVILIZE_4956758060913570060: VariantsMap = [
    &["overcivilize"],
    &["overcivilise"],
    &["overcivilize"],
    &["overcivilise"],
];

pub(crate) static ENTRY_OVERCLAMORS_12504082063740601729: VariantsMap = [
    &["overclamors"],
    &["overclamours"],
    &["overclamours"],
    &["overclamours"],
];

pub(crate) static ENTRY_OVERCLAMOR_10459408943570121640: VariantsMap = [
    &["overclamor"],
    &["overclamour"],
    &["overclamour"],
    &["overclamour"],
];

pub(crate) static ENTRY_OVERCOLORATION_12100936843984700781: VariantsMap = [
    &["overcoloration"],
    &["overcolouration"],
    &["overcolouration"],
    &["overcolouration"],
];

pub(crate) static ENTRY_OVERCOLORING_1527032230883157274: VariantsMap = [
    &["overcoloring"],
    &["overcolouring"],
    &["overcolouring"],
    &["overcolouring"],
];

pub(crate) static ENTRY_OVERCOLORS_13972470541416809937: VariantsMap = [
    &["overcolors"],
    &["overcolours"],
    &["overcolours"],
    &["overcolours"],
];

pub(crate) static ENTRY_OVERCOLOR_6668121705049321640: VariantsMap = [
    &["overcolor"],
    &["overcolour"],
    &["overcolour"],
    &["overcolour"],
];

pub(crate) static ENTRY_OVERCRITICIZES_7375544340563907361: VariantsMap = [
    &["overcriticizes"],
    &["overcriticises"],
    &["overcriticizes"],
    &["overcriticises"],
];

pub(crate) static ENTRY_OVERCRITICIZE_11527670059794563047: VariantsMap = [
    &["overcriticize"],
    &["overcriticise"],
    &["overcriticize"],
    &["overcriticise"],
];

pub(crate) static ENTRY_OVERDOCTRINIZES_12501026687501771984: VariantsMap = [
    &["overdoctrinizes"],
    &["overdoctrinises"],
    &["overdoctrinizes"],
    &["overdoctrinises"],
];

pub(crate) static ENTRY_OVERDOCTRINIZE_6756558981699337418: VariantsMap = [
    &["overdoctrinize"],
    &["overdoctrinise"],
    &["overdoctrinize"],
    &["overdoctrinise"],
];

pub(crate) static ENTRY_OVERDRAMATIZED_5081815422525179522: VariantsMap = [
    &["overdramatized"],
    &["overdramatised"],
    &["overdramatized"],
    &["overdramatised"],
];

pub(crate) static ENTRY_OVERDRAMATIZES_6361099448793870473: VariantsMap = [
    &["overdramatizes"],
    &["overdramatises"],
    &["overdramatizes"],
    &["overdramatises"],
];

pub(crate) static ENTRY_OVERDRAMATIZE_3991296625721922524: VariantsMap = [
    &["overdramatize"],
    &["overdramatise"],
    &["overdramatize"],
    &["overdramatise"],
];

pub(crate) static ENTRY_OVERDRAMATIZING_14402358516227867882: VariantsMap = [
    &["overdramatizing"],
    &["overdramatising"],
    &["overdramatizing"],
    &["overdramatising"],
];

pub(crate) static ENTRY_OVEREMOTIONALIZES_8370132205966048150: VariantsMap = [
    &["overemotionalizes"],
    &["overemotionalises"],
    &["overemotionalizes"],
    &["overemotionalises"],
];

pub(crate) static ENTRY_OVEREMOTIONALIZE_3169525508710692200: VariantsMap = [
    &["overemotionalize"],
    &["overemotionalise"],
    &["overemotionalize"],
    &["overemotionalise"],
];

pub(crate) static ENTRY_OVEREMPHASIZED_10786070739152462413: VariantsMap = [
    &["overemphasized"],
    &["overemphasised"],
    &["overemphasized"],
    &["overemphasised"],
];

pub(crate) static ENTRY_OVEREMPHASIZERS_2232850070738046753: VariantsMap = [
    &["overemphasizers"],
    &["overemphasisers"],
    &["overemphasizers"],
    &["overemphasisers"],
];

pub(crate) static ENTRY_OVEREMPHASIZER_3909831921528574703: VariantsMap = [
    &["overemphasizer"],
    &["overemphasiser"],
    &["overemphasizer"],
    &["overemphasiser"],
];

pub(crate) static ENTRY_OVEREMPHASIZES_3357752816724585460: VariantsMap = [
    &["overemphasizes"],
    &["overemphasises"],
    &["overemphasizes"],
    &["overemphasises"],
];

pub(crate) static ENTRY_OVEREMPHASIZE_9555654201029285273: VariantsMap = [
    &["overemphasize"],
    &["overemphasise"],
    &["overemphasize"],
    &["overemphasise"],
];

pub(crate) static ENTRY_OVEREMPHASIZING_5600939134455436136: VariantsMap = [
    &["overemphasizing"],
    &["overemphasising"],
    &["overemphasizing"],
    &["overemphasising"],
];

pub(crate) static ENTRY_OVERFAVORABLES_13349672237716253716: VariantsMap = [
    &["overfavorables"],
    &["overfavourables"],
    &["overfavourables"],
    &["overfavourables"],
];

pub(crate) static ENTRY_OVERFAVORABLE_2253479099213937128: VariantsMap = [
    &["overfavorable"],
    &["overfavourable"],
    &["overfavourable"],
    &["overfavourable"],
];

pub(crate) static ENTRY_OVERFAVORABLIES_12931915139716470778: VariantsMap = [
    &["overfavorablies"],
    &["overfavourablies"],
    &["overfavourablies"],
    &["overfavourablies"],
];

pub(crate) static ENTRY_OVERFAVORABLY_9201409646497245624: VariantsMap = [
    &["overfavorably"],
    &["overfavourably"],
    &["overfavourably"],
    &["overfavourably"],
];

pub(crate) static ENTRY_OVERFAVORS_7531387216996007889: VariantsMap = [
    &["overfavors"],
    &["overfavours"],
    &["overfavours"],
    &["overfavours"],
];

pub(crate) static ENTRY_OVERFAVOR_2988640921037745317: VariantsMap = [
    &["overfavor"],
    &["overfavour"],
    &["overfavour"],
    &["overfavour"],
];

pub(crate) static ENTRY_OVERFERTILIZATION_15333294448468078644: VariantsMap = [
    &["overfertilization"],
    &["overfertilisation"],
    &["overfertilization"],
    &["overfertilisation"],
];

pub(crate) static ENTRY_OVERGENERALIZED_8841918834486724985: VariantsMap = [
    &["overgeneralized"],
    &["overgeneralised"],
    &["overgeneralized"],
    &["overgeneralised"],
];

pub(crate) static ENTRY_OVERGENERALIZES_5216897570369112390: VariantsMap = [
    &["overgeneralizes"],
    &["overgeneralises"],
    &["overgeneralizes"],
    &["overgeneralises"],
];

pub(crate) static ENTRY_OVERGENERALIZE_12617960222070124101: VariantsMap = [
    &["overgeneralize"],
    &["overgeneralise"],
    &["overgeneralize"],
    &["overgeneralise"],
];

pub(crate) static ENTRY_OVERGENERALIZING_10418526262017180256: VariantsMap = [
    &["overgeneralizing"],
    &["overgeneralising"],
    &["overgeneralizing"],
    &["overgeneralising"],
];

pub(crate) static ENTRY_OVERHONORS_10103397574554573266: VariantsMap = [
    &["overhonors"],
    &["overhonours"],
    &["overhonours"],
    &["overhonours"],
];

pub(crate) static ENTRY_OVERHONOR_7235171621843361158: VariantsMap = [
    &["overhonor"],
    &["overhonour"],
    &["overhonour"],
    &["overhonour"],
];

pub(crate) static ENTRY_OVERHUMANIZES_14873101185551055589: VariantsMap = [
    &["overhumanizes"],
    &["overhumanises"],
    &["overhumanizes"],
    &["overhumanises"],
];

pub(crate) static ENTRY_OVERHUMANIZE_13455822973320239965: VariantsMap = [
    &["overhumanize"],
    &["overhumanise"],
    &["overhumanize"],
    &["overhumanise"],
];

pub(crate) static ENTRY_OVERINDUSTRIALIZATIONS_2479660567106903260: VariantsMap = [
    &["overindustrializations"],
    &["overindustrialisations"],
    &["overindustrializations"],
    &["overindustrialisations"],
];

pub(crate) static ENTRY_OVERINDUSTRIALIZATION_16044744419846949421: VariantsMap = [
    &["overindustrialization"],
    &["overindustrialisation"],
    &["overindustrialization"],
    &["overindustrialisation"],
];

pub(crate) static ENTRY_OVERINDUSTRIALIZES_8736294717956607405: VariantsMap = [
    &["overindustrializes"],
    &["overindustrialises"],
    &["overindustrializes"],
    &["overindustrialises"],
];

pub(crate) static ENTRY_OVERINDUSTRIALIZE_7348456951187570038: VariantsMap = [
    &["overindustrialize"],
    &["overindustrialise"],
    &["overindustrialize"],
    &["overindustrialise"],
];

pub(crate) static ENTRY_OVERJUDGMENTS_16817152636455142022: VariantsMap = [
    &["overjudgments"],
    &["overjudgements"],
    &["overjudgements"],
    &["overjudgements"],
];

pub(crate) static ENTRY_OVERJUDGMENT_12325219415629312934: VariantsMap = [
    &["overjudgment"],
    &["overjudgement"],
    &["overjudgement"],
    &["overjudgement"],
];

pub(crate) static ENTRY_OVERLABORED_2757049959631908045: VariantsMap = [
    &["overlabored"],
    &["overlaboured"],
    &["overlaboured"],
    &["overlaboured"],
];

pub(crate) static ENTRY_OVERLABORING_15266943753097543372: VariantsMap = [
    &["overlaboring"],
    &["overlabouring"],
    &["overlabouring"],
    &["overlabouring"],
];

pub(crate) static ENTRY_OVERLABORS_15107230618633371659: VariantsMap = [
    &["overlabors"],
    &["overlabours"],
    &["overlabours"],
    &["overlabours"],
];

pub(crate) static ENTRY_OVERLABOR_4761949762410556291: VariantsMap = [
    &["overlabor"],
    &["overlabour"],
    &["overlabour"],
    &["overlabour"],
];

pub(crate) static ENTRY_OVERNATIONALIZATIONS_16720417975201334473: VariantsMap = [
    &["overnationalizations"],
    &["overnationalisations"],
    &["overnationalizations"],
    &["overnationalisations"],
];

pub(crate) static ENTRY_OVERNATIONALIZATION_16427980336477721392: VariantsMap = [
    &["overnationalization"],
    &["overnationalisation"],
    &["overnationalization"],
    &["overnationalisation"],
];

pub(crate) static ENTRY_OVERRAPTURIZES_4064312914205956145: VariantsMap = [
    &["overrapturizes"],
    &["overrapturises"],
    &["overrapturizes"],
    &["overrapturises"],
];

pub(crate) static ENTRY_OVERRAPTURIZE_3350211032805151786: VariantsMap = [
    &["overrapturize"],
    &["overrapturise"],
    &["overrapturize"],
    &["overrapturise"],
];

pub(crate) static ENTRY_OVERRATIONALIZES_1263206603271065559: VariantsMap = [
    &["overrationalizes"],
    &["overrationalises"],
    &["overrationalizes"],
    &["overrationalises"],
];

pub(crate) static ENTRY_OVERRATIONALIZE_14162691183665004674: VariantsMap = [
    &["overrationalize"],
    &["overrationalise"],
    &["overrationalize"],
    &["overrationalise"],
];

pub(crate) static ENTRY_OVERSENTIMENTALIZES_10334951405364037229: VariantsMap = [
    &["oversentimentalizes"],
    &["oversentimentalises"],
    &["oversentimentalizes"],
    &["oversentimentalises"],
];

pub(crate) static ENTRY_OVERSENTIMENTALIZE_2920069227773965746: VariantsMap = [
    &["oversentimentalize"],
    &["oversentimentalise"],
    &["oversentimentalize"],
    &["oversentimentalise"],
];

pub(crate) static ENTRY_OVERSPECIALIZATIONS_602774670593965924: VariantsMap = [
    &["overspecializations"],
    &["overspecialisations"],
    &["overspecializations"],
    &["overspecialisations"],
];

pub(crate) static ENTRY_OVERSPECIALIZATION_9400215891169659422: VariantsMap = [
    &["overspecialization"],
    &["overspecialisation"],
    &["overspecialization"],
    &["overspecialisation"],
];

pub(crate) static ENTRY_OVERSPECIALIZED_10776456971324744822: VariantsMap = [
    &["overspecialized"],
    &["overspecialised"],
    &["overspecialized"],
    &["overspecialised"],
];

pub(crate) static ENTRY_OVERSPECIALIZES_5323874136922790809: VariantsMap = [
    &["overspecializes"],
    &["overspecialises"],
    &["overspecializes"],
    &["overspecialises"],
];

pub(crate) static ENTRY_OVERSPECIALIZE_9155848039135346764: VariantsMap = [
    &["overspecialize"],
    &["overspecialise"],
    &["overspecialize"],
    &["overspecialise"],
];

pub(crate) static ENTRY_OVERSPECIALIZING_13810584292392678750: VariantsMap = [
    &["overspecializing"],
    &["overspecialising"],
    &["overspecializing"],
    &["overspecialising"],
];

pub(crate) static ENTRY_OVERSYSTEMATIZES_7828674482109481491: VariantsMap = [
    &["oversystematizes"],
    &["oversystematises"],
    &["oversystematizes"],
    &["oversystematises"],
];

pub(crate) static ENTRY_OVERSYSTEMATIZE_15317981286987240656: VariantsMap = [
    &["oversystematize"],
    &["oversystematise"],
    &["oversystematize"],
    &["oversystematise"],
];

pub(crate) static ENTRY_OVERUNIONIZEDS_12564195815119338339: VariantsMap = [
    &["overunionizeds"],
    &["overunioniseds"],
    &["overunionizeds"],
    &["overunioniseds"],
];

pub(crate) static ENTRY_OVERUNIONIZED_4047937475394439730: VariantsMap = [
    &["overunionized"],
    &["overunionised"],
    &["overunionized"],
    &["overunionised"],
];

pub(crate) static ENTRY_OVERURBANIZATIONS_16844312525315293215: VariantsMap = [
    &["overurbanizations"],
    &["overurbanisations"],
    &["overurbanizations"],
    &["overurbanisations"],
];

pub(crate) static ENTRY_OVERURBANIZATION_5193813995283903294: VariantsMap = [
    &["overurbanization"],
    &["overurbanisation"],
    &["overurbanization"],
    &["overurbanisation"],
];

pub(crate) static ENTRY_OVERUTILIZATION_11909002111381917615: VariantsMap = [
    &["overutilization"],
    &["overutilisation"],
    &["overutilization"],
    &["overutilisation"],
];

pub(crate) static ENTRY_OVERWOMANIZES_14746928621471259508: VariantsMap = [
    &["overwomanizes"],
    &["overwomanises"],
    &["overwomanizes"],
    &["overwomanises"],
];

pub(crate) static ENTRY_OVERWOMANIZE_200946611941560951: VariantsMap = [
    &["overwomanize"],
    &["overwomanise"],
    &["overwomanize"],
    &["overwomanise"],
];

pub(crate) static ENTRY_OWERCOME_7825693961556665659: VariantsMap =
    [&["owercome"], &["owrecome"], &["owrecome"], &["owrecome"]];

pub(crate) static ENTRY_OWERWORD_11634074558985348166: VariantsMap =
    [&["owerword"], &["owreword"], &["owreword"], &["owreword"]];

pub(crate) static ENTRY_OWER_3833680922718495358: VariantsMap =
    [&["ower"], &["owre"], &["owre"], &["owre"]];

pub(crate) static ENTRY_OXALEMIA_8359876312463994118: VariantsMap = [
    &["oxalemia"],
    &["oxalaemia"],
    &["oxalaemia"],
    &["oxalaemia"],
];

pub(crate) static ENTRY_OXIDIZABILITIES_14142108330730081987: VariantsMap = [
    &["oxidizabilities"],
    &["oxidisabilities"],
    &["oxidizabilities"],
    &["oxidisabilities"],
];

pub(crate) static ENTRY_OXIDIZABILITY_17098615307353278078: VariantsMap = [
    &["oxidizability"],
    &["oxidisability"],
    &["oxidizability"],
    &["oxidisability"],
];

pub(crate) static ENTRY_OXIDIZABLES_14774967969017909671: VariantsMap = [
    &["oxidizables"],
    &["oxidisables"],
    &["oxidizables"],
    &["oxidisables"],
];

pub(crate) static ENTRY_OXIDIZABLE_13099591425208273704: VariantsMap = [
    &["oxidizable"],
    &["oxidisable"],
    &["oxidizable"],
    &["oxidisable"],
];

pub(crate) static ENTRY_OXIDIZATIONS_18384605206557692188: VariantsMap = [
    &["oxidizations"],
    &["oxidisations"],
    &["oxidizations"],
    &["oxidisations"],
];

pub(crate) static ENTRY_OXIDIZATION_8640581345639188227: VariantsMap = [
    &["oxidization"],
    &["oxidisation"],
    &["oxidization"],
    &["oxidisation"],
];

pub(crate) static ENTRY_OXIDIZED_863679133104485205: VariantsMap =
    [&["oxidized"], &["oxidised"], &["oxidized"], &["oxidised"]];

pub(crate) static ENTRY_OXIDIZEMENTS_2713172646044852097: VariantsMap = [
    &["oxidizements"],
    &["oxidisements"],
    &["oxidizements"],
    &["oxidisements"],
];

pub(crate) static ENTRY_OXIDIZEMENT_3824208269824742167: VariantsMap = [
    &["oxidizement"],
    &["oxidisement"],
    &["oxidizement"],
    &["oxidisement"],
];

pub(crate) static ENTRY_OXIDIZERS_2504217545277966354: VariantsMap = [
    &["oxidizers"],
    &["oxidisers"],
    &["oxidizers"],
    &["oxidisers"],
];

pub(crate) static ENTRY_OXIDIZER_8663348272113963982: VariantsMap =
    [&["oxidizer"], &["oxidiser"], &["oxidizer"], &["oxidiser"]];

pub(crate) static ENTRY_OXIDIZES_12570513258219136803: VariantsMap =
    [&["oxidizes"], &["oxidises"], &["oxidizes"], &["oxidises"]];

pub(crate) static ENTRY_OXIDIZE_14098521888186084656: VariantsMap =
    [&["oxidize"], &["oxidise"], &["oxidize"], &["oxidise"]];

pub(crate) static ENTRY_OXIDIZINGS_11236022938943463443: VariantsMap = [
    &["oxidizings"],
    &["oxidisings"],
    &["oxidizings"],
    &["oxidisings"],
];

pub(crate) static ENTRY_OXIDIZING_16524857865197942594: VariantsMap = [
    &["oxidizing"],
    &["oxidising"],
    &["oxidizing"],
    &["oxidising"],
];

pub(crate) static ENTRY_OXYGENIZABLES_4594746039702721234: VariantsMap = [
    &["oxygenizables"],
    &["oxygenisables"],
    &["oxygenizables"],
    &["oxygenisables"],
];

pub(crate) static ENTRY_OXYGENIZABLE_17479103681379009352: VariantsMap = [
    &["oxygenizable"],
    &["oxygenisable"],
    &["oxygenizable"],
    &["oxygenisable"],
];

pub(crate) static ENTRY_OXYGENIZED_12741796950494986234: VariantsMap = [
    &["oxygenized"],
    &["oxygenised"],
    &["oxygenized"],
    &["oxygenised"],
];

pub(crate) static ENTRY_OXYGENIZEMENTS_6061271087856140584: VariantsMap = [
    &["oxygenizements"],
    &["oxygenisements"],
    &["oxygenizements"],
    &["oxygenisements"],
];

pub(crate) static ENTRY_OXYGENIZEMENT_15662309540642399495: VariantsMap = [
    &["oxygenizement"],
    &["oxygenisement"],
    &["oxygenizement"],
    &["oxygenisement"],
];

pub(crate) static ENTRY_OXYGENIZERS_8437931482323607770: VariantsMap = [
    &["oxygenizers"],
    &["oxygenisers"],
    &["oxygenizers"],
    &["oxygenisers"],
];

pub(crate) static ENTRY_OXYGENIZER_1558268197723031493: VariantsMap = [
    &["oxygenizer"],
    &["oxygeniser"],
    &["oxygenizer"],
    &["oxygeniser"],
];

pub(crate) static ENTRY_OXYGENIZES_12301201819705648739: VariantsMap = [
    &["oxygenizes"],
    &["oxygenises"],
    &["oxygenizes"],
    &["oxygenises"],
];

pub(crate) static ENTRY_OXYGENIZE_17957343902815945531: VariantsMap = [
    &["oxygenize"],
    &["oxygenise"],
    &["oxygenize"],
    &["oxygenise"],
];

pub(crate) static ENTRY_OXYGENIZING_14936091316073194120: VariantsMap = [
    &["oxygenizing"],
    &["oxygenising"],
    &["oxygenizing"],
    &["oxygenising"],
];

pub(crate) static ENTRY_OXYHEMATIN_1679679880778856911: VariantsMap = [
    &["oxyhematin"],
    &["oxyhaematin"],
    &["oxyhaematin"],
    &["oxyhaematin"],
];

pub(crate) static ENTRY_OXYHEMOGLOBINS_3513395291969542293: VariantsMap = [
    &["oxyhemoglobins"],
    &["oxyhaemoglobins"],
    &["oxyhaemoglobins"],
    &["oxyhaemoglobins"],
];

pub(crate) static ENTRY_OXYHEMOGLOBIN_9033247027705350750: VariantsMap = [
    &["oxyhemoglobin"],
    &["oxyhaemoglobin"],
    &["oxyhaemoglobin"],
    &["oxyhaemoglobin"],
];

pub(crate) static ENTRY_OZENA_12738332874299794404: VariantsMap =
    [&["ozena"], &["ozoena"], &["ozoena"], &["ozoena"]];

pub(crate) static ENTRY_OZENA_4969729645065668012: VariantsMap =
    [&["ozena"], &["ozaena"], &["ozaena"], &["ozaena"]];

pub(crate) static ENTRY_OZONIZATIONS_502893906779520668: VariantsMap = [
    &["ozonizations"],
    &["ozonisations"],
    &["ozonizations"],
    &["ozonisations"],
];

pub(crate) static ENTRY_OZONIZATION_3896308943103224579: VariantsMap = [
    &["ozonization"],
    &["ozonisation"],
    &["ozonization"],
    &["ozonisation"],
];

pub(crate) static ENTRY_OZONIZED_11239117268275093032: VariantsMap =
    [&["ozonized"], &["ozonised"], &["ozonized"], &["ozonised"]];

pub(crate) static ENTRY_OZONIZERS_3033483267089639714: VariantsMap = [
    &["ozonizers"],
    &["ozonisers"],
    &["ozonizers"],
    &["ozonisers"],
];

pub(crate) static ENTRY_OZONIZER_3300785248284358800: VariantsMap =
    [&["ozonizer"], &["ozoniser"], &["ozonizer"], &["ozoniser"]];

pub(crate) static ENTRY_OZONIZES_6522169179054787769: VariantsMap =
    [&["ozonizes"], &["ozonises"], &["ozonizes"], &["ozonises"]];

pub(crate) static ENTRY_OZONIZE_17942847956579128151: VariantsMap =
    [&["ozonize"], &["ozonise"], &["ozonize"], &["ozonise"]];

pub(crate) static ENTRY_OZONIZING_4927916636257465073: VariantsMap = [
    &["ozonizing"],
    &["ozonising"],
    &["ozonizing"],
    &["ozonising"],
];

pub(crate) static ENTRY_PACHYEMIA_2167378922137939193: VariantsMap = [
    &["pachyemia"],
    &["pachyaemia"],
    &["pachyaemia"],
    &["pachyaemia"],
];

pub(crate) static ENTRY_PACHYHEMIA_8064242457811444804: VariantsMap = [
    &["pachyhemia"],
    &["pachyhaemia"],
    &["pachyhaemia"],
    &["pachyhaemia"],
];

pub(crate) static ENTRY_PACKETIZATION_16208754302696410419: VariantsMap = [
    &["packetization"],
    &["packetisation"],
    &["packetization"],
    &["packetisation"],
];

pub(crate) static ENTRY_PACKETIZED_8899832600620412912: VariantsMap = [
    &["packetized"],
    &["packetised"],
    &["packetized"],
    &["packetised"],
];

pub(crate) static ENTRY_PACKETIZERS_6524285336219061046: VariantsMap = [
    &["packetizers"],
    &["packetisers"],
    &["packetizers"],
    &["packetisers"],
];

pub(crate) static ENTRY_PACKETIZER_16605776441937490688: VariantsMap = [
    &["packetizer"],
    &["packetiser"],
    &["packetizer"],
    &["packetiser"],
];

pub(crate) static ENTRY_PACKETIZES_2813822036312110356: VariantsMap = [
    &["packetizes"],
    &["packetises"],
    &["packetizes"],
    &["packetises"],
];

pub(crate) static ENTRY_PACKETIZE_5972448088884110761: VariantsMap = [
    &["packetize"],
    &["packetise"],
    &["packetize"],
    &["packetise"],
];

pub(crate) static ENTRY_PACKETIZING_11521124697410978844: VariantsMap = [
    &["packetizing"],
    &["packetising"],
    &["packetizing"],
    &["packetising"],
];

pub(crate) static ENTRY_PAEANIZES_5368855730242432342: VariantsMap = [
    &["paeanizes"],
    &["paeanises"],
    &["paeanizes"],
    &["paeanises"],
];

pub(crate) static ENTRY_PAEANIZE_8806779712541481579: VariantsMap =
    [&["paeanize"], &["paeanise"], &["paeanize"], &["paeanise"]];

pub(crate) static ENTRY_PAGANIZATIONS_14987195852717725095: VariantsMap = [
    &["paganizations"],
    &["paganisations"],
    &["paganizations"],
    &["paganisations"],
];

pub(crate) static ENTRY_PAGANIZATION_6403498613271915860: VariantsMap = [
    &["paganization"],
    &["paganisation"],
    &["paganization"],
    &["paganisation"],
];

pub(crate) static ENTRY_PAGANIZED_16558435393352092294: VariantsMap = [
    &["paganized"],
    &["paganised"],
    &["paganized"],
    &["paganised"],
];

pub(crate) static ENTRY_PAGANIZERS_2218453433509959012: VariantsMap = [
    &["paganizers"],
    &["paganisers"],
    &["paganizers"],
    &["paganisers"],
];

pub(crate) static ENTRY_PAGANIZER_6489619638171822325: VariantsMap = [
    &["paganizer"],
    &["paganiser"],
    &["paganizer"],
    &["paganiser"],
];

pub(crate) static ENTRY_PAGANIZES_16725516347835135653: VariantsMap = [
    &["paganizes"],
    &["paganises"],
    &["paganizes"],
    &["paganises"],
];

pub(crate) static ENTRY_PAGANIZE_3365967695778839525: VariantsMap =
    [&["paganize"], &["paganise"], &["paganize"], &["paganise"]];

pub(crate) static ENTRY_PAGANIZING_17172254602210790902: VariantsMap = [
    &["paganizing"],
    &["paganising"],
    &["paganizing"],
    &["paganising"],
];

pub(crate) static ENTRY_PAGINE_14470123767926692710: VariantsMap =
    [&["pagine"], &["paginae"], &["paginae"], &["paginae"]];

pub(crate) static ENTRY_PAJAMAED_5631330919975772121: VariantsMap = [
    &["pajamaed"],
    &["pyjamased"],
    &["pyjamased"],
    &["pyjamased"],
];

pub(crate) static ENTRY_PAJAMAS_2981078080473633806: VariantsMap =
    [&["pajamas"], &["pyjamas"], &["pyjamas"], &["pyjamas"]];

pub(crate) static ENTRY_PAJAMA_6036010499883376406: VariantsMap =
    [&["pajama"], &["pyjama"], &["pyjama"], &["pyjama"]];

pub(crate) static ENTRY_PALAME_12060485423001427334: VariantsMap =
    [&["palame"], &["palamae"], &["palamae"], &["palamae"]];

pub(crate) static ENTRY_PALATALIZATIONS_7795389490222118981: VariantsMap = [
    &["palatalizations"],
    &["palatalisations"],
    &["palatalizations"],
    &["palatalisations"],
];

pub(crate) static ENTRY_PALATALIZATION_2924504919577641238: VariantsMap = [
    &["palatalization"],
    &["palatalisation"],
    &["palatalization"],
    &["palatalisation"],
];

pub(crate) static ENTRY_PALATALIZED_17714539904743727901: VariantsMap = [
    &["palatalized"],
    &["palatalised"],
    &["palatalized"],
    &["palatalised"],
];

pub(crate) static ENTRY_PALATALIZES_14289910770533134417: VariantsMap = [
    &["palatalizes"],
    &["palatalises"],
    &["palatalizes"],
    &["palatalises"],
];

pub(crate) static ENTRY_PALATALIZE_16275238324442191490: VariantsMap = [
    &["palatalize"],
    &["palatalise"],
    &["palatalize"],
    &["palatalise"],
];

pub(crate) static ENTRY_PALATALIZING_3515198110356997816: VariantsMap = [
    &["palatalizing"],
    &["palatalising"],
    &["palatalizing"],
    &["palatalising"],
];

pub(crate) static ENTRY_PALATIZATIONS_17121847778628207370: VariantsMap = [
    &["palatizations"],
    &["palatisations"],
    &["palatizations"],
    &["palatisations"],
];

pub(crate) static ENTRY_PALATIZATION_15642824953699641821: VariantsMap = [
    &["palatization"],
    &["palatisation"],
    &["palatization"],
    &["palatisation"],
];

pub(crate) static ENTRY_PALATIZES_14141187893507819752: VariantsMap = [
    &["palatizes"],
    &["palatises"],
    &["palatizes"],
    &["palatises"],
];

pub(crate) static ENTRY_PALATIZE_5498275993725862299: VariantsMap =
    [&["palatize"], &["palatise"], &["palatize"], &["palatise"]];

pub(crate) static ENTRY_PALEANTHROPIC_5128209237270456861: VariantsMap = [
    &["paleanthropic"],
    &["palaeanthropic"],
    &["palaeanthropic"],
    &["palaeanthropic"],
];

pub(crate) static ENTRY_PALEARCTIC_10203452201396606217: VariantsMap = [
    &["palearctic"],
    &["palaearctic"],
    &["palearctic"],
    &["palaearctic"],
];

pub(crate) static ENTRY_PALEENCEPHALON_17919159965626856547: VariantsMap = [
    &["paleencephalon"],
    &["palaeencephalon"],
    &["palaeencephalon"],
    &["palaeencephalon"],
];

pub(crate) static ENTRY_PALEENTOMOLOGY_9853812566754690275: VariantsMap = [
    &["paleentomology"],
    &["palaeentomology"],
    &["palaeentomology"],
    &["palaeentomology"],
];

pub(crate) static ENTRY_PALEETHNOLOGICAL_10389145458276668226: VariantsMap = [
    &["paleethnological"],
    &["palaeethnological"],
    &["palaeethnological"],
    &["palaeethnological"],
];

pub(crate) static ENTRY_PALEETHNOLOGIC_14949290099499270450: VariantsMap = [
    &["paleethnologic"],
    &["palaeethnologic"],
    &["palaeethnologic"],
    &["palaeethnologic"],
];

pub(crate) static ENTRY_PALEETHNOLOGIST_16035307690789850776: VariantsMap = [
    &["paleethnologist"],
    &["palaeethnologist"],
    &["palaeethnologist"],
    &["palaeethnologist"],
];

pub(crate) static ENTRY_PALEETHNOLOGY_8564666823564344109: VariantsMap = [
    &["paleethnology"],
    &["palaeethnology"],
    &["palaeethnology"],
    &["palaeethnology"],
];

pub(crate) static ENTRY_PALEICHTHYOLOGIST_18367699513737958699: VariantsMap = [
    &["paleichthyologist"],
    &["palaeichthyologist"],
    &["palaeichthyologist"],
    &["palaeichthyologist"],
];

pub(crate) static ENTRY_PALEICHTHYOLOGY_8302040066162628624: VariantsMap = [
    &["paleichthyology"],
    &["palaeichthyology"],
    &["palaeichthyology"],
    &["palaeichthyology"],
];

pub(crate) static ENTRY_PALEOALCHEMICAL_15713650654596147408: VariantsMap = [
    &["paleoalchemical"],
    &["palaeoalchemical"],
    &["palaeoalchemical"],
    &["palaeoalchemical"],
];

pub(crate) static ENTRY_PALEOANTHROPIC_5954958120113844205: VariantsMap = [
    &["paleoanthropic"],
    &["palaeoanthropic"],
    &["palaeoanthropic"],
    &["palaeoanthropic"],
];

pub(crate) static ENTRY_PALEOANTHROPOGRAPHY_9998212461382827548: VariantsMap = [
    &["paleoanthropography"],
    &["palaeoanthropography"],
    &["palaeoanthropography"],
    &["palaeoanthropography"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGICAL_18192493413636001900: VariantsMap = [
    &["paleoanthropological"],
    &["palaeoanthropological"],
    &["palaeoanthropological"],
    &["palaeoanthropological"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGIES_8205118955898337795: VariantsMap = [
    &["paleoanthropologies"],
    &["palaeoanthropologies"],
    &["palaeoanthropologies"],
    &["palaeoanthropologies"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGISTS_4369638882884050551: VariantsMap = [
    &["paleoanthropologists"],
    &["palaeoanthropologists"],
    &["palaeoanthropologists"],
    &["palaeoanthropologists"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGIST_17669887741894885204: VariantsMap = [
    &["paleoanthropologist"],
    &["palaeoanthropologist"],
    &["palaeoanthropologist"],
    &["palaeoanthropologist"],
];

pub(crate) static ENTRY_PALEOANTHROPOLOGY_3812740593686907410: VariantsMap = [
    &["paleoanthropology"],
    &["palaeoanthropology"],
    &["palaeoanthropology"],
    &["palaeoanthropology"],
];

pub(crate) static ENTRY_PALEOANTHROPUS_7420869959409316912: VariantsMap = [
    &["paleoanthropus"],
    &["palaeoanthropus"],
    &["palaeoanthropus"],
    &["palaeoanthropus"],
];

pub(crate) static ENTRY_PALEOATAVISM_8551400910343690690: VariantsMap = [
    &["paleoatavism"],
    &["palaeoatavism"],
    &["palaeoatavism"],
    &["palaeoatavism"],
];

pub(crate) static ENTRY_PALEOATAVISTIC_10050677946807803791: VariantsMap = [
    &["paleoatavistic"],
    &["palaeoatavistic"],
    &["palaeoatavistic"],
    &["palaeoatavistic"],
];

pub(crate) static ENTRY_PALEOBIOGEOGRAPHY_12815064252785970775: VariantsMap = [
    &["paleobiogeography"],
    &["palaeobiogeography"],
    &["palaeobiogeography"],
    &["palaeobiogeography"],
];

pub(crate) static ENTRY_PALEOBIOLOGICAL_6984844449398043034: VariantsMap = [
    &["paleobiological"],
    &["palaeobiological"],
    &["palaeobiological"],
    &["palaeobiological"],
];

pub(crate) static ENTRY_PALEOBIOLOGIC_16440511702072730664: VariantsMap = [
    &["paleobiologic"],
    &["palaeobiologic"],
    &["palaeobiologic"],
    &["palaeobiologic"],
];

pub(crate) static ENTRY_PALEOBIOLOGIES_9640345759259243883: VariantsMap = [
    &["paleobiologies"],
    &["palaeobiologies"],
    &["palaeobiologies"],
    &["palaeobiologies"],
];

pub(crate) static ENTRY_PALEOBIOLOGISTS_13074678415638321770: VariantsMap = [
    &["paleobiologists"],
    &["palaeobiologists"],
    &["palaeobiologists"],
    &["palaeobiologists"],
];

pub(crate) static ENTRY_PALEOBIOLOGIST_10727925421273428200: VariantsMap = [
    &["paleobiologist"],
    &["palaeobiologist"],
    &["palaeobiologist"],
    &["palaeobiologist"],
];

pub(crate) static ENTRY_PALEOBIOLOGY_11504082211509448873: VariantsMap = [
    &["paleobiology"],
    &["palaeobiology"],
    &["palaeobiology"],
    &["palaeobiology"],
];

pub(crate) static ENTRY_PALEOBOTANICALLY_531809237195935810: VariantsMap = [
    &["paleobotanically"],
    &["palaeobotanically"],
    &["palaeobotanically"],
    &["palaeobotanically"],
];

pub(crate) static ENTRY_PALEOBOTANICAL_15741271816715346651: VariantsMap = [
    &["paleobotanical"],
    &["palaeobotanical"],
    &["palaeobotanical"],
    &["palaeobotanical"],
];

pub(crate) static ENTRY_PALEOBOTANIC_4268740945431822060: VariantsMap = [
    &["paleobotanic"],
    &["palaeobotanic"],
    &["palaeobotanic"],
    &["palaeobotanic"],
];

pub(crate) static ENTRY_PALEOBOTANIES_9907904145366116896: VariantsMap = [
    &["paleobotanies"],
    &["palaeobotanies"],
    &["palaeobotanies"],
    &["palaeobotanies"],
];

pub(crate) static ENTRY_PALEOBOTANISTS_4400435446022569085: VariantsMap = [
    &["paleobotanists"],
    &["palaeobotanists"],
    &["palaeobotanists"],
    &["palaeobotanists"],
];

pub(crate) static ENTRY_PALEOBOTANIST_899453557168994746: VariantsMap = [
    &["paleobotanist"],
    &["palaeobotanist"],
    &["palaeobotanist"],
    &["palaeobotanist"],
];

pub(crate) static ENTRY_PALEOBOTANY_14491399323716171031: VariantsMap = [
    &["paleobotany"],
    &["palaeobotany"],
    &["palaeobotany"],
    &["palaeobotany"],
];

pub(crate) static ENTRY_PALEOCEANOGRAPHY_17101199344090437462: VariantsMap = [
    &["paleoceanography"],
    &["palaeoceanography"],
    &["palaeoceanography"],
    &["palaeoceanography"],
];

pub(crate) static ENTRY_PALEOCHOROLOGY_5640429438972653065: VariantsMap = [
    &["paleochorology"],
    &["palaeochorology"],
    &["palaeochorology"],
    &["palaeochorology"],
];

pub(crate) static ENTRY_PALEOCLIMATIC_4864976749151865103: VariantsMap = [
    &["paleoclimatic"],
    &["palaeoclimatic"],
    &["palaeoclimatic"],
    &["palaeoclimatic"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGICAL_1574786532199586705: VariantsMap = [
    &["paleoclimatological"],
    &["palaeoclimatological"],
    &["palaeoclimatological"],
    &["palaeoclimatological"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGIC_526146125986738672: VariantsMap = [
    &["paleoclimatologic"],
    &["palaeoclimatologic"],
    &["palaeoclimatologic"],
    &["palaeoclimatologic"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGIES_5179884944969798580: VariantsMap = [
    &["paleoclimatologies"],
    &["palaeoclimatologies"],
    &["paleoclimatologies"],
    &["palaeoclimatologies"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGISTS_12743875895326058182: VariantsMap = [
    &["paleoclimatologists"],
    &["palaeoclimatologists"],
    &["palaeoclimatologists"],
    &["palaeoclimatologists"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGIST_6598866277215835335: VariantsMap = [
    &["paleoclimatologist"],
    &["palaeoclimatologist"],
    &["palaeoclimatologist"],
    &["palaeoclimatologist"],
];

pub(crate) static ENTRY_PALEOCLIMATOLOGY_15887222804850141365: VariantsMap = [
    &["paleoclimatology"],
    &["palaeoclimatology"],
    &["paleoclimatology"],
    &["palaeoclimatology"],
];

pub(crate) static ENTRY_PALEOCONCHA_17786127602602440622: VariantsMap = [
    &["paleoconcha"],
    &["palaeoconcha"],
    &["palaeoconcha"],
    &["palaeoconcha"],
];

pub(crate) static ENTRY_PALEOCOSMIC_7194233103148258600: VariantsMap = [
    &["paleocosmic"],
    &["palaeocosmic"],
    &["palaeocosmic"],
    &["palaeocosmic"],
];

pub(crate) static ENTRY_PALEOCOSMOLOGY_7229374416435600718: VariantsMap = [
    &["paleocosmology"],
    &["palaeocosmology"],
    &["palaeocosmology"],
    &["palaeocosmology"],
];

pub(crate) static ENTRY_PALEOCRYSTALLIC_14538230435317171258: VariantsMap = [
    &["paleocrystallic"],
    &["palaeocrystallic"],
    &["palaeocrystallic"],
    &["palaeocrystallic"],
];

pub(crate) static ENTRY_PALEOCRYSTALLINE_10365119975362565017: VariantsMap = [
    &["paleocrystalline"],
    &["palaeocrystalline"],
    &["palaeocrystalline"],
    &["palaeocrystalline"],
];

pub(crate) static ENTRY_PALEOCRYSTAL_9876015479913580253: VariantsMap = [
    &["paleocrystal"],
    &["palaeocrystal"],
    &["palaeocrystal"],
    &["palaeocrystal"],
];

pub(crate) static ENTRY_PALEOCRYSTIC_2695211631331372901: VariantsMap = [
    &["paleocrystic"],
    &["palaeocrystic"],
    &["palaeocrystic"],
    &["palaeocrystic"],
];

pub(crate) static ENTRY_PALEOCYCLIC_1891041371707085992: VariantsMap = [
    &["paleocyclic"],
    &["palaeocyclic"],
    &["palaeocyclic"],
    &["palaeocyclic"],
];

pub(crate) static ENTRY_PALEODENDROLOGICALLY_3827473591390270826: VariantsMap = [
    &["paleodendrologically"],
    &["palaeodendrologically"],
    &["palaeodendrologically"],
    &["palaeodendrologically"],
];

pub(crate) static ENTRY_PALEODENDROLOGICAL_2041711262884531596: VariantsMap = [
    &["paleodendrological"],
    &["palaeodendrological"],
    &["palaeodendrological"],
    &["palaeodendrological"],
];

pub(crate) static ENTRY_PALEODENDROLOGIC_8085277507686382792: VariantsMap = [
    &["paleodendrologic"],
    &["palaeodendrologic"],
    &["palaeodendrologic"],
    &["palaeodendrologic"],
];

pub(crate) static ENTRY_PALEODENDROLOGIST_1101730449788449946: VariantsMap = [
    &["paleodendrologist"],
    &["palaeodendrologist"],
    &["palaeodendrologist"],
    &["palaeodendrologist"],
];

pub(crate) static ENTRY_PALEODENDROLOGY_4540542604348310427: VariantsMap = [
    &["paleodendrology"],
    &["palaeodendrology"],
    &["palaeodendrology"],
    &["palaeodendrology"],
];

pub(crate) static ENTRY_PALEOECOLOGICAL_11947291013008837430: VariantsMap = [
    &["paleoecological"],
    &["palaeoecological"],
    &["palaeoecological"],
    &["palaeoecological"],
];

pub(crate) static ENTRY_PALEOECOLOGIC_2338176615715809865: VariantsMap = [
    &["paleoecologic"],
    &["palaeoecologic"],
    &["palaeoecologic"],
    &["palaeoecologic"],
];

pub(crate) static ENTRY_PALEOECOLOGIES_11813930991122462231: VariantsMap = [
    &["paleoecologies"],
    &["palaeoecologies"],
    &["paleoecologies"],
    &["palaeoecologies"],
];

pub(crate) static ENTRY_PALEOECOLOGISTS_12793530961960552689: VariantsMap = [
    &["paleoecologists"],
    &["palaeoecologists"],
    &["palaeoecologists"],
    &["palaeoecologists"],
];

pub(crate) static ENTRY_PALEOECOLOGIST_6577271230726993315: VariantsMap = [
    &["paleoecologist"],
    &["palaeoecologist"],
    &["palaeoecologist"],
    &["palaeoecologist"],
];

pub(crate) static ENTRY_PALEOECOLOGY_9627329165537969229: VariantsMap = [
    &["paleoecology"],
    &["palaeoecology"],
    &["paleoecology"],
    &["palaeoecology"],
];

pub(crate) static ENTRY_PALEOENCEPHALON_12092496594413779771: VariantsMap = [
    &["paleoencephalon"],
    &["palaeoencephalon"],
    &["palaeoencephalon"],
    &["palaeoencephalon"],
];

pub(crate) static ENTRY_PALEOENTOMOLOGICAL_13035092658337348165: VariantsMap = [
    &["paleoentomological"],
    &["palaeoentomological"],
    &["palaeoentomological"],
    &["palaeoentomological"],
];

pub(crate) static ENTRY_PALEOENTOMOLOGIC_383886705450148741: VariantsMap = [
    &["paleoentomologic"],
    &["palaeoentomologic"],
    &["palaeoentomologic"],
    &["palaeoentomologic"],
];

pub(crate) static ENTRY_PALEOENTOMOLOGIST_5711399062674583841: VariantsMap = [
    &["paleoentomologist"],
    &["palaeoentomologist"],
    &["palaeoentomologist"],
    &["palaeoentomologist"],
];

pub(crate) static ENTRY_PALEOEREMOLOGY_4326619216815037045: VariantsMap = [
    &["paleoeremology"],
    &["palaeoeremology"],
    &["palaeoeremology"],
    &["palaeoeremology"],
];

pub(crate) static ENTRY_PALEOETHNIC_2616697170182083042: VariantsMap = [
    &["paleoethnic"],
    &["palaeoethnic"],
    &["palaeoethnic"],
    &["palaeoethnic"],
];

pub(crate) static ENTRY_PALEOETHNOGRAPHY_10029791943046919018: VariantsMap = [
    &["paleoethnography"],
    &["palaeoethnography"],
    &["palaeoethnography"],
    &["palaeoethnography"],
];

pub(crate) static ENTRY_PALEOETHNOLOGICAL_4237301460218128665: VariantsMap = [
    &["paleoethnological"],
    &["palaeoethnological"],
    &["palaeoethnological"],
    &["palaeoethnological"],
];

pub(crate) static ENTRY_PALEOETHNOLOGIC_1647305402535030374: VariantsMap = [
    &["paleoethnologic"],
    &["palaeoethnologic"],
    &["palaeoethnologic"],
    &["palaeoethnologic"],
];

pub(crate) static ENTRY_PALEOETHNOLOGIST_7879442028488422184: VariantsMap = [
    &["paleoethnologist"],
    &["palaeoethnologist"],
    &["palaeoethnologist"],
    &["palaeoethnologist"],
];

pub(crate) static ENTRY_PALEOETHNOLOGY_8500804609820740340: VariantsMap = [
    &["paleoethnology"],
    &["palaeoethnology"],
    &["palaeoethnology"],
    &["palaeoethnology"],
];

pub(crate) static ENTRY_PALEOFAUNA_9255676362516904097: VariantsMap = [
    &["paleofauna"],
    &["palaeofauna"],
    &["palaeofauna"],
    &["palaeofauna"],
];

pub(crate) static ENTRY_PALEOGENESIS_3600166863543332590: VariantsMap = [
    &["paleogenesis"],
    &["palaeogenesis"],
    &["palaeogenesis"],
    &["palaeogenesis"],
];

pub(crate) static ENTRY_PALEOGENETIC_1015196132875105067: VariantsMap = [
    &["paleogenetic"],
    &["palaeogenetic"],
    &["palaeogenetic"],
    &["palaeogenetic"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHERS_17871739223134050844: VariantsMap = [
    &["paleogeographers"],
    &["palaeogeographers"],
    &["palaeogeographers"],
    &["palaeogeographers"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHER_6181412299853337706: VariantsMap = [
    &["paleogeographer"],
    &["palaeogeographer"],
    &["palaeogeographer"],
    &["palaeogeographer"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHICALLY_13029998877556984898: VariantsMap = [
    &["paleogeographically"],
    &["palaeogeographically"],
    &["palaeogeographically"],
    &["palaeogeographically"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHICAL_8531426019765749589: VariantsMap = [
    &["paleogeographical"],
    &["palaeogeographical"],
    &["palaeogeographical"],
    &["palaeogeographical"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHIC_7239153512084908161: VariantsMap = [
    &["paleogeographic"],
    &["palaeogeographic"],
    &["palaeogeographic"],
    &["palaeogeographic"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHIES_4879378358799199366: VariantsMap = [
    &["paleogeographies"],
    &["palaeogeographies"],
    &["paleogeographies"],
    &["palaeogeographies"],
];

pub(crate) static ENTRY_PALEOGEOGRAPHY_9694730594843353950: VariantsMap = [
    &["paleogeography"],
    &["palaeogeography"],
    &["paleogeography"],
    &["palaeogeography"],
];

pub(crate) static ENTRY_PALEOGEOLOGY_1446971404483318371: VariantsMap = [
    &["paleogeology"],
    &["palaeogeology"],
    &["palaeogeology"],
    &["palaeogeology"],
];

pub(crate) static ENTRY_PALEOGLACIOLOGY_1379886853019110102: VariantsMap = [
    &["paleoglaciology"],
    &["palaeoglaciology"],
    &["palaeoglaciology"],
    &["palaeoglaciology"],
];

pub(crate) static ENTRY_PALEOGLYPH_15757196795062379228: VariantsMap = [
    &["paleoglyph"],
    &["palaeoglyph"],
    &["palaeoglyph"],
    &["palaeoglyph"],
];

pub(crate) static ENTRY_PALEOGRAPHICALLY_13565114456978434920: VariantsMap = [
    &["paleographically"],
    &["palaeographically"],
    &["palaeographically"],
    &["palaeographically"],
];

pub(crate) static ENTRY_PALEOGRAPHICAL_8773289818657734421: VariantsMap = [
    &["paleographical"],
    &["palaeographical"],
    &["palaeographical"],
    &["palaeographical"],
];

pub(crate) static ENTRY_PALEOGRAPHIC_13213503981348166251: VariantsMap = [
    &["paleographic"],
    &["palaeographic"],
    &["palaeographic"],
    &["palaeographic"],
];

pub(crate) static ENTRY_PALEOGRAPHIST_1276539096646670959: VariantsMap = [
    &["paleographist"],
    &["palaeographist"],
    &["palaeographist"],
    &["palaeographist"],
];

pub(crate) static ENTRY_PALEOGRAPH_12540277689198261106: VariantsMap = [
    &["paleograph"],
    &["palaeograph"],
    &["palaeograph"],
    &["palaeograph"],
];

pub(crate) static ENTRY_PALEOHERPETOLOGIST_2006506636872959347: VariantsMap = [
    &["paleoherpetologist"],
    &["palaeoherpetologist"],
    &["palaeoherpetologist"],
    &["palaeoherpetologist"],
];

pub(crate) static ENTRY_PALEOHERPETOLOGY_6195422226443274584: VariantsMap = [
    &["paleoherpetology"],
    &["palaeoherpetology"],
    &["palaeoherpetology"],
    &["palaeoherpetology"],
];

pub(crate) static ENTRY_PALEOHISTOLOGY_11971446365505053036: VariantsMap = [
    &["paleohistology"],
    &["palaeohistology"],
    &["palaeohistology"],
    &["palaeohistology"],
];

pub(crate) static ENTRY_PALEOHYDROGRAPHY_16923732770996851993: VariantsMap = [
    &["paleohydrography"],
    &["palaeohydrography"],
    &["palaeohydrography"],
    &["palaeohydrography"],
];

pub(crate) static ENTRY_PALEOICHTHYOLOGY_7690182781909447343: VariantsMap = [
    &["paleoichthyology"],
    &["palaeoichthyology"],
    &["palaeoichthyology"],
    &["palaeoichthyology"],
];

pub(crate) static ENTRY_PALEOLATRY_10924970429013530423: VariantsMap = [
    &["paleolatry"],
    &["palaeolatry"],
    &["palaeolatry"],
    &["palaeolatry"],
];

pub(crate) static ENTRY_PALEOLIMNOLOGY_14150694516900017849: VariantsMap = [
    &["paleolimnology"],
    &["palaeolimnology"],
    &["palaeolimnology"],
    &["palaeolimnology"],
];

pub(crate) static ENTRY_PALEOLITHICAL_2938847385029098541: VariantsMap = [
    &["paleolithical"],
    &["palaeolithical"],
    &["palaeolithical"],
    &["palaeolithical"],
];

pub(crate) static ENTRY_PALEOLITHIC_9773849440157812866: VariantsMap = [
    &["paleolithic"],
    &["palaeolithic"],
    &["paleolithic"],
    &["palaeolithic"],
];

pub(crate) static ENTRY_PALEOLITHIST_5532799631229777418: VariantsMap = [
    &["paleolithist"],
    &["palaeolithist"],
    &["palaeolithist"],
    &["palaeolithist"],
];

pub(crate) static ENTRY_PALEOLITHOID_13241766435280101823: VariantsMap = [
    &["paleolithoid"],
    &["palaeolithoid"],
    &["palaeolithoid"],
    &["palaeolithoid"],
];

pub(crate) static ENTRY_PALEOLITHS_17748074122835398462: VariantsMap = [
    &["paleoliths"],
    &["palaeoliths"],
    &["palaeoliths"],
    &["palaeoliths"],
];

pub(crate) static ENTRY_PALEOLITHY_10861400960502824252: VariantsMap = [
    &["paleolithy"],
    &["palaeolithy"],
    &["palaeolithy"],
    &["palaeolithy"],
];

pub(crate) static ENTRY_PALEOLITH_1045819319387817757: VariantsMap = [
    &["paleolith"],
    &["palaeolith"],
    &["palaeolith"],
    &["palaeolith"],
];

pub(crate) static ENTRY_PALEOLOGICAL_14540869198514592883: VariantsMap = [
    &["paleological"],
    &["palaeological"],
    &["palaeological"],
    &["palaeological"],
];

pub(crate) static ENTRY_PALEOLOGIST_12695091568939120465: VariantsMap = [
    &["paleologist"],
    &["palaeologist"],
    &["palaeologist"],
    &["palaeologist"],
];

pub(crate) static ENTRY_PALEOLOGY_14864767825292514427: VariantsMap = [
    &["paleology"],
    &["palaeology"],
    &["palaeology"],
    &["palaeology"],
];

pub(crate) static ENTRY_PALEOMAGNETISMS_12975495479790421940: VariantsMap = [
    &["paleomagnetisms"],
    &["palaeomagnetisms"],
    &["palaeomagnetisms"],
    &["palaeomagnetisms"],
];

pub(crate) static ENTRY_PALEOMAGNETISM_12747245265284798200: VariantsMap = [
    &["paleomagnetism"],
    &["palaeomagnetism"],
    &["palaeomagnetism"],
    &["palaeomagnetism"],
];

pub(crate) static ENTRY_PALEOMETALLIC_496020103900724451: VariantsMap = [
    &["paleometallic"],
    &["palaeometallic"],
    &["palaeometallic"],
    &["palaeometallic"],
];

pub(crate) static ENTRY_PALEOMETEOROLOGICAL_550400106195388111: VariantsMap = [
    &["paleometeorological"],
    &["palaeometeorological"],
    &["palaeometeorological"],
    &["palaeometeorological"],
];

pub(crate) static ENTRY_PALEOMETEOROLOGY_13517875046229169369: VariantsMap = [
    &["paleometeorology"],
    &["palaeometeorology"],
    &["palaeometeorology"],
    &["palaeometeorology"],
];

pub(crate) static ENTRY_PALEONTOGRAPHICAL_14600480157080012123: VariantsMap = [
    &["paleontographical"],
    &["palaeontographical"],
    &["palaeontographical"],
    &["palaeontographical"],
];

pub(crate) static ENTRY_PALEONTOGRAPHIC_14553442358192254400: VariantsMap = [
    &["paleontographic"],
    &["palaeontographic"],
    &["palaeontographic"],
    &["palaeontographic"],
];

pub(crate) static ENTRY_PALEONTOGRAPHIES_4145254269175447370: VariantsMap = [
    &["paleontographies"],
    &["palaeontographies"],
    &["palaeontographies"],
    &["palaeontographies"],
];

pub(crate) static ENTRY_PALEONTOGRAPHY_7112963726296976935: VariantsMap = [
    &["paleontography"],
    &["palaeontography"],
    &["palaeontography"],
    &["palaeontography"],
];

pub(crate) static ENTRY_PALEONTOLOGICALLY_3574530926178177300: VariantsMap = [
    &["paleontologically"],
    &["palaeontologically"],
    &["palaeontologically"],
    &["palaeontologically"],
];

pub(crate) static ENTRY_PALEONTOLOGICAL_12663535461634576551: VariantsMap = [
    &["paleontological"],
    &["palaeontological"],
    &["paleontological"],
    &["palaeontological"],
];

pub(crate) static ENTRY_PALEONTOLOGIC_17768892661333746888: VariantsMap = [
    &["paleontologic"],
    &["palaeontologic"],
    &["palaeontologic"],
    &["palaeontologic"],
];

pub(crate) static ENTRY_PALEONTOLOGISTS_13268509669082698999: VariantsMap = [
    &["paleontologists"],
    &["palaeontologists"],
    &["paleontologists"],
    &["palaeontologists"],
];

pub(crate) static ENTRY_PALEONTOLOGIST_12247171017461904774: VariantsMap = [
    &["paleontologist"],
    &["palaeontologist"],
    &["paleontologist"],
    &["palaeontologist"],
];

pub(crate) static ENTRY_PALEONTOLOGY_9348542274173969502: VariantsMap = [
    &["paleontology"],
    &["palaeontology"],
    &["paleontology"],
    &["palaeontology"],
];

pub(crate) static ENTRY_PALEONTOL_12365596636789393329: VariantsMap = [
    &["paleontol"],
    &["palaeontol"],
    &["palaeontol"],
    &["palaeontol"],
];

pub(crate) static ENTRY_PALEOPATHOLOGICAL_6887317455291404805: VariantsMap = [
    &["paleopathological"],
    &["palaeopathological"],
    &["palaeopathological"],
    &["palaeopathological"],
];

pub(crate) static ENTRY_PALEOPATHOLOGIC_12214316584075954034: VariantsMap = [
    &["paleopathologic"],
    &["palaeopathologic"],
    &["palaeopathologic"],
    &["palaeopathologic"],
];

pub(crate) static ENTRY_PALEOPATHOLOGIES_14671677750367365866: VariantsMap = [
    &["paleopathologies"],
    &["palaeopathologies"],
    &["palaeopathologies"],
    &["palaeopathologies"],
];

pub(crate) static ENTRY_PALEOPATHOLOGISTS_17271348023550711951: VariantsMap = [
    &["paleopathologists"],
    &["palaeopathologists"],
    &["palaeopathologists"],
    &["palaeopathologists"],
];

pub(crate) static ENTRY_PALEOPATHOLOGIST_12270610216847457118: VariantsMap = [
    &["paleopathologist"],
    &["palaeopathologist"],
    &["palaeopathologist"],
    &["palaeopathologist"],
];

pub(crate) static ENTRY_PALEOPATHOLOGY_5627090926175726231: VariantsMap = [
    &["paleopathology"],
    &["palaeopathology"],
    &["palaeopathology"],
    &["palaeopathology"],
];

pub(crate) static ENTRY_PALEOPEDOLOGY_1197146382262396542: VariantsMap = [
    &["paleopedology"],
    &["palaeopedology"],
    &["palaeopedology"],
    &["palaeopedology"],
];

pub(crate) static ENTRY_PALEOPHYSIOGRAPHY_12430780127473103003: VariantsMap = [
    &["paleophysiography"],
    &["palaeophysiography"],
    &["palaeophysiography"],
    &["palaeophysiography"],
];

pub(crate) static ENTRY_PALEOPHYSIOLOGY_11536100909731884978: VariantsMap = [
    &["paleophysiology"],
    &["palaeophysiology"],
    &["palaeophysiology"],
    &["palaeophysiology"],
];

pub(crate) static ENTRY_PALEOPHYTIC_11763578694401197746: VariantsMap = [
    &["paleophytic"],
    &["palaeophytic"],
    &["palaeophytic"],
    &["palaeophytic"],
];

pub(crate) static ENTRY_PALEOPHYTOLOGICAL_11128259889095522921: VariantsMap = [
    &["paleophytological"],
    &["palaeophytological"],
    &["palaeophytological"],
    &["palaeophytological"],
];

pub(crate) static ENTRY_PALEOPHYTOLOGIST_8077452540555712875: VariantsMap = [
    &["paleophytologist"],
    &["palaeophytologist"],
    &["palaeophytologist"],
    &["palaeophytologist"],
];

pub(crate) static ENTRY_PALEOPHYTOLOGY_17976758756772027621: VariantsMap = [
    &["paleophytology"],
    &["palaeophytology"],
    &["palaeophytology"],
    &["palaeophytology"],
];

pub(crate) static ENTRY_PALEOPLAIN_3909898326665799560: VariantsMap = [
    &["paleoplain"],
    &["palaeoplain"],
    &["palaeoplain"],
    &["palaeoplain"],
];

pub(crate) static ENTRY_PALEOPOTAMOLOGY_5121637181893167860: VariantsMap = [
    &["paleopotamology"],
    &["palaeopotamology"],
    &["palaeopotamology"],
    &["palaeopotamology"],
];

pub(crate) static ENTRY_PALEOPSYCHIC_4583882512800260814: VariantsMap = [
    &["paleopsychic"],
    &["palaeopsychic"],
    &["palaeopsychic"],
    &["palaeopsychic"],
];

pub(crate) static ENTRY_PALEOPSYCHOLOGICAL_11882282799276562417: VariantsMap = [
    &["paleopsychological"],
    &["palaeopsychological"],
    &["palaeopsychological"],
    &["palaeopsychological"],
];

pub(crate) static ENTRY_PALEOPSYCHOLOGY_283847755015723996: VariantsMap = [
    &["paleopsychology"],
    &["palaeopsychology"],
    &["palaeopsychology"],
    &["palaeopsychology"],
];

pub(crate) static ENTRY_PALEORNITHOLOGICAL_1866733716411651985: VariantsMap = [
    &["paleornithological"],
    &["palaeornithological"],
    &["palaeornithological"],
    &["palaeornithological"],
];

pub(crate) static ENTRY_PALEORNITHOLOGY_3476002279004463238: VariantsMap = [
    &["paleornithology"],
    &["palaeornithology"],
    &["palaeornithology"],
    &["palaeornithology"],
];

pub(crate) static ENTRY_PALEOSTRIATAL_11075530959524135503: VariantsMap = [
    &["paleostriatal"],
    &["palaeostriatal"],
    &["palaeostriatal"],
    &["palaeostriatal"],
];

pub(crate) static ENTRY_PALEOSTRIATUM_3018739928180146534: VariantsMap = [
    &["paleostriatum"],
    &["palaeostriatum"],
    &["palaeostriatum"],
    &["palaeostriatum"],
];

pub(crate) static ENTRY_PALEOSTYLIC_7185491761609231755: VariantsMap = [
    &["paleostylic"],
    &["palaeostylic"],
    &["palaeostylic"],
    &["palaeostylic"],
];

pub(crate) static ENTRY_PALEOSTYLY_16331580432550579450: VariantsMap = [
    &["paleostyly"],
    &["palaeostyly"],
    &["palaeostyly"],
    &["palaeostyly"],
];

pub(crate) static ENTRY_PALEOTECHNIC_15389758989633104362: VariantsMap = [
    &["paleotechnic"],
    &["palaeotechnic"],
    &["palaeotechnic"],
    &["palaeotechnic"],
];

pub(crate) static ENTRY_PALEOTHALAMUS_7765630969377615058: VariantsMap = [
    &["paleothalamus"],
    &["palaeothalamus"],
    &["palaeothalamus"],
    &["palaeothalamus"],
];

pub(crate) static ENTRY_PALEOTROPICAL_5321237610871013456: VariantsMap = [
    &["paleotropical"],
    &["palaeotropical"],
    &["palaeotropical"],
    &["palaeotropical"],
];

pub(crate) static ENTRY_PALEOVOLCANIC_375156208850882906: VariantsMap = [
    &["paleovolcanic"],
    &["palaeovolcanic"],
    &["palaeovolcanic"],
    &["palaeovolcanic"],
];

pub(crate) static ENTRY_PALEOZOIC_15539659693355565678: VariantsMap = [
    &["paleozoic"],
    &["palaeozoic"],
    &["palaeozoic"],
    &["palaeozoic"],
];

pub(crate) static ENTRY_PALEOZOOLOGICAL_8783617239969730799: VariantsMap = [
    &["paleozoological"],
    &["palaeozoological"],
    &["palaeozoological"],
    &["palaeozoological"],
];

pub(crate) static ENTRY_PALEOZOOLOGIC_15918765432702043975: VariantsMap = [
    &["paleozoologic"],
    &["palaeozoologic"],
    &["palaeozoologic"],
    &["palaeozoologic"],
];

pub(crate) static ENTRY_PALEOZOOLOGIES_3410495526345315585: VariantsMap = [
    &["paleozoologies"],
    &["palaeozoologies"],
    &["palaeozoologies"],
    &["palaeozoologies"],
];

pub(crate) static ENTRY_PALEOZOOLOGISTS_16974824863261009461: VariantsMap = [
    &["paleozoologists"],
    &["palaeozoologists"],
    &["palaeozoologists"],
    &["palaeozoologists"],
];

pub(crate) static ENTRY_PALEOZOOLOGIST_18146472512848833302: VariantsMap = [
    &["paleozoologist"],
    &["palaeozoologist"],
    &["palaeozoologist"],
    &["palaeozoologist"],
];

pub(crate) static ENTRY_PALEOZOOLOGY_1422962101591588438: VariantsMap = [
    &["paleozoology"],
    &["palaeozoology"],
    &["palaeozoology"],
    &["palaeozoology"],
];

pub(crate) static ENTRY_PALESTRAE_1477667196546852023: VariantsMap = [
    &["palestrae"],
    &["palaestrae"],
    &["palaestrae"],
    &["palaestrae"],
];

pub(crate) static ENTRY_PALESTRAL_2129721318476523672: VariantsMap = [
    &["palestral"],
    &["palaestral"],
    &["palaestral"],
    &["palaestral"],
];

pub(crate) static ENTRY_PALESTRAS_10577628877980961814: VariantsMap = [
    &["palestras"],
    &["palaestras"],
    &["palaestras"],
    &["palaestras"],
];

pub(crate) static ENTRY_PALESTRA_5229500943251203121: VariantsMap = [
    &["palestra"],
    &["palaestra"],
    &["palaestra"],
    &["palaestra"],
];

pub(crate) static ENTRY_PALESTRIAN_16896525722710554753: VariantsMap = [
    &["palestrian"],
    &["palaestrian"],
    &["palaestrian"],
    &["palaestrian"],
];

pub(crate) static ENTRY_PALESTRIC_13247296948328839180: VariantsMap = [
    &["palestric"],
    &["palaestric"],
    &["palaestric"],
    &["palaestric"],
];

pub(crate) static ENTRY_PALETIOLOGY_10862221893256067090: VariantsMap = [
    &["paletiology"],
    &["palaetiology"],
    &["palaetiology"],
    &["palaetiology"],
];

pub(crate) static ENTRY_PALLADIUMIZES_9849089739995990190: VariantsMap = [
    &["palladiumizes"],
    &["palladiumises"],
    &["palladiumizes"],
    &["palladiumises"],
];

pub(crate) static ENTRY_PALLADIUMIZE_17702952767718609388: VariantsMap = [
    &["palladiumize"],
    &["palladiumise"],
    &["palladiumize"],
    &["palladiumise"],
];

pub(crate) static ENTRY_PALLETIZATIONS_6464829452261813832: VariantsMap = [
    &["palletizations"],
    &["palletisations"],
    &["palletizations"],
    &["palletisations"],
];

pub(crate) static ENTRY_PALLETIZATION_9100136200462548037: VariantsMap = [
    &["palletization"],
    &["palletisation"],
    &["palletization"],
    &["palletisation"],
];

pub(crate) static ENTRY_PALLETIZED_12902140764229882038: VariantsMap = [
    &["palletized"],
    &["palletised"],
    &["palletized"],
    &["palletised"],
];

pub(crate) static ENTRY_PALLETIZERS_11548138475235590986: VariantsMap = [
    &["palletizers"],
    &["palletisers"],
    &["palletizers"],
    &["palletisers"],
];

pub(crate) static ENTRY_PALLETIZER_6914094309015631146: VariantsMap = [
    &["palletizer"],
    &["palletiser"],
    &["palletizer"],
    &["palletiser"],
];

pub(crate) static ENTRY_PALLETIZES_13198673987307815474: VariantsMap = [
    &["palletizes"],
    &["palletises"],
    &["palletizes"],
    &["palletises"],
];

pub(crate) static ENTRY_PALLETIZE_1396210646911825010: VariantsMap = [
    &["palletize"],
    &["palletise"],
    &["palletize"],
    &["palletise"],
];

pub(crate) static ENTRY_PALLETIZING_10974154931828649144: VariantsMap = [
    &["palletizing"],
    &["palletising"],
    &["palletizing"],
    &["palletising"],
];

pub(crate) static ENTRY_PAMPERIZES_14945268529810280091: VariantsMap = [
    &["pamperizes"],
    &["pamperises"],
    &["pamperizes"],
    &["pamperises"],
];

pub(crate) static ENTRY_PAMPERIZE_340939352609954382: VariantsMap = [
    &["pamperize"],
    &["pamperise"],
    &["pamperize"],
    &["pamperise"],
];

pub(crate) static ENTRY_PAMPHLETIZES_10198512299714902969: VariantsMap = [
    &["pamphletizes"],
    &["pamphletises"],
    &["pamphletizes"],
    &["pamphletises"],
];

pub(crate) static ENTRY_PAMPHLETIZE_11971804629691384479: VariantsMap = [
    &["pamphletize"],
    &["pamphletise"],
    &["pamphletize"],
    &["pamphletise"],
];

pub(crate) static ENTRY_PANDERIZES_1524284286880339446: VariantsMap = [
    &["panderizes"],
    &["panderises"],
    &["panderizes"],
    &["panderises"],
];

pub(crate) static ENTRY_PANDERIZE_13584391243213121721: VariantsMap = [
    &["panderize"],
    &["panderise"],
    &["panderize"],
    &["panderise"],
];

pub(crate) static ENTRY_PANDORA_3725190345946682637: VariantsMap =
    [&["pandora"], &["pandoura"], &["pandoura"], &["pandoura"]];

pub(crate) static ENTRY_PANEGYRIZED_2757369675942335026: VariantsMap = [
    &["panegyrized"],
    &["panegyrised"],
    &["panegyrized"],
    &["panegyrised"],
];

pub(crate) static ENTRY_PANEGYRIZES_11019653756667579465: VariantsMap = [
    &["panegyrizes"],
    &["panegyrises"],
    &["panegyrizes"],
    &["panegyrises"],
];

pub(crate) static ENTRY_PANEGYRIZE_13725594811903766701: VariantsMap = [
    &["panegyrize"],
    &["panegyrise"],
    &["panegyrize"],
    &["panegyrise"],
];

pub(crate) static ENTRY_PANEGYRIZING_8733146786926436047: VariantsMap = [
    &["panegyrizing"],
    &["panegyrising"],
    &["panegyrizing"],
    &["panegyrising"],
];

pub(crate) static ENTRY_PANELED_13703633025394020864: VariantsMap =
    [&["paneled"], &["panelled"], &["panelled"], &["panelled"]];

pub(crate) static ENTRY_PANELINGS_15074841711846726284: VariantsMap = [
    &["panelings"],
    &["panellings"],
    &["panellings"],
    &["panellings"],
];

pub(crate) static ENTRY_PANELING_6797910716086726489: VariantsMap = [
    &["paneling"],
    &["panelling"],
    &["panelling"],
    &["panelling"],
];

pub(crate) static ENTRY_PANELISTS_3944165336031850149: VariantsMap = [
    &["panelists"],
    &["panellists"],
    &["panellists"],
    &["panellists"],
];

pub(crate) static ENTRY_PANELIST_1479227178929273987: VariantsMap = [
    &["panelist"],
    &["panellist"],
    &["panellist"],
    &["panellist"],
];

pub(crate) static ENTRY_PANELIZATION_16652578521390386065: VariantsMap = [
    &["panelization"],
    &["panellisation"],
    &["panellization"],
    &["panellisation"],
];

pub(crate) static ENTRY_PANELIZED_13331281099468759927: VariantsMap = [
    &["panelized"],
    &["panelised"],
    &["panelized"],
    &["panelised"],
];

pub(crate) static ENTRY_PANESTHESIAS_12180956018251533666: VariantsMap = [
    &["panesthesias"],
    &["panaesthesias"],
    &["panaesthesias"],
    &["panaesthesias"],
];

pub(crate) static ENTRY_PANESTHESIA_11035715240294507957: VariantsMap = [
    &["panesthesia"],
    &["panaesthesia"],
    &["panaesthesia"],
    &["panaesthesia"],
];

pub(crate) static ENTRY_PANESTHETIC_11607514217078102793: VariantsMap = [
    &["panesthetic"],
    &["panaesthetic"],
    &["panaesthetic"],
    &["panaesthetic"],
];

pub(crate) static ENTRY_PANGEA_7134656067039212415: VariantsMap =
    [&["pangea"], &["pangaea"], &["pangaea"], &["pangaea"]];

pub(crate) static ENTRY_PANOMPHEAN_3871256800146061540: VariantsMap = [
    &["panomphean"],
    &["panomphaean"],
    &["panomphaean"],
    &["panomphaean"],
];

pub(crate) static ENTRY_PANTHEONIZATIONS_3423114313425744840: VariantsMap = [
    &["pantheonizations"],
    &["pantheonisations"],
    &["pantheonizations"],
    &["pantheonisations"],
];

pub(crate) static ENTRY_PANTHEONIZATION_944840168044661015: VariantsMap = [
    &["pantheonization"],
    &["pantheonisation"],
    &["pantheonization"],
    &["pantheonisation"],
];

pub(crate) static ENTRY_PANTHEONIZES_2223291708212001129: VariantsMap = [
    &["pantheonizes"],
    &["pantheonises"],
    &["pantheonizes"],
    &["pantheonises"],
];

pub(crate) static ENTRY_PANTHEONIZE_13681139475213145828: VariantsMap = [
    &["pantheonize"],
    &["pantheonise"],
    &["pantheonize"],
    &["pantheonise"],
];

pub(crate) static ENTRY_PAPALIZATIONS_8937933260778799316: VariantsMap = [
    &["papalizations"],
    &["papalisations"],
    &["papalizations"],
    &["papalisations"],
];

pub(crate) static ENTRY_PAPALIZATION_18093835441065843962: VariantsMap = [
    &["papalization"],
    &["papalisation"],
    &["papalization"],
    &["papalisation"],
];

pub(crate) static ENTRY_PAPALIZED_8860509933771894456: VariantsMap = [
    &["papalized"],
    &["papalised"],
    &["papalized"],
    &["papalised"],
];

pub(crate) static ENTRY_PAPALIZERS_3871507791493356862: VariantsMap = [
    &["papalizers"],
    &["papalisers"],
    &["papalizers"],
    &["papalisers"],
];

pub(crate) static ENTRY_PAPALIZER_16569059721153045662: VariantsMap = [
    &["papalizer"],
    &["papaliser"],
    &["papalizer"],
    &["papaliser"],
];

pub(crate) static ENTRY_PAPALIZES_16609776725154006255: VariantsMap = [
    &["papalizes"],
    &["papalises"],
    &["papalizes"],
    &["papalises"],
];

pub(crate) static ENTRY_PAPALIZE_7508341397145332147: VariantsMap =
    [&["papalize"], &["papalise"], &["papalize"], &["papalise"]];

pub(crate) static ENTRY_PAPALIZING_11590725765608182808: VariantsMap = [
    &["papalizing"],
    &["papalising"],
    &["papalizing"],
    &["papalising"],
];

pub(crate) static ENTRY_PAPILLEDEMA_13947738993687090385: VariantsMap = [
    &["papilledema"],
    &["papilloedema"],
    &["papilloedema"],
    &["papilloedema"],
];

pub(crate) static ENTRY_PAPULE_7630225005240179696: VariantsMap =
    [&["papule"], &["papulae"], &["papulae"], &["papulae"]];

pub(crate) static ENTRY_PARABOLIZATION_3443054328623013834: VariantsMap = [
    &["parabolization"],
    &["parabolisation"],
    &["parabolization"],
    &["parabolisation"],
];

pub(crate) static ENTRY_PARABOLIZED_16123534121411965653: VariantsMap = [
    &["parabolized"],
    &["parabolised"],
    &["parabolized"],
    &["parabolised"],
];

pub(crate) static ENTRY_PARABOLIZES_7112996769899442233: VariantsMap = [
    &["parabolizes"],
    &["parabolises"],
    &["parabolizes"],
    &["parabolises"],
];

pub(crate) static ENTRY_PARABOLIZE_647480633800331213: VariantsMap = [
    &["parabolize"],
    &["parabolise"],
    &["parabolize"],
    &["parabolise"],
];

pub(crate) static ENTRY_PARABOLIZING_16537085326922700301: VariantsMap = [
    &["parabolizing"],
    &["parabolising"],
    &["parabolizing"],
    &["parabolising"],
];

pub(crate) static ENTRY_PARAFFINIZES_12064336249396828188: VariantsMap = [
    &["paraffinizes"],
    &["paraffinises"],
    &["paraffinizes"],
    &["paraffinises"],
];

pub(crate) static ENTRY_PARAFFINIZE_10242502814954171305: VariantsMap = [
    &["paraffinize"],
    &["paraffinise"],
    &["paraffinize"],
    &["paraffinise"],
];

pub(crate) static ENTRY_PARAGRAPHIZES_18032803927207327558: VariantsMap = [
    &["paragraphizes"],
    &["paragraphises"],
    &["paragraphizes"],
    &["paragraphises"],
];

pub(crate) static ENTRY_PARAGRAPHIZE_15316990182254058602: VariantsMap = [
    &["paragraphize"],
    &["paragraphise"],
    &["paragraphize"],
    &["paragraphise"],
];

pub(crate) static ENTRY_PARALLELIZATIONS_5527525018980081767: VariantsMap = [
    &["parallelizations"],
    &["parallelisations"],
    &["parallelizations"],
    &["parallelisations"],
];

pub(crate) static ENTRY_PARALLELIZATION_11371893526743177056: VariantsMap = [
    &["parallelization"],
    &["parallelisation"],
    &["parallelization"],
    &["parallelisation"],
];

pub(crate) static ENTRY_PARALLELIZED_7737697672669886109: VariantsMap = [
    &["parallelized"],
    &["parallelised"],
    &["parallelized"],
    &["parallelised"],
];

pub(crate) static ENTRY_PARALLELIZERS_17955085162563936649: VariantsMap = [
    &["parallelizers"],
    &["parallelisers"],
    &["parallelizers"],
    &["parallelisers"],
];

pub(crate) static ENTRY_PARALLELIZER_9529835313527884654: VariantsMap = [
    &["parallelizer"],
    &["paralleliser"],
    &["parallelizer"],
    &["paralleliser"],
];

pub(crate) static ENTRY_PARALLELIZES_6725281951117805650: VariantsMap = [
    &["parallelizes"],
    &["parallelises"],
    &["parallelizes"],
    &["parallelises"],
];

pub(crate) static ENTRY_PARALLELIZE_4476089616460732502: VariantsMap = [
    &["parallelize"],
    &["parallelise"],
    &["parallelize"],
    &["parallelise"],
];

pub(crate) static ENTRY_PARALLELIZING_10961993960559405417: VariantsMap = [
    &["parallelizing"],
    &["parallelising"],
    &["parallelizing"],
    &["parallelising"],
];

pub(crate) static ENTRY_PARALOGIZED_7353441990226128641: VariantsMap = [
    &["paralogized"],
    &["paralogised"],
    &["paralogized"],
    &["paralogised"],
];

pub(crate) static ENTRY_PARALOGIZES_12884972439326038225: VariantsMap = [
    &["paralogizes"],
    &["paralogises"],
    &["paralogizes"],
    &["paralogises"],
];

pub(crate) static ENTRY_PARALOGIZE_276245645846907921: VariantsMap = [
    &["paralogize"],
    &["paralogise"],
    &["paralogize"],
    &["paralogise"],
];

pub(crate) static ENTRY_PARALOGIZING_8939374896317650319: VariantsMap = [
    &["paralogizing"],
    &["paralogising"],
    &["paralogizing"],
    &["paralogising"],
];

pub(crate) static ENTRY_PARALYZATIONS_1774275609038042526: VariantsMap = [
    &["paralyzations"],
    &["paralysations"],
    &["paralysations"],
    &["paralysations"],
];

pub(crate) static ENTRY_PARALYZATION_16507089340912060778: VariantsMap = [
    &["paralyzation"],
    &["paralysation"],
    &["paralysation"],
    &["paralysation"],
];

pub(crate) static ENTRY_PARALYZEDLIES_3750343561858475702: VariantsMap = [
    &["paralyzedlies"],
    &["paralysedlies"],
    &["paralysedlies"],
    &["paralysedlies"],
];

pub(crate) static ENTRY_PARALYZEDLY_8828875855047300798: VariantsMap = [
    &["paralyzedly"],
    &["paralysedly"],
    &["paralysedly"],
    &["paralysedly"],
];

pub(crate) static ENTRY_PARALYZED_14571626041912266449: VariantsMap = [
    &["paralyzed"],
    &["paralysed"],
    &["paralyzed"],
    &["paralysed"],
];

pub(crate) static ENTRY_PARALYZERS_16689764779974601608: VariantsMap = [
    &["paralyzers"],
    &["paralysers"],
    &["paralysers"],
    &["paralysers"],
];

pub(crate) static ENTRY_PARALYZER_12700307170063304346: VariantsMap = [
    &["paralyzer"],
    &["paralyser"],
    &["paralyser"],
    &["paralyser"],
];

pub(crate) static ENTRY_PARALYZES_13640131716118540510: VariantsMap = [
    &["paralyzes"],
    &["paralyses"],
    &["paralyzes"],
    &["paralyses"],
];

pub(crate) static ENTRY_PARALYZE_4857352680562257186: VariantsMap =
    [&["paralyze"], &["paralyse"], &["paralyze"], &["paralyse"]];

pub(crate) static ENTRY_PARALYZINGLIES_8785740653550502606: VariantsMap = [
    &["paralyzinglies"],
    &["paralysinglies"],
    &["paralysinglies"],
    &["paralysinglies"],
];

pub(crate) static ENTRY_PARALYZINGLY_2992135569354984660: VariantsMap = [
    &["paralyzingly"],
    &["paralysingly"],
    &["paralysingly"],
    &["paralysingly"],
];

pub(crate) static ENTRY_PARALYZING_4886446215231470079: VariantsMap = [
    &["paralyzing"],
    &["paralysing"],
    &["paralyzing"],
    &["paralysing"],
];

pub(crate) static ENTRY_PARAMECIUM_11380345148477920829: VariantsMap = [
    &["paramecium"],
    &["paramoecium"],
    &["paramoecium"],
    &["paramoecium"],
];

pub(crate) static ENTRY_PARAMETERIZABLE_2808545627544279194: VariantsMap = [
    &["parameterizable"],
    &["parameterisable"],
    &["parameterizable"],
    &["parameterisable"],
];

pub(crate) static ENTRY_PARAMETERIZATIONS_4100532402271729672: VariantsMap = [
    &["parameterizations"],
    &["parameterisations"],
    &["parameterizations"],
    &["parameterisations"],
];

pub(crate) static ENTRY_PARAMETERIZATION_7197627343403819237: VariantsMap = [
    &["parameterization"],
    &["parameterisation"],
    &["parameterization"],
    &["parameterisation"],
];

pub(crate) static ENTRY_PARAMETERIZED_13105902558710911600: VariantsMap = [
    &["parameterized"],
    &["parameterised"],
    &["parameterized"],
    &["parameterised"],
];

pub(crate) static ENTRY_PARAMETERIZES_5120553313235644221: VariantsMap = [
    &["parameterizes"],
    &["parameterises"],
    &["parameterizes"],
    &["parameterises"],
];

pub(crate) static ENTRY_PARAMETERIZE_749505129591253272: VariantsMap = [
    &["parameterize"],
    &["parameterise"],
    &["parameterize"],
    &["parameterise"],
];

pub(crate) static ENTRY_PARAMETERIZING_11261879865339041710: VariantsMap = [
    &["parameterizing"],
    &["parameterising"],
    &["parameterizing"],
    &["parameterising"],
];

pub(crate) static ENTRY_PARAMETRIZABLE_5928777122379787793: VariantsMap = [
    &["parametrizable"],
    &["parametrisable"],
    &["parametrizable"],
    &["parametrisable"],
];

pub(crate) static ENTRY_PARAMETRIZATIONS_5016585554931052909: VariantsMap = [
    &["parametrizations"],
    &["parametrisations"],
    &["parametrizations"],
    &["parametrisations"],
];

pub(crate) static ENTRY_PARAMETRIZATION_7411406993709104163: VariantsMap = [
    &["parametrization"],
    &["parametrisation"],
    &["parametrization"],
    &["parametrisation"],
];

pub(crate) static ENTRY_PARAMETRIZED_17784422469128630511: VariantsMap = [
    &["parametrized"],
    &["parametrised"],
    &["parametrized"],
    &["parametrised"],
];

pub(crate) static ENTRY_PARAMETRIZES_15875840276606359299: VariantsMap = [
    &["parametrizes"],
    &["parametrises"],
    &["parametrizes"],
    &["parametrises"],
];

pub(crate) static ENTRY_PARAMETRIZE_14088334789658250719: VariantsMap = [
    &["parametrize"],
    &["parametrise"],
    &["parametrize"],
    &["parametrise"],
];

pub(crate) static ENTRY_PARAMETRIZING_684518743725650757: VariantsMap = [
    &["parametrizing"],
    &["parametrising"],
    &["parametrizing"],
    &["parametrising"],
];

pub(crate) static ENTRY_PARASELENE_14205012842021982883: VariantsMap = [
    &["paraselene"],
    &["paraselenae"],
    &["paraselenae"],
    &["paraselenae"],
];

pub(crate) static ENTRY_PARASITEMIA_2010465244019964494: VariantsMap = [
    &["parasitemia"],
    &["parasitaemia"],
    &["parasitaemia"],
    &["parasitaemia"],
];

pub(crate) static ENTRY_PARASITIZATION_14820584356162257753: VariantsMap = [
    &["parasitization"],
    &["parasitisation"],
    &["parasitization"],
    &["parasitisation"],
];

pub(crate) static ENTRY_PARASITIZED_8321931620618387182: VariantsMap = [
    &["parasitized"],
    &["parasitised"],
    &["parasitized"],
    &["parasitised"],
];

pub(crate) static ENTRY_PARASITIZES_4416122141775362722: VariantsMap = [
    &["parasitizes"],
    &["parasitises"],
    &["parasitizes"],
    &["parasitises"],
];

pub(crate) static ENTRY_PARASITIZE_5242435462062853785: VariantsMap = [
    &["parasitize"],
    &["parasitise"],
    &["parasitize"],
    &["parasitise"],
];

pub(crate) static ENTRY_PARASITIZING_9042112679581969658: VariantsMap = [
    &["parasitizing"],
    &["parasitising"],
    &["parasitizing"],
    &["parasitising"],
];

pub(crate) static ENTRY_PARATHYROIDECTOMIZED_6685949501942941317: VariantsMap = [
    &["parathyroidectomized"],
    &["parathyroidectomised"],
    &["parathyroidectomized"],
    &["parathyroidectomised"],
];

pub(crate) static ENTRY_PARATHYROIDECTOMIZES_13875716632357128903: VariantsMap = [
    &["parathyroidectomizes"],
    &["parathyroidectomises"],
    &["parathyroidectomizes"],
    &["parathyroidectomises"],
];

pub(crate) static ENTRY_PARATHYROIDECTOMIZE_14332962201064430908: VariantsMap = [
    &["parathyroidectomize"],
    &["parathyroidectomise"],
    &["parathyroidectomize"],
    &["parathyroidectomise"],
];

pub(crate) static ENTRY_PARATHYROIDECTOMIZING_12468529059301511586: VariantsMap = [
    &["parathyroidectomizing"],
    &["parathyroidectomising"],
    &["parathyroidectomizing"],
    &["parathyroidectomising"],
];

pub(crate) static ENTRY_PARATRAGEDIA_7102269813615164101: VariantsMap = [
    &["paratragedia"],
    &["paratragoedia"],
    &["paratragoedia"],
    &["paratragoedia"],
];

pub(crate) static ENTRY_PARCELED_13390569989951727254: VariantsMap = [
    &["parceled"],
    &["parcelled"],
    &["parcelled"],
    &["parcelled"],
];

pub(crate) static ENTRY_PARCELER_13062850192066854861: VariantsMap = [
    &["parceler"],
    &["parceller"],
    &["parceller"],
    &["parceller"],
];

pub(crate) static ENTRY_PARCELING_8316945993856781576: VariantsMap = [
    &["parceling"],
    &["parcelling"],
    &["parcelling"],
    &["parcelling"],
];

pub(crate) static ENTRY_PARCHMENTIZED_12167483454807635503: VariantsMap = [
    &["parchmentized"],
    &["parchmentised"],
    &["parchmentized"],
    &["parchmentised"],
];

pub(crate) static ENTRY_PARCHMENTIZES_3633165695178418266: VariantsMap = [
    &["parchmentizes"],
    &["parchmentises"],
    &["parchmentizes"],
    &["parchmentises"],
];

pub(crate) static ENTRY_PARCHMENTIZE_12324213011474346454: VariantsMap = [
    &["parchmentize"],
    &["parchmentise"],
    &["parchmentize"],
    &["parchmentise"],
];

pub(crate) static ENTRY_PARCHMENTIZING_5076165931333507700: VariantsMap = [
    &["parchmentizing"],
    &["parchmentising"],
    &["parchmentizing"],
    &["parchmentising"],
];

pub(crate) static ENTRY_PARECIOUSLY_11156310959668142943: VariantsMap = [
    &["pareciously"],
    &["paroeciously"],
    &["paroeciously"],
    &["paroeciously"],
];

pub(crate) static ENTRY_PARECIOUSNESS_7874749331627836854: VariantsMap = [
    &["pareciousness"],
    &["paroeciousness"],
    &["paroeciousness"],
    &["paroeciousness"],
];

pub(crate) static ENTRY_PARECIOUS_12511564458907798074: VariantsMap = [
    &["parecious"],
    &["paroecious"],
    &["paroecious"],
    &["paroecious"],
];

pub(crate) static ENTRY_PARECISM_15139198512135907949: VariantsMap = [
    &["parecism"],
    &["paroecism"],
    &["paroecism"],
    &["paroecism"],
];

pub(crate) static ENTRY_PARECY_5096581135883021145: VariantsMap =
    [&["parecy"], &["paroecy"], &["paroecy"], &["paroecy"]];

pub(crate) static ENTRY_PARENESES_13856725007668956765: VariantsMap = [
    &["pareneses"],
    &["paraeneses"],
    &["paraeneses"],
    &["paraeneses"],
];

pub(crate) static ENTRY_PARENESIS_16089230337112310128: VariantsMap = [
    &["parenesis"],
    &["paraenesis"],
    &["paraenesis"],
    &["paraenesis"],
];

pub(crate) static ENTRY_PARENETICAL_16075969944259996555: VariantsMap = [
    &["parenetical"],
    &["paraenetical"],
    &["paraenetical"],
    &["paraenetical"],
];

pub(crate) static ENTRY_PARENETIC_14181412180643963721: VariantsMap = [
    &["parenetic"],
    &["paraenetic"],
    &["paraenetic"],
    &["paraenetic"],
];

pub(crate) static ENTRY_PARENTHESIZATION_9124500764491892448: VariantsMap = [
    &["parenthesization"],
    &["parenthesisation"],
    &["parenthesization"],
    &["parenthesisation"],
];

pub(crate) static ENTRY_PARENTHESIZED_13190399718764525857: VariantsMap = [
    &["parenthesized"],
    &["parenthesised"],
    &["parenthesized"],
    &["parenthesised"],
];

pub(crate) static ENTRY_PARENTHESIZES_16946392961248470353: VariantsMap = [
    &["parenthesizes"],
    &["parenthesises"],
    &["parenthesizes"],
    &["parenthesises"],
];

pub(crate) static ENTRY_PARENTHESIZE_14226036285596216236: VariantsMap = [
    &["parenthesize"],
    &["parenthesise"],
    &["parenthesize"],
    &["parenthesise"],
];

pub(crate) static ENTRY_PARENTHESIZING_4060837799462431128: VariantsMap = [
    &["parenthesizing"],
    &["parenthesising"],
    &["parenthesizing"],
    &["parenthesising"],
];

pub(crate) static ENTRY_PARESTHESIAS_1637525985108297517: VariantsMap = [
    &["paresthesias"],
    &["paraesthesias"],
    &["paraesthesias"],
    &["paraesthesias"],
];

pub(crate) static ENTRY_PARESTHESIA_1881280237839265168: VariantsMap = [
    &["paresthesia"],
    &["paraesthesia"],
    &["paraesthesia"],
    &["paraesthesia"],
];

pub(crate) static ENTRY_PARESTHETIC_3283039464622031643: VariantsMap = [
    &["paresthetic"],
    &["paraesthetic"],
    &["paraesthetic"],
    &["paraesthetic"],
];

pub(crate) static ENTRY_PARFOCALIZATION_15255494080564826957: VariantsMap = [
    &["parfocalization"],
    &["parfocalisation"],
    &["parfocalization"],
    &["parfocalisation"],
];

pub(crate) static ENTRY_PARFOCALIZE_11199953063987118573: VariantsMap = [
    &["parfocalize"],
    &["parfocalise"],
    &["parfocalize"],
    &["parfocalise"],
];

pub(crate) static ENTRY_PARISIANIZATIONS_12496635998441245631: VariantsMap = [
    &["parisianizations"],
    &["parisianisations"],
    &["parisianizations"],
    &["parisianisations"],
];

pub(crate) static ENTRY_PARISIANIZATION_2149081518294904073: VariantsMap = [
    &["parisianization"],
    &["parisianisation"],
    &["parisianization"],
    &["parisianisation"],
];

pub(crate) static ENTRY_PARISIANIZES_425663399052281478: VariantsMap = [
    &["parisianizes"],
    &["parisianises"],
    &["parisianizes"],
    &["parisianises"],
];

pub(crate) static ENTRY_PARISIANIZE_6192760037620464041: VariantsMap = [
    &["parisianize"],
    &["parisianise"],
    &["parisianize"],
    &["parisianise"],
];

pub(crate) static ENTRY_PARLORISH_12231920163055198915: VariantsMap = [
    &["parlorish"],
    &["parlourish"],
    &["parlourish"],
    &["parlourish"],
];

pub(crate) static ENTRY_PARLORMAID_11273400895928326109: VariantsMap = [
    &["parlormaid"],
    &["parlourmaid"],
    &["parlourmaid"],
    &["parlourmaid"],
];

pub(crate) static ENTRY_PARLORS_15955075320930669198: VariantsMap =
    [&["parlors"], &["parlours"], &["parlours"], &["parlours"]];

pub(crate) static ENTRY_PARLOR_941908612091762590: VariantsMap =
    [&["parlor"], &["parlour"], &["parlour"], &["parlour"]];

pub(crate) static ENTRY_PAROCHIALIZATIONS_9802414540039811945: VariantsMap = [
    &["parochializations"],
    &["parochialisations"],
    &["parochializations"],
    &["parochialisations"],
];

pub(crate) static ENTRY_PAROCHIALIZATION_9992801911204982717: VariantsMap = [
    &["parochialization"],
    &["parochialisation"],
    &["parochialization"],
    &["parochialisation"],
];

pub(crate) static ENTRY_PAROCHIALIZED_7260130425534967642: VariantsMap = [
    &["parochialized"],
    &["parochialised"],
    &["parochialized"],
    &["parochialised"],
];

pub(crate) static ENTRY_PAROCHIALIZES_18097243070015350318: VariantsMap = [
    &["parochializes"],
    &["parochialises"],
    &["parochializes"],
    &["parochialises"],
];

pub(crate) static ENTRY_PAROCHIALIZE_4878369212533866158: VariantsMap = [
    &["parochialize"],
    &["parochialise"],
    &["parochialize"],
    &["parochialise"],
];

pub(crate) static ENTRY_PAROCHIALIZING_17616216312392224371: VariantsMap = [
    &["parochializing"],
    &["parochialising"],
    &["parochializing"],
    &["parochialising"],
];

pub(crate) static ENTRY_PARROTIZES_9482751000492529167: VariantsMap = [
    &["parrotizes"],
    &["parrotises"],
    &["parrotizes"],
    &["parrotises"],
];

pub(crate) static ENTRY_PARROTIZE_3559774235199949197: VariantsMap = [
    &["parrotize"],
    &["parrotise"],
    &["parrotize"],
    &["parrotise"],
];

pub(crate) static ENTRY_PARSONIZES_7532265200903960160: VariantsMap = [
    &["parsonizes"],
    &["parsonises"],
    &["parsonizes"],
    &["parsonises"],
];

pub(crate) static ENTRY_PARSONIZE_999620183438182016: VariantsMap = [
    &["parsonize"],
    &["parsonise"],
    &["parsonize"],
    &["parsonise"],
];

pub(crate) static ENTRY_PARTIALIZED_2709517819508033472: VariantsMap = [
    &["partialized"],
    &["partialised"],
    &["partialized"],
    &["partialised"],
];

pub(crate) static ENTRY_PARTIALIZES_13769905578223386853: VariantsMap = [
    &["partializes"],
    &["partialises"],
    &["partializes"],
    &["partialises"],
];

pub(crate) static ENTRY_PARTIALIZE_6483459727437604593: VariantsMap = [
    &["partialize"],
    &["partialise"],
    &["partialize"],
    &["partialise"],
];

pub(crate) static ENTRY_PARTIALIZING_11646327448099240465: VariantsMap = [
    &["partializing"],
    &["partialising"],
    &["partializing"],
    &["partialising"],
];

pub(crate) static ENTRY_PARTICOLOREDDER_10954556914378270950: VariantsMap = [
    &["particoloredder"],
    &["particolouredder"],
    &["particolouredder"],
    &["particolouredder"],
];

pub(crate) static ENTRY_PARTICOLOREDDEST_2681475883544822311: VariantsMap = [
    &["particoloreddest"],
    &["particoloureddest"],
    &["particoloureddest"],
    &["particoloureddest"],
];

pub(crate) static ENTRY_PARTICOLORED_4962898152175870348: VariantsMap = [
    &["particolored"],
    &["particoloured"],
    &["particoloured"],
    &["particoloured"],
];

pub(crate) static ENTRY_PARTICULARIZATIONS_12840694709588521802: VariantsMap = [
    &["particularizations"],
    &["particularisations"],
    &["particularizations"],
    &["particularisations"],
];

pub(crate) static ENTRY_PARTICULARIZATION_10597016863146923743: VariantsMap = [
    &["particularization"],
    &["particularisation"],
    &["particularization"],
    &["particularisation"],
];

pub(crate) static ENTRY_PARTICULARIZED_14793866807327365849: VariantsMap = [
    &["particularized"],
    &["particularised"],
    &["particularized"],
    &["particularised"],
];

pub(crate) static ENTRY_PARTICULARIZER_9553956621020704685: VariantsMap = [
    &["particularizer"],
    &["particulariser"],
    &["particularizer"],
    &["particulariser"],
];

pub(crate) static ENTRY_PARTICULARIZES_3435670524070905736: VariantsMap = [
    &["particularizes"],
    &["particularises"],
    &["particularizes"],
    &["particularises"],
];

pub(crate) static ENTRY_PARTICULARIZE_6799382390040618665: VariantsMap = [
    &["particularize"],
    &["particularise"],
    &["particularize"],
    &["particularise"],
];

pub(crate) static ENTRY_PARTICULARIZING_2129782421225948865: VariantsMap = [
    &["particularizing"],
    &["particularising"],
    &["particularizing"],
    &["particularising"],
];

pub(crate) static ENTRY_PARTISANIZES_9558412409025070058: VariantsMap = [
    &["partisanizes"],
    &["partisanises"],
    &["partisanizes"],
    &["partisanises"],
];

pub(crate) static ENTRY_PARTISANIZE_7728091169711740923: VariantsMap = [
    &["partisanize"],
    &["partisanise"],
    &["partisanize"],
    &["partisanise"],
];

pub(crate) static ENTRY_PASIPHAE_10488119709560322867: VariantsMap = [
    &["pasiphae"],
    &["pasiphaae"],
    &["pasiphaae"],
    &["pasiphaae"],
];

pub(crate) static ENTRY_PASSADES_13578732946213603806: VariantsMap = [
    &["passades"],
    &["passadoes"],
    &["passadoes"],
    &["passadoes"],
];

pub(crate) static ENTRY_PASSIVIZATION_14743361941945546861: VariantsMap = [
    &["passivization"],
    &["passivisation"],
    &["passivization"],
    &["passivisation"],
];

pub(crate) static ENTRY_PASTEURIZATIONS_102052595045476495: VariantsMap = [
    &["pasteurizations"],
    &["pasteurisations"],
    &["pasteurizations"],
    &["pasteurisations"],
];

pub(crate) static ENTRY_PASTEURIZATION_3504555580005315179: VariantsMap = [
    &["pasteurization"],
    &["pasteurisation"],
    &["pasteurization"],
    &["pasteurisation"],
];

pub(crate) static ENTRY_PASTEURIZED_5146326881382822263: VariantsMap = [
    &["pasteurized"],
    &["pasteurised"],
    &["pasteurized"],
    &["pasteurised"],
];

pub(crate) static ENTRY_PASTEURIZERS_9491345555555085016: VariantsMap = [
    &["pasteurizers"],
    &["pasteurisers"],
    &["pasteurizers"],
    &["pasteurisers"],
];

pub(crate) static ENTRY_PASTEURIZER_7779730307883141682: VariantsMap = [
    &["pasteurizer"],
    &["pasteuriser"],
    &["pasteurizer"],
    &["pasteuriser"],
];

pub(crate) static ENTRY_PASTEURIZES_16714282537428831202: VariantsMap = [
    &["pasteurizes"],
    &["pasteurises"],
    &["pasteurizes"],
    &["pasteurises"],
];

pub(crate) static ENTRY_PASTEURIZE_2832181573565026454: VariantsMap = [
    &["pasteurize"],
    &["pasteurise"],
    &["pasteurize"],
    &["pasteurise"],
];

pub(crate) static ENTRY_PASTEURIZING_7347504323568813914: VariantsMap = [
    &["pasteurizing"],
    &["pasteurising"],
    &["pasteurizing"],
    &["pasteurising"],
];

pub(crate) static ENTRY_PASTORALIZES_4475797865513749802: VariantsMap = [
    &["pastoralizes"],
    &["pastoralises"],
    &["pastoralizes"],
    &["pastoralises"],
];

pub(crate) static ENTRY_PASTORALIZE_17951514580198521378: VariantsMap = [
    &["pastoralize"],
    &["pastoralise"],
    &["pastoralize"],
    &["pastoralise"],
];

pub(crate) static ENTRY_PASTORIZES_7445639879481102329: VariantsMap = [
    &["pastorizes"],
    &["pastorises"],
    &["pastorizes"],
    &["pastorises"],
];

pub(crate) static ENTRY_PASTORIZE_1632691559568233544: VariantsMap = [
    &["pastorize"],
    &["pastorise"],
    &["pastorize"],
    &["pastorise"],
];

pub(crate) static ENTRY_PATERNALIZES_1247257877767433807: VariantsMap = [
    &["paternalizes"],
    &["paternalises"],
    &["paternalizes"],
    &["paternalises"],
];

pub(crate) static ENTRY_PATERNALIZE_16820296051551287672: VariantsMap = [
    &["paternalize"],
    &["paternalise"],
    &["paternalize"],
    &["paternalise"],
];

pub(crate) static ENTRY_PATINED_13394457292336487862: VariantsMap =
    [&["patined"], &["patinaed"], &["patinaed"], &["patinaed"]];

pub(crate) static ENTRY_PATINE_2970293521113220017: VariantsMap =
    [&["patine"], &["patinae"], &["patinae"], &["patinae"]];

pub(crate) static ENTRY_PATRIALIZATIONS_17945934088767852952: VariantsMap = [
    &["patrializations"],
    &["patrialisations"],
    &["patrializations"],
    &["patrialisations"],
];

pub(crate) static ENTRY_PATRIALIZATION_16537461446526410102: VariantsMap = [
    &["patrialization"],
    &["patrialisation"],
    &["patrialization"],
    &["patrialisation"],
];

pub(crate) static ENTRY_PATRIALIZED_3341367979909806645: VariantsMap = [
    &["patrialized"],
    &["patrialised"],
    &["patrialized"],
    &["patrialised"],
];

pub(crate) static ENTRY_PATRIALIZES_185244585711165697: VariantsMap = [
    &["patrializes"],
    &["patrialises"],
    &["patrializes"],
    &["patrialises"],
];

pub(crate) static ENTRY_PATRIALIZE_9230345548828707773: VariantsMap = [
    &["patrialize"],
    &["patrialise"],
    &["patrialize"],
    &["patrialise"],
];

pub(crate) static ENTRY_PATRIALIZING_11575701095687435072: VariantsMap = [
    &["patrializing"],
    &["patrialising"],
    &["patrializing"],
    &["patrialising"],
];

pub(crate) static ENTRY_PATRICES_5662411576011637155: VariantsMap = [
    &["patrices"],
    &["patricoes"],
    &["patricoes"],
    &["patricoes"],
];

pub(crate) static ENTRY_PATRONIZABLER_4132412027758830590: VariantsMap = [
    &["patronizabler"],
    &["patronisabler"],
    &["patronizabler"],
    &["patronisabler"],
];

pub(crate) static ENTRY_PATRONIZABLEST_9689527443658363422: VariantsMap = [
    &["patronizablest"],
    &["patronisablest"],
    &["patronizablest"],
    &["patronisablest"],
];

pub(crate) static ENTRY_PATRONIZABLES_9272342348159028844: VariantsMap = [
    &["patronizables"],
    &["patronisables"],
    &["patronizables"],
    &["patronisables"],
];

pub(crate) static ENTRY_PATRONIZABLE_15319193123060273715: VariantsMap = [
    &["patronizable"],
    &["patronisable"],
    &["patronizable"],
    &["patronisable"],
];

pub(crate) static ENTRY_PATRONIZATIONS_7552667099953006768: VariantsMap = [
    &["patronizations"],
    &["patronisations"],
    &["patronizations"],
    &["patronisations"],
];

pub(crate) static ENTRY_PATRONIZATION_6477606590083038612: VariantsMap = [
    &["patronization"],
    &["patronisation"],
    &["patronization"],
    &["patronisation"],
];

pub(crate) static ENTRY_PATRONIZED_2861263128246082573: VariantsMap = [
    &["patronized"],
    &["patronised"],
    &["patronized"],
    &["patronised"],
];

pub(crate) static ENTRY_PATRONIZERS_12866923462083731422: VariantsMap = [
    &["patronizers"],
    &["patronisers"],
    &["patronizers"],
    &["patronisers"],
];

pub(crate) static ENTRY_PATRONIZER_6993255105150109640: VariantsMap = [
    &["patronizer"],
    &["patroniser"],
    &["patronizer"],
    &["patroniser"],
];

pub(crate) static ENTRY_PATRONIZES_339151254169886766: VariantsMap = [
    &["patronizes"],
    &["patronises"],
    &["patronizes"],
    &["patronises"],
];

pub(crate) static ENTRY_PATRONIZE_5579497708777119859: VariantsMap = [
    &["patronize"],
    &["patronise"],
    &["patronize"],
    &["patronise"],
];

pub(crate) static ENTRY_PATRONIZINGLIER_4247129633497959722: VariantsMap = [
    &["patronizinglier"],
    &["patronisinglier"],
    &["patronizinglier"],
    &["patronisinglier"],
];

pub(crate) static ENTRY_PATRONIZINGLIEST_16680534920939329902: VariantsMap = [
    &["patronizingliest"],
    &["patronisingliest"],
    &["patronizingliest"],
    &["patronisingliest"],
];

pub(crate) static ENTRY_PATRONIZINGLY_1677195389459576502: VariantsMap = [
    &["patronizingly"],
    &["patronisingly"],
    &["patronizingly"],
    &["patronisingly"],
];

pub(crate) static ENTRY_PATRONIZINGS_17625682551925708597: VariantsMap = [
    &["patronizings"],
    &["patronisings"],
    &["patronizings"],
    &["patronisings"],
];

pub(crate) static ENTRY_PATRONIZING_3034907083264382838: VariantsMap = [
    &["patronizing"],
    &["patronising"],
    &["patronizing"],
    &["patronising"],
];

pub(crate) static ENTRY_PATTERNIZES_12992806022556722958: VariantsMap = [
    &["patternizes"],
    &["patternises"],
    &["patternizes"],
    &["patternises"],
];

pub(crate) static ENTRY_PATTERNIZE_3076936465414513253: VariantsMap = [
    &["patternize"],
    &["patternise"],
    &["patternize"],
    &["patternise"],
];

pub(crate) static ENTRY_PATTE_18436126856913566134: VariantsMap =
    [&["patte"], &["pattae"], &["pattae"], &["pattae"]];

pub(crate) static ENTRY_PAULINIZES_7824935294790294303: VariantsMap = [
    &["paulinizes"],
    &["paulinises"],
    &["paulinizes"],
    &["paulinises"],
];

pub(crate) static ENTRY_PAULINIZE_4447070483648697360: VariantsMap = [
    &["paulinize"],
    &["paulinise"],
    &["paulinize"],
    &["paulinise"],
];

pub(crate) static ENTRY_PAUPERIZATIONS_12078339223087449719: VariantsMap = [
    &["pauperizations"],
    &["pauperisations"],
    &["pauperizations"],
    &["pauperisations"],
];

pub(crate) static ENTRY_PAUPERIZATION_1367294979133470708: VariantsMap = [
    &["pauperization"],
    &["pauperisation"],
    &["pauperization"],
    &["pauperisation"],
];

pub(crate) static ENTRY_PAUPERIZED_2170585696432841058: VariantsMap = [
    &["pauperized"],
    &["pauperised"],
    &["pauperized"],
    &["pauperised"],
];

pub(crate) static ENTRY_PAUPERIZERS_11032753764651813331: VariantsMap = [
    &["pauperizers"],
    &["pauperisers"],
    &["pauperizers"],
    &["pauperisers"],
];

pub(crate) static ENTRY_PAUPERIZER_17515758464001019002: VariantsMap = [
    &["pauperizer"],
    &["pauperiser"],
    &["pauperizer"],
    &["pauperiser"],
];

pub(crate) static ENTRY_PAUPERIZES_6629297486906140663: VariantsMap = [
    &["pauperizes"],
    &["pauperises"],
    &["pauperizes"],
    &["pauperises"],
];

pub(crate) static ENTRY_PAUPERIZE_8616451812771143864: VariantsMap = [
    &["pauperize"],
    &["pauperise"],
    &["pauperize"],
    &["pauperise"],
];

pub(crate) static ENTRY_PAUPERIZING_15608270047399709224: VariantsMap = [
    &["pauperizing"],
    &["pauperising"],
    &["pauperizing"],
    &["pauperising"],
];

pub(crate) static ENTRY_PAVIORS_7306783981371552851: VariantsMap =
    [&["paviors"], &["paviours"], &["paviours"], &["paviours"]];

pub(crate) static ENTRY_PAVIOR_17636375175721697070: VariantsMap =
    [&["pavior"], &["paviour"], &["paviour"], &["paviour"]];

pub(crate) static ENTRY_PAYNIZES_15490955026943979655: VariantsMap =
    [&["paynizes"], &["paynises"], &["paynizes"], &["paynises"]];

pub(crate) static ENTRY_PAYNIZE_3729038275545179140: VariantsMap =
    [&["paynize"], &["paynise"], &["paynize"], &["paynise"]];

pub(crate) static ENTRY_PEARLIZATION_26508564052178328: VariantsMap = [
    &["pearlization"],
    &["pearlisation"],
    &["pearlization"],
    &["pearlisation"],
];

pub(crate) static ENTRY_PEARLIZED_1624453871015926144: VariantsMap = [
    &["pearlized"],
    &["pearlised"],
    &["pearlized"],
    &["pearlised"],
];

pub(crate) static ENTRY_PEARLIZES_12869936007759673957: VariantsMap = [
    &["pearlizes"],
    &["pearlises"],
    &["pearlizes"],
    &["pearlises"],
];

pub(crate) static ENTRY_PEARLIZE_1870800665189695789: VariantsMap =
    [&["pearlize"], &["pearlise"], &["pearlize"], &["pearlise"]];

pub(crate) static ENTRY_PEARLIZING_9707287977475426638: VariantsMap = [
    &["pearlizing"],
    &["pearlising"],
    &["pearlizing"],
    &["pearlising"],
];

pub(crate) static ENTRY_PEASANTIZES_10166156031855873894: VariantsMap = [
    &["peasantizes"],
    &["peasantises"],
    &["peasantizes"],
    &["peasantises"],
];

pub(crate) static ENTRY_PEASANTIZE_642017851460607948: VariantsMap = [
    &["peasantize"],
    &["peasantise"],
    &["peasantize"],
    &["peasantise"],
];

pub(crate) static ENTRY_PECTIZATIONS_4185232191919886847: VariantsMap = [
    &["pectizations"],
    &["pectisations"],
    &["pectizations"],
    &["pectisations"],
];

pub(crate) static ENTRY_PECTIZATION_11254255408733762028: VariantsMap = [
    &["pectization"],
    &["pectisation"],
    &["pectization"],
    &["pectisation"],
];

pub(crate) static ENTRY_PECTIZED_10449981344915979630: VariantsMap =
    [&["pectized"], &["pectised"], &["pectized"], &["pectised"]];

pub(crate) static ENTRY_PECTIZES_755598332277146179: VariantsMap =
    [&["pectizes"], &["pectises"], &["pectizes"], &["pectises"]];

pub(crate) static ENTRY_PECTIZE_5412505057526179714: VariantsMap =
    [&["pectize"], &["pectise"], &["pectize"], &["pectise"]];

pub(crate) static ENTRY_PECTIZING_3322743597581866011: VariantsMap = [
    &["pectizing"],
    &["pectising"],
    &["pectizing"],
    &["pectising"],
];

pub(crate) static ENTRY_PECULIARIZED_1005227671399616416: VariantsMap = [
    &["peculiarized"],
    &["peculiarised"],
    &["peculiarized"],
    &["peculiarised"],
];

pub(crate) static ENTRY_PECULIARIZES_4613690243312766864: VariantsMap = [
    &["peculiarizes"],
    &["peculiarises"],
    &["peculiarizes"],
    &["peculiarises"],
];

pub(crate) static ENTRY_PECULIARIZE_3060403711343105035: VariantsMap = [
    &["peculiarize"],
    &["peculiarise"],
    &["peculiarize"],
    &["peculiarise"],
];

pub(crate) static ENTRY_PECULIARIZING_2141506766135845761: VariantsMap = [
    &["peculiarizing"],
    &["peculiarising"],
    &["peculiarizing"],
    &["peculiarising"],
];

pub(crate) static ENTRY_PEDAGOGISM_2620385797924030298: VariantsMap = [
    &["pedagogism"],
    &["paedagogism"],
    &["paedagogism"],
    &["paedagogism"],
];

pub(crate) static ENTRY_PEDAGOGUES_16264776000371188720: VariantsMap = [
    &["pedagogues"],
    &["pedagogues"],
    &["pedagogues"],
    &["pedagogues"],
];

pub(crate) static ENTRY_PEDAGOGUE_5925453470466399155: VariantsMap = [
    &["pedagogue"],
    &["pedagogue"],
    &["pedagogue"],
    &["pedagogue"],
];

pub(crate) static ENTRY_PEDALED_7595673651683866382: VariantsMap =
    [&["pedaled"], &["pedalled"], &["pedalled"], &["pedalled"]];

pub(crate) static ENTRY_PEDALERS_4293589040040332936: VariantsMap = [
    &["pedalers"],
    &["pedallers"],
    &["pedallers"],
    &["pedallers"],
];

pub(crate) static ENTRY_PEDALER_10178424986842986369: VariantsMap =
    [&["pedaler"], &["pedaller"], &["pedaller"], &["pedaller"]];

pub(crate) static ENTRY_PEDALING_16638355318352644805: VariantsMap = [
    &["pedaling"],
    &["pedalling"],
    &["pedalling"],
    &["pedalling"],
];

pub(crate) static ENTRY_PEDANTICIZED_2644900939669971869: VariantsMap = [
    &["pedanticized"],
    &["pedanticised"],
    &["pedanticized"],
    &["pedanticised"],
];

pub(crate) static ENTRY_PEDANTICIZES_14833130317335097545: VariantsMap = [
    &["pedanticizes"],
    &["pedanticises"],
    &["pedanticizes"],
    &["pedanticises"],
];

pub(crate) static ENTRY_PEDANTICIZE_15008322026356551489: VariantsMap = [
    &["pedanticize"],
    &["pedanticise"],
    &["pedanticize"],
    &["pedanticise"],
];

pub(crate) static ENTRY_PEDANTICIZING_5200924377674025265: VariantsMap = [
    &["pedanticizing"],
    &["pedanticising"],
    &["pedanticizing"],
    &["pedanticising"],
];

pub(crate) static ENTRY_PEDANTIZED_7459552709032736273: VariantsMap = [
    &["pedantized"],
    &["pedantised"],
    &["pedantized"],
    &["pedantised"],
];

pub(crate) static ENTRY_PEDANTIZES_9391276727368944001: VariantsMap = [
    &["pedantizes"],
    &["pedantises"],
    &["pedantizes"],
    &["pedantises"],
];

pub(crate) static ENTRY_PEDANTIZE_692434760472693565: VariantsMap = [
    &["pedantize"],
    &["pedantise"],
    &["pedantize"],
    &["pedantise"],
];

pub(crate) static ENTRY_PEDANTIZING_12101236953723349590: VariantsMap = [
    &["pedantizing"],
    &["pedantising"],
    &["pedantizing"],
    &["pedantising"],
];

pub(crate) static ENTRY_PEDATROPHIA_11165730187451303309: VariantsMap = [
    &["pedatrophia"],
    &["paedatrophia"],
    &["paedatrophia"],
    &["paedatrophia"],
];

pub(crate) static ENTRY_PEDATROPHY_16866522103673061087: VariantsMap = [
    &["pedatrophy"],
    &["paedatrophy"],
    &["paedatrophy"],
    &["paedatrophy"],
];

pub(crate) static ENTRY_PEDDLERS_7582072568641139004: VariantsMap =
    [&["peddlers"], &["pedlars"], &["peddlers"], &["pedlars"]];

pub(crate) static ENTRY_PEDDLER_12988527131900246705: VariantsMap =
    [&["peddler"], &["pedlar"], &["peddler"], &["pedlar"]];

pub(crate) static ENTRY_PEDERASTICALLY_1594944586317571210: VariantsMap = [
    &["pederastically"],
    &["paederastically"],
    &["paederastically"],
    &["paederastically"],
];

pub(crate) static ENTRY_PEDERASTIC_17115437534756487424: VariantsMap = [
    &["pederastic"],
    &["paederastic"],
    &["paederastic"],
    &["paederastic"],
];

pub(crate) static ENTRY_PEDERASTS_10300182548635094556: VariantsMap = [
    &["pederasts"],
    &["pederasts"],
    &["pederasts"],
    &["pederasts"],
];

pub(crate) static ENTRY_PEDERAST_1403668280826164388: VariantsMap =
    [&["pederast"], &["pederast"], &["pederast"], &["pederast"]];

pub(crate) static ENTRY_PEDESTALED_5064702925171931752: VariantsMap = [
    &["pedestaled"],
    &["pedestalled"],
    &["pedestalled"],
    &["pedestalled"],
];

pub(crate) static ENTRY_PEDESTALING_5513881429185692140: VariantsMap = [
    &["pedestaling"],
    &["pedestalling"],
    &["pedestalling"],
    &["pedestalling"],
];

pub(crate) static ENTRY_PEDESTRIANIZATIONS_1818839118428039973: VariantsMap = [
    &["pedestrianizations"],
    &["pedestrianisations"],
    &["pedestrianizations"],
    &["pedestrianisations"],
];

pub(crate) static ENTRY_PEDESTRIANIZATION_6831974054939138972: VariantsMap = [
    &["pedestrianization"],
    &["pedestrianisation"],
    &["pedestrianization"],
    &["pedestrianisation"],
];

pub(crate) static ENTRY_PEDESTRIANIZED_6092822769668740533: VariantsMap = [
    &["pedestrianized"],
    &["pedestrianised"],
    &["pedestrianized"],
    &["pedestrianised"],
];

pub(crate) static ENTRY_PEDESTRIANIZES_4773122656566851623: VariantsMap = [
    &["pedestrianizes"],
    &["pedestrianises"],
    &["pedestrianizes"],
    &["pedestrianises"],
];

pub(crate) static ENTRY_PEDESTRIANIZE_8912536611462431290: VariantsMap = [
    &["pedestrianize"],
    &["pedestrianise"],
    &["pedestrianize"],
    &["pedestrianise"],
];

pub(crate) static ENTRY_PEDESTRIANIZING_6787761233409265782: VariantsMap = [
    &["pedestrianizing"],
    &["pedestrianising"],
    &["pedestrianizing"],
    &["pedestrianising"],
];

pub(crate) static ENTRY_PEDIATRICIANS_15463730532134461621: VariantsMap = [
    &["pediatricians"],
    &["paediatricians"],
    &["pediatricians"],
    &["paediatricians"],
];

pub(crate) static ENTRY_PEDIATRICIAN_4966154998070314122: VariantsMap = [
    &["pediatrician"],
    &["paediatrician"],
    &["pediatrician"],
    &["paediatrician"],
];

pub(crate) static ENTRY_PEDIATRICS_13936732030428661587: VariantsMap = [
    &["pediatrics"],
    &["paediatrics"],
    &["pediatrics"],
    &["paediatrics"],
];

pub(crate) static ENTRY_PEDIATRIC_15313872787895414938: VariantsMap = [
    &["pediatric"],
    &["paediatric"],
    &["pediatric"],
    &["paediatric"],
];

pub(crate) static ENTRY_PEDIATRY_2293953192712354696: VariantsMap = [
    &["pediatry"],
    &["paediatry"],
    &["paediatry"],
    &["paediatry"],
];

pub(crate) static ENTRY_PEDOBAPTISM_10804678125904355110: VariantsMap = [
    &["pedobaptism"],
    &["paedobaptism"],
    &["paedobaptism"],
    &["paedobaptism"],
];

pub(crate) static ENTRY_PEDOBAPTIST_17393232685703437549: VariantsMap = [
    &["pedobaptist"],
    &["paedobaptist"],
    &["paedobaptist"],
    &["paedobaptist"],
];

pub(crate) static ENTRY_PEDODONTICS_5640137182749900289: VariantsMap = [
    &["pedodontics"],
    &["paedodontics"],
    &["paedodontics"],
    &["paedodontics"],
];

pub(crate) static ENTRY_PEDODONTIC_10829590082192845044: VariantsMap = [
    &["pedodontic"],
    &["paedodontic"],
    &["paedodontic"],
    &["paedodontic"],
];

pub(crate) static ENTRY_PEDOGENESES_15579264777447032512: VariantsMap = [
    &["pedogeneses"],
    &["paedogeneses"],
    &["paedogeneses"],
    &["paedogeneses"],
];

pub(crate) static ENTRY_PEDOGENESIS_2691289146214329072: VariantsMap = [
    &["pedogenesis"],
    &["paedogenesis"],
    &["paedogenesis"],
    &["paedogenesis"],
];

pub(crate) static ENTRY_PEDOGENETIC_9300436022082143535: VariantsMap = [
    &["pedogenetic"],
    &["paedogenetic"],
    &["paedogenetic"],
    &["paedogenetic"],
];

pub(crate) static ENTRY_PEDOGENIC_15968023895342516337: VariantsMap = [
    &["pedogenic"],
    &["paedogenic"],
    &["paedogenic"],
    &["paedogenic"],
];

pub(crate) static ENTRY_PEDOLOGICAL_10471927294836257811: VariantsMap = [
    &["pedological"],
    &["paedological"],
    &["paedological"],
    &["paedological"],
];

pub(crate) static ENTRY_PEDOLOGIES_8776905115060190956: VariantsMap = [
    &["pedologies"],
    &["paedologies"],
    &["paedologies"],
    &["paedologies"],
];

pub(crate) static ENTRY_PEDOLOGISTS_1295482932093776852: VariantsMap = [
    &["pedologists"],
    &["paedologists"],
    &["paedologists"],
    &["paedologists"],
];

pub(crate) static ENTRY_PEDOLOGIST_17875058654848962441: VariantsMap = [
    &["pedologist"],
    &["paedologist"],
    &["paedologist"],
    &["paedologist"],
];

pub(crate) static ENTRY_PEDOLOGY_3417988831421593040: VariantsMap = [
    &["pedology"],
    &["paedology"],
    &["paedology"],
    &["paedology"],
];

pub(crate) static ENTRY_PEDOMETRICAL_11798284037226839595: VariantsMap = [
    &["pedometrical"],
    &["paedometrical"],
    &["paedometrical"],
    &["paedometrical"],
];

pub(crate) static ENTRY_PEDOMORPHIC_6860459212658075764: VariantsMap = [
    &["pedomorphic"],
    &["paedomorphic"],
    &["paedomorphic"],
    &["paedomorphic"],
];

pub(crate) static ENTRY_PEDOMORPHISMS_16472332478041997069: VariantsMap = [
    &["pedomorphisms"],
    &["paedomorphisms"],
    &["paedomorphisms"],
    &["paedomorphisms"],
];

pub(crate) static ENTRY_PEDOMORPHISM_1336265225990998891: VariantsMap = [
    &["pedomorphism"],
    &["paedomorphism"],
    &["paedomorphism"],
    &["paedomorphism"],
];

pub(crate) static ENTRY_PEDOMORPHOSES_11301460943449417276: VariantsMap = [
    &["pedomorphoses"],
    &["paedomorphoses"],
    &["paedomorphoses"],
    &["paedomorphoses"],
];

pub(crate) static ENTRY_PEDOMORPHOSIS_14966272193032820392: VariantsMap = [
    &["pedomorphosis"],
    &["paedomorphosis"],
    &["paedomorphosis"],
    &["paedomorphosis"],
];

pub(crate) static ENTRY_PEDOPHILES_4655841018136971409: VariantsMap = [
    &["pedophiles"],
    &["paedophiles"],
    &["pedophiles"],
    &["paedophiles"],
];

pub(crate) static ENTRY_PEDOPHILE_9927986055882192373: VariantsMap = [
    &["pedophile"],
    &["paedophile"],
    &["pedophile"],
    &["paedophile"],
];

pub(crate) static ENTRY_PEDOPHILIACS_9467101932093289852: VariantsMap = [
    &["pedophiliacs"],
    &["paedophiliacs"],
    &["paedophiliacs"],
    &["paedophiliacs"],
];

pub(crate) static ENTRY_PEDOPHILIAC_875642557192171107: VariantsMap = [
    &["pedophiliac"],
    &["paedophiliac"],
    &["paedophiliac"],
    &["paedophiliac"],
];

pub(crate) static ENTRY_PEDOPHILIAS_10406528979051385197: VariantsMap = [
    &["pedophilias"],
    &["paedophilias"],
    &["paedophilias"],
    &["paedophilias"],
];

pub(crate) static ENTRY_PEDOPHILIA_9946016916272449426: VariantsMap = [
    &["pedophilia"],
    &["paedophilia"],
    &["paedophilia"],
    &["paedophilia"],
];

pub(crate) static ENTRY_PEDOPHILIC_10586175930831437217: VariantsMap = [
    &["pedophilic"],
    &["paedophilic"],
    &["paedophilic"],
    &["paedophilic"],
];

pub(crate) static ENTRY_PEDOTRIBE_5791037896195905072: VariantsMap = [
    &["pedotribe"],
    &["paedotribe"],
    &["paedotribe"],
    &["paedotribe"],
];

pub(crate) static ENTRY_PEDOTROPHIC_4225819697418345119: VariantsMap = [
    &["pedotrophic"],
    &["paedotrophic"],
    &["paedotrophic"],
    &["paedotrophic"],
];

pub(crate) static ENTRY_PEDOTROPHIST_13613791383976217031: VariantsMap = [
    &["pedotrophist"],
    &["paedotrophist"],
    &["paedotrophist"],
    &["paedotrophist"],
];

pub(crate) static ENTRY_PEDOTROPHY_11224422965985252808: VariantsMap = [
    &["pedotrophy"],
    &["paedotrophy"],
    &["paedotrophy"],
    &["paedotrophy"],
];

pub(crate) static ENTRY_PEIZED_12509957894247332986: VariantsMap =
    [&["peized"], &["peised"], &["peized"], &["peised"]];

pub(crate) static ENTRY_PEIZES_2190131057773292627: VariantsMap =
    [&["peizes"], &["peises"], &["peizes"], &["peises"]];

pub(crate) static ENTRY_PEIZE_885907093702515829: VariantsMap =
    [&["peize"], &["peise"], &["peize"], &["peise"]];

pub(crate) static ENTRY_PEIZING_15796017161972728108: VariantsMap =
    [&["peizing"], &["peising"], &["peizing"], &["peising"]];

pub(crate) static ENTRY_PELLETIZATIONS_1053842567457998907: VariantsMap = [
    &["pelletizations"],
    &["pelletisations"],
    &["pelletizations"],
    &["pelletisations"],
];

pub(crate) static ENTRY_PELLETIZATION_6788072609952471440: VariantsMap = [
    &["pelletization"],
    &["pelletisation"],
    &["pelletization"],
    &["pelletisation"],
];

pub(crate) static ENTRY_PELLETIZED_3294804075577157384: VariantsMap = [
    &["pelletized"],
    &["pelletised"],
    &["pelletized"],
    &["pelletised"],
];

pub(crate) static ENTRY_PELLETIZER_17745386141239426126: VariantsMap = [
    &["pelletizer"],
    &["pelletiser"],
    &["pelletizer"],
    &["pelletiser"],
];

pub(crate) static ENTRY_PELLETIZES_1850622828084500629: VariantsMap = [
    &["pelletizes"],
    &["pelletises"],
    &["pelletizes"],
    &["pelletises"],
];

pub(crate) static ENTRY_PELLETIZE_14681817165893413798: VariantsMap = [
    &["pelletize"],
    &["pelletise"],
    &["pelletize"],
    &["pelletise"],
];

pub(crate) static ENTRY_PELLETIZING_9020807315258444838: VariantsMap = [
    &["pelletizing"],
    &["pelletising"],
    &["pelletizing"],
    &["pelletising"],
];

pub(crate) static ENTRY_PELORIZED_14193283977378715867: VariantsMap = [
    &["pelorized"],
    &["pelorised"],
    &["pelorized"],
    &["pelorised"],
];

pub(crate) static ENTRY_PEMMICANIZATIONS_17863458648609504163: VariantsMap = [
    &["pemmicanizations"],
    &["pemmicanisations"],
    &["pemmicanizations"],
    &["pemmicanisations"],
];

pub(crate) static ENTRY_PEMMICANIZATION_3498493847858548991: VariantsMap = [
    &["pemmicanization"],
    &["pemmicanisation"],
    &["pemmicanization"],
    &["pemmicanisation"],
];

pub(crate) static ENTRY_PEMMICANIZES_6099205721806444605: VariantsMap = [
    &["pemmicanizes"],
    &["pemmicanises"],
    &["pemmicanizes"],
    &["pemmicanises"],
];

pub(crate) static ENTRY_PEMMICANIZE_8863060726060100789: VariantsMap = [
    &["pemmicanize"],
    &["pemmicanise"],
    &["pemmicanize"],
    &["pemmicanise"],
];

pub(crate) static ENTRY_PENALIZABLER_10283897399997620359: VariantsMap = [
    &["penalizabler"],
    &["penalisabler"],
    &["penalizabler"],
    &["penalisabler"],
];

pub(crate) static ENTRY_PENALIZABLEST_16037788470703942853: VariantsMap = [
    &["penalizablest"],
    &["penalisablest"],
    &["penalizablest"],
    &["penalisablest"],
];

pub(crate) static ENTRY_PENALIZABLES_14294337734166643281: VariantsMap = [
    &["penalizables"],
    &["penalisables"],
    &["penalizables"],
    &["penalisables"],
];

pub(crate) static ENTRY_PENALIZABLE_16402490500753160561: VariantsMap = [
    &["penalizable"],
    &["penalisable"],
    &["penalizable"],
    &["penalisable"],
];

pub(crate) static ENTRY_PENALIZATIONS_9661842803190426071: VariantsMap = [
    &["penalizations"],
    &["penalisations"],
    &["penalizations"],
    &["penalisations"],
];

pub(crate) static ENTRY_PENALIZATION_17360891794071301320: VariantsMap = [
    &["penalization"],
    &["penalisation"],
    &["penalization"],
    &["penalisation"],
];

pub(crate) static ENTRY_PENALIZED_7857910456156235058: VariantsMap = [
    &["penalized"],
    &["penalised"],
    &["penalized"],
    &["penalised"],
];

pub(crate) static ENTRY_PENALIZES_3401061733632791919: VariantsMap = [
    &["penalizes"],
    &["penalises"],
    &["penalizes"],
    &["penalises"],
];

pub(crate) static ENTRY_PENALIZE_13430081598461307052: VariantsMap =
    [&["penalize"], &["penalise"], &["penalize"], &["penalise"]];

pub(crate) static ENTRY_PENALIZING_18001384479269088536: VariantsMap = [
    &["penalizing"],
    &["penalising"],
    &["penalizing"],
    &["penalising"],
];

pub(crate) static ENTRY_PENCILED_10698957931815950057: VariantsMap = [
    &["penciled"],
    &["pencilled"],
    &["pencilled"],
    &["pencilled"],
];

pub(crate) static ENTRY_PENCILERS_13737441358026249172: VariantsMap = [
    &["pencilers"],
    &["pencillers"],
    &["pencillers"],
    &["pencillers"],
];

pub(crate) static ENTRY_PENCILER_9299836922075131413: VariantsMap = [
    &["penciler"],
    &["penciller"],
    &["penciller"],
    &["penciller"],
];

pub(crate) static ENTRY_PENCILINGS_819897427661414754: VariantsMap = [
    &["pencilings"],
    &["pencillings"],
    &["pencillings"],
    &["pencillings"],
];

pub(crate) static ENTRY_PENCILING_13598020385460524085: VariantsMap = [
    &["penciling"],
    &["pencilling"],
    &["pencilling"],
    &["pencilling"],
];

pub(crate) static ENTRY_PENELOPIZED_16045288822105268504: VariantsMap = [
    &["penelopized"],
    &["penelopised"],
    &["penelopized"],
    &["penelopised"],
];

pub(crate) static ENTRY_PENELOPIZES_15812264060242899742: VariantsMap = [
    &["penelopizes"],
    &["penelopises"],
    &["penelopizes"],
    &["penelopises"],
];

pub(crate) static ENTRY_PENELOPIZE_222534767843534320: VariantsMap = [
    &["penelopize"],
    &["penelopise"],
    &["penelopize"],
    &["penelopise"],
];

pub(crate) static ENTRY_PENELOPIZING_9454561321061976299: VariantsMap = [
    &["penelopizing"],
    &["penelopising"],
    &["penelopizing"],
    &["penelopising"],
];

pub(crate) static ENTRY_PENNE_16194116927221501612: VariantsMap =
    [&["penne"], &["pennae"], &["pennae"], &["pennae"]];

pub(crate) static ENTRY_PENSE_14215361872352066210: VariantsMap =
    [&["pense"], &["pensae"], &["pensae"], &["pensae"]];

pub(crate) static ENTRY_PEPTIZABLES_15657004397021338874: VariantsMap = [
    &["peptizables"],
    &["peptisables"],
    &["peptizables"],
    &["peptisables"],
];

pub(crate) static ENTRY_PEPTIZABLE_13316576643501522207: VariantsMap = [
    &["peptizable"],
    &["peptisable"],
    &["peptizable"],
    &["peptisable"],
];

pub(crate) static ENTRY_PEPTIZATIONS_7100944985070861177: VariantsMap = [
    &["peptizations"],
    &["peptisations"],
    &["peptizations"],
    &["peptisations"],
];

pub(crate) static ENTRY_PEPTIZATION_5533911940283450501: VariantsMap = [
    &["peptization"],
    &["peptisation"],
    &["peptization"],
    &["peptisation"],
];

pub(crate) static ENTRY_PEPTIZED_15712022209384607271: VariantsMap =
    [&["peptized"], &["peptised"], &["peptized"], &["peptised"]];

pub(crate) static ENTRY_PEPTIZERS_969896506919570594: VariantsMap = [
    &["peptizers"],
    &["peptisers"],
    &["peptizers"],
    &["peptisers"],
];

pub(crate) static ENTRY_PEPTIZER_10333676369659848983: VariantsMap =
    [&["peptizer"], &["peptiser"], &["peptizer"], &["peptiser"]];

pub(crate) static ENTRY_PEPTIZES_5403839734258988322: VariantsMap =
    [&["peptizes"], &["peptises"], &["peptizes"], &["peptises"]];

pub(crate) static ENTRY_PEPTIZE_3206314528337021093: VariantsMap =
    [&["peptize"], &["peptise"], &["peptize"], &["peptise"]];

pub(crate) static ENTRY_PEPTIZING_15074374005726673747: VariantsMap = [
    &["peptizing"],
    &["peptising"],
    &["peptizing"],
    &["peptising"],
];

pub(crate) static ENTRY_PEPTONEMIA_8029620330697355971: VariantsMap = [
    &["peptonemia"],
    &["peptonaemia"],
    &["peptonaemia"],
    &["peptonaemia"],
];

pub(crate) static ENTRY_PEPTONIZATIONS_2407257450314860216: VariantsMap = [
    &["peptonizations"],
    &["peptonisations"],
    &["peptonizations"],
    &["peptonisations"],
];

pub(crate) static ENTRY_PEPTONIZATION_17372160958497222923: VariantsMap = [
    &["peptonization"],
    &["peptonisation"],
    &["peptonization"],
    &["peptonisation"],
];

pub(crate) static ENTRY_PEPTONIZED_13587359379059596523: VariantsMap = [
    &["peptonized"],
    &["peptonised"],
    &["peptonized"],
    &["peptonised"],
];

pub(crate) static ENTRY_PEPTONIZER_17508640818259226113: VariantsMap = [
    &["peptonizer"],
    &["peptoniser"],
    &["peptonizer"],
    &["peptoniser"],
];

pub(crate) static ENTRY_PEPTONIZES_1040139223657965665: VariantsMap = [
    &["peptonizes"],
    &["peptonises"],
    &["peptonizes"],
    &["peptonises"],
];

pub(crate) static ENTRY_PEPTONIZE_912826138201664087: VariantsMap = [
    &["peptonize"],
    &["peptonise"],
    &["peptonize"],
    &["peptonise"],
];

pub(crate) static ENTRY_PEPTONIZING_5828043672896126547: VariantsMap = [
    &["peptonizing"],
    &["peptonising"],
    &["peptonizing"],
    &["peptonising"],
];

pub(crate) static ENTRY_PERACIDITY_1147905095983877951: VariantsMap = [
    &["peracidity"],
    &["preacidity"],
    &["preacidity"],
    &["preacidity"],
];

pub(crate) static ENTRY_PERACID_17853350354268795572: VariantsMap =
    [&["peracid"], &["preacid"], &["preacid"], &["preacid"]];

pub(crate) static ENTRY_PERACT_16940258999462133608: VariantsMap =
    [&["peract"], &["preact"], &["preact"], &["preact"]];

pub(crate) static ENTRY_PERACUTE_2328162913715436273: VariantsMap =
    [&["peracute"], &["preacute"], &["preacute"], &["preacute"]];

pub(crate) static ENTRY_PERAMBULATORY_3211690938406856596: VariantsMap = [
    &["perambulatory"],
    &["preambulatory"],
    &["preambulatory"],
    &["preambulatory"],
];

pub(crate) static ENTRY_PERCES_984660829518258229: VariantsMap =
    [&["perces"], &["preces"], &["preces"], &["preces"]];

pub(crate) static ENTRY_PERCHLORETHANE_6974667202987518966: VariantsMap = [
    &["perchlorethane"],
    &["perchloroethane"],
    &["perchloroethane"],
    &["perchloroethane"],
];

pub(crate) static ENTRY_PERCHLORETHYLENE_3449824728229271694: VariantsMap = [
    &["perchlorethylene"],
    &["perchloroethylene"],
    &["perchloroethylene"],
    &["perchloroethylene"],
];

pub(crate) static ENTRY_PERCHLORIC_15808215951562951935: VariantsMap = [
    &["perchloric"],
    &["prechloric"],
    &["prechloric"],
    &["prechloric"],
];

pub(crate) static ENTRY_PERCLOSE_11470867655063256438: VariantsMap =
    [&["perclose"], &["preclose"], &["preclose"], &["preclose"]];

pub(crate) static ENTRY_PERCOMPOUND_414258272162299801: VariantsMap = [
    &["percompound"],
    &["precompound"],
    &["precompound"],
    &["precompound"],
];

pub(crate) static ENTRY_PERCURRENT_15522415679210362636: VariantsMap = [
    &["percurrent"],
    &["precurrent"],
    &["precurrent"],
    &["precurrent"],
];

pub(crate) static ENTRY_PERCUSSIONIZES_9711788919324651680: VariantsMap = [
    &["percussionizes"],
    &["percussionises"],
    &["percussionizes"],
    &["percussionises"],
];

pub(crate) static ENTRY_PERCUSSIONIZE_5158674871645362213: VariantsMap = [
    &["percussionize"],
    &["percussionise"],
    &["percussionize"],
    &["percussionise"],
];

pub(crate) static ENTRY_PERDICINE_4604747959856287967: VariantsMap = [
    &["perdicine"],
    &["perdicinae"],
    &["perdicinae"],
    &["perdicinae"],
];

pub(crate) static ENTRY_PERDILIGENT_5349792271361198811: VariantsMap = [
    &["perdiligent"],
    &["prediligent"],
    &["prediligent"],
    &["prediligent"],
];

pub(crate) static ENTRY_PERDY_1390936130181263743: VariantsMap =
    [&["perdy"], &["predy"], &["predy"], &["predy"]];

pub(crate) static ENTRY_PEREA_5147570010794111976: VariantsMap =
    [&["perea"], &["peraea"], &["peraea"], &["peraea"]];

pub(crate) static ENTRY_PERENNIALIZES_4803467841688723694: VariantsMap = [
    &["perennializes"],
    &["perennialises"],
    &["perennializes"],
    &["perennialises"],
];

pub(crate) static ENTRY_PERENNIALIZE_16426253784606656534: VariantsMap = [
    &["perennialize"],
    &["perennialise"],
    &["perennialize"],
    &["perennialise"],
];

pub(crate) static ENTRY_PEREON_16795200992980059464: VariantsMap =
    [&["pereon"], &["peraeon"], &["peraeon"], &["peraeon"]];

pub(crate) static ENTRY_PEREOPODS_14626696459269814659: VariantsMap = [
    &["pereopods"],
    &["peraeopods"],
    &["peraeopods"],
    &["peraeopods"],
];

pub(crate) static ENTRY_PEREOPOD_9605155749429362953: VariantsMap = [
    &["pereopod"],
    &["peraeopod"],
    &["peraeopod"],
    &["peraeopod"],
];

pub(crate) static ENTRY_PERFECTIVIZES_9087949345192893342: VariantsMap = [
    &["perfectivizes"],
    &["perfectivises"],
    &["perfectivizes"],
    &["perfectivises"],
];

pub(crate) static ENTRY_PERFECTIVIZE_12830499112403314573: VariantsMap = [
    &["perfectivize"],
    &["perfectivise"],
    &["perfectivize"],
    &["perfectivise"],
];

pub(crate) static ENTRY_PERFERVORS_3703900686039672985: VariantsMap = [
    &["perfervors"],
    &["perfervours"],
    &["perfervours"],
    &["perfervours"],
];

pub(crate) static ENTRY_PERFERVOR_514072560594963060: VariantsMap = [
    &["perfervor"],
    &["perfervour"],
    &["perfervour"],
    &["perfervour"],
];

pub(crate) static ENTRY_PERFET_12737033377426427677: VariantsMap =
    [&["perfet"], &["prefet"], &["prefet"], &["prefet"]];

pub(crate) static ENTRY_PERFOLIATIONS_5441070203325996418: VariantsMap = [
    &["perfoliations"],
    &["prefoliations"],
    &["prefoliations"],
    &["prefoliations"],
];

pub(crate) static ENTRY_PERFOLIATION_15643738965251302962: VariantsMap = [
    &["perfoliation"],
    &["prefoliation"],
    &["prefoliation"],
    &["prefoliation"],
];

pub(crate) static ENTRY_PERFORMANT_1886331341238867877: VariantsMap = [
    &["performant"],
    &["preformant"],
    &["preformant"],
    &["preformant"],
];

pub(crate) static ENTRY_PERFORMATIVE_11653583321194826668: VariantsMap = [
    &["performative"],
    &["preformative"],
    &["preformative"],
    &["preformative"],
];

pub(crate) static ENTRY_PERHAZARD_5172084758894143542: VariantsMap = [
    &["perhazard"],
    &["prehazard"],
    &["prehazard"],
    &["prehazard"],
];

pub(crate) static ENTRY_PERICECAL_5535752974684809547: VariantsMap = [
    &["pericecal"],
    &["pericaecal"],
    &["pericaecal"],
    &["pericaecal"],
];

pub(crate) static ENTRY_PERICECITIS_12086693101644590542: VariantsMap = [
    &["pericecitis"],
    &["pericaecitis"],
    &["pericaecitis"],
    &["pericaecitis"],
];

pub(crate) static ENTRY_PERICENTER_10108739404975251919: VariantsMap = [
    &["pericenter"],
    &["pericentre"],
    &["pericentre"],
    &["pericentre"],
];

pub(crate) static ENTRY_PERICHETE_2868508308788688470: VariantsMap = [
    &["perichete"],
    &["perichaete"],
    &["perichaete"],
    &["perichaete"],
];

pub(crate) static ENTRY_PERICOPE_2464029041518638801: VariantsMap = [
    &["pericope"],
    &["pericopae"],
    &["pericopae"],
    &["pericopae"],
];

pub(crate) static ENTRY_PERIESOPHAGEAL_9030912638833637940: VariantsMap = [
    &["periesophageal"],
    &["perioesophageal"],
    &["perioesophageal"],
    &["perioesophageal"],
];

pub(crate) static ENTRY_PERILED_4377735023565021754: VariantsMap =
    [&["periled"], &["perilled"], &["perilled"], &["perilled"]];

pub(crate) static ENTRY_PERILING_9472490737862744839: VariantsMap = [
    &["periling"],
    &["perilling"],
    &["perilling"],
    &["perilling"],
];

pub(crate) static ENTRY_PERIODICALIZES_7197610449394818524: VariantsMap = [
    &["periodicalizes"],
    &["periodicalises"],
    &["periodicalizes"],
    &["periodicalises"],
];

pub(crate) static ENTRY_PERIODICALIZE_16956000779487375960: VariantsMap = [
    &["periodicalize"],
    &["periodicalise"],
    &["periodicalize"],
    &["periodicalise"],
];

pub(crate) static ENTRY_PERIODIZATIONS_16536767337590632344: VariantsMap = [
    &["periodizations"],
    &["periodisations"],
    &["periodizations"],
    &["periodisations"],
];

pub(crate) static ENTRY_PERIODIZATION_5007045201160928503: VariantsMap = [
    &["periodization"],
    &["periodisation"],
    &["periodization"],
    &["periodisation"],
];

pub(crate) static ENTRY_PERIODIZED_14494857337622522468: VariantsMap = [
    &["periodized"],
    &["periodised"],
    &["periodized"],
    &["periodised"],
];

pub(crate) static ENTRY_PERIODIZES_184925638931471611: VariantsMap = [
    &["periodizes"],
    &["periodises"],
    &["periodizes"],
    &["periodises"],
];

pub(crate) static ENTRY_PERIODIZE_14073031487379844742: VariantsMap = [
    &["periodize"],
    &["periodise"],
    &["periodize"],
    &["periodise"],
];

pub(crate) static ENTRY_PERIODIZING_9095983531047177361: VariantsMap = [
    &["periodizing"],
    &["periodising"],
    &["periodizing"],
    &["periodising"],
];

pub(crate) static ENTRY_PERJINK_7961075561267618144: VariantsMap =
    [&["perjink"], &["prejink"], &["prejink"], &["prejink"]];

pub(crate) static ENTRY_PERLECTION_3296452498431632093: VariantsMap = [
    &["perlection"],
    &["prelection"],
    &["prelection"],
    &["prelection"],
];

pub(crate) static ENTRY_PERLINGUALLY_11928722645527217541: VariantsMap = [
    &["perlingually"],
    &["prelingually"],
    &["prelingually"],
    &["prelingually"],
];

pub(crate) static ENTRY_PERLINGUAL_3419901988075232474: VariantsMap = [
    &["perlingual"],
    &["prelingual"],
    &["prelingual"],
    &["prelingual"],
];

pub(crate) static ENTRY_PERMISSABLE_8744644961382997089: VariantsMap = [
    &["permissable"],
    &["premissable"],
    &["premissable"],
    &["premissable"],
];

pub(crate) static ENTRY_PERMIXTURE_15232799364862600989: VariantsMap = [
    &["permixture"],
    &["premixture"],
    &["premixture"],
    &["premixture"],
];

pub(crate) static ENTRY_PERNASAL_16102840364502673315: VariantsMap =
    [&["pernasal"], &["prenasal"], &["prenasal"], &["prenasal"]];

pub(crate) static ENTRY_PERORALLY_2346315785712029791: VariantsMap = [
    &["perorally"],
    &["preorally"],
    &["preorally"],
    &["preorally"],
];

pub(crate) static ENTRY_PERORAL_1577247151206222930: VariantsMap =
    [&["peroral"], &["preoral"], &["preoral"], &["preoral"]];

pub(crate) static ENTRY_PEROTIC_2582865836237824851: VariantsMap =
    [&["perotic"], &["preotic"], &["preotic"], &["preotic"]];

pub(crate) static ENTRY_PEROXIDIZED_501835571565398577: VariantsMap = [
    &["peroxidized"],
    &["peroxidised"],
    &["peroxidized"],
    &["peroxidised"],
];

pub(crate) static ENTRY_PEROXIDIZEMENTS_14879084608269866527: VariantsMap = [
    &["peroxidizements"],
    &["peroxidisements"],
    &["peroxidizements"],
    &["peroxidisements"],
];

pub(crate) static ENTRY_PEROXIDIZEMENT_15148226652591344641: VariantsMap = [
    &["peroxidizement"],
    &["peroxidisement"],
    &["peroxidizement"],
    &["peroxidisement"],
];

pub(crate) static ENTRY_PEROXIDIZES_2231452525489889274: VariantsMap = [
    &["peroxidizes"],
    &["peroxidises"],
    &["peroxidizes"],
    &["peroxidises"],
];

pub(crate) static ENTRY_PEROXIDIZE_15017198944556073397: VariantsMap = [
    &["peroxidize"],
    &["peroxidise"],
    &["peroxidize"],
    &["peroxidise"],
];

pub(crate) static ENTRY_PEROXIDIZING_9108083056272744022: VariantsMap = [
    &["peroxidizing"],
    &["peroxidising"],
    &["peroxidizing"],
    &["peroxidising"],
];

pub(crate) static ENTRY_PERPENDED_14779081215925715227: VariantsMap = [
    &["perpended"],
    &["prepended"],
    &["prepended"],
    &["prepended"],
];

pub(crate) static ENTRY_PERPENDING_9760848409550374555: VariantsMap = [
    &["perpending"],
    &["prepending"],
    &["prepending"],
    &["prepending"],
];

pub(crate) static ENTRY_PERPEND_7695504195883399642: VariantsMap =
    [&["perpend"], &["prepend"], &["prepend"], &["prepend"]];

pub(crate) static ENTRY_PERPERFECT_2601720249166533392: VariantsMap = [
    &["perperfect"],
    &["preperfect"],
    &["preperfect"],
    &["preperfect"],
];

pub(crate) static ENTRY_PERSE_13659628269605068524: VariantsMap =
    [&["perse"], &["persae"], &["persae"], &["persae"]];

pub(crate) static ENTRY_PERSE_2874440396224431051: VariantsMap =
    [&["perse"], &["prese"], &["prese"], &["prese"]];

pub(crate) static ENTRY_PERSIANIZATIONS_12804723289958534578: VariantsMap = [
    &["persianizations"],
    &["persianisations"],
    &["persianizations"],
    &["persianisations"],
];

pub(crate) static ENTRY_PERSIANIZATION_10456152347071316181: VariantsMap = [
    &["persianization"],
    &["persianisation"],
    &["persianization"],
    &["persianisation"],
];

pub(crate) static ENTRY_PERSIANIZED_9516440395848303807: VariantsMap = [
    &["persianized"],
    &["persianised"],
    &["persianized"],
    &["persianised"],
];

pub(crate) static ENTRY_PERSIANIZES_9445770532797771551: VariantsMap = [
    &["persianizes"],
    &["persianises"],
    &["persianizes"],
    &["persianises"],
];

pub(crate) static ENTRY_PERSIANIZE_10319509138110538325: VariantsMap = [
    &["persianize"],
    &["persianise"],
    &["persianize"],
    &["persianise"],
];

pub(crate) static ENTRY_PERSIANIZING_12004543135849853067: VariantsMap = [
    &["persianizing"],
    &["persianising"],
    &["persianizing"],
    &["persianising"],
];

pub(crate) static ENTRY_PERSICIZED_8426958054366327606: VariantsMap = [
    &["persicized"],
    &["persicised"],
    &["persicized"],
    &["persicised"],
];

pub(crate) static ENTRY_PERSICIZES_3173733872542747533: VariantsMap = [
    &["persicizes"],
    &["persicises"],
    &["persicizes"],
    &["persicises"],
];

pub(crate) static ENTRY_PERSICIZE_9817820256246452496: VariantsMap = [
    &["persicize"],
    &["persicise"],
    &["persicize"],
    &["persicise"],
];

pub(crate) static ENTRY_PERSICIZING_345314971166446532: VariantsMap = [
    &["persicizing"],
    &["persicising"],
    &["persicizing"],
    &["persicising"],
];

pub(crate) static ENTRY_PERSOLVE_11803654124888842880: VariantsMap =
    [&["persolve"], &["presolve"], &["presolve"], &["presolve"]];

pub(crate) static ENTRY_PERSONALIZATIONS_3072710456827540417: VariantsMap = [
    &["personalizations"],
    &["personalisations"],
    &["personalizations"],
    &["personalisations"],
];

pub(crate) static ENTRY_PERSONALIZATION_8393077675198614709: VariantsMap = [
    &["personalization"],
    &["personalisation"],
    &["personalization"],
    &["personalisation"],
];

pub(crate) static ENTRY_PERSONALIZED_8380116593820467680: VariantsMap = [
    &["personalized"],
    &["personalised"],
    &["personalized"],
    &["personalised"],
];

pub(crate) static ENTRY_PERSONALIZES_8288542045462193378: VariantsMap = [
    &["personalizes"],
    &["personalises"],
    &["personalizes"],
    &["personalises"],
];

pub(crate) static ENTRY_PERSONALIZE_4748948411684788546: VariantsMap = [
    &["personalize"],
    &["personalise"],
    &["personalize"],
    &["personalise"],
];

pub(crate) static ENTRY_PERSONALIZING_6482443885062681058: VariantsMap = [
    &["personalizing"],
    &["personalising"],
    &["personalizing"],
    &["personalising"],
];

pub(crate) static ENTRY_PERSONIZATIONS_2363579352700768230: VariantsMap = [
    &["personizations"],
    &["personisations"],
    &["personizations"],
    &["personisations"],
];

pub(crate) static ENTRY_PERSONIZATION_15871628578229626875: VariantsMap = [
    &["personization"],
    &["personisation"],
    &["personization"],
    &["personisation"],
];

pub(crate) static ENTRY_PERSONIZED_13450813166358378857: VariantsMap = [
    &["personized"],
    &["personised"],
    &["personized"],
    &["personised"],
];

pub(crate) static ENTRY_PERSONIZES_990720830743251132: VariantsMap = [
    &["personizes"],
    &["personises"],
    &["personizes"],
    &["personises"],
];

pub(crate) static ENTRY_PERSONIZE_13482080998389432603: VariantsMap = [
    &["personize"],
    &["personise"],
    &["personize"],
    &["personise"],
];

pub(crate) static ENTRY_PERSONIZING_14903686723706359501: VariantsMap = [
    &["personizing"],
    &["personising"],
    &["personizing"],
    &["personising"],
];

pub(crate) static ENTRY_PERST_10410873219912667942: VariantsMap =
    [&["perst"], &["prest"], &["prest"], &["prest"]];

pub(crate) static ENTRY_PERUVIANIZES_14090175275525112564: VariantsMap = [
    &["peruvianizes"],
    &["peruvianises"],
    &["peruvianizes"],
    &["peruvianises"],
];

pub(crate) static ENTRY_PERUVIANIZE_6382627651753832553: VariantsMap = [
    &["peruvianize"],
    &["peruvianise"],
    &["peruvianize"],
    &["peruvianise"],
];

pub(crate) static ENTRY_PERVED_18208319127618556214: VariantsMap =
    [&["perved"], &["preved"], &["preved"], &["preved"]];

pub(crate) static ENTRY_PERVES_5996851197956304566: VariantsMap =
    [&["perves"], &["preves"], &["preves"], &["preves"]];

pub(crate) static ENTRY_PERVE_18165674324823475517: VariantsMap =
    [&["perve"], &["preve"], &["preve"], &["preve"]];

pub(crate) static ENTRY_PERVIABLE_4699952660241611906: VariantsMap = [
    &["perviable"],
    &["previable"],
    &["previable"],
    &["previable"],
];

pub(crate) static ENTRY_PERVING_12586188415039019252: VariantsMap =
    [&["perving"], &["preving"], &["preving"], &["preving"]];

pub(crate) static ENTRY_PERVIOUSNESSES_15261112133254148006: VariantsMap = [
    &["perviousnesses"],
    &["previousnesses"],
    &["previousnesses"],
    &["previousnesses"],
];

pub(crate) static ENTRY_PERVIOUSNESS_4962441648916650935: VariantsMap = [
    &["perviousness"],
    &["previousness"],
    &["previousness"],
    &["previousness"],
];

pub(crate) static ENTRY_PERV_1140727827150260852: VariantsMap =
    [&["perv"], &["prev"], &["prev"], &["prev"]];

pub(crate) static ENTRY_PETALED_67675403619589060: VariantsMap =
    [&["petaled"], &["petalled"], &["petalled"], &["petalled"]];

pub(crate) static ENTRY_PETLING_4679867327279057417: VariantsMap =
    [&["petling"], &["poetling"], &["poetling"], &["poetling"]];

pub(crate) static ENTRY_PETRARCHIZED_7254765400339686109: VariantsMap = [
    &["petrarchized"],
    &["petrarchised"],
    &["petrarchized"],
    &["petrarchised"],
];

pub(crate) static ENTRY_PETRARCHIZES_4178876562035449090: VariantsMap = [
    &["petrarchizes"],
    &["petrarchises"],
    &["petrarchizes"],
    &["petrarchises"],
];

pub(crate) static ENTRY_PETRARCHIZE_7900319410477587125: VariantsMap = [
    &["petrarchize"],
    &["petrarchise"],
    &["petrarchize"],
    &["petrarchise"],
];

pub(crate) static ENTRY_PETRARCHIZING_12012636599315128862: VariantsMap = [
    &["petrarchizing"],
    &["petrarchising"],
    &["petrarchizing"],
    &["petrarchising"],
];

pub(crate) static ENTRY_PETROLIZATIONS_7511909901714380822: VariantsMap = [
    &["petrolizations"],
    &["petrolisations"],
    &["petrolizations"],
    &["petrolisations"],
];

pub(crate) static ENTRY_PETROLIZATION_16999409919613399973: VariantsMap = [
    &["petrolization"],
    &["petrolisation"],
    &["petrolization"],
    &["petrolisation"],
];

pub(crate) static ENTRY_PETROLIZES_4132811127736998863: VariantsMap = [
    &["petrolizes"],
    &["petrolises"],
    &["petrolizes"],
    &["petrolises"],
];

pub(crate) static ENTRY_PETROLIZE_7665552287162264221: VariantsMap = [
    &["petrolize"],
    &["petrolise"],
    &["petrolize"],
    &["petrolise"],
];

pub(crate) static ENTRY_PE_11577855917495375674: VariantsMap =
    [&["pe"], &["poe"], &["poe"], &["poe"]];

pub(crate) static ENTRY_PHACOCHERE_4955198037695802664: VariantsMap = [
    &["phacochere"],
    &["phacochoere"],
    &["phacochoere"],
    &["phacochoere"],
];

pub(crate) static ENTRY_PHACOCHERINE_10095812869794876875: VariantsMap = [
    &["phacocherine"],
    &["phacochoerine"],
    &["phacochoerine"],
    &["phacochoerine"],
];

pub(crate) static ENTRY_PHAENNA_6872669718419162795: VariantsMap =
    [&["phaenna"], &["phaaenna"], &["phaaenna"], &["phaaenna"]];

pub(crate) static ENTRY_PHAGEDENAS_11187954412184935604: VariantsMap = [
    &["phagedenas"],
    &["phagedaenas"],
    &["phagedaenas"],
    &["phagedaenas"],
];

pub(crate) static ENTRY_PHAGEDENA_317734246379814153: VariantsMap = [
    &["phagedena"],
    &["phagedaena"],
    &["phagedaena"],
    &["phagedaena"],
];

pub(crate) static ENTRY_PHAGEDENICAL_16284853943068372065: VariantsMap = [
    &["phagedenical"],
    &["phagedaenical"],
    &["phagedaenical"],
    &["phagedaenical"],
];

pub(crate) static ENTRY_PHAGEDENIC_17318315545560183857: VariantsMap = [
    &["phagedenic"],
    &["phagedaenic"],
    &["phagedaenic"],
    &["phagedaenic"],
];

pub(crate) static ENTRY_PHAGEDENOUS_1804302093376783588: VariantsMap = [
    &["phagedenous"],
    &["phagedaenous"],
    &["phagedaenous"],
    &["phagedaenous"],
];

pub(crate) static ENTRY_PHAGOCYTIZES_5484801342814585347: VariantsMap = [
    &["phagocytizes"],
    &["phagocytises"],
    &["phagocytizes"],
    &["phagocytises"],
];

pub(crate) static ENTRY_PHAGOCYTIZE_14412062490428630989: VariantsMap = [
    &["phagocytize"],
    &["phagocytise"],
    &["phagocytize"],
    &["phagocytise"],
];

pub(crate) static ENTRY_PHANTOMIZERS_12075504307273453169: VariantsMap = [
    &["phantomizers"],
    &["phantomisers"],
    &["phantomizers"],
    &["phantomisers"],
];

pub(crate) static ENTRY_PHANTOMIZER_15050193001568501253: VariantsMap = [
    &["phantomizer"],
    &["phantomiser"],
    &["phantomizer"],
    &["phantomiser"],
];

pub(crate) static ENTRY_PHANTOMIZES_5888358266315867784: VariantsMap = [
    &["phantomizes"],
    &["phantomises"],
    &["phantomizes"],
    &["phantomises"],
];

pub(crate) static ENTRY_PHANTOMIZE_9606576662403812455: VariantsMap = [
    &["phantomize"],
    &["phantomise"],
    &["phantomize"],
    &["phantomise"],
];

pub(crate) static ENTRY_PHARISEAN_2326065742596188618: VariantsMap = [
    &["pharisean"],
    &["pharisaean"],
    &["pharisaean"],
    &["pharisaean"],
];

pub(crate) static ENTRY_PHARMACOPEIAN_4683846151180244693: VariantsMap = [
    &["pharmacopeian"],
    &["pharmacopoeian"],
    &["pharmacopoeian"],
    &["pharmacopoeian"],
];

pub(crate) static ENTRY_PHARMACOPOEIAL_11804050835567169007: VariantsMap = [
    &["pharmacopoeial"],
    &["pharmacopoeial"],
    &["pharmacopoeial"],
    &["pharmacopoeial"],
];

pub(crate) static ENTRY_PHELONIONS_7275701311297650329: VariantsMap = [
    &["phelonions"],
    &["phaelonions"],
    &["phaelonions"],
    &["phaelonions"],
];

pub(crate) static ENTRY_PHELONION_6969396090547227356: VariantsMap = [
    &["phelonion"],
    &["phaelonion"],
    &["phaelonion"],
    &["phaelonion"],
];

pub(crate) static ENTRY_PHENICIA_14934589472014784294: VariantsMap = [
    &["phenicia"],
    &["phoenicia"],
    &["phoenicia"],
    &["phoenicia"],
];

pub(crate) static ENTRY_PHENICOPTER_102813840191262241: VariantsMap = [
    &["phenicopter"],
    &["phoenicopter"],
    &["phoenicopter"],
    &["phoenicopter"],
];

pub(crate) static ENTRY_PHENOGAMS_16570370822932628992: VariantsMap = [
    &["phenogams"],
    &["phaenogams"],
    &["phaenogams"],
    &["phaenogams"],
];

pub(crate) static ENTRY_PHENOGAM_2031537475522870003: VariantsMap = [
    &["phenogam"],
    &["phaenogam"],
    &["phaenogam"],
    &["phaenogam"],
];

pub(crate) static ENTRY_PHENOGENESIS_17567829228271993340: VariantsMap = [
    &["phenogenesis"],
    &["phaenogenesis"],
    &["phaenogenesis"],
    &["phaenogenesis"],
];

pub(crate) static ENTRY_PHENOGENETIC_17720618598147822936: VariantsMap = [
    &["phenogenetic"],
    &["phaenogenetic"],
    &["phaenogenetic"],
    &["phaenogenetic"],
];

pub(crate) static ENTRY_PHENOLIZATIONS_14432785009139345517: VariantsMap = [
    &["phenolizations"],
    &["phenolisations"],
    &["phenolizations"],
    &["phenolisations"],
];

pub(crate) static ENTRY_PHENOLIZATION_2757248655281103600: VariantsMap = [
    &["phenolization"],
    &["phenolisation"],
    &["phenolization"],
    &["phenolisation"],
];

pub(crate) static ENTRY_PHENOLIZES_7668478898891743701: VariantsMap = [
    &["phenolizes"],
    &["phenolises"],
    &["phenolizes"],
    &["phenolises"],
];

pub(crate) static ENTRY_PHENOLIZE_13707720084951712605: VariantsMap = [
    &["phenolize"],
    &["phenolise"],
    &["phenolize"],
    &["phenolise"],
];

pub(crate) static ENTRY_PHENOLOGICAL_18143589645340253850: VariantsMap = [
    &["phenological"],
    &["phaenological"],
    &["phaenological"],
    &["phaenological"],
];

pub(crate) static ENTRY_PHENOLOGIES_16864158914924322992: VariantsMap = [
    &["phenologies"],
    &["phaenologies"],
    &["phaenologies"],
    &["phaenologies"],
];

pub(crate) static ENTRY_PHENOLOGY_10696299477585495820: VariantsMap = [
    &["phenology"],
    &["phaenology"],
    &["phaenology"],
    &["phaenology"],
];

pub(crate) static ENTRY_PHENOMENALIZATIONS_14204828183062550964: VariantsMap = [
    &["phenomenalizations"],
    &["phenomenalisations"],
    &["phenomenalizations"],
    &["phenomenalisations"],
];

pub(crate) static ENTRY_PHENOMENALIZATION_3655891833450393811: VariantsMap = [
    &["phenomenalization"],
    &["phenomenalisation"],
    &["phenomenalization"],
    &["phenomenalisation"],
];

pub(crate) static ENTRY_PHENOMENALIZED_5794978347542150916: VariantsMap = [
    &["phenomenalized"],
    &["phenomenalised"],
    &["phenomenalized"],
    &["phenomenalised"],
];

pub(crate) static ENTRY_PHENOMENALIZES_14468079307814950479: VariantsMap = [
    &["phenomenalizes"],
    &["phenomenalises"],
    &["phenomenalizes"],
    &["phenomenalises"],
];

pub(crate) static ENTRY_PHENOMENALIZE_11717565309304041099: VariantsMap = [
    &["phenomenalize"],
    &["phenomenalise"],
    &["phenomenalize"],
    &["phenomenalise"],
];

pub(crate) static ENTRY_PHENOMENALIZING_15597205978617856018: VariantsMap = [
    &["phenomenalizing"],
    &["phenomenalising"],
    &["phenomenalizing"],
    &["phenomenalising"],
];

pub(crate) static ENTRY_PHENOMENISM_5615148023723810129: VariantsMap = [
    &["phenomenism"],
    &["phaenomenism"],
    &["phaenomenism"],
    &["phaenomenism"],
];

pub(crate) static ENTRY_PHENOMENIZED_1139593925364905286: VariantsMap = [
    &["phenomenized"],
    &["phenomenised"],
    &["phenomenized"],
    &["phenomenised"],
];

pub(crate) static ENTRY_PHENOMENIZES_17606511759958816816: VariantsMap = [
    &["phenomenizes"],
    &["phenomenises"],
    &["phenomenizes"],
    &["phenomenises"],
];

pub(crate) static ENTRY_PHENOMENIZE_9110544169399242876: VariantsMap = [
    &["phenomenize"],
    &["phenomenise"],
    &["phenomenize"],
    &["phenomenise"],
];

pub(crate) static ENTRY_PHENOMENIZING_6848532127265778662: VariantsMap = [
    &["phenomenizing"],
    &["phenomenising"],
    &["phenomenizing"],
    &["phenomenising"],
];

pub(crate) static ENTRY_PHENOZYGOUS_10218199328032200205: VariantsMap = [
    &["phenozygous"],
    &["phaenozygous"],
    &["phaenozygous"],
    &["phaenozygous"],
];

pub(crate) static ENTRY_PHEOPHYLL_17122888113078909815: VariantsMap = [
    &["pheophyll"],
    &["phaeophyll"],
    &["phaeophyll"],
    &["phaeophyll"],
];

pub(crate) static ENTRY_PHEOPHYL_11552466584906711269: VariantsMap = [
    &["pheophyl"],
    &["phaeophyl"],
    &["phaeophyl"],
    &["phaeophyl"],
];

pub(crate) static ENTRY_PHEOPHYTIN_2724547005457304078: VariantsMap = [
    &["pheophytin"],
    &["phaeophytin"],
    &["phaeophytin"],
    &["phaeophytin"],
];

pub(crate) static ENTRY_PHIALE_15569191502692089501: VariantsMap =
    [&["phiale"], &["phialae"], &["phialae"], &["phialae"]];

pub(crate) static ENTRY_PHILANTHROPIZED_17491092524543553798: VariantsMap = [
    &["philanthropized"],
    &["philanthropised"],
    &["philanthropized"],
    &["philanthropised"],
];

pub(crate) static ENTRY_PHILANTHROPIZES_151487037009790340: VariantsMap = [
    &["philanthropizes"],
    &["philanthropises"],
    &["philanthropizes"],
    &["philanthropises"],
];

pub(crate) static ENTRY_PHILANTHROPIZE_12054368829621898817: VariantsMap = [
    &["philanthropize"],
    &["philanthropise"],
    &["philanthropize"],
    &["philanthropise"],
];

pub(crate) static ENTRY_PHILANTHROPIZING_8217762732269119746: VariantsMap = [
    &["philanthropizing"],
    &["philanthropising"],
    &["philanthropizing"],
    &["philanthropising"],
];

pub(crate) static ENTRY_PHILIPPIZED_178919350171556335: VariantsMap = [
    &["philippized"],
    &["philippised"],
    &["philippized"],
    &["philippised"],
];

pub(crate) static ENTRY_PHILIPPIZES_14363488635976035891: VariantsMap = [
    &["philippizes"],
    &["philippises"],
    &["philippizes"],
    &["philippises"],
];

pub(crate) static ENTRY_PHILIPPIZE_9477479770062521505: VariantsMap = [
    &["philippize"],
    &["philippise"],
    &["philippize"],
    &["philippise"],
];

pub(crate) static ENTRY_PHILIPPIZING_12349528995152369239: VariantsMap = [
    &["philippizing"],
    &["philippising"],
    &["philippizing"],
    &["philippising"],
];

pub(crate) static ENTRY_PHILISTINIZED_6164180281250753702: VariantsMap = [
    &["philistinized"],
    &["philistinised"],
    &["philistinized"],
    &["philistinised"],
];

pub(crate) static ENTRY_PHILISTINIZES_3022920025750648291: VariantsMap = [
    &["philistinizes"],
    &["philistinises"],
    &["philistinizes"],
    &["philistinises"],
];

pub(crate) static ENTRY_PHILISTINIZE_16879618291594956234: VariantsMap = [
    &["philistinize"],
    &["philistinise"],
    &["philistinize"],
    &["philistinise"],
];

pub(crate) static ENTRY_PHILISTINIZING_14787991683374543288: VariantsMap = [
    &["philistinizing"],
    &["philistinising"],
    &["philistinizing"],
    &["philistinising"],
];

pub(crate) static ENTRY_PHILOPENAS_8942731290254359945: VariantsMap = [
    &["philopenas"],
    &["philopoenas"],
    &["philopoenas"],
    &["philopoenas"],
];

pub(crate) static ENTRY_PHILOPENA_14474550932692405335: VariantsMap = [
    &["philopena"],
    &["philopoena"],
    &["philopoena"],
    &["philopoena"],
];

pub(crate) static ENTRY_PHILOSOPHIZATIONS_1471954898649055414: VariantsMap = [
    &["philosophizations"],
    &["philosophisations"],
    &["philosophizations"],
    &["philosophisations"],
];

pub(crate) static ENTRY_PHILOSOPHIZATION_16601469055263628196: VariantsMap = [
    &["philosophization"],
    &["philosophisation"],
    &["philosophization"],
    &["philosophisation"],
];

pub(crate) static ENTRY_PHILOSOPHIZED_11971381862609038159: VariantsMap = [
    &["philosophized"],
    &["philosophised"],
    &["philosophized"],
    &["philosophised"],
];

pub(crate) static ENTRY_PHILOSOPHIZERS_9374939330362272451: VariantsMap = [
    &["philosophizers"],
    &["philosophisers"],
    &["philosophizers"],
    &["philosophisers"],
];

pub(crate) static ENTRY_PHILOSOPHIZER_1947368971791216137: VariantsMap = [
    &["philosophizer"],
    &["philosophiser"],
    &["philosophizer"],
    &["philosophiser"],
];

pub(crate) static ENTRY_PHILOSOPHIZES_9120030685330947055: VariantsMap = [
    &["philosophizes"],
    &["philosophises"],
    &["philosophizes"],
    &["philosophises"],
];

pub(crate) static ENTRY_PHILOSOPHIZE_13043053738496452138: VariantsMap = [
    &["philosophize"],
    &["philosophise"],
    &["philosophize"],
    &["philosophise"],
];

pub(crate) static ENTRY_PHILOSOPHIZING_7182661913083580067: VariantsMap = [
    &["philosophizing"],
    &["philosophising"],
    &["philosophizing"],
    &["philosophising"],
];

pub(crate) static ENTRY_PHILTERS_13502292058065280597: VariantsMap =
    [&["philters"], &["philtres"], &["philtres"], &["philtres"]];

pub(crate) static ENTRY_PHILTER_15997600924358339768: VariantsMap =
    [&["philter"], &["philtre"], &["philtre"], &["philtre"]];

pub(crate) static ENTRY_PHLEBOTOMIZATIONS_3737256506686661609: VariantsMap = [
    &["phlebotomizations"],
    &["phlebotomisations"],
    &["phlebotomizations"],
    &["phlebotomisations"],
];

pub(crate) static ENTRY_PHLEBOTOMIZATION_17488495197793456474: VariantsMap = [
    &["phlebotomization"],
    &["phlebotomisation"],
    &["phlebotomization"],
    &["phlebotomisation"],
];

pub(crate) static ENTRY_PHLEBOTOMIZED_970872551213502213: VariantsMap = [
    &["phlebotomized"],
    &["phlebotomised"],
    &["phlebotomized"],
    &["phlebotomised"],
];

pub(crate) static ENTRY_PHLEBOTOMIZES_14047846782365849478: VariantsMap = [
    &["phlebotomizes"],
    &["phlebotomises"],
    &["phlebotomizes"],
    &["phlebotomises"],
];

pub(crate) static ENTRY_PHLEBOTOMIZE_13394579245233538581: VariantsMap = [
    &["phlebotomize"],
    &["phlebotomise"],
    &["phlebotomize"],
    &["phlebotomise"],
];

pub(crate) static ENTRY_PHLEBOTOMIZING_11774110694895870408: VariantsMap = [
    &["phlebotomizing"],
    &["phlebotomising"],
    &["phlebotomizing"],
    &["phlebotomising"],
];

pub(crate) static ENTRY_PHLEUM_16719770166396319761: VariantsMap =
    [&["phleum"], &["phloeum"], &["phloeum"], &["phloeum"]];

pub(crate) static ENTRY_PHLYCTENAE_12296549464075244070: VariantsMap = [
    &["phlyctenae"],
    &["phlyctaenae"],
    &["phlyctaenae"],
    &["phlyctaenae"],
];

pub(crate) static ENTRY_PHLYCTENA_8261775604592086893: VariantsMap = [
    &["phlyctena"],
    &["phlyctaena"],
    &["phlyctaena"],
    &["phlyctaena"],
];

pub(crate) static ENTRY_PHLYCTENULA_6345950092510926138: VariantsMap = [
    &["phlyctenula"],
    &["phlyctaenula"],
    &["phlyctaenula"],
    &["phlyctaenula"],
];

pub(crate) static ENTRY_PHOCEAN_7579607581288728415: VariantsMap =
    [&["phocean"], &["phocaean"], &["phocaean"], &["phocaean"]];

pub(crate) static ENTRY_PHONEMICIZATIONS_11036149124276358577: VariantsMap = [
    &["phonemicizations"],
    &["phonemicisations"],
    &["phonemicizations"],
    &["phonemicisations"],
];

pub(crate) static ENTRY_PHONEMICIZATION_6303074211462240322: VariantsMap = [
    &["phonemicization"],
    &["phonemicisation"],
    &["phonemicization"],
    &["phonemicisation"],
];

pub(crate) static ENTRY_PHONEMICIZED_17232917412462599644: VariantsMap = [
    &["phonemicized"],
    &["phonemicised"],
    &["phonemicized"],
    &["phonemicised"],
];

pub(crate) static ENTRY_PHONEMICIZES_17606626718946608666: VariantsMap = [
    &["phonemicizes"],
    &["phonemicises"],
    &["phonemicizes"],
    &["phonemicises"],
];

pub(crate) static ENTRY_PHONEMICIZE_1810541375439591225: VariantsMap = [
    &["phonemicize"],
    &["phonemicise"],
    &["phonemicize"],
    &["phonemicise"],
];

pub(crate) static ENTRY_PHONEMICIZING_15981242182632342378: VariantsMap = [
    &["phonemicizing"],
    &["phonemicising"],
    &["phonemicizing"],
    &["phonemicising"],
];

pub(crate) static ENTRY_PHONETICIZATIONS_12272721619858915699: VariantsMap = [
    &["phoneticizations"],
    &["phoneticisations"],
    &["phoneticizations"],
    &["phoneticisations"],
];

pub(crate) static ENTRY_PHONETICIZATION_6365986386084047589: VariantsMap = [
    &["phoneticization"],
    &["phoneticisation"],
    &["phoneticization"],
    &["phoneticisation"],
];

pub(crate) static ENTRY_PHONETICIZED_10076514556044395589: VariantsMap = [
    &["phoneticized"],
    &["phoneticised"],
    &["phoneticized"],
    &["phoneticised"],
];

pub(crate) static ENTRY_PHONETICIZES_5738497385018760916: VariantsMap = [
    &["phoneticizes"],
    &["phoneticises"],
    &["phoneticizes"],
    &["phoneticises"],
];

pub(crate) static ENTRY_PHONETICIZE_2002370945385634969: VariantsMap = [
    &["phoneticize"],
    &["phoneticise"],
    &["phoneticize"],
    &["phoneticise"],
];

pub(crate) static ENTRY_PHONETICIZING_10352945092040857910: VariantsMap = [
    &["phoneticizing"],
    &["phoneticising"],
    &["phoneticizing"],
    &["phoneticising"],
];

pub(crate) static ENTRY_PHONETIZATIONS_1478303085829485731: VariantsMap = [
    &["phonetizations"],
    &["phonetisations"],
    &["phonetizations"],
    &["phonetisations"],
];

pub(crate) static ENTRY_PHONETIZATION_5080772382710194175: VariantsMap = [
    &["phonetization"],
    &["phonetisation"],
    &["phonetization"],
    &["phonetisation"],
];

pub(crate) static ENTRY_PHONETIZED_11767329492705150794: VariantsMap = [
    &["phonetized"],
    &["phonetised"],
    &["phonetized"],
    &["phonetised"],
];

pub(crate) static ENTRY_PHONETIZES_242560119274525330: VariantsMap = [
    &["phonetizes"],
    &["phonetises"],
    &["phonetizes"],
    &["phonetises"],
];

pub(crate) static ENTRY_PHONETIZE_3810717706362844733: VariantsMap = [
    &["phonetize"],
    &["phonetise"],
    &["phonetize"],
    &["phonetise"],
];

pub(crate) static ENTRY_PHONETIZING_14395480576666108961: VariantsMap = [
    &["phonetizing"],
    &["phonetising"],
    &["phonetizing"],
    &["phonetising"],
];

pub(crate) static ENTRY_PHONIED_13398169357989663661: VariantsMap =
    [&["phonied"], &["phonied"], &["phonied"], &["phonied"]];

pub(crate) static ENTRY_PHONYING_3078208997195609574: VariantsMap =
    [&["phonying"], &["phonying"], &["phonying"], &["phonying"]];

pub(crate) static ENTRY_PHORRHEA_13208068197196345881: VariantsMap = [
    &["phorrhea"],
    &["phorrhoea"],
    &["phorrhoea"],
    &["phorrhoea"],
];

pub(crate) static ENTRY_PHOSPHATIZATIONS_12255974002935158132: VariantsMap = [
    &["phosphatizations"],
    &["phosphatisations"],
    &["phosphatizations"],
    &["phosphatisations"],
];

pub(crate) static ENTRY_PHOSPHATIZATION_4175899370839304733: VariantsMap = [
    &["phosphatization"],
    &["phosphatisation"],
    &["phosphatization"],
    &["phosphatisation"],
];

pub(crate) static ENTRY_PHOSPHATIZED_8578950796519736557: VariantsMap = [
    &["phosphatized"],
    &["phosphatised"],
    &["phosphatized"],
    &["phosphatised"],
];

pub(crate) static ENTRY_PHOSPHATIZES_5129360819999903073: VariantsMap = [
    &["phosphatizes"],
    &["phosphatises"],
    &["phosphatizes"],
    &["phosphatises"],
];

pub(crate) static ENTRY_PHOSPHATIZE_589509609004210876: VariantsMap = [
    &["phosphatize"],
    &["phosphatise"],
    &["phosphatize"],
    &["phosphatise"],
];

pub(crate) static ENTRY_PHOSPHATIZING_4826539255258763256: VariantsMap = [
    &["phosphatizing"],
    &["phosphatising"],
    &["phosphatizing"],
    &["phosphatising"],
];

pub(crate) static ENTRY_PHOSPHORIZED_3504819966842929193: VariantsMap = [
    &["phosphorized"],
    &["phosphorised"],
    &["phosphorized"],
    &["phosphorised"],
];

pub(crate) static ENTRY_PHOSPHORIZES_17522331139923456458: VariantsMap = [
    &["phosphorizes"],
    &["phosphorises"],
    &["phosphorizes"],
    &["phosphorises"],
];

pub(crate) static ENTRY_PHOSPHORIZE_13215518786176964054: VariantsMap = [
    &["phosphorize"],
    &["phosphorise"],
    &["phosphorize"],
    &["phosphorise"],
];

pub(crate) static ENTRY_PHOSPHORIZING_12248460229299793587: VariantsMap = [
    &["phosphorizing"],
    &["phosphorising"],
    &["phosphorizing"],
    &["phosphorising"],
];

pub(crate) static ENTRY_PHOTESTHESIS_17727520840546347652: VariantsMap = [
    &["photesthesis"],
    &["photoesthesis"],
    &["photoesthesis"],
    &["photoesthesis"],
];

pub(crate) static ENTRY_PHOTESTHESIS_6981549980908445509: VariantsMap = [
    &["photesthesis"],
    &["photaesthesis"],
    &["photaesthesis"],
    &["photaesthesis"],
];

pub(crate) static ENTRY_PHOTOCATALYZERS_13764405179670914256: VariantsMap = [
    &["photocatalyzers"],
    &["photocatalysers"],
    &["photocatalysers"],
    &["photocatalysers"],
];

pub(crate) static ENTRY_PHOTOCATALYZER_11050841619007985543: VariantsMap = [
    &["photocatalyzer"],
    &["photocatalyser"],
    &["photocatalyser"],
    &["photocatalyser"],
];

pub(crate) static ENTRY_PHOTOESTHETIC_6617324081715374387: VariantsMap = [
    &["photoesthetic"],
    &["photoaesthetic"],
    &["photoaesthetic"],
    &["photoaesthetic"],
];

pub(crate) static ENTRY_PHOTOGRAPHIZES_7246623188004089530: VariantsMap = [
    &["photographizes"],
    &["photographises"],
    &["photographizes"],
    &["photographises"],
];

pub(crate) static ENTRY_PHOTOGRAPHIZE_3680030487733185738: VariantsMap = [
    &["photographize"],
    &["photographise"],
    &["photographize"],
    &["photographise"],
];

pub(crate) static ENTRY_PHOTOIONIZATIONS_4578393814749909045: VariantsMap = [
    &["photoionizations"],
    &["photoionisations"],
    &["photoionizations"],
    &["photoionisations"],
];

pub(crate) static ENTRY_PHOTOIONIZATION_3174791429214154918: VariantsMap = [
    &["photoionization"],
    &["photoionisation"],
    &["photoionization"],
    &["photoionisation"],
];

pub(crate) static ENTRY_PHOTOISOMERIZATIONS_14085447749077811360: VariantsMap = [
    &["photoisomerizations"],
    &["photoisomerisations"],
    &["photoisomerizations"],
    &["photoisomerisations"],
];

pub(crate) static ENTRY_PHOTOISOMERIZATION_6751720425527323933: VariantsMap = [
    &["photoisomerization"],
    &["photoisomerisation"],
    &["photoisomerization"],
    &["photoisomerisation"],
];

pub(crate) static ENTRY_PHOTOLABELED_9221461550333475470: VariantsMap = [
    &["photolabeled"],
    &["photolabelled"],
    &["photolabelled"],
    &["photolabelled"],
];

pub(crate) static ENTRY_PHOTOLABELER_13495566989885803749: VariantsMap = [
    &["photolabeler"],
    &["photolabeller"],
    &["photolabeller"],
    &["photolabeller"],
];

pub(crate) static ENTRY_PHOTOLABELING_12804494872614821285: VariantsMap = [
    &["photolabeling"],
    &["photolabelling"],
    &["photolabelling"],
    &["photolabelling"],
];

pub(crate) static ENTRY_PHOTOLYZABLE_1307676699359278891: VariantsMap = [
    &["photolyzable"],
    &["photolysable"],
    &["photolysable"],
    &["photolysable"],
];

pub(crate) static ENTRY_PHOTOLYZED_15412604323863050603: VariantsMap = [
    &["photolyzed"],
    &["photolysed"],
    &["photolyzed"],
    &["photolysed"],
];

pub(crate) static ENTRY_PHOTOLYZES_13815346102662155645: VariantsMap = [
    &["photolyzes"],
    &["photolyses"],
    &["photolyzes"],
    &["photolyses"],
];

pub(crate) static ENTRY_PHOTOLYZE_16302775288316268906: VariantsMap = [
    &["photolyze"],
    &["photolyse"],
    &["photolyze"],
    &["photolyse"],
];

pub(crate) static ENTRY_PHOTOLYZING_5023754747286858353: VariantsMap = [
    &["photolyzing"],
    &["photolysing"],
    &["photolyzing"],
    &["photolysing"],
];

pub(crate) static ENTRY_PHOTOPOLYMERIZATIONS_5207608956609586528: VariantsMap = [
    &["photopolymerizations"],
    &["photopolymerisations"],
    &["photopolymerizations"],
    &["photopolymerisations"],
];

pub(crate) static ENTRY_PHOTOPOLYMERIZATION_16063694208716353085: VariantsMap = [
    &["photopolymerization"],
    &["photopolymerisation"],
    &["photopolymerization"],
    &["photopolymerisation"],
];

pub(crate) static ENTRY_PHOTOSENSITIZATIONS_13004505883705820957: VariantsMap = [
    &["photosensitizations"],
    &["photosensitisations"],
    &["photosensitizations"],
    &["photosensitisations"],
];

pub(crate) static ENTRY_PHOTOSENSITIZATION_5069654584948615148: VariantsMap = [
    &["photosensitization"],
    &["photosensitisation"],
    &["photosensitization"],
    &["photosensitisation"],
];

pub(crate) static ENTRY_PHOTOSENSITIZED_12285633572666221887: VariantsMap = [
    &["photosensitized"],
    &["photosensitised"],
    &["photosensitized"],
    &["photosensitised"],
];

pub(crate) static ENTRY_PHOTOSENSITIZERS_9865390720202085290: VariantsMap = [
    &["photosensitizers"],
    &["photosensitisers"],
    &["photosensitizers"],
    &["photosensitisers"],
];

pub(crate) static ENTRY_PHOTOSENSITIZER_16139858535991349387: VariantsMap = [
    &["photosensitizer"],
    &["photosensitiser"],
    &["photosensitizer"],
    &["photosensitiser"],
];

pub(crate) static ENTRY_PHOTOSENSITIZES_9120738511428773132: VariantsMap = [
    &["photosensitizes"],
    &["photosensitises"],
    &["photosensitizes"],
    &["photosensitises"],
];

pub(crate) static ENTRY_PHOTOSENSITIZE_8288914178365456711: VariantsMap = [
    &["photosensitize"],
    &["photosensitise"],
    &["photosensitize"],
    &["photosensitise"],
];

pub(crate) static ENTRY_PHOTOSENSITIZING_2349728015045574141: VariantsMap = [
    &["photosensitizing"],
    &["photosensitising"],
    &["photosensitizing"],
    &["photosensitising"],
];

pub(crate) static ENTRY_PHOTOSYNTHESIZED_4022833954742135604: VariantsMap = [
    &["photosynthesized"],
    &["photosynthesised"],
    &["photosynthesized"],
    &["photosynthesised"],
];

pub(crate) static ENTRY_PHOTOSYNTHESIZES_11615882972300115120: VariantsMap = [
    &["photosynthesizes"],
    &["photosynthesises"],
    &["photosynthesizes"],
    &["photosynthesises"],
];

pub(crate) static ENTRY_PHOTOSYNTHESIZE_16528133077473184545: VariantsMap = [
    &["photosynthesize"],
    &["photosynthesise"],
    &["photosynthesize"],
    &["photosynthesise"],
];

pub(crate) static ENTRY_PHOTOSYNTHESIZING_1052004418989698159: VariantsMap = [
    &["photosynthesizing"],
    &["photosynthesising"],
    &["photosynthesizing"],
    &["photosynthesising"],
];

pub(crate) static ENTRY_PHRENOLOGIZED_5269289788245932959: VariantsMap = [
    &["phrenologized"],
    &["phrenologised"],
    &["phrenologized"],
    &["phrenologised"],
];

pub(crate) static ENTRY_PHRENOLOGIZES_9501866944819113429: VariantsMap = [
    &["phrenologizes"],
    &["phrenologises"],
    &["phrenologizes"],
    &["phrenologises"],
];

pub(crate) static ENTRY_PHRENOLOGIZE_12593199073368999981: VariantsMap = [
    &["phrenologize"],
    &["phrenologise"],
    &["phrenologize"],
    &["phrenologise"],
];

pub(crate) static ENTRY_PHRENOLOGIZING_16363166802450050044: VariantsMap = [
    &["phrenologizing"],
    &["phrenologising"],
    &["phrenologizing"],
    &["phrenologising"],
];

pub(crate) static ENTRY_PHYLACTOLEMATA_15645283540839306050: VariantsMap = [
    &["phylactolemata"],
    &["phylactolaemata"],
    &["phylactolaemata"],
    &["phylactolaemata"],
];

pub(crate) static ENTRY_PHYLACTOLEMA_17387053296583525798: VariantsMap = [
    &["phylactolema"],
    &["phylactolaema"],
    &["phylactolaema"],
    &["phylactolaema"],
];

pub(crate) static ENTRY_PHYTOECOLOGY_3833250044946066382: VariantsMap = [
    &["phytoecology"],
    &["phytooecology"],
    &["phytooecology"],
    &["phytooecology"],
];

pub(crate) static ENTRY_PHYTOHEMAGGLUTININ_8708803765514094222: VariantsMap = [
    &["phytohemagglutinin"],
    &["phytohaemagglutinin"],
    &["phytohaemagglutinin"],
    &["phytohaemagglutinin"],
];

pub(crate) static ENTRY_PIARHEMIC_4373779022618005958: VariantsMap = [
    &["piarhemic"],
    &["piarhaemic"],
    &["piarhaemic"],
    &["piarhaemic"],
];

pub(crate) static ENTRY_PIASTERS_16176301200771126280: VariantsMap =
    [&["piasters"], &["piastres"], &["piastres"], &["piastres"]];

pub(crate) static ENTRY_PIASTER_13635975646054450930: VariantsMap =
    [&["piaster"], &["piastre"], &["piastre"], &["piastre"]];

pub(crate) static ENTRY_PICOGRAMS_10906014752748869240: VariantsMap = [
    &["picograms"],
    &["picogrammes"],
    &["picograms"],
    &["picogrammes"],
];

pub(crate) static ENTRY_PICOGRAM_11350367043126236604: VariantsMap = [
    &["picogram"],
    &["picogramme"],
    &["picogram"],
    &["picogramme"],
];

pub(crate) static ENTRY_PICOMETERS_12211512401784472293: VariantsMap = [
    &["picometers"],
    &["picometres"],
    &["picometres"],
    &["picometres"],
];

pub(crate) static ENTRY_PICOMETER_2628061784674895811: VariantsMap = [
    &["picometer"],
    &["picometre"],
    &["picometre"],
    &["picometre"],
];

pub(crate) static ENTRY_PICTORIALIZATIONS_4913660434215340848: VariantsMap = [
    &["pictorializations"],
    &["pictorialisations"],
    &["pictorializations"],
    &["pictorialisations"],
];

pub(crate) static ENTRY_PICTORIALIZATION_14708484463367740539: VariantsMap = [
    &["pictorialization"],
    &["pictorialisation"],
    &["pictorialization"],
    &["pictorialisation"],
];

pub(crate) static ENTRY_PICTORIALIZED_4300804023861683584: VariantsMap = [
    &["pictorialized"],
    &["pictorialised"],
    &["pictorialized"],
    &["pictorialised"],
];

pub(crate) static ENTRY_PICTORIALIZES_17175738548381080003: VariantsMap = [
    &["pictorializes"],
    &["pictorialises"],
    &["pictorializes"],
    &["pictorialises"],
];

pub(crate) static ENTRY_PICTORIALIZE_17160489486570007365: VariantsMap = [
    &["pictorialize"],
    &["pictorialise"],
    &["pictorialize"],
    &["pictorialise"],
];

pub(crate) static ENTRY_PICTORIALIZING_4361304323804901214: VariantsMap = [
    &["pictorializing"],
    &["pictorialising"],
    &["pictorializing"],
    &["pictorialising"],
];

pub(crate) static ENTRY_PICTURIZATIONS_8940902236643797185: VariantsMap = [
    &["picturizations"],
    &["picturisations"],
    &["picturizations"],
    &["picturisations"],
];

pub(crate) static ENTRY_PICTURIZATION_16841013829361902460: VariantsMap = [
    &["picturization"],
    &["picturisation"],
    &["picturization"],
    &["picturisation"],
];

pub(crate) static ENTRY_PICTURIZED_3383491133099344173: VariantsMap = [
    &["picturized"],
    &["picturised"],
    &["picturized"],
    &["picturised"],
];

pub(crate) static ENTRY_PICTURIZES_9102727891294622822: VariantsMap = [
    &["picturizes"],
    &["picturises"],
    &["picturizes"],
    &["picturises"],
];

pub(crate) static ENTRY_PICTURIZE_9024247702062369559: VariantsMap = [
    &["picturize"],
    &["picturise"],
    &["picturize"],
    &["picturise"],
];

pub(crate) static ENTRY_PICTURIZING_10815202759366884688: VariantsMap = [
    &["picturizing"],
    &["picturising"],
    &["picturizing"],
    &["picturising"],
];

pub(crate) static ENTRY_PIDGINIZATIONS_12337613956252475858: VariantsMap = [
    &["pidginizations"],
    &["pidginisations"],
    &["pidginizations"],
    &["pidginisations"],
];

pub(crate) static ENTRY_PIDGINIZATION_4247850683463639292: VariantsMap = [
    &["pidginization"],
    &["pidginisation"],
    &["pidginization"],
    &["pidginisation"],
];

pub(crate) static ENTRY_PIDGINIZED_9275549597676109200: VariantsMap = [
    &["pidginized"],
    &["pidginised"],
    &["pidginized"],
    &["pidginised"],
];

pub(crate) static ENTRY_PIDGINIZES_9819290300342306986: VariantsMap = [
    &["pidginizes"],
    &["pidginises"],
    &["pidginizes"],
    &["pidginises"],
];

pub(crate) static ENTRY_PIDGINIZE_16450854328377794588: VariantsMap = [
    &["pidginize"],
    &["pidginise"],
    &["pidginize"],
    &["pidginise"],
];

pub(crate) static ENTRY_PIDGINIZING_1233279765890722824: VariantsMap = [
    &["pidginizing"],
    &["pidginising"],
    &["pidginizing"],
    &["pidginising"],
];

pub(crate) static ENTRY_PIGMEAN_838416186676693472: VariantsMap =
    [&["pigmean"], &["pigmaean"], &["pigmaean"], &["pigmaean"]];

pub(crate) static ENTRY_PIGMENTIZES_7839824677968960729: VariantsMap = [
    &["pigmentizes"],
    &["pigmentises"],
    &["pigmentizes"],
    &["pigmentises"],
];

pub(crate) static ENTRY_PIGMENTIZE_17000768533660304435: VariantsMap = [
    &["pigmentize"],
    &["pigmentise"],
    &["pigmentize"],
    &["pigmentise"],
];

pub(crate) static ENTRY_PILGRIMIZED_11204759801928429576: VariantsMap = [
    &["pilgrimized"],
    &["pilgrimised"],
    &["pilgrimized"],
    &["pilgrimised"],
];

pub(crate) static ENTRY_PILGRIMIZES_245368581812668914: VariantsMap = [
    &["pilgrimizes"],
    &["pilgrimises"],
    &["pilgrimizes"],
    &["pilgrimises"],
];

pub(crate) static ENTRY_PILGRIMIZE_15115937713453969329: VariantsMap = [
    &["pilgrimize"],
    &["pilgrimise"],
    &["pilgrimize"],
    &["pilgrimise"],
];

pub(crate) static ENTRY_PILGRIMIZING_9980588741013675877: VariantsMap = [
    &["pilgrimizing"],
    &["pilgrimising"],
    &["pilgrimizing"],
    &["pilgrimising"],
];

pub(crate) static ENTRY_PILLARIZES_17692578717946990918: VariantsMap = [
    &["pillarizes"],
    &["pillarises"],
    &["pillarizes"],
    &["pillarises"],
];

pub(crate) static ENTRY_PILLARIZE_9018246236618645996: VariantsMap = [
    &["pillarize"],
    &["pillarise"],
    &["pillarize"],
    &["pillarise"],
];

pub(crate) static ENTRY_PILLORIZED_894715813225067108: VariantsMap = [
    &["pillorized"],
    &["pillorised"],
    &["pillorized"],
    &["pillorised"],
];

pub(crate) static ENTRY_PILLORIZES_12687325336889895788: VariantsMap = [
    &["pillorizes"],
    &["pillorises"],
    &["pillorizes"],
    &["pillorises"],
];

pub(crate) static ENTRY_PILLORIZE_7161828989665068634: VariantsMap = [
    &["pillorize"],
    &["pillorise"],
    &["pillorize"],
    &["pillorise"],
];

pub(crate) static ENTRY_PILLORIZING_16890095566787510096: VariantsMap = [
    &["pillorizing"],
    &["pillorising"],
    &["pillorizing"],
    &["pillorising"],
];

pub(crate) static ENTRY_PILLOWBEER_7601320084724894311: VariantsMap = [
    &["pillowbeer"],
    &["pillowbere"],
    &["pillowbere"],
    &["pillowbere"],
];

pub(crate) static ENTRY_PINDARIZED_6373523452419605770: VariantsMap = [
    &["pindarized"],
    &["pindarised"],
    &["pindarized"],
    &["pindarised"],
];

pub(crate) static ENTRY_PINDARIZES_4435880422606251900: VariantsMap = [
    &["pindarizes"],
    &["pindarises"],
    &["pindarizes"],
    &["pindarises"],
];

pub(crate) static ENTRY_PINDARIZE_3371672470278825880: VariantsMap = [
    &["pindarize"],
    &["pindarise"],
    &["pindarize"],
    &["pindarise"],
];

pub(crate) static ENTRY_PINDARIZING_9646845228045121987: VariantsMap = [
    &["pindarizing"],
    &["pindarising"],
    &["pindarizing"],
    &["pindarising"],
];

pub(crate) static ENTRY_PINNULE_585935578756924342: VariantsMap =
    [&["pinnule"], &["pinnulae"], &["pinnulae"], &["pinnulae"]];

pub(crate) static ENTRY_PIRATIZES_8919560401490093200: VariantsMap = [
    &["piratizes"],
    &["piratises"],
    &["piratizes"],
    &["piratises"],
];

pub(crate) static ENTRY_PIRATIZE_6749125827462808539: VariantsMap =
    [&["piratize"], &["piratise"], &["piratize"], &["piratise"]];

pub(crate) static ENTRY_PISCINE_5027149564915569308: VariantsMap =
    [&["piscine"], &["piscinae"], &["piscinae"], &["piscinae"]];

pub(crate) static ENTRY_PISTOLED_14184147191541856361: VariantsMap = [
    &["pistoled"],
    &["pistolled"],
    &["pistolled"],
    &["pistolled"],
];

pub(crate) static ENTRY_PISTOLING_10255809735953360817: VariantsMap = [
    &["pistoling"],
    &["pistolling"],
    &["pistolling"],
    &["pistolling"],
];

pub(crate) static ENTRY_PIZES_15927503519599533301: VariantsMap =
    [&["pizes"], &["pises"], &["pizes"], &["pises"]];

pub(crate) static ENTRY_PLACEAN_10780406184619843162: VariantsMap =
    [&["placean"], &["placaean"], &["placaean"], &["placaean"]];

pub(crate) static ENTRY_PLAGE_5780289291015820410: VariantsMap =
    [&["plage"], &["plagae"], &["plagae"], &["plagae"]];

pub(crate) static ENTRY_PLAGIARIZATIONS_3623763755946048017: VariantsMap = [
    &["plagiarizations"],
    &["plagiarisations"],
    &["plagiarizations"],
    &["plagiarisations"],
];

pub(crate) static ENTRY_PLAGIARIZATION_4700253329027850825: VariantsMap = [
    &["plagiarization"],
    &["plagiarisation"],
    &["plagiarization"],
    &["plagiarisation"],
];

pub(crate) static ENTRY_PLAGIARIZED_12321658142956326932: VariantsMap = [
    &["plagiarized"],
    &["plagiarised"],
    &["plagiarized"],
    &["plagiarised"],
];

pub(crate) static ENTRY_PLAGIARIZERS_4000297058035207269: VariantsMap = [
    &["plagiarizers"],
    &["plagiarisers"],
    &["plagiarizers"],
    &["plagiarisers"],
];

pub(crate) static ENTRY_PLAGIARIZER_6131721956520951955: VariantsMap = [
    &["plagiarizer"],
    &["plagiariser"],
    &["plagiarizer"],
    &["plagiariser"],
];

pub(crate) static ENTRY_PLAGIARIZES_3079051217833247235: VariantsMap = [
    &["plagiarizes"],
    &["plagiarises"],
    &["plagiarizes"],
    &["plagiarises"],
];

pub(crate) static ENTRY_PLAGIARIZE_3775190677956286864: VariantsMap = [
    &["plagiarize"],
    &["plagiarise"],
    &["plagiarize"],
    &["plagiarise"],
];

pub(crate) static ENTRY_PLAGIARIZING_6331297137787838542: VariantsMap = [
    &["plagiarizing"],
    &["plagiarising"],
    &["plagiarizing"],
    &["plagiarising"],
];

pub(crate) static ENTRY_PLANTE_15938795954501174987: VariantsMap =
    [&["plante"], &["plantae"], &["plantae"], &["plantae"]];

pub(crate) static ENTRY_PLANTULE_7509094958023933361: VariantsMap = [
    &["plantule"],
    &["plantulae"],
    &["plantulae"],
    &["plantulae"],
];

pub(crate) static ENTRY_PLASMAPHERESIS_1508628979977175584: VariantsMap = [
    &["plasmapheresis"],
    &["plasmaphaeresis"],
    &["plasmaphaeresis"],
    &["plasmaphaeresis"],
];

pub(crate) static ENTRY_PLASMOLYZED_1073560925313062172: VariantsMap = [
    &["plasmolyzed"],
    &["plasmolysed"],
    &["plasmolysed"],
    &["plasmolysed"],
];

pub(crate) static ENTRY_PLASMOLYZES_14848652000638172841: VariantsMap = [
    &["plasmolyzes"],
    &["plasmolyses"],
    &["plasmolyses"],
    &["plasmolyses"],
];

pub(crate) static ENTRY_PLASMOLYZE_7108165619266701720: VariantsMap = [
    &["plasmolyze"],
    &["plasmolyse"],
    &["plasmolyse"],
    &["plasmolyse"],
];

pub(crate) static ENTRY_PLASMOLYZING_14342415833639819900: VariantsMap = [
    &["plasmolyzing"],
    &["plasmolysing"],
    &["plasmolysing"],
    &["plasmolysing"],
];

pub(crate) static ENTRY_PLASTICIZATIONS_8714202375888992754: VariantsMap = [
    &["plasticizations"],
    &["plasticisations"],
    &["plasticizations"],
    &["plasticisations"],
];

pub(crate) static ENTRY_PLASTICIZATION_14104512748126545924: VariantsMap = [
    &["plasticization"],
    &["plasticisation"],
    &["plasticization"],
    &["plasticisation"],
];

pub(crate) static ENTRY_PLASTICIZED_1092409437998471695: VariantsMap = [
    &["plasticized"],
    &["plasticised"],
    &["plasticized"],
    &["plasticised"],
];

pub(crate) static ENTRY_PLASTICIZERS_1689438428234931431: VariantsMap = [
    &["plasticizers"],
    &["plasticisers"],
    &["plasticizers"],
    &["plasticisers"],
];

pub(crate) static ENTRY_PLASTICIZER_4503458591975420540: VariantsMap = [
    &["plasticizer"],
    &["plasticiser"],
    &["plasticizer"],
    &["plasticiser"],
];

pub(crate) static ENTRY_PLASTICIZES_14237267039551578506: VariantsMap = [
    &["plasticizes"],
    &["plasticises"],
    &["plasticizes"],
    &["plasticises"],
];

pub(crate) static ENTRY_PLASTICIZE_5295414425579558521: VariantsMap = [
    &["plasticize"],
    &["plasticise"],
    &["plasticize"],
    &["plasticise"],
];

pub(crate) static ENTRY_PLASTICIZING_10532662878530701536: VariantsMap = [
    &["plasticizing"],
    &["plasticising"],
    &["plasticizing"],
    &["plasticising"],
];

pub(crate) static ENTRY_PLATEA_8349780907664188770: VariantsMap =
    [&["platea"], &["plataea"], &["plataea"], &["plataea"]];

pub(crate) static ENTRY_PLATINIZATIONS_15552354246238607901: VariantsMap = [
    &["platinizations"],
    &["platinisations"],
    &["platinizations"],
    &["platinisations"],
];

pub(crate) static ENTRY_PLATINIZATION_7294928098928662795: VariantsMap = [
    &["platinization"],
    &["platinisation"],
    &["platinization"],
    &["platinisation"],
];

pub(crate) static ENTRY_PLATINIZED_1054043595774840925: VariantsMap = [
    &["platinized"],
    &["platinised"],
    &["platinized"],
    &["platinised"],
];

pub(crate) static ENTRY_PLATINIZES_15021159787768685270: VariantsMap = [
    &["platinizes"],
    &["platinises"],
    &["platinizes"],
    &["platinises"],
];

pub(crate) static ENTRY_PLATINIZE_1605954097470852281: VariantsMap = [
    &["platinize"],
    &["platinise"],
    &["platinize"],
    &["platinise"],
];

pub(crate) static ENTRY_PLATINIZING_15398368952512453882: VariantsMap = [
    &["platinizing"],
    &["platinising"],
    &["platinizing"],
    &["platinising"],
];

pub(crate) static ENTRY_PLATITUDINIZATIONS_7700065669634779606: VariantsMap = [
    &["platitudinizations"],
    &["platitudinisations"],
    &["platitudinizations"],
    &["platitudinisations"],
];

pub(crate) static ENTRY_PLATITUDINIZATION_13708809875774352690: VariantsMap = [
    &["platitudinization"],
    &["platitudinisation"],
    &["platitudinization"],
    &["platitudinisation"],
];

pub(crate) static ENTRY_PLATITUDINIZED_162055508592689397: VariantsMap = [
    &["platitudinized"],
    &["platitudinised"],
    &["platitudinized"],
    &["platitudinised"],
];

pub(crate) static ENTRY_PLATITUDINIZER_9937278398027092459: VariantsMap = [
    &["platitudinizer"],
    &["platitudiniser"],
    &["platitudinizer"],
    &["platitudiniser"],
];

pub(crate) static ENTRY_PLATITUDINIZES_4385490697041100884: VariantsMap = [
    &["platitudinizes"],
    &["platitudinises"],
    &["platitudinizes"],
    &["platitudinises"],
];

pub(crate) static ENTRY_PLATITUDINIZE_16047744417590066437: VariantsMap = [
    &["platitudinize"],
    &["platitudinise"],
    &["platitudinize"],
    &["platitudinise"],
];

pub(crate) static ENTRY_PLATITUDINIZING_17727869419869709916: VariantsMap = [
    &["platitudinizing"],
    &["platitudinising"],
    &["platitudinizing"],
    &["platitudinising"],
];

pub(crate) static ENTRY_PLATONIZATION_7174077875190383867: VariantsMap = [
    &["platonization"],
    &["platonisation"],
    &["platonization"],
    &["platonisation"],
];

pub(crate) static ENTRY_PLATONIZED_17997626260125938103: VariantsMap = [
    &["platonized"],
    &["platonised"],
    &["platonized"],
    &["platonised"],
];

pub(crate) static ENTRY_PLATONIZER_3400111701490312811: VariantsMap = [
    &["platonizer"],
    &["platoniser"],
    &["platonizer"],
    &["platoniser"],
];

pub(crate) static ENTRY_PLATONIZES_12255582039294891460: VariantsMap = [
    &["platonizes"],
    &["platonises"],
    &["platonizes"],
    &["platonises"],
];

pub(crate) static ENTRY_PLATONIZE_16844425756925172171: VariantsMap = [
    &["platonize"],
    &["platonise"],
    &["platonize"],
    &["platonise"],
];

pub(crate) static ENTRY_PLATONIZING_3294563492691077109: VariantsMap = [
    &["platonizing"],
    &["platonising"],
    &["platonizing"],
    &["platonising"],
];

pub(crate) static ENTRY_PLATYCELIAN_16729912161176580577: VariantsMap = [
    &["platycelian"],
    &["platycoelian"],
    &["platycoelian"],
    &["platycoelian"],
];

pub(crate) static ENTRY_PLATYCELOUS_6600039705539585991: VariantsMap = [
    &["platycelous"],
    &["platycoelous"],
    &["platycoelous"],
    &["platycoelous"],
];

pub(crate) static ENTRY_PLEBEIANIZATION_4489677126502230770: VariantsMap = [
    &["plebeianization"],
    &["plebeianisation"],
    &["plebeianization"],
    &["plebeianisation"],
];

pub(crate) static ENTRY_PLEBEIANIZED_12150770105441799169: VariantsMap = [
    &["plebeianized"],
    &["plebeianised"],
    &["plebeianized"],
    &["plebeianised"],
];

pub(crate) static ENTRY_PLEBEIANIZES_8283743331693072026: VariantsMap = [
    &["plebeianizes"],
    &["plebeianises"],
    &["plebeianizes"],
    &["plebeianises"],
];

pub(crate) static ENTRY_PLEBEIANIZE_13948307616682534202: VariantsMap = [
    &["plebeianize"],
    &["plebeianise"],
    &["plebeianize"],
    &["plebeianise"],
];

pub(crate) static ENTRY_PLEBEIANIZING_18092068760405524948: VariantsMap = [
    &["plebeianizing"],
    &["plebeianising"],
    &["plebeianizing"],
    &["plebeianising"],
];

pub(crate) static ENTRY_PLEUROPERITONEAL_18421227973934406014: VariantsMap = [
    &["pleuroperitoneal"],
    &["pleuroperitonaeal"],
    &["pleuroperitonaeal"],
    &["pleuroperitonaeal"],
];

pub(crate) static ENTRY_PLOWABLE_714244179924658667: VariantsMap = [
    &["plowable"],
    &["ploughable"],
    &["plowable"],
    &["ploughable"],
];

pub(crate) static ENTRY_PLOWBOYS_15819867342839929654: VariantsMap = [
    &["plowboys"],
    &["ploughboys"],
    &["ploughboys"],
    &["ploughboys"],
];

pub(crate) static ENTRY_PLOWBOY_17926082723965440447: VariantsMap =
    [&["plowboy"], &["ploughboy"], &["ploughboy"], &["ploughboy"]];

pub(crate) static ENTRY_PLOWED_2972982119152462143: VariantsMap =
    [&["plowed"], &["ploughed"], &["plowed"], &["ploughed"]];

pub(crate) static ENTRY_PLOWERS_12826470249782049773: VariantsMap =
    [&["plowers"], &["ploughers"], &["plowers"], &["ploughers"]];

pub(crate) static ENTRY_PLOWER_2190961427050860856: VariantsMap =
    [&["plower"], &["plougher"], &["plower"], &["plougher"]];

pub(crate) static ENTRY_PLOWHEAD_14619897313081193220: VariantsMap = [
    &["plowhead"],
    &["ploughhead"],
    &["ploughhead"],
    &["ploughhead"],
];

pub(crate) static ENTRY_PLOWING_16570546940479665223: VariantsMap =
    [&["plowing"], &["ploughing"], &["plowing"], &["ploughing"]];

pub(crate) static ENTRY_PLOWMAN_13581836870693601113: VariantsMap =
    [&["plowman"], &["ploughman"], &["ploughman"], &["ploughman"]];

pub(crate) static ENTRY_PLOWMEN_15058389578896302329: VariantsMap =
    [&["plowmen"], &["ploughmen"], &["ploughmen"], &["ploughmen"]];

pub(crate) static ENTRY_PLOWSHARES_10499526776608850484: VariantsMap = [
    &["plowshares"],
    &["ploughshares"],
    &["ploughshares"],
    &["ploughshares"],
];

pub(crate) static ENTRY_PLOWSHARE_6048515192383180113: VariantsMap = [
    &["plowshare"],
    &["ploughshare"],
    &["ploughshare"],
    &["ploughshare"],
];

pub(crate) static ENTRY_PLOWS_17736521420248608990: VariantsMap =
    [&["plows"], &["ploughs"], &["plows"], &["ploughs"]];

pub(crate) static ENTRY_PLOW_15240143167426020265: VariantsMap =
    [&["plow"], &["plough"], &["plow"], &["plough"]];

pub(crate) static ENTRY_PLUMULE_11005874244288887731: VariantsMap =
    [&["plumule"], &["plumulae"], &["plumulae"], &["plumulae"]];

pub(crate) static ENTRY_PLURALIZATIONS_1198848109390483960: VariantsMap = [
    &["pluralizations"],
    &["pluralisations"],
    &["pluralizations"],
    &["pluralisations"],
];

pub(crate) static ENTRY_PLURALIZATION_8169254968713730067: VariantsMap = [
    &["pluralization"],
    &["pluralisation"],
    &["pluralization"],
    &["pluralisation"],
];

pub(crate) static ENTRY_PLURALIZED_3500489174231988842: VariantsMap = [
    &["pluralized"],
    &["pluralised"],
    &["pluralized"],
    &["pluralised"],
];

pub(crate) static ENTRY_PLURALIZERS_17783207971007642026: VariantsMap = [
    &["pluralizers"],
    &["pluralisers"],
    &["pluralizers"],
    &["pluralisers"],
];

pub(crate) static ENTRY_PLURALIZER_1892398405711976310: VariantsMap = [
    &["pluralizer"],
    &["pluraliser"],
    &["pluralizer"],
    &["pluraliser"],
];

pub(crate) static ENTRY_PLURALIZES_15840415766673228613: VariantsMap = [
    &["pluralizes"],
    &["pluralises"],
    &["pluralizes"],
    &["pluralises"],
];

pub(crate) static ENTRY_PLURALIZE_4399070254818053480: VariantsMap = [
    &["pluralize"],
    &["pluralise"],
    &["pluralize"],
    &["pluralise"],
];

pub(crate) static ENTRY_PLURALIZING_11743846805855674925: VariantsMap = [
    &["pluralizing"],
    &["pluralising"],
    &["pluralizing"],
    &["pluralising"],
];

pub(crate) static ENTRY_POETICIZATION_3652192917145042403: VariantsMap = [
    &["poeticization"],
    &["poeticisation"],
    &["poeticization"],
    &["poeticisation"],
];

pub(crate) static ENTRY_POETICIZED_12390573338020882499: VariantsMap = [
    &["poeticized"],
    &["poeticised"],
    &["poeticized"],
    &["poeticised"],
];

pub(crate) static ENTRY_POETICIZES_14806750979505922739: VariantsMap = [
    &["poeticizes"],
    &["poeticises"],
    &["poeticizes"],
    &["poeticises"],
];

pub(crate) static ENTRY_POETICIZE_9872291277159870038: VariantsMap = [
    &["poeticize"],
    &["poeticise"],
    &["poeticize"],
    &["poeticise"],
];

pub(crate) static ENTRY_POETICIZING_612825552438033007: VariantsMap = [
    &["poeticizing"],
    &["poeticising"],
    &["poeticizing"],
    &["poeticising"],
];

pub(crate) static ENTRY_POETIZATIONS_14017988435836090874: VariantsMap = [
    &["poetizations"],
    &["poetisations"],
    &["poetizations"],
    &["poetisations"],
];

pub(crate) static ENTRY_POETIZATION_4980016800203199624: VariantsMap = [
    &["poetization"],
    &["poetisation"],
    &["poetization"],
    &["poetisation"],
];

pub(crate) static ENTRY_POETIZED_1386961114003301059: VariantsMap =
    [&["poetized"], &["poetised"], &["poetized"], &["poetised"]];

pub(crate) static ENTRY_POETIZERS_18165640128590713376: VariantsMap = [
    &["poetizers"],
    &["poetisers"],
    &["poetizers"],
    &["poetisers"],
];

pub(crate) static ENTRY_POETIZER_6456895478682975622: VariantsMap =
    [&["poetizer"], &["poetiser"], &["poetizer"], &["poetiser"]];

pub(crate) static ENTRY_POETIZES_5644621901340662571: VariantsMap =
    [&["poetizes"], &["poetises"], &["poetizes"], &["poetises"]];

pub(crate) static ENTRY_POETIZE_12703762149983503651: VariantsMap =
    [&["poetize"], &["poetise"], &["poetize"], &["poetise"]];

pub(crate) static ENTRY_POETIZING_5617458256013617960: VariantsMap = [
    &["poetizing"],
    &["poetising"],
    &["poetizing"],
    &["poetising"],
];

pub(crate) static ENTRY_POGROMIZES_15657629853908989575: VariantsMap = [
    &["pogromizes"],
    &["pogromises"],
    &["pogromizes"],
    &["pogromises"],
];

pub(crate) static ENTRY_POGROMIZE_6165616786920282232: VariantsMap = [
    &["pogromize"],
    &["pogromise"],
    &["pogromize"],
    &["pogromise"],
];

pub(crate) static ENTRY_POLARIZABILITIES_13289488269656306907: VariantsMap = [
    &["polarizabilities"],
    &["polarisabilities"],
    &["polarizabilities"],
    &["polarisabilities"],
];

pub(crate) static ENTRY_POLARIZABILITY_2003936501471489904: VariantsMap = [
    &["polarizability"],
    &["polarisability"],
    &["polarizability"],
    &["polarisability"],
];

pub(crate) static ENTRY_POLARIZABLES_17746214108386056113: VariantsMap = [
    &["polarizables"],
    &["polarisables"],
    &["polarizables"],
    &["polarisables"],
];

pub(crate) static ENTRY_POLARIZABLE_7358307787201683785: VariantsMap = [
    &["polarizable"],
    &["polarisable"],
    &["polarizable"],
    &["polarisable"],
];

pub(crate) static ENTRY_POLARIZATIONS_16811903515928848250: VariantsMap = [
    &["polarizations"],
    &["polarisations"],
    &["polarizations"],
    &["polarisations"],
];

pub(crate) static ENTRY_POLARIZATION_4404414468379288726: VariantsMap = [
    &["polarization"],
    &["polarisation"],
    &["polarization"],
    &["polarisation"],
];

pub(crate) static ENTRY_POLARIZED_12877424935504157237: VariantsMap = [
    &["polarized"],
    &["polarised"],
    &["polarized"],
    &["polarised"],
];

pub(crate) static ENTRY_POLARIZERS_4664406204726333551: VariantsMap = [
    &["polarizers"],
    &["polarisers"],
    &["polarizers"],
    &["polarisers"],
];

pub(crate) static ENTRY_POLARIZER_3000102012663356590: VariantsMap = [
    &["polarizer"],
    &["polariser"],
    &["polarizer"],
    &["polariser"],
];

pub(crate) static ENTRY_POLARIZES_2266758101576701172: VariantsMap = [
    &["polarizes"],
    &["polarises"],
    &["polarizes"],
    &["polarises"],
];

pub(crate) static ENTRY_POLARIZE_4104034252753850020: VariantsMap =
    [&["polarize"], &["polarise"], &["polarize"], &["polarise"]];

pub(crate) static ENTRY_POLARIZING_7254748840434133551: VariantsMap = [
    &["polarizing"],
    &["polarising"],
    &["polarizing"],
    &["polarising"],
];

pub(crate) static ENTRY_POLEMICIZED_13601254523654189992: VariantsMap = [
    &["polemicized"],
    &["polemicised"],
    &["polemicized"],
    &["polemicised"],
];

pub(crate) static ENTRY_POLEMICIZES_7887077854042670715: VariantsMap = [
    &["polemicizes"],
    &["polemicises"],
    &["polemicizes"],
    &["polemicises"],
];

pub(crate) static ENTRY_POLEMICIZE_15883334541461649709: VariantsMap = [
    &["polemicize"],
    &["polemicise"],
    &["polemicize"],
    &["polemicise"],
];

pub(crate) static ENTRY_POLEMICIZING_15439521581223222709: VariantsMap = [
    &["polemicizing"],
    &["polemicising"],
    &["polemicizing"],
    &["polemicising"],
];

pub(crate) static ENTRY_POLEMIZED_5436292800704660484: VariantsMap = [
    &["polemized"],
    &["polemised"],
    &["polemized"],
    &["polemised"],
];

pub(crate) static ENTRY_POLEMIZES_15540925378458860831: VariantsMap = [
    &["polemizes"],
    &["polemises"],
    &["polemizes"],
    &["polemises"],
];

pub(crate) static ENTRY_POLEMIZE_2362684992503726512: VariantsMap =
    [&["polemize"], &["polemise"], &["polemize"], &["polemise"]];

pub(crate) static ENTRY_POLEMIZING_15735246634115649723: VariantsMap = [
    &["polemizing"],
    &["polemising"],
    &["polemizing"],
    &["polemising"],
];

pub(crate) static ENTRY_POLICIZERS_8186732544489935409: VariantsMap = [
    &["policizers"],
    &["policisers"],
    &["policizers"],
    &["policisers"],
];

pub(crate) static ENTRY_POLICIZER_7661480523981039298: VariantsMap = [
    &["policizer"],
    &["policiser"],
    &["policizer"],
    &["policiser"],
];

pub(crate) static ENTRY_POLICIZES_17833072986612710012: VariantsMap = [
    &["policizes"],
    &["policises"],
    &["policizes"],
    &["policises"],
];

pub(crate) static ENTRY_POLICIZE_10899804007360448438: VariantsMap =
    [&["policize"], &["policise"], &["policize"], &["policise"]];

pub(crate) static ENTRY_POLIENCEPHALITIS_172737026792843669: VariantsMap = [
    &["poliencephalitis"],
    &["polioencephalitis"],
    &["polioencephalitis"],
    &["polioencephalitis"],
];

pub(crate) static ENTRY_POLIENCEPHALOMYELITIS_8330515026545676649: VariantsMap = [
    &["poliencephalomyelitis"],
    &["polioencephalomyelitis"],
    &["polioencephalomyelitis"],
    &["polioencephalomyelitis"],
];

pub(crate) static ENTRY_POLITICALIZES_14895104409541264986: VariantsMap = [
    &["politicalizes"],
    &["politicalises"],
    &["politicalizes"],
    &["politicalises"],
];

pub(crate) static ENTRY_POLITICALIZE_10489182143049842367: VariantsMap = [
    &["politicalize"],
    &["politicalise"],
    &["politicalize"],
    &["politicalise"],
];

pub(crate) static ENTRY_POLITICIZATIONS_16141763812889263962: VariantsMap = [
    &["politicizations"],
    &["politicisations"],
    &["politicizations"],
    &["politicisations"],
];

pub(crate) static ENTRY_POLITICIZATION_9693630840601338434: VariantsMap = [
    &["politicization"],
    &["politicisation"],
    &["politicization"],
    &["politicisation"],
];

pub(crate) static ENTRY_POLITICIZED_9943489674474208118: VariantsMap = [
    &["politicized"],
    &["politicised"],
    &["politicized"],
    &["politicised"],
];

pub(crate) static ENTRY_POLITICIZERS_8269047630805008309: VariantsMap = [
    &["politicizers"],
    &["politicisers"],
    &["politicizers"],
    &["politicisers"],
];

pub(crate) static ENTRY_POLITICIZER_8670872545261874659: VariantsMap = [
    &["politicizer"],
    &["politiciser"],
    &["politicizer"],
    &["politiciser"],
];

pub(crate) static ENTRY_POLITICIZES_16334449170755490531: VariantsMap = [
    &["politicizes"],
    &["politicises"],
    &["politicizes"],
    &["politicises"],
];

pub(crate) static ENTRY_POLITICIZE_1586885444741062386: VariantsMap = [
    &["politicize"],
    &["politicise"],
    &["politicize"],
    &["politicise"],
];

pub(crate) static ENTRY_POLITICIZING_1898540618836719058: VariantsMap = [
    &["politicizing"],
    &["politicising"],
    &["politicizing"],
    &["politicising"],
];

pub(crate) static ENTRY_POLITIZES_15000365599209906701: VariantsMap = [
    &["politizes"],
    &["politises"],
    &["politizes"],
    &["politises"],
];

pub(crate) static ENTRY_POLITIZE_10652477445125067866: VariantsMap =
    [&["politize"], &["politise"], &["politize"], &["politise"]];

pub(crate) static ENTRY_POLLENIZER_5840287768704113985: VariantsMap = [
    &["pollenizer"],
    &["polleniser"],
    &["pollenizer"],
    &["polleniser"],
];

pub(crate) static ENTRY_POLLINIZED_6258305591882108144: VariantsMap = [
    &["pollinized"],
    &["pollinised"],
    &["pollinized"],
    &["pollinised"],
];

pub(crate) static ENTRY_POLLINIZER_6800524124081945052: VariantsMap = [
    &["pollinizer"],
    &["polliniser"],
    &["pollinizer"],
    &["polliniser"],
];

pub(crate) static ENTRY_POLLINIZES_11100365061845756268: VariantsMap = [
    &["pollinizes"],
    &["pollinises"],
    &["pollinizes"],
    &["pollinises"],
];

pub(crate) static ENTRY_POLLINIZE_10886640222621907817: VariantsMap = [
    &["pollinize"],
    &["pollinise"],
    &["pollinize"],
    &["pollinise"],
];

pub(crate) static ENTRY_POLLINIZING_4104790501701690763: VariantsMap = [
    &["pollinizing"],
    &["pollinising"],
    &["pollinizing"],
    &["pollinising"],
];

pub(crate) static ENTRY_POLONIZATION_8741534032787718755: VariantsMap = [
    &["polonization"],
    &["polonisation"],
    &["polonization"],
    &["polonisation"],
];

pub(crate) static ENTRY_POLONIZED_13808803990994600692: VariantsMap = [
    &["polonized"],
    &["polonised"],
    &["polonized"],
    &["polonised"],
];

pub(crate) static ENTRY_POLONIZES_1377448503955337088: VariantsMap = [
    &["polonizes"],
    &["polonises"],
    &["polonizes"],
    &["polonises"],
];

pub(crate) static ENTRY_POLONIZE_9672172949014869969: VariantsMap =
    [&["polonize"], &["polonise"], &["polonize"], &["polonise"]];

pub(crate) static ENTRY_POLONIZING_11665670612780971592: VariantsMap = [
    &["polonizing"],
    &["polonising"],
    &["polonizing"],
    &["polonising"],
];

pub(crate) static ENTRY_POLYCHETOUS_17197291065339885815: VariantsMap = [
    &["polychetous"],
    &["polychaetous"],
    &["polychaetous"],
    &["polychaetous"],
];

pub(crate) static ENTRY_POLYCHROMATIZES_16629345361533556580: VariantsMap = [
    &["polychromatizes"],
    &["polychromatises"],
    &["polychromatizes"],
    &["polychromatises"],
];

pub(crate) static ENTRY_POLYCHROMATIZE_14431815754129053959: VariantsMap = [
    &["polychromatize"],
    &["polychromatise"],
    &["polychromatize"],
    &["polychromatise"],
];

pub(crate) static ENTRY_POLYCHROMIZES_2277776581160811502: VariantsMap = [
    &["polychromizes"],
    &["polychromises"],
    &["polychromizes"],
    &["polychromises"],
];

pub(crate) static ENTRY_POLYCHROMIZE_13944884036814089178: VariantsMap = [
    &["polychromize"],
    &["polychromise"],
    &["polychromize"],
    &["polychromise"],
];

pub(crate) static ENTRY_POLYCYTHEMIAS_7616824030036243533: VariantsMap = [
    &["polycythemias"],
    &["polycythaemias"],
    &["polycythaemias"],
    &["polycythaemias"],
];

pub(crate) static ENTRY_POLYCYTHEMIA_14165398609961484401: VariantsMap = [
    &["polycythemia"],
    &["polycythaemia"],
    &["polycythaemia"],
    &["polycythaemia"],
];

pub(crate) static ENTRY_POLYCYTHEMIC_5540881666593967005: VariantsMap = [
    &["polycythemic"],
    &["polycythaemic"],
    &["polycythaemic"],
    &["polycythaemic"],
];

pub(crate) static ENTRY_POLYDEMONISMS_17257398736277156608: VariantsMap = [
    &["polydemonisms"],
    &["polydaemonisms"],
    &["polydaemonisms"],
    &["polydaemonisms"],
];

pub(crate) static ENTRY_POLYDEMONISM_16806489744265358404: VariantsMap = [
    &["polydemonism"],
    &["polydaemonism"],
    &["polydaemonism"],
    &["polydaemonism"],
];

pub(crate) static ENTRY_POLYDEMONIST_2400662006979178253: VariantsMap = [
    &["polydemonist"],
    &["polydaemonist"],
    &["polydaemonist"],
    &["polydaemonist"],
];

pub(crate) static ENTRY_POLYEMIA_17781042628014686510: VariantsMap = [
    &["polyemia"],
    &["polyaemia"],
    &["polyaemia"],
    &["polyaemia"],
];

pub(crate) static ENTRY_POLYEMIC_18304127681548786255: VariantsMap = [
    &["polyemic"],
    &["polyaemic"],
    &["polyaemic"],
    &["polyaemic"],
];

pub(crate) static ENTRY_POLYESTROUS_2879884995798832892: VariantsMap = [
    &["polyestrous"],
    &["polyoestrous"],
    &["polyoestrous"],
    &["polyoestrous"],
];

pub(crate) static ENTRY_POLYGAMIZES_4155489596892642301: VariantsMap = [
    &["polygamizes"],
    &["polygamises"],
    &["polygamizes"],
    &["polygamises"],
];

pub(crate) static ENTRY_POLYGAMIZE_4701005109108984743: VariantsMap = [
    &["polygamize"],
    &["polygamise"],
    &["polygamize"],
    &["polygamise"],
];

pub(crate) static ENTRY_POLYHEMIA_4404645305177677050: VariantsMap = [
    &["polyhemia"],
    &["polyhaemia"],
    &["polyhaemia"],
    &["polyhaemia"],
];

pub(crate) static ENTRY_POLYHEMIC_8102827937421178102: VariantsMap = [
    &["polyhemic"],
    &["polyhaemic"],
    &["polyhaemic"],
    &["polyhaemic"],
];

pub(crate) static ENTRY_POLYMERIZATIONS_1788553349915748767: VariantsMap = [
    &["polymerizations"],
    &["polymerisations"],
    &["polymerizations"],
    &["polymerisations"],
];

pub(crate) static ENTRY_POLYMERIZATION_18049461613528686745: VariantsMap = [
    &["polymerization"],
    &["polymerisation"],
    &["polymerization"],
    &["polymerisation"],
];

pub(crate) static ENTRY_POLYMERIZED_12064504202018530181: VariantsMap = [
    &["polymerized"],
    &["polymerised"],
    &["polymerized"],
    &["polymerised"],
];

pub(crate) static ENTRY_POLYMERIZES_13931345882261943519: VariantsMap = [
    &["polymerizes"],
    &["polymerises"],
    &["polymerizes"],
    &["polymerises"],
];

pub(crate) static ENTRY_POLYMERIZE_11038516628766467707: VariantsMap = [
    &["polymerize"],
    &["polymerise"],
    &["polymerize"],
    &["polymerise"],
];

pub(crate) static ENTRY_POLYMERIZING_15482080955154321693: VariantsMap = [
    &["polymerizing"],
    &["polymerising"],
    &["polymerizing"],
    &["polymerising"],
];

pub(crate) static ENTRY_POLYPNEA_16221546989138969049: VariantsMap = [
    &["polypnea"],
    &["polypnoea"],
    &["polypnoea"],
    &["polypnoea"],
];

pub(crate) static ENTRY_POLYPNEIC_6919979616272944790: VariantsMap = [
    &["polypneic"],
    &["polypnoeic"],
    &["polypnoeic"],
    &["polypnoeic"],
];

pub(crate) static ENTRY_POLYSULPHURIZATIONS_12547437930211655448: VariantsMap = [
    &["polysulphurizations"],
    &["polysulphurisations"],
    &["polysulphurizations"],
    &["polysulphurisations"],
];

pub(crate) static ENTRY_POLYSULPHURIZATION_16575270856614193114: VariantsMap = [
    &["polysulphurization"],
    &["polysulphurisation"],
    &["polysulphurization"],
    &["polysulphurisation"],
];

pub(crate) static ENTRY_POLYTETRAFLUORETHYLENES_14333880617074724294: VariantsMap = [
    &["polytetrafluorethylenes"],
    &["polytetrafluoroethylenes"],
    &["polytetrafluoroethylenes"],
    &["polytetrafluoroethylenes"],
];

pub(crate) static ENTRY_POLYTETRAFLUORETHYLENE_11537018490473818492: VariantsMap = [
    &["polytetrafluorethylene"],
    &["polytetrafluoroethylene"],
    &["polytetrafluoroethylene"],
    &["polytetrafluoroethylene"],
];

pub(crate) static ENTRY_POMERIUM_7580577065603898743: VariantsMap = [
    &["pomerium"],
    &["pomoerium"],
    &["pomoerium"],
    &["pomoerium"],
];

pub(crate) static ENTRY_POMMELED_16416408068787374405: VariantsMap = [
    &["pommeled"],
    &["pommelled"],
    &["pommelled"],
    &["pommelled"],
];

pub(crate) static ENTRY_POMMELING_3838938060420187338: VariantsMap = [
    &["pommeling"],
    &["pommelling"],
    &["pommelling"],
    &["pommelling"],
];

pub(crate) static ENTRY_POMME_11806614092839333597: VariantsMap =
    [&["pomme"], &["pommae"], &["pommae"], &["pommae"]];

pub(crate) static ENTRY_POPLITEAL_14608064669039474519: VariantsMap = [
    &["popliteal"],
    &["poplitaeal"],
    &["poplitaeal"],
    &["poplitaeal"],
];

pub(crate) static ENTRY_POPULARIZATIONS_10148778209943335276: VariantsMap = [
    &["popularizations"],
    &["popularisations"],
    &["popularizations"],
    &["popularisations"],
];

pub(crate) static ENTRY_POPULARIZATION_10295312737144065502: VariantsMap = [
    &["popularization"],
    &["popularisation"],
    &["popularization"],
    &["popularisation"],
];

pub(crate) static ENTRY_POPULARIZED_13593967020396788947: VariantsMap = [
    &["popularized"],
    &["popularised"],
    &["popularized"],
    &["popularised"],
];

pub(crate) static ENTRY_POPULARIZERS_5104664749735053424: VariantsMap = [
    &["popularizers"],
    &["popularisers"],
    &["popularizers"],
    &["popularisers"],
];

pub(crate) static ENTRY_POPULARIZER_6873378968353377212: VariantsMap = [
    &["popularizer"],
    &["populariser"],
    &["popularizer"],
    &["populariser"],
];

pub(crate) static ENTRY_POPULARIZES_7700265923486687652: VariantsMap = [
    &["popularizes"],
    &["popularises"],
    &["popularizes"],
    &["popularises"],
];

pub(crate) static ENTRY_POPULARIZE_17375893854271172775: VariantsMap = [
    &["popularize"],
    &["popularise"],
    &["popularize"],
    &["popularise"],
];

pub(crate) static ENTRY_POPULARIZING_14605893405429303093: VariantsMap = [
    &["popularizing"],
    &["popularising"],
    &["popularizing"],
    &["popularising"],
];

pub(crate) static ENTRY_PORCELAINIZATIONS_14201569580189820572: VariantsMap = [
    &["porcelainizations"],
    &["porcelainisations"],
    &["porcelainizations"],
    &["porcelainisations"],
];

pub(crate) static ENTRY_PORCELAINIZATION_9987125517935607146: VariantsMap = [
    &["porcelainization"],
    &["porcelainisation"],
    &["porcelainization"],
    &["porcelainisation"],
];

pub(crate) static ENTRY_PORCELAINIZED_8958345284962155259: VariantsMap = [
    &["porcelainized"],
    &["porcelainised"],
    &["porcelainized"],
    &["porcelainised"],
];

pub(crate) static ENTRY_PORCELAINIZES_1116700990546127264: VariantsMap = [
    &["porcelainizes"],
    &["porcelainises"],
    &["porcelainizes"],
    &["porcelainises"],
];

pub(crate) static ENTRY_PORCELAINIZE_7702297476189597070: VariantsMap = [
    &["porcelainize"],
    &["porcelainise"],
    &["porcelainize"],
    &["porcelainise"],
];

pub(crate) static ENTRY_PORCELAINIZING_2678178218886181111: VariantsMap = [
    &["porcelainizing"],
    &["porcelainising"],
    &["porcelainizing"],
    &["porcelainising"],
];

pub(crate) static ENTRY_PORCELLANIZED_12491685883750980597: VariantsMap = [
    &["porcellanized"],
    &["porcellanised"],
    &["porcellanized"],
    &["porcellanised"],
];

pub(crate) static ENTRY_PORCELLANIZES_17114777964969417887: VariantsMap = [
    &["porcellanizes"],
    &["porcellanises"],
    &["porcellanizes"],
    &["porcellanises"],
];

pub(crate) static ENTRY_PORCELLANIZE_5956584629780862310: VariantsMap = [
    &["porcellanize"],
    &["porcellanise"],
    &["porcellanize"],
    &["porcellanise"],
];

pub(crate) static ENTRY_PORCELLANIZING_6640350574304143446: VariantsMap = [
    &["porcellanizing"],
    &["porcellanising"],
    &["porcellanizing"],
    &["porcellanising"],
];

pub(crate) static ENTRY_PORERS_4411327756997706729: VariantsMap =
    [&["porers"], &["pourers"], &["pourers"], &["pourers"]];

pub(crate) static ENTRY_PORER_9472582636394035687: VariantsMap =
    [&["porer"], &["pourer"], &["pourer"], &["pourer"]];

pub(crate) static ENTRY_PORINGLY_740562095994905397: VariantsMap = [
    &["poringly"],
    &["pouringly"],
    &["pouringly"],
    &["pouringly"],
];

pub(crate) static ENTRY_PORPHYRIZATION_15592157274159456926: VariantsMap = [
    &["porphyrization"],
    &["porphyrisation"],
    &["porphyrization"],
    &["porphyrisation"],
];

pub(crate) static ENTRY_PORTE_13739395240559234500: VariantsMap =
    [&["porte"], &["portae"], &["portae"], &["portae"]];

pub(crate) static ENTRY_PORTIONIZES_8759997646839791547: VariantsMap = [
    &["portionizes"],
    &["portionises"],
    &["portionizes"],
    &["portionises"],
];

pub(crate) static ENTRY_PORTIONIZE_8183616402693368236: VariantsMap = [
    &["portionize"],
    &["portionise"],
    &["portionize"],
    &["portionise"],
];

pub(crate) static ENTRY_POSITIVIZES_14569839266695497939: VariantsMap = [
    &["positivizes"],
    &["positivises"],
    &["positivizes"],
    &["positivises"],
];

pub(crate) static ENTRY_POSITIVIZE_13041357091243880766: VariantsMap = [
    &["positivize"],
    &["positivise"],
    &["positivize"],
    &["positivise"],
];

pub(crate) static ENTRY_POSTCECAL_14039669434720483948: VariantsMap = [
    &["postcecal"],
    &["postcaecal"],
    &["postcaecal"],
    &["postcaecal"],
];

pub(crate) static ENTRY_POSTCENAL_71447031611727038: VariantsMap = [
    &["postcenal"],
    &["postcoenal"],
    &["postcoenal"],
    &["postcoenal"],
];

pub(crate) static ENTRY_POSTERIZES_9574605860726504253: VariantsMap = [
    &["posterizes"],
    &["posterises"],
    &["posterizes"],
    &["posterises"],
];

pub(crate) static ENTRY_POSTERIZE_4633009065826989954: VariantsMap = [
    &["posterize"],
    &["posterise"],
    &["posterize"],
    &["posterise"],
];

pub(crate) static ENTRY_POSTFETAL_16829805480542213123: VariantsMap = [
    &["postfetal"],
    &["postfoetal"],
    &["postfoetal"],
    &["postfoetal"],
];

pub(crate) static ENTRY_POSTMEDIEVAL_10289905348058220127: VariantsMap = [
    &["postmedieval"],
    &["postmediaeval"],
    &["postmediaeval"],
    &["postmediaeval"],
];

pub(crate) static ENTRY_POSTSYNCHRONIZATION_9735500999067667804: VariantsMap = [
    &["postsynchronization"],
    &["postsynchronisation"],
    &["postsynchronization"],
    &["postsynchronisation"],
];

pub(crate) static ENTRY_POSTURIZED_2355664241763722768: VariantsMap = [
    &["posturized"],
    &["posturised"],
    &["posturized"],
    &["posturised"],
];

pub(crate) static ENTRY_POSTURIZES_17600122313050486119: VariantsMap = [
    &["posturizes"],
    &["posturises"],
    &["posturizes"],
    &["posturises"],
];

pub(crate) static ENTRY_POSTURIZE_539261955307310954: VariantsMap = [
    &["posturize"],
    &["posturise"],
    &["posturize"],
    &["posturise"],
];

pub(crate) static ENTRY_POSTURIZING_14553163107601026995: VariantsMap = [
    &["posturizing"],
    &["posturising"],
    &["posturizing"],
    &["posturising"],
];

pub(crate) static ENTRY_POTENTIALIZATIONS_16123270987906203275: VariantsMap = [
    &["potentializations"],
    &["potentialisations"],
    &["potentializations"],
    &["potentialisations"],
];

pub(crate) static ENTRY_POTENTIALIZATION_11370824378801485428: VariantsMap = [
    &["potentialization"],
    &["potentialisation"],
    &["potentialization"],
    &["potentialisation"],
];

pub(crate) static ENTRY_POTENTIALIZES_7730671741473751473: VariantsMap = [
    &["potentializes"],
    &["potentialises"],
    &["potentializes"],
    &["potentialises"],
];

pub(crate) static ENTRY_POTENTIALIZE_5306242383006066570: VariantsMap = [
    &["potentialize"],
    &["potentialise"],
    &["potentialize"],
    &["potentialise"],
];

pub(crate) static ENTRY_POTENTIZED_16902758254500333884: VariantsMap = [
    &["potentized"],
    &["potentised"],
    &["potentized"],
    &["potentised"],
];

pub(crate) static ENTRY_POTENTIZES_1694669823229591466: VariantsMap = [
    &["potentizes"],
    &["potentises"],
    &["potentizes"],
    &["potentises"],
];

pub(crate) static ENTRY_POTENTIZE_10353484216841656321: VariantsMap = [
    &["potentize"],
    &["potentise"],
    &["potentize"],
    &["potentise"],
];

pub(crate) static ENTRY_POTENTIZING_10663920911074862748: VariantsMap = [
    &["potentizing"],
    &["potentising"],
    &["potentizing"],
    &["potentising"],
];

pub(crate) static ENTRY_POUDERS_8848899925700000053: VariantsMap =
    [&["pouders"], &["poudres"], &["poudres"], &["poudres"]];

pub(crate) static ENTRY_POUDER_1862804635953235487: VariantsMap =
    [&["pouder"], &["poudre"], &["poudre"], &["poudre"]];

pub(crate) static ENTRY_POULDERS_4715865184887114546: VariantsMap =
    [&["poulders"], &["pouldres"], &["pouldres"], &["pouldres"]];

pub(crate) static ENTRY_POULDER_6920280469594748753: VariantsMap =
    [&["poulder"], &["pouldre"], &["pouldre"], &["pouldre"]];

pub(crate) static ENTRY_POWDERIZATIONS_9770977248142054242: VariantsMap = [
    &["powderizations"],
    &["powderisations"],
    &["powderizations"],
    &["powderisations"],
];

pub(crate) static ENTRY_POWDERIZATION_12047778760438241820: VariantsMap = [
    &["powderization"],
    &["powderisation"],
    &["powderization"],
    &["powderisation"],
];

pub(crate) static ENTRY_POWDERIZERS_7366910102231696330: VariantsMap = [
    &["powderizers"],
    &["powderisers"],
    &["powderizers"],
    &["powderisers"],
];

pub(crate) static ENTRY_POWDERIZER_11484081010411649926: VariantsMap = [
    &["powderizer"],
    &["powderiser"],
    &["powderizer"],
    &["powderiser"],
];

pub(crate) static ENTRY_POWDERIZES_11458042212841934341: VariantsMap = [
    &["powderizes"],
    &["powderises"],
    &["powderizes"],
    &["powderises"],
];

pub(crate) static ENTRY_POWDERIZE_10555038798728915476: VariantsMap = [
    &["powderize"],
    &["powderise"],
    &["powderize"],
    &["powderise"],
];

pub(crate) static ENTRY_POWELLIZED_12963613621406656955: VariantsMap = [
    &["powellized"],
    &["powellised"],
    &["powellized"],
    &["powellised"],
];

pub(crate) static ENTRY_POWELLIZES_16503487494090301096: VariantsMap = [
    &["powellizes"],
    &["powellises"],
    &["powellizes"],
    &["powellises"],
];

pub(crate) static ENTRY_POWELLIZE_14871332950257843934: VariantsMap = [
    &["powellize"],
    &["powellise"],
    &["powellize"],
    &["powellise"],
];

pub(crate) static ENTRY_POWELLIZING_8322629798558997363: VariantsMap = [
    &["powellizing"],
    &["powellising"],
    &["powellizing"],
    &["powellising"],
];

pub(crate) static ENTRY_PRACTICED_11550656047130039147: VariantsMap = [
    &["practiced"],
    &["practised"],
    &["practised"],
    &["practised"],
];

pub(crate) static ENTRY_PRACTICERS_15222235322635642468: VariantsMap = [
    &["practicers"],
    &["practisers"],
    &["practisers"],
    &["practisers"],
];

pub(crate) static ENTRY_PRACTICER_839837859698199934: VariantsMap = [
    &["practicer"],
    &["practiser"],
    &["practiser"],
    &["practiser"],
];

pub(crate) static ENTRY_PRACTICING_13680497227185368763: VariantsMap = [
    &["practicing"],
    &["practising"],
    &["practising"],
    &["practising"],
];

pub(crate) static ENTRY_PRAENOMENS_5004906408322264673: VariantsMap = [
    &["praenomens"],
    &["praenomens"],
    &["praenomens"],
    &["praenomens"],
];

pub(crate) static ENTRY_PRAENOMEN_2873680985932826564: VariantsMap = [
    &["praenomen"],
    &["praenomen"],
    &["praenomen"],
    &["praenomen"],
];

pub(crate) static ENTRY_PRAGMATIZATIONS_1347693305826589779: VariantsMap = [
    &["pragmatizations"],
    &["pragmatisations"],
    &["pragmatizations"],
    &["pragmatisations"],
];

pub(crate) static ENTRY_PRAGMATIZATION_8346324153987456718: VariantsMap = [
    &["pragmatization"],
    &["pragmatisation"],
    &["pragmatization"],
    &["pragmatisation"],
];

pub(crate) static ENTRY_PRAGMATIZED_15911492964724941957: VariantsMap = [
    &["pragmatized"],
    &["pragmatised"],
    &["pragmatized"],
    &["pragmatised"],
];

pub(crate) static ENTRY_PRAGMATIZERS_17050725505178628169: VariantsMap = [
    &["pragmatizers"],
    &["pragmatisers"],
    &["pragmatizers"],
    &["pragmatisers"],
];

pub(crate) static ENTRY_PRAGMATIZER_13231924506248328620: VariantsMap = [
    &["pragmatizer"],
    &["pragmatiser"],
    &["pragmatizer"],
    &["pragmatiser"],
];

pub(crate) static ENTRY_PRAGMATIZES_4196103149615407244: VariantsMap = [
    &["pragmatizes"],
    &["pragmatises"],
    &["pragmatizes"],
    &["pragmatises"],
];

pub(crate) static ENTRY_PRAGMATIZE_10222982293817030908: VariantsMap = [
    &["pragmatize"],
    &["pragmatise"],
    &["pragmatize"],
    &["pragmatise"],
];

pub(crate) static ENTRY_PRAGMATIZING_5484672503035338428: VariantsMap = [
    &["pragmatizing"],
    &["pragmatising"],
    &["pragmatizing"],
    &["pragmatising"],
];

pub(crate) static ENTRY_PREABDOMEN_8539482488045440061: VariantsMap = [
    &["preabdomen"],
    &["praeabdomen"],
    &["praeabdomen"],
    &["praeabdomen"],
];

pub(crate) static ENTRY_PREACETABULAR_8250642348247679862: VariantsMap = [
    &["preacetabular"],
    &["praeacetabular"],
    &["praeacetabular"],
    &["praeacetabular"],
];

pub(crate) static ENTRY_PREACHERIZES_18214780901228990451: VariantsMap = [
    &["preacherizes"],
    &["preacherises"],
    &["preacherizes"],
    &["preacherises"],
];

pub(crate) static ENTRY_PREACHERIZE_3114832429644025826: VariantsMap = [
    &["preacherize"],
    &["preacherise"],
    &["preacherize"],
    &["preacherise"],
];

pub(crate) static ENTRY_PREACKNOWLEDGMENTS_5969739714891516296: VariantsMap = [
    &["preacknowledgments"],
    &["preacknowledgements"],
    &["preacknowledgements"],
    &["preacknowledgements"],
];

pub(crate) static ENTRY_PREACKNOWLEDGMENT_15471253594011483017: VariantsMap = [
    &["preacknowledgment"],
    &["preacknowledgement"],
    &["preacknowledgement"],
    &["preacknowledgement"],
];

pub(crate) static ENTRY_PREANAL_8282447312000633016: VariantsMap =
    [&["preanal"], &["praeanal"], &["praeanal"], &["praeanal"]];

pub(crate) static ENTRY_PREANESTHETICS_8419853812971756134: VariantsMap = [
    &["preanesthetics"],
    &["preanaesthetics"],
    &["preanaesthetics"],
    &["preanaesthetics"],
];

pub(crate) static ENTRY_PREANESTHETIC_17135960641353610099: VariantsMap = [
    &["preanesthetic"],
    &["preanaesthetic"],
    &["preanaesthetic"],
    &["preanaesthetic"],
];

pub(crate) static ENTRY_PREAPPRIZED_1864318479019696185: VariantsMap = [
    &["preapprized"],
    &["preapprised"],
    &["preapprized"],
    &["preapprised"],
];

pub(crate) static ENTRY_PREAPPRIZE_14429026707964341876: VariantsMap = [
    &["preapprize"],
    &["preapprise"],
    &["preapprize"],
    &["preapprise"],
];

pub(crate) static ENTRY_PREAPPRIZING_7573932856271642590: VariantsMap = [
    &["preapprizing"],
    &["preapprising"],
    &["preapprizing"],
    &["preapprising"],
];

pub(crate) static ENTRY_PREAUTHORIZE_15918741156332951414: VariantsMap = [
    &["preauthorize"],
    &["preauthorise"],
    &["preauthorize"],
    &["preauthorise"],
];

pub(crate) static ENTRY_PREBAPTIZES_11093608958711804148: VariantsMap = [
    &["prebaptizes"],
    &["prebaptises"],
    &["prebaptizes"],
    &["prebaptises"],
];

pub(crate) static ENTRY_PREBAPTIZE_17160053539170465128: VariantsMap = [
    &["prebaptize"],
    &["prebaptise"],
    &["prebaptize"],
    &["prebaptise"],
];

pub(crate) static ENTRY_PRECANCELATION_15491223411860446070: VariantsMap = [
    &["precancelation"],
    &["precancellation"],
    &["precancellation"],
    &["precancellation"],
];

pub(crate) static ENTRY_PRECAVAE_5572444235139095890: VariantsMap = [
    &["precavae"],
    &["praecavae"],
    &["praecavae"],
    &["praecavae"],
];

pub(crate) static ENTRY_PRECAVA_2402040055160081507: VariantsMap =
    [&["precava"], &["praecava"], &["praecava"], &["praecava"]];

pub(crate) static ENTRY_PRECIPES_591594308859789992: VariantsMap = [
    &["precipes"],
    &["praecipes"],
    &["praecipes"],
    &["praecipes"],
];

pub(crate) static ENTRY_PRECIPE_13555769800049677911: VariantsMap =
    [&["precipe"], &["praecipe"], &["praecipe"], &["praecipe"]];

pub(crate) static ENTRY_PRECISIONIZES_17461523032107876112: VariantsMap = [
    &["precisionizes"],
    &["precisionises"],
    &["precisionizes"],
    &["precisionises"],
];

pub(crate) static ENTRY_PRECISIONIZE_16309913476870820127: VariantsMap = [
    &["precisionize"],
    &["precisionise"],
    &["precisionize"],
    &["precisionise"],
];

pub(crate) static ENTRY_PRECIVILIZATIONS_15617845600007536715: VariantsMap = [
    &["precivilizations"],
    &["precivilisations"],
    &["precivilizations"],
    &["precivilisations"],
];

pub(crate) static ENTRY_PRECIVILIZATION_8718510999880386433: VariantsMap = [
    &["precivilization"],
    &["precivilisation"],
    &["precivilization"],
    &["precivilisation"],
];

pub(crate) static ENTRY_PRECOCIAL_8294693877415543753: VariantsMap = [
    &["precocial"],
    &["praecocial"],
    &["praecocial"],
    &["praecocial"],
];

pub(crate) static ENTRY_PRECOLORABLER_11767685787558642755: VariantsMap = [
    &["precolorabler"],
    &["precolourabler"],
    &["precolourabler"],
    &["precolourabler"],
];

pub(crate) static ENTRY_PRECOLORABLEST_6808278957047261325: VariantsMap = [
    &["precolorablest"],
    &["precolourablest"],
    &["precolourablest"],
    &["precolourablest"],
];

pub(crate) static ENTRY_PRECOLORABLES_16733631722514561712: VariantsMap = [
    &["precolorables"],
    &["precolourables"],
    &["precolourables"],
    &["precolourables"],
];

pub(crate) static ENTRY_PRECOLORABLE_5487085359496706867: VariantsMap = [
    &["precolorable"],
    &["precolourable"],
    &["precolourable"],
    &["precolourable"],
];

pub(crate) static ENTRY_PRECOLORATIONS_10499804334250645010: VariantsMap = [
    &["precolorations"],
    &["precolourations"],
    &["precolourations"],
    &["precolourations"],
];

pub(crate) static ENTRY_PRECOLORATION_10656995892359877853: VariantsMap = [
    &["precoloration"],
    &["precolouration"],
    &["precolouration"],
    &["precolouration"],
];

pub(crate) static ENTRY_PRECOLORED_9698300540722607314: VariantsMap = [
    &["precolored"],
    &["precoloured"],
    &["precoloured"],
    &["precoloured"],
];

pub(crate) static ENTRY_PRECOLORINGS_4691510199823561883: VariantsMap = [
    &["precolorings"],
    &["precolourings"],
    &["precolourings"],
    &["precolourings"],
];

pub(crate) static ENTRY_PRECOLORING_6024220919758395050: VariantsMap = [
    &["precoloring"],
    &["precolouring"],
    &["precolouring"],
    &["precolouring"],
];

pub(crate) static ENTRY_PRECOLORS_9083220684090884764: VariantsMap = [
    &["precolors"],
    &["precolours"],
    &["precolours"],
    &["precolours"],
];

pub(crate) static ENTRY_PRECOLOR_17299860958104955202: VariantsMap = [
    &["precolor"],
    &["precolour"],
    &["precolour"],
    &["precolour"],
];

pub(crate) static ENTRY_PRECONIZATIONS_12551697775601965661: VariantsMap = [
    &["preconizations"],
    &["preconisations"],
    &["preconizations"],
    &["preconisations"],
];

pub(crate) static ENTRY_PRECONIZATION_16258034160636183447: VariantsMap = [
    &["preconization"],
    &["preconisation"],
    &["preconization"],
    &["preconisation"],
];

pub(crate) static ENTRY_PRECONIZED_9790826501440568673: VariantsMap = [
    &["preconized"],
    &["preconised"],
    &["preconized"],
    &["preconised"],
];

pub(crate) static ENTRY_PRECONIZERS_5442536382274699448: VariantsMap = [
    &["preconizers"],
    &["preconisers"],
    &["preconizers"],
    &["preconisers"],
];

pub(crate) static ENTRY_PRECONIZER_1030946604754458839: VariantsMap = [
    &["preconizer"],
    &["preconiser"],
    &["preconizer"],
    &["preconiser"],
];

pub(crate) static ENTRY_PRECONIZES_1119327710154936908: VariantsMap = [
    &["preconizes"],
    &["preconises"],
    &["preconizes"],
    &["preconises"],
];

pub(crate) static ENTRY_PRECONIZE_9740123560582240989: VariantsMap = [
    &["preconize"],
    &["preconise"],
    &["preconize"],
    &["preconise"],
];

pub(crate) static ENTRY_PRECONIZING_10462413300311269807: VariantsMap = [
    &["preconizing"],
    &["preconising"],
    &["preconizing"],
    &["preconising"],
];

pub(crate) static ENTRY_PRECORACOID_8217660205581287132: VariantsMap = [
    &["precoracoid"],
    &["praecoracoid"],
    &["praecoracoid"],
    &["praecoracoid"],
];

pub(crate) static ENTRY_PRECORDIAL_11745663068833489838: VariantsMap = [
    &["precordial"],
    &["praecordial"],
    &["praecordial"],
    &["praecordial"],
];

pub(crate) static ENTRY_PRECORDIA_1238253163440816627: VariantsMap = [
    &["precordia"],
    &["praecordia"],
    &["praecordia"],
    &["praecordia"],
];

pub(crate) static ENTRY_PRECORDIUM_5299854035063803868: VariantsMap = [
    &["precordium"],
    &["praecordium"],
    &["praecordium"],
    &["praecordium"],
];

pub(crate) static ENTRY_PRECORNU_1505512584010830310: VariantsMap = [
    &["precornu"],
    &["praecornu"],
    &["praecornu"],
    &["praecornu"],
];

pub(crate) static ENTRY_PRECOX_3189402882782043655: VariantsMap =
    [&["precox"], &["praecox"], &["praecox"], &["praecox"]];

pub(crate) static ENTRY_PRECRITICIZES_15135281493768452751: VariantsMap = [
    &["precriticizes"],
    &["precriticises"],
    &["precriticizes"],
    &["precriticises"],
];

pub(crate) static ENTRY_PRECRITICIZE_8846824592864407133: VariantsMap = [
    &["precriticize"],
    &["precriticise"],
    &["precriticize"],
    &["precriticise"],
];

pub(crate) static ENTRY_PRECUNEUS_11481546809254856891: VariantsMap = [
    &["precuneus"],
    &["praecuneus"],
    &["praecuneus"],
    &["praecuneus"],
];

pub(crate) static ENTRY_PREDIALIST_224083735542634220: VariantsMap = [
    &["predialist"],
    &["praedialist"],
    &["praedialist"],
    &["praedialist"],
];

pub(crate) static ENTRY_PREDIALITY_5750901920352866705: VariantsMap = [
    &["prediality"],
    &["praediality"],
    &["praediality"],
    &["praediality"],
];

pub(crate) static ENTRY_PREDIALS_13414568675400088449: VariantsMap = [
    &["predials"],
    &["praedials"],
    &["praedials"],
    &["praedials"],
];

pub(crate) static ENTRY_PREDIAL_9694094483984666534: VariantsMap =
    [&["predial"], &["praedial"], &["praedial"], &["praedial"]];

pub(crate) static ENTRY_PREEMPTOR_2461656381478908185: VariantsMap = [
    &["preemptor"],
    &["preaemptor"],
    &["preaemptor"],
    &["preaemptor"],
];

pub(crate) static ENTRY_PREESOPHAGEAL_14877226231602978003: VariantsMap = [
    &["preesophageal"],
    &["praeesophageal"],
    &["praeesophageal"],
    &["praeesophageal"],
];

pub(crate) static ENTRY_PREESOPHAGEAL_2065887315526261809: VariantsMap = [
    &["preesophageal"],
    &["preoesophageal"],
    &["preoesophageal"],
    &["preoesophageal"],
];

pub(crate) static ENTRY_PREESTIVAL_6075881105306786790: VariantsMap = [
    &["preestival"],
    &["preaestival"],
    &["preaestival"],
    &["preaestival"],
];

pub(crate) static ENTRY_PREEXISTENT_5468737224949447194: VariantsMap = [
    &["preexistent"],
    &["preaexistent"],
    &["preaexistent"],
    &["preaexistent"],
];

pub(crate) static ENTRY_PREFAVORABLES_15171050073851160534: VariantsMap = [
    &["prefavorables"],
    &["prefavourables"],
    &["prefavourables"],
    &["prefavourables"],
];

pub(crate) static ENTRY_PREFAVORABLE_15977451896887575400: VariantsMap = [
    &["prefavorable"],
    &["prefavourable"],
    &["prefavourable"],
    &["prefavourable"],
];

pub(crate) static ENTRY_PREFAVORABLIES_10995828792301769177: VariantsMap = [
    &["prefavorablies"],
    &["prefavourablies"],
    &["prefavourablies"],
    &["prefavourablies"],
];

pub(crate) static ENTRY_PREFAVORABLY_2906405353959131669: VariantsMap = [
    &["prefavorably"],
    &["prefavourably"],
    &["prefavourably"],
    &["prefavourably"],
];

pub(crate) static ENTRY_PREFAVORITES_1782004517342464146: VariantsMap = [
    &["prefavorites"],
    &["prefavourites"],
    &["prefavourites"],
    &["prefavourites"],
];

pub(crate) static ENTRY_PREFAVORITE_12845110563536419892: VariantsMap = [
    &["prefavorite"],
    &["prefavourite"],
    &["prefavourite"],
    &["prefavourite"],
];

pub(crate) static ENTRY_PREFAVORS_7516975395445427601: VariantsMap = [
    &["prefavors"],
    &["prefavours"],
    &["prefavours"],
    &["prefavours"],
];

pub(crate) static ENTRY_PREFAVOR_9822958321616866402: VariantsMap = [
    &["prefavor"],
    &["prefavour"],
    &["prefavour"],
    &["prefavour"],
];

pub(crate) static ENTRY_PREFECTORIAL_15709778797625379140: VariantsMap = [
    &["prefectorial"],
    &["praefectorial"],
    &["praefectorial"],
    &["praefectorial"],
];

pub(crate) static ENTRY_PREFERTILIZATIONS_1818756888116056700: VariantsMap = [
    &["prefertilizations"],
    &["prefertilisations"],
    &["prefertilizations"],
    &["prefertilisations"],
];

pub(crate) static ENTRY_PREFERTILIZATION_18227646050360159024: VariantsMap = [
    &["prefertilization"],
    &["prefertilisation"],
    &["prefertilization"],
    &["prefertilisation"],
];

pub(crate) static ENTRY_PREFERTILIZES_1495803436587693020: VariantsMap = [
    &["prefertilizes"],
    &["prefertilises"],
    &["prefertilizes"],
    &["prefertilises"],
];

pub(crate) static ENTRY_PREFERTILIZE_14615806731386054716: VariantsMap = [
    &["prefertilize"],
    &["prefertilise"],
    &["prefertilize"],
    &["prefertilise"],
];

pub(crate) static ENTRY_PREFLAVORINGS_4617219348151300123: VariantsMap = [
    &["preflavorings"],
    &["preflavourings"],
    &["preflavourings"],
    &["preflavourings"],
];

pub(crate) static ENTRY_PREFLAVORING_6802911008767761287: VariantsMap = [
    &["preflavoring"],
    &["preflavouring"],
    &["preflavouring"],
    &["preflavouring"],
];

pub(crate) static ENTRY_PREFLAVORS_6105553296569719644: VariantsMap = [
    &["preflavors"],
    &["preflavours"],
    &["preflavours"],
    &["preflavours"],
];

pub(crate) static ENTRY_PREFLAVOR_17202106869497805689: VariantsMap = [
    &["preflavor"],
    &["preflavour"],
    &["preflavour"],
    &["preflavour"],
];

pub(crate) static ENTRY_PREFLORATION_11916715073975297394: VariantsMap = [
    &["prefloration"],
    &["praefloration"],
    &["praefloration"],
    &["praefloration"],
];

pub(crate) static ENTRY_PREFOLIATION_802436263196003766: VariantsMap = [
    &["prefoliation"],
    &["praefoliation"],
    &["praefoliation"],
    &["praefoliation"],
];

pub(crate) static ENTRY_PREGALVANIZES_12463518520956893780: VariantsMap = [
    &["pregalvanizes"],
    &["pregalvanises"],
    &["pregalvanizes"],
    &["pregalvanises"],
];

pub(crate) static ENTRY_PREGALVANIZE_12483583304872451614: VariantsMap = [
    &["pregalvanize"],
    &["pregalvanise"],
    &["pregalvanize"],
    &["pregalvanise"],
];

pub(crate) static ENTRY_PREHALLUX_13547378424609565453: VariantsMap = [
    &["prehallux"],
    &["praehallux"],
    &["praehallux"],
    &["praehallux"],
];

pub(crate) static ENTRY_PREHUMORS_5727486563202761536: VariantsMap = [
    &["prehumors"],
    &["prehumours"],
    &["prehumours"],
    &["prehumours"],
];

pub(crate) static ENTRY_PREHUMOR_5171358378179024334: VariantsMap = [
    &["prehumor"],
    &["prehumour"],
    &["prehumour"],
    &["prehumour"],
];

pub(crate) static ENTRY_PREINITIALIZED_1342530234296788703: VariantsMap = [
    &["preinitialized"],
    &["preinitialised"],
    &["preinitialized"],
    &["preinitialised"],
];

pub(crate) static ENTRY_PREINITIALIZES_1948106422392976020: VariantsMap = [
    &["preinitializes"],
    &["preinitialises"],
    &["preinitializes"],
    &["preinitialises"],
];

pub(crate) static ENTRY_PREINITIALIZE_5958730031534599577: VariantsMap = [
    &["preinitialize"],
    &["preinitialise"],
    &["preinitialize"],
    &["preinitialise"],
];

pub(crate) static ENTRY_PREINITIALIZING_12725446901089230467: VariantsMap = [
    &["preinitializing"],
    &["preinitialising"],
    &["preinitializing"],
    &["preinitialising"],
];

pub(crate) static ENTRY_PREJUDGMENTS_10781730302929103775: VariantsMap = [
    &["prejudgments"],
    &["prejudgements"],
    &["prejudgments"],
    &["prejudgements"],
];

pub(crate) static ENTRY_PREJUDGMENT_17092778308241323356: VariantsMap = [
    &["prejudgment"],
    &["prejudgement"],
    &["prejudgment"],
    &["prejudgement"],
];

pub(crate) static ENTRY_PRELABORS_17252519264142630543: VariantsMap = [
    &["prelabors"],
    &["prelabours"],
    &["prelabours"],
    &["prelabours"],
];

pub(crate) static ENTRY_PRELABOR_12579549139000343078: VariantsMap = [
    &["prelabor"],
    &["prelabour"],
    &["prelabour"],
    &["prelabour"],
];

pub(crate) static ENTRY_PRELABRUM_10363708726410721819: VariantsMap = [
    &["prelabrum"],
    &["praelabrum"],
    &["praelabrum"],
    &["praelabrum"],
];

pub(crate) static ENTRY_PRELATIZED_17510592065974205916: VariantsMap = [
    &["prelatized"],
    &["prelatised"],
    &["prelatized"],
    &["prelatised"],
];

pub(crate) static ENTRY_PRELATIZES_10566341519699434934: VariantsMap = [
    &["prelatizes"],
    &["prelatises"],
    &["prelatizes"],
    &["prelatises"],
];

pub(crate) static ENTRY_PRELATIZE_4433569070164127916: VariantsMap = [
    &["prelatize"],
    &["prelatise"],
    &["prelatize"],
    &["prelatise"],
];

pub(crate) static ENTRY_PRELATIZING_14962226743591213307: VariantsMap = [
    &["prelatizing"],
    &["prelatising"],
    &["prelatizing"],
    &["prelatising"],
];

pub(crate) static ENTRY_PRELECTED_7002487587150372222: VariantsMap = [
    &["prelected"],
    &["praelected"],
    &["praelected"],
    &["praelected"],
];

pub(crate) static ENTRY_PRELECTING_16302727756637083199: VariantsMap = [
    &["prelecting"],
    &["praelecting"],
    &["praelecting"],
    &["praelecting"],
];

pub(crate) static ENTRY_PRELECTION_2555285504483882003: VariantsMap = [
    &["prelection"],
    &["praelection"],
    &["praelection"],
    &["praelection"],
];

pub(crate) static ENTRY_PRELECTORSHIP_10522488084784290490: VariantsMap = [
    &["prelectorship"],
    &["praelectorship"],
    &["praelectorship"],
    &["praelectorship"],
];

pub(crate) static ENTRY_PRELECTOR_8132693048713382385: VariantsMap = [
    &["prelector"],
    &["praelector"],
    &["praelector"],
    &["praelector"],
];

pub(crate) static ENTRY_PRELECTRESS_16642358695295070918: VariantsMap = [
    &["prelectress"],
    &["praelectress"],
    &["praelectress"],
    &["praelectress"],
];

pub(crate) static ENTRY_PRELECTS_14241179781669955525: VariantsMap = [
    &["prelects"],
    &["praelects"],
    &["praelects"],
    &["praelects"],
];

pub(crate) static ENTRY_PRELECT_15124133363040005475: VariantsMap =
    [&["prelect"], &["praelect"], &["praelect"], &["praelect"]];

pub(crate) static ENTRY_PRELOCALIZATIONS_6698192050669739492: VariantsMap = [
    &["prelocalizations"],
    &["prelocalisations"],
    &["prelocalizations"],
    &["prelocalisations"],
];

pub(crate) static ENTRY_PRELOCALIZATION_17757820466661991097: VariantsMap = [
    &["prelocalization"],
    &["prelocalisation"],
    &["prelocalization"],
    &["prelocalisation"],
];

pub(crate) static ENTRY_PRELUDIUM_16182938175477138747: VariantsMap = [
    &["preludium"],
    &["praeludium"],
    &["praeludium"],
    &["praeludium"],
];

pub(crate) static ENTRY_PRELUDIZES_17476896209888158296: VariantsMap = [
    &["preludizes"],
    &["preludises"],
    &["preludizes"],
    &["preludises"],
];

pub(crate) static ENTRY_PRELUDIZE_11687616460356004648: VariantsMap = [
    &["preludize"],
    &["preludise"],
    &["preludize"],
    &["preludise"],
];

pub(crate) static ENTRY_PREMAXILLA_16555020865872052033: VariantsMap = [
    &["premaxilla"],
    &["praemaxilla"],
    &["praemaxilla"],
    &["praemaxilla"],
];

pub(crate) static ENTRY_PREMIAL_17144185719904663728: VariantsMap =
    [&["premial"], &["proemial"], &["proemial"], &["proemial"]];

pub(crate) static ENTRY_PREMILLENNIALIZED_9480514167408665185: VariantsMap = [
    &["premillennialized"],
    &["premillennialised"],
    &["premillennialized"],
    &["premillennialised"],
];

pub(crate) static ENTRY_PREMILLENNIALIZE_18288969862610819617: VariantsMap = [
    &["premillennialize"],
    &["premillennialise"],
    &["premillennialize"],
    &["premillennialise"],
];

pub(crate) static ENTRY_PREMILLENNIALIZING_250347440556746925: VariantsMap = [
    &["premillennializing"],
    &["premillennialising"],
    &["premillennializing"],
    &["premillennialising"],
];

pub(crate) static ENTRY_PREMONOPOLIZES_7937512297899186558: VariantsMap = [
    &["premonopolizes"],
    &["premonopolises"],
    &["premonopolizes"],
    &["premonopolises"],
];

pub(crate) static ENTRY_PREMONOPOLIZE_14172697931226828378: VariantsMap = [
    &["premonopolize"],
    &["premonopolise"],
    &["premonopolize"],
    &["premonopolise"],
];

pub(crate) static ENTRY_PREMUNIRE_3892014183676337382: VariantsMap = [
    &["premunire"],
    &["praemunire"],
    &["praemunire"],
    &["praemunire"],
];

pub(crate) static ENTRY_PRENARIAL_18182351486930830192: VariantsMap = [
    &["prenarial"],
    &["praenarial"],
    &["praenarial"],
    &["praenarial"],
];

pub(crate) static ENTRY_PRENEURAL_3562453023809034170: VariantsMap = [
    &["preneural"],
    &["praeneural"],
    &["praeneural"],
    &["praeneural"],
];

pub(crate) static ENTRY_PRENOMINAL_10726676408919250433: VariantsMap = [
    &["prenominal"],
    &["praenominal"],
    &["praenominal"],
    &["praenominal"],
];

pub(crate) static ENTRY_PRENOMINA_17447004374293437505: VariantsMap = [
    &["prenomina"],
    &["praenomina"],
    &["praenomina"],
    &["praenomina"],
];

pub(crate) static ENTRY_PREOFFENSES_7584630623721414684: VariantsMap = [
    &["preoffenses"],
    &["preoffences"],
    &["preoffences"],
    &["preoffences"],
];

pub(crate) static ENTRY_PREOFFENSE_11630042685186486975: VariantsMap = [
    &["preoffense"],
    &["preoffence"],
    &["preoffence"],
    &["preoffence"],
];

pub(crate) static ENTRY_PREOPERCULUM_4376076836382915800: VariantsMap = [
    &["preoperculum"],
    &["praeoperculum"],
    &["praeoperculum"],
    &["praeoperculum"],
];

pub(crate) static ENTRY_PREORGANIZATIONS_3818715016042200743: VariantsMap = [
    &["preorganizations"],
    &["preorganisations"],
    &["preorganizations"],
    &["preorganisations"],
];

pub(crate) static ENTRY_PREORGANIZATION_17672450543180011422: VariantsMap = [
    &["preorganization"],
    &["preorganisation"],
    &["preorganization"],
    &["preorganisation"],
];

pub(crate) static ENTRY_PREORGANIZES_17328812055563044028: VariantsMap = [
    &["preorganizes"],
    &["preorganises"],
    &["preorganizes"],
    &["preorganises"],
];

pub(crate) static ENTRY_PREORGANIZE_15777355745082526626: VariantsMap = [
    &["preorganize"],
    &["preorganise"],
    &["preorganize"],
    &["preorganise"],
];

pub(crate) static ENTRY_PREOXIDIZED_9338268775141885485: VariantsMap = [
    &["preoxidized"],
    &["preoxidised"],
    &["preoxidized"],
    &["preoxidised"],
];

pub(crate) static ENTRY_PREOXIDIZES_17578000495699558353: VariantsMap = [
    &["preoxidizes"],
    &["preoxidises"],
    &["preoxidizes"],
    &["preoxidises"],
];

pub(crate) static ENTRY_PREOXIDIZE_17502318642758251409: VariantsMap = [
    &["preoxidize"],
    &["preoxidise"],
    &["preoxidize"],
    &["preoxidise"],
];

pub(crate) static ENTRY_PREOXIDIZING_3438668301704654435: VariantsMap = [
    &["preoxidizing"],
    &["preoxidising"],
    &["preoxidizing"],
    &["preoxidising"],
];

pub(crate) static ENTRY_PREPALEOLITHIC_14202951488126805096: VariantsMap = [
    &["prepaleolithic"],
    &["prepalaeolithic"],
    &["prepalaeolithic"],
    &["prepalaeolithic"],
];

pub(crate) static ENTRY_PREPOSITOR_12797659440544372540: VariantsMap = [
    &["prepositor"],
    &["praepositor"],
    &["praepositor"],
    &["praepositor"],
];

pub(crate) static ENTRY_PREPOSITURE_5966359554589897516: VariantsMap = [
    &["prepositure"],
    &["praepositure"],
    &["praepositure"],
    &["praepositure"],
];

pub(crate) static ENTRY_PREPOSTER_9979045838450867710: VariantsMap = [
    &["preposter"],
    &["praeposter"],
    &["praeposter"],
    &["praeposter"],
];

pub(crate) static ENTRY_PREPOSTORS_8760995478070950332: VariantsMap = [
    &["prepostors"],
    &["praepostors"],
    &["praepostors"],
    &["praepostors"],
];

pub(crate) static ENTRY_PREPOSTOR_6334579978765007057: VariantsMap = [
    &["prepostor"],
    &["praepostor"],
    &["praepostor"],
    &["praepostor"],
];

pub(crate) static ENTRY_PREPROGRAM_182544249377649179: VariantsMap = [
    &["preprogram"],
    &["preprogramme"],
    &["preprogram"],
    &["preprogramme"],
];

pub(crate) static ENTRY_PREPUBIS_17618648717583634353: VariantsMap = [
    &["prepubis"],
    &["praepubis"],
    &["praepubis"],
    &["praepubis"],
];

pub(crate) static ENTRY_PREREALIZATIONS_7749496154695447428: VariantsMap = [
    &["prerealizations"],
    &["prerealisations"],
    &["prerealizations"],
    &["prerealisations"],
];

pub(crate) static ENTRY_PREREALIZATION_4400758119524381256: VariantsMap = [
    &["prerealization"],
    &["prerealisation"],
    &["prerealization"],
    &["prerealisation"],
];

pub(crate) static ENTRY_PREREALIZES_2515206386849164818: VariantsMap = [
    &["prerealizes"],
    &["prerealises"],
    &["prerealizes"],
    &["prerealises"],
];

pub(crate) static ENTRY_PREREALIZE_10993114358642100374: VariantsMap = [
    &["prerealize"],
    &["prerealise"],
    &["prerealize"],
    &["prerealise"],
];

pub(crate) static ENTRY_PRERECOGNIZES_7610001357511214473: VariantsMap = [
    &["prerecognizes"],
    &["prerecognises"],
    &["prerecognizes"],
    &["prerecognises"],
];

pub(crate) static ENTRY_PRERECOGNIZE_14434517406120082197: VariantsMap = [
    &["prerecognize"],
    &["prerecognise"],
    &["prerecognize"],
    &["prerecognise"],
];

pub(crate) static ENTRY_PRESBYTERIANIZED_5190559539797332403: VariantsMap = [
    &["presbyterianized"],
    &["presbyterianised"],
    &["presbyterianized"],
    &["presbyterianised"],
];

pub(crate) static ENTRY_PRESBYTERIANIZES_8616191738584033370: VariantsMap = [
    &["presbyterianizes"],
    &["presbyterianises"],
    &["presbyterianizes"],
    &["presbyterianises"],
];

pub(crate) static ENTRY_PRESBYTERIANIZE_8184517241649663285: VariantsMap = [
    &["presbyterianize"],
    &["presbyterianise"],
    &["presbyterianize"],
    &["presbyterianise"],
];

pub(crate) static ENTRY_PRESBYTERIANIZING_11910404725477468034: VariantsMap = [
    &["presbyterianizing"],
    &["presbyterianising"],
    &["presbyterianizing"],
    &["presbyterianising"],
];

pub(crate) static ENTRY_PRESCUTUM_17649301303017684495: VariantsMap = [
    &["prescutum"],
    &["praescutum"],
    &["praescutum"],
    &["praescutum"],
];

pub(crate) static ENTRY_PRESIDIUMS_9456994175801399467: VariantsMap = [
    &["praesidiums", "presidia", "presidiums"],
    &["presidiums"],
    &["presidiums"],
    &["presidiums"],
];

pub(crate) static ENTRY_PRESPECIALIZES_4338740854406485524: VariantsMap = [
    &["prespecializes"],
    &["prespecialises"],
    &["prespecializes"],
    &["prespecialises"],
];

pub(crate) static ENTRY_PRESPECIALIZE_5200997299409119252: VariantsMap = [
    &["prespecialize"],
    &["prespecialise"],
    &["prespecialize"],
    &["prespecialise"],
];

pub(crate) static ENTRY_PRESPHENOID_4701941519879933792: VariantsMap = [
    &["presphenoid"],
    &["praesphenoid"],
    &["praesphenoid"],
    &["praesphenoid"],
];

pub(crate) static ENTRY_PRESPLENDORS_7651174344094545694: VariantsMap = [
    &["presplendors"],
    &["presplendours"],
    &["presplendours"],
    &["presplendours"],
];

pub(crate) static ENTRY_PRESPLENDOR_14618107087953500253: VariantsMap = [
    &["presplendor"],
    &["presplendour"],
    &["presplendour"],
    &["presplendour"],
];

pub(crate) static ENTRY_PRESSURIZATIONS_9413572764001477371: VariantsMap = [
    &["pressurizations"],
    &["pressurisations"],
    &["pressurizations"],
    &["pressurisations"],
];

pub(crate) static ENTRY_PRESSURIZATION_4111870375056375369: VariantsMap = [
    &["pressurization"],
    &["pressurisation"],
    &["pressurization"],
    &["pressurisation"],
];

pub(crate) static ENTRY_PRESSURIZED_5893734113312881931: VariantsMap = [
    &["pressurized"],
    &["pressurised"],
    &["pressurized"],
    &["pressurised"],
];

pub(crate) static ENTRY_PRESSURIZERS_9860382008246735540: VariantsMap = [
    &["pressurizers"],
    &["pressurisers"],
    &["pressurizers"],
    &["pressurisers"],
];

pub(crate) static ENTRY_PRESSURIZER_14526609251745245222: VariantsMap = [
    &["pressurizer"],
    &["pressuriser"],
    &["pressurizer"],
    &["pressuriser"],
];

pub(crate) static ENTRY_PRESSURIZES_3533546061921034401: VariantsMap = [
    &["pressurizes"],
    &["pressurises"],
    &["pressurizes"],
    &["pressurises"],
];

pub(crate) static ENTRY_PRESSURIZE_3538034947751085670: VariantsMap = [
    &["pressurize"],
    &["pressurise"],
    &["pressurize"],
    &["pressurise"],
];

pub(crate) static ENTRY_PRESSURIZING_920510292816130320: VariantsMap = [
    &["pressurizing"],
    &["pressurising"],
    &["pressurizing"],
    &["pressurising"],
];

pub(crate) static ENTRY_PRESTANDARDIZATIONS_5412386093865221649: VariantsMap = [
    &["prestandardizations"],
    &["prestandardisations"],
    &["prestandardizations"],
    &["prestandardisations"],
];

pub(crate) static ENTRY_PRESTANDARDIZATION_3948421959409387438: VariantsMap = [
    &["prestandardization"],
    &["prestandardisation"],
    &["prestandardization"],
    &["prestandardisation"],
];

pub(crate) static ENTRY_PRESTANDARDIZES_9801992665812395054: VariantsMap = [
    &["prestandardizes"],
    &["prestandardises"],
    &["prestandardizes"],
    &["prestandardises"],
];

pub(crate) static ENTRY_PRESTANDARDIZE_16454569100293825332: VariantsMap = [
    &["prestandardize"],
    &["prestandardise"],
    &["prestandardize"],
    &["prestandardise"],
];

pub(crate) static ENTRY_PRESTERNAL_3731098073887538850: VariantsMap = [
    &["presternal"],
    &["praesternal"],
    &["praesternal"],
    &["praesternal"],
];

pub(crate) static ENTRY_PRESTERNUM_10191977327812747108: VariantsMap = [
    &["presternum"],
    &["praesternum"],
    &["praesternum"],
    &["praesternum"],
];

pub(crate) static ENTRY_PRESTOMIUM_2175790353005742393: VariantsMap = [
    &["prestomium"],
    &["praestomium"],
    &["praestomium"],
    &["praestomium"],
];

pub(crate) static ENTRY_PRESYMPATHIZES_2675310532900913878: VariantsMap = [
    &["presympathizes"],
    &["presympathises"],
    &["presympathizes"],
    &["presympathises"],
];

pub(crate) static ENTRY_PRESYMPATHIZE_15962690746467493454: VariantsMap = [
    &["presympathize"],
    &["presympathise"],
    &["presympathize"],
    &["presympathise"],
];

pub(crate) static ENTRY_PRESYSTOLIC_17980529676890563829: VariantsMap = [
    &["presystolic"],
    &["praesystolic"],
    &["praesystolic"],
    &["praesystolic"],
];

pub(crate) static ENTRY_PRETAXATION_16254819888221291653: VariantsMap = [
    &["pretaxation"],
    &["praetaxation"],
    &["praetaxation"],
    &["praetaxation"],
];

pub(crate) static ENTRY_PRETENSES_15397156974880122447: VariantsMap = [
    &["pretenses"],
    &["pretences"],
    &["pretenses"],
    &["pretences"],
];

pub(crate) static ENTRY_PRETENSE_1806063105069921307: VariantsMap =
    [&["pretense"], &["pretence"], &["pretense"], &["pretence"]];

pub(crate) static ENTRY_PRETENSIVE_6141437866379382582: VariantsMap = [
    &["pretensive"],
    &["pretencive"],
    &["pretencive"],
    &["pretencive"],
];

pub(crate) static ENTRY_PRETERITS_3983698582275509615: VariantsMap = [
    &["preterits"],
    &["preterites"],
    &["preterites"],
    &["preterites"],
];

pub(crate) static ENTRY_PRETERIT_6327351993261882986: VariantsMap = [
    &["preterit"],
    &["preterite"],
    &["preterite"],
    &["preterite"],
];

pub(crate) static ENTRY_PRETEXTAE_16184667912878448094: VariantsMap = [
    &["pretextae"],
    &["praetextae"],
    &["praetextae"],
    &["praetextae"],
];

pub(crate) static ENTRY_PRETEXTA_322521945222134396: VariantsMap = [
    &["pretexta"],
    &["praetexta"],
    &["praetexta"],
    &["praetexta"],
];

pub(crate) static ENTRY_PRETORIAL_7197260765783954402: VariantsMap = [
    &["pretorial"],
    &["praetorial"],
    &["praetorial"],
    &["praetorial"],
];

pub(crate) static ENTRY_PRETORIANS_5321413914837421784: VariantsMap = [
    &["pretorians"],
    &["praetorians"],
    &["praetorians"],
    &["praetorians"],
];

pub(crate) static ENTRY_PRETORIUM_1712722934465958271: VariantsMap = [
    &["pretorium"],
    &["praetorium"],
    &["praetorium"],
    &["praetorium"],
];

pub(crate) static ENTRY_PRETORIUS_278833463846710853: VariantsMap = [
    &["pretorius"],
    &["praetorius"],
    &["praetorius"],
    &["praetorius"],
];

pub(crate) static ENTRY_PRETORSHIP_298144548841059349: VariantsMap = [
    &["pretorship"],
    &["praetorship"],
    &["praetorship"],
    &["praetorship"],
];

pub(crate) static ENTRY_PREUTILIZABLES_16060283126975272357: VariantsMap = [
    &["preutilizables"],
    &["preutilisables"],
    &["preutilizables"],
    &["preutilisables"],
];

pub(crate) static ENTRY_PREUTILIZABLE_13773594832026128190: VariantsMap = [
    &["preutilizable"],
    &["preutilisable"],
    &["preutilizable"],
    &["preutilisable"],
];

pub(crate) static ENTRY_PREUTILIZATIONS_15650215591627789397: VariantsMap = [
    &["preutilizations"],
    &["preutilisations"],
    &["preutilizations"],
    &["preutilisations"],
];

pub(crate) static ENTRY_PREUTILIZATION_4481094491629481493: VariantsMap = [
    &["preutilization"],
    &["preutilisation"],
    &["preutilization"],
    &["preutilisation"],
];

pub(crate) static ENTRY_PREUTILIZES_9219722857883342032: VariantsMap = [
    &["preutilizes"],
    &["preutilises"],
    &["preutilizes"],
    &["preutilises"],
];

pub(crate) static ENTRY_PREUTILIZE_2615669183062771932: VariantsMap = [
    &["preutilize"],
    &["preutilise"],
    &["preutilize"],
    &["preutilise"],
];

pub(crate) static ENTRY_PREVIEWS_1728617467859287905: VariantsMap =
    [&["previews"], &["previews"], &["previews"], &["previews"]];

pub(crate) static ENTRY_PREVIEW_17926315694824576755: VariantsMap =
    [&["preview"], &["preview"], &["preview"], &["preview"]];

pub(crate) static ENTRY_PREVIZE_17807664688989533725: VariantsMap =
    [&["previze"], &["previse"], &["previze"], &["previse"]];

pub(crate) static ENTRY_PREZYGAPOPHYSIS_14960217627658149191: VariantsMap = [
    &["prezygapophysis"],
    &["praezygapophysis"],
    &["praezygapophysis"],
    &["praezygapophysis"],
];

pub(crate) static ENTRY_PRIMEVALLY_2674971179088086646: VariantsMap = [
    &["primevally"],
    &["primevally"],
    &["primevally"],
    &["primevally"],
];

pub(crate) static ENTRY_PRIMEVAL_14403698219446531068: VariantsMap =
    [&["primeval"], &["primeval"], &["primeval"], &["primeval"]];

pub(crate) static ENTRY_PRIORITIZATIONS_6646156489290472561: VariantsMap = [
    &["prioritizations"],
    &["prioritisations"],
    &["prioritizations"],
    &["prioritisations"],
];

pub(crate) static ENTRY_PRIORITIZATION_10049497275055472359: VariantsMap = [
    &["prioritization"],
    &["prioritisation"],
    &["prioritization"],
    &["prioritisation"],
];

pub(crate) static ENTRY_PRIORITIZED_18023070841869180732: VariantsMap = [
    &["prioritized"],
    &["prioritised"],
    &["prioritized"],
    &["prioritised"],
];

pub(crate) static ENTRY_PRIORITIZERS_16197836004941116010: VariantsMap = [
    &["prioritizers"],
    &["prioritisers"],
    &["prioritizers"],
    &["prioritisers"],
];

pub(crate) static ENTRY_PRIORITIZER_6938111019701759275: VariantsMap = [
    &["prioritizer"],
    &["prioritiser"],
    &["prioritizer"],
    &["prioritiser"],
];

pub(crate) static ENTRY_PRIORITIZES_11503923781258978352: VariantsMap = [
    &["prioritizes"],
    &["prioritises"],
    &["prioritizes"],
    &["prioritises"],
];

pub(crate) static ENTRY_PRIORITIZE_6692938915255740696: VariantsMap = [
    &["prioritize"],
    &["prioritise"],
    &["prioritize"],
    &["prioritise"],
];

pub(crate) static ENTRY_PRIORITIZINGS_4795506597517888826: VariantsMap = [
    &["prioritizings"],
    &["prioritisings"],
    &["prioritizings"],
    &["prioritisings"],
];

pub(crate) static ENTRY_PRIORITIZING_1918447248395854235: VariantsMap = [
    &["prioritizing"],
    &["prioritising"],
    &["prioritizing"],
    &["prioritising"],
];

pub(crate) static ENTRY_PRIORIZATIONS_7395933477241911403: VariantsMap = [
    &["priorizations"],
    &["priorisations"],
    &["priorizations"],
    &["priorisations"],
];

pub(crate) static ENTRY_PRIORIZATION_15831247715416791292: VariantsMap = [
    &["priorization"],
    &["priorisation"],
    &["priorization"],
    &["priorisation"],
];

pub(crate) static ENTRY_PRIORIZED_986408301813837211: VariantsMap = [
    &["priorized"],
    &["priorised"],
    &["priorized"],
    &["priorised"],
];

pub(crate) static ENTRY_PRIORIZES_9591483062801861397: VariantsMap = [
    &["priorizes"],
    &["priorises"],
    &["priorizes"],
    &["priorises"],
];

pub(crate) static ENTRY_PRIORIZE_4435503407458868165: VariantsMap =
    [&["priorize"], &["priorise"], &["priorize"], &["priorise"]];

pub(crate) static ENTRY_PRIORIZING_9325893624043708471: VariantsMap = [
    &["priorizing"],
    &["priorising"],
    &["priorizing"],
    &["priorising"],
];

pub(crate) static ENTRY_PRIVATIZATIONS_14900435995228716791: VariantsMap = [
    &["privatizations"],
    &["privatisations"],
    &["privatizations"],
    &["privatisations"],
];

pub(crate) static ENTRY_PRIVATIZATION_13261595712696321543: VariantsMap = [
    &["privatization"],
    &["privatisation"],
    &["privatization"],
    &["privatisation"],
];

pub(crate) static ENTRY_PRIVATIZED_18440711924740318570: VariantsMap = [
    &["privatized"],
    &["privatised"],
    &["privatized"],
    &["privatised"],
];

pub(crate) static ENTRY_PRIVATIZERS_4935862002795256053: VariantsMap = [
    &["privatizers"],
    &["privatisers"],
    &["privatizers"],
    &["privatisers"],
];

pub(crate) static ENTRY_PRIVATIZER_5363515162384255634: VariantsMap = [
    &["privatizer"],
    &["privatiser"],
    &["privatizer"],
    &["privatiser"],
];

pub(crate) static ENTRY_PRIVATIZES_13414685946229171001: VariantsMap = [
    &["privatizes"],
    &["privatises"],
    &["privatizes"],
    &["privatises"],
];

pub(crate) static ENTRY_PRIVATIZE_15602436903519402958: VariantsMap = [
    &["privatize"],
    &["privatise"],
    &["privatize"],
    &["privatise"],
];

pub(crate) static ENTRY_PRIVATIZING_12559648713578210369: VariantsMap = [
    &["privatizing"],
    &["privatising"],
    &["privatizing"],
    &["privatising"],
];

pub(crate) static ENTRY_PRIZABLE_8782369217264532396: VariantsMap =
    [&["prizable"], &["prisable"], &["prizable"], &["prisable"]];

pub(crate) static ENTRY_PRIZED_5215566249205572067: VariantsMap =
    [&["prized"], &["prised"], &["prized"], &["prised"]];

pub(crate) static ENTRY_PRIZERS_17915377328744820091: VariantsMap =
    [&["prizers"], &["prisers"], &["prizers"], &["prisers"]];

pub(crate) static ENTRY_PRIZER_2531822262597590420: VariantsMap =
    [&["prizer"], &["priser"], &["prizer"], &["priser"]];

pub(crate) static ENTRY_PRIZES_15467106908555365225: VariantsMap =
    [&["prizes"], &["prises"], &["prizes"], &["prises"]];

pub(crate) static ENTRY_PRIZE_9161502193249494227: VariantsMap =
    [&["prize"], &["prise"], &["prize"], &["prise"]];

pub(crate) static ENTRY_PRIZING_5227861388750045611: VariantsMap =
    [&["prizing"], &["prising"], &["prizing"], &["prising"]];

pub(crate) static ENTRY_PROADVERTIZING_11854284288281126528: VariantsMap = [
    &["proadvertizing"],
    &["proadvertising"],
    &["proadvertizing"],
    &["proadvertising"],
];

pub(crate) static ENTRY_PROBLEMIZES_16167676205731844544: VariantsMap = [
    &["problemizes"],
    &["problemises"],
    &["problemizes"],
    &["problemises"],
];

pub(crate) static ENTRY_PROBLEMIZE_3733154693918512723: VariantsMap = [
    &["problemize"],
    &["problemise"],
    &["problemize"],
    &["problemise"],
];

pub(crate) static ENTRY_PROCESSIONIZES_13973102018086646225: VariantsMap = [
    &["processionizes"],
    &["processionises"],
    &["processionizes"],
    &["processionises"],
];

pub(crate) static ENTRY_PROCESSIONIZE_7433283850303828458: VariantsMap = [
    &["processionize"],
    &["processionise"],
    &["processionize"],
    &["processionise"],
];

pub(crate) static ENTRY_PROCRUSTEANIZES_16493517354618629803: VariantsMap = [
    &["procrusteanizes"],
    &["procrusteanises"],
    &["procrusteanizes"],
    &["procrusteanises"],
];

pub(crate) static ENTRY_PROCRUSTEANIZE_744493252621097169: VariantsMap = [
    &["procrusteanize"],
    &["procrusteanise"],
    &["procrusteanize"],
    &["procrusteanise"],
];

pub(crate) static ENTRY_PROCTODEAL_4699518537214479716: VariantsMap = [
    &["proctodeal"],
    &["proctodaeal"],
    &["proctodaeal"],
    &["proctodaeal"],
];

pub(crate) static ENTRY_PROCTODEA_7394203941595428980: VariantsMap = [
    &["proctodea"],
    &["proctodaea"],
    &["proctodaea"],
    &["proctodaea"],
];

pub(crate) static ENTRY_PROCTODEUMS_7965990816311016504: VariantsMap = [
    &["proctodeums"],
    &["proctodaeums"],
    &["proctodaeums"],
    &["proctodaeums"],
];

pub(crate) static ENTRY_PROCTODEUM_12835100775651605738: VariantsMap = [
    &["proctodeum"],
    &["proctodaeum"],
    &["proctodaeum"],
    &["proctodaeum"],
];

pub(crate) static ENTRY_PROCTORIZATIONS_16880863477174659915: VariantsMap = [
    &["proctorizations"],
    &["proctorisations"],
    &["proctorizations"],
    &["proctorisations"],
];

pub(crate) static ENTRY_PROCTORIZATION_10856447202079910826: VariantsMap = [
    &["proctorization"],
    &["proctorisation"],
    &["proctorization"],
    &["proctorisation"],
];

pub(crate) static ENTRY_PROCTORIZED_2668674070254259488: VariantsMap = [
    &["proctorized"],
    &["proctorised"],
    &["proctorized"],
    &["proctorised"],
];

pub(crate) static ENTRY_PROCTORIZES_5348616729395822128: VariantsMap = [
    &["proctorizes"],
    &["proctorises"],
    &["proctorizes"],
    &["proctorises"],
];

pub(crate) static ENTRY_PROCTORIZE_2264104820190419500: VariantsMap = [
    &["proctorize"],
    &["proctorise"],
    &["proctorize"],
    &["proctorise"],
];

pub(crate) static ENTRY_PROCTORIZING_12194166959190016917: VariantsMap = [
    &["proctorizing"],
    &["proctorising"],
    &["proctorizing"],
    &["proctorising"],
];

pub(crate) static ENTRY_PRODIGALIZED_3428487070963375705: VariantsMap = [
    &["prodigalized"],
    &["prodigalised"],
    &["prodigalized"],
    &["prodigalised"],
];

pub(crate) static ENTRY_PRODIGALIZES_14628265773798361699: VariantsMap = [
    &["prodigalizes"],
    &["prodigalises"],
    &["prodigalizes"],
    &["prodigalises"],
];

pub(crate) static ENTRY_PRODIGALIZE_12533163844995161541: VariantsMap = [
    &["prodigalize"],
    &["prodigalise"],
    &["prodigalize"],
    &["prodigalise"],
];

pub(crate) static ENTRY_PRODIGALIZING_14011101052657811503: VariantsMap = [
    &["prodigalizing"],
    &["prodigalising"],
    &["prodigalizing"],
    &["prodigalising"],
];

pub(crate) static ENTRY_PRODUCTIZED_10091772006605087705: VariantsMap = [
    &["productized"],
    &["productised"],
    &["productized"],
    &["productised"],
];

pub(crate) static ENTRY_PRODUCTIZERS_7546776594887641211: VariantsMap = [
    &["productizers"],
    &["productisers"],
    &["productizers"],
    &["productisers"],
];

pub(crate) static ENTRY_PRODUCTIZER_743913279002903740: VariantsMap = [
    &["productizer"],
    &["productiser"],
    &["productizer"],
    &["productiser"],
];

pub(crate) static ENTRY_PRODUCTIZES_15067875440491410917: VariantsMap = [
    &["productizes"],
    &["productises"],
    &["productizes"],
    &["productises"],
];

pub(crate) static ENTRY_PRODUCTIZE_355214308695677973: VariantsMap = [
    &["productize"],
    &["productise"],
    &["productize"],
    &["productise"],
];

pub(crate) static ENTRY_PRODUCTIZING_14463995875743510428: VariantsMap = [
    &["productizing"],
    &["productising"],
    &["productizing"],
    &["productising"],
];

pub(crate) static ENTRY_PROEMIUM_11682631817645057378: VariantsMap = [
    &["proemium"],
    &["prooemium"],
    &["prooemium"],
    &["prooemium"],
];

pub(crate) static ENTRY_PROFANIZES_15276099779609209125: VariantsMap = [
    &["profanizes"],
    &["profanises"],
    &["profanizes"],
    &["profanises"],
];

pub(crate) static ENTRY_PROFANIZE_12830076681879400499: VariantsMap = [
    &["profanize"],
    &["profanise"],
    &["profanize"],
    &["profanise"],
];

pub(crate) static ENTRY_PROFER_10895731134357597757: VariantsMap =
    [&["profer"], &["profre"], &["profre"], &["profre"]];

pub(crate) static ENTRY_PROFESSIONALIZATIONS_820894818241176416: VariantsMap = [
    &["professionalizations"],
    &["professionalisations"],
    &["professionalizations"],
    &["professionalisations"],
];

pub(crate) static ENTRY_PROFESSIONALIZATION_17530475144205441796: VariantsMap = [
    &["professionalization"],
    &["professionalisation"],
    &["professionalization"],
    &["professionalisation"],
];

pub(crate) static ENTRY_PROFESSIONALIZED_12953071907076905796: VariantsMap = [
    &["professionalized"],
    &["professionalised"],
    &["professionalized"],
    &["professionalised"],
];

pub(crate) static ENTRY_PROFESSIONALIZES_13019583386600406552: VariantsMap = [
    &["professionalizes"],
    &["professionalises"],
    &["professionalizes"],
    &["professionalises"],
];

pub(crate) static ENTRY_PROFESSIONALIZE_6867732579804889823: VariantsMap = [
    &["professionalize"],
    &["professionalise"],
    &["professionalize"],
    &["professionalise"],
];

pub(crate) static ENTRY_PROFESSIONALIZING_7693734081343569569: VariantsMap = [
    &["professionalizing"],
    &["professionalising"],
    &["professionalizing"],
    &["professionalising"],
];

pub(crate) static ENTRY_PROFESSIONIZES_7991571007403712278: VariantsMap = [
    &["professionizes"],
    &["professionises"],
    &["professionizes"],
    &["professionises"],
];

pub(crate) static ENTRY_PROFESSIONIZE_13454304658050553817: VariantsMap = [
    &["professionize"],
    &["professionise"],
    &["professionize"],
    &["professionise"],
];

pub(crate) static ENTRY_PROGRAMMED_15849257509422591276: VariantsMap = [
    &["programmed"],
    &["programmed"],
    &["programmed"],
    &["programmed"],
];

pub(crate) static ENTRY_PROGRAMMED_3055388991746463602: VariantsMap = [
    &["programmed"],
    &["programmed"],
    &["programmed"],
    &["programmed"],
];

pub(crate) static ENTRY_PROGRAMMERS_4515854859838156319: VariantsMap = [
    &["programmers"],
    &["programmers"],
    &["programmers"],
    &["programmers"],
];

pub(crate) static ENTRY_PROGRAMMER_12330374135731657861: VariantsMap = [
    &["programmer"],
    &["programmer"],
    &["programmer"],
    &["programmer"],
];

pub(crate) static ENTRY_PROGRAMMING_13190911417711133911: VariantsMap = [
    &["programming"],
    &["programming"],
    &["programming"],
    &["programming"],
];

pub(crate) static ENTRY_PROGRAMMING_9724385457632698919: VariantsMap = [
    &["programming"],
    &["programming"],
    &["programming"],
    &["programming"],
];

pub(crate) static ENTRY_PROGRAMS_11792468001587502418: VariantsMap =
    [&["programs"], &["programs"], &["programs"], &["programs"]];

pub(crate) static ENTRY_PROGRAMS_8949972925814469251: VariantsMap =
    [&["programs"], &["programmes"], &["programs"], &["programs"]];

pub(crate) static ENTRY_PROGRAM_1168207610116917818: VariantsMap =
    [&["program"], &["programme"], &["program"], &["program"]];

pub(crate) static ENTRY_PROGRAM_15467367788727504514: VariantsMap =
    [&["program"], &["program"], &["program"], &["program"]];

pub(crate) static ENTRY_PROINDUSTRIALIZATION_15813974036579142612: VariantsMap = [
    &["proindustrialization"],
    &["proindustrialisation"],
    &["proindustrialization"],
    &["proindustrialisation"],
];

pub(crate) static ENTRY_PROJECTIZATIONS_11440603583583794637: VariantsMap = [
    &["projectizations"],
    &["projectisations"],
    &["projectizations"],
    &["projectisations"],
];

pub(crate) static ENTRY_PROJECTIZATION_8930022185867417632: VariantsMap = [
    &["projectization"],
    &["projectisation"],
    &["projectization"],
    &["projectisation"],
];

pub(crate) static ENTRY_PROLETARIANIZATIONS_18153332863179741779: VariantsMap = [
    &["proletarianizations"],
    &["proletarianisations"],
    &["proletarianizations"],
    &["proletarianisations"],
];

pub(crate) static ENTRY_PROLETARIANIZATION_13313275210976607060: VariantsMap = [
    &["proletarianization"],
    &["proletarianisation"],
    &["proletarianization"],
    &["proletarianisation"],
];

pub(crate) static ENTRY_PROLETARIANIZED_5537836316707945052: VariantsMap = [
    &["proletarianized"],
    &["proletarianised"],
    &["proletarianized"],
    &["proletarianised"],
];

pub(crate) static ENTRY_PROLETARIANIZES_3808504865584636556: VariantsMap = [
    &["proletarianizes"],
    &["proletarianises"],
    &["proletarianizes"],
    &["proletarianises"],
];

pub(crate) static ENTRY_PROLETARIANIZE_10306000725556427592: VariantsMap = [
    &["proletarianize"],
    &["proletarianise"],
    &["proletarianize"],
    &["proletarianise"],
];

pub(crate) static ENTRY_PROLETARIANIZING_14033305622778298474: VariantsMap = [
    &["proletarianizing"],
    &["proletarianising"],
    &["proletarianizing"],
    &["proletarianising"],
];

pub(crate) static ENTRY_PROLETARIZED_10377426615142966996: VariantsMap = [
    &["proletarized"],
    &["proletarised"],
    &["proletarized"],
    &["proletarised"],
];

pub(crate) static ENTRY_PROLETARIZE_7658575278102132004: VariantsMap = [
    &["proletarize"],
    &["proletarise"],
    &["proletarize"],
    &["proletarise"],
];

pub(crate) static ENTRY_PROLETARIZING_7622597255202403783: VariantsMap = [
    &["proletarizing"],
    &["proletarising"],
    &["proletarizing"],
    &["proletarising"],
];

pub(crate) static ENTRY_PROLOGIZED_3624222185686090329: VariantsMap = [
    &["prologized"],
    &["prologised"],
    &["prologized"],
    &["prologised"],
];

pub(crate) static ENTRY_PROLOGIZES_12046698321881734610: VariantsMap = [
    &["prologizes"],
    &["prologises"],
    &["prologizes"],
    &["prologises"],
];

pub(crate) static ENTRY_PROLOGIZE_15505078668032774171: VariantsMap = [
    &["prologize"],
    &["prologise"],
    &["prologize"],
    &["prologise"],
];

pub(crate) static ENTRY_PROLOGIZING_18036732420796600279: VariantsMap = [
    &["prologizing"],
    &["prologising"],
    &["prologizing"],
    &["prologising"],
];

pub(crate) static ENTRY_PROLOGUES_9340649334758661479: VariantsMap = [
    &["prologues"],
    &["prologues"],
    &["prologues"],
    &["prologues"],
];

pub(crate) static ENTRY_PROLOGUE_17671930941462455526: VariantsMap =
    [&["prologue"], &["prologue"], &["prologue"], &["prologue"]];

pub(crate) static ENTRY_PROLOGUIZED_3253550402486536987: VariantsMap = [
    &["prologuized"],
    &["prologuised"],
    &["prologuized"],
    &["prologuised"],
];

pub(crate) static ENTRY_PROLOGUIZERS_2076286811253592679: VariantsMap = [
    &["prologuizers"],
    &["prologuisers"],
    &["prologuizers"],
    &["prologuisers"],
];

pub(crate) static ENTRY_PROLOGUIZER_11977593482018675531: VariantsMap = [
    &["prologuizer"],
    &["prologuiser"],
    &["prologuizer"],
    &["prologuiser"],
];

pub(crate) static ENTRY_PROLOGUIZES_3296728645194085464: VariantsMap = [
    &["prologuizes"],
    &["prologuises"],
    &["prologuizes"],
    &["prologuises"],
];

pub(crate) static ENTRY_PROLOGUIZE_11510955088004134734: VariantsMap = [
    &["prologuize"],
    &["prologuise"],
    &["prologuize"],
    &["prologuise"],
];

pub(crate) static ENTRY_PROLOGUIZING_3954350899886287768: VariantsMap = [
    &["prologuizing"],
    &["prologuising"],
    &["prologuizing"],
    &["prologuising"],
];

pub(crate) static ENTRY_PROLUSIONIZES_17256356705404835970: VariantsMap = [
    &["prolusionizes"],
    &["prolusionises"],
    &["prolusionizes"],
    &["prolusionises"],
];

pub(crate) static ENTRY_PROLUSIONIZE_16730185172419057812: VariantsMap = [
    &["prolusionize"],
    &["prolusionise"],
    &["prolusionize"],
    &["prolusionise"],
];

pub(crate) static ENTRY_PRONOMINALIZATION_17724208934767078054: VariantsMap = [
    &["pronominalization"],
    &["pronominalisation"],
    &["pronominalization"],
    &["pronominalisation"],
];

pub(crate) static ENTRY_PRONOMINALIZE_3240389965162843516: VariantsMap = [
    &["pronominalize"],
    &["pronominalise"],
    &["pronominalize"],
    &["pronominalise"],
];

pub(crate) static ENTRY_PROPAGANDIZED_7923401534538057928: VariantsMap = [
    &["propagandized"],
    &["propagandised"],
    &["propagandized"],
    &["propagandised"],
];

pub(crate) static ENTRY_PROPAGANDIZES_17414306414554519223: VariantsMap = [
    &["propagandizes"],
    &["propagandises"],
    &["propagandizes"],
    &["propagandises"],
];

pub(crate) static ENTRY_PROPAGANDIZE_17672695121638138026: VariantsMap = [
    &["propagandize"],
    &["propagandise"],
    &["propagandize"],
    &["propagandise"],
];

pub(crate) static ENTRY_PROPAGANDIZING_14458179375605730291: VariantsMap = [
    &["propagandizing"],
    &["propagandising"],
    &["propagandizing"],
    &["propagandising"],
];

pub(crate) static ENTRY_PROPHETIZES_7700079523894166264: VariantsMap = [
    &["prophetizes"],
    &["prophetises"],
    &["prophetizes"],
    &["prophetises"],
];

pub(crate) static ENTRY_PROPHETIZE_3283856741265018815: VariantsMap = [
    &["prophetize"],
    &["prophetise"],
    &["prophetize"],
    &["prophetise"],
];

pub(crate) static ENTRY_PROPOSITIONIZES_13969404499779129990: VariantsMap = [
    &["propositionizes"],
    &["propositionises"],
    &["propositionizes"],
    &["propositionises"],
];

pub(crate) static ENTRY_PROPOSITIONIZE_16503275049520839015: VariantsMap = [
    &["propositionize"],
    &["propositionise"],
    &["propositionize"],
    &["propositionise"],
];

pub(crate) static ENTRY_PROPRETORIAL_4183494453271841116: VariantsMap = [
    &["propretorial"],
    &["propraetorial"],
    &["propraetorial"],
    &["propraetorial"],
];

pub(crate) static ENTRY_PROPRETORIAN_14560418131352376207: VariantsMap = [
    &["propretorian"],
    &["propraetorian"],
    &["propraetorian"],
    &["propraetorian"],
];

pub(crate) static ENTRY_PROPRETORS_1061872627090076302: VariantsMap = [
    &["propretors"],
    &["propraetors"],
    &["propraetors"],
    &["propraetors"],
];

pub(crate) static ENTRY_PROPRETOR_8308951553220524726: VariantsMap = [
    &["propretor"],
    &["propraetor"],
    &["propraetor"],
    &["propraetor"],
];

pub(crate) static ENTRY_PROPYLITIZATIONS_7094329496024697216: VariantsMap = [
    &["propylitizations"],
    &["propylitisations"],
    &["propylitizations"],
    &["propylitisations"],
];

pub(crate) static ENTRY_PROPYLITIZATION_13836495940814672284: VariantsMap = [
    &["propylitization"],
    &["propylitisation"],
    &["propylitization"],
    &["propylitisation"],
];

pub(crate) static ENTRY_PROPYLITIZED_8590898197469215076: VariantsMap = [
    &["propylitized"],
    &["propylitised"],
    &["propylitized"],
    &["propylitised"],
];

pub(crate) static ENTRY_PROPYLITIZES_1960476382403426175: VariantsMap = [
    &["propylitizes"],
    &["propylitises"],
    &["propylitizes"],
    &["propylitises"],
];

pub(crate) static ENTRY_PROPYLITIZE_11679071963245365055: VariantsMap = [
    &["propylitize"],
    &["propylitise"],
    &["propylitize"],
    &["propylitise"],
];

pub(crate) static ENTRY_PROPYLITIZING_1919046230221160069: VariantsMap = [
    &["propylitizing"],
    &["propylitising"],
    &["propylitizing"],
    &["propylitising"],
];

pub(crate) static ENTRY_PROSELYTIZATIONS_9868313451413411610: VariantsMap = [
    &["proselytizations"],
    &["proselytisations"],
    &["proselytizations"],
    &["proselytisations"],
];

pub(crate) static ENTRY_PROSELYTIZATION_6529379067249492159: VariantsMap = [
    &["proselytization"],
    &["proselytisation"],
    &["proselytization"],
    &["proselytisation"],
];

pub(crate) static ENTRY_PROSELYTIZED_2214158284515887133: VariantsMap = [
    &["proselytized"],
    &["proselytised"],
    &["proselytized"],
    &["proselytised"],
];

pub(crate) static ENTRY_PROSELYTIZERS_8374451172555772107: VariantsMap = [
    &["proselytizers"],
    &["proselytisers"],
    &["proselytizers"],
    &["proselytisers"],
];

pub(crate) static ENTRY_PROSELYTIZER_16192805406416418559: VariantsMap = [
    &["proselytizer"],
    &["proselytiser"],
    &["proselytizer"],
    &["proselytiser"],
];

pub(crate) static ENTRY_PROSELYTIZES_17493975453031891132: VariantsMap = [
    &["proselytizes"],
    &["proselytises"],
    &["proselytizes"],
    &["proselytises"],
];

pub(crate) static ENTRY_PROSELYTIZE_2045808347498243297: VariantsMap = [
    &["proselytize"],
    &["proselytise"],
    &["proselytize"],
    &["proselytise"],
];

pub(crate) static ENTRY_PROSELYTIZING_9230222865633259129: VariantsMap = [
    &["proselytizing"],
    &["proselytising"],
    &["proselytizing"],
    &["proselytising"],
];

pub(crate) static ENTRY_PROSEUCHE_18082547994938576822: VariantsMap = [
    &["proseuche"],
    &["proseuchae"],
    &["proseuchae"],
    &["proseuchae"],
];

pub(crate) static ENTRY_PROSOCELE_8377653530954019059: VariantsMap = [
    &["prosocele"],
    &["prosocoele"],
    &["prosocoele"],
    &["prosocoele"],
];

pub(crate) static ENTRY_PROSOPOPEIAL_11424645114316445715: VariantsMap = [
    &["prosopopeial"],
    &["prosopopoeial"],
    &["prosopopoeial"],
    &["prosopopoeial"],
];

pub(crate) static ENTRY_PROSOPOPOEIAS_7785383172591439340: VariantsMap = [
    &["prosopopoeias"],
    &["prosopopoeias"],
    &["prosopopoeias"],
    &["prosopopoeias"],
];

pub(crate) static ENTRY_PROSOPOPOEIA_18371169721208163527: VariantsMap = [
    &["prosopopoeia"],
    &["prosopopoeia"],
    &["prosopopoeia"],
    &["prosopopoeia"],
];

pub(crate) static ENTRY_PROSTATORRHEA_560097517692680467: VariantsMap = [
    &["prostatorrhea"],
    &["prostatorrhoea"],
    &["prostatorrhoea"],
    &["prostatorrhoea"],
];

pub(crate) static ENTRY_PROTECTIONIZES_10344288741949666317: VariantsMap = [
    &["protectionizes"],
    &["protectionises"],
    &["protectionizes"],
    &["protectionises"],
];

pub(crate) static ENTRY_PROTECTIONIZE_13639705024576405936: VariantsMap = [
    &["protectionize"],
    &["protectionise"],
    &["protectionize"],
    &["protectionise"],
];

pub(crate) static ENTRY_PROTEIDE_15177699273216527826: VariantsMap = [
    &["proteide"],
    &["proteidae"],
    &["proteidae"],
    &["proteidae"],
];

pub(crate) static ENTRY_PROTESTANTIZED_7638390729359938099: VariantsMap = [
    &["protestantized"],
    &["protestantised"],
    &["protestantized"],
    &["protestantised"],
];

pub(crate) static ENTRY_PROTESTANTIZES_1093133710944013164: VariantsMap = [
    &["protestantizes"],
    &["protestantises"],
    &["protestantizes"],
    &["protestantises"],
];

pub(crate) static ENTRY_PROTESTANTIZE_5849584465690284720: VariantsMap = [
    &["protestantize"],
    &["protestantise"],
    &["protestantize"],
    &["protestantise"],
];

pub(crate) static ENTRY_PROTESTANTIZING_218744719233014114: VariantsMap = [
    &["protestantizing"],
    &["protestantising"],
    &["protestantizing"],
    &["protestantising"],
];

pub(crate) static ENTRY_PROTHOENOR_15356183037577716314: VariantsMap = [
    &["prothoenor"],
    &["prothoaenor"],
    &["prothoaenor"],
    &["prothoaenor"],
];

pub(crate) static ENTRY_PROTOARCHEOLOGY_3979328534027257913: VariantsMap = [
    &["protoarcheology"],
    &["protoarchaeology"],
    &["protoarchaeology"],
    &["protoarchaeology"],
];

pub(crate) static ENTRY_PROTOCOLED_9184207318768023915: VariantsMap = [
    &["protocoled"],
    &["protocolled"],
    &["protocolled"],
    &["protocolled"],
];

pub(crate) static ENTRY_PROTOCOLING_16289008591020603327: VariantsMap = [
    &["protocoling"],
    &["protocolling"],
    &["protocolling"],
    &["protocolling"],
];

pub(crate) static ENTRY_PROTOCOLIZATIONS_15242092987659511854: VariantsMap = [
    &["protocolizations"],
    &["protocolisations"],
    &["protocolizations"],
    &["protocolisations"],
];

pub(crate) static ENTRY_PROTOCOLIZATION_912207443070037399: VariantsMap = [
    &["protocolization"],
    &["protocolisation"],
    &["protocolization"],
    &["protocolisation"],
];

pub(crate) static ENTRY_PROTOCOLIZED_17551306331631525677: VariantsMap = [
    &["protocolized"],
    &["protocolised"],
    &["protocolized"],
    &["protocolised"],
];

pub(crate) static ENTRY_PROTOCOLIZES_11921216524567616192: VariantsMap = [
    &["protocolizes"],
    &["protocolises"],
    &["protocolizes"],
    &["protocolises"],
];

pub(crate) static ENTRY_PROTOCOLIZE_15855693097748168695: VariantsMap = [
    &["protocolize"],
    &["protocolise"],
    &["protocolize"],
    &["protocolise"],
];

pub(crate) static ENTRY_PROTOCOLIZING_6817748168002379013: VariantsMap = [
    &["protocolizing"],
    &["protocolising"],
    &["protocolizing"],
    &["protocolising"],
];

pub(crate) static ENTRY_PROVERBIALIZED_15384141908364563413: VariantsMap = [
    &["proverbialized"],
    &["proverbialised"],
    &["proverbialized"],
    &["proverbialised"],
];

pub(crate) static ENTRY_PROVERBIALIZES_5554547456085258371: VariantsMap = [
    &["proverbializes"],
    &["proverbialises"],
    &["proverbializes"],
    &["proverbialises"],
];

pub(crate) static ENTRY_PROVERBIALIZE_10779880440815640572: VariantsMap = [
    &["proverbialize"],
    &["proverbialise"],
    &["proverbialize"],
    &["proverbialise"],
];

pub(crate) static ENTRY_PROVERBIALIZING_16662355151354609960: VariantsMap = [
    &["proverbializing"],
    &["proverbialising"],
    &["proverbializing"],
    &["proverbialising"],
];

pub(crate) static ENTRY_PROVERBIZES_1232232315538032087: VariantsMap = [
    &["proverbizes"],
    &["proverbises"],
    &["proverbizes"],
    &["proverbises"],
];

pub(crate) static ENTRY_PROVERBIZE_5057145621251371752: VariantsMap = [
    &["proverbize"],
    &["proverbise"],
    &["proverbize"],
    &["proverbise"],
];

pub(crate) static ENTRY_PROVINCIALIZATIONS_7082778031208249106: VariantsMap = [
    &["provincializations"],
    &["provincialisations"],
    &["provincializations"],
    &["provincialisations"],
];

pub(crate) static ENTRY_PROVINCIALIZATION_13831389932205748314: VariantsMap = [
    &["provincialization"],
    &["provincialisation"],
    &["provincialization"],
    &["provincialisation"],
];

pub(crate) static ENTRY_PROVINCIALIZED_2188539660593884677: VariantsMap = [
    &["provincialized"],
    &["provincialised"],
    &["provincialized"],
    &["provincialised"],
];

pub(crate) static ENTRY_PROVINCIALIZES_2334082830205990146: VariantsMap = [
    &["provincializes"],
    &["provincialises"],
    &["provincializes"],
    &["provincialises"],
];

pub(crate) static ENTRY_PROVINCIALIZE_15342640692775315618: VariantsMap = [
    &["provincialize"],
    &["provincialise"],
    &["provincialize"],
    &["provincialise"],
];

pub(crate) static ENTRY_PROVINCIALIZING_13986914622652313230: VariantsMap = [
    &["provincializing"],
    &["provincialising"],
    &["provincializing"],
    &["provincialising"],
];

pub(crate) static ENTRY_PRUSSIANIZATIONS_6915840876369617729: VariantsMap = [
    &["prussianizations"],
    &["prussianisations"],
    &["prussianizations"],
    &["prussianisations"],
];

pub(crate) static ENTRY_PRUSSIANIZATION_10958382439781151197: VariantsMap = [
    &["prussianization"],
    &["prussianisation"],
    &["prussianization"],
    &["prussianisation"],
];

pub(crate) static ENTRY_PRUSSIANIZED_7738848135177998531: VariantsMap = [
    &["prussianized"],
    &["prussianised"],
    &["prussianized"],
    &["prussianised"],
];

pub(crate) static ENTRY_PRUSSIANIZERS_15563358695966470583: VariantsMap = [
    &["prussianizers"],
    &["prussianisers"],
    &["prussianizers"],
    &["prussianisers"],
];

pub(crate) static ENTRY_PRUSSIANIZER_17577551278831620692: VariantsMap = [
    &["prussianizer"],
    &["prussianiser"],
    &["prussianizer"],
    &["prussianiser"],
];

pub(crate) static ENTRY_PRUSSIANIZES_16592096312730648273: VariantsMap = [
    &["prussianizes"],
    &["prussianises"],
    &["prussianizes"],
    &["prussianises"],
];

pub(crate) static ENTRY_PRUSSIANIZE_12907469526535425712: VariantsMap = [
    &["prussianize"],
    &["prussianise"],
    &["prussianize"],
    &["prussianise"],
];

pub(crate) static ENTRY_PRUSSIANIZING_17187448249162985680: VariantsMap = [
    &["prussianizing"],
    &["prussianising"],
    &["prussianizing"],
    &["prussianising"],
];

pub(crate) static ENTRY_PSALMODIZED_9886224417033316783: VariantsMap = [
    &["psalmodized"],
    &["psalmodised"],
    &["psalmodized"],
    &["psalmodised"],
];

pub(crate) static ENTRY_PSALMODIZES_313135324604902888: VariantsMap = [
    &["psalmodizes"],
    &["psalmodises"],
    &["psalmodizes"],
    &["psalmodises"],
];

pub(crate) static ENTRY_PSALMODIZE_6785943915373540400: VariantsMap = [
    &["psalmodize"],
    &["psalmodise"],
    &["psalmodize"],
    &["psalmodise"],
];

pub(crate) static ENTRY_PSALMODIZING_16968583801346153803: VariantsMap = [
    &["psalmodizing"],
    &["psalmodising"],
    &["psalmodizing"],
    &["psalmodising"],
];

pub(crate) static ENTRY_PSEUDELEPHANT_11694652678064871967: VariantsMap = [
    &["pseudelephant"],
    &["pseudoelephant"],
    &["pseudoelephant"],
    &["pseudoelephant"],
];

pub(crate) static ENTRY_PSEUDEMBRYONIC_17990306181748605974: VariantsMap = [
    &["pseudembryonic"],
    &["pseudoembryonic"],
    &["pseudoembryonic"],
    &["pseudoembryonic"],
];

pub(crate) static ENTRY_PSEUDEMBRYO_10487252041242116470: VariantsMap = [
    &["pseudembryo"],
    &["pseudoembryo"],
    &["pseudoembryo"],
    &["pseudoembryo"],
];

pub(crate) static ENTRY_PSEUDESTHESIA_12407767994846061516: VariantsMap = [
    &["pseudesthesia"],
    &["pseudaesthesia"],
    &["pseudaesthesia"],
    &["pseudaesthesia"],
];

pub(crate) static ENTRY_PSEUDHEMAL_4355056111903797494: VariantsMap = [
    &["pseudhemal"],
    &["pseudhaemal"],
    &["pseudhaemal"],
    &["pseudhaemal"],
];

pub(crate) static ENTRY_PSEUDOANEMIAS_6046630203472884287: VariantsMap = [
    &["pseudoanemias"],
    &["pseudoanaemias"],
    &["pseudoanaemias"],
    &["pseudoanaemias"],
];

pub(crate) static ENTRY_PSEUDOANEMIA_5124966852485838539: VariantsMap = [
    &["pseudoanemia"],
    &["pseudoanaemia"],
    &["pseudoanaemia"],
    &["pseudoanaemia"],
];

pub(crate) static ENTRY_PSEUDOANEMICS_2122831063804414766: VariantsMap = [
    &["pseudoanemics"],
    &["pseudoanaemics"],
    &["pseudoanaemics"],
    &["pseudoanaemics"],
];

pub(crate) static ENTRY_PSEUDOANEMIC_11200180250612296538: VariantsMap = [
    &["pseudoanemic"],
    &["pseudoanaemic"],
    &["pseudoanaemic"],
    &["pseudoanaemic"],
];

pub(crate) static ENTRY_PSEUDOCELE_16415452007409564004: VariantsMap = [
    &["pseudocele"],
    &["pseudocoele"],
    &["pseudocoele"],
    &["pseudocoele"],
];

pub(crate) static ENTRY_PSEUDOCELOM_1695207054053145685: VariantsMap = [
    &["pseudocelom"],
    &["pseudocoelom"],
    &["pseudocoelom"],
    &["pseudocoelom"],
];

pub(crate) static ENTRY_PSEUDOEDEMAS_16026718825763332741: VariantsMap = [
    &["pseudoedemas"],
    &["pseudooedemas"],
    &["pseudooedemas"],
    &["pseudooedemas"],
];

pub(crate) static ENTRY_PSEUDOEDEMA_15891555805692784302: VariantsMap = [
    &["pseudoedema"],
    &["pseudooedema"],
    &["pseudooedema"],
    &["pseudooedema"],
];

pub(crate) static ENTRY_PSEUDOGRAPHIZES_3672980465786441046: VariantsMap = [
    &["pseudographizes"],
    &["pseudographises"],
    &["pseudographizes"],
    &["pseudographises"],
];

pub(crate) static ENTRY_PSEUDOGRAPHIZE_5452057591678689737: VariantsMap = [
    &["pseudographize"],
    &["pseudographise"],
    &["pseudographize"],
    &["pseudographise"],
];

pub(crate) static ENTRY_PSEUDOLUNULE_1282566980410169374: VariantsMap = [
    &["pseudolunule"],
    &["pseudolunulae"],
    &["pseudolunulae"],
    &["pseudolunulae"],
];

pub(crate) static ENTRY_PSYCHOANALYZED_5816959482018278884: VariantsMap = [
    &["psychoanalyzed"],
    &["psychoanalysed"],
    &["psychoanalyzed"],
    &["psychoanalysed"],
];

pub(crate) static ENTRY_PSYCHOANALYZERS_1935290147506502388: VariantsMap = [
    &["psychoanalyzers"],
    &["psychoanalysers"],
    &["psychoanalyzers"],
    &["psychoanalysers"],
];

pub(crate) static ENTRY_PSYCHOANALYZER_12400127427681777018: VariantsMap = [
    &["psychoanalyzer"],
    &["psychoanalyser"],
    &["psychoanalyzer"],
    &["psychoanalyser"],
];

pub(crate) static ENTRY_PSYCHOANALYZES_16566220832374590261: VariantsMap = [
    &["psychoanalyzes"],
    &["psychoanalyses"],
    &["psychoanalyzes"],
    &["psychoanalyses"],
];

pub(crate) static ENTRY_PSYCHOANALYZE_3750025217840958426: VariantsMap = [
    &["psychoanalyze"],
    &["psychoanalyse"],
    &["psychoanalyze"],
    &["psychoanalyse"],
];

pub(crate) static ENTRY_PSYCHOANALYZING_11072585094830037830: VariantsMap = [
    &["psychoanalyzing"],
    &["psychoanalysing"],
    &["psychoanalyzing"],
    &["psychoanalysing"],
];

pub(crate) static ENTRY_PSYCHOLOGIZATION_13227193510267031057: VariantsMap = [
    &["psychologization"],
    &["psychologisation"],
    &["psychologization"],
    &["psychologisation"],
];

pub(crate) static ENTRY_PSYCHOLOGIZED_12194990558663330704: VariantsMap = [
    &["psychologized"],
    &["psychologised"],
    &["psychologized"],
    &["psychologised"],
];

pub(crate) static ENTRY_PSYCHOLOGIZES_13336468276425310690: VariantsMap = [
    &["psychologizes"],
    &["psychologises"],
    &["psychologizes"],
    &["psychologises"],
];

pub(crate) static ENTRY_PSYCHOLOGIZE_15669513547256121943: VariantsMap = [
    &["psychologize"],
    &["psychologise"],
    &["psychologize"],
    &["psychologise"],
];

pub(crate) static ENTRY_PSYCHOLOGIZING_15426494443157713628: VariantsMap = [
    &["psychologizing"],
    &["psychologising"],
    &["psychologizing"],
    &["psychologising"],
];

pub(crate) static ENTRY_PTOLEMEAN_7707720059199920848: VariantsMap = [
    &["ptolemean"],
    &["ptolemaean"],
    &["ptolemaean"],
    &["ptolemaean"],
];

pub(crate) static ENTRY_PTYALIZED_14737891637486973456: VariantsMap = [
    &["ptyalized"],
    &["ptyalised"],
    &["ptyalized"],
    &["ptyalised"],
];

pub(crate) static ENTRY_PTYALIZES_12224265186752645935: VariantsMap = [
    &["ptyalizes"],
    &["ptyalises"],
    &["ptyalizes"],
    &["ptyalises"],
];

pub(crate) static ENTRY_PTYALIZE_4353643134370653716: VariantsMap =
    [&["ptyalize"], &["ptyalise"], &["ptyalize"], &["ptyalise"]];

pub(crate) static ENTRY_PTYALIZING_4613334822493205194: VariantsMap = [
    &["ptyalizing"],
    &["ptyalising"],
    &["ptyalizing"],
    &["ptyalising"],
];

pub(crate) static ENTRY_PUBLICE_2505581592993963568: VariantsMap =
    [&["publice"], &["publicae"], &["publicae"], &["publicae"]];

pub(crate) static ENTRY_PUBLICIZED_18157849789983063314: VariantsMap = [
    &["publicized"],
    &["publicised"],
    &["publicized"],
    &["publicised"],
];

pub(crate) static ENTRY_PUBLICIZES_16376391030778715202: VariantsMap = [
    &["publicizes"],
    &["publicises"],
    &["publicizes"],
    &["publicises"],
];

pub(crate) static ENTRY_PUBLICIZE_3888814953502121211: VariantsMap = [
    &["publicize"],
    &["publicise"],
    &["publicize"],
    &["publicise"],
];

pub(crate) static ENTRY_PUBLICIZING_15997293412271552492: VariantsMap = [
    &["publicizing"],
    &["publicising"],
    &["publicizing"],
    &["publicising"],
];

pub(crate) static ENTRY_PUEBLOIZATIONS_17184954788467253967: VariantsMap = [
    &["puebloizations"],
    &["puebloisations"],
    &["puebloizations"],
    &["puebloisations"],
];

pub(crate) static ENTRY_PUEBLOIZATION_14471611923776355990: VariantsMap = [
    &["puebloization"],
    &["puebloisation"],
    &["puebloization"],
    &["puebloisation"],
];

pub(crate) static ENTRY_PUEBLOIZES_16793523394160108027: VariantsMap = [
    &["puebloizes"],
    &["puebloises"],
    &["puebloizes"],
    &["puebloises"],
];

pub(crate) static ENTRY_PUEBLOIZE_4789148533035124772: VariantsMap = [
    &["puebloize"],
    &["puebloise"],
    &["puebloize"],
    &["puebloise"],
];

pub(crate) static ENTRY_PUERS_17142262766965004130: VariantsMap =
    [&["puers"], &["pures"], &["pures"], &["pures"]];

pub(crate) static ENTRY_PULICIDE_3980015686815717552: VariantsMap = [
    &["pulicide"],
    &["pulicidae"],
    &["pulicidae"],
    &["pulicidae"],
];

pub(crate) static ENTRY_PULLMANIZES_15655484632672360202: VariantsMap = [
    &["pullmanizes"],
    &["pullmanises"],
    &["pullmanizes"],
    &["pullmanises"],
];

pub(crate) static ENTRY_PULLMANIZE_5203335815973067932: VariantsMap = [
    &["pullmanize"],
    &["pullmanise"],
    &["pullmanize"],
    &["pullmanise"],
];

pub(crate) static ENTRY_PULPITIZES_600820339977194743: VariantsMap = [
    &["pulpitizes"],
    &["pulpitises"],
    &["pulpitizes"],
    &["pulpitises"],
];

pub(crate) static ENTRY_PULPITIZE_14520819506187442470: VariantsMap = [
    &["pulpitize"],
    &["pulpitise"],
    &["pulpitize"],
    &["pulpitise"],
];

pub(crate) static ENTRY_PULVERIZABLER_10798841945279688999: VariantsMap = [
    &["pulverizabler"],
    &["pulverisabler"],
    &["pulverizabler"],
    &["pulverisabler"],
];

pub(crate) static ENTRY_PULVERIZABLEST_9880898831981142418: VariantsMap = [
    &["pulverizablest"],
    &["pulverisablest"],
    &["pulverizablest"],
    &["pulverisablest"],
];

pub(crate) static ENTRY_PULVERIZABLES_12801837069908355828: VariantsMap = [
    &["pulverizables"],
    &["pulverisables"],
    &["pulverizables"],
    &["pulverisables"],
];

pub(crate) static ENTRY_PULVERIZABLE_5528070605510221873: VariantsMap = [
    &["pulverizable"],
    &["pulverisable"],
    &["pulverizable"],
    &["pulverisable"],
];

pub(crate) static ENTRY_PULVERIZATIONS_14450827217528983318: VariantsMap = [
    &["pulverizations"],
    &["pulverisations"],
    &["pulverizations"],
    &["pulverisations"],
];

pub(crate) static ENTRY_PULVERIZATION_200228103143865531: VariantsMap = [
    &["pulverization"],
    &["pulverisation"],
    &["pulverization"],
    &["pulverisation"],
];

pub(crate) static ENTRY_PULVERIZED_14246254308729460669: VariantsMap = [
    &["pulverized"],
    &["pulverised"],
    &["pulverized"],
    &["pulverised"],
];

pub(crate) static ENTRY_PULVERIZERS_7182805923294437318: VariantsMap = [
    &["pulverizers"],
    &["pulverisers"],
    &["pulverizers"],
    &["pulverisers"],
];

pub(crate) static ENTRY_PULVERIZER_14835766143113548223: VariantsMap = [
    &["pulverizer"],
    &["pulveriser"],
    &["pulverizer"],
    &["pulveriser"],
];

pub(crate) static ENTRY_PULVERIZES_1827295055378958546: VariantsMap = [
    &["pulverizes"],
    &["pulverises"],
    &["pulverizes"],
    &["pulverises"],
];

pub(crate) static ENTRY_PULVERIZE_4116752745240045211: VariantsMap = [
    &["pulverize"],
    &["pulverise"],
    &["pulverize"],
    &["pulverise"],
];

pub(crate) static ENTRY_PULVERIZING_17352214593955572763: VariantsMap = [
    &["pulverizing"],
    &["pulverising"],
    &["pulverizing"],
    &["pulverising"],
];

pub(crate) static ENTRY_PULVILIZED_10532293626777762076: VariantsMap = [
    &["pulvilized"],
    &["pulvilised"],
    &["pulvilized"],
    &["pulvilised"],
];

pub(crate) static ENTRY_PUMMELED_18323564550000511359: VariantsMap = [
    &["pummeled"],
    &["pummelled"],
    &["pummelled"],
    &["pummelled"],
];

pub(crate) static ENTRY_PUMMELER_15868425804772851271: VariantsMap = [
    &["pummeler"],
    &["pummeller"],
    &["pummeller"],
    &["pummeller"],
];

pub(crate) static ENTRY_PUMMELING_11168437237560180925: VariantsMap = [
    &["pummeling"],
    &["pummelling"],
    &["pummelling"],
    &["pummelling"],
];

pub(crate) static ENTRY_PUPILIZES_1894766054254996796: VariantsMap = [
    &["pupilizes"],
    &["pupilises"],
    &["pupilizes"],
    &["pupilises"],
];

pub(crate) static ENTRY_PUPILIZE_5377680490535459429: VariantsMap =
    [&["pupilize"], &["pupilise"], &["pupilize"], &["pupilise"]];

pub(crate) static ENTRY_PUPPETIZES_4248804414422953519: VariantsMap = [
    &["puppetizes"],
    &["puppetises"],
    &["puppetizes"],
    &["puppetises"],
];

pub(crate) static ENTRY_PUPPETIZE_77358709430575945: VariantsMap = [
    &["puppetize"],
    &["puppetise"],
    &["puppetize"],
    &["puppetise"],
];

pub(crate) static ENTRY_PURITANIZED_6789297151619861986: VariantsMap = [
    &["puritanized"],
    &["puritanised"],
    &["puritanized"],
    &["puritanised"],
];

pub(crate) static ENTRY_PURITANIZERS_1778141389685069367: VariantsMap = [
    &["puritanizers"],
    &["puritanisers"],
    &["puritanizers"],
    &["puritanisers"],
];

pub(crate) static ENTRY_PURITANIZER_5571229184904133146: VariantsMap = [
    &["puritanizer"],
    &["puritaniser"],
    &["puritanizer"],
    &["puritaniser"],
];

pub(crate) static ENTRY_PURITANIZES_4562255768937344613: VariantsMap = [
    &["puritanizes"],
    &["puritanises"],
    &["puritanizes"],
    &["puritanises"],
];

pub(crate) static ENTRY_PURITANIZE_8338922501694901333: VariantsMap = [
    &["puritanize"],
    &["puritanise"],
    &["puritanize"],
    &["puritanise"],
];

pub(crate) static ENTRY_PURITANIZING_2268731325006525499: VariantsMap = [
    &["puritanizing"],
    &["puritanising"],
    &["puritanizing"],
    &["puritanising"],
];

pub(crate) static ENTRY_PYEMIAS_9051871355215634753: VariantsMap =
    [&["pyemias"], &["pyaemias"], &["pyaemias"], &["pyaemias"]];

pub(crate) static ENTRY_PYEMIA_7988102216395544750: VariantsMap =
    [&["pyemia"], &["pyaemia"], &["pyaemia"], &["pyaemia"]];

pub(crate) static ENTRY_PYEMIC_11860923235877484798: VariantsMap =
    [&["pyemic"], &["pyaemic"], &["pyaemic"], &["pyaemic"]];

pub(crate) static ENTRY_PYGMEAN_12059756127958428908: VariantsMap =
    [&["pygmean"], &["pygmaean"], &["pygmaean"], &["pygmaean"]];

pub(crate) static ENTRY_PYORRHEALER_15895959795219668705: VariantsMap = [
    &["pyorrhealer"],
    &["pyorrhoealer"],
    &["pyorrhoealer"],
    &["pyorrhoealer"],
];

pub(crate) static ENTRY_PYORRHEALEST_1028023297156077918: VariantsMap = [
    &["pyorrhealest"],
    &["pyorrhoealest"],
    &["pyorrhoealest"],
    &["pyorrhoealest"],
];

pub(crate) static ENTRY_PYORRHEAL_12472249177810835579: VariantsMap = [
    &["pyorrheal"],
    &["pyorrhoeal"],
    &["pyorrhoeal"],
    &["pyorrhoeal"],
];

pub(crate) static ENTRY_PYORRHEAS_9316984276613632473: VariantsMap = [
    &["pyorrheas"],
    &["pyorrhoeas"],
    &["pyorrheas"],
    &["pyorrhoeas"],
];

pub(crate) static ENTRY_PYORRHEA_11452852603058973873: VariantsMap =
    [&["pyorrhea"], &["pyorrhoea"], &["pyorrhea"], &["pyorrhoea"]];

pub(crate) static ENTRY_PYORRHEIC_3299650509022396406: VariantsMap = [
    &["pyorrheic"],
    &["pyorrhoeic"],
    &["pyorrhoeic"],
    &["pyorrhoeic"],
];

pub(crate) static ENTRY_PYRAMIDIZES_12212385747150866566: VariantsMap = [
    &["pyramidizes"],
    &["pyramidises"],
    &["pyramidizes"],
    &["pyramidises"],
];

pub(crate) static ENTRY_PYRAMIDIZE_10588274532217907765: VariantsMap = [
    &["pyramidize"],
    &["pyramidise"],
    &["pyramidize"],
    &["pyramidise"],
];

pub(crate) static ENTRY_PYRENEAN_2152548018236454357: VariantsMap = [
    &["pyrenean"],
    &["pyrenaean"],
    &["pyrenaean"],
    &["pyrenaean"],
];

pub(crate) static ENTRY_PYRENEUS_10190704627498876210: VariantsMap = [
    &["pyreneus"],
    &["pyrenaeus"],
    &["pyrenaeus"],
    &["pyrenaeus"],
];

pub(crate) static ENTRY_PYRIDINIZES_3075368646720279500: VariantsMap = [
    &["pyridinizes"],
    &["pyridinises"],
    &["pyridinizes"],
    &["pyridinises"],
];

pub(crate) static ENTRY_PYRIDINIZE_3186988452300111430: VariantsMap = [
    &["pyridinize"],
    &["pyridinise"],
    &["pyridinize"],
    &["pyridinise"],
];

pub(crate) static ENTRY_PYRITIZATIONS_190433604980286404: VariantsMap = [
    &["pyritizations"],
    &["pyritisations"],
    &["pyritizations"],
    &["pyritisations"],
];

pub(crate) static ENTRY_PYRITIZATION_6948326992466383447: VariantsMap = [
    &["pyritization"],
    &["pyritisation"],
    &["pyritization"],
    &["pyritisation"],
];

pub(crate) static ENTRY_PYRITIZED_10674668536971383379: VariantsMap = [
    &["pyritized"],
    &["pyritised"],
    &["pyritized"],
    &["pyritised"],
];

pub(crate) static ENTRY_PYRITIZES_14093831203611662019: VariantsMap = [
    &["pyritizes"],
    &["pyritises"],
    &["pyritizes"],
    &["pyritises"],
];

pub(crate) static ENTRY_PYRITIZE_14505383613972185021: VariantsMap =
    [&["pyritize"], &["pyritise"], &["pyritize"], &["pyritise"]];

pub(crate) static ENTRY_PYRITIZING_12622208379397963806: VariantsMap = [
    &["pyritizing"],
    &["pyritising"],
    &["pyritizing"],
    &["pyritising"],
];

pub(crate) static ENTRY_PYROLYZABLE_16182293090477516327: VariantsMap = [
    &["pyrolyzable"],
    &["pyrolysable"],
    &["pyrolysable"],
    &["pyrolysable"],
];

pub(crate) static ENTRY_PYROLYZATES_6791890316899917756: VariantsMap = [
    &["pyrolyzates"],
    &["pyrolysates"],
    &["pyrolysates"],
    &["pyrolysates"],
];

pub(crate) static ENTRY_PYROLYZATE_13930186823001114533: VariantsMap = [
    &["pyrolyzate"],
    &["pyrolysate"],
    &["pyrolysate"],
    &["pyrolysate"],
];

pub(crate) static ENTRY_PYROLYZED_6450196473837000816: VariantsMap = [
    &["pyrolyzed"],
    &["pyrolysed"],
    &["pyrolyzed"],
    &["pyrolysed"],
];

pub(crate) static ENTRY_PYROLYZER_11614680328839062524: VariantsMap = [
    &["pyrolyzer"],
    &["pyrolyser"],
    &["pyrolyser"],
    &["pyrolyser"],
];

pub(crate) static ENTRY_PYROLYZES_2811540809177764183: VariantsMap = [
    &["pyrolyzes"],
    &["pyrolyses"],
    &["pyrolyzes"],
    &["pyrolyses"],
];

pub(crate) static ENTRY_PYROLYZE_13780640574314797884: VariantsMap =
    [&["pyrolyze"], &["pyrolyse"], &["pyrolyze"], &["pyrolyse"]];

pub(crate) static ENTRY_PYROLYZING_11483665575108061827: VariantsMap = [
    &["pyrolyzing"],
    &["pyrolysing"],
    &["pyrolyzing"],
    &["pyrolysing"],
];

pub(crate) static ENTRY_PYTHAGOREANIZES_7402158601998337606: VariantsMap = [
    &["pythagoreanizes"],
    &["pythagoreanises"],
    &["pythagoreanizes"],
    &["pythagoreanises"],
];

pub(crate) static ENTRY_PYTHAGOREANIZE_8350121642033180635: VariantsMap = [
    &["pythagoreanize"],
    &["pythagoreanise"],
    &["pythagoreanize"],
    &["pythagoreanise"],
];

pub(crate) static ENTRY_PYTHONINE_8378069869888673614: VariantsMap = [
    &["pythonine"],
    &["pythoninae"],
    &["pythoninae"],
    &["pythoninae"],
];

pub(crate) static ENTRY_PYTHONIZES_14271598598290338942: VariantsMap = [
    &["pythonizes"],
    &["pythonises"],
    &["pythonizes"],
    &["pythonises"],
];

pub(crate) static ENTRY_PYTHONIZE_5308256505462488849: VariantsMap = [
    &["pythonize"],
    &["pythonise"],
    &["pythonize"],
    &["pythonise"],
];

pub(crate) static ENTRY_QUAESTORS_8483323232262543948: VariantsMap = [
    &["quaestors"],
    &["quaestors"],
    &["quaestors"],
    &["quaestors"],
];

pub(crate) static ENTRY_QUAESTOR_17594907692681861950: VariantsMap =
    [&["quaestor"], &["quaestor"], &["quaestor"], &["quaestor"]];

pub(crate) static ENTRY_QUAKERIZATIONS_9091064691709489634: VariantsMap = [
    &["quakerizations"],
    &["quakerisations"],
    &["quakerizations"],
    &["quakerisations"],
];

pub(crate) static ENTRY_QUAKERIZATION_15271082910314921958: VariantsMap = [
    &["quakerization"],
    &["quakerisation"],
    &["quakerization"],
    &["quakerisation"],
];

pub(crate) static ENTRY_QUAKERIZES_6225644625493387619: VariantsMap = [
    &["quakerizes"],
    &["quakerises"],
    &["quakerizes"],
    &["quakerises"],
];

pub(crate) static ENTRY_QUAKERIZE_11128424253154253323: VariantsMap = [
    &["quakerize"],
    &["quakerise"],
    &["quakerize"],
    &["quakerise"],
];

pub(crate) static ENTRY_QUANTIZATIONS_18436605585180790614: VariantsMap = [
    &["quantizations"],
    &["quantisations"],
    &["quantizations"],
    &["quantisations"],
];

pub(crate) static ENTRY_QUANTIZATION_17530637216436047165: VariantsMap = [
    &["quantization"],
    &["quantisation"],
    &["quantization"],
    &["quantisation"],
];

pub(crate) static ENTRY_QUANTIZED_2680364749022486524: VariantsMap = [
    &["quantized"],
    &["quantised"],
    &["quantized"],
    &["quantised"],
];

pub(crate) static ENTRY_QUANTIZERS_7834757600518271281: VariantsMap = [
    &["quantizers"],
    &["quantisers"],
    &["quantizers"],
    &["quantisers"],
];

pub(crate) static ENTRY_QUANTIZER_3494983548212992900: VariantsMap = [
    &["quantizer"],
    &["quantiser"],
    &["quantizer"],
    &["quantiser"],
];

pub(crate) static ENTRY_QUANTIZES_4468236107907530850: VariantsMap = [
    &["quantizes"],
    &["quantises"],
    &["quantizes"],
    &["quantises"],
];

pub(crate) static ENTRY_QUANTIZE_11931499095330665012: VariantsMap =
    [&["quantize"], &["quantise"], &["quantize"], &["quantise"]];

pub(crate) static ENTRY_QUANTIZING_17051402668649809855: VariantsMap = [
    &["quantizing"],
    &["quantising"],
    &["quantizing"],
    &["quantising"],
];

pub(crate) static ENTRY_QUARRELED_5653253897786374680: VariantsMap = [
    &["quarreled"],
    &["quarrelled"],
    &["quarrelled"],
    &["quarrelled"],
];

pub(crate) static ENTRY_QUARRELERS_358900163381073241: VariantsMap = [
    &["quarrelers"],
    &["quarrellers"],
    &["quarrellers"],
    &["quarrellers"],
];

pub(crate) static ENTRY_QUARRELER_4085235523024441706: VariantsMap = [
    &["quarreler"],
    &["quarreller"],
    &["quarreller"],
    &["quarreller"],
];

pub(crate) static ENTRY_QUARRELING_10764751794518869060: VariantsMap = [
    &["quarreling"],
    &["quarrelling"],
    &["quarrelling"],
    &["quarrelling"],
];

pub(crate) static ENTRY_QUARRELOUS_11262396164858801968: VariantsMap = [
    &["quarrelous"],
    &["quarrellous"],
    &["quarrellous"],
    &["quarrellous"],
];

pub(crate) static ENTRY_QUARTERIZATIONS_5989124183283298739: VariantsMap = [
    &["quarterizations"],
    &["quarterisations"],
    &["quarterizations"],
    &["quarterisations"],
];

pub(crate) static ENTRY_QUARTERIZATION_15534356304257305635: VariantsMap = [
    &["quarterization"],
    &["quarterisation"],
    &["quarterization"],
    &["quarterisation"],
];

pub(crate) static ENTRY_QUATERS_9944017358673782792: VariantsMap =
    [&["quaters"], &["quatres"], &["quatres"], &["quatres"]];

pub(crate) static ENTRY_QUERELE_11808184504409924035: VariantsMap =
    [&["querele"], &["querelae"], &["querelae"], &["querelae"]];

pub(crate) static ENTRY_QUESTIONARIES_10402520069112102625: VariantsMap = [
    &["questionaries"],
    &["quaestionaries"],
    &["quaestionaries"],
    &["quaestionaries"],
];

pub(crate) static ENTRY_QUESTIONARY_355066268016349878: VariantsMap = [
    &["questionary"],
    &["quaestionary"],
    &["quaestionary"],
    &["quaestionary"],
];

pub(crate) static ENTRY_QUESTORIAL_3922144180001555115: VariantsMap = [
    &["questorial"],
    &["quaestorial"],
    &["quaestorial"],
    &["quaestorial"],
];

pub(crate) static ENTRY_QUESTORSHIP_6181167330242868713: VariantsMap = [
    &["questorship"],
    &["quaestorship"],
    &["quaestorship"],
    &["quaestorship"],
];

pub(crate) static ENTRY_QUEUING_16824913408770003331: VariantsMap =
    [&["queuing"], &["queuing"], &["queuing"], &["queuing"]];

pub(crate) static ENTRY_QUE_13586725649236549292: VariantsMap =
    [&["que"], &["quae"], &["quae"], &["quae"]];

pub(crate) static ENTRY_QUININIZES_10108031189738596948: VariantsMap = [
    &["quininizes"],
    &["quininises"],
    &["quininizes"],
    &["quininises"],
];

pub(crate) static ENTRY_QUININIZE_2087156858031016226: VariantsMap = [
    &["quininize"],
    &["quininise"],
    &["quininize"],
    &["quininise"],
];

pub(crate) static ENTRY_QUINTESSENTIALIZED_10608544255035328498: VariantsMap = [
    &["quintessentialized"],
    &["quintessentialised"],
    &["quintessentialized"],
    &["quintessentialised"],
];

pub(crate) static ENTRY_QUINTESSENTIALIZES_5864610073124488816: VariantsMap = [
    &["quintessentializes"],
    &["quintessentialises"],
    &["quintessentializes"],
    &["quintessentialises"],
];

pub(crate) static ENTRY_QUINTESSENTIALIZE_1798676908258309491: VariantsMap = [
    &["quintessentialize"],
    &["quintessentialise"],
    &["quintessentialize"],
    &["quintessentialise"],
];

pub(crate) static ENTRY_QUINTESSENTIALIZING_13955826412375505803: VariantsMap = [
    &["quintessentializing"],
    &["quintessentialising"],
    &["quintessentializing"],
    &["quintessentialising"],
];

pub(crate) static ENTRY_RACEMIZATIONS_14925364252241043462: VariantsMap = [
    &["racemizations"],
    &["racemisations"],
    &["racemizations"],
    &["racemisations"],
];

pub(crate) static ENTRY_RACEMIZATION_14866059904893991517: VariantsMap = [
    &["racemization"],
    &["racemisation"],
    &["racemization"],
    &["racemisation"],
];

pub(crate) static ENTRY_RACEMIZED_15166940075916248285: VariantsMap = [
    &["racemized"],
    &["racemised"],
    &["racemized"],
    &["racemised"],
];

pub(crate) static ENTRY_RACEMIZES_12324385455966583212: VariantsMap = [
    &["racemizes"],
    &["racemises"],
    &["racemizes"],
    &["racemises"],
];

pub(crate) static ENTRY_RACEMIZE_16676538356806008445: VariantsMap =
    [&["racemize"], &["racemise"], &["racemize"], &["racemise"]];

pub(crate) static ENTRY_RACEMIZING_10678064324413578265: VariantsMap = [
    &["racemizing"],
    &["racemising"],
    &["racemizing"],
    &["racemising"],
];

pub(crate) static ENTRY_RACIALIZATIONS_6346019920628038343: VariantsMap = [
    &["racializations"],
    &["racialisations"],
    &["racializations"],
    &["racialisations"],
];

pub(crate) static ENTRY_RACIALIZATION_3759743204420570975: VariantsMap = [
    &["racialization"],
    &["racialisation"],
    &["racialization"],
    &["racialisation"],
];

pub(crate) static ENTRY_RACIALIZES_4973469964628099453: VariantsMap = [
    &["racializes"],
    &["racialises"],
    &["racializes"],
    &["racialises"],
];

pub(crate) static ENTRY_RACIALIZE_5925611520403941440: VariantsMap = [
    &["racialize"],
    &["racialise"],
    &["racialize"],
    &["racialise"],
];

pub(crate) static ENTRY_RADBORNE_10850064437245752174: VariantsMap = [
    &["radborne"],
    &["radbourne"],
    &["radbourne"],
    &["radbourne"],
];

pub(crate) static ENTRY_RADIALIZATIONS_15793970150795442621: VariantsMap = [
    &["radializations"],
    &["radialisations"],
    &["radializations"],
    &["radialisations"],
];

pub(crate) static ENTRY_RADIALIZATION_15909242338822109844: VariantsMap = [
    &["radialization"],
    &["radialisation"],
    &["radialization"],
    &["radialisation"],
];

pub(crate) static ENTRY_RADIALIZED_4912265723493507733: VariantsMap = [
    &["radialized"],
    &["radialised"],
    &["radialized"],
    &["radialised"],
];

pub(crate) static ENTRY_RADIALIZES_8096719627410360859: VariantsMap = [
    &["radializes"],
    &["radialises"],
    &["radializes"],
    &["radialises"],
];

pub(crate) static ENTRY_RADIALIZE_4331722839835606750: VariantsMap = [
    &["radialize"],
    &["radialise"],
    &["radialize"],
    &["radialise"],
];

pub(crate) static ENTRY_RADIALIZING_3370202487268261936: VariantsMap = [
    &["radializing"],
    &["radialising"],
    &["radializing"],
    &["radialising"],
];

pub(crate) static ENTRY_RADICALIZATIONS_9773145707790145185: VariantsMap = [
    &["radicalizations"],
    &["radicalisations"],
    &["radicalizations"],
    &["radicalisations"],
];

pub(crate) static ENTRY_RADICALIZATION_4526956637788815699: VariantsMap = [
    &["radicalization"],
    &["radicalisation"],
    &["radicalization"],
    &["radicalisation"],
];

pub(crate) static ENTRY_RADICALIZED_970968663725575990: VariantsMap = [
    &["radicalized"],
    &["radicalised"],
    &["radicalized"],
    &["radicalised"],
];

pub(crate) static ENTRY_RADICALIZES_6199505773390853831: VariantsMap = [
    &["radicalizes"],
    &["radicalises"],
    &["radicalizes"],
    &["radicalises"],
];

pub(crate) static ENTRY_RADICALIZE_657046847784299688: VariantsMap = [
    &["radicalize"],
    &["radicalise"],
    &["radicalize"],
    &["radicalise"],
];

pub(crate) static ENTRY_RADICALIZING_13409080083804221460: VariantsMap = [
    &["radicalizing"],
    &["radicalising"],
    &["radicalizing"],
    &["radicalising"],
];

pub(crate) static ENTRY_RADIOPASTEURIZATION_10077706312711948195: VariantsMap = [
    &["radiopasteurization"],
    &["radiopasteurisation"],
    &["radiopasteurization"],
    &["radiopasteurisation"],
];

pub(crate) static ENTRY_RADIOSENSITIZED_10310974351051252440: VariantsMap = [
    &["radiosensitized"],
    &["radiosensitised"],
    &["radiosensitized"],
    &["radiosensitised"],
];

pub(crate) static ENTRY_RADIOSENSITIZES_4744175567736666306: VariantsMap = [
    &["radiosensitizes"],
    &["radiosensitises"],
    &["radiosensitizes"],
    &["radiosensitises"],
];

pub(crate) static ENTRY_RADIOSENSITIZE_493147068573479374: VariantsMap = [
    &["radiosensitize"],
    &["radiosensitise"],
    &["radiosensitize"],
    &["radiosensitise"],
];

pub(crate) static ENTRY_RADIOSENSITIZING_15687044239286203316: VariantsMap = [
    &["radiosensitizing"],
    &["radiosensitising"],
    &["radiosensitizing"],
    &["radiosensitising"],
];

pub(crate) static ENTRY_RADIOSTERILIZATION_14328698460471594598: VariantsMap = [
    &["radiosterilization"],
    &["radiosterilisation"],
    &["radiosterilization"],
    &["radiosterilisation"],
];

pub(crate) static ENTRY_RADIOSTERILIZED_16138782642102283578: VariantsMap = [
    &["radiosterilized"],
    &["radiosterilised"],
    &["radiosterilized"],
    &["radiosterilised"],
];

pub(crate) static ENTRY_RADIOSTERILIZES_17227682815929026577: VariantsMap = [
    &["radiosterilizes"],
    &["radiosterilises"],
    &["radiosterilizes"],
    &["radiosterilises"],
];

pub(crate) static ENTRY_RADIOSTERILIZE_12451407989140658611: VariantsMap = [
    &["radiosterilize"],
    &["radiosterilise"],
    &["radiosterilize"],
    &["radiosterilise"],
];

pub(crate) static ENTRY_RADIOSTERILIZING_12025330816893790142: VariantsMap = [
    &["radiosterilizing"],
    &["radiosterilising"],
    &["radiosterilizing"],
    &["radiosterilising"],
];

pub(crate) static ENTRY_RADIUMIZATIONS_843643436347756512: VariantsMap = [
    &["radiumizations"],
    &["radiumisations"],
    &["radiumizations"],
    &["radiumisations"],
];

pub(crate) static ENTRY_RADIUMIZATION_619606104192746118: VariantsMap = [
    &["radiumization"],
    &["radiumisation"],
    &["radiumization"],
    &["radiumisation"],
];

pub(crate) static ENTRY_RADIUMIZES_769494073563782637: VariantsMap = [
    &["radiumizes"],
    &["radiumises"],
    &["radiumizes"],
    &["radiumises"],
];

pub(crate) static ENTRY_RADIUMIZE_2819850161118182574: VariantsMap = [
    &["radiumize"],
    &["radiumise"],
    &["radiumize"],
    &["radiumise"],
];

pub(crate) static ENTRY_RAME_6231188682149452305: VariantsMap =
    [&["rame"], &["ramae"], &["ramae"], &["ramae"]];

pub(crate) static ENTRY_RAMPIER_15736266043397566231: VariantsMap =
    [&["rampier"], &["rampire"], &["rampire"], &["rampire"]];

pub(crate) static ENTRY_RANCORS_6479511528152236851: VariantsMap =
    [&["rancors"], &["rancours"], &["rancours"], &["rancours"]];

pub(crate) static ENTRY_RANCOR_3021538336566889427: VariantsMap =
    [&["rancor"], &["rancour"], &["rancour"], &["rancour"]];

pub(crate) static ENTRY_RANDOMIZATIONS_17892832491968037972: VariantsMap = [
    &["randomizations"],
    &["randomisations"],
    &["randomizations"],
    &["randomisations"],
];

pub(crate) static ENTRY_RANDOMIZATION_1289611966234918219: VariantsMap = [
    &["randomization"],
    &["randomisation"],
    &["randomization"],
    &["randomisation"],
];

pub(crate) static ENTRY_RANDOMIZED_14523974732692007480: VariantsMap = [
    &["randomized"],
    &["randomised"],
    &["randomized"],
    &["randomised"],
];

pub(crate) static ENTRY_RANDOMIZERS_15224984926574272799: VariantsMap = [
    &["randomizers"],
    &["randomisers"],
    &["randomizers"],
    &["randomisers"],
];

pub(crate) static ENTRY_RANDOMIZER_17355019921057008602: VariantsMap = [
    &["randomizer"],
    &["randomiser"],
    &["randomizer"],
    &["randomiser"],
];

pub(crate) static ENTRY_RANDOMIZES_13716959639798364190: VariantsMap = [
    &["randomizes"],
    &["randomises"],
    &["randomizes"],
    &["randomises"],
];

pub(crate) static ENTRY_RANDOMIZE_13711817980083119800: VariantsMap = [
    &["randomize"],
    &["randomise"],
    &["randomize"],
    &["randomise"],
];

pub(crate) static ENTRY_RANDOMIZING_1606855122710420786: VariantsMap = [
    &["randomizing"],
    &["randomising"],
    &["randomizing"],
    &["randomising"],
];

pub(crate) static ENTRY_RAPHE_15534448576458755657: VariantsMap =
    [&["raphe"], &["raphae"], &["raphae"], &["raphae"]];

pub(crate) static ENTRY_RAPHIDE_6262708817040760676: VariantsMap =
    [&["raphide"], &["raphidae"], &["raphidae"], &["raphidae"]];

pub(crate) static ENTRY_RAPTURIZED_3183871509685674458: VariantsMap = [
    &["rapturized"],
    &["rapturised"],
    &["rapturized"],
    &["rapturised"],
];

pub(crate) static ENTRY_RAPTURIZES_3958786363790102011: VariantsMap = [
    &["rapturizes"],
    &["rapturises"],
    &["rapturizes"],
    &["rapturises"],
];

pub(crate) static ENTRY_RAPTURIZE_14952128339321888268: VariantsMap = [
    &["rapturize"],
    &["rapturise"],
    &["rapturize"],
    &["rapturise"],
];

pub(crate) static ENTRY_RAPTURIZING_12142986500465888480: VariantsMap = [
    &["rapturizing"],
    &["rapturising"],
    &["rapturizing"],
    &["rapturising"],
];

pub(crate) static ENTRY_RASCALIZES_12077348347946302905: VariantsMap = [
    &["rascalizes"],
    &["rascalises"],
    &["rascalizes"],
    &["rascalises"],
];

pub(crate) static ENTRY_RASCALIZE_69827033231107941: VariantsMap = [
    &["rascalize"],
    &["rascalise"],
    &["rascalize"],
    &["rascalise"],
];

pub(crate) static ENTRY_RATIONALIZABLES_2843790548240367930: VariantsMap = [
    &["rationalizables"],
    &["rationalisables"],
    &["rationalizables"],
    &["rationalisables"],
];

pub(crate) static ENTRY_RATIONALIZABLE_10229605389803701324: VariantsMap = [
    &["rationalizable"],
    &["rationalisable"],
    &["rationalizable"],
    &["rationalisable"],
];

pub(crate) static ENTRY_RATIONALIZATIONS_8459085318220075747: VariantsMap = [
    &["rationalizations"],
    &["rationalisations"],
    &["rationalizations"],
    &["rationalisations"],
];

pub(crate) static ENTRY_RATIONALIZATION_8601852902277773028: VariantsMap = [
    &["rationalization"],
    &["rationalisation"],
    &["rationalization"],
    &["rationalisation"],
];

pub(crate) static ENTRY_RATIONALIZED_17223545651759435903: VariantsMap = [
    &["rationalized"],
    &["rationalised"],
    &["rationalized"],
    &["rationalised"],
];

pub(crate) static ENTRY_RATIONALIZERS_12960131638398414888: VariantsMap = [
    &["rationalizers"],
    &["rationalisers"],
    &["rationalizers"],
    &["rationalisers"],
];

pub(crate) static ENTRY_RATIONALIZER_6435122838480912496: VariantsMap = [
    &["rationalizer"],
    &["rationaliser"],
    &["rationalizer"],
    &["rationaliser"],
];

pub(crate) static ENTRY_RATIONALIZES_6112460011448011714: VariantsMap = [
    &["rationalizes"],
    &["rationalises"],
    &["rationalizes"],
    &["rationalises"],
];

pub(crate) static ENTRY_RATIONALIZE_17083234249921972490: VariantsMap = [
    &["rationalize"],
    &["rationalise"],
    &["rationalize"],
    &["rationalise"],
];

pub(crate) static ENTRY_RATIONALIZING_2753577106103404272: VariantsMap = [
    &["rationalizing"],
    &["rationalising"],
    &["rationalizing"],
    &["rationalising"],
];

pub(crate) static ENTRY_RATITE_17526384648991858474: VariantsMap =
    [&["ratite"], &["ratitae"], &["ratitae"], &["ratitae"]];

pub(crate) static ENTRY_RAVELED_13769751134216869095: VariantsMap =
    [&["raveled"], &["ravelled"], &["ravelled"], &["ravelled"]];

pub(crate) static ENTRY_RAVELERS_15565713204718807849: VariantsMap = [
    &["ravelers"],
    &["ravellers"],
    &["ravellers"],
    &["ravellers"],
];

pub(crate) static ENTRY_RAVELER_5664226560864499541: VariantsMap =
    [&["raveler"], &["raveller"], &["raveller"], &["raveller"]];

pub(crate) static ENTRY_RAVELINGS_4361143677870266413: VariantsMap = [
    &["ravelings"],
    &["ravellings"],
    &["ravellings"],
    &["ravellings"],
];

pub(crate) static ENTRY_RAVELING_14313363779439759025: VariantsMap = [
    &["raveling"],
    &["ravelling"],
    &["ravelling"],
    &["ravelling"],
];

pub(crate) static ENTRY_RAVELING_17036141143171588397: VariantsMap = [
    &["raveling"],
    &["ravelling"],
    &["ravelling"],
    &["ravelling"],
];

pub(crate) static ENTRY_REACCLIMATIZATIONS_445812918952620334: VariantsMap = [
    &["reacclimatizations"],
    &["reacclimatisations"],
    &["reacclimatizations"],
    &["reacclimatisations"],
];

pub(crate) static ENTRY_REACCLIMATIZATION_8003619318055185625: VariantsMap = [
    &["reacclimatization"],
    &["reacclimatisation"],
    &["reacclimatization"],
    &["reacclimatisation"],
];

pub(crate) static ENTRY_REACCLIMATIZED_10228493679848009990: VariantsMap = [
    &["reacclimatized"],
    &["reacclimatised"],
    &["reacclimatized"],
    &["reacclimatised"],
];

pub(crate) static ENTRY_REACCLIMATIZES_3770736538867723242: VariantsMap = [
    &["reacclimatizes"],
    &["reacclimatises"],
    &["reacclimatizes"],
    &["reacclimatises"],
];

pub(crate) static ENTRY_REACCLIMATIZE_16936237501871362788: VariantsMap = [
    &["reacclimatize"],
    &["reacclimatise"],
    &["reacclimatize"],
    &["reacclimatise"],
];

pub(crate) static ENTRY_REACCLIMATIZING_13464669649206437692: VariantsMap = [
    &["reacclimatizing"],
    &["reacclimatising"],
    &["reacclimatizing"],
    &["reacclimatising"],
];

pub(crate) static ENTRY_REACTUALIZES_5611298045086045988: VariantsMap = [
    &["reactualizes"],
    &["reactualises"],
    &["reactualizes"],
    &["reactualises"],
];

pub(crate) static ENTRY_REACTUALIZE_15121608179320441718: VariantsMap = [
    &["reactualize"],
    &["reactualise"],
    &["reactualize"],
    &["reactualise"],
];

pub(crate) static ENTRY_READVERTIZED_17989467612846660175: VariantsMap = [
    &["readvertized"],
    &["readvertised"],
    &["readvertized"],
    &["readvertised"],
];

pub(crate) static ENTRY_READVERTIZE_17135010889729486559: VariantsMap = [
    &["readvertize"],
    &["readvertise"],
    &["readvertize"],
    &["readvertise"],
];

pub(crate) static ENTRY_READVERTIZING_4761320404074285638: VariantsMap = [
    &["readvertizing"],
    &["readvertising"],
    &["readvertizing"],
    &["readvertising"],
];

pub(crate) static ENTRY_REALISTICIZES_9600102337891080845: VariantsMap = [
    &["realisticizes"],
    &["realisticises"],
    &["realisticizes"],
    &["realisticises"],
];

pub(crate) static ENTRY_REALISTICIZE_5772362692210402917: VariantsMap = [
    &["realisticize"],
    &["realisticise"],
    &["realisticize"],
    &["realisticise"],
];

pub(crate) static ENTRY_REALIZABILITIES_1107948109278957869: VariantsMap = [
    &["realizabilities"],
    &["realisabilities"],
    &["realizabilities"],
    &["realisabilities"],
];

pub(crate) static ENTRY_REALIZABILITY_7120240154132794852: VariantsMap = [
    &["realizability"],
    &["realisability"],
    &["realizability"],
    &["realisability"],
];

pub(crate) static ENTRY_REALIZABLENESS_16356767595928190053: VariantsMap = [
    &["realizableness"],
    &["realisableness"],
    &["realizableness"],
    &["realisableness"],
];

pub(crate) static ENTRY_REALIZABLER_10808842652675364031: VariantsMap = [
    &["realizabler"],
    &["realisabler"],
    &["realizabler"],
    &["realisabler"],
];

pub(crate) static ENTRY_REALIZABLEST_5797694315741755778: VariantsMap = [
    &["realizablest"],
    &["realisablest"],
    &["realizablest"],
    &["realisablest"],
];

pub(crate) static ENTRY_REALIZABLES_12573952050524775505: VariantsMap = [
    &["realizables"],
    &["realisables"],
    &["realizables"],
    &["realisables"],
];

pub(crate) static ENTRY_REALIZABLE_17163353249932728066: VariantsMap = [
    &["realizable"],
    &["realisable"],
    &["realizable"],
    &["realisable"],
];

pub(crate) static ENTRY_REALIZABLIES_11825765500038359602: VariantsMap = [
    &["realizablies"],
    &["realisablies"],
    &["realizablies"],
    &["realisablies"],
];

pub(crate) static ENTRY_REALIZABLY_9506389367577953795: VariantsMap = [
    &["realizably"],
    &["realisably"],
    &["realizably"],
    &["realisably"],
];

pub(crate) static ENTRY_REALIZATIONS_11017380405499744692: VariantsMap = [
    &["realizations"],
    &["realisations"],
    &["realizations"],
    &["realisations"],
];

pub(crate) static ENTRY_REALIZATION_14225128147203750365: VariantsMap = [
    &["realization"],
    &["realisation"],
    &["realization"],
    &["realisation"],
];

pub(crate) static ENTRY_REALIZED_1705791300416174175: VariantsMap =
    [&["realized"], &["realised"], &["realized"], &["realised"]];

pub(crate) static ENTRY_REALIZERS_5837268423419941688: VariantsMap = [
    &["realizers"],
    &["realisers"],
    &["realizers"],
    &["realisers"],
];

pub(crate) static ENTRY_REALIZER_492931096277732629: VariantsMap =
    [&["realizer"], &["realiser"], &["realizer"], &["realiser"]];

pub(crate) static ENTRY_REALIZES_10741119444291026235: VariantsMap =
    [&["realizes"], &["realises"], &["realizes"], &["realises"]];

pub(crate) static ENTRY_REALIZE_2182577141310692876: VariantsMap =
    [&["realize"], &["realise"], &["realize"], &["realise"]];

pub(crate) static ENTRY_REALIZINGLY_11111595947779632968: VariantsMap = [
    &["realizingly"],
    &["realisingly"],
    &["realizingly"],
    &["realisingly"],
];

pub(crate) static ENTRY_REALIZINGS_8807041604242423702: VariantsMap = [
    &["realizings"],
    &["realisings"],
    &["realizings"],
    &["realisings"],
];

pub(crate) static ENTRY_REALIZING_3319107293179944558: VariantsMap = [
    &["realizing"],
    &["realising"],
    &["realizing"],
    &["realising"],
];

pub(crate) static ENTRY_REANALYZED_4571855154510793046: VariantsMap = [
    &["reanalyzed"],
    &["reanalysed"],
    &["reanalyzed"],
    &["reanalysed"],
];

pub(crate) static ENTRY_REANALYZERS_11991980726543842859: VariantsMap = [
    &["reanalyzers"],
    &["reanalysers"],
    &["reanalyzers"],
    &["reanalysers"],
];

pub(crate) static ENTRY_REANALYZER_3769720403208548613: VariantsMap = [
    &["reanalyzer"],
    &["reanalyser"],
    &["reanalyzer"],
    &["reanalyser"],
];

pub(crate) static ENTRY_REANALYZES_6422780434253423868: VariantsMap = [
    &["reanalyzes"],
    &["reanalyses"],
    &["reanalyzes"],
    &["reanalyses"],
];

pub(crate) static ENTRY_REANALYZE_10186131393135073487: VariantsMap = [
    &["reanalyze"],
    &["reanalyse"],
    &["reanalyze"],
    &["reanalyse"],
];

pub(crate) static ENTRY_REANALYZING_7827332182372932126: VariantsMap = [
    &["reanalyzing"],
    &["reanalysing"],
    &["reanalyzing"],
    &["reanalysing"],
];

pub(crate) static ENTRY_REANIMALIZES_15653498423524957266: VariantsMap = [
    &["reanimalizes"],
    &["reanimalises"],
    &["reanimalizes"],
    &["reanimalises"],
];

pub(crate) static ENTRY_REANIMALIZE_3196465253809288594: VariantsMap = [
    &["reanimalize"],
    &["reanimalise"],
    &["reanimalize"],
    &["reanimalise"],
];

pub(crate) static ENTRY_REAPOLOGIZES_2274108662665466732: VariantsMap = [
    &["reapologizes"],
    &["reapologises"],
    &["reapologizes"],
    &["reapologises"],
];

pub(crate) static ENTRY_REAPOLOGIZE_14132055598610834333: VariantsMap = [
    &["reapologize"],
    &["reapologise"],
    &["reapologize"],
    &["reapologise"],
];

pub(crate) static ENTRY_REAUTHORIZATIONS_15987529216192362803: VariantsMap = [
    &["reauthorizations"],
    &["reauthorisations"],
    &["reauthorizations"],
    &["reauthorisations"],
];

pub(crate) static ENTRY_REAUTHORIZATION_5069423989935588733: VariantsMap = [
    &["reauthorization"],
    &["reauthorisation"],
    &["reauthorization"],
    &["reauthorisation"],
];

pub(crate) static ENTRY_REAUTHORIZES_9412231466354343842: VariantsMap = [
    &["reauthorizes"],
    &["reauthorises"],
    &["reauthorizes"],
    &["reauthorises"],
];

pub(crate) static ENTRY_REAUTHORIZE_1493549425007215475: VariantsMap = [
    &["reauthorize"],
    &["reauthorise"],
    &["reauthorize"],
    &["reauthorise"],
];

pub(crate) static ENTRY_REBAPTIZATIONS_10409601231952199745: VariantsMap = [
    &["rebaptizations"],
    &["rebaptisations"],
    &["rebaptizations"],
    &["rebaptisations"],
];

pub(crate) static ENTRY_REBAPTIZATION_14913572866891296519: VariantsMap = [
    &["rebaptization"],
    &["rebaptisation"],
    &["rebaptization"],
    &["rebaptisation"],
];

pub(crate) static ENTRY_REBAPTIZED_7549343503873914730: VariantsMap = [
    &["rebaptized"],
    &["rebaptised"],
    &["rebaptized"],
    &["rebaptised"],
];

pub(crate) static ENTRY_REBAPTIZES_8627235980201949978: VariantsMap = [
    &["rebaptizes"],
    &["rebaptises"],
    &["rebaptizes"],
    &["rebaptises"],
];

pub(crate) static ENTRY_REBAPTIZE_571434688106506900: VariantsMap = [
    &["rebaptize"],
    &["rebaptise"],
    &["rebaptize"],
    &["rebaptise"],
];

pub(crate) static ENTRY_REBAPTIZING_1458650261134996813: VariantsMap = [
    &["rebaptizing"],
    &["rebaptising"],
    &["rebaptizing"],
    &["rebaptising"],
];

pub(crate) static ENTRY_REBOURBONIZES_17217540334190607076: VariantsMap = [
    &["rebourbonizes"],
    &["rebourbonises"],
    &["rebourbonizes"],
    &["rebourbonises"],
];

pub(crate) static ENTRY_REBOURBONIZE_5261400215839580856: VariantsMap = [
    &["rebourbonize"],
    &["rebourbonise"],
    &["rebourbonize"],
    &["rebourbonise"],
];

pub(crate) static ENTRY_REBRUTALIZES_4495483792663700379: VariantsMap = [
    &["rebrutalizes"],
    &["rebrutalises"],
    &["rebrutalizes"],
    &["rebrutalises"],
];

pub(crate) static ENTRY_REBRUTALIZE_15890308064516958097: VariantsMap = [
    &["rebrutalize"],
    &["rebrutalise"],
    &["rebrutalize"],
    &["rebrutalise"],
];

pub(crate) static ENTRY_RECANALIZATION_9848130740850646766: VariantsMap = [
    &["recanalization"],
    &["recanalisation"],
    &["recanalization"],
    &["recanalisation"],
];

pub(crate) static ENTRY_RECAPITALIZATIONS_3489528805026955416: VariantsMap = [
    &["recapitalizations"],
    &["recapitalisations"],
    &["recapitalizations"],
    &["recapitalisations"],
];

pub(crate) static ENTRY_RECAPITALIZATION_13789246273577829586: VariantsMap = [
    &["recapitalization"],
    &["recapitalisation"],
    &["recapitalization"],
    &["recapitalisation"],
];

pub(crate) static ENTRY_RECAPITALIZED_3935375616241692055: VariantsMap = [
    &["recapitalized"],
    &["recapitalised"],
    &["recapitalized"],
    &["recapitalised"],
];

pub(crate) static ENTRY_RECAPITALIZES_8130308401555173305: VariantsMap = [
    &["recapitalizes"],
    &["recapitalises"],
    &["recapitalizes"],
    &["recapitalises"],
];

pub(crate) static ENTRY_RECAPITALIZE_18040056007083479651: VariantsMap = [
    &["recapitalize"],
    &["recapitalise"],
    &["recapitalize"],
    &["recapitalise"],
];

pub(crate) static ENTRY_RECAPITALIZING_14545289468100637309: VariantsMap = [
    &["recapitalizing"],
    &["recapitalising"],
    &["recapitalizing"],
    &["recapitalising"],
];

pub(crate) static ENTRY_RECARBONIZATIONS_17520317422251898259: VariantsMap = [
    &["recarbonizations"],
    &["recarbonisations"],
    &["recarbonizations"],
    &["recarbonisations"],
];

pub(crate) static ENTRY_RECARBONIZATION_14106539650901519060: VariantsMap = [
    &["recarbonization"],
    &["recarbonisation"],
    &["recarbonization"],
    &["recarbonisation"],
];

pub(crate) static ENTRY_RECARBONIZERS_13171975227254449418: VariantsMap = [
    &["recarbonizers"],
    &["recarbonisers"],
    &["recarbonizers"],
    &["recarbonisers"],
];

pub(crate) static ENTRY_RECARBONIZER_6401093463168506503: VariantsMap = [
    &["recarbonizer"],
    &["recarboniser"],
    &["recarbonizer"],
    &["recarboniser"],
];

pub(crate) static ENTRY_RECARBONIZES_1395029874212040625: VariantsMap = [
    &["recarbonizes"],
    &["recarbonises"],
    &["recarbonizes"],
    &["recarbonises"],
];

pub(crate) static ENTRY_RECARBONIZE_15994488180990553654: VariantsMap = [
    &["recarbonize"],
    &["recarbonise"],
    &["recarbonize"],
    &["recarbonise"],
];

pub(crate) static ENTRY_RECATEGORIZED_1861087840624306453: VariantsMap = [
    &["recategorized"],
    &["recategorised"],
    &["recategorized"],
    &["recategorised"],
];

pub(crate) static ENTRY_RECAUSTICIZES_13573292008926947855: VariantsMap = [
    &["recausticizes"],
    &["recausticises"],
    &["recausticizes"],
    &["recausticises"],
];

pub(crate) static ENTRY_RECAUSTICIZE_14314640527642854828: VariantsMap = [
    &["recausticize"],
    &["recausticise"],
    &["recausticize"],
    &["recausticise"],
];

pub(crate) static ENTRY_RECENTRALIZATIONS_17081718818823233232: VariantsMap = [
    &["recentralizations"],
    &["recentralisations"],
    &["recentralizations"],
    &["recentralisations"],
];

pub(crate) static ENTRY_RECENTRALIZATION_6419892289797763156: VariantsMap = [
    &["recentralization"],
    &["recentralisation"],
    &["recentralization"],
    &["recentralisation"],
];

pub(crate) static ENTRY_RECENTRALIZES_14658033323787489399: VariantsMap = [
    &["recentralizes"],
    &["recentralises"],
    &["recentralizes"],
    &["recentralises"],
];

pub(crate) static ENTRY_RECENTRALIZE_5404153365159026113: VariantsMap = [
    &["recentralize"],
    &["recentralise"],
    &["recentralize"],
    &["recentralise"],
];

pub(crate) static ENTRY_RECERCELE_9415487321125207769: VariantsMap = [
    &["recercele"],
    &["recercelae"],
    &["recercelae"],
    &["recercelae"],
];

pub(crate) static ENTRY_RECIPROCALIZES_6837540957901914138: VariantsMap = [
    &["reciprocalizes"],
    &["reciprocalises"],
    &["reciprocalizes"],
    &["reciprocalises"],
];

pub(crate) static ENTRY_RECIPROCALIZE_14788818366272476641: VariantsMap = [
    &["reciprocalize"],
    &["reciprocalise"],
    &["reciprocalize"],
    &["reciprocalise"],
];

pub(crate) static ENTRY_RECIVILIZATIONS_15159458739775450649: VariantsMap = [
    &["recivilizations"],
    &["recivilisations"],
    &["recivilizations"],
    &["recivilisations"],
];

pub(crate) static ENTRY_RECIVILIZATION_16749469924106120267: VariantsMap = [
    &["recivilization"],
    &["recivilisation"],
    &["recivilization"],
    &["recivilisation"],
];

pub(crate) static ENTRY_RECIVILIZES_13280929754254705028: VariantsMap = [
    &["recivilizes"],
    &["recivilises"],
    &["recivilizes"],
    &["recivilises"],
];

pub(crate) static ENTRY_RECIVILIZE_3997712789498055993: VariantsMap = [
    &["recivilize"],
    &["recivilise"],
    &["recivilize"],
    &["recivilise"],
];

pub(crate) static ENTRY_RECOGNIZABILITY_16998271750617343863: VariantsMap = [
    &["recognizability"],
    &["recognisability"],
    &["recognizability"],
    &["recognisability"],
];

pub(crate) static ENTRY_RECOGNIZABLER_4175265933374548777: VariantsMap = [
    &["recognizabler"],
    &["recognisabler"],
    &["recognizabler"],
    &["recognisabler"],
];

pub(crate) static ENTRY_RECOGNIZABLEST_10751547482572497805: VariantsMap = [
    &["recognizablest"],
    &["recognisablest"],
    &["recognizablest"],
    &["recognisablest"],
];

pub(crate) static ENTRY_RECOGNIZABLE_5889010403845230013: VariantsMap = [
    &["recognizable"],
    &["recognisable"],
    &["recognizable"],
    &["recognisable"],
];

pub(crate) static ENTRY_RECOGNIZABLY_11330537720549631906: VariantsMap = [
    &["recognizably"],
    &["recognisably"],
    &["recognizably"],
    &["recognisably"],
];

pub(crate) static ENTRY_RECOGNIZANCES_6362532022872453821: VariantsMap = [
    &["recognizances"],
    &["recognisances"],
    &["recognizances"],
    &["recognisances"],
];

pub(crate) static ENTRY_RECOGNIZANCE_15579684512687603764: VariantsMap = [
    &["recognizance"],
    &["recognisance"],
    &["recognizance"],
    &["recognisance"],
];

pub(crate) static ENTRY_RECOGNIZEDLIES_14465767719751035498: VariantsMap = [
    &["recognizedlies"],
    &["recognisedlies"],
    &["recognizedlies"],
    &["recognisedlies"],
];

pub(crate) static ENTRY_RECOGNIZEDLY_15932389996645062386: VariantsMap = [
    &["recognizedly"],
    &["recognisedly"],
    &["recognizedly"],
    &["recognisedly"],
];

pub(crate) static ENTRY_RECOGNIZED_1395716530900621428: VariantsMap = [
    &["recognized"],
    &["recognised"],
    &["recognized"],
    &["recognised"],
];

pub(crate) static ENTRY_RECOGNIZERS_6758013473971762546: VariantsMap = [
    &["recognizers"],
    &["recognisers"],
    &["recognizers"],
    &["recognisers"],
];

pub(crate) static ENTRY_RECOGNIZER_8772856764417667202: VariantsMap = [
    &["recognizer"],
    &["recogniser"],
    &["recognizer"],
    &["recogniser"],
];

pub(crate) static ENTRY_RECOGNIZES_10660009240958159019: VariantsMap = [
    &["recognizes"],
    &["recognises"],
    &["recognizes"],
    &["recognises"],
];

pub(crate) static ENTRY_RECOGNIZE_8073300949060678463: VariantsMap = [
    &["recognize"],
    &["recognise"],
    &["recognize"],
    &["recognise"],
];

pub(crate) static ENTRY_RECOGNIZINGLIES_11967771031854316683: VariantsMap = [
    &["recognizinglies"],
    &["recognisinglies"],
    &["recognizinglies"],
    &["recognisinglies"],
];

pub(crate) static ENTRY_RECOGNIZINGLY_15449966182297309703: VariantsMap = [
    &["recognizingly"],
    &["recognisingly"],
    &["recognizingly"],
    &["recognisingly"],
];

pub(crate) static ENTRY_RECOGNIZING_11885856045541184543: VariantsMap = [
    &["recognizing"],
    &["recognising"],
    &["recognizing"],
    &["recognising"],
];

pub(crate) static ENTRY_RECOLONIZATIONS_7011055890180445996: VariantsMap = [
    &["recolonizations"],
    &["recolonisations"],
    &["recolonizations"],
    &["recolonisations"],
];

pub(crate) static ENTRY_RECOLONIZATION_16258927676742050499: VariantsMap = [
    &["recolonization"],
    &["recolonisation"],
    &["recolonization"],
    &["recolonisation"],
];

pub(crate) static ENTRY_RECOLONIZED_1553732142933540424: VariantsMap = [
    &["recolonized"],
    &["recolonised"],
    &["recolonized"],
    &["recolonised"],
];

pub(crate) static ENTRY_RECOLONIZES_7070029475272886204: VariantsMap = [
    &["recolonizes"],
    &["recolonises"],
    &["recolonizes"],
    &["recolonises"],
];

pub(crate) static ENTRY_RECOLONIZE_1210620957407633342: VariantsMap = [
    &["recolonize"],
    &["recolonise"],
    &["recolonize"],
    &["recolonise"],
];

pub(crate) static ENTRY_RECOLONIZING_15474385751968098455: VariantsMap = [
    &["recolonizing"],
    &["recolonising"],
    &["recolonizing"],
    &["recolonising"],
];

pub(crate) static ENTRY_RECOLORATIONS_4889262529781127619: VariantsMap = [
    &["recolorations"],
    &["recolourations"],
    &["recolourations"],
    &["recolourations"],
];

pub(crate) static ENTRY_RECOLORATION_284267020047489567: VariantsMap = [
    &["recoloration"],
    &["recolouration"],
    &["recolouration"],
    &["recolouration"],
];

pub(crate) static ENTRY_RECOLORED_17015675809629209249: VariantsMap = [
    &["recolored"],
    &["recoloured"],
    &["recoloured"],
    &["recoloured"],
];

pub(crate) static ENTRY_RECOLORING_6696403137875712708: VariantsMap = [
    &["recoloring"],
    &["recolouring"],
    &["recolouring"],
    &["recolouring"],
];

pub(crate) static ENTRY_RECOLORS_13250820879245551898: VariantsMap = [
    &["recolors"],
    &["recolours"],
    &["recolours"],
    &["recolours"],
];

pub(crate) static ENTRY_RECOLOR_3257883209193222439: VariantsMap =
    [&["recolor"], &["recolour"], &["recolour"], &["recolour"]];

pub(crate) static ENTRY_RECONCEPTUALIZATION_3284710301791003378: VariantsMap = [
    &["reconceptualization"],
    &["reconceptualisation"],
    &["reconceptualization"],
    &["reconceptualisation"],
];

pub(crate) static ENTRY_RECONCEPTUALIZING_14548968664268398028: VariantsMap = [
    &["reconceptualizing"],
    &["reconceptualising"],
    &["reconceptualizing"],
    &["reconceptualising"],
];

pub(crate) static ENTRY_RECONNOITERED_1091968190945009220: VariantsMap = [
    &["reconnoitered"],
    &["reconnoitred"],
    &["reconnoitred"],
    &["reconnoitred"],
];

pub(crate) static ENTRY_RECONNOITERERS_8799608756200599017: VariantsMap = [
    &["reconnoiterers"],
    &["reconnoitrers"],
    &["reconnoitrers"],
    &["reconnoitrers"],
];

pub(crate) static ENTRY_RECONNOITERER_12511415252932652959: VariantsMap = [
    &["reconnoiterer"],
    &["reconnoitrer"],
    &["reconnoitrer"],
    &["reconnoitrer"],
];

pub(crate) static ENTRY_RECONNOITERING_18391585459717006853: VariantsMap = [
    &["reconnoitering"],
    &["reconnoitring"],
    &["reconnoitring"],
    &["reconnoitring"],
];

pub(crate) static ENTRY_RECONNOITERS_13027705962087318478: VariantsMap = [
    &["reconnoiters"],
    &["reconnoitres"],
    &["reconnoitres"],
    &["reconnoitres"],
];

pub(crate) static ENTRY_RECONNOITER_18316377090168333117: VariantsMap = [
    &["reconnoiter"],
    &["reconnoitre"],
    &["reconnoitre"],
    &["reconnoitre"],
];

pub(crate) static ENTRY_RECRITICIZES_90813554752564010: VariantsMap = [
    &["recriticizes"],
    &["recriticises"],
    &["recriticizes"],
    &["recriticises"],
];

pub(crate) static ENTRY_RECRITICIZE_10742947607354632832: VariantsMap = [
    &["recriticize"],
    &["recriticise"],
    &["recriticize"],
    &["recriticise"],
];

pub(crate) static ENTRY_RECRYSTALLIZATIONS_16182832227691275920: VariantsMap = [
    &["recrystallizations"],
    &["recrystallisations"],
    &["recrystallizations"],
    &["recrystallisations"],
];

pub(crate) static ENTRY_RECRYSTALLIZATION_1860786864462001408: VariantsMap = [
    &["recrystallization"],
    &["recrystallisation"],
    &["recrystallization"],
    &["recrystallisation"],
];

pub(crate) static ENTRY_RECRYSTALLIZED_11205669347561069076: VariantsMap = [
    &["recrystallized"],
    &["recrystallised"],
    &["recrystallized"],
    &["recrystallised"],
];

pub(crate) static ENTRY_RECRYSTALLIZES_16108644468574946795: VariantsMap = [
    &["recrystallizes"],
    &["recrystallises"],
    &["recrystallizes"],
    &["recrystallises"],
];

pub(crate) static ENTRY_RECRYSTALLIZE_17331547300893041236: VariantsMap = [
    &["recrystallize"],
    &["recrystallise"],
    &["recrystallize"],
    &["recrystallise"],
];

pub(crate) static ENTRY_RECRYSTALLIZING_12962671839000145939: VariantsMap = [
    &["recrystallizing"],
    &["recrystallising"],
    &["recrystallizing"],
    &["recrystallising"],
];

pub(crate) static ENTRY_REDIALED_1443583636270689000: VariantsMap =
    [&["redialed"], &["redialled"], &["redialed"], &["redialled"]];

pub(crate) static ENTRY_REDIALER_15041522948567414545: VariantsMap = [
    &["redialer"],
    &["redialler"],
    &["redialler"],
    &["redialler"],
];

pub(crate) static ENTRY_REDIALING_7917159843633067663: VariantsMap = [
    &["redialing"],
    &["redialling"],
    &["redialing"],
    &["redialling"],
];

pub(crate) static ENTRY_REDISSEIZE_12321412602071096537: VariantsMap = [
    &["redisseize"],
    &["redisseise"],
    &["redisseize"],
    &["redisseise"],
];

pub(crate) static ENTRY_REDISSEIZIN_5313153373478904686: VariantsMap = [
    &["redisseizin"],
    &["redisseisin"],
    &["redisseizin"],
    &["redisseisin"],
];

pub(crate) static ENTRY_REEDIFIED_17185371367326424982: VariantsMap = [
    &["reedified"],
    &["reaedified"],
    &["reaedified"],
    &["reaedified"],
];

pub(crate) static ENTRY_REEDIFIES_9756610285343034160: VariantsMap = [
    &["reedifies"],
    &["reaedifies"],
    &["reaedifies"],
    &["reaedifies"],
];

pub(crate) static ENTRY_REEDIFYING_13575861282224820161: VariantsMap = [
    &["reedifying"],
    &["reaedifying"],
    &["reaedifying"],
    &["reaedifying"],
];

pub(crate) static ENTRY_REEDIFY_14467490388921640991: VariantsMap =
    [&["reedify"], &["reaedify"], &["reaedify"], &["reaedify"]];

pub(crate) static ENTRY_REEMPHASIZED_12384916709213775729: VariantsMap = [
    &["reemphasized"],
    &["reemphasised"],
    &["reemphasized"],
    &["reemphasised"],
];

pub(crate) static ENTRY_REEMPHASIZERS_5418129948384015229: VariantsMap = [
    &["reemphasizers"],
    &["reemphasisers"],
    &["reemphasizers"],
    &["reemphasisers"],
];

pub(crate) static ENTRY_REEMPHASIZER_15541175908528906257: VariantsMap = [
    &["reemphasizer"],
    &["reemphasiser"],
    &["reemphasizer"],
    &["reemphasiser"],
];

pub(crate) static ENTRY_REEMPHASIZES_1924687289037556817: VariantsMap = [
    &["reemphasizes"],
    &["reemphasises"],
    &["reemphasizes"],
    &["reemphasises"],
];

pub(crate) static ENTRY_REEMPHASIZE_14845797480169011940: VariantsMap = [
    &["reemphasize"],
    &["reemphasise"],
    &["reemphasize"],
    &["reemphasise"],
];

pub(crate) static ENTRY_REEMPHASIZING_5952154417428143353: VariantsMap = [
    &["reemphasizing"],
    &["reemphasising"],
    &["reemphasizing"],
    &["reemphasising"],
];

pub(crate) static ENTRY_REENTRANCE_14813557870017739558: VariantsMap = [
    &["reentrance"],
    &["reaentrance"],
    &["reaentrance"],
    &["reaentrance"],
];

pub(crate) static ENTRY_REEXPORTATION_9761953209479597434: VariantsMap = [
    &["reexportation"],
    &["reaexportation"],
    &["reaexportation"],
    &["reaexportation"],
];

pub(crate) static ENTRY_REEXPORTER_204235148455899141: VariantsMap = [
    &["reexporter"],
    &["reaexporter"],
    &["reaexporter"],
    &["reaexporter"],
];

pub(crate) static ENTRY_REFAVORS_6261091989940159944: VariantsMap = [
    &["refavors"],
    &["refavours"],
    &["refavours"],
    &["refavours"],
];

pub(crate) static ENTRY_REFAVOR_13127112244409244390: VariantsMap =
    [&["refavor"], &["refavour"], &["refavour"], &["refavour"]];

pub(crate) static ENTRY_REFERTILIZATIONS_10209257884796898169: VariantsMap = [
    &["refertilizations"],
    &["refertilisations"],
    &["refertilizations"],
    &["refertilisations"],
];

pub(crate) static ENTRY_REFERTILIZATION_10871550741687115201: VariantsMap = [
    &["refertilization"],
    &["refertilisation"],
    &["refertilization"],
    &["refertilisation"],
];

pub(crate) static ENTRY_REFERTILIZES_10965697532320057521: VariantsMap = [
    &["refertilizes"],
    &["refertilises"],
    &["refertilizes"],
    &["refertilises"],
];

pub(crate) static ENTRY_REFERTILIZE_12372222114547549332: VariantsMap = [
    &["refertilize"],
    &["refertilise"],
    &["refertilize"],
    &["refertilise"],
];

pub(crate) static ENTRY_REFLECTORIZED_13272320600964781160: VariantsMap = [
    &["reflectorized"],
    &["reflectorised"],
    &["reflectorized"],
    &["reflectorised"],
];

pub(crate) static ENTRY_REFLECTORIZES_8900369302482342783: VariantsMap = [
    &["reflectorizes"],
    &["reflectorises"],
    &["reflectorizes"],
    &["reflectorises"],
];

pub(crate) static ENTRY_REFLECTORIZE_10275704482949346236: VariantsMap = [
    &["reflectorize"],
    &["reflectorise"],
    &["reflectorize"],
    &["reflectorise"],
];

pub(crate) static ENTRY_REFLECTORIZING_8154759098223325317: VariantsMap = [
    &["reflectorizing"],
    &["reflectorising"],
    &["reflectorizing"],
    &["reflectorising"],
];

pub(crate) static ENTRY_REFORESTIZATION_9160443628806080238: VariantsMap = [
    &["reforestization"],
    &["reforestisation"],
    &["reforestization"],
    &["reforestisation"],
];

pub(crate) static ENTRY_REFORESTIZES_11290483511697450376: VariantsMap = [
    &["reforestizes"],
    &["reforestises"],
    &["reforestizes"],
    &["reforestises"],
];

pub(crate) static ENTRY_REFORESTIZE_2340774127981028167: VariantsMap = [
    &["reforestize"],
    &["reforestise"],
    &["reforestize"],
    &["reforestise"],
];

pub(crate) static ENTRY_REFORMADES_3091028366731709504: VariantsMap = [
    &["reformades"],
    &["reformadoes"],
    &["reformadoes"],
    &["reformadoes"],
];

pub(crate) static ENTRY_REFUELED_6350295186272675162: VariantsMap = [
    &["refueled"],
    &["refuelled"],
    &["refuelled"],
    &["refuelled"],
];

pub(crate) static ENTRY_REFUELING_13653298214509580404: VariantsMap = [
    &["refueling"],
    &["refuelling"],
    &["refuelling"],
    &["refuelling"],
];

pub(crate) static ENTRY_REGALIZES_11732011390337045014: VariantsMap = [
    &["regalizes"],
    &["regalises"],
    &["regalizes"],
    &["regalises"],
];

pub(crate) static ENTRY_REGALIZE_13206969410028193305: VariantsMap =
    [&["regalize"], &["regalise"], &["regalize"], &["regalise"]];

pub(crate) static ENTRY_REGALVANIZATIONS_6701296608833759714: VariantsMap = [
    &["regalvanizations"],
    &["regalvanisations"],
    &["regalvanizations"],
    &["regalvanisations"],
];

pub(crate) static ENTRY_REGALVANIZATION_17316748002349190251: VariantsMap = [
    &["regalvanization"],
    &["regalvanisation"],
    &["regalvanization"],
    &["regalvanisation"],
];

pub(crate) static ENTRY_REGALVANIZES_4666153610159994761: VariantsMap = [
    &["regalvanizes"],
    &["regalvanises"],
    &["regalvanizes"],
    &["regalvanises"],
];

pub(crate) static ENTRY_REGALVANIZE_13575761445305979993: VariantsMap = [
    &["regalvanize"],
    &["regalvanise"],
    &["regalvanize"],
    &["regalvanise"],
];

pub(crate) static ENTRY_REGES_12087241832921230914: VariantsMap =
    [&["reges"], &["regoes"], &["regoes"], &["regoes"]];

pub(crate) static ENTRY_REGIONALIZATIONS_17188055835713620803: VariantsMap = [
    &["regionalizations"],
    &["regionalisations"],
    &["regionalizations"],
    &["regionalisations"],
];

pub(crate) static ENTRY_REGIONALIZATION_6883441710934248998: VariantsMap = [
    &["regionalization"],
    &["regionalisation"],
    &["regionalization"],
    &["regionalisation"],
];

pub(crate) static ENTRY_REGIONALIZED_5226562196343077794: VariantsMap = [
    &["regionalized"],
    &["regionalised"],
    &["regionalized"],
    &["regionalised"],
];

pub(crate) static ENTRY_REGIONALIZES_15726054798830210051: VariantsMap = [
    &["regionalizes"],
    &["regionalises"],
    &["regionalizes"],
    &["regionalises"],
];

pub(crate) static ENTRY_REGIONALIZE_5480712559619945996: VariantsMap = [
    &["regionalize"],
    &["regionalise"],
    &["regionalize"],
    &["regionalise"],
];

pub(crate) static ENTRY_REGIONALIZING_16531030062440884204: VariantsMap = [
    &["regionalizing"],
    &["regionalising"],
    &["regionalizing"],
    &["regionalising"],
];

pub(crate) static ENTRY_REGULARIZATIONS_17491359825165931567: VariantsMap = [
    &["regularizations"],
    &["regularisations"],
    &["regularizations"],
    &["regularisations"],
];

pub(crate) static ENTRY_REGULARIZATION_15955920955652647734: VariantsMap = [
    &["regularization"],
    &["regularisation"],
    &["regularization"],
    &["regularisation"],
];

pub(crate) static ENTRY_REGULARIZED_16522280649650166951: VariantsMap = [
    &["regularized"],
    &["regularised"],
    &["regularized"],
    &["regularised"],
];

pub(crate) static ENTRY_REGULARIZERS_5127847040742478418: VariantsMap = [
    &["regularizers"],
    &["regularisers"],
    &["regularizers"],
    &["regularisers"],
];

pub(crate) static ENTRY_REGULARIZER_13094146389105795730: VariantsMap = [
    &["regularizer"],
    &["regulariser"],
    &["regularizer"],
    &["regulariser"],
];

pub(crate) static ENTRY_REGULARIZES_16029852279967676023: VariantsMap = [
    &["regularizes"],
    &["regularises"],
    &["regularizes"],
    &["regularises"],
];

pub(crate) static ENTRY_REGULARIZE_7969176896988982612: VariantsMap = [
    &["regularize"],
    &["regularise"],
    &["regularize"],
    &["regularise"],
];

pub(crate) static ENTRY_REGULARIZING_3972227314519446977: VariantsMap = [
    &["regularizing"],
    &["regularising"],
    &["regularizing"],
    &["regularising"],
];

pub(crate) static ENTRY_REGULIZED_14442601898306206117: VariantsMap = [
    &["regulized"],
    &["regulised"],
    &["regulized"],
    &["regulised"],
];

pub(crate) static ENTRY_REGULIZES_7068489394292161911: VariantsMap = [
    &["regulizes"],
    &["regulises"],
    &["regulizes"],
    &["regulises"],
];

pub(crate) static ENTRY_REGULIZE_1184324425868079001: VariantsMap =
    [&["regulize"], &["regulise"], &["regulize"], &["regulise"]];

pub(crate) static ENTRY_REGULIZING_10993526810603007915: VariantsMap = [
    &["regulizing"],
    &["regulising"],
    &["regulizing"],
    &["regulising"],
];

pub(crate) static ENTRY_REHARMONIZATION_12536421913907080148: VariantsMap = [
    &["reharmonization"],
    &["reharmonisation"],
    &["reharmonization"],
    &["reharmonisation"],
];

pub(crate) static ENTRY_REHARMONIZES_7115017876161212459: VariantsMap = [
    &["reharmonizes"],
    &["reharmonises"],
    &["reharmonizes"],
    &["reharmonises"],
];

pub(crate) static ENTRY_REHARMONIZE_13548735377725430821: VariantsMap = [
    &["reharmonize"],
    &["reharmonise"],
    &["reharmonize"],
    &["reharmonise"],
];

pub(crate) static ENTRY_REHM_1954003150274029388: VariantsMap =
    [&["rehm"], &["roehm"], &["roehm"], &["roehm"]];

pub(crate) static ENTRY_REHONORS_4455044786531477320: VariantsMap = [
    &["rehonors"],
    &["rehonours"],
    &["rehonours"],
    &["rehonours"],
];

pub(crate) static ENTRY_REHONOR_10506420481569052180: VariantsMap =
    [&["rehonor"], &["rehonour"], &["rehonour"], &["rehonour"]];

pub(crate) static ENTRY_REHUMANIZATION_823615019743132382: VariantsMap = [
    &["rehumanization"],
    &["rehumanisation"],
    &["rehumanization"],
    &["rehumanisation"],
];

pub(crate) static ENTRY_REHUMANIZES_9376605652523591285: VariantsMap = [
    &["rehumanizes"],
    &["rehumanises"],
    &["rehumanizes"],
    &["rehumanises"],
];

pub(crate) static ENTRY_REHUMANIZE_10181332086255781696: VariantsMap = [
    &["rehumanize"],
    &["rehumanise"],
    &["rehumanize"],
    &["rehumanise"],
];

pub(crate) static ENTRY_REHYBRIDIZES_10629734025595806199: VariantsMap = [
    &["rehybridizes"],
    &["rehybridises"],
    &["rehybridizes"],
    &["rehybridises"],
];

pub(crate) static ENTRY_REHYBRIDIZE_13653700826314235211: VariantsMap = [
    &["rehybridize"],
    &["rehybridise"],
    &["rehybridize"],
    &["rehybridise"],
];

pub(crate) static ENTRY_REINDUSTRIALIZATIONS_9294526708641521678: VariantsMap = [
    &["reindustrializations"],
    &["reindustrialisations"],
    &["reindustrializations"],
    &["reindustrialisations"],
];

pub(crate) static ENTRY_REINDUSTRIALIZATION_14617747281891421599: VariantsMap = [
    &["reindustrialization"],
    &["reindustrialisation"],
    &["reindustrialization"],
    &["reindustrialisation"],
];

pub(crate) static ENTRY_REINDUSTRIALIZED_501582076968778654: VariantsMap = [
    &["reindustrialized"],
    &["reindustrialised"],
    &["reindustrialized"],
    &["reindustrialised"],
];

pub(crate) static ENTRY_REINDUSTRIALIZES_6040168470805305881: VariantsMap = [
    &["reindustrializes"],
    &["reindustrialises"],
    &["reindustrializes"],
    &["reindustrialises"],
];

pub(crate) static ENTRY_REINDUSTRIALIZE_15338922682080771453: VariantsMap = [
    &["reindustrialize"],
    &["reindustrialise"],
    &["reindustrialize"],
    &["reindustrialise"],
];

pub(crate) static ENTRY_REINDUSTRIALIZING_12638875256658078134: VariantsMap = [
    &["reindustrializing"],
    &["reindustrialising"],
    &["reindustrializing"],
    &["reindustrialising"],
];

pub(crate) static ENTRY_REINFORCED_10977672612230158068: VariantsMap = [
    &["reinforced"],
    &["reinforced"],
    &["reinforced"],
    &["reinforced"],
];

pub(crate) static ENTRY_REINFORCES_12402996319523896012: VariantsMap = [
    &["reinforces"],
    &["reinforces"],
    &["reinforces"],
    &["reinforces"],
];

pub(crate) static ENTRY_REINFORCE_15866859185409520783: VariantsMap = [
    &["reinforce"],
    &["reinforce"],
    &["reinforce"],
    &["reinforce"],
];

pub(crate) static ENTRY_REINFORCING_9420906960117208611: VariantsMap = [
    &["reinforcing"],
    &["reinforcing"],
    &["reinforcing"],
    &["reinforcing"],
];

pub(crate) static ENTRY_REINITIALIZATION_8409745411283248302: VariantsMap = [
    &["reinitialization"],
    &["reinitialisation"],
    &["reinitialization"],
    &["reinitialisation"],
];

pub(crate) static ENTRY_REINITIALIZED_5276107785704620977: VariantsMap = [
    &["reinitialized"],
    &["reinitialised"],
    &["reinitialized"],
    &["reinitialised"],
];

pub(crate) static ENTRY_REINITIALIZES_10777259538596408245: VariantsMap = [
    &["reinitializes"],
    &["reinitialises"],
    &["reinitializes"],
    &["reinitialises"],
];

pub(crate) static ENTRY_REINITIALIZE_13966181957218775879: VariantsMap = [
    &["reinitialize"],
    &["reinitialise"],
    &["reinitialize"],
    &["reinitialise"],
];

pub(crate) static ENTRY_REINITIALIZING_2886046725474516411: VariantsMap = [
    &["reinitializing"],
    &["reinitialising"],
    &["reinitializing"],
    &["reinitialising"],
];

pub(crate) static ENTRY_REITEMIZES_371522371959673766: VariantsMap = [
    &["reitemizes"],
    &["reitemises"],
    &["reitemizes"],
    &["reitemises"],
];

pub(crate) static ENTRY_REITEMIZE_16632605337485238276: VariantsMap = [
    &["reitemize"],
    &["reitemise"],
    &["reitemize"],
    &["reitemise"],
];

pub(crate) static ENTRY_REJUVENIZED_8024394360112020134: VariantsMap = [
    &["rejuvenized"],
    &["rejuvenised"],
    &["rejuvenized"],
    &["rejuvenised"],
];

pub(crate) static ENTRY_REJUVENIZES_13596416797841620302: VariantsMap = [
    &["rejuvenizes"],
    &["rejuvenises"],
    &["rejuvenizes"],
    &["rejuvenises"],
];

pub(crate) static ENTRY_REJUVENIZE_15499984299215050232: VariantsMap = [
    &["rejuvenize"],
    &["rejuvenise"],
    &["rejuvenize"],
    &["rejuvenise"],
];

pub(crate) static ENTRY_REJUVENIZING_13051690954489546501: VariantsMap = [
    &["rejuvenizing"],
    &["rejuvenising"],
    &["rejuvenizing"],
    &["rejuvenising"],
];

pub(crate) static ENTRY_RELABELED_10158046552075682397: VariantsMap = [
    &["relabeled"],
    &["relabelled"],
    &["relabelled"],
    &["relabelled"],
];

pub(crate) static ENTRY_RELABELERS_3510633218011220958: VariantsMap = [
    &["relabelers"],
    &["relabellers"],
    &["relabellers"],
    &["relabellers"],
];

pub(crate) static ENTRY_RELABELER_9218654604392185637: VariantsMap = [
    &["relabeler"],
    &["relabeller"],
    &["relabeller"],
    &["relabeller"],
];

pub(crate) static ENTRY_RELABELING_17510567259263942187: VariantsMap = [
    &["relabeling"],
    &["relabelling"],
    &["relabelling"],
    &["relabelling"],
];

pub(crate) static ENTRY_RELATIVIZATIONS_1630960536153392856: VariantsMap = [
    &["relativizations"],
    &["relativisations"],
    &["relativizations"],
    &["relativisations"],
];

pub(crate) static ENTRY_RELATIVIZATION_5661633830317099380: VariantsMap = [
    &["relativization"],
    &["relativisation"],
    &["relativization"],
    &["relativisation"],
];

pub(crate) static ENTRY_RELATIVIZED_2041795511676409313: VariantsMap = [
    &["relativized"],
    &["relativised"],
    &["relativized"],
    &["relativised"],
];

pub(crate) static ENTRY_RELATIVIZES_4604141453046621024: VariantsMap = [
    &["relativizes"],
    &["relativises"],
    &["relativizes"],
    &["relativises"],
];

pub(crate) static ENTRY_RELATIVIZE_17942359056176228223: VariantsMap = [
    &["relativize"],
    &["relativise"],
    &["relativize"],
    &["relativise"],
];

pub(crate) static ENTRY_RELATIVIZING_11299084213627555677: VariantsMap = [
    &["relativizing"],
    &["relativising"],
    &["relativizing"],
    &["relativising"],
];

pub(crate) static ENTRY_RELIGIONIZED_1463181140685954820: VariantsMap = [
    &["religionized"],
    &["religionised"],
    &["religionized"],
    &["religionised"],
];

pub(crate) static ENTRY_RELIGIONIZES_14839970703278120755: VariantsMap = [
    &["religionizes"],
    &["religionises"],
    &["religionizes"],
    &["religionises"],
];

pub(crate) static ENTRY_RELIGIONIZE_6532592146342717831: VariantsMap = [
    &["religionize"],
    &["religionise"],
    &["religionize"],
    &["religionise"],
];

pub(crate) static ENTRY_RELIGIONIZING_9823945316309054025: VariantsMap = [
    &["religionizing"],
    &["religionising"],
    &["religionizing"],
    &["religionising"],
];

pub(crate) static ENTRY_REMAGNETIZATIONS_301607721419429650: VariantsMap = [
    &["remagnetizations"],
    &["remagnetisations"],
    &["remagnetizations"],
    &["remagnetisations"],
];

pub(crate) static ENTRY_REMAGNETIZATION_7449488408017816339: VariantsMap = [
    &["remagnetization"],
    &["remagnetisation"],
    &["remagnetization"],
    &["remagnetisation"],
];

pub(crate) static ENTRY_REMAGNETIZES_11510663723565945487: VariantsMap = [
    &["remagnetizes"],
    &["remagnetises"],
    &["remagnetizes"],
    &["remagnetises"],
];

pub(crate) static ENTRY_REMAGNETIZE_7944947263065196618: VariantsMap = [
    &["remagnetize"],
    &["remagnetise"],
    &["remagnetize"],
    &["remagnetise"],
];

pub(crate) static ENTRY_REMATERIALIZED_5664061553925446220: VariantsMap = [
    &["rematerialized"],
    &["rematerialised"],
    &["rematerialized"],
    &["rematerialised"],
];

pub(crate) static ENTRY_REMATERIALIZES_9384263525573606944: VariantsMap = [
    &["rematerializes"],
    &["rematerialises"],
    &["rematerializes"],
    &["rematerialises"],
];

pub(crate) static ENTRY_REMATERIALIZE_12678282950195083048: VariantsMap = [
    &["rematerialize"],
    &["rematerialise"],
    &["rematerialize"],
    &["rematerialise"],
];

pub(crate) static ENTRY_REMEMORIZES_3334768426875225854: VariantsMap = [
    &["rememorizes"],
    &["rememorises"],
    &["rememorizes"],
    &["rememorises"],
];

pub(crate) static ENTRY_REMEMORIZE_9141700253852689935: VariantsMap = [
    &["rememorize"],
    &["rememorise"],
    &["rememorize"],
    &["rememorise"],
];

pub(crate) static ENTRY_REMILITARIZATIONS_14597687455768382338: VariantsMap = [
    &["remilitarizations"],
    &["remilitarisations"],
    &["remilitarizations"],
    &["remilitarisations"],
];

pub(crate) static ENTRY_REMILITARIZATION_11523126169071197406: VariantsMap = [
    &["remilitarization"],
    &["remilitarisation"],
    &["remilitarization"],
    &["remilitarisation"],
];

pub(crate) static ENTRY_REMILITARIZED_11554404031299874708: VariantsMap = [
    &["remilitarized"],
    &["remilitarised"],
    &["remilitarized"],
    &["remilitarised"],
];

pub(crate) static ENTRY_REMILITARIZES_940580432740816145: VariantsMap = [
    &["remilitarizes"],
    &["remilitarises"],
    &["remilitarizes"],
    &["remilitarises"],
];

pub(crate) static ENTRY_REMILITARIZE_18288519237186766997: VariantsMap = [
    &["remilitarize"],
    &["remilitarise"],
    &["remilitarize"],
    &["remilitarise"],
];

pub(crate) static ENTRY_REMILITARIZING_4173334694500632492: VariantsMap = [
    &["remilitarizing"],
    &["remilitarising"],
    &["remilitarizing"],
    &["remilitarising"],
];

pub(crate) static ENTRY_REMINERALIZATIONS_13810098978375898404: VariantsMap = [
    &["remineralizations"],
    &["remineralisations"],
    &["remineralizations"],
    &["remineralisations"],
];

pub(crate) static ENTRY_REMINERALIZATION_9915243010575985238: VariantsMap = [
    &["remineralization"],
    &["remineralisation"],
    &["remineralization"],
    &["remineralisation"],
];

pub(crate) static ENTRY_REMINERALIZED_3026252061420046310: VariantsMap = [
    &["remineralized"],
    &["remineralised"],
    &["remineralized"],
    &["remineralised"],
];

pub(crate) static ENTRY_REMINERALIZES_17167344080905173349: VariantsMap = [
    &["remineralizes"],
    &["remineralises"],
    &["remineralizes"],
    &["remineralises"],
];

pub(crate) static ENTRY_REMINERALIZE_4937501175287881412: VariantsMap = [
    &["remineralize"],
    &["remineralise"],
    &["remineralize"],
    &["remineralise"],
];

pub(crate) static ENTRY_REMINERALIZING_15635899904434541758: VariantsMap = [
    &["remineralizing"],
    &["remineralising"],
    &["remineralizing"],
    &["remineralising"],
];

pub(crate) static ENTRY_REMOBILIZATIONS_11227586492863758304: VariantsMap = [
    &["remobilizations"],
    &["remobilisations"],
    &["remobilizations"],
    &["remobilisations"],
];

pub(crate) static ENTRY_REMOBILIZATION_6261107144969557050: VariantsMap = [
    &["remobilization"],
    &["remobilisation"],
    &["remobilization"],
    &["remobilisation"],
];

pub(crate) static ENTRY_REMOBILIZES_12377835762207128096: VariantsMap = [
    &["remobilizes"],
    &["remobilises"],
    &["remobilizes"],
    &["remobilises"],
];

pub(crate) static ENTRY_REMOBILIZE_923807659543256995: VariantsMap = [
    &["remobilize"],
    &["remobilise"],
    &["remobilize"],
    &["remobilise"],
];

pub(crate) static ENTRY_REMODELED_11951619598691255997: VariantsMap = [
    &["remodeled"],
    &["remodelled"],
    &["remodelled"],
    &["remodelled"],
];

pub(crate) static ENTRY_REMODELING_5571366996719584181: VariantsMap = [
    &["remodeling"],
    &["remodelling"],
    &["remodelling"],
    &["remodelling"],
];

pub(crate) static ENTRY_REMOLDED_18050524398894974310: VariantsMap = [
    &["remolded"],
    &["remoulded"],
    &["remoulded"],
    &["remoulded"],
];

pub(crate) static ENTRY_REMOLDING_6944457580128330593: VariantsMap = [
    &["remolding"],
    &["remoulding"],
    &["remoulding"],
    &["remoulding"],
];

pub(crate) static ENTRY_REMOLDS_1959267912662850297: VariantsMap =
    [&["remolds"], &["remoulds"], &["remoulds"], &["remoulds"]];

pub(crate) static ENTRY_REMOLD_2526819628693250098: VariantsMap =
    [&["remold"], &["remould"], &["remould"], &["remould"]];

pub(crate) static ENTRY_REMONETIZATIONS_5697855088114742500: VariantsMap = [
    &["remonetizations"],
    &["remonetisations"],
    &["remonetizations"],
    &["remonetisations"],
];

pub(crate) static ENTRY_REMONETIZATION_212742877311562271: VariantsMap = [
    &["remonetization"],
    &["remonetisation"],
    &["remonetization"],
    &["remonetisation"],
];

pub(crate) static ENTRY_REMONETIZED_7157192020575645575: VariantsMap = [
    &["remonetized"],
    &["remonetised"],
    &["remonetized"],
    &["remonetised"],
];

pub(crate) static ENTRY_REMONETIZES_10479599926916307809: VariantsMap = [
    &["remonetizes"],
    &["remonetises"],
    &["remonetizes"],
    &["remonetises"],
];

pub(crate) static ENTRY_REMONETIZE_10588050293708931308: VariantsMap = [
    &["remonetize"],
    &["remonetise"],
    &["remonetize"],
    &["remonetise"],
];

pub(crate) static ENTRY_REMONETIZING_11312258848004221079: VariantsMap = [
    &["remonetizing"],
    &["remonetising"],
    &["remonetizing"],
    &["remonetising"],
];

pub(crate) static ENTRY_REMORALIZATIONS_5269456965430948283: VariantsMap = [
    &["remoralizations"],
    &["remoralisations"],
    &["remoralizations"],
    &["remoralisations"],
];

pub(crate) static ENTRY_REMORALIZATION_14016073140723680519: VariantsMap = [
    &["remoralization"],
    &["remoralisation"],
    &["remoralization"],
    &["remoralisation"],
];

pub(crate) static ENTRY_REMORALIZED_16025093535995812890: VariantsMap = [
    &["remoralized"],
    &["remoralised"],
    &["remoralized"],
    &["remoralised"],
];

pub(crate) static ENTRY_REMORALIZES_11138700545539530334: VariantsMap = [
    &["remoralizes"],
    &["remoralises"],
    &["remoralizes"],
    &["remoralises"],
];

pub(crate) static ENTRY_REMORALIZE_8012535825718652462: VariantsMap = [
    &["remoralize"],
    &["remoralise"],
    &["remoralize"],
    &["remoralise"],
];

pub(crate) static ENTRY_REMORALIZING_5859909096957765153: VariantsMap = [
    &["remoralizing"],
    &["remoralising"],
    &["remoralizing"],
    &["remoralising"],
];

pub(crate) static ENTRY_RENATIONALIZED_245883000485081396: VariantsMap = [
    &["renationalized"],
    &["renationalised"],
    &["renationalized"],
    &["renationalised"],
];

pub(crate) static ENTRY_RENATIONALIZES_15008886789696665182: VariantsMap = [
    &["renationalizes"],
    &["renationalises"],
    &["renationalizes"],
    &["renationalises"],
];

pub(crate) static ENTRY_RENATIONALIZE_13763420489757292678: VariantsMap = [
    &["renationalize"],
    &["renationalise"],
    &["renationalize"],
    &["renationalise"],
];

pub(crate) static ENTRY_RENATIONALIZING_528289503767142524: VariantsMap = [
    &["renationalizing"],
    &["renationalising"],
    &["renationalizing"],
    &["renationalising"],
];

pub(crate) static ENTRY_RENCOUNTER_17790527784370805465: VariantsMap = [
    &["rencounter"],
    &["rencontre"],
    &["rencontre"],
    &["rencontre"],
];

pub(crate) static ENTRY_RENFERD_5332380987373616326: VariantsMap =
    [&["renferd"], &["renfred"], &["renfred"], &["renfred"]];

pub(crate) static ENTRY_RENORMALIZATIONS_6818740031112910643: VariantsMap = [
    &["renormalizations"],
    &["renormalisations"],
    &["renormalizations"],
    &["renormalisations"],
];

pub(crate) static ENTRY_RENORMALIZATION_9891230551808040808: VariantsMap = [
    &["renormalization"],
    &["renormalisation"],
    &["renormalization"],
    &["renormalisation"],
];

pub(crate) static ENTRY_RENORMALIZED_12583163063216549053: VariantsMap = [
    &["renormalized"],
    &["renormalised"],
    &["renormalized"],
    &["renormalised"],
];

pub(crate) static ENTRY_RENORMALIZES_12053503023445454685: VariantsMap = [
    &["renormalizes"],
    &["renormalises"],
    &["renormalizes"],
    &["renormalises"],
];

pub(crate) static ENTRY_RENORMALIZE_4228995450916847764: VariantsMap = [
    &["renormalize"],
    &["renormalise"],
    &["renormalize"],
    &["renormalise"],
];

pub(crate) static ENTRY_RENORMALIZING_4696927106111124982: VariantsMap = [
    &["renormalizing"],
    &["renormalising"],
    &["renormalizing"],
    &["renormalising"],
];

pub(crate) static ENTRY_REOBJECTIVIZATIONS_484037855015245777: VariantsMap = [
    &["reobjectivizations"],
    &["reobjectivisations"],
    &["reobjectivizations"],
    &["reobjectivisations"],
];

pub(crate) static ENTRY_REOBJECTIVIZATION_9934627242133960188: VariantsMap = [
    &["reobjectivization"],
    &["reobjectivisation"],
    &["reobjectivization"],
    &["reobjectivisation"],
];

pub(crate) static ENTRY_REOBJECTIVIZES_2442086806688158809: VariantsMap = [
    &["reobjectivizes"],
    &["reobjectivises"],
    &["reobjectivizes"],
    &["reobjectivises"],
];

pub(crate) static ENTRY_REOBJECTIVIZE_4586321694839316243: VariantsMap = [
    &["reobjectivize"],
    &["reobjectivise"],
    &["reobjectivize"],
    &["reobjectivise"],
];

pub(crate) static ENTRY_REORGANIZATIONAL_10984641565360643637: VariantsMap = [
    &["reorganizational"],
    &["reorganisational"],
    &["reorganizational"],
    &["reorganisational"],
];

pub(crate) static ENTRY_REORGANIZATIONISTS_10384586979829403733: VariantsMap = [
    &["reorganizationists"],
    &["reorganisationists"],
    &["reorganizationists"],
    &["reorganisationists"],
];

pub(crate) static ENTRY_REORGANIZATIONIST_11925492221252212415: VariantsMap = [
    &["reorganizationist"],
    &["reorganisationist"],
    &["reorganizationist"],
    &["reorganisationist"],
];

pub(crate) static ENTRY_REORGANIZATIONS_3908357981488387825: VariantsMap = [
    &["reorganizations"],
    &["reorganisations"],
    &["reorganizations"],
    &["reorganisations"],
];

pub(crate) static ENTRY_REORGANIZATION_8169886605299414196: VariantsMap = [
    &["reorganization"],
    &["reorganisation"],
    &["reorganization"],
    &["reorganisation"],
];

pub(crate) static ENTRY_REORGANIZED_5774790920194407083: VariantsMap = [
    &["reorganized"],
    &["reorganised"],
    &["reorganized"],
    &["reorganised"],
];

pub(crate) static ENTRY_REORGANIZERS_9885992780785484737: VariantsMap = [
    &["reorganizers"],
    &["reorganisers"],
    &["reorganizers"],
    &["reorganisers"],
];

pub(crate) static ENTRY_REORGANIZER_2092510006819704008: VariantsMap = [
    &["reorganizer"],
    &["reorganiser"],
    &["reorganizer"],
    &["reorganiser"],
];

pub(crate) static ENTRY_REORGANIZES_3740948184951472727: VariantsMap = [
    &["reorganizes"],
    &["reorganises"],
    &["reorganizes"],
    &["reorganises"],
];

pub(crate) static ENTRY_REORGANIZE_18181270914612994788: VariantsMap = [
    &["reorganize"],
    &["reorganise"],
    &["reorganize"],
    &["reorganise"],
];

pub(crate) static ENTRY_REORGANIZING_15784567964948699452: VariantsMap = [
    &["reorganizing"],
    &["reorganising"],
    &["reorganizing"],
    &["reorganising"],
];

pub(crate) static ENTRY_REOXIDIZED_13705047693863706297: VariantsMap = [
    &["reoxidized"],
    &["reoxidised"],
    &["reoxidized"],
    &["reoxidised"],
];

pub(crate) static ENTRY_REOXIDIZES_14522324553215140631: VariantsMap = [
    &["reoxidizes"],
    &["reoxidises"],
    &["reoxidizes"],
    &["reoxidises"],
];

pub(crate) static ENTRY_REOXIDIZE_4983823425119723374: VariantsMap = [
    &["reoxidize"],
    &["reoxidise"],
    &["reoxidize"],
    &["reoxidise"],
];

pub(crate) static ENTRY_REOXIDIZING_18024783650819146058: VariantsMap = [
    &["reoxidizing"],
    &["reoxidising"],
    &["reoxidizing"],
    &["reoxidising"],
];

pub(crate) static ENTRY_REOXYGENIZES_17640431467346669041: VariantsMap = [
    &["reoxygenizes"],
    &["reoxygenises"],
    &["reoxygenizes"],
    &["reoxygenises"],
];

pub(crate) static ENTRY_REOXYGENIZE_6926836183647945085: VariantsMap = [
    &["reoxygenize"],
    &["reoxygenise"],
    &["reoxygenize"],
    &["reoxygenise"],
];

pub(crate) static ENTRY_REPAGANIZATIONS_11524549005753966827: VariantsMap = [
    &["repaganizations"],
    &["repaganisations"],
    &["repaganizations"],
    &["repaganisations"],
];

pub(crate) static ENTRY_REPAGANIZATION_17048111709890154504: VariantsMap = [
    &["repaganization"],
    &["repaganisation"],
    &["repaganization"],
    &["repaganisation"],
];

pub(crate) static ENTRY_REPAGANIZERS_1945767306900866182: VariantsMap = [
    &["repaganizers"],
    &["repaganisers"],
    &["repaganizers"],
    &["repaganisers"],
];

pub(crate) static ENTRY_REPAGANIZER_6412817561993591645: VariantsMap = [
    &["repaganizer"],
    &["repaganiser"],
    &["repaganizer"],
    &["repaganiser"],
];

pub(crate) static ENTRY_REPAGANIZES_9803449503187685243: VariantsMap = [
    &["repaganizes"],
    &["repaganises"],
    &["repaganizes"],
    &["repaganises"],
];

pub(crate) static ENTRY_REPAGANIZE_12973755742278560404: VariantsMap = [
    &["repaganize"],
    &["repaganise"],
    &["repaganize"],
    &["repaganise"],
];

pub(crate) static ENTRY_REPATRONIZES_15919891777429804526: VariantsMap = [
    &["repatronizes"],
    &["repatronises"],
    &["repatronizes"],
    &["repatronises"],
];

pub(crate) static ENTRY_REPATRONIZE_14079123483159349622: VariantsMap = [
    &["repatronize"],
    &["repatronise"],
    &["repatronize"],
    &["repatronise"],
];

pub(crate) static ENTRY_REPERSONALIZE_6974920904850829865: VariantsMap = [
    &["repersonalize"],
    &["repersonalise"],
    &["repersonalize"],
    &["repersonalise"],
];

pub(crate) static ENTRY_REPHOSPHORIZATIONS_10501113871961153156: VariantsMap = [
    &["rephosphorizations"],
    &["rephosphorisations"],
    &["rephosphorizations"],
    &["rephosphorisations"],
];

pub(crate) static ENTRY_REPHOSPHORIZATION_1249759851309425020: VariantsMap = [
    &["rephosphorization"],
    &["rephosphorisation"],
    &["rephosphorization"],
    &["rephosphorisation"],
];

pub(crate) static ENTRY_REPHOSPHORIZES_17888482873852406388: VariantsMap = [
    &["rephosphorizes"],
    &["rephosphorises"],
    &["rephosphorizes"],
    &["rephosphorises"],
];

pub(crate) static ENTRY_REPHOSPHORIZE_419529770369265116: VariantsMap = [
    &["rephosphorize"],
    &["rephosphorise"],
    &["rephosphorize"],
    &["rephosphorise"],
];

pub(crate) static ENTRY_REPOLYMERIZATIONS_5935058147340822679: VariantsMap = [
    &["repolymerizations"],
    &["repolymerisations"],
    &["repolymerizations"],
    &["repolymerisations"],
];

pub(crate) static ENTRY_REPOLYMERIZATION_4016733859370100512: VariantsMap = [
    &["repolymerization"],
    &["repolymerisation"],
    &["repolymerization"],
    &["repolymerisation"],
];

pub(crate) static ENTRY_REPOLYMERIZES_278489027229578119: VariantsMap = [
    &["repolymerizes"],
    &["repolymerises"],
    &["repolymerizes"],
    &["repolymerises"],
];

pub(crate) static ENTRY_REPOLYMERIZE_9036336021273167586: VariantsMap = [
    &["repolymerize"],
    &["repolymerise"],
    &["repolymerize"],
    &["repolymerise"],
];

pub(crate) static ENTRY_REPOPULARIZE_9953057472377229635: VariantsMap = [
    &["repopularize"],
    &["repopularise"],
    &["repopularize"],
    &["repopularise"],
];

pub(crate) static ENTRY_REPRIVATIZATIONS_14878285207711233234: VariantsMap = [
    &["reprivatizations"],
    &["reprivatisations"],
    &["reprivatizations"],
    &["reprivatisations"],
];

pub(crate) static ENTRY_REPRIVATIZATION_13650773811954050943: VariantsMap = [
    &["reprivatization"],
    &["reprivatisation"],
    &["reprivatization"],
    &["reprivatisation"],
];

pub(crate) static ENTRY_REPRIVATIZED_12098289997527637409: VariantsMap = [
    &["reprivatized"],
    &["reprivatised"],
    &["reprivatized"],
    &["reprivatised"],
];

pub(crate) static ENTRY_REPRIVATIZES_16228664850321170772: VariantsMap = [
    &["reprivatizes"],
    &["reprivatises"],
    &["reprivatizes"],
    &["reprivatises"],
];

pub(crate) static ENTRY_REPRIVATIZE_5415509619751214059: VariantsMap = [
    &["reprivatize"],
    &["reprivatise"],
    &["reprivatize"],
    &["reprivatise"],
];

pub(crate) static ENTRY_REPRIVATIZING_12815705532271804492: VariantsMap = [
    &["reprivatizing"],
    &["reprivatising"],
    &["reprivatizing"],
    &["reprivatising"],
];

pub(crate) static ENTRY_REPRIZED_7288407637875600947: VariantsMap =
    [&["reprized"], &["reprised"], &["reprized"], &["reprised"]];

pub(crate) static ENTRY_REPROGRAMS_14411569368989355062: VariantsMap = [
    &["reprograms"],
    &["reprograms"],
    &["reprograms"],
    &["reprograms"],
];

pub(crate) static ENTRY_REPROGRAM_4774339528962451273: VariantsMap = [
    &["reprogram"],
    &["reprogram"],
    &["reprogram"],
    &["reprogram"],
];

pub(crate) static ENTRY_REPUBLICANIZATIONS_383652106092527995: VariantsMap = [
    &["republicanizations"],
    &["republicanisations"],
    &["republicanizations"],
    &["republicanisations"],
];

pub(crate) static ENTRY_REPUBLICANIZATION_1944426904861411795: VariantsMap = [
    &["republicanization"],
    &["republicanisation"],
    &["republicanization"],
    &["republicanisation"],
];

pub(crate) static ENTRY_REPUBLICANIZED_580437874147385001: VariantsMap = [
    &["republicanized"],
    &["republicanised"],
    &["republicanized"],
    &["republicanised"],
];

pub(crate) static ENTRY_REPUBLICANIZERS_15251018630663619701: VariantsMap = [
    &["republicanizers"],
    &["republicanisers"],
    &["republicanizers"],
    &["republicanisers"],
];

pub(crate) static ENTRY_REPUBLICANIZER_18381174866390455070: VariantsMap = [
    &["republicanizer"],
    &["republicaniser"],
    &["republicanizer"],
    &["republicaniser"],
];

pub(crate) static ENTRY_REPUBLICANIZES_7718357541376368950: VariantsMap = [
    &["republicanizes"],
    &["republicanises"],
    &["republicanizes"],
    &["republicanises"],
];

pub(crate) static ENTRY_REPUBLICANIZE_10386133133725020930: VariantsMap = [
    &["republicanize"],
    &["republicanise"],
    &["republicanize"],
    &["republicanise"],
];

pub(crate) static ENTRY_REPUBLICANIZING_8829607189097248923: VariantsMap = [
    &["republicanizing"],
    &["republicanising"],
    &["republicanizing"],
    &["republicanising"],
];

pub(crate) static ENTRY_REPULVERIZES_16864243522912897832: VariantsMap = [
    &["repulverizes"],
    &["repulverises"],
    &["repulverizes"],
    &["repulverises"],
];

pub(crate) static ENTRY_REPULVERIZE_7976316581557319006: VariantsMap = [
    &["repulverize"],
    &["repulverise"],
    &["repulverize"],
    &["repulverise"],
];

pub(crate) static ENTRY_REROYALIZES_658053808235761746: VariantsMap = [
    &["reroyalizes"],
    &["reroyalises"],
    &["reroyalizes"],
    &["reroyalises"],
];

pub(crate) static ENTRY_REROYALIZE_9299210178122090712: VariantsMap = [
    &["reroyalize"],
    &["reroyalise"],
    &["reroyalize"],
    &["reroyalise"],
];

pub(crate) static ENTRY_RESEIZER_14462609884001927595: VariantsMap =
    [&["reseizer"], &["reseiser"], &["reseizer"], &["reseiser"]];

pub(crate) static ENTRY_RESEIZE_11829660618323635615: VariantsMap =
    [&["reseize"], &["reseise"], &["reseize"], &["reseise"]];

pub(crate) static ENTRY_RESENSITIZATIONS_919995710981311836: VariantsMap = [
    &["resensitizations"],
    &["resensitisations"],
    &["resensitizations"],
    &["resensitisations"],
];

pub(crate) static ENTRY_RESENSITIZATION_3685514235786941102: VariantsMap = [
    &["resensitization"],
    &["resensitisation"],
    &["resensitization"],
    &["resensitisation"],
];

pub(crate) static ENTRY_RESENSITIZES_12908617404622953233: VariantsMap = [
    &["resensitizes"],
    &["resensitises"],
    &["resensitizes"],
    &["resensitises"],
];

pub(crate) static ENTRY_RESENSITIZE_1303613677297439531: VariantsMap = [
    &["resensitize"],
    &["resensitise"],
    &["resensitize"],
    &["resensitise"],
];

pub(crate) static ENTRY_RESEPULCHERS_6740248117563664747: VariantsMap = [
    &["resepulchers"],
    &["resepulchres"],
    &["resepulchres"],
    &["resepulchres"],
];

pub(crate) static ENTRY_RESEPULCHER_13255687324173800374: VariantsMap = [
    &["resepulcher"],
    &["resepulchre"],
    &["resepulchre"],
    &["resepulchre"],
];

pub(crate) static ENTRY_RESHES_14193366709422680589: VariantsMap =
    [&["reshes"], &["reshoes"], &["reshoes"], &["reshoes"]];

pub(crate) static ENTRY_RESINIZED_13345987737745617709: VariantsMap = [
    &["resinized"],
    &["resinised"],
    &["resinized"],
    &["resinised"],
];

pub(crate) static ENTRY_RESINIZES_7409295825688368205: VariantsMap = [
    &["resinizes"],
    &["resinises"],
    &["resinizes"],
    &["resinises"],
];

pub(crate) static ENTRY_RESINIZE_14451332919662209430: VariantsMap =
    [&["resinize"], &["resinise"], &["resinize"], &["resinise"]];

pub(crate) static ENTRY_RESINIZING_7347311689783160837: VariantsMap = [
    &["resinizing"],
    &["resinising"],
    &["resinizing"],
    &["resinising"],
];

pub(crate) static ENTRY_RESOLEMNIZES_10613919753057256614: VariantsMap = [
    &["resolemnizes"],
    &["resolemnises"],
    &["resolemnizes"],
    &["resolemnises"],
];

pub(crate) static ENTRY_RESOLEMNIZE_6056068872801503882: VariantsMap = [
    &["resolemnize"],
    &["resolemnise"],
    &["resolemnize"],
    &["resolemnise"],
];

pub(crate) static ENTRY_RESPECTABILIZED_14730970511118216639: VariantsMap = [
    &["respectabilized"],
    &["respectabilised"],
    &["respectabilized"],
    &["respectabilised"],
];

pub(crate) static ENTRY_RESPECTABILIZES_14602704037450130293: VariantsMap = [
    &["respectabilizes"],
    &["respectabilises"],
    &["respectabilizes"],
    &["respectabilises"],
];

pub(crate) static ENTRY_RESPECTABILIZE_11155380117077366918: VariantsMap = [
    &["respectabilize"],
    &["respectabilise"],
    &["respectabilize"],
    &["respectabilise"],
];

pub(crate) static ENTRY_RESPECTABILIZING_10915529601473940175: VariantsMap = [
    &["respectabilizing"],
    &["respectabilising"],
    &["respectabilizing"],
    &["respectabilising"],
];

pub(crate) static ENTRY_RESTANDARDIZATIONS_13459493042218397698: VariantsMap = [
    &["restandardizations"],
    &["restandardisations"],
    &["restandardizations"],
    &["restandardisations"],
];

pub(crate) static ENTRY_RESTANDARDIZATION_1125896047095372970: VariantsMap = [
    &["restandardization"],
    &["restandardisation"],
    &["restandardization"],
    &["restandardisation"],
];

pub(crate) static ENTRY_RESTANDARDIZES_16671190134442482587: VariantsMap = [
    &["restandardizes"],
    &["restandardises"],
    &["restandardizes"],
    &["restandardises"],
];

pub(crate) static ENTRY_RESTANDARDIZE_8395056711505036016: VariantsMap = [
    &["restandardize"],
    &["restandardise"],
    &["restandardize"],
    &["restandardise"],
];

pub(crate) static ENTRY_RESTERILIZES_6083780946048684800: VariantsMap = [
    &["resterilizes"],
    &["resterilises"],
    &["resterilizes"],
    &["resterilises"],
];

pub(crate) static ENTRY_RESTERILIZE_4378046269917637799: VariantsMap = [
    &["resterilize"],
    &["resterilise"],
    &["resterilize"],
    &["resterilise"],
];

pub(crate) static ENTRY_RESTIGMATIZES_6711731024062346456: VariantsMap = [
    &["restigmatizes"],
    &["restigmatises"],
    &["restigmatizes"],
    &["restigmatises"],
];

pub(crate) static ENTRY_RESTIGMATIZE_4978105981890694357: VariantsMap = [
    &["restigmatize"],
    &["restigmatise"],
    &["restigmatize"],
    &["restigmatise"],
];

pub(crate) static ENTRY_RESURRECTIONIZED_9400111854395469022: VariantsMap = [
    &["resurrectionized"],
    &["resurrectionised"],
    &["resurrectionized"],
    &["resurrectionised"],
];

pub(crate) static ENTRY_RESURRECTIONIZES_13187140164794979295: VariantsMap = [
    &["resurrectionizes"],
    &["resurrectionises"],
    &["resurrectionizes"],
    &["resurrectionises"],
];

pub(crate) static ENTRY_RESURRECTIONIZE_6291356889036253818: VariantsMap = [
    &["resurrectionize"],
    &["resurrectionise"],
    &["resurrectionize"],
    &["resurrectionise"],
];

pub(crate) static ENTRY_RESURRECTIONIZING_691774540853612989: VariantsMap = [
    &["resurrectionizing"],
    &["resurrectionising"],
    &["resurrectionizing"],
    &["resurrectionising"],
];

pub(crate) static ENTRY_RESYMBOLIZATIONS_13698200804085478042: VariantsMap = [
    &["resymbolizations"],
    &["resymbolisations"],
    &["resymbolizations"],
    &["resymbolisations"],
];

pub(crate) static ENTRY_RESYMBOLIZATION_18289962759086702120: VariantsMap = [
    &["resymbolization"],
    &["resymbolisation"],
    &["resymbolization"],
    &["resymbolisation"],
];

pub(crate) static ENTRY_RESYMBOLIZES_15380238287856922249: VariantsMap = [
    &["resymbolizes"],
    &["resymbolises"],
    &["resymbolizes"],
    &["resymbolises"],
];

pub(crate) static ENTRY_RESYMBOLIZE_14905039520367290035: VariantsMap = [
    &["resymbolize"],
    &["resymbolise"],
    &["resymbolize"],
    &["resymbolise"],
];

pub(crate) static ENTRY_RESYNCHRONIZATIONS_15270865884370608060: VariantsMap = [
    &["resynchronizations"],
    &["resynchronisations"],
    &["resynchronizations"],
    &["resynchronisations"],
];

pub(crate) static ENTRY_RESYNCHRONIZATION_5015538818065006720: VariantsMap = [
    &["resynchronization"],
    &["resynchronisation"],
    &["resynchronization"],
    &["resynchronisation"],
];

pub(crate) static ENTRY_RESYNCHRONIZED_3132801989882471857: VariantsMap = [
    &["resynchronized"],
    &["resynchronised"],
    &["resynchronized"],
    &["resynchronised"],
];

pub(crate) static ENTRY_RESYNCHRONIZES_5801125742459097915: VariantsMap = [
    &["resynchronizes"],
    &["resynchronises"],
    &["resynchronizes"],
    &["resynchronises"],
];

pub(crate) static ENTRY_RESYNCHRONIZE_2523532124129456381: VariantsMap = [
    &["resynchronize"],
    &["resynchronise"],
    &["resynchronize"],
    &["resynchronise"],
];

pub(crate) static ENTRY_RESYNCHRONIZING_2324560686252943876: VariantsMap = [
    &["resynchronizing"],
    &["resynchronising"],
    &["resynchronizing"],
    &["resynchronising"],
];

pub(crate) static ENTRY_RESYNTHESIZES_5964175748046341312: VariantsMap = [
    &["resynthesizes"],
    &["resynthesises"],
    &["resynthesizes"],
    &["resynthesises"],
];

pub(crate) static ENTRY_RESYNTHESIZE_8960121186358208467: VariantsMap = [
    &["resynthesize"],
    &["resynthesise"],
    &["resynthesize"],
    &["resynthesise"],
];

pub(crate) static ENTRY_RETINIZES_17069507706296598945: VariantsMap = [
    &["retinizes"],
    &["retinises"],
    &["retinizes"],
    &["retinises"],
];

pub(crate) static ENTRY_RETINIZE_8601446109320109567: VariantsMap =
    [&["retinize"], &["retinise"], &["retinize"], &["retinise"]];

pub(crate) static ENTRY_RETINULE_17387772655780198016: VariantsMap = [
    &["retinule"],
    &["retinulae"],
    &["retinulae"],
    &["retinulae"],
];

pub(crate) static ENTRY_RETRANQUILIZES_11477435536722915071: VariantsMap = [
    &["retranquilizes"],
    &["retranquilises"],
    &["retranquilizes"],
    &["retranquilises"],
];

pub(crate) static ENTRY_RETRANQUILIZE_10089381173173353384: VariantsMap = [
    &["retranquilize"],
    &["retranquilise"],
    &["retranquilize"],
    &["retranquilise"],
];

pub(crate) static ENTRY_RETROCECAL_264766737757922842: VariantsMap = [
    &["retrocecal"],
    &["retrocaecal"],
    &["retrocaecal"],
    &["retrocaecal"],
];

pub(crate) static ENTRY_REUTILIZATION_2443696530088053698: VariantsMap = [
    &["reutilization"],
    &["reutilisation"],
    &["reutilization"],
    &["reutilisation"],
];

pub(crate) static ENTRY_REUTILIZED_16677084184753064782: VariantsMap = [
    &["reutilized"],
    &["reutilised"],
    &["reutilized"],
    &["reutilised"],
];

pub(crate) static ENTRY_REUTILIZES_14294564954952197276: VariantsMap = [
    &["reutilizes"],
    &["reutilises"],
    &["reutilizes"],
    &["reutilises"],
];

pub(crate) static ENTRY_REUTILIZE_1981534996476836105: VariantsMap = [
    &["reutilize"],
    &["reutilise"],
    &["reutilize"],
    &["reutilise"],
];

pub(crate) static ENTRY_REUTILIZING_4912219485422295764: VariantsMap = [
    &["reutilizing"],
    &["reutilising"],
    &["reutilizing"],
    &["reutilising"],
];

pub(crate) static ENTRY_REVALORIZATIONS_8329585362057485832: VariantsMap = [
    &["revalorizations"],
    &["revalorisations"],
    &["revalorizations"],
    &["revalorisations"],
];

pub(crate) static ENTRY_REVALORIZATION_16691637355795598388: VariantsMap = [
    &["revalorization"],
    &["revalorisation"],
    &["revalorization"],
    &["revalorisation"],
];

pub(crate) static ENTRY_REVALORIZED_390002619883458956: VariantsMap = [
    &["revalorized"],
    &["revalorised"],
    &["revalorized"],
    &["revalorised"],
];

pub(crate) static ENTRY_REVALORIZES_9002308862045152018: VariantsMap = [
    &["revalorizes"],
    &["revalorises"],
    &["revalorizes"],
    &["revalorises"],
];

pub(crate) static ENTRY_REVALORIZE_2146865524723286062: VariantsMap = [
    &["revalorize"],
    &["revalorise"],
    &["revalorize"],
    &["revalorise"],
];

pub(crate) static ENTRY_REVALORIZING_15461035195176448361: VariantsMap = [
    &["revalorizing"],
    &["revalorising"],
    &["revalorizing"],
    &["revalorising"],
];

pub(crate) static ENTRY_REVAPORIZATIONS_5789264572660925070: VariantsMap = [
    &["revaporizations"],
    &["revapourisations"],
    &["revaporizations"],
    &["revapourisations"],
];

pub(crate) static ENTRY_REVAPORIZATION_13446372973926423118: VariantsMap = [
    &["revaporization"],
    &["revapourisation"],
    &["revaporization"],
    &["revapourisation"],
];

pub(crate) static ENTRY_REVAPORIZES_10059326494130071423: VariantsMap = [
    &["revaporizes"],
    &["revaporises"],
    &["revaporizes"],
    &["revaporises"],
];

pub(crate) static ENTRY_REVAPORIZE_7400570187982142267: VariantsMap = [
    &["revaporize"],
    &["revaporise"],
    &["revaporize"],
    &["revaporise"],
];

pub(crate) static ENTRY_REVELATIONIZES_5374780340001639912: VariantsMap = [
    &["revelationizes"],
    &["revelationises"],
    &["revelationizes"],
    &["revelationises"],
];

pub(crate) static ENTRY_REVELATIONIZE_5638146163757517114: VariantsMap = [
    &["revelationize"],
    &["revelationise"],
    &["revelationize"],
    &["revelationise"],
];

pub(crate) static ENTRY_REVELED_3269597357727386753: VariantsMap =
    [&["reveled"], &["revelled"], &["revelled"], &["revelled"]];

pub(crate) static ENTRY_REVELERS_6407829396102668960: VariantsMap = [
    &["revelers"],
    &["revellers"],
    &["revellers"],
    &["revellers"],
];

pub(crate) static ENTRY_REVELER_6411534393495033889: VariantsMap =
    [&["reveler"], &["reveller"], &["reveller"], &["reveller"]];

pub(crate) static ENTRY_REVELINGS_14514277807211085480: VariantsMap = [
    &["revelings"],
    &["revellings"],
    &["revellings"],
    &["revellings"],
];

pub(crate) static ENTRY_REVELING_7333428498196314928: VariantsMap = [
    &["reveling"],
    &["revelling"],
    &["revelling"],
    &["revelling"],
];

pub(crate) static ENTRY_REVIGOR_2376178882147635752: VariantsMap =
    [&["revigor"], &["revigour"], &["revigour"], &["revigour"]];

pub(crate) static ENTRY_REVISUALIZATIONS_5722856801090540723: VariantsMap = [
    &["revisualizations"],
    &["revisualisations"],
    &["revisualizations"],
    &["revisualisations"],
];

pub(crate) static ENTRY_REVISUALIZATION_8953713191827785558: VariantsMap = [
    &["revisualization"],
    &["revisualisation"],
    &["revisualization"],
    &["revisualisation"],
];

pub(crate) static ENTRY_REVISUALIZES_757435382058959188: VariantsMap = [
    &["revisualizes"],
    &["revisualises"],
    &["revisualizes"],
    &["revisualises"],
];

pub(crate) static ENTRY_REVISUALIZE_10854082452689148747: VariantsMap = [
    &["revisualize"],
    &["revisualise"],
    &["revisualize"],
    &["revisualise"],
];

pub(crate) static ENTRY_REVITALIZATIONS_10832630253278670475: VariantsMap = [
    &["revitalizations"],
    &["revitalisations"],
    &["revitalizations"],
    &["revitalisations"],
];

pub(crate) static ENTRY_REVITALIZATION_13062486022413792020: VariantsMap = [
    &["revitalization"],
    &["revitalisation"],
    &["revitalization"],
    &["revitalisation"],
];

pub(crate) static ENTRY_REVITALIZED_8383897663298145675: VariantsMap = [
    &["revitalized"],
    &["revitalised"],
    &["revitalized"],
    &["revitalised"],
];

pub(crate) static ENTRY_REVITALIZERS_8120596477873838119: VariantsMap = [
    &["revitalizers"],
    &["revitalisers"],
    &["revitalizers"],
    &["revitalisers"],
];

pub(crate) static ENTRY_REVITALIZER_1269369318155795055: VariantsMap = [
    &["revitalizer"],
    &["revitaliser"],
    &["revitalizer"],
    &["revitaliser"],
];

pub(crate) static ENTRY_REVITALIZES_17733294788931304767: VariantsMap = [
    &["revitalizes"],
    &["revitalises"],
    &["revitalizes"],
    &["revitalises"],
];

pub(crate) static ENTRY_REVITALIZE_193715103532234630: VariantsMap = [
    &["revitalize"],
    &["revitalise"],
    &["revitalize"],
    &["revitalise"],
];

pub(crate) static ENTRY_REVITALIZING_16112731945721210438: VariantsMap = [
    &["revitalizing"],
    &["revitalising"],
    &["revitalizing"],
    &["revitalising"],
];

pub(crate) static ENTRY_REVIVALIZES_3796336163019290557: VariantsMap = [
    &["revivalizes"],
    &["revivalises"],
    &["revivalizes"],
    &["revivalises"],
];

pub(crate) static ENTRY_REVIVALIZE_12399394256488111764: VariantsMap = [
    &["revivalize"],
    &["revivalise"],
    &["revivalize"],
    &["revivalise"],
];

pub(crate) static ENTRY_REVOLATILIZES_261087607754605694: VariantsMap = [
    &["revolatilizes"],
    &["revolatilises"],
    &["revolatilizes"],
    &["revolatilises"],
];

pub(crate) static ENTRY_REVOLATILIZE_2071105640143175086: VariantsMap = [
    &["revolatilize"],
    &["revolatilise"],
    &["revolatilize"],
    &["revolatilise"],
];

pub(crate) static ENTRY_REVOLUTIONIZED_14375673469401672065: VariantsMap = [
    &["revolutionized"],
    &["revolutionised"],
    &["revolutionized"],
    &["revolutionised"],
];

pub(crate) static ENTRY_REVOLUTIONIZEMENTS_8372696219470999573: VariantsMap = [
    &["revolutionizements"],
    &["revolutionisements"],
    &["revolutionizements"],
    &["revolutionisements"],
];

pub(crate) static ENTRY_REVOLUTIONIZEMENT_3712613042773672198: VariantsMap = [
    &["revolutionizement"],
    &["revolutionisement"],
    &["revolutionizement"],
    &["revolutionisement"],
];

pub(crate) static ENTRY_REVOLUTIONIZERS_8217397059633187294: VariantsMap = [
    &["revolutionizers"],
    &["revolutionisers"],
    &["revolutionizers"],
    &["revolutionisers"],
];

pub(crate) static ENTRY_REVOLUTIONIZER_13149778382986804291: VariantsMap = [
    &["revolutionizer"],
    &["revolutioniser"],
    &["revolutionizer"],
    &["revolutioniser"],
];

pub(crate) static ENTRY_REVOLUTIONIZES_6397868062466700275: VariantsMap = [
    &["revolutionizes"],
    &["revolutionises"],
    &["revolutionizes"],
    &["revolutionises"],
];

pub(crate) static ENTRY_REVOLUTIONIZE_7544492450899006022: VariantsMap = [
    &["revolutionize"],
    &["revolutionise"],
    &["revolutionize"],
    &["revolutionise"],
];

pub(crate) static ENTRY_REVOLUTIONIZING_5584470119488633133: VariantsMap = [
    &["revolutionizing"],
    &["revolutionising"],
    &["revolutionizing"],
    &["revolutionising"],
];

pub(crate) static ENTRY_REXFORD_3887609989644811794: VariantsMap =
    [&["rexford"], &["rexfourd"], &["rexfourd"], &["rexfourd"]];

pub(crate) static ENTRY_RHAPHE_12384818764664453874: VariantsMap =
    [&["rhaphe"], &["rhaphae"], &["rhaphae"], &["rhaphae"]];

pub(crate) static ENTRY_RHAPSODIZED_11519621996184024336: VariantsMap = [
    &["rhapsodized"],
    &["rhapsodised"],
    &["rhapsodized"],
    &["rhapsodised"],
];

pub(crate) static ENTRY_RHAPSODIZES_7765267067797422211: VariantsMap = [
    &["rhapsodizes"],
    &["rhapsodises"],
    &["rhapsodizes"],
    &["rhapsodises"],
];

pub(crate) static ENTRY_RHAPSODIZE_12516177585413432849: VariantsMap = [
    &["rhapsodize"],
    &["rhapsodise"],
    &["rhapsodize"],
    &["rhapsodise"],
];

pub(crate) static ENTRY_RHAPSODIZING_13362377815551382619: VariantsMap = [
    &["rhapsodizing"],
    &["rhapsodising"],
    &["rhapsodizing"],
    &["rhapsodising"],
];

pub(crate) static ENTRY_RHEADINE_9620364319130309940: VariantsMap = [
    &["rheadine"],
    &["rhoeadine"],
    &["rhoeadine"],
    &["rhoeadine"],
];

pub(crate) static ENTRY_RHEBOSIS_5734830824723368566: VariantsMap = [
    &["rhebosis"],
    &["rhaebosis"],
    &["rhaebosis"],
    &["rhaebosis"],
];

pub(crate) static ENTRY_RHETIAN_7773375067640200565: VariantsMap =
    [&["rhetian"], &["rhaetian"], &["rhaetian"], &["rhaetian"]];

pub(crate) static ENTRY_RHETIC_18110954895356174940: VariantsMap =
    [&["rhetic"], &["rhaetic"], &["rhaetic"], &["rhaetic"]];

pub(crate) static ENTRY_RHETORIZED_12036770468694769802: VariantsMap = [
    &["rhetorized"],
    &["rhetorised"],
    &["rhetorized"],
    &["rhetorised"],
];

pub(crate) static ENTRY_RHETORIZES_11610320224318377716: VariantsMap = [
    &["rhetorizes"],
    &["rhetorises"],
    &["rhetorizes"],
    &["rhetorises"],
];

pub(crate) static ENTRY_RHETORIZE_15085474485565052687: VariantsMap = [
    &["rhetorize"],
    &["rhetorise"],
    &["rhetorize"],
    &["rhetorise"],
];

pub(crate) static ENTRY_RHETORIZING_4161503331833209409: VariantsMap = [
    &["rhetorizing"],
    &["rhetorising"],
    &["rhetorizing"],
    &["rhetorising"],
];

pub(crate) static ENTRY_RHEUMATIZED_5025722576540634515: VariantsMap = [
    &["rheumatized"],
    &["rheumatised"],
    &["rheumatized"],
    &["rheumatised"],
];

pub(crate) static ENTRY_RHEUMATIZES_5411071701844053603: VariantsMap = [
    &["rheumatizes"],
    &["rheumatises"],
    &["rheumatizes"],
    &["rheumatises"],
];

pub(crate) static ENTRY_RHEUMATIZE_1531026966882650471: VariantsMap = [
    &["rheumatize"],
    &["rheumatise"],
    &["rheumatize"],
    &["rheumatise"],
];

pub(crate) static ENTRY_RHEUMATIZING_16915712102407745517: VariantsMap = [
    &["rheumatizing"],
    &["rheumatising"],
    &["rheumatizing"],
    &["rheumatising"],
];

pub(crate) static ENTRY_RHINOCELE_13394138248730638628: VariantsMap = [
    &["rhinocele"],
    &["rhinocoele"],
    &["rhinocoele"],
    &["rhinocoele"],
];

pub(crate) static ENTRY_RHINOCELIAN_7468732235130691380: VariantsMap = [
    &["rhinocelian"],
    &["rhinocoelian"],
    &["rhinocoelian"],
    &["rhinocoelian"],
];

pub(crate) static ENTRY_RHINORRHEAL_4168671082299209434: VariantsMap = [
    &["rhinorrheal"],
    &["rhinorrhoeal"],
    &["rhinorrhoeal"],
    &["rhinorrhoeal"],
];

pub(crate) static ENTRY_RHINORRHEA_17760754621625220758: VariantsMap = [
    &["rhinorrhea"],
    &["rhinorrhoea"],
    &["rhinorrhoea"],
    &["rhinorrhoea"],
];

pub(crate) static ENTRY_RHODANIZED_12583740850093807678: VariantsMap = [
    &["rhodanized"],
    &["rhodanised"],
    &["rhodanized"],
    &["rhodanised"],
];

pub(crate) static ENTRY_RHODANIZES_12761949215613135994: VariantsMap = [
    &["rhodanizes"],
    &["rhodanises"],
    &["rhodanizes"],
    &["rhodanises"],
];

pub(crate) static ENTRY_RHODANIZE_302153013978993410: VariantsMap = [
    &["rhodanize"],
    &["rhodanise"],
    &["rhodanize"],
    &["rhodanise"],
];

pub(crate) static ENTRY_RHODANIZING_15623745248128814712: VariantsMap = [
    &["rhodanizing"],
    &["rhodanising"],
    &["rhodanizing"],
    &["rhodanising"],
];

pub(crate) static ENTRY_RHOTACIZED_9176740167556084330: VariantsMap = [
    &["rhotacized"],
    &["rhotacised"],
    &["rhotacized"],
    &["rhotacised"],
];

pub(crate) static ENTRY_RHOTACIZES_700796813593687972: VariantsMap = [
    &["rhotacizes"],
    &["rhotacises"],
    &["rhotacizes"],
    &["rhotacises"],
];

pub(crate) static ENTRY_RHOTACIZE_2196984425576687851: VariantsMap = [
    &["rhotacize"],
    &["rhotacise"],
    &["rhotacize"],
    &["rhotacise"],
];

pub(crate) static ENTRY_RHOTACIZING_1370798169034491463: VariantsMap = [
    &["rhotacizing"],
    &["rhotacising"],
    &["rhotacizing"],
    &["rhotacising"],
];

pub(crate) static ENTRY_RHYTHMICIZES_6647633033339306298: VariantsMap = [
    &["rhythmicizes"],
    &["rhythmicises"],
    &["rhythmicizes"],
    &["rhythmicises"],
];

pub(crate) static ENTRY_RHYTHMICIZE_5163197837266584786: VariantsMap = [
    &["rhythmicize"],
    &["rhythmicise"],
    &["rhythmicize"],
    &["rhythmicise"],
];

pub(crate) static ENTRY_RHYTHMIZABLES_17776105921216752906: VariantsMap = [
    &["rhythmizables"],
    &["rhythmisables"],
    &["rhythmizables"],
    &["rhythmisables"],
];

pub(crate) static ENTRY_RHYTHMIZABLE_2677462370618412645: VariantsMap = [
    &["rhythmizable"],
    &["rhythmisable"],
    &["rhythmizable"],
    &["rhythmisable"],
];

pub(crate) static ENTRY_RHYTHMIZATIONS_7293786921946666216: VariantsMap = [
    &["rhythmizations"],
    &["rhythmisations"],
    &["rhythmizations"],
    &["rhythmisations"],
];

pub(crate) static ENTRY_RHYTHMIZATION_16019734668485258402: VariantsMap = [
    &["rhythmization"],
    &["rhythmisation"],
    &["rhythmization"],
    &["rhythmisation"],
];

pub(crate) static ENTRY_RHYTHMIZED_5132054189203196434: VariantsMap = [
    &["rhythmized"],
    &["rhythmised"],
    &["rhythmized"],
    &["rhythmised"],
];

pub(crate) static ENTRY_RHYTHMIZES_5770183289187248055: VariantsMap = [
    &["rhythmizes"],
    &["rhythmises"],
    &["rhythmizes"],
    &["rhythmises"],
];

pub(crate) static ENTRY_RHYTHMIZE_10511981276106529519: VariantsMap = [
    &["rhythmize"],
    &["rhythmise"],
    &["rhythmize"],
    &["rhythmise"],
];

pub(crate) static ENTRY_RHYTHMIZING_4940630798632079527: VariantsMap = [
    &["rhythmizing"],
    &["rhythmising"],
    &["rhythmizing"],
    &["rhythmising"],
];

pub(crate) static ENTRY_RIDICULIZES_14575559099525792123: VariantsMap = [
    &["ridiculizes"],
    &["ridiculises"],
    &["ridiculizes"],
    &["ridiculises"],
];

pub(crate) static ENTRY_RIDICULIZE_1054636858349594298: VariantsMap = [
    &["ridiculize"],
    &["ridiculise"],
    &["ridiculize"],
    &["ridiculise"],
];

pub(crate) static ENTRY_RIGIDIZED_2511443842946442888: VariantsMap = [
    &["rigidized"],
    &["rigidised"],
    &["rigidized"],
    &["rigidised"],
];

pub(crate) static ENTRY_RIGIDIZES_8642244566818162964: VariantsMap = [
    &["rigidizes"],
    &["rigidises"],
    &["rigidizes"],
    &["rigidises"],
];

pub(crate) static ENTRY_RIGIDIZE_156720177693369344: VariantsMap =
    [&["rigidize"], &["rigidise"], &["rigidize"], &["rigidise"]];

pub(crate) static ENTRY_RIGIDIZING_14021102904701047671: VariantsMap = [
    &["rigidizing"],
    &["rigidising"],
    &["rigidizing"],
    &["rigidising"],
];

pub(crate) static ENTRY_RIGORISM_14069127364398578519: VariantsMap = [
    &["rigorism"],
    &["rigourism"],
    &["rigourism"],
    &["rigourism"],
];

pub(crate) static ENTRY_RIGORISTIC_12345844524001178474: VariantsMap = [
    &["rigoristic"],
    &["rigouristic"],
    &["rigouristic"],
    &["rigouristic"],
];

pub(crate) static ENTRY_RIGORIST_6703622095815747851: VariantsMap = [
    &["rigorist"],
    &["rigourist"],
    &["rigourist"],
    &["rigourist"],
];

pub(crate) static ENTRY_RIGORS_163306158062409929: VariantsMap =
    [&["rigors"], &["rigours"], &["rigours"], &["rigours"]];

pub(crate) static ENTRY_RIGOR_6127041250190650208: VariantsMap =
    [&["rigor"], &["rigour"], &["rigour"], &["rigour"]];

pub(crate) static ENTRY_RIOTIZES_17355146657912726592: VariantsMap =
    [&["riotizes"], &["riotises"], &["riotizes"], &["riotises"]];

pub(crate) static ENTRY_RIOTIZE_6719680474007390438: VariantsMap =
    [&["riotize"], &["riotise"], &["riotize"], &["riotise"]];

pub(crate) static ENTRY_RITORNELLES_18174381851390434260: VariantsMap = [
    &["ritornelles"],
    &["ritournelles"],
    &["ritournelles"],
    &["ritournelles"],
];

pub(crate) static ENTRY_RITORNELLE_12914215580998668402: VariantsMap = [
    &["ritornelle"],
    &["ritournelle"],
    &["ritournelle"],
    &["ritournelle"],
];

pub(crate) static ENTRY_RITUALIZATIONS_6446107650917771589: VariantsMap = [
    &["ritualizations"],
    &["ritualisations"],
    &["ritualizations"],
    &["ritualisations"],
];

pub(crate) static ENTRY_RITUALIZATION_17705479449777175846: VariantsMap = [
    &["ritualization"],
    &["ritualisation"],
    &["ritualization"],
    &["ritualisation"],
];

pub(crate) static ENTRY_RITUALIZED_14603675570872660022: VariantsMap = [
    &["ritualized"],
    &["ritualised"],
    &["ritualized"],
    &["ritualised"],
];

pub(crate) static ENTRY_RITUALIZES_6743897608838025402: VariantsMap = [
    &["ritualizes"],
    &["ritualises"],
    &["ritualizes"],
    &["ritualises"],
];

pub(crate) static ENTRY_RITUALIZE_10559347390928816833: VariantsMap = [
    &["ritualize"],
    &["ritualise"],
    &["ritualize"],
    &["ritualise"],
];

pub(crate) static ENTRY_RITUALIZING_5584795455479400064: VariantsMap = [
    &["ritualizing"],
    &["ritualising"],
    &["ritualizing"],
    &["ritualising"],
];

pub(crate) static ENTRY_RIVALED_1310914145976397449: VariantsMap =
    [&["rivaled"], &["rivalled"], &["rivalled"], &["rivalled"]];

pub(crate) static ENTRY_RIVALESSES_7896212397487020650: VariantsMap = [
    &["rivalesses"],
    &["rivallesses"],
    &["rivallesses"],
    &["rivallesses"],
];

pub(crate) static ENTRY_RIVALESS_17030046039543701469: VariantsMap = [
    &["rivaless"],
    &["rivalless"],
    &["rivalless"],
    &["rivalless"],
];

pub(crate) static ENTRY_RIVALING_6945496358803583057: VariantsMap = [
    &["rivaling"],
    &["rivalling"],
    &["rivalling"],
    &["rivalling"],
];

pub(crate) static ENTRY_RIVALIZED_7182768422071390801: VariantsMap = [
    &["rivalized"],
    &["rivalised"],
    &["rivalized"],
    &["rivalised"],
];

pub(crate) static ENTRY_RIVALIZES_2452557101215464168: VariantsMap = [
    &["rivalizes"],
    &["rivalises"],
    &["rivalizes"],
    &["rivalises"],
];

pub(crate) static ENTRY_RIVALIZE_7944174065886798683: VariantsMap =
    [&["rivalize"], &["rivalise"], &["rivalize"], &["rivalise"]];

pub(crate) static ENTRY_RIVALIZING_14048952717153236037: VariantsMap = [
    &["rivalizing"],
    &["rivalising"],
    &["rivalizing"],
    &["rivalising"],
];

pub(crate) static ENTRY_ROBOTIZATIONS_11624944842780950110: VariantsMap = [
    &["robotizations"],
    &["robotisations"],
    &["robotizations"],
    &["robotisations"],
];

pub(crate) static ENTRY_ROBOTIZATION_10442464385649584788: VariantsMap = [
    &["robotization"],
    &["robotisation"],
    &["robotization"],
    &["robotisation"],
];

pub(crate) static ENTRY_ROBOTIZED_6871096401872030909: VariantsMap = [
    &["robotized"],
    &["robotised"],
    &["robotized"],
    &["robotised"],
];

pub(crate) static ENTRY_ROBOTIZES_8084732757819391045: VariantsMap = [
    &["robotizes"],
    &["robotises"],
    &["robotizes"],
    &["robotises"],
];

pub(crate) static ENTRY_ROBOTIZE_1822365081322284994: VariantsMap =
    [&["robotize"], &["robotise"], &["robotize"], &["robotise"]];

pub(crate) static ENTRY_ROBOTIZING_9767982352083703401: VariantsMap = [
    &["robotizing"],
    &["robotising"],
    &["robotizing"],
    &["robotising"],
];

pub(crate) static ENTRY_ROED_7491598846688934647: VariantsMap =
    [&["roed"], &["rooed"], &["rooed"], &["rooed"]];

pub(crate) static ENTRY_ROENTGENIZE_10746435571343043012: VariantsMap = [
    &["roentgenize"],
    &["roentgenise"],
    &["roentgenize"],
    &["roentgenise"],
];

pub(crate) static ENTRY_ROER_9399565430831118531: VariantsMap =
    [&["roer"], &["rore"], &["rore"], &["rore"]];

pub(crate) static ENTRY_ROMANIAS_9441434726837892631: VariantsMap = [
    &["romanias"],
    &["roumanias"],
    &["roumanias"],
    &["roumanias"],
];

pub(crate) static ENTRY_ROMANIA_14647491915869407300: VariantsMap =
    [&["romania"], &["roumania"], &["roumania"], &["roumania"]];

pub(crate) static ENTRY_ROMANIZATIONS_9179904637420783701: VariantsMap = [
    &["romanizations"],
    &["romanisations"],
    &["romanizations"],
    &["romanisations"],
];

pub(crate) static ENTRY_ROMANIZATION_1812649176047396288: VariantsMap = [
    &["romanization"],
    &["romanisation"],
    &["romanization"],
    &["romanisation"],
];

pub(crate) static ENTRY_ROMANIZED_8188127372098085668: VariantsMap = [
    &["romanized"],
    &["romanised"],
    &["romanized"],
    &["romanised"],
];

pub(crate) static ENTRY_ROMANIZERS_7186572903998412475: VariantsMap = [
    &["romanizers"],
    &["romanisers"],
    &["romanizers"],
    &["romanisers"],
];

pub(crate) static ENTRY_ROMANIZER_10910799684441102818: VariantsMap = [
    &["romanizer"],
    &["romaniser"],
    &["romanizer"],
    &["romaniser"],
];

pub(crate) static ENTRY_ROMANIZES_7603852869065493171: VariantsMap = [
    &["romanizes"],
    &["romanises"],
    &["romanizes"],
    &["romanises"],
];

pub(crate) static ENTRY_ROMANIZE_2020383270516389989: VariantsMap =
    [&["romanize"], &["romanise"], &["romanize"], &["romanise"]];

pub(crate) static ENTRY_ROMANIZING_1191652903917979672: VariantsMap = [
    &["romanizing"],
    &["romanising"],
    &["romanizing"],
    &["romanising"],
];

pub(crate) static ENTRY_ROMANTICIZATIONS_14371809476146672855: VariantsMap = [
    &["romanticizations"],
    &["romanticisations"],
    &["romanticizations"],
    &["romanticisations"],
];

pub(crate) static ENTRY_ROMANTICIZATION_1655615510397751437: VariantsMap = [
    &["romanticization"],
    &["romanticisation"],
    &["romanticization"],
    &["romanticisation"],
];

pub(crate) static ENTRY_ROMANTICIZED_10936525722537335211: VariantsMap = [
    &["romanticized"],
    &["romanticised"],
    &["romanticized"],
    &["romanticised"],
];

pub(crate) static ENTRY_ROMANTICIZES_14376155573214247856: VariantsMap = [
    &["romanticizes"],
    &["romanticises"],
    &["romanticizes"],
    &["romanticises"],
];

pub(crate) static ENTRY_ROMANTICIZE_17291657258585049672: VariantsMap = [
    &["romanticize"],
    &["romanticise"],
    &["romanticize"],
    &["romanticise"],
];

pub(crate) static ENTRY_ROMANTICIZING_7257111435910768108: VariantsMap = [
    &["romanticizing"],
    &["romanticising"],
    &["romanticizing"],
    &["romanticising"],
];

pub(crate) static ENTRY_ROUTINIZATIONS_15252472006215427062: VariantsMap = [
    &["routinizations"],
    &["routinisations"],
    &["routinizations"],
    &["routinisations"],
];

pub(crate) static ENTRY_ROUTINIZATION_16656207668238320072: VariantsMap = [
    &["routinization"],
    &["routinisation"],
    &["routinization"],
    &["routinisation"],
];

pub(crate) static ENTRY_ROUTINIZED_1851279582216291255: VariantsMap = [
    &["routinized"],
    &["routinised"],
    &["routinized"],
    &["routinised"],
];

pub(crate) static ENTRY_ROUTINIZES_2715007322555254066: VariantsMap = [
    &["routinizes"],
    &["routinises"],
    &["routinizes"],
    &["routinises"],
];

pub(crate) static ENTRY_ROUTINIZE_5626420320204126115: VariantsMap = [
    &["routinize"],
    &["routinise"],
    &["routinize"],
    &["routinise"],
];

pub(crate) static ENTRY_ROUTINIZING_6227530109158853879: VariantsMap = [
    &["routinizing"],
    &["routinising"],
    &["routinizing"],
    &["routinising"],
];

pub(crate) static ENTRY_ROWELED_13637303372527211405: VariantsMap =
    [&["roweled"], &["rowelled"], &["rowelled"], &["rowelled"]];

pub(crate) static ENTRY_ROWELING_13952035716222413490: VariantsMap = [
    &["roweling"],
    &["rowelling"],
    &["rowelling"],
    &["rowelling"],
];

pub(crate) static ENTRY_ROYALIZATIONS_16712363081334842649: VariantsMap = [
    &["royalizations"],
    &["royalisations"],
    &["royalizations"],
    &["royalisations"],
];

pub(crate) static ENTRY_ROYALIZATION_11067381201878855200: VariantsMap = [
    &["royalization"],
    &["royalisation"],
    &["royalization"],
    &["royalisation"],
];

pub(crate) static ENTRY_ROYALIZED_5272390552778035423: VariantsMap = [
    &["royalized"],
    &["royalised"],
    &["royalized"],
    &["royalised"],
];

pub(crate) static ENTRY_ROYALIZES_806193357964394419: VariantsMap = [
    &["royalizes"],
    &["royalises"],
    &["royalizes"],
    &["royalises"],
];

pub(crate) static ENTRY_ROYALIZE_14272296856251086161: VariantsMap =
    [&["royalize"], &["royalise"], &["royalize"], &["royalise"]];

pub(crate) static ENTRY_ROYALIZING_3246861064960016421: VariantsMap = [
    &["royalizing"],
    &["royalising"],
    &["royalizing"],
    &["royalising"],
];

pub(crate) static ENTRY_RUBBERIZATION_3122682324183377228: VariantsMap = [
    &["rubberization"],
    &["rubberisation"],
    &["rubberization"],
    &["rubberisation"],
];

pub(crate) static ENTRY_RUBBERIZED_15637607135983122135: VariantsMap = [
    &["rubberized"],
    &["rubberised"],
    &["rubberized"],
    &["rubberised"],
];

pub(crate) static ENTRY_RUBBERIZES_3912030953974462546: VariantsMap = [
    &["rubberizes"],
    &["rubberises"],
    &["rubberizes"],
    &["rubberises"],
];

pub(crate) static ENTRY_RUBBERIZE_8534952429152157034: VariantsMap = [
    &["rubberize"],
    &["rubberise"],
    &["rubberize"],
    &["rubberise"],
];

pub(crate) static ENTRY_RUBBERIZING_5203082318061539960: VariantsMap = [
    &["rubberizing"],
    &["rubberising"],
    &["rubberizing"],
    &["rubberising"],
];

pub(crate) static ENTRY_RUBLES_5273455018786501602: VariantsMap =
    [&["rubles"], &["roubles"], &["roubles"], &["roubles"]];

pub(crate) static ENTRY_RUBLE_10117878449438778810: VariantsMap =
    [&["ruble"], &["rouble"], &["rouble"], &["rouble"]];

pub(crate) static ENTRY_RUBRICIZES_6613684611958202027: VariantsMap = [
    &["rubricizes"],
    &["rubricises"],
    &["rubricizes"],
    &["rubricises"],
];

pub(crate) static ENTRY_RUBRICIZE_9836541413862092246: VariantsMap = [
    &["rubricize"],
    &["rubricise"],
    &["rubricize"],
    &["rubricise"],
];

pub(crate) static ENTRY_RUFFIANIZES_14576217936902384026: VariantsMap = [
    &["ruffianizes"],
    &["ruffianises"],
    &["ruffianizes"],
    &["ruffianises"],
];

pub(crate) static ENTRY_RUFFIANIZE_17407878081648774516: VariantsMap = [
    &["ruffianize"],
    &["ruffianise"],
    &["ruffianize"],
    &["ruffianise"],
];

pub(crate) static ENTRY_RUGGEDIZATIONS_632588497204849835: VariantsMap = [
    &["ruggedizations"],
    &["ruggedisations"],
    &["ruggedizations"],
    &["ruggedisations"],
];

pub(crate) static ENTRY_RUGGEDIZATION_5669230878299551336: VariantsMap = [
    &["ruggedization"],
    &["ruggedisation"],
    &["ruggedization"],
    &["ruggedisation"],
];

pub(crate) static ENTRY_RUGGEDIZED_16294057666793563055: VariantsMap = [
    &["ruggedized"],
    &["ruggedised"],
    &["ruggedized"],
    &["ruggedised"],
];

pub(crate) static ENTRY_RUGGEDIZES_16648500507504288559: VariantsMap = [
    &["ruggedizes"],
    &["ruggedises"],
    &["ruggedizes"],
    &["ruggedises"],
];

pub(crate) static ENTRY_RUGGEDIZE_452263712716974983: VariantsMap = [
    &["ruggedize"],
    &["ruggedise"],
    &["ruggedize"],
    &["ruggedise"],
];

pub(crate) static ENTRY_RUGGEDIZING_10631138816687857349: VariantsMap = [
    &["ruggedizing"],
    &["ruggedising"],
    &["ruggedizing"],
    &["ruggedising"],
];

pub(crate) static ENTRY_RUMORED_18309275267346665123: VariantsMap =
    [&["rumored"], &["rumoured"], &["rumoured"], &["rumoured"]];

pub(crate) static ENTRY_RUMORERS_6357305227935379172: VariantsMap = [
    &["rumorers"],
    &["rumourers"],
    &["rumourers"],
    &["rumourers"],
];

pub(crate) static ENTRY_RUMORER_11488343213641948242: VariantsMap =
    [&["rumorer"], &["rumourer"], &["rumourer"], &["rumourer"]];

pub(crate) static ENTRY_RUMORING_2328261845579723307: VariantsMap = [
    &["rumoring"],
    &["rumouring"],
    &["rumouring"],
    &["rumouring"],
];

pub(crate) static ENTRY_RUMORMONGERS_12499750377413614176: VariantsMap = [
    &["rumormongers"],
    &["rumourmongers"],
    &["rumourmongers"],
    &["rumourmongers"],
];

pub(crate) static ENTRY_RUMORMONGER_7299548335065542796: VariantsMap = [
    &["rumormonger"],
    &["rumourmonger"],
    &["rumourmonger"],
    &["rumourmonger"],
];

pub(crate) static ENTRY_RUMORS_4907921740910409378: VariantsMap =
    [&["rumors"], &["rumours"], &["rumours"], &["rumours"]];

pub(crate) static ENTRY_RUMOR_9709120178518195057: VariantsMap =
    [&["rumor"], &["rumour"], &["rumour"], &["rumour"]];

pub(crate) static ENTRY_RURALIZATIONS_18364650995853039163: VariantsMap = [
    &["ruralizations"],
    &["ruralisations"],
    &["ruralizations"],
    &["ruralisations"],
];

pub(crate) static ENTRY_RURALIZATION_12199675531569627500: VariantsMap = [
    &["ruralization"],
    &["ruralisation"],
    &["ruralization"],
    &["ruralisation"],
];

pub(crate) static ENTRY_RURALIZED_10330894529989453328: VariantsMap = [
    &["ruralized"],
    &["ruralised"],
    &["ruralized"],
    &["ruralised"],
];

pub(crate) static ENTRY_RURALIZES_2177534473483628527: VariantsMap = [
    &["ruralizes"],
    &["ruralises"],
    &["ruralizes"],
    &["ruralises"],
];

pub(crate) static ENTRY_RURALIZE_10315684701653459711: VariantsMap =
    [&["ruralize"], &["ruralise"], &["ruralize"], &["ruralise"]];

pub(crate) static ENTRY_RURALIZING_13347398545539483501: VariantsMap = [
    &["ruralizing"],
    &["ruralising"],
    &["ruralizing"],
    &["ruralising"],
];

pub(crate) static ENTRY_RUSSIANIZATIONS_11585141916754458789: VariantsMap = [
    &["russianizations"],
    &["russianisations"],
    &["russianizations"],
    &["russianisations"],
];

pub(crate) static ENTRY_RUSSIANIZATION_16898768923421263030: VariantsMap = [
    &["russianization"],
    &["russianisation"],
    &["russianization"],
    &["russianisation"],
];

pub(crate) static ENTRY_RUSSIANIZED_15749625767358498066: VariantsMap = [
    &["russianized"],
    &["russianised"],
    &["russianized"],
    &["russianised"],
];

pub(crate) static ENTRY_RUSSIANIZES_16645859177250529320: VariantsMap = [
    &["russianizes"],
    &["russianises"],
    &["russianizes"],
    &["russianises"],
];

pub(crate) static ENTRY_RUSSIANIZE_9206676310088840254: VariantsMap = [
    &["russianize"],
    &["russianise"],
    &["russianize"],
    &["russianise"],
];

pub(crate) static ENTRY_RUSSIANIZING_12272597000608712547: VariantsMap = [
    &["russianizing"],
    &["russianising"],
    &["russianizing"],
    &["russianising"],
];

pub(crate) static ENTRY_RUSTICIZED_8719798803495007326: VariantsMap = [
    &["rusticized"],
    &["rusticised"],
    &["rusticized"],
    &["rusticised"],
];

pub(crate) static ENTRY_RUSTICIZES_5457546844148812271: VariantsMap = [
    &["rusticizes"],
    &["rusticises"],
    &["rusticizes"],
    &["rusticises"],
];

pub(crate) static ENTRY_RUSTICIZE_12734614119488995185: VariantsMap = [
    &["rusticize"],
    &["rusticise"],
    &["rusticize"],
    &["rusticise"],
];

pub(crate) static ENTRY_RUSTICIZING_2240961739878480538: VariantsMap = [
    &["rusticizing"],
    &["rusticising"],
    &["rusticizing"],
    &["rusticising"],
];

pub(crate) static ENTRY_SABBATHIZES_14657735120604873546: VariantsMap = [
    &["sabbathizes"],
    &["sabbathises"],
    &["sabbathizes"],
    &["sabbathises"],
];

pub(crate) static ENTRY_SABBATHIZE_9135552393539099453: VariantsMap = [
    &["sabbathize"],
    &["sabbathise"],
    &["sabbathize"],
    &["sabbathise"],
];

pub(crate) static ENTRY_SABBATIZED_13406040171945222761: VariantsMap = [
    &["sabbatized"],
    &["sabbatised"],
    &["sabbatized"],
    &["sabbatised"],
];

pub(crate) static ENTRY_SABBATIZES_15314102181592132563: VariantsMap = [
    &["sabbatizes"],
    &["sabbatises"],
    &["sabbatizes"],
    &["sabbatises"],
];

pub(crate) static ENTRY_SABBATIZE_9501648681615619705: VariantsMap = [
    &["sabbatize"],
    &["sabbatise"],
    &["sabbatize"],
    &["sabbatise"],
];

pub(crate) static ENTRY_SABBATIZING_12733815021350519705: VariantsMap = [
    &["sabbatizing"],
    &["sabbatising"],
    &["sabbatizing"],
    &["sabbatising"],
];

pub(crate) static ENTRY_SABEANS_6165241232825542997: VariantsMap =
    [&["sabeans"], &["sabaeans"], &["sabaeans"], &["sabaeans"]];

pub(crate) static ENTRY_SABEAN_3967530483638026323: VariantsMap =
    [&["sabean"], &["sabaean"], &["sabaean"], &["sabaean"]];

pub(crate) static ENTRY_SABERBILL_8906790336832465441: VariantsMap = [
    &["saberbill"],
    &["sabrebill"],
    &["sabrebill"],
    &["sabrebill"],
];

pub(crate) static ENTRY_SABERED_6570351091920240802: VariantsMap =
    [&["sabered"], &["sabred"], &["sabred"], &["sabred"]];

pub(crate) static ENTRY_SABERING_678610951848245655: VariantsMap =
    [&["sabering"], &["sabring"], &["sabring"], &["sabring"]];

pub(crate) static ENTRY_SABERLIKES_11200825439513418213: VariantsMap = [
    &["saberlikes"],
    &["sabrelikes"],
    &["sabrelikes"],
    &["sabrelikes"],
];

pub(crate) static ENTRY_SABERLIKE_13557431937207997081: VariantsMap = [
    &["saberlike"],
    &["sabrelike"],
    &["sabrelike"],
    &["sabrelike"],
];

pub(crate) static ENTRY_SABERS_16530304349268606792: VariantsMap =
    [&["sabers"], &["sabres"], &["sabres"], &["sabres"]];

pub(crate) static ENTRY_SABERTOOTH_232682195526621441: VariantsMap = [
    &["sabertooth"],
    &["sabretooth"],
    &["sabretooth"],
    &["sabretooth"],
];

pub(crate) static ENTRY_SABER_11546898781047404082: VariantsMap =
    [&["saber"], &["sabre"], &["sabre"], &["sabre"]];

pub(crate) static ENTRY_SACCHARIZATIONS_17924715140172127263: VariantsMap = [
    &["saccharizations"],
    &["saccharisations"],
    &["saccharizations"],
    &["saccharisations"],
];

pub(crate) static ENTRY_SACCHARIZATION_12951479435448622533: VariantsMap = [
    &["saccharization"],
    &["saccharisation"],
    &["saccharization"],
    &["saccharisation"],
];

pub(crate) static ENTRY_SACCHARIZED_17475431280128284092: VariantsMap = [
    &["saccharized"],
    &["saccharised"],
    &["saccharized"],
    &["saccharised"],
];

pub(crate) static ENTRY_SACCHARIZES_17004868231094363900: VariantsMap = [
    &["saccharizes"],
    &["saccharises"],
    &["saccharizes"],
    &["saccharises"],
];

pub(crate) static ENTRY_SACCHARIZE_8112536361258402472: VariantsMap = [
    &["saccharize"],
    &["saccharise"],
    &["saccharize"],
    &["saccharise"],
];

pub(crate) static ENTRY_SACCHARIZING_4047419846397824266: VariantsMap = [
    &["saccharizing"],
    &["saccharising"],
    &["saccharizing"],
    &["saccharising"],
];

pub(crate) static ENTRY_SACERDOTALIZED_3090555217942359397: VariantsMap = [
    &["sacerdotalized"],
    &["sacerdotalised"],
    &["sacerdotalized"],
    &["sacerdotalised"],
];

pub(crate) static ENTRY_SACERDOTALIZES_3677365514994329629: VariantsMap = [
    &["sacerdotalizes"],
    &["sacerdotalises"],
    &["sacerdotalizes"],
    &["sacerdotalises"],
];

pub(crate) static ENTRY_SACERDOTALIZE_6234124268374846096: VariantsMap = [
    &["sacerdotalize"],
    &["sacerdotalise"],
    &["sacerdotalize"],
    &["sacerdotalise"],
];

pub(crate) static ENTRY_SACERDOTALIZING_17120181135430251071: VariantsMap = [
    &["sacerdotalizing"],
    &["sacerdotalising"],
    &["sacerdotalizing"],
    &["sacerdotalising"],
];

pub(crate) static ENTRY_SACRALIZATIONS_14811964160883679275: VariantsMap = [
    &["sacralizations"],
    &["sacralisations"],
    &["sacralizations"],
    &["sacralisations"],
];

pub(crate) static ENTRY_SACRALIZATION_1618414885145018191: VariantsMap = [
    &["sacralization"],
    &["sacralisation"],
    &["sacralization"],
    &["sacralisation"],
];

pub(crate) static ENTRY_SACRALIZED_9465526025728376412: VariantsMap = [
    &["sacralized"],
    &["sacralised"],
    &["sacralized"],
    &["sacralised"],
];

pub(crate) static ENTRY_SACRALIZES_15118462953215987237: VariantsMap = [
    &["sacralizes"],
    &["sacralises"],
    &["sacralizes"],
    &["sacralises"],
];

pub(crate) static ENTRY_SACRALIZE_10390344760188291303: VariantsMap = [
    &["sacralize"],
    &["sacralise"],
    &["sacralize"],
    &["sacralise"],
];

pub(crate) static ENTRY_SACRALIZING_12013845710799024326: VariantsMap = [
    &["sacralizing"],
    &["sacralising"],
    &["sacralizing"],
    &["sacralising"],
];

pub(crate) static ENTRY_SACRAMENTIZES_16943481266153665364: VariantsMap = [
    &["sacramentizes"],
    &["sacramentises"],
    &["sacramentizes"],
    &["sacramentises"],
];

pub(crate) static ENTRY_SACRAMENTIZE_5105033131237471754: VariantsMap = [
    &["sacramentize"],
    &["sacramentise"],
    &["sacramentize"],
    &["sacramentise"],
];

pub(crate) static ENTRY_SAFIER_7130557169601659947: VariantsMap =
    [&["safier"], &["safire"], &["safire"], &["safire"]];

pub(crate) static ENTRY_SAILORIZINGS_828877064204542534: VariantsMap = [
    &["sailorizings"],
    &["sailorisings"],
    &["sailorizings"],
    &["sailorisings"],
];

pub(crate) static ENTRY_SAILORIZING_10847894908498319787: VariantsMap = [
    &["sailorizing"],
    &["sailorising"],
    &["sailorizing"],
    &["sailorising"],
];

pub(crate) static ENTRY_SALABLER_2191562261555828404: VariantsMap = [
    &["salabler"],
    &["saleabler"],
    &["saleabler"],
    &["saleabler"],
];

pub(crate) static ENTRY_SALABLEST_11739630936470269511: VariantsMap = [
    &["salablest"],
    &["saleablest"],
    &["saleablest"],
    &["saleablest"],
];

pub(crate) static ENTRY_SALABLE_13489586256964068577: VariantsMap =
    [&["salable"], &["saleable"], &["saleable"], &["saleable"]];

pub(crate) static ENTRY_SALINIZATION_14249030620674770707: VariantsMap = [
    &["salinization"],
    &["salinisation"],
    &["salinization"],
    &["salinisation"],
];

pub(crate) static ENTRY_SALINIZES_15735130644009593162: VariantsMap = [
    &["salinizes"],
    &["salinises"],
    &["salinizes"],
    &["salinises"],
];

pub(crate) static ENTRY_SALINIZE_1624463717219344911: VariantsMap =
    [&["salinize"], &["salinise"], &["salinize"], &["salinise"]];

pub(crate) static ENTRY_SALTIERS_15037062520661036868: VariantsMap =
    [&["saltiers"], &["saltires"], &["saltires"], &["saltires"]];

pub(crate) static ENTRY_SALTIERWISE_13939673853461651998: VariantsMap = [
    &["saltierwise"],
    &["saltirewise"],
    &["saltirewise"],
    &["saltirewise"],
];

pub(crate) static ENTRY_SALTPETERS_13396036659008372276: VariantsMap = [
    &["saltpeters"],
    &["saltpetres"],
    &["saltpetres"],
    &["saltpetres"],
];

pub(crate) static ENTRY_SALTPETER_1364613771688244608: VariantsMap = [
    &["saltpeter"],
    &["saltpetre"],
    &["saltpetre"],
    &["saltpetre"],
];

pub(crate) static ENTRY_SANCTUARIZED_13881929576576103541: VariantsMap = [
    &["sanctuarized"],
    &["sanctuarised"],
    &["sanctuarized"],
    &["sanctuarised"],
];

pub(crate) static ENTRY_SANCTUARIZES_886243961160484101: VariantsMap = [
    &["sanctuarizes"],
    &["sanctuarises"],
    &["sanctuarizes"],
    &["sanctuarises"],
];

pub(crate) static ENTRY_SANCTUARIZE_2684033985693966023: VariantsMap = [
    &["sanctuarize"],
    &["sanctuarise"],
    &["sanctuarize"],
    &["sanctuarise"],
];

pub(crate) static ENTRY_SANCTUARIZING_6723253584803089826: VariantsMap = [
    &["sanctuarizing"],
    &["sanctuarising"],
    &["sanctuarizing"],
    &["sanctuarising"],
];

pub(crate) static ENTRY_SANDALED_13249873388295186265: VariantsMap = [
    &["sandaled"],
    &["sandalled"],
    &["sandalled"],
    &["sandalled"],
];

pub(crate) static ENTRY_SANDALING_7683116982062206539: VariantsMap = [
    &["sandaling"],
    &["sandalling"],
    &["sandalling"],
    &["sandalling"],
];

pub(crate) static ENTRY_SANFERD_7356557887418560168: VariantsMap =
    [&["sanferd"], &["sanfred"], &["sanfred"], &["sanfred"]];

pub(crate) static ENTRY_SANFORIZES_2563826137147657575: VariantsMap = [
    &["sanforizes"],
    &["sanforises"],
    &["sanforizes"],
    &["sanforises"],
];

pub(crate) static ENTRY_SANFORIZE_4265814001637231765: VariantsMap = [
    &["sanforize"],
    &["sanforise"],
    &["sanforize"],
    &["sanforise"],
];

pub(crate) static ENTRY_SANFORIZING_2868487486423425023: VariantsMap = [
    &["sanforizing"],
    &["sanforising"],
    &["sanforizing"],
    &["sanforising"],
];

pub(crate) static ENTRY_SANITIZATIONS_8021402000169967705: VariantsMap = [
    &["sanitizations"],
    &["sanitisations"],
    &["sanitizations"],
    &["sanitisations"],
];

pub(crate) static ENTRY_SANITIZATION_10312415212709623714: VariantsMap = [
    &["sanitization"],
    &["sanitisation"],
    &["sanitization"],
    &["sanitisation"],
];

pub(crate) static ENTRY_SANITIZED_5841984440856760755: VariantsMap = [
    &["sanitized"],
    &["sanitised"],
    &["sanitized"],
    &["sanitised"],
];

pub(crate) static ENTRY_SANITIZERS_9114154210371871378: VariantsMap = [
    &["sanitizers"],
    &["sanitisers"],
    &["sanitizers"],
    &["sanitisers"],
];

pub(crate) static ENTRY_SANITIZER_6961399843419580720: VariantsMap = [
    &["sanitizer"],
    &["sanitiser"],
    &["sanitizer"],
    &["sanitiser"],
];

pub(crate) static ENTRY_SANITIZES_14632226777926157749: VariantsMap = [
    &["sanitizes"],
    &["sanitises"],
    &["sanitizes"],
    &["sanitises"],
];

pub(crate) static ENTRY_SANITIZE_7331650509497054123: VariantsMap =
    [&["sanitize"], &["sanitise"], &["sanitize"], &["sanitise"]];

pub(crate) static ENTRY_SANITIZING_15814691895167354347: VariantsMap = [
    &["sanitizing"],
    &["sanitising"],
    &["sanitizing"],
    &["sanitising"],
];

pub(crate) static ENTRY_SANSKRITIZE_8185278319719381954: VariantsMap = [
    &["sanskritize"],
    &["sanskritise"],
    &["sanskritize"],
    &["sanskritise"],
];

pub(crate) static ENTRY_SAPIENTIZES_16382959409533620025: VariantsMap = [
    &["sapientizes"],
    &["sapientises"],
    &["sapientizes"],
    &["sapientises"],
];

pub(crate) static ENTRY_SAPIENTIZE_14146190997329896957: VariantsMap = [
    &["sapientize"],
    &["sapientise"],
    &["sapientize"],
    &["sapientise"],
];

pub(crate) static ENTRY_SAPORS_15668621297825529733: VariantsMap =
    [&["sapors"], &["sapours"], &["sapours"], &["sapours"]];

pub(crate) static ENTRY_SAPOR_14377617062405537073: VariantsMap =
    [&["sapor"], &["sapour"], &["sapour"], &["sapour"]];

pub(crate) static ENTRY_SAPREMIAS_2393230130508325789: VariantsMap = [
    &["sapremias"],
    &["sapraemias"],
    &["sapraemias"],
    &["sapraemias"],
];

pub(crate) static ENTRY_SAPREMIA_10927593620047632704: VariantsMap = [
    &["sapremia"],
    &["sapraemia"],
    &["sapraemia"],
    &["sapraemia"],
];

pub(crate) static ENTRY_SAPREMIC_9405591661600178250: VariantsMap = [
    &["sapremic"],
    &["sapraemic"],
    &["sapraemic"],
    &["sapraemic"],
];

pub(crate) static ENTRY_SARCINE_1474563832611431940: VariantsMap =
    [&["sarcine"], &["sarcinae"], &["sarcinae"], &["sarcinae"]];

pub(crate) static ENTRY_SASSANIDE_5335894015828476896: VariantsMap = [
    &["sassanide"],
    &["sassanidae"],
    &["sassanidae"],
    &["sassanidae"],
];

pub(crate) static ENTRY_SATANIZES_4037603454744610431: VariantsMap = [
    &["satanizes"],
    &["satanises"],
    &["satanizes"],
    &["satanises"],
];

pub(crate) static ENTRY_SATANIZE_2951447326962462423: VariantsMap =
    [&["satanize"], &["satanise"], &["satanize"], &["satanise"]];

pub(crate) static ENTRY_SATELLITIZED_4530790908872238564: VariantsMap = [
    &["satellitized"],
    &["satellitised"],
    &["satellitized"],
    &["satellitised"],
];

pub(crate) static ENTRY_SATELLITIZES_15756736520028846542: VariantsMap = [
    &["satellitizes"],
    &["satellitises"],
    &["satellitizes"],
    &["satellitises"],
];

pub(crate) static ENTRY_SATELLITIZE_1312953346097302445: VariantsMap = [
    &["satellitize"],
    &["satellitise"],
    &["satellitize"],
    &["satellitise"],
];

pub(crate) static ENTRY_SATELLITIZING_5844820839355010398: VariantsMap = [
    &["satellitizing"],
    &["satellitising"],
    &["satellitizing"],
    &["satellitising"],
];

pub(crate) static ENTRY_SATINIZES_542674649787102689: VariantsMap = [
    &["satinizes"],
    &["satinises"],
    &["satinizes"],
    &["satinises"],
];

pub(crate) static ENTRY_SATINIZE_12856779838184407064: VariantsMap =
    [&["satinize"], &["satinise"], &["satinize"], &["satinise"]];

pub(crate) static ENTRY_SATIRIZABLES_12495079216543111113: VariantsMap = [
    &["satirizables"],
    &["satirisables"],
    &["satirizables"],
    &["satirisables"],
];

pub(crate) static ENTRY_SATIRIZABLE_2981879413723745381: VariantsMap = [
    &["satirizable"],
    &["satirisable"],
    &["satirizable"],
    &["satirisable"],
];

pub(crate) static ENTRY_SATIRIZATION_5803523737972554169: VariantsMap = [
    &["satirization"],
    &["satirisation"],
    &["satirization"],
    &["satirisation"],
];

pub(crate) static ENTRY_SATIRIZED_7754739640320301410: VariantsMap = [
    &["satirized"],
    &["satirised"],
    &["satirized"],
    &["satirised"],
];

pub(crate) static ENTRY_SATIRIZERS_15574884911196071567: VariantsMap = [
    &["satirizers"],
    &["satirisers"],
    &["satirizers"],
    &["satirisers"],
];

pub(crate) static ENTRY_SATIRIZER_852195482153342188: VariantsMap = [
    &["satirizer"],
    &["satiriser"],
    &["satirizer"],
    &["satiriser"],
];

pub(crate) static ENTRY_SATIRIZES_10052925778146532918: VariantsMap = [
    &["satirizes"],
    &["satirises"],
    &["satirizes"],
    &["satirises"],
];

pub(crate) static ENTRY_SATIRIZE_4670452432959122101: VariantsMap =
    [&["satirize"], &["satirise"], &["satirize"], &["satirise"]];

pub(crate) static ENTRY_SATIRIZING_1764005323783146105: VariantsMap = [
    &["satirizing"],
    &["satirising"],
    &["satirizing"],
    &["satirising"],
];

pub(crate) static ENTRY_SATIVE_2657172684842563277: VariantsMap =
    [&["sative"], &["sativae"], &["sativae"], &["sativae"]];

pub(crate) static ENTRY_SAVAGIZES_3717388500719289056: VariantsMap = [
    &["savagizes"],
    &["savagises"],
    &["savagizes"],
    &["savagises"],
];

pub(crate) static ENTRY_SAVAGIZE_826547977271561744: VariantsMap =
    [&["savagize"], &["savagise"], &["savagize"], &["savagise"]];

pub(crate) static ENTRY_SAVIORESS_8494654417327749250: VariantsMap = [
    &["savioress"],
    &["saviouress"],
    &["saviouress"],
    &["saviouress"],
];

pub(crate) static ENTRY_SAVIORHOODS_2311230659362646694: VariantsMap = [
    &["saviorhoods"],
    &["saviourhoods"],
    &["saviourhoods"],
    &["saviourhoods"],
];

pub(crate) static ENTRY_SAVIORHOOD_2729791171284683689: VariantsMap = [
    &["saviorhood"],
    &["saviourhood"],
    &["saviourhood"],
    &["saviourhood"],
];

pub(crate) static ENTRY_SAVIORSHIPS_11936339798406737592: VariantsMap = [
    &["saviorships"],
    &["saviourships"],
    &["saviourships"],
    &["saviourships"],
];

pub(crate) static ENTRY_SAVIORSHIP_2762957268664282572: VariantsMap = [
    &["saviorship"],
    &["saviourship"],
    &["saviourship"],
    &["saviourship"],
];

pub(crate) static ENTRY_SAVIORS_13252400093779282591: VariantsMap =
    [&["saviors"], &["saviours"], &["saviours"], &["saviours"]];

pub(crate) static ENTRY_SAVIOR_11215020799589174317: VariantsMap =
    [&["savior"], &["saviour"], &["saviour"], &["saviour"]];

pub(crate) static ENTRY_SAVORED_17866382687586191735: VariantsMap =
    [&["savored"], &["savoured"], &["savoured"], &["savoured"]];

pub(crate) static ENTRY_SAVORERS_11787687508614999748: VariantsMap = [
    &["savorers"],
    &["savourers"],
    &["savourers"],
    &["savourers"],
];

pub(crate) static ENTRY_SAVORER_15451082667887423810: VariantsMap =
    [&["savorer"], &["savourer"], &["savourer"], &["savourer"]];

pub(crate) static ENTRY_SAVORIER_6303687459165405447: VariantsMap = [
    &["savorier"],
    &["savourier"],
    &["savourier"],
    &["savourier"],
];

pub(crate) static ENTRY_SAVORIEST_17206072645132615270: VariantsMap = [
    &["savoriest"],
    &["savouriest"],
    &["savouriest"],
    &["savouriest"],
];

pub(crate) static ENTRY_SAVORIES_9905015268014283974: VariantsMap = [
    &["savories"],
    &["savouries"],
    &["savouries"],
    &["savouries"],
];

pub(crate) static ENTRY_SAVORILIES_6579003325829163067: VariantsMap = [
    &["savorilies"],
    &["savourilies"],
    &["savourilies"],
    &["savourilies"],
];

pub(crate) static ENTRY_SAVORILY_15448585721024708912: VariantsMap = [
    &["savorily"],
    &["savourily"],
    &["savourily"],
    &["savourily"],
];

pub(crate) static ENTRY_SAVORINESSES_10065971623388592088: VariantsMap = [
    &["savorinesses"],
    &["savourinesses"],
    &["savourinesses"],
    &["savourinesses"],
];

pub(crate) static ENTRY_SAVORINESS_13968014337021909965: VariantsMap = [
    &["savoriness"],
    &["savouriness"],
    &["savouriness"],
    &["savouriness"],
];

pub(crate) static ENTRY_SAVORINGLIER_10137328596366632769: VariantsMap = [
    &["savoringlier"],
    &["savouringlier"],
    &["savouringlier"],
    &["savouringlier"],
];

pub(crate) static ENTRY_SAVORINGLIEST_15169226019310047256: VariantsMap = [
    &["savoringliest"],
    &["savouringliest"],
    &["savouringliest"],
    &["savouringliest"],
];

pub(crate) static ENTRY_SAVORINGLIES_16962535350125218546: VariantsMap = [
    &["savoringlies"],
    &["savouringlies"],
    &["savouringlies"],
    &["savouringlies"],
];

pub(crate) static ENTRY_SAVORINGLY_188792191137435132: VariantsMap = [
    &["savoringly"],
    &["savouringly"],
    &["savouringly"],
    &["savouringly"],
];

pub(crate) static ENTRY_SAVORING_6763000239615004808: VariantsMap = [
    &["savoring"],
    &["savouring"],
    &["savouring"],
    &["savouring"],
];

pub(crate) static ENTRY_SAVORLESSER_15665106123472425180: VariantsMap = [
    &["savorlesser"],
    &["savourlesser"],
    &["savourlesser"],
    &["savourlesser"],
];

pub(crate) static ENTRY_SAVORLESSEST_9190940621548012509: VariantsMap = [
    &["savorlessest"],
    &["savourlessest"],
    &["savourlessest"],
    &["savourlessest"],
];

pub(crate) static ENTRY_SAVORLESSES_7670792878511449933: VariantsMap = [
    &["savorlesses"],
    &["savourlesses"],
    &["savourlesses"],
    &["savourlesses"],
];

pub(crate) static ENTRY_SAVORLESS_8806630377030275637: VariantsMap = [
    &["savorless"],
    &["savourless"],
    &["savourless"],
    &["savourless"],
];

pub(crate) static ENTRY_SAVORLY_7024626808530014518: VariantsMap =
    [&["savorly"], &["savourly"], &["savourly"], &["savourly"]];

pub(crate) static ENTRY_SAVOROUSER_1727203765225429536: VariantsMap = [
    &["savorouser"],
    &["savourouser"],
    &["savourouser"],
    &["savourouser"],
];

pub(crate) static ENTRY_SAVOROUSEST_3100516665411914597: VariantsMap = [
    &["savorousest"],
    &["savourousest"],
    &["savourousest"],
    &["savourousest"],
];

pub(crate) static ENTRY_SAVOROUS_11062427848542635268: VariantsMap = [
    &["savorous"],
    &["savourous"],
    &["savourous"],
    &["savourous"],
];

pub(crate) static ENTRY_SAVORS_17864742679821873261: VariantsMap =
    [&["savors"], &["savours"], &["savours"], &["savours"]];

pub(crate) static ENTRY_SAVORY_18035223196990312431: VariantsMap =
    [&["savory"], &["savoury"], &["savoury"], &["savoury"]];

pub(crate) static ENTRY_SAVOR_7268353245862880587: VariantsMap =
    [&["savor"], &["savour"], &["savour"], &["savour"]];

pub(crate) static ENTRY_SAXONIZATIONS_2318853882636501152: VariantsMap = [
    &["saxonizations"],
    &["saxonisations"],
    &["saxonizations"],
    &["saxonisations"],
];

pub(crate) static ENTRY_SAXONIZATION_13920447163448605602: VariantsMap = [
    &["saxonization"],
    &["saxonisation"],
    &["saxonization"],
    &["saxonisation"],
];

pub(crate) static ENTRY_SAXONIZED_12370590955724966093: VariantsMap = [
    &["saxonized"],
    &["saxonised"],
    &["saxonized"],
    &["saxonised"],
];

pub(crate) static ENTRY_SAXONIZES_5168843153581210465: VariantsMap = [
    &["saxonizes"],
    &["saxonises"],
    &["saxonizes"],
    &["saxonises"],
];

pub(crate) static ENTRY_SAXONIZE_9115638203834180868: VariantsMap =
    [&["saxonize"], &["saxonise"], &["saxonize"], &["saxonise"]];

pub(crate) static ENTRY_SAXONIZING_15329045328723618614: VariantsMap = [
    &["saxonizing"],
    &["saxonising"],
    &["saxonizing"],
    &["saxonising"],
];

pub(crate) static ENTRY_SCANDALED_1881652881768607660: VariantsMap = [
    &["scandaled"],
    &["scandalled"],
    &["scandalled"],
    &["scandalled"],
];

pub(crate) static ENTRY_SCANDALING_6393905647064815426: VariantsMap = [
    &["scandaling"],
    &["scandalling"],
    &["scandalling"],
    &["scandalling"],
];

pub(crate) static ENTRY_SCANDALIZATIONS_7898720696120879071: VariantsMap = [
    &["scandalizations"],
    &["scandalisations"],
    &["scandalizations"],
    &["scandalisations"],
];

pub(crate) static ENTRY_SCANDALIZATION_1685701550263872659: VariantsMap = [
    &["scandalization"],
    &["scandalisation"],
    &["scandalization"],
    &["scandalisation"],
];

pub(crate) static ENTRY_SCANDALIZED_11085730138699741279: VariantsMap = [
    &["scandalized"],
    &["scandalised"],
    &["scandalized"],
    &["scandalised"],
];

pub(crate) static ENTRY_SCANDALIZERS_15197543038839412069: VariantsMap = [
    &["scandalizers"],
    &["scandalisers"],
    &["scandalizers"],
    &["scandalisers"],
];

pub(crate) static ENTRY_SCANDALIZER_5001392876013065734: VariantsMap = [
    &["scandalizer"],
    &["scandaliser"],
    &["scandalizer"],
    &["scandaliser"],
];

pub(crate) static ENTRY_SCANDALIZES_11290093653234602832: VariantsMap = [
    &["scandalizes"],
    &["scandalises"],
    &["scandalizes"],
    &["scandalises"],
];

pub(crate) static ENTRY_SCANDALIZE_14741991033789550594: VariantsMap = [
    &["scandalize"],
    &["scandalise"],
    &["scandalize"],
    &["scandalise"],
];

pub(crate) static ENTRY_SCANDALIZING_3021901097391350682: VariantsMap = [
    &["scandalizing"],
    &["scandalising"],
    &["scandalizing"],
    &["scandalising"],
];

pub(crate) static ENTRY_SCAPED_11838614965333604867: VariantsMap =
    [&["scaped"], &["scapaed"], &["scapaed"], &["scapaed"]];

pub(crate) static ENTRY_SCENARIOIZATIONS_5354132606433153264: VariantsMap = [
    &["scenarioizations"],
    &["scenarioisations"],
    &["scenarioizations"],
    &["scenarioisations"],
];

pub(crate) static ENTRY_SCENARIOIZATION_11568016783832907853: VariantsMap = [
    &["scenarioization"],
    &["scenarioisation"],
    &["scenarioization"],
    &["scenarioisation"],
];

pub(crate) static ENTRY_SCENARIOIZES_482550746480154259: VariantsMap = [
    &["scenarioizes"],
    &["scenarioises"],
    &["scenarioizes"],
    &["scenarioises"],
];

pub(crate) static ENTRY_SCENARIOIZE_10573641030848141241: VariantsMap = [
    &["scenarioize"],
    &["scenarioise"],
    &["scenarioize"],
    &["scenarioise"],
];

pub(crate) static ENTRY_SCENARIZATIONS_15320566627597434538: VariantsMap = [
    &["scenarizations"],
    &["scenarisations"],
    &["scenarizations"],
    &["scenarisations"],
];

pub(crate) static ENTRY_SCENARIZATION_8267687093775898269: VariantsMap = [
    &["scenarization"],
    &["scenarisation"],
    &["scenarization"],
    &["scenarisation"],
];

pub(crate) static ENTRY_SCENARIZED_13846545490430585820: VariantsMap = [
    &["scenarized"],
    &["scenarised"],
    &["scenarized"],
    &["scenarised"],
];

pub(crate) static ENTRY_SCENARIZES_843838764401688514: VariantsMap = [
    &["scenarizes"],
    &["scenarises"],
    &["scenarizes"],
    &["scenarises"],
];

pub(crate) static ENTRY_SCENARIZE_7764842416771702084: VariantsMap = [
    &["scenarize"],
    &["scenarise"],
    &["scenarize"],
    &["scenarise"],
];

pub(crate) static ENTRY_SCENARIZING_4139993347505235123: VariantsMap = [
    &["scenarizing"],
    &["scenarising"],
    &["scenarizing"],
    &["scenarising"],
];

pub(crate) static ENTRY_SCENA_13970174413239259767: VariantsMap =
    [&["scena"], &["scaena"], &["scaena"], &["scaena"]];

pub(crate) static ENTRY_SCEPTERDOM_17727578002621263233: VariantsMap = [
    &["scepterdom"],
    &["sceptredom"],
    &["sceptredom"],
    &["sceptredom"],
];

pub(crate) static ENTRY_SCEPTERED_4309367457883178779: VariantsMap =
    [&["sceptered"], &["sceptred"], &["sceptred"], &["sceptred"]];

pub(crate) static ENTRY_SCEPTERING_11235334755425728893: VariantsMap = [
    &["sceptering"],
    &["sceptring"],
    &["sceptring"],
    &["sceptring"],
];

pub(crate) static ENTRY_SCEPTERLESSES_3211886999266482763: VariantsMap = [
    &["scepterlesses"],
    &["sceptrelesses"],
    &["sceptrelesses"],
    &["sceptrelesses"],
];

pub(crate) static ENTRY_SCEPTERLESS_14014584389608395039: VariantsMap = [
    &["scepterless"],
    &["sceptreless"],
    &["sceptreless"],
    &["sceptreless"],
];

pub(crate) static ENTRY_SCEPTERS_17320251109355012747: VariantsMap =
    [&["scepters"], &["sceptres"], &["sceptres"], &["sceptres"]];

pub(crate) static ENTRY_SCEPTER_2634314741124349621: VariantsMap =
    [&["scepter"], &["sceptre"], &["sceptre"], &["sceptre"]];

pub(crate) static ENTRY_SCEVOR_17742563930876297446: VariantsMap =
    [&["scevor"], &["scevour"], &["scevour"], &["scevour"]];

pub(crate) static ENTRY_SCHEDULIZES_11998681560108042990: VariantsMap = [
    &["schedulizes"],
    &["schedulises"],
    &["schedulizes"],
    &["schedulises"],
];

pub(crate) static ENTRY_SCHEDULIZE_5696008845820733070: VariantsMap = [
    &["schedulize"],
    &["schedulise"],
    &["schedulize"],
    &["schedulise"],
];

pub(crate) static ENTRY_SCHEMATIZATIONS_10214946104759561540: VariantsMap = [
    &["schematizations"],
    &["schematisations"],
    &["schematizations"],
    &["schematisations"],
];

pub(crate) static ENTRY_SCHEMATIZATION_12280133115355003981: VariantsMap = [
    &["schematization"],
    &["schematisation"],
    &["schematization"],
    &["schematisation"],
];

pub(crate) static ENTRY_SCHEMATIZED_6065522728213827719: VariantsMap = [
    &["schematized"],
    &["schematised"],
    &["schematized"],
    &["schematised"],
];

pub(crate) static ENTRY_SCHEMATIZERS_4368175659338148324: VariantsMap = [
    &["schematizers"],
    &["schematisers"],
    &["schematizers"],
    &["schematisers"],
];

pub(crate) static ENTRY_SCHEMATIZER_5371535585135012777: VariantsMap = [
    &["schematizer"],
    &["schematiser"],
    &["schematizer"],
    &["schematiser"],
];

pub(crate) static ENTRY_SCHEMATIZES_5464172182149518273: VariantsMap = [
    &["schematizes"],
    &["schematises"],
    &["schematizes"],
    &["schematises"],
];

pub(crate) static ENTRY_SCHEMATIZE_17242177807075430578: VariantsMap = [
    &["schematize"],
    &["schematise"],
    &["schematize"],
    &["schematise"],
];

pub(crate) static ENTRY_SCHEMATIZING_5183188849408735782: VariantsMap = [
    &["schematizing"],
    &["schematising"],
    &["schematizing"],
    &["schematising"],
];

pub(crate) static ENTRY_SCHILLERIZATIONS_1097721139918947159: VariantsMap = [
    &["schillerizations"],
    &["schillerisations"],
    &["schillerizations"],
    &["schillerisations"],
];

pub(crate) static ENTRY_SCHILLERIZATION_1975534132552758492: VariantsMap = [
    &["schillerization"],
    &["schillerisation"],
    &["schillerization"],
    &["schillerisation"],
];

pub(crate) static ENTRY_SCHILLERIZED_8127379884079449773: VariantsMap = [
    &["schillerized"],
    &["schillerised"],
    &["schillerized"],
    &["schillerised"],
];

pub(crate) static ENTRY_SCHILLERIZES_7351365606194447161: VariantsMap = [
    &["schillerizes"],
    &["schillerises"],
    &["schillerizes"],
    &["schillerises"],
];

pub(crate) static ENTRY_SCHILLERIZE_955273459416220138: VariantsMap = [
    &["schillerize"],
    &["schillerise"],
    &["schillerize"],
    &["schillerise"],
];

pub(crate) static ENTRY_SCHILLERIZING_10704749465715034583: VariantsMap = [
    &["schillerizing"],
    &["schillerising"],
    &["schillerizing"],
    &["schillerising"],
];

pub(crate) static ENTRY_SCHISMATIZED_3002177619960082558: VariantsMap = [
    &["schismatized"],
    &["schismatised"],
    &["schismatized"],
    &["schismatised"],
];

pub(crate) static ENTRY_SCHISMATIZES_14979481534021263364: VariantsMap = [
    &["schismatizes"],
    &["schismatises"],
    &["schismatizes"],
    &["schismatises"],
];

pub(crate) static ENTRY_SCHISMATIZE_6430207238586664982: VariantsMap = [
    &["schismatize"],
    &["schismatise"],
    &["schismatize"],
    &["schismatise"],
];

pub(crate) static ENTRY_SCHISMATIZING_18224301025260482655: VariantsMap = [
    &["schismatizing"],
    &["schismatising"],
    &["schismatizing"],
    &["schismatising"],
];

pub(crate) static ENTRY_SCHISTOCELIA_3827142390073980619: VariantsMap = [
    &["schistocelia"],
    &["schistocoelia"],
    &["schistocoelia"],
    &["schistocoelia"],
];

pub(crate) static ENTRY_SCIENTIZED_3311115608371296118: VariantsMap = [
    &["scientized"],
    &["scientised"],
    &["scientized"],
    &["scientised"],
];

pub(crate) static ENTRY_SCIENTIZES_16694012140134350335: VariantsMap = [
    &["scientizes"],
    &["scientises"],
    &["scientizes"],
    &["scientises"],
];

pub(crate) static ENTRY_SCIENTIZE_10148514792697844596: VariantsMap = [
    &["scientize"],
    &["scientise"],
    &["scientize"],
    &["scientise"],
];

pub(crate) static ENTRY_SCIENTIZING_15849402639331786377: VariantsMap = [
    &["scientizing"],
    &["scientising"],
    &["scientizing"],
    &["scientising"],
];

pub(crate) static ENTRY_SCLERE_9746329931158778294: VariantsMap =
    [&["sclere"], &["sclerae"], &["sclerae"], &["sclerae"]];

pub(crate) static ENTRY_SCLEROTIZATION_15026971996955314482: VariantsMap = [
    &["sclerotization"],
    &["sclerotisation"],
    &["sclerotization"],
    &["sclerotisation"],
];

pub(crate) static ENTRY_SCLEROTIZED_13849096612293754473: VariantsMap = [
    &["sclerotized"],
    &["sclerotised"],
    &["sclerotized"],
    &["sclerotised"],
];

pub(crate) static ENTRY_SCLEROTIZES_15593295504016734858: VariantsMap = [
    &["sclerotizes"],
    &["sclerotises"],
    &["sclerotizes"],
    &["sclerotises"],
];

pub(crate) static ENTRY_SCLEROTIZE_11388338623919176754: VariantsMap = [
    &["sclerotize"],
    &["sclerotise"],
    &["sclerotize"],
    &["sclerotise"],
];

pub(crate) static ENTRY_SCLEROTIZING_5997112524177379321: VariantsMap = [
    &["sclerotizing"],
    &["sclerotising"],
    &["sclerotizing"],
    &["sclerotising"],
];

pub(crate) static ENTRY_SCORSED_16083267741792838932: VariantsMap =
    [&["scorsed"], &["scoursed"], &["scoursed"], &["scoursed"]];

pub(crate) static ENTRY_SCORSES_7140175579256526605: VariantsMap =
    [&["scorses"], &["scourses"], &["scourses"], &["scourses"]];

pub(crate) static ENTRY_SCORSE_15078698805947392168: VariantsMap =
    [&["scorse"], &["scourse"], &["scourse"], &["scourse"]];

pub(crate) static ENTRY_SCORSING_3188653853529728017: VariantsMap = [
    &["scorsing"],
    &["scoursing"],
    &["scoursing"],
    &["scoursing"],
];

pub(crate) static ENTRY_SCOTTICIZED_9176139469703286390: VariantsMap = [
    &["scotticized"],
    &["scotticised"],
    &["scotticized"],
    &["scotticised"],
];

pub(crate) static ENTRY_SCOTTICIZES_4892539654566755234: VariantsMap = [
    &["scotticizes"],
    &["scotticises"],
    &["scotticizes"],
    &["scotticises"],
];

pub(crate) static ENTRY_SCOTTICIZE_17245280330015663168: VariantsMap = [
    &["scotticize"],
    &["scotticise"],
    &["scotticize"],
    &["scotticise"],
];

pub(crate) static ENTRY_SCOTTICIZING_2341284462577725385: VariantsMap = [
    &["scotticizing"],
    &["scotticising"],
    &["scotticizing"],
    &["scotticising"],
];

pub(crate) static ENTRY_SCRIPTURALIZES_6331235887129690543: VariantsMap = [
    &["scripturalizes"],
    &["scripturalises"],
    &["scripturalizes"],
    &["scripturalises"],
];

pub(crate) static ENTRY_SCRIPTURALIZE_16965719438311609740: VariantsMap = [
    &["scripturalize"],
    &["scripturalise"],
    &["scripturalize"],
    &["scripturalise"],
];

pub(crate) static ENTRY_SCRUTINIZATIONS_16986534141035954565: VariantsMap = [
    &["scrutinizations"],
    &["scrutinisations"],
    &["scrutinizations"],
    &["scrutinisations"],
];

pub(crate) static ENTRY_SCRUTINIZATION_17415762227653222410: VariantsMap = [
    &["scrutinization"],
    &["scrutinisation"],
    &["scrutinization"],
    &["scrutinisation"],
];

pub(crate) static ENTRY_SCRUTINIZED_138448923562603427: VariantsMap = [
    &["scrutinized"],
    &["scrutinised"],
    &["scrutinized"],
    &["scrutinised"],
];

pub(crate) static ENTRY_SCRUTINIZERS_9843755621018893931: VariantsMap = [
    &["scrutinizers"],
    &["scrutinisers"],
    &["scrutinizers"],
    &["scrutinisers"],
];

pub(crate) static ENTRY_SCRUTINIZER_16787119409611200536: VariantsMap = [
    &["scrutinizer"],
    &["scrutiniser"],
    &["scrutinizer"],
    &["scrutiniser"],
];

pub(crate) static ENTRY_SCRUTINIZES_14143862930988132210: VariantsMap = [
    &["scrutinizes"],
    &["scrutinises"],
    &["scrutinizes"],
    &["scrutinises"],
];

pub(crate) static ENTRY_SCRUTINIZE_2495160673295116727: VariantsMap = [
    &["scrutinize"],
    &["scrutinise"],
    &["scrutinize"],
    &["scrutinise"],
];

pub(crate) static ENTRY_SCRUTINIZINGLIES_6550131961437823868: VariantsMap = [
    &["scrutinizinglies"],
    &["scrutinisinglies"],
    &["scrutinizinglies"],
    &["scrutinisinglies"],
];

pub(crate) static ENTRY_SCRUTINIZINGLY_6838183545046867792: VariantsMap = [
    &["scrutinizingly"],
    &["scrutinisingly"],
    &["scrutinizingly"],
    &["scrutinisingly"],
];

pub(crate) static ENTRY_SCRUTINIZING_10650157705768207198: VariantsMap = [
    &["scrutinizing"],
    &["scrutinising"],
    &["scrutinizing"],
    &["scrutinising"],
];

pub(crate) static ENTRY_SEBORRHEAS_17176346816866257994: VariantsMap = [
    &["seborrheas"],
    &["seborrhoeas"],
    &["seborrheas"],
    &["seborrhoeas"],
];

pub(crate) static ENTRY_SEBORRHEA_5911144256699940196: VariantsMap = [
    &["seborrhea"],
    &["seborrhoea"],
    &["seborrhea"],
    &["seborrhoea"],
];

pub(crate) static ENTRY_SEBORRHEIC_1999320639299394735: VariantsMap = [
    &["seborrheic"],
    &["seborrhoeic"],
    &["seborrheic"],
    &["seborrhoeic"],
];

pub(crate) static ENTRY_SECTARIANIZATION_10329500434104171538: VariantsMap = [
    &["sectarianization"],
    &["sectarianisation"],
    &["sectarianization"],
    &["sectarianisation"],
];

pub(crate) static ENTRY_SECTARIANIZED_4323075987609952650: VariantsMap = [
    &["sectarianized"],
    &["sectarianised"],
    &["sectarianized"],
    &["sectarianised"],
];

pub(crate) static ENTRY_SECTARIANIZES_16984853238843084036: VariantsMap = [
    &["sectarianizes"],
    &["sectarianises"],
    &["sectarianizes"],
    &["sectarianises"],
];

pub(crate) static ENTRY_SECTARIANIZE_1734665934956097961: VariantsMap = [
    &["sectarianize"],
    &["sectarianise"],
    &["sectarianize"],
    &["sectarianise"],
];

pub(crate) static ENTRY_SECTARIANIZING_16586872715969887648: VariantsMap = [
    &["sectarianizing"],
    &["sectarianising"],
    &["sectarianizing"],
    &["sectarianising"],
];

pub(crate) static ENTRY_SECTIONALIZATIONS_3982770312292073083: VariantsMap = [
    &["sectionalizations"],
    &["sectionalisations"],
    &["sectionalizations"],
    &["sectionalisations"],
];

pub(crate) static ENTRY_SECTIONALIZATION_7372956859343047861: VariantsMap = [
    &["sectionalization"],
    &["sectionalisation"],
    &["sectionalization"],
    &["sectionalisation"],
];

pub(crate) static ENTRY_SECTIONALIZED_15063335524950991716: VariantsMap = [
    &["sectionalized"],
    &["sectionalised"],
    &["sectionalized"],
    &["sectionalised"],
];

pub(crate) static ENTRY_SECTIONALIZES_4950660755628313153: VariantsMap = [
    &["sectionalizes"],
    &["sectionalises"],
    &["sectionalizes"],
    &["sectionalises"],
];

pub(crate) static ENTRY_SECTIONALIZE_6731417115868692513: VariantsMap = [
    &["sectionalize"],
    &["sectionalise"],
    &["sectionalize"],
    &["sectionalise"],
];

pub(crate) static ENTRY_SECTIONALIZING_11106492791716994585: VariantsMap = [
    &["sectionalizing"],
    &["sectionalising"],
    &["sectionalizing"],
    &["sectionalising"],
];

pub(crate) static ENTRY_SECTIONIZATIONS_7138672770671968877: VariantsMap = [
    &["sectionizations"],
    &["sectionisations"],
    &["sectionizations"],
    &["sectionisations"],
];

pub(crate) static ENTRY_SECTIONIZATION_5059309185384353865: VariantsMap = [
    &["sectionization"],
    &["sectionisation"],
    &["sectionization"],
    &["sectionisation"],
];

pub(crate) static ENTRY_SECTIONIZED_4875591137215667653: VariantsMap = [
    &["sectionized"],
    &["sectionised"],
    &["sectionized"],
    &["sectionised"],
];

pub(crate) static ENTRY_SECTIONIZES_6513394183804020021: VariantsMap = [
    &["sectionizes"],
    &["sectionises"],
    &["sectionizes"],
    &["sectionises"],
];

pub(crate) static ENTRY_SECTIONIZE_3662925954380476587: VariantsMap = [
    &["sectionize"],
    &["sectionise"],
    &["sectionize"],
    &["sectionise"],
];

pub(crate) static ENTRY_SECTIONIZING_5472076843239971417: VariantsMap = [
    &["sectionizing"],
    &["sectionising"],
    &["sectionizing"],
    &["sectionising"],
];

pub(crate) static ENTRY_SECTORIZATIONS_1272351990881337199: VariantsMap = [
    &["sectorizations"],
    &["sectorisations"],
    &["sectorizations"],
    &["sectorisations"],
];

pub(crate) static ENTRY_SECTORIZATION_13074208022324954117: VariantsMap = [
    &["sectorization"],
    &["sectorisation"],
    &["sectorization"],
    &["sectorisation"],
];

pub(crate) static ENTRY_SECTORIZED_3551279836961169706: VariantsMap = [
    &["sectorized"],
    &["sectorised"],
    &["sectorized"],
    &["sectorised"],
];

pub(crate) static ENTRY_SECTORIZES_3606396525392350810: VariantsMap = [
    &["sectorizes"],
    &["sectorises"],
    &["sectorizes"],
    &["sectorises"],
];

pub(crate) static ENTRY_SECTORIZE_16349435987024198076: VariantsMap = [
    &["sectorize"],
    &["sectorise"],
    &["sectorize"],
    &["sectorise"],
];

pub(crate) static ENTRY_SECTORIZING_8533377571217926271: VariantsMap = [
    &["sectorizing"],
    &["sectorising"],
    &["sectorizing"],
    &["sectorising"],
];

pub(crate) static ENTRY_SECULARIZATIONS_18385656083748383194: VariantsMap = [
    &["secularizations"],
    &["secularisations"],
    &["secularizations"],
    &["secularisations"],
];

pub(crate) static ENTRY_SECULARIZATION_4665508589899729279: VariantsMap = [
    &["secularization"],
    &["secularisation"],
    &["secularization"],
    &["secularisation"],
];

pub(crate) static ENTRY_SECULARIZED_4356348361234297427: VariantsMap = [
    &["secularized"],
    &["secularised"],
    &["secularized"],
    &["secularised"],
];

pub(crate) static ENTRY_SECULARIZERS_959509276810245817: VariantsMap = [
    &["secularizers"],
    &["secularisers"],
    &["secularizers"],
    &["secularisers"],
];

pub(crate) static ENTRY_SECULARIZER_8531483256485763608: VariantsMap = [
    &["secularizer"],
    &["seculariser"],
    &["secularizer"],
    &["seculariser"],
];

pub(crate) static ENTRY_SECULARIZES_17808446279659322674: VariantsMap = [
    &["secularizes"],
    &["secularises"],
    &["secularizes"],
    &["secularises"],
];

pub(crate) static ENTRY_SECULARIZE_8691674226029598576: VariantsMap = [
    &["secularize"],
    &["secularise"],
    &["secularize"],
    &["secularise"],
];

pub(crate) static ENTRY_SECULARIZING_3038011191545839970: VariantsMap = [
    &["secularizing"],
    &["secularising"],
    &["secularizing"],
    &["secularising"],
];

pub(crate) static ENTRY_SECULUMS_1417148559086086183: VariantsMap = [
    &["seculums"],
    &["saeculums"],
    &["saeculums"],
    &["saeculums"],
];

pub(crate) static ENTRY_SECULUM_14580513950849648417: VariantsMap =
    [&["seculum"], &["saeculum"], &["saeculum"], &["saeculum"]];

pub(crate) static ENTRY_SECURITIZATIONS_14825154146636731025: VariantsMap = [
    &["securitizations"],
    &["securitisations"],
    &["securitizations"],
    &["securitisations"],
];

pub(crate) static ENTRY_SECURITIZATION_15104434495314939017: VariantsMap = [
    &["securitization"],
    &["securitisation"],
    &["securitization"],
    &["securitisation"],
];

pub(crate) static ENTRY_SECURITIZED_3968791155978166897: VariantsMap = [
    &["securitized"],
    &["securitised"],
    &["securitized"],
    &["securitised"],
];

pub(crate) static ENTRY_SECURITIZES_964431635949451194: VariantsMap = [
    &["securitizes"],
    &["securitises"],
    &["securitizes"],
    &["securitises"],
];

pub(crate) static ENTRY_SECURITIZE_14199237267948737829: VariantsMap = [
    &["securitize"],
    &["securitise"],
    &["securitize"],
    &["securitise"],
];

pub(crate) static ENTRY_SECURITIZING_10216698736284529838: VariantsMap = [
    &["securitizing"],
    &["securitising"],
    &["securitizing"],
    &["securitising"],
];

pub(crate) static ENTRY_SEED_321113364137294796: VariantsMap =
    [&["seed"], &["saeed"], &["saeed"], &["saeed"]];

pub(crate) static ENTRY_SEIZABLE_6299895893787769311: VariantsMap =
    [&["seizable"], &["seisable"], &["seizable"], &["seisable"]];

pub(crate) static ENTRY_SEIZERS_3311206369321638961: VariantsMap =
    [&["seizers"], &["seisers"], &["seizers"], &["seisers"]];

pub(crate) static ENTRY_SEIZER_12783623317695995317: VariantsMap =
    [&["seizer"], &["seiser"], &["seizer"], &["seiser"]];

pub(crate) static ENTRY_SEIZINGS_4904640050385479436: VariantsMap =
    [&["seizings"], &["seisings"], &["seizings"], &["seisings"]];

pub(crate) static ENTRY_SEIZINS_9859687246678890466: VariantsMap =
    [&["seizins"], &["seisins"], &["seizins"], &["seisins"]];

pub(crate) static ENTRY_SEIZIN_7497048659697035283: VariantsMap =
    [&["seizin"], &["seisin"], &["seizin"], &["seisin"]];

pub(crate) static ENTRY_SELLE_12446852445813787272: VariantsMap =
    [&["selle"], &["sellae"], &["sellae"], &["sellae"]];

pub(crate) static ENTRY_SEMENOV_2935209069826757991: VariantsMap =
    [&["semenov"], &["semaenov"], &["semaenov"], &["semaenov"]];

pub(crate) static ENTRY_SEMIANESTHETIC_603220656140835402: VariantsMap = [
    &["semianesthetic"],
    &["semianaesthetic"],
    &["semianaesthetic"],
    &["semianaesthetic"],
];

pub(crate) static ENTRY_SEMICARBONIZES_1797293499149887442: VariantsMap = [
    &["semicarbonizes"],
    &["semicarbonises"],
    &["semicarbonizes"],
    &["semicarbonises"],
];

pub(crate) static ENTRY_SEMICARBONIZE_8409774805182130142: VariantsMap = [
    &["semicarbonize"],
    &["semicarbonise"],
    &["semicarbonize"],
    &["semicarbonise"],
];

pub(crate) static ENTRY_SEMICIVILIZATIONS_5720575445164622576: VariantsMap = [
    &["semicivilizations"],
    &["semicivilisations"],
    &["semicivilizations"],
    &["semicivilisations"],
];

pub(crate) static ENTRY_SEMICIVILIZATION_15242671581564814120: VariantsMap = [
    &["semicivilization"],
    &["semicivilisation"],
    &["semicivilization"],
    &["semicivilisation"],
];

pub(crate) static ENTRY_SEMICIVILIZEDS_2897438279018112835: VariantsMap = [
    &["semicivilizeds"],
    &["semiciviliseds"],
    &["semicivilizeds"],
    &["semiciviliseds"],
];

pub(crate) static ENTRY_SEMICIVILIZED_4637923957818205530: VariantsMap = [
    &["semicivilized"],
    &["semicivilised"],
    &["semicivilized"],
    &["semicivilised"],
];

pub(crate) static ENTRY_SEMIFOSSILIZEDS_7710393663692254880: VariantsMap = [
    &["semifossilizeds"],
    &["semifossiliseds"],
    &["semifossilizeds"],
    &["semifossiliseds"],
];

pub(crate) static ENTRY_SEMIFOSSILIZED_9350071948098066704: VariantsMap = [
    &["semifossilized"],
    &["semifossilised"],
    &["semifossilized"],
    &["semifossilised"],
];

pub(crate) static ENTRY_SEMIHONORS_12462123375978457923: VariantsMap = [
    &["semihonors"],
    &["semihonours"],
    &["semihonours"],
    &["semihonours"],
];

pub(crate) static ENTRY_SEMIHONOR_7457444383686448706: VariantsMap = [
    &["semihonor"],
    &["semihonour"],
    &["semihonour"],
    &["semihonour"],
];

pub(crate) static ENTRY_SEMIHUMANIZEDS_17371974753621699342: VariantsMap = [
    &["semihumanizeds"],
    &["semihumaniseds"],
    &["semihumanizeds"],
    &["semihumaniseds"],
];

pub(crate) static ENTRY_SEMIHUMANIZED_17638546783529197556: VariantsMap = [
    &["semihumanized"],
    &["semihumanised"],
    &["semihumanized"],
    &["semihumanised"],
];

pub(crate) static ENTRY_SEMIMERCERIZEDS_6499518726299354192: VariantsMap = [
    &["semimercerizeds"],
    &["semimerceriseds"],
    &["semimercerizeds"],
    &["semimerceriseds"],
];

pub(crate) static ENTRY_SEMIMERCERIZED_7395245349141510735: VariantsMap = [
    &["semimercerized"],
    &["semimercerised"],
    &["semimercerized"],
    &["semimercerised"],
];

pub(crate) static ENTRY_SEMIMINERALIZEDS_7867390791226894698: VariantsMap = [
    &["semimineralizeds"],
    &["semimineraliseds"],
    &["semimineralizeds"],
    &["semimineraliseds"],
];

pub(crate) static ENTRY_SEMIMINERALIZED_16937456193304785591: VariantsMap = [
    &["semimineralized"],
    &["semimineralised"],
    &["semimineralized"],
    &["semimineralised"],
];

pub(crate) static ENTRY_SEMINARIZES_1867316917365228789: VariantsMap = [
    &["seminarizes"],
    &["seminarises"],
    &["seminarizes"],
    &["seminarises"],
];

pub(crate) static ENTRY_SEMINARIZE_16382184306789061126: VariantsMap = [
    &["seminarize"],
    &["seminarise"],
    &["seminarize"],
    &["seminarise"],
];

pub(crate) static ENTRY_SEMINATIONALIZATIONS_17200787028274260651: VariantsMap = [
    &["seminationalizations"],
    &["seminationalisations"],
    &["seminationalizations"],
    &["seminationalisations"],
];

pub(crate) static ENTRY_SEMINATIONALIZATION_14555714753335877358: VariantsMap = [
    &["seminationalization"],
    &["seminationalisation"],
    &["seminationalization"],
    &["seminationalisation"],
];

pub(crate) static ENTRY_SEMIORGANIZEDS_12008364003973962769: VariantsMap = [
    &["semiorganizeds"],
    &["semiorganiseds"],
    &["semiorganizeds"],
    &["semiorganiseds"],
];

pub(crate) static ENTRY_SEMIORGANIZED_6555791236440295060: VariantsMap = [
    &["semiorganized"],
    &["semiorganised"],
    &["semiorganized"],
    &["semiorganised"],
];

pub(crate) static ENTRY_SEMIOXIDIZEDS_6159043438844186188: VariantsMap = [
    &["semioxidizeds"],
    &["semioxidiseds"],
    &["semioxidizeds"],
    &["semioxidiseds"],
];

pub(crate) static ENTRY_SEMIOXIDIZED_5315770266537512020: VariantsMap = [
    &["semioxidized"],
    &["semioxidised"],
    &["semioxidized"],
    &["semioxidised"],
];

pub(crate) static ENTRY_SEMIOXYGENIZEDS_2404118500235275979: VariantsMap = [
    &["semioxygenizeds"],
    &["semioxygeniseds"],
    &["semioxygenizeds"],
    &["semioxygeniseds"],
];

pub(crate) static ENTRY_SEMIOXYGENIZED_15324068707582079762: VariantsMap = [
    &["semioxygenized"],
    &["semioxygenised"],
    &["semioxygenized"],
    &["semioxygenised"],
];

pub(crate) static ENTRY_SEMIPROFESSIONALIZEDS_15921777243236052227: VariantsMap = [
    &["semiprofessionalizeds"],
    &["semiprofessionaliseds"],
    &["semiprofessionalizeds"],
    &["semiprofessionaliseds"],
];

pub(crate) static ENTRY_SEMIPROFESSIONALIZED_17328179078904677907: VariantsMap = [
    &["semiprofessionalized"],
    &["semiprofessionalised"],
    &["semiprofessionalized"],
    &["semiprofessionalised"],
];

pub(crate) static ENTRY_SEMITE_8050506285147736874: VariantsMap =
    [&["semite"], &["semitae"], &["semitae"], &["semitae"]];

pub(crate) static ENTRY_SEMITICIZES_14074646105957764366: VariantsMap = [
    &["semiticizes"],
    &["semiticises"],
    &["semiticizes"],
    &["semiticises"],
];

pub(crate) static ENTRY_SEMITICIZE_2609826288107126486: VariantsMap = [
    &["semiticize"],
    &["semiticise"],
    &["semiticize"],
    &["semiticise"],
];

pub(crate) static ENTRY_SEMITIZATIONS_13807542369819114157: VariantsMap = [
    &["semitizations"],
    &["semitisations"],
    &["semitizations"],
    &["semitisations"],
];

pub(crate) static ENTRY_SEMITIZATION_2814386441666130450: VariantsMap = [
    &["semitization"],
    &["semitisation"],
    &["semitization"],
    &["semitisation"],
];

pub(crate) static ENTRY_SEMITIZED_17290416988749434330: VariantsMap = [
    &["semitized"],
    &["semitised"],
    &["semitized"],
    &["semitised"],
];

pub(crate) static ENTRY_SEMITIZES_11925278580314760912: VariantsMap = [
    &["semitizes"],
    &["semitises"],
    &["semitizes"],
    &["semitises"],
];

pub(crate) static ENTRY_SEMITIZE_941534843473568569: VariantsMap =
    [&["semitize"], &["semitise"], &["semitize"], &["semitise"]];

pub(crate) static ENTRY_SEMITIZING_2963320286843005115: VariantsMap = [
    &["semitizing"],
    &["semitising"],
    &["semitizing"],
    &["semitising"],
];

pub(crate) static ENTRY_SEMIVULCANIZEDS_13162744092050979464: VariantsMap = [
    &["semivulcanizeds"],
    &["semivulcaniseds"],
    &["semivulcanizeds"],
    &["semivulcaniseds"],
];

pub(crate) static ENTRY_SEMIVULCANIZED_14359220447980579562: VariantsMap = [
    &["semivulcanized"],
    &["semivulcanised"],
    &["semivulcanized"],
    &["semivulcanised"],
];

pub(crate) static ENTRY_SEMPER_8108831112347458625: VariantsMap =
    [&["semper"], &["sempre"], &["sempre"], &["sempre"]];

pub(crate) static ENTRY_SENILIZES_12383752921132409565: VariantsMap = [
    &["senilizes"],
    &["senilises"],
    &["senilizes"],
    &["senilises"],
];

pub(crate) static ENTRY_SENILIZE_8029621471742989343: VariantsMap =
    [&["senilize"], &["senilise"], &["senilize"], &["senilise"]];

pub(crate) static ENTRY_SENSATIONALIZED_15672094773557124276: VariantsMap = [
    &["sensationalized"],
    &["sensationalised"],
    &["sensationalized"],
    &["sensationalised"],
];

pub(crate) static ENTRY_SENSATIONALIZES_6023223775469404764: VariantsMap = [
    &["sensationalizes"],
    &["sensationalises"],
    &["sensationalizes"],
    &["sensationalises"],
];

pub(crate) static ENTRY_SENSATIONALIZE_3612877228613212928: VariantsMap = [
    &["sensationalize"],
    &["sensationalise"],
    &["sensationalize"],
    &["sensationalise"],
];

pub(crate) static ENTRY_SENSATIONALIZING_3700944391567555627: VariantsMap = [
    &["sensationalizing"],
    &["sensationalising"],
    &["sensationalizing"],
    &["sensationalising"],
];

pub(crate) static ENTRY_SENSITIZATIONS_13654430266545943350: VariantsMap = [
    &["sensitizations"],
    &["sensitisations"],
    &["sensitizations"],
    &["sensitisations"],
];

pub(crate) static ENTRY_SENSITIZATION_5562142577083526555: VariantsMap = [
    &["sensitization"],
    &["sensitisation"],
    &["sensitization"],
    &["sensitisation"],
];

pub(crate) static ENTRY_SENSITIZED_3980543883168272054: VariantsMap = [
    &["sensitized"],
    &["sensitised"],
    &["sensitized"],
    &["sensitised"],
];

pub(crate) static ENTRY_SENSITIZERS_18244790979608274479: VariantsMap = [
    &["sensitizers"],
    &["sensitisers"],
    &["sensitizers"],
    &["sensitisers"],
];

pub(crate) static ENTRY_SENSITIZER_10276855194832816189: VariantsMap = [
    &["sensitizer"],
    &["sensitiser"],
    &["sensitizer"],
    &["sensitiser"],
];

pub(crate) static ENTRY_SENSITIZES_577413584210679666: VariantsMap = [
    &["sensitizes"],
    &["sensitises"],
    &["sensitizes"],
    &["sensitises"],
];

pub(crate) static ENTRY_SENSITIZE_314572801275315620: VariantsMap = [
    &["sensitize"],
    &["sensitise"],
    &["sensitize"],
    &["sensitise"],
];

pub(crate) static ENTRY_SENSITIZING_7753308060738960399: VariantsMap = [
    &["sensitizing"],
    &["sensitising"],
    &["sensitizing"],
    &["sensitising"],
];

pub(crate) static ENTRY_SENSIZES_10006992614374882912: VariantsMap =
    [&["sensizes"], &["sensises"], &["sensizes"], &["sensises"]];

pub(crate) static ENTRY_SENSIZE_17053253712096730252: VariantsMap =
    [&["sensize"], &["sensise"], &["sensize"], &["sensise"]];

pub(crate) static ENTRY_SENSUALIZATIONS_4903697434091196616: VariantsMap = [
    &["sensualizations"],
    &["sensualisations"],
    &["sensualizations"],
    &["sensualisations"],
];

pub(crate) static ENTRY_SENSUALIZATION_18438288000507867475: VariantsMap = [
    &["sensualization"],
    &["sensualisation"],
    &["sensualization"],
    &["sensualisation"],
];

pub(crate) static ENTRY_SENSUALIZED_5812075572460333798: VariantsMap = [
    &["sensualized"],
    &["sensualised"],
    &["sensualized"],
    &["sensualised"],
];

pub(crate) static ENTRY_SENSUALIZES_6027047404814047775: VariantsMap = [
    &["sensualizes"],
    &["sensualises"],
    &["sensualizes"],
    &["sensualises"],
];

pub(crate) static ENTRY_SENSUALIZE_16925018484398827656: VariantsMap = [
    &["sensualize"],
    &["sensualise"],
    &["sensualize"],
    &["sensualise"],
];

pub(crate) static ENTRY_SENSUALIZING_8787028083330334024: VariantsMap = [
    &["sensualizing"],
    &["sensualising"],
    &["sensualizing"],
    &["sensualising"],
];

pub(crate) static ENTRY_SENTIMENTALIZATIONS_17372211169793747786: VariantsMap = [
    &["sentimentalizations"],
    &["sentimentalisations"],
    &["sentimentalizations"],
    &["sentimentalisations"],
];

pub(crate) static ENTRY_SENTIMENTALIZATION_9061044606950222949: VariantsMap = [
    &["sentimentalization"],
    &["sentimentalisation"],
    &["sentimentalization"],
    &["sentimentalisation"],
];

pub(crate) static ENTRY_SENTIMENTALIZED_7395272655741592803: VariantsMap = [
    &["sentimentalized"],
    &["sentimentalised"],
    &["sentimentalized"],
    &["sentimentalised"],
];

pub(crate) static ENTRY_SENTIMENTALIZERS_4236225160895961849: VariantsMap = [
    &["sentimentalizers"],
    &["sentimentalisers"],
    &["sentimentalizers"],
    &["sentimentalisers"],
];

pub(crate) static ENTRY_SENTIMENTALIZER_10892451054407203292: VariantsMap = [
    &["sentimentalizer"],
    &["sentimentaliser"],
    &["sentimentalizer"],
    &["sentimentaliser"],
];

pub(crate) static ENTRY_SENTIMENTALIZES_11687838812874218316: VariantsMap = [
    &["sentimentalizes"],
    &["sentimentalises"],
    &["sentimentalizes"],
    &["sentimentalises"],
];

pub(crate) static ENTRY_SENTIMENTALIZE_9074334910736712170: VariantsMap = [
    &["sentimentalize"],
    &["sentimentalise"],
    &["sentimentalize"],
    &["sentimentalise"],
];

pub(crate) static ENTRY_SENTIMENTALIZING_9011281810726145623: VariantsMap = [
    &["sentimentalizing"],
    &["sentimentalising"],
    &["sentimentalizing"],
    &["sentimentalising"],
];

pub(crate) static ENTRY_SENTINELED_15164238305822628477: VariantsMap = [
    &["sentineled"],
    &["sentinelled"],
    &["sentinelled"],
    &["sentinelled"],
];

pub(crate) static ENTRY_SENTINELING_11104191602796418564: VariantsMap = [
    &["sentineling"],
    &["sentinelling"],
    &["sentinelling"],
    &["sentinelling"],
];

pub(crate) static ENTRY_SEPALEDDER_18149050438233478463: VariantsMap = [
    &["sepaledder"],
    &["sepalledder"],
    &["sepalledder"],
    &["sepalledder"],
];

pub(crate) static ENTRY_SEPALEDDEST_16726621142433806076: VariantsMap = [
    &["sepaleddest"],
    &["sepalleddest"],
    &["sepalleddest"],
    &["sepalleddest"],
];

pub(crate) static ENTRY_SEPALED_12090295642380405616: VariantsMap =
    [&["sepaled"], &["sepalled"], &["sepalled"], &["sepalled"]];

pub(crate) static ENTRY_SEPTEMBRIZERS_5568167245143709930: VariantsMap = [
    &["septembrizers"],
    &["septembrisers"],
    &["septembrizers"],
    &["septembrisers"],
];

pub(crate) static ENTRY_SEPTEMBRIZER_14180678052471741675: VariantsMap = [
    &["septembrizer"],
    &["septembriser"],
    &["septembrizer"],
    &["septembriser"],
];

pub(crate) static ENTRY_SEPTEMIA_17627373967872968416: VariantsMap = [
    &["septemia"],
    &["septaemia"],
    &["septaemia"],
    &["septaemia"],
];

pub(crate) static ENTRY_SEPTICEMIAS_12503495764642957726: VariantsMap = [
    &["septicemias"],
    &["septicaemias"],
    &["septicemias"],
    &["septicaemias"],
];

pub(crate) static ENTRY_SEPTICEMIA_11397632634952601953: VariantsMap = [
    &["septicemia"],
    &["septicaemia"],
    &["septicemia"],
    &["septicaemia"],
];

pub(crate) static ENTRY_SEPTICEMIC_17224432424285146941: VariantsMap = [
    &["septicemic"],
    &["septicaemic"],
    &["septicemic"],
    &["septicaemic"],
];

pub(crate) static ENTRY_SEPTICIZATIONS_14828929428564717195: VariantsMap = [
    &["septicizations"],
    &["septicisations"],
    &["septicizations"],
    &["septicisations"],
];

pub(crate) static ENTRY_SEPTICIZATION_14002989906709765055: VariantsMap = [
    &["septicization"],
    &["septicisation"],
    &["septicization"],
    &["septicisation"],
];

pub(crate) static ENTRY_SEPTICOLORED_5211825597090733015: VariantsMap = [
    &["septicolored"],
    &["septicoloured"],
    &["septicoloured"],
    &["septicoloured"],
];

pub(crate) static ENTRY_SEPULCHERED_13156739439863668198: VariantsMap = [
    &["sepulchered"],
    &["sepulchred"],
    &["sepulchred"],
    &["sepulchred"],
];

pub(crate) static ENTRY_SEPULCHERING_15916701810150961536: VariantsMap = [
    &["sepulchering"],
    &["sepulchring"],
    &["sepulchring"],
    &["sepulchring"],
];

pub(crate) static ENTRY_SEPULCHERS_17907839135565596907: VariantsMap = [
    &["sepulchers"],
    &["sepulchres"],
    &["sepulchres"],
    &["sepulchres"],
];

pub(crate) static ENTRY_SEPULCHER_5901571127124975988: VariantsMap = [
    &["sepulcher"],
    &["sepulchre"],
    &["sepulchre"],
    &["sepulchre"],
];

pub(crate) static ENTRY_SEPULCHRALIZES_11618984573736373917: VariantsMap = [
    &["sepulchralizes"],
    &["sepulchralises"],
    &["sepulchralizes"],
    &["sepulchralises"],
];

pub(crate) static ENTRY_SEPULCHRALIZE_471485549032044787: VariantsMap = [
    &["sepulchralize"],
    &["sepulchralise"],
    &["sepulchralize"],
    &["sepulchralise"],
];

pub(crate) static ENTRY_SEQUENTIALIZED_13342886831978411557: VariantsMap = [
    &["sequentialized"],
    &["sequentialised"],
    &["sequentialized"],
    &["sequentialised"],
];

pub(crate) static ENTRY_SEQUENTIALIZES_903062549732554575: VariantsMap = [
    &["sequentializes"],
    &["sequentialises"],
    &["sequentializes"],
    &["sequentialises"],
];

pub(crate) static ENTRY_SEQUENTIALIZE_7687249845236795: VariantsMap = [
    &["sequentialize"],
    &["sequentialise"],
    &["sequentialize"],
    &["sequentialise"],
];

pub(crate) static ENTRY_SEQUENTIALIZING_12526259102466204603: VariantsMap = [
    &["sequentializing"],
    &["sequentialising"],
    &["sequentializing"],
    &["sequentialising"],
];

pub(crate) static ENTRY_SERENIZES_3953496351859270409: VariantsMap = [
    &["serenizes"],
    &["serenises"],
    &["serenizes"],
    &["serenises"],
];

pub(crate) static ENTRY_SERENIZE_13954843561052019043: VariantsMap =
    [&["serenize"], &["serenise"], &["serenize"], &["serenise"]];

pub(crate) static ENTRY_SERIALIZABILITY_7773982292760873044: VariantsMap = [
    &["serializability"],
    &["serialisability"],
    &["serializability"],
    &["serialisability"],
];

pub(crate) static ENTRY_SERIALIZABLE_1502323051817082784: VariantsMap = [
    &["serializable"],
    &["serialisable"],
    &["serializable"],
    &["serialisable"],
];

pub(crate) static ENTRY_SERIALIZATIONS_16803629240691327375: VariantsMap = [
    &["serializations"],
    &["serialisations"],
    &["serializations"],
    &["serialisations"],
];

pub(crate) static ENTRY_SERIALIZATION_8026595017898253094: VariantsMap = [
    &["serialization"],
    &["serialisation"],
    &["serialization"],
    &["serialisation"],
];

pub(crate) static ENTRY_SERIALIZED_1888364664748280784: VariantsMap = [
    &["serialized"],
    &["serialised"],
    &["serialized"],
    &["serialised"],
];

pub(crate) static ENTRY_SERIALIZES_15444051215059194506: VariantsMap = [
    &["serializes"],
    &["serialises"],
    &["serializes"],
    &["serialises"],
];

pub(crate) static ENTRY_SERIALIZE_14044145149155879461: VariantsMap = [
    &["serialize"],
    &["serialise"],
    &["serialize"],
    &["serialise"],
];

pub(crate) static ENTRY_SERIALIZING_13270926386983604461: VariantsMap = [
    &["serializing"],
    &["serialising"],
    &["serializing"],
    &["serialising"],
];

pub(crate) static ENTRY_SERICITIZATIONS_3976668030061776680: VariantsMap = [
    &["sericitizations"],
    &["sericitisations"],
    &["sericitizations"],
    &["sericitisations"],
];

pub(crate) static ENTRY_SERICITIZATION_8474782731600998020: VariantsMap = [
    &["sericitization"],
    &["sericitisation"],
    &["sericitization"],
    &["sericitisation"],
];

pub(crate) static ENTRY_SERMONIZED_5857494441485850990: VariantsMap = [
    &["sermonized"],
    &["sermonised"],
    &["sermonized"],
    &["sermonised"],
];

pub(crate) static ENTRY_SERMONIZERS_10627211662032897475: VariantsMap = [
    &["sermonizers"],
    &["sermonisers"],
    &["sermonizers"],
    &["sermonisers"],
];

pub(crate) static ENTRY_SERMONIZER_9999853450353383558: VariantsMap = [
    &["sermonizer"],
    &["sermoniser"],
    &["sermonizer"],
    &["sermoniser"],
];

pub(crate) static ENTRY_SERMONIZES_8207614673919524386: VariantsMap = [
    &["sermonizes"],
    &["sermonises"],
    &["sermonizes"],
    &["sermonises"],
];

pub(crate) static ENTRY_SERMONIZE_237921077671914948: VariantsMap = [
    &["sermonize"],
    &["sermonise"],
    &["sermonize"],
    &["sermonise"],
];

pub(crate) static ENTRY_SERMONIZING_9180710516114443189: VariantsMap = [
    &["sermonizing"],
    &["sermonising"],
    &["sermonizing"],
    &["sermonising"],
];

pub(crate) static ENTRY_SEROSE_10469280893173049445: VariantsMap =
    [&["serose"], &["serosae"], &["serosae"], &["serosae"]];

pub(crate) static ENTRY_SERPENTINIZATIONS_18216025003407152452: VariantsMap = [
    &["serpentinizations"],
    &["serpentinisations"],
    &["serpentinizations"],
    &["serpentinisations"],
];

pub(crate) static ENTRY_SERPENTINIZATION_5560169582513450767: VariantsMap = [
    &["serpentinization"],
    &["serpentinisation"],
    &["serpentinization"],
    &["serpentinisation"],
];

pub(crate) static ENTRY_SERPENTINIZED_7455002792008011952: VariantsMap = [
    &["serpentinized"],
    &["serpentinised"],
    &["serpentinized"],
    &["serpentinised"],
];

pub(crate) static ENTRY_SERPENTINIZES_8678826049205047091: VariantsMap = [
    &["serpentinizes"],
    &["serpentinises"],
    &["serpentinizes"],
    &["serpentinises"],
];

pub(crate) static ENTRY_SERPENTINIZE_9866240419191948775: VariantsMap = [
    &["serpentinize"],
    &["serpentinise"],
    &["serpentinize"],
    &["serpentinise"],
];

pub(crate) static ENTRY_SERPENTINIZING_9092366228143126428: VariantsMap = [
    &["serpentinizing"],
    &["serpentinising"],
    &["serpentinizing"],
    &["serpentinising"],
];

pub(crate) static ENTRY_SERPENTIZED_4330573112091394638: VariantsMap = [
    &["serpentized"],
    &["serpentised"],
    &["serpentized"],
    &["serpentised"],
];

pub(crate) static ENTRY_SERPENTIZES_1625704616745057635: VariantsMap = [
    &["serpentizes"],
    &["serpentises"],
    &["serpentizes"],
    &["serpentises"],
];

pub(crate) static ENTRY_SERPENTIZE_3384972221379685069: VariantsMap = [
    &["serpentize"],
    &["serpentise"],
    &["serpentize"],
    &["serpentise"],
];

pub(crate) static ENTRY_SERPENTIZING_9593903542078580092: VariantsMap = [
    &["serpentizing"],
    &["serpentising"],
    &["serpentizing"],
    &["serpentising"],
];

pub(crate) static ENTRY_SERRE_3180474638636958561: VariantsMap =
    [&["serre"], &["serrae"], &["serrae"], &["serrae"]];

pub(crate) static ENTRY_SERVILIZES_8276384829138801671: VariantsMap = [
    &["servilizes"],
    &["servilises"],
    &["servilizes"],
    &["servilises"],
];

pub(crate) static ENTRY_SERVILIZE_14834152406961369316: VariantsMap = [
    &["servilize"],
    &["servilise"],
    &["servilize"],
    &["servilise"],
];

pub(crate) static ENTRY_SETA_9673520022199067907: VariantsMap =
    [&["seta"], &["saeta"], &["saeta"], &["saeta"]];

pub(crate) static ENTRY_SETULE_8234529077451319159: VariantsMap =
    [&["setule"], &["setulae"], &["setulae"], &["setulae"]];

pub(crate) static ENTRY_SEVERALIZES_10859120750647710400: VariantsMap = [
    &["severalizes"],
    &["severalises"],
    &["severalizes"],
    &["severalises"],
];

pub(crate) static ENTRY_SEVERALIZE_10314418645470673257: VariantsMap = [
    &["severalize"],
    &["severalise"],
    &["severalize"],
    &["severalise"],
];

pub(crate) static ENTRY_SEVERIZATIONS_14701963156627030317: VariantsMap = [
    &["severizations"],
    &["severisations"],
    &["severizations"],
    &["severisations"],
];

pub(crate) static ENTRY_SEVERIZATION_5132300365352798030: VariantsMap = [
    &["severization"],
    &["severisation"],
    &["severization"],
    &["severisation"],
];

pub(crate) static ENTRY_SEVERIZES_3513402572065109149: VariantsMap = [
    &["severizes"],
    &["severises"],
    &["severizes"],
    &["severises"],
];

pub(crate) static ENTRY_SEVERIZE_17078342800840793427: VariantsMap =
    [&["severize"], &["severise"], &["severize"], &["severise"]];

pub(crate) static ENTRY_SEXUALIZATIONS_6419691977489313070: VariantsMap = [
    &["sexualizations"],
    &["sexualisations"],
    &["sexualizations"],
    &["sexualisations"],
];

pub(crate) static ENTRY_SEXUALIZATION_598558153365374975: VariantsMap = [
    &["sexualization"],
    &["sexualisation"],
    &["sexualization"],
    &["sexualisation"],
];

pub(crate) static ENTRY_SEXUALIZED_17516220740309805973: VariantsMap = [
    &["sexualized"],
    &["sexualised"],
    &["sexualized"],
    &["sexualised"],
];

pub(crate) static ENTRY_SEXUALIZES_14899097055849161352: VariantsMap = [
    &["sexualizes"],
    &["sexualises"],
    &["sexualizes"],
    &["sexualises"],
];

pub(crate) static ENTRY_SEXUALIZE_9305579592150587788: VariantsMap = [
    &["sexualize"],
    &["sexualise"],
    &["sexualize"],
    &["sexualise"],
];

pub(crate) static ENTRY_SEXUALIZING_13168796826287121808: VariantsMap = [
    &["sexualizing"],
    &["sexualising"],
    &["sexualizing"],
    &["sexualising"],
];

pub(crate) static ENTRY_SE_15361672265999879694: VariantsMap =
    [&["se"], &["soe"], &["soe"], &["soe"]];

pub(crate) static ENTRY_SE_2594869031866220942: VariantsMap =
    [&["se"], &["sae"], &["sae"], &["sae"]];

pub(crate) static ENTRY_SHAKESPEARIZES_17778092510718324337: VariantsMap = [
    &["shakespearizes"],
    &["shakespearises"],
    &["shakespearizes"],
    &["shakespearises"],
];

pub(crate) static ENTRY_SHAKESPEARIZE_6066803341152707552: VariantsMap = [
    &["shakespearize"],
    &["shakespearise"],
    &["shakespearize"],
    &["shakespearise"],
];

pub(crate) static ENTRY_SHEIKHS_10762489381044075569: VariantsMap =
    [&["sheikhs"], &["sheikhs"], &["sheiks"], &["sheikhs"]];

pub(crate) static ENTRY_SHEIKH_8983659288141972445: VariantsMap =
    [&["sheikh"], &["sheikh"], &["sheik"], &["sheikh"]];

pub(crate) static ENTRY_SHEPHERDIZES_4618442149214601958: VariantsMap = [
    &["shepherdizes"],
    &["shepherdises"],
    &["shepherdizes"],
    &["shepherdises"],
];

pub(crate) static ENTRY_SHEPHERDIZE_9589644434591127897: VariantsMap = [
    &["shepherdize"],
    &["shepherdise"],
    &["shepherdize"],
    &["shepherdise"],
];

pub(crate) static ENTRY_SHERARDIZED_3013055586963630691: VariantsMap = [
    &["sherardized"],
    &["sherardised"],
    &["sherardized"],
    &["sherardised"],
];

pub(crate) static ENTRY_SHERARDIZES_5495265908461761242: VariantsMap = [
    &["sherardizes"],
    &["sherardises"],
    &["sherardizes"],
    &["sherardises"],
];

pub(crate) static ENTRY_SHERARDIZE_16617170604726285533: VariantsMap = [
    &["sherardize"],
    &["sherardise"],
    &["sherardize"],
    &["sherardise"],
];

pub(crate) static ENTRY_SHERARDIZING_6141668254225889701: VariantsMap = [
    &["sherardizing"],
    &["sherardising"],
    &["sherardizing"],
    &["sherardising"],
];

pub(crate) static ENTRY_SHERE_8519598491987964057: VariantsMap =
    [&["shere"], &["shree"], &["shree"], &["shree"]];

pub(crate) static ENTRY_SHER_17217175326411018784: VariantsMap =
    [&["sher"], &["shoer"], &["shoer"], &["shoer"]];

pub(crate) static ENTRY_SHINTOIZES_7087800735292630340: VariantsMap = [
    &["shintoizes"],
    &["shintoises"],
    &["shintoizes"],
    &["shintoises"],
];

pub(crate) static ENTRY_SHINTOIZE_11809502309481638164: VariantsMap = [
    &["shintoize"],
    &["shintoise"],
    &["shintoize"],
    &["shintoise"],
];

pub(crate) static ENTRY_SHKODER_5585881395862931532: VariantsMap =
    [&["shkoder"], &["shkodaer"], &["shkodaer"], &["shkodaer"]];

pub(crate) static ENTRY_SHOVELED_15062634087638291011: VariantsMap = [
    &["shoveled"],
    &["shovelled"],
    &["shovelled"],
    &["shovelled"],
];

pub(crate) static ENTRY_SHOVELERS_2279935736385901824: VariantsMap = [
    &["shovelers"],
    &["shovellers"],
    &["shovellers"],
    &["shovellers"],
];

pub(crate) static ENTRY_SHOVELER_7861570800291993508: VariantsMap = [
    &["shoveler"],
    &["shoveller"],
    &["shoveller"],
    &["shoveller"],
];

pub(crate) static ENTRY_SHOVELING_4658042570347509024: VariantsMap = [
    &["shoveling"],
    &["shovelling"],
    &["shovelling"],
    &["shovelling"],
];

pub(crate) static ENTRY_SHRIVELED_9173718681891056162: VariantsMap = [
    &["shriveled"],
    &["shrivelled"],
    &["shrivelled"],
    &["shrivelled"],
];

pub(crate) static ENTRY_SHRIVELING_9001440579199169374: VariantsMap = [
    &["shriveling"],
    &["shrivelling"],
    &["shrivelling"],
    &["shrivelling"],
];

pub(crate) static ENTRY_SIALORRHEA_6484075731495212593: VariantsMap = [
    &["sialorrhea"],
    &["sialorrhoea"],
    &["sialorrhoea"],
    &["sialorrhoea"],
];

pub(crate) static ENTRY_SIDEREALIZES_5077853180450618510: VariantsMap = [
    &["siderealizes"],
    &["siderealises"],
    &["siderealizes"],
    &["siderealises"],
];

pub(crate) static ENTRY_SIDEREALIZE_13138990443604086580: VariantsMap = [
    &["siderealize"],
    &["siderealise"],
    &["siderealize"],
    &["siderealise"],
];

pub(crate) static ENTRY_SIGNALED_4517098988465661597: VariantsMap = [
    &["signaled"],
    &["signalled"],
    &["signalled"],
    &["signalled"],
];

pub(crate) static ENTRY_SIGNALERS_8816754826640457370: VariantsMap = [
    &["signalers"],
    &["signallers"],
    &["signallers"],
    &["signallers"],
];

pub(crate) static ENTRY_SIGNALER_11540498906832061128: VariantsMap = [
    &["signaler"],
    &["signaller"],
    &["signaller"],
    &["signaller"],
];

pub(crate) static ENTRY_SIGNALING_38367410174135288: VariantsMap = [
    &["signaling"],
    &["signalling"],
    &["signalling"],
    &["signalling"],
];

pub(crate) static ENTRY_SIGNALIZATION_6300811578722786643: VariantsMap = [
    &["signalization"],
    &["signalisation"],
    &["signalization"],
    &["signalisation"],
];

pub(crate) static ENTRY_SIGNALIZED_1328658457279077123: VariantsMap = [
    &["signalized"],
    &["signalised"],
    &["signalized"],
    &["signalised"],
];

pub(crate) static ENTRY_SIGNALIZES_15183847864880876512: VariantsMap = [
    &["signalizes"],
    &["signalises"],
    &["signalizes"],
    &["signalises"],
];

pub(crate) static ENTRY_SIGNALIZE_15445299234874331775: VariantsMap = [
    &["signalize"],
    &["signalise"],
    &["signalize"],
    &["signalise"],
];

pub(crate) static ENTRY_SIGNALIZING_14031692614622999963: VariantsMap = [
    &["signalizing"],
    &["signalising"],
    &["signalizing"],
    &["signalising"],
];

pub(crate) static ENTRY_SILED_10789450856636085272: VariantsMap =
    [&["siled"], &["siloed"], &["siloed"], &["siloed"]];

pub(crate) static ENTRY_SILICATIZATIONS_12311801766905293588: VariantsMap = [
    &["silicatizations"],
    &["silicatisations"],
    &["silicatizations"],
    &["silicatisations"],
];

pub(crate) static ENTRY_SILICATIZATION_15183159520715497593: VariantsMap = [
    &["silicatization"],
    &["silicatisation"],
    &["silicatization"],
    &["silicatisation"],
];

pub(crate) static ENTRY_SILICIDIZES_5809599080861161027: VariantsMap = [
    &["silicidizes"],
    &["silicidises"],
    &["silicidizes"],
    &["silicidises"],
];

pub(crate) static ENTRY_SILICIDIZE_7437759950119638805: VariantsMap = [
    &["silicidize"],
    &["silicidise"],
    &["silicidize"],
    &["silicidise"],
];

pub(crate) static ENTRY_SILICONIZES_14042775956262597692: VariantsMap = [
    &["siliconizes"],
    &["siliconises"],
    &["siliconizes"],
    &["siliconises"],
];

pub(crate) static ENTRY_SILICONIZE_13299465442579992202: VariantsMap = [
    &["siliconize"],
    &["siliconise"],
    &["siliconize"],
    &["siliconise"],
];

pub(crate) static ENTRY_SILICULE_16607190405791216240: VariantsMap = [
    &["silicule"],
    &["siliculae"],
    &["siliculae"],
    &["siliculae"],
];

pub(crate) static ENTRY_SILIQUE_350570384784907901: VariantsMap =
    [&["silique"], &["siliquae"], &["siliquae"], &["siliquae"]];

pub(crate) static ENTRY_SILVERIZED_3373734626849304080: VariantsMap = [
    &["silverized"],
    &["silverised"],
    &["silverized"],
    &["silverised"],
];

pub(crate) static ENTRY_SILVERIZERS_3216971382949916106: VariantsMap = [
    &["silverizers"],
    &["silverisers"],
    &["silverizers"],
    &["silverisers"],
];

pub(crate) static ENTRY_SILVERIZER_15985635737519372213: VariantsMap = [
    &["silverizer"],
    &["silveriser"],
    &["silverizer"],
    &["silveriser"],
];

pub(crate) static ENTRY_SILVERIZES_15646884568196086232: VariantsMap = [
    &["silverizes"],
    &["silverises"],
    &["silverizes"],
    &["silverises"],
];

pub(crate) static ENTRY_SILVERIZE_1532148002770872366: VariantsMap = [
    &["silverize"],
    &["silverise"],
    &["silverize"],
    &["silverise"],
];

pub(crate) static ENTRY_SILVERIZING_2034359189517396764: VariantsMap = [
    &["silverizing"],
    &["silverising"],
    &["silverizing"],
    &["silverising"],
];

pub(crate) static ENTRY_SIMILARIZES_304454380831943452: VariantsMap = [
    &["similarizes"],
    &["similarises"],
    &["similarizes"],
    &["similarises"],
];

pub(crate) static ENTRY_SIMILARIZE_2700808984999286713: VariantsMap = [
    &["similarize"],
    &["similarise"],
    &["similarize"],
    &["similarise"],
];

pub(crate) static ENTRY_SIMILIZED_10847342221820288097: VariantsMap = [
    &["similized"],
    &["similised"],
    &["similized"],
    &["similised"],
];

pub(crate) static ENTRY_SIMILIZES_8302279519436698760: VariantsMap = [
    &["similizes"],
    &["similises"],
    &["similizes"],
    &["similises"],
];

pub(crate) static ENTRY_SIMILIZE_5812929733131056435: VariantsMap =
    [&["similize"], &["similise"], &["similize"], &["similise"]];

pub(crate) static ENTRY_SIMILIZING_1862547745562599944: VariantsMap = [
    &["similizing"],
    &["similising"],
    &["similizing"],
    &["similising"],
];

pub(crate) static ENTRY_SIMONIZE_353967938486861116: VariantsMap =
    [&["simonize"], &["simonise"], &["simonize"], &["simonise"]];

pub(crate) static ENTRY_SINE_3419162536566868807: VariantsMap =
    [&["sine"], &["sinae"], &["sinae"], &["sinae"]];

pub(crate) static ENTRY_SINGULARIZATIONS_4989978119532359980: VariantsMap = [
    &["singularizations"],
    &["singularisations"],
    &["singularizations"],
    &["singularisations"],
];

pub(crate) static ENTRY_SINGULARIZATION_4933930872001149831: VariantsMap = [
    &["singularization"],
    &["singularisation"],
    &["singularization"],
    &["singularisation"],
];

pub(crate) static ENTRY_SINGULARIZED_14288632382502472280: VariantsMap = [
    &["singularized"],
    &["singularised"],
    &["singularized"],
    &["singularised"],
];

pub(crate) static ENTRY_SINGULARIZES_5332763602386440207: VariantsMap = [
    &["singularizes"],
    &["singularises"],
    &["singularizes"],
    &["singularises"],
];

pub(crate) static ENTRY_SINGULARIZE_12969745354704340141: VariantsMap = [
    &["singularize"],
    &["singularise"],
    &["singularize"],
    &["singularise"],
];

pub(crate) static ENTRY_SINGULARIZING_5008211603587521125: VariantsMap = [
    &["singularizing"],
    &["singularising"],
    &["singularizing"],
    &["singularising"],
];

pub(crate) static ENTRY_SINICIZED_1170587988011526807: VariantsMap = [
    &["sinicized"],
    &["sinicised"],
    &["sinicized"],
    &["sinicised"],
];

pub(crate) static ENTRY_SINICIZES_16916655538728896626: VariantsMap = [
    &["sinicizes"],
    &["sinicises"],
    &["sinicizes"],
    &["sinicises"],
];

pub(crate) static ENTRY_SINICIZE_5519781244176228688: VariantsMap =
    [&["sinicize"], &["sinicise"], &["sinicize"], &["sinicise"]];

pub(crate) static ENTRY_SINICIZING_12485406975219661792: VariantsMap = [
    &["sinicizing"],
    &["sinicising"],
    &["sinicizing"],
    &["sinicising"],
];

pub(crate) static ENTRY_SIPHONED_13775252266477144644: VariantsMap =
    [&["siphoned"], &["siphoned"], &["siphoned"], &["siphoned"]];

pub(crate) static ENTRY_SIPHONING_3524409665423772935: VariantsMap = [
    &["siphoning"],
    &["siphoning"],
    &["siphoning"],
    &["siphoning"],
];

pub(crate) static ENTRY_SIPHONLESSES_6742087362595900505: VariantsMap = [
    &["siphonlesses"],
    &["siphonlesses"],
    &["siphonlesses"],
    &["siphonlesses"],
];

pub(crate) static ENTRY_SIPHONLESS_10853607871264713731: VariantsMap = [
    &["siphonless"],
    &["siphonless"],
    &["siphonless"],
    &["siphonless"],
];

pub(crate) static ENTRY_SIPHONLIKES_4271727245061818819: VariantsMap = [
    &["siphonlikes"],
    &["siphonlikes"],
    &["siphonlikes"],
    &["siphonlikes"],
];

pub(crate) static ENTRY_SIPHONLIKE_3466549338188047789: VariantsMap = [
    &["siphonlike"],
    &["siphonlike"],
    &["siphonlike"],
    &["siphonlike"],
];

pub(crate) static ENTRY_SIPHONOPHORE_13045084369054789980: VariantsMap = [
    &["siphonophore"],
    &["siphonophore"],
    &["siphonophore"],
    &["siphonophore"],
];

pub(crate) static ENTRY_SIPHONOSTELE_10401690898945006274: VariantsMap = [
    &["siphonostele"],
    &["siphonostele"],
    &["siphonostele"],
    &["siphonostele"],
];

pub(crate) static ENTRY_SIPHONOSTELIC_6331118512817996757: VariantsMap = [
    &["siphonostelic"],
    &["siphonostelic"],
    &["siphonostelic"],
    &["siphonostelic"],
];

pub(crate) static ENTRY_SIPHONOSTELY_260206920676310428: VariantsMap = [
    &["siphonostely"],
    &["siphonostely"],
    &["siphonostely"],
    &["siphonostely"],
];

pub(crate) static ENTRY_SIPHONS_9477554659409124740: VariantsMap =
    [&["siphons"], &["siphons"], &["siphons"], &["siphons"]];

pub(crate) static ENTRY_SIPHON_7910828118148547350: VariantsMap =
    [&["siphon"], &["siphon"], &["siphon"], &["siphon"]];

pub(crate) static ENTRY_SIRENIZED_2574909956439544564: VariantsMap = [
    &["sirenized"],
    &["sirenised"],
    &["sirenized"],
    &["sirenised"],
];

pub(crate) static ENTRY_SIRENIZES_16814257006036530236: VariantsMap = [
    &["sirenizes"],
    &["sirenises"],
    &["sirenizes"],
    &["sirenises"],
];

pub(crate) static ENTRY_SIRENIZE_4666184332714606459: VariantsMap =
    [&["sirenize"], &["sirenise"], &["sirenize"], &["sirenise"]];

pub(crate) static ENTRY_SIRENIZING_6540711504301955920: VariantsMap = [
    &["sirenizing"],
    &["sirenising"],
    &["sirenizing"],
    &["sirenising"],
];

pub(crate) static ENTRY_SISTERIZES_17019596055143071237: VariantsMap = [
    &["sisterizes"],
    &["sisterises"],
    &["sisterizes"],
    &["sisterises"],
];

pub(crate) static ENTRY_SISTERIZE_6948431239930971695: VariantsMap = [
    &["sisterize"],
    &["sisterise"],
    &["sisterize"],
    &["sisterise"],
];

pub(crate) static ENTRY_SISTERN_11311516313136487178: VariantsMap =
    [&["sistern"], &["sistren"], &["sistren"], &["sistren"]];

pub(crate) static ENTRY_SIZABLY_1222403150260882875: VariantsMap =
    [&["sizably"], &["sizeably"], &["sizably"], &["sizeably"]];

pub(crate) static ENTRY_SIZEL_3837879429176540015: VariantsMap =
    [&["sizel"], &["sisel"], &["sizel"], &["sisel"]];

pub(crate) static ENTRY_SKEER_1740844404740176995: VariantsMap =
    [&["skeer"], &["skere"], &["skere"], &["skere"]];

pub(crate) static ENTRY_SKELETONIZATIONS_2952274931614855136: VariantsMap = [
    &["skeletonizations"],
    &["skeletonisations"],
    &["skeletonizations"],
    &["skeletonisations"],
];

pub(crate) static ENTRY_SKELETONIZATION_15176281057395840132: VariantsMap = [
    &["skeletonization"],
    &["skeletonisation"],
    &["skeletonization"],
    &["skeletonisation"],
];

pub(crate) static ENTRY_SKELETONIZED_5834618125945052179: VariantsMap = [
    &["skeletonized"],
    &["skeletonised"],
    &["skeletonized"],
    &["skeletonised"],
];

pub(crate) static ENTRY_SKELETONIZERS_11894178897960069861: VariantsMap = [
    &["skeletonizers"],
    &["skeletonisers"],
    &["skeletonizers"],
    &["skeletonisers"],
];

pub(crate) static ENTRY_SKELETONIZER_1742743360367189615: VariantsMap = [
    &["skeletonizer"],
    &["skeletoniser"],
    &["skeletonizer"],
    &["skeletoniser"],
];

pub(crate) static ENTRY_SKELETONIZES_5920383959770274591: VariantsMap = [
    &["skeletonizes"],
    &["skeletonises"],
    &["skeletonizes"],
    &["skeletonises"],
];

pub(crate) static ENTRY_SKELETONIZE_8844202107033296437: VariantsMap = [
    &["skeletonize"],
    &["skeletonise"],
    &["skeletonize"],
    &["skeletonise"],
];

pub(crate) static ENTRY_SKELETONIZING_1830503588720890182: VariantsMap = [
    &["skeletonizing"],
    &["skeletonising"],
    &["skeletonizing"],
    &["skeletonising"],
];

pub(crate) static ENTRY_SKEPTICALER_3504236392319734868: VariantsMap = [
    &["skepticaler"],
    &["scepticaler"],
    &["skepticaler"],
    &["scepticaler"],
];

pub(crate) static ENTRY_SKEPTICALEST_1822492830960306797: VariantsMap = [
    &["skepticalest"],
    &["scepticalest"],
    &["skepticalest"],
    &["scepticalest"],
];

pub(crate) static ENTRY_SKEPTICALLY_15015708074924057237: VariantsMap = [
    &["skeptically"],
    &["sceptically"],
    &["skeptically"],
    &["sceptically"],
];

pub(crate) static ENTRY_SKEPTICAL_7567920697289876244: VariantsMap = [
    &["skeptical"],
    &["sceptical"],
    &["skeptical"],
    &["sceptical"],
];

pub(crate) static ENTRY_SKEPTICER_2654895074232389427: VariantsMap = [
    &["skepticer"],
    &["scepticer"],
    &["skepticer"],
    &["scepticer"],
];

pub(crate) static ENTRY_SKEPTICEST_13124338123587490640: VariantsMap = [
    &["skepticest"],
    &["scepticest"],
    &["skepticest"],
    &["scepticest"],
];

pub(crate) static ENTRY_SKEPTICISMS_9470460390001384677: VariantsMap = [
    &["skepticisms"],
    &["scepticisms"],
    &["skepticisms"],
    &["scepticisms"],
];

pub(crate) static ENTRY_SKEPTICISM_16324594783111490926: VariantsMap = [
    &["skepticism"],
    &["scepticism"],
    &["skepticism"],
    &["scepticism"],
];

pub(crate) static ENTRY_SKEPTICIZES_1621712858377146669: VariantsMap = [
    &["skepticizes"],
    &["skepticises"],
    &["skepticizes"],
    &["skepticises"],
];

pub(crate) static ENTRY_SKEPTICIZE_233558052004506284: VariantsMap = [
    &["skepticize"],
    &["skepticise"],
    &["skepticize"],
    &["skepticise"],
];

pub(crate) static ENTRY_SKEPTICS_13432613087589375835: VariantsMap =
    [&["skeptics"], &["sceptics"], &["skeptics"], &["sceptics"]];

pub(crate) static ENTRY_SKEPTIC_9366141399207033866: VariantsMap =
    [&["skeptic"], &["sceptic"], &["skeptic"], &["sceptic"]];

pub(crate) static ENTRY_SKILLFULLY_17336988368413616611: VariantsMap = [
    &["skillfully"],
    &["skilfully"],
    &["skilfully"],
    &["skilfully"],
];

pub(crate) static ENTRY_SKILLFULNESS_10066018729560545262: VariantsMap = [
    &["skillfulness"],
    &["skilfulness"],
    &["skilfulness"],
    &["skilfulness"],
];

pub(crate) static ENTRY_SKILLFUL_8097707939529755598: VariantsMap =
    [&["skillful"], &["skilful"], &["skilful"], &["skilful"]];

pub(crate) static ENTRY_SKYERS_744502748846351073: VariantsMap =
    [&["skyers"], &["skyres"], &["skyres"], &["skyres"]];

pub(crate) static ENTRY_SKYER_15996106329790412626: VariantsMap =
    [&["skyer"], &["skyre"], &["skyre"], &["skyre"]];

pub(crate) static ENTRY_SLAVICIZES_4846190454350142805: VariantsMap = [
    &["slavicizes"],
    &["slavicises"],
    &["slavicizes"],
    &["slavicises"],
];

pub(crate) static ENTRY_SLAVICIZE_9761827906822368262: VariantsMap = [
    &["slavicize"],
    &["slavicise"],
    &["slavicize"],
    &["slavicise"],
];

pub(crate) static ENTRY_SLAVIZATIONS_7586698825967104620: VariantsMap = [
    &["slavizations"],
    &["slavisations"],
    &["slavizations"],
    &["slavisations"],
];

pub(crate) static ENTRY_SLAVIZATION_13156747122292743639: VariantsMap = [
    &["slavization"],
    &["slavisation"],
    &["slavization"],
    &["slavisation"],
];

pub(crate) static ENTRY_SLAVIZES_13267642890664123364: VariantsMap =
    [&["slavizes"], &["slavises"], &["slavizes"], &["slavises"]];

pub(crate) static ENTRY_SLAVIZE_12144031893570739805: VariantsMap =
    [&["slavize"], &["slavise"], &["slavize"], &["slavise"]];

pub(crate) static ENTRY_SLAVONICIZED_4556769722338287574: VariantsMap = [
    &["slavonicized"],
    &["slavonicised"],
    &["slavonicized"],
    &["slavonicised"],
];

pub(crate) static ENTRY_SLAVONICIZES_14342428999925133169: VariantsMap = [
    &["slavonicizes"],
    &["slavonicises"],
    &["slavonicizes"],
    &["slavonicises"],
];

pub(crate) static ENTRY_SLAVONICIZE_7075894969271900254: VariantsMap = [
    &["slavonicize"],
    &["slavonicise"],
    &["slavonicize"],
    &["slavonicise"],
];

pub(crate) static ENTRY_SLAVONICIZING_9470034451915609982: VariantsMap = [
    &["slavonicizing"],
    &["slavonicising"],
    &["slavonicizing"],
    &["slavonicising"],
];

pub(crate) static ENTRY_SLAVONIZED_5503323155898817895: VariantsMap = [
    &["slavonized"],
    &["slavonised"],
    &["slavonized"],
    &["slavonised"],
];

pub(crate) static ENTRY_SLAVONIZES_1966145414926838006: VariantsMap = [
    &["slavonizes"],
    &["slavonises"],
    &["slavonizes"],
    &["slavonises"],
];

pub(crate) static ENTRY_SLAVONIZE_10938982615068583928: VariantsMap = [
    &["slavonize"],
    &["slavonise"],
    &["slavonize"],
    &["slavonise"],
];

pub(crate) static ENTRY_SLAVONIZING_13559715578718041723: VariantsMap = [
    &["slavonizing"],
    &["slavonising"],
    &["slavonizing"],
    &["slavonising"],
];

pub(crate) static ENTRY_SLENDERIZED_7959376560880260414: VariantsMap = [
    &["slenderized"],
    &["slenderised"],
    &["slenderized"],
    &["slenderised"],
];

pub(crate) static ENTRY_SLENDERIZES_16779186498929500242: VariantsMap = [
    &["slenderizes"],
    &["slenderises"],
    &["slenderizes"],
    &["slenderises"],
];

pub(crate) static ENTRY_SLENDERIZE_8515172316335563483: VariantsMap = [
    &["slenderize"],
    &["slenderise"],
    &["slenderize"],
    &["slenderise"],
];

pub(crate) static ENTRY_SLENDERIZING_13145961426039938518: VariantsMap = [
    &["slenderizing"],
    &["slenderising"],
    &["slenderizing"],
    &["slenderising"],
];

pub(crate) static ENTRY_SLE_604254537387974736: VariantsMap =
    [&["sle"], &["slae"], &["slae"], &["slae"]];

pub(crate) static ENTRY_SLIER_17739050457284539156: VariantsMap =
    [&["slier"], &["slyer"], &["slyer"], &["slyer"]];

pub(crate) static ENTRY_SLIEST_8783540132102900417: VariantsMap =
    [&["sliest"], &["slyest"], &["slyest"], &["slyest"]];

pub(crate) static ENTRY_SLOGANIZED_17548782227632388322: VariantsMap = [
    &["sloganized"],
    &["sloganised"],
    &["sloganized"],
    &["sloganised"],
];

pub(crate) static ENTRY_SLOGANIZES_2095570969989848762: VariantsMap = [
    &["sloganizes"],
    &["sloganises"],
    &["sloganizes"],
    &["sloganises"],
];

pub(crate) static ENTRY_SLOGANIZE_5861449365002655564: VariantsMap = [
    &["sloganize"],
    &["sloganise"],
    &["sloganize"],
    &["sloganise"],
];

pub(crate) static ENTRY_SLOGANIZINGS_8139231964165892944: VariantsMap = [
    &["sloganizings"],
    &["sloganisings"],
    &["sloganizings"],
    &["sloganisings"],
];

pub(crate) static ENTRY_SLOGANIZING_5351599027342186318: VariantsMap = [
    &["sloganizing"],
    &["sloganising"],
    &["sloganizing"],
    &["sloganising"],
];

pub(crate) static ENTRY_SLUGGARDIZED_7217161359617146286: VariantsMap = [
    &["sluggardized"],
    &["sluggardised"],
    &["sluggardized"],
    &["sluggardised"],
];

pub(crate) static ENTRY_SLUGGARDIZES_2193421694271241177: VariantsMap = [
    &["sluggardizes"],
    &["sluggardises"],
    &["sluggardizes"],
    &["sluggardises"],
];

pub(crate) static ENTRY_SLUGGARDIZE_15179917084453478031: VariantsMap = [
    &["sluggardize"],
    &["sluggardise"],
    &["sluggardize"],
    &["sluggardise"],
];

pub(crate) static ENTRY_SLUGGARDIZING_3263004984707806773: VariantsMap = [
    &["sluggardizing"],
    &["sluggardising"],
    &["sluggardizing"],
    &["sluggardising"],
];

pub(crate) static ENTRY_SLYLY_3141561617868439191: VariantsMap =
    [&["slyly"], &["slyly"], &["slyly"], &["slyly"]];

pub(crate) static ENTRY_SMIDGENS_5145607016666105466: VariantsMap =
    [&["smidgens"], &["smidgens"], &["smidgens"], &["smidgens"]];

pub(crate) static ENTRY_SMIDGEN_2401448801521207321: VariantsMap =
    [&["smidgen"], &["smidgen"], &["smidgen"], &["smidgen"]];

pub(crate) static ENTRY_SMOLDERED_12136966478992754787: VariantsMap = [
    &["smoldered"],
    &["smouldered"],
    &["smouldered"],
    &["smouldered"],
];

pub(crate) static ENTRY_SMOLDERING_17971483108204682038: VariantsMap = [
    &["smoldering"],
    &["smouldering"],
    &["smouldering"],
    &["smouldering"],
];

pub(crate) static ENTRY_SMOLDERS_16317626305242093646: VariantsMap = [
    &["smolders"],
    &["smoulders"],
    &["smoulders"],
    &["smoulders"],
];

pub(crate) static ENTRY_SMOLDER_18276687156827940484: VariantsMap =
    [&["smolder"], &["smoulder"], &["smoulder"], &["smoulder"]];

pub(crate) static ENTRY_SNIVELED_18043727065802009410: VariantsMap = [
    &["sniveled"],
    &["snivelled"],
    &["snivelled"],
    &["snivelled"],
];

pub(crate) static ENTRY_SNIVELERS_1542130229737259691: VariantsMap = [
    &["snivelers"],
    &["snivellers"],
    &["snivellers"],
    &["snivellers"],
];

pub(crate) static ENTRY_SNIVELER_2280951551750996939: VariantsMap = [
    &["sniveler"],
    &["sniveller"],
    &["sniveller"],
    &["sniveller"],
];

pub(crate) static ENTRY_SNIVELINGS_9742658510844280475: VariantsMap = [
    &["snivelings"],
    &["snivellings"],
    &["snivellings"],
    &["snivellings"],
];

pub(crate) static ENTRY_SNIVELING_7895796690459397538: VariantsMap = [
    &["sniveling"],
    &["snivelling"],
    &["snivelling"],
    &["snivelling"],
];

pub(crate) static ENTRY_SNOBSNIVELING_2460193893793738982: VariantsMap = [
    &["snobsniveling"],
    &["snobsnivelling"],
    &["snobsnivelling"],
    &["snobsnivelling"],
];

pub(crate) static ENTRY_SNORKELED_17424014433959603672: VariantsMap = [
    &["snorkeled"],
    &["snorkelled"],
    &["snorkelled"],
    &["snorkelled"],
];

pub(crate) static ENTRY_SNORKELING_16143785804725093743: VariantsMap = [
    &["snorkeling"],
    &["snorkelling"],
    &["snorkelling"],
    &["snorkelling"],
];

pub(crate) static ENTRY_SNOWPLOWS_1272088169272096167: VariantsMap = [
    &["snowplows"],
    &["snowploughs"],
    &["snowplows"],
    &["snowploughs"],
];

pub(crate) static ENTRY_SNOWPLOW_3516237879610950869: VariantsMap = [
    &["snowplow"],
    &["snowplough"],
    &["snowplow"],
    &["snowplough"],
];

pub(crate) static ENTRY_SNOWSHED_9651694831654123091: VariantsMap = [
    &["snowshed"],
    &["snowshoed"],
    &["snowshoed"],
    &["snowshoed"],
];

pub(crate) static ENTRY_SNUFFCOLORED_10869337707924680144: VariantsMap = [
    &["snuffcolored"],
    &["snuffcoloured"],
    &["snuffcoloured"],
    &["snuffcoloured"],
];

pub(crate) static ENTRY_SOBERIZED_7343261452157716449: VariantsMap = [
    &["soberized"],
    &["soberised"],
    &["soberized"],
    &["soberised"],
];

pub(crate) static ENTRY_SOBERIZES_6877701061854218485: VariantsMap = [
    &["soberizes"],
    &["soberises"],
    &["soberizes"],
    &["soberises"],
];

pub(crate) static ENTRY_SOBERIZE_13532853448534221620: VariantsMap =
    [&["soberize"], &["soberise"], &["soberize"], &["soberise"]];

pub(crate) static ENTRY_SOBERIZING_10684751466686644496: VariantsMap = [
    &["soberizing"],
    &["soberising"],
    &["soberizing"],
    &["soberising"],
];

pub(crate) static ENTRY_SOCIALIZATIONS_10749899080870387486: VariantsMap = [
    &["socializations"],
    &["socialisations"],
    &["socializations"],
    &["socialisations"],
];

pub(crate) static ENTRY_SOCIALIZATION_2084413938110848032: VariantsMap = [
    &["socialization"],
    &["socialisation"],
    &["socialization"],
    &["socialisation"],
];

pub(crate) static ENTRY_SOCIALIZED_11336946122134321158: VariantsMap = [
    &["socialized"],
    &["socialised"],
    &["socialized"],
    &["socialised"],
];

pub(crate) static ENTRY_SOCIALIZER_15740033054008322482: VariantsMap = [
    &["socializer"],
    &["socialiser"],
    &["socializer"],
    &["socialiser"],
];

pub(crate) static ENTRY_SOCIALIZES_1566074373781161623: VariantsMap = [
    &["socializes"],
    &["socialises"],
    &["socializes"],
    &["socialises"],
];

pub(crate) static ENTRY_SOCIALIZE_6985846630440818655: VariantsMap = [
    &["socialize"],
    &["socialise"],
    &["socialize"],
    &["socialise"],
];

pub(crate) static ENTRY_SOCIALIZING_505177211807278288: VariantsMap = [
    &["socializing"],
    &["socialising"],
    &["socializing"],
    &["socialising"],
];

pub(crate) static ENTRY_SOCKDOLOGIZING_16991441468659816755: VariantsMap = [
    &["sockdologizing"],
    &["sockdologising"],
    &["sockdologizing"],
    &["sockdologising"],
];

pub(crate) static ENTRY_SOCRATIZED_9270084545030336528: VariantsMap = [
    &["socratized"],
    &["socratised"],
    &["socratized"],
    &["socratised"],
];

pub(crate) static ENTRY_SOCRATIZES_14641664105677151925: VariantsMap = [
    &["socratizes"],
    &["socratises"],
    &["socratizes"],
    &["socratises"],
];

pub(crate) static ENTRY_SOCRATIZE_14310113146869106182: VariantsMap = [
    &["socratize"],
    &["socratise"],
    &["socratize"],
    &["socratise"],
];

pub(crate) static ENTRY_SOCRATIZING_1982796648064876142: VariantsMap = [
    &["socratizing"],
    &["socratising"],
    &["socratizing"],
    &["socratising"],
];

pub(crate) static ENTRY_SODOMIZED_12622748833680108292: VariantsMap = [
    &["sodomized"],
    &["sodomised"],
    &["sodomized"],
    &["sodomised"],
];

pub(crate) static ENTRY_SODOMIZES_743917781797229302: VariantsMap = [
    &["sodomizes"],
    &["sodomises"],
    &["sodomizes"],
    &["sodomises"],
];

pub(crate) static ENTRY_SODOMIZE_6206294818202684654: VariantsMap =
    [&["sodomize"], &["sodomise"], &["sodomize"], &["sodomise"]];

pub(crate) static ENTRY_SODOMIZING_14921360499846607434: VariantsMap = [
    &["sodomizing"],
    &["sodomising"],
    &["sodomizing"],
    &["sodomising"],
];

pub(crate) static ENTRY_SOLARIZATIONS_4722132275104202763: VariantsMap = [
    &["solarizations"],
    &["solarisations"],
    &["solarizations"],
    &["solarisations"],
];

pub(crate) static ENTRY_SOLARIZATION_1192428962792189832: VariantsMap = [
    &["solarization"],
    &["solarisation"],
    &["solarization"],
    &["solarisation"],
];

pub(crate) static ENTRY_SOLARIZED_5808975743485239818: VariantsMap = [
    &["solarized"],
    &["solarised"],
    &["solarized"],
    &["solarised"],
];

pub(crate) static ENTRY_SOLARIZES_5534323195052354549: VariantsMap = [
    &["solarizes"],
    &["solarises"],
    &["solarizes"],
    &["solarises"],
];

pub(crate) static ENTRY_SOLARIZE_18258216759051483358: VariantsMap =
    [&["solarize"], &["solarise"], &["solarize"], &["solarise"]];

pub(crate) static ENTRY_SOLARIZING_10862859858263346398: VariantsMap = [
    &["solarizing"],
    &["solarising"],
    &["solarizing"],
    &["solarising"],
];

pub(crate) static ENTRY_SOLDIERIZES_11157601016192388331: VariantsMap = [
    &["soldierizes"],
    &["soldierises"],
    &["soldierizes"],
    &["soldierises"],
];

pub(crate) static ENTRY_SOLDIERIZE_16604236556396943965: VariantsMap = [
    &["soldierize"],
    &["soldierise"],
    &["soldierize"],
    &["soldierise"],
];

pub(crate) static ENTRY_SOLECIZED_15911538990572619815: VariantsMap = [
    &["solecized"],
    &["solecised"],
    &["solecized"],
    &["solecised"],
];

pub(crate) static ENTRY_SOLECIZES_15788433464347659056: VariantsMap = [
    &["solecizes"],
    &["solecises"],
    &["solecizes"],
    &["solecises"],
];

pub(crate) static ENTRY_SOLECIZE_4990335805125403138: VariantsMap =
    [&["solecize"], &["solecise"], &["solecize"], &["solecise"]];

pub(crate) static ENTRY_SOLECIZING_12747426853182310591: VariantsMap = [
    &["solecizing"],
    &["solecising"],
    &["solecizing"],
    &["solecising"],
];

pub(crate) static ENTRY_SOLEMNIZATIONS_6129091422641859142: VariantsMap = [
    &["solemnizations"],
    &["solemnisations"],
    &["solemnizations"],
    &["solemnisations"],
];

pub(crate) static ENTRY_SOLEMNIZATION_16787130687056363702: VariantsMap = [
    &["solemnization"],
    &["solemnisation"],
    &["solemnization"],
    &["solemnisation"],
];

pub(crate) static ENTRY_SOLEMNIZED_2852788835971325204: VariantsMap = [
    &["solemnized"],
    &["solemnised"],
    &["solemnized"],
    &["solemnised"],
];

pub(crate) static ENTRY_SOLEMNIZERS_2397316897252319748: VariantsMap = [
    &["solemnizers"],
    &["solemnisers"],
    &["solemnizers"],
    &["solemnisers"],
];

pub(crate) static ENTRY_SOLEMNIZER_5978295607112033996: VariantsMap = [
    &["solemnizer"],
    &["solemniser"],
    &["solemnizer"],
    &["solemniser"],
];

pub(crate) static ENTRY_SOLEMNIZES_17312526288446264851: VariantsMap = [
    &["solemnizes"],
    &["solemnises"],
    &["solemnizes"],
    &["solemnises"],
];

pub(crate) static ENTRY_SOLEMNIZE_15796782944155668670: VariantsMap = [
    &["solemnize"],
    &["solemnise"],
    &["solemnize"],
    &["solemnise"],
];

pub(crate) static ENTRY_SOLEMNIZING_1873698687937846065: VariantsMap = [
    &["solemnizing"],
    &["solemnising"],
    &["solemnizing"],
    &["solemnising"],
];

pub(crate) static ENTRY_SOLILOQUIZATION_269312513960661785: VariantsMap = [
    &["soliloquization"],
    &["soliloquisation"],
    &["soliloquization"],
    &["soliloquisation"],
];

pub(crate) static ENTRY_SOLILOQUIZED_17939687163528373325: VariantsMap = [
    &["soliloquized"],
    &["soliloquised"],
    &["soliloquized"],
    &["soliloquised"],
];

pub(crate) static ENTRY_SOLILOQUIZERS_1912861598555034277: VariantsMap = [
    &["soliloquizers"],
    &["soliloquisers"],
    &["soliloquizers"],
    &["soliloquisers"],
];

pub(crate) static ENTRY_SOLILOQUIZER_5490319459061869143: VariantsMap = [
    &["soliloquizer"],
    &["soliloquiser"],
    &["soliloquizer"],
    &["soliloquiser"],
];

pub(crate) static ENTRY_SOLILOQUIZES_9261685774539508340: VariantsMap = [
    &["soliloquizes"],
    &["soliloquises"],
    &["soliloquizes"],
    &["soliloquises"],
];

pub(crate) static ENTRY_SOLILOQUIZE_12226193284594737636: VariantsMap = [
    &["soliloquize"],
    &["soliloquise"],
    &["soliloquize"],
    &["soliloquise"],
];

pub(crate) static ENTRY_SOLILOQUIZINGLY_2770653047985095587: VariantsMap = [
    &["soliloquizingly"],
    &["soliloquisingly"],
    &["soliloquizingly"],
    &["soliloquisingly"],
];

pub(crate) static ENTRY_SOLILOQUIZINGS_16013560258108957465: VariantsMap = [
    &["soliloquizings"],
    &["soliloquisings"],
    &["soliloquizings"],
    &["soliloquisings"],
];

pub(crate) static ENTRY_SOLILOQUIZING_15896904890682292482: VariantsMap = [
    &["soliloquizing"],
    &["soliloquising"],
    &["soliloquizing"],
    &["soliloquising"],
];

pub(crate) static ENTRY_SOLMIZATIONS_13280876893352435221: VariantsMap = [
    &["solmizations"],
    &["solmisations"],
    &["solmizations"],
    &["solmisations"],
];

pub(crate) static ENTRY_SOLMIZATION_8566929989308185368: VariantsMap = [
    &["solmization"],
    &["solmisation"],
    &["solmization"],
    &["solmisation"],
];

pub(crate) static ENTRY_SOLONIZATIONS_4433313152747643816: VariantsMap = [
    &["solonizations"],
    &["solonisations"],
    &["solonizations"],
    &["solonisations"],
];

pub(crate) static ENTRY_SOLONIZATION_11249232042663309133: VariantsMap = [
    &["solonization"],
    &["solonisation"],
    &["solonization"],
    &["solonisation"],
];

pub(crate) static ENTRY_SOLUBILIZATIONS_4369156796378163009: VariantsMap = [
    &["solubilizations"],
    &["solubilisations"],
    &["solubilizations"],
    &["solubilisations"],
];

pub(crate) static ENTRY_SOLUBILIZATION_11329836872303618229: VariantsMap = [
    &["solubilization"],
    &["solubilisation"],
    &["solubilization"],
    &["solubilisation"],
];

pub(crate) static ENTRY_SOLUBILIZED_6258117609347074455: VariantsMap = [
    &["solubilized"],
    &["solubilised"],
    &["solubilized"],
    &["solubilised"],
];

pub(crate) static ENTRY_SOLUBILIZES_13987666377462264730: VariantsMap = [
    &["solubilizes"],
    &["solubilises"],
    &["solubilizes"],
    &["solubilises"],
];

pub(crate) static ENTRY_SOLUBILIZE_1662872893301039501: VariantsMap = [
    &["solubilize"],
    &["solubilise"],
    &["solubilize"],
    &["solubilise"],
];

pub(crate) static ENTRY_SOLUBILIZING_10490972660552675683: VariantsMap = [
    &["solubilizing"],
    &["solubilising"],
    &["solubilizing"],
    &["solubilising"],
];

pub(crate) static ENTRY_SOLUTIZERS_16598006390430358557: VariantsMap = [
    &["solutizers"],
    &["solutisers"],
    &["solutizers"],
    &["solutisers"],
];

pub(crate) static ENTRY_SOLUTIZER_6497015698400010769: VariantsMap = [
    &["solutizer"],
    &["solutiser"],
    &["solutizer"],
    &["solutiser"],
];

pub(crate) static ENTRY_SOLUTIZES_16990892992718942912: VariantsMap = [
    &["solutizes"],
    &["solutises"],
    &["solutizes"],
    &["solutises"],
];

pub(crate) static ENTRY_SOLUTIZE_5438116954578400359: VariantsMap =
    [&["solutize"], &["solutise"], &["solutize"], &["solutise"]];

pub(crate) static ENTRY_SOMBERER_17580079165913630117: VariantsMap =
    [&["somberer"], &["sombrer"], &["sombrer"], &["sombrer"]];

pub(crate) static ENTRY_SOMBEREST_3884649068642437270: VariantsMap =
    [&["somberest"], &["sombrest"], &["sombrest"], &["sombrest"]];

pub(crate) static ENTRY_SOMBERISH_9751798617429837974: VariantsMap = [
    &["somberish"],
    &["sombreish"],
    &["sombreish"],
    &["sombreish"],
];

pub(crate) static ENTRY_SOMBERLY_14824241355422186369: VariantsMap =
    [&["somberly"], &["sombrely"], &["sombrely"], &["sombrely"]];

pub(crate) static ENTRY_SOMBERNESSES_5970684106925544470: VariantsMap = [
    &["sombernesses"],
    &["sombrenesses"],
    &["sombrenesses"],
    &["sombrenesses"],
];

pub(crate) static ENTRY_SOMBERNESS_3289235689799463770: VariantsMap = [
    &["somberness"],
    &["sombreness"],
    &["sombreness"],
    &["sombreness"],
];

pub(crate) static ENTRY_SOMBER_5140950589921348685: VariantsMap =
    [&["somber"], &["sombre"], &["sombre"], &["sombre"]];

pub(crate) static ENTRY_SOMESTHESIA_11184895325270057547: VariantsMap = [
    &["somesthesia"],
    &["somaesthesia"],
    &["somaesthesia"],
    &["somaesthesia"],
];

pub(crate) static ENTRY_SOMESTHESIS_3205445442940535664: VariantsMap = [
    &["somesthesis"],
    &["somaesthesis"],
    &["somaesthesis"],
    &["somaesthesis"],
];

pub(crate) static ENTRY_SOMNILOQUIZED_11728587916951539904: VariantsMap = [
    &["somniloquized"],
    &["somniloquised"],
    &["somniloquized"],
    &["somniloquised"],
];

pub(crate) static ENTRY_SOMNILOQUIZES_7318100064004324381: VariantsMap = [
    &["somniloquizes"],
    &["somniloquises"],
    &["somniloquizes"],
    &["somniloquises"],
];

pub(crate) static ENTRY_SOMNILOQUIZE_14989120006007292353: VariantsMap = [
    &["somniloquize"],
    &["somniloquise"],
    &["somniloquize"],
    &["somniloquise"],
];

pub(crate) static ENTRY_SOMNILOQUIZING_13842334488833594229: VariantsMap = [
    &["somniloquizing"],
    &["somniloquising"],
    &["somniloquizing"],
    &["somniloquising"],
];

pub(crate) static ENTRY_SONANTIZEDS_5806347613534212865: VariantsMap = [
    &["sonantizeds"],
    &["sonantiseds"],
    &["sonantizeds"],
    &["sonantiseds"],
];

pub(crate) static ENTRY_SONANTIZED_7465742307673093545: VariantsMap = [
    &["sonantized"],
    &["sonantised"],
    &["sonantized"],
    &["sonantised"],
];

pub(crate) static ENTRY_SONNETIZATION_17811800137071473898: VariantsMap = [
    &["sonnetization"],
    &["sonnetisation"],
    &["sonnetization"],
    &["sonnetisation"],
];

pub(crate) static ENTRY_SONNETIZED_16371695347786264769: VariantsMap = [
    &["sonnetized"],
    &["sonnetised"],
    &["sonnetized"],
    &["sonnetised"],
];

pub(crate) static ENTRY_SONNETIZES_6585967879025542142: VariantsMap = [
    &["sonnetizes"],
    &["sonnetises"],
    &["sonnetizes"],
    &["sonnetises"],
];

pub(crate) static ENTRY_SONNETIZE_3336641041466286630: VariantsMap = [
    &["sonnetize"],
    &["sonnetise"],
    &["sonnetize"],
    &["sonnetise"],
];

pub(crate) static ENTRY_SONNETIZING_2853568487817375411: VariantsMap = [
    &["sonnetizing"],
    &["sonnetising"],
    &["sonnetizing"],
    &["sonnetising"],
];

pub(crate) static ENTRY_SORBITIZATIONS_15094150133852333070: VariantsMap = [
    &["sorbitizations"],
    &["sorbitisations"],
    &["sorbitizations"],
    &["sorbitisations"],
];

pub(crate) static ENTRY_SORBITIZATION_3511955197103798019: VariantsMap = [
    &["sorbitization"],
    &["sorbitisation"],
    &["sorbitization"],
    &["sorbitisation"],
];

pub(crate) static ENTRY_SORBITIZED_11029247990437433113: VariantsMap = [
    &["sorbitized"],
    &["sorbitised"],
    &["sorbitized"],
    &["sorbitised"],
];

pub(crate) static ENTRY_SORBITIZES_17239730547558440933: VariantsMap = [
    &["sorbitizes"],
    &["sorbitises"],
    &["sorbitizes"],
    &["sorbitises"],
];

pub(crate) static ENTRY_SORBITIZE_4953121359286386634: VariantsMap = [
    &["sorbitize"],
    &["sorbitise"],
    &["sorbitize"],
    &["sorbitise"],
];

pub(crate) static ENTRY_SORBITIZING_10552560528290540525: VariantsMap = [
    &["sorbitizing"],
    &["sorbitising"],
    &["sorbitizing"],
    &["sorbitising"],
];

pub(crate) static ENTRY_SORDINES_17955052261708476598: VariantsMap = [
    &["sordines"],
    &["sourdines"],
    &["sourdines"],
    &["sourdines"],
];

pub(crate) static ENTRY_SORDINE_13046642983492348660: VariantsMap =
    [&["sordine"], &["sourdine"], &["sourdine"], &["sourdine"]];

pub(crate) static ENTRY_SORD_16682875115764427041: VariantsMap =
    [&["sord"], &["sourd"], &["sourd"], &["sourd"]];

pub(crate) static ENTRY_SORORIZED_10275110518887074085: VariantsMap = [
    &["sororized"],
    &["sororised"],
    &["sororized"],
    &["sororised"],
];

pub(crate) static ENTRY_SORORIZES_5655621331560912625: VariantsMap = [
    &["sororizes"],
    &["sororises"],
    &["sororizes"],
    &["sororises"],
];

pub(crate) static ENTRY_SORORIZE_10455264558591532576: VariantsMap =
    [&["sororize"], &["sororise"], &["sororize"], &["sororise"]];

pub(crate) static ENTRY_SORORIZING_2971025569489318464: VariantsMap = [
    &["sororizing"],
    &["sororising"],
    &["sororizing"],
    &["sororising"],
];

pub(crate) static ENTRY_SORY_866294547402037500: VariantsMap =
    [&["sory"], &["soury"], &["soury"], &["soury"]];

pub(crate) static ENTRY_SOUFFLED_11288921415541351012: VariantsMap = [
    &["souffled"],
    &["soufflaed"],
    &["soufflaed"],
    &["soufflaed"],
];

pub(crate) static ENTRY_SOULTER_16287779215263702830: VariantsMap =
    [&["soulter"], &["soultre"], &["soultre"], &["soultre"]];

pub(crate) static ENTRY_SOUTHERNIZED_5166061537133315558: VariantsMap = [
    &["southernized"],
    &["southernised"],
    &["southernized"],
    &["southernised"],
];

pub(crate) static ENTRY_SOUTHERNIZES_17801238247060666066: VariantsMap = [
    &["southernizes"],
    &["southernises"],
    &["southernizes"],
    &["southernises"],
];

pub(crate) static ENTRY_SOUTHERNIZE_2007900784402703927: VariantsMap = [
    &["southernize"],
    &["southernise"],
    &["southernize"],
    &["southernise"],
];

pub(crate) static ENTRY_SOUTHERNIZING_7105097135265474755: VariantsMap = [
    &["southernizing"],
    &["southernising"],
    &["southernizing"],
    &["southernising"],
];

pub(crate) static ENTRY_SOVIETIZATIONS_2629132161469247656: VariantsMap = [
    &["sovietizations"],
    &["sovietisations"],
    &["sovietizations"],
    &["sovietisations"],
];

pub(crate) static ENTRY_SOVIETIZATION_13205972349841767875: VariantsMap = [
    &["sovietization"],
    &["sovietisation"],
    &["sovietization"],
    &["sovietisation"],
];

pub(crate) static ENTRY_SOVIETIZED_7565927092510685793: VariantsMap = [
    &["sovietized"],
    &["sovietised"],
    &["sovietized"],
    &["sovietised"],
];

pub(crate) static ENTRY_SOVIETIZES_11590305664562136263: VariantsMap = [
    &["sovietizes"],
    &["sovietises"],
    &["sovietizes"],
    &["sovietises"],
];

pub(crate) static ENTRY_SOVIETIZE_15802906407586023669: VariantsMap = [
    &["sovietize"],
    &["sovietise"],
    &["sovietize"],
    &["sovietise"],
];

pub(crate) static ENTRY_SOVIETIZING_16212924505860778534: VariantsMap = [
    &["sovietizing"],
    &["sovietising"],
    &["sovietizing"],
    &["sovietising"],
];

pub(crate) static ENTRY_SPANEMIA_9395556157284175278: VariantsMap = [
    &["spanemia"],
    &["spanaemia"],
    &["spanaemia"],
    &["spanaemia"],
];

pub(crate) static ENTRY_SPANEMIC_7019184248567022986: VariantsMap = [
    &["spanemic"],
    &["spanaemic"],
    &["spanaemic"],
    &["spanaemic"],
];

pub(crate) static ENTRY_SPANIARDIZATIONS_15525961894554670327: VariantsMap = [
    &["spaniardizations"],
    &["spaniardisations"],
    &["spaniardizations"],
    &["spaniardisations"],
];

pub(crate) static ENTRY_SPANIARDIZATION_10902219760262843235: VariantsMap = [
    &["spaniardization"],
    &["spaniardisation"],
    &["spaniardization"],
    &["spaniardisation"],
];

pub(crate) static ENTRY_SPANIARDIZES_6439262747070069854: VariantsMap = [
    &["spaniardizes"],
    &["spaniardises"],
    &["spaniardizes"],
    &["spaniardises"],
];

pub(crate) static ENTRY_SPANIARDIZE_9569545691628177723: VariantsMap = [
    &["spaniardize"],
    &["spaniardise"],
    &["spaniardize"],
    &["spaniardise"],
];

pub(crate) static ENTRY_SPANIOLIZED_9570991099566114102: VariantsMap = [
    &["spaniolized"],
    &["spaniolised"],
    &["spaniolized"],
    &["spaniolised"],
];

pub(crate) static ENTRY_SPANIOLIZES_7108790081189873491: VariantsMap = [
    &["spaniolizes"],
    &["spaniolises"],
    &["spaniolizes"],
    &["spaniolises"],
];

pub(crate) static ENTRY_SPANIOLIZE_16413139481606920807: VariantsMap = [
    &["spaniolize"],
    &["spaniolise"],
    &["spaniolize"],
    &["spaniolise"],
];

pub(crate) static ENTRY_SPANIOLIZING_13650496056576542802: VariantsMap = [
    &["spaniolizing"],
    &["spaniolising"],
    &["spaniolizing"],
    &["spaniolising"],
];

pub(crate) static ENTRY_SPANISHIZES_15280734989274435032: VariantsMap = [
    &["spanishizes"],
    &["spanishises"],
    &["spanishizes"],
    &["spanishises"],
];

pub(crate) static ENTRY_SPANISHIZE_11599801654411089329: VariantsMap = [
    &["spanishize"],
    &["spanishise"],
    &["spanishize"],
    &["spanishise"],
];

pub(crate) static ENTRY_SPANOPNEA_8865008578129066489: VariantsMap = [
    &["spanopnea"],
    &["spanopnoea"],
    &["spanopnoea"],
    &["spanopnoea"],
];

pub(crate) static ENTRY_SPARERS_12651957075913392459: VariantsMap =
    [&["sparers"], &["sparres"], &["sparres"], &["sparres"]];

pub(crate) static ENTRY_SPARTANIZES_11376123191933793512: VariantsMap = [
    &["spartanizes"],
    &["spartanises"],
    &["spartanizes"],
    &["spartanises"],
];

pub(crate) static ENTRY_SPARTANIZE_14452942641175240684: VariantsMap = [
    &["spartanize"],
    &["spartanise"],
    &["spartanize"],
    &["spartanise"],
];

pub(crate) static ENTRY_SPATIALIZATIONS_4112547726772378999: VariantsMap = [
    &["spatializations"],
    &["spatialisations"],
    &["spatializations"],
    &["spatialisations"],
];

pub(crate) static ENTRY_SPATIALIZATION_17405201949564996789: VariantsMap = [
    &["spatialization"],
    &["spatialisation"],
    &["spatialization"],
    &["spatialisation"],
];

pub(crate) static ENTRY_SPATIALIZES_13997333572376113619: VariantsMap = [
    &["spatializes"],
    &["spatialises"],
    &["spatializes"],
    &["spatialises"],
];

pub(crate) static ENTRY_SPATIALIZE_16660740722538409917: VariantsMap = [
    &["spatialize"],
    &["spatialise"],
    &["spatialize"],
    &["spatialise"],
];

pub(crate) static ENTRY_SPECIALIZATIONS_13893908534368099370: VariantsMap = [
    &["specializations"],
    &["specialisations"],
    &["specializations"],
    &["specialisations"],
];

pub(crate) static ENTRY_SPECIALIZATION_14868724416514006075: VariantsMap = [
    &["specialization"],
    &["specialisation"],
    &["specialization"],
    &["specialisation"],
];

pub(crate) static ENTRY_SPECIALIZED_8365382398741657820: VariantsMap = [
    &["specialized"],
    &["specialised"],
    &["specialized"],
    &["specialised"],
];

pub(crate) static ENTRY_SPECIALIZERS_321317241265822118: VariantsMap = [
    &["specializers"],
    &["specialisers"],
    &["specializers"],
    &["specialisers"],
];

pub(crate) static ENTRY_SPECIALIZER_3424451690381023981: VariantsMap = [
    &["specializer"],
    &["specialiser"],
    &["specializer"],
    &["specialiser"],
];

pub(crate) static ENTRY_SPECIALIZES_12943575911419958048: VariantsMap = [
    &["specializes"],
    &["specialises"],
    &["specializes"],
    &["specialises"],
];

pub(crate) static ENTRY_SPECIALIZE_13734198890330005704: VariantsMap = [
    &["specialize"],
    &["specialise"],
    &["specialize"],
    &["specialise"],
];

pub(crate) static ENTRY_SPECIALIZING_2079181106562003064: VariantsMap = [
    &["specializing"],
    &["specialising"],
    &["specializing"],
    &["specialising"],
];

pub(crate) static ENTRY_SPECIALTIES_3691519001585260032: VariantsMap = [
    &["specialties"],
    &["specialities"],
    &["specialties"],
    &["specialities"],
];

pub(crate) static ENTRY_SPECIALTY_15229334144133093973: VariantsMap = [
    &["specialty"],
    &["speciality"],
    &["specialty"],
    &["speciality"],
];

pub(crate) static ENTRY_SPECIFICIZES_14547115587945723943: VariantsMap = [
    &["specificizes"],
    &["specificises"],
    &["specificizes"],
    &["specificises"],
];

pub(crate) static ENTRY_SPECIFICIZE_14913302620346573053: VariantsMap = [
    &["specificize"],
    &["specificise"],
    &["specificize"],
    &["specificise"],
];

pub(crate) static ENTRY_SPECIMENIZES_8129034162279199571: VariantsMap = [
    &["specimenizes"],
    &["specimenises"],
    &["specimenizes"],
    &["specimenises"],
];

pub(crate) static ENTRY_SPECIMENIZE_2090384801819711905: VariantsMap = [
    &["specimenize"],
    &["specimenise"],
    &["specimenize"],
    &["specimenise"],
];

pub(crate) static ENTRY_SPECTERED_863247434920694580: VariantsMap =
    [&["spectered"], &["spectred"], &["spectred"], &["spectred"]];

pub(crate) static ENTRY_SPECTERLIKES_484157250269129460: VariantsMap = [
    &["specterlikes"],
    &["spectrelikes"],
    &["spectrelikes"],
    &["spectrelikes"],
];

pub(crate) static ENTRY_SPECTERLIKE_18260751826068593688: VariantsMap = [
    &["specterlike"],
    &["spectrelike"],
    &["spectrelike"],
    &["spectrelike"],
];

pub(crate) static ENTRY_SPECTERS_7942939111689789209: VariantsMap =
    [&["specters"], &["spectres"], &["spectres"], &["spectres"]];

pub(crate) static ENTRY_SPECTER_13138390153678479670: VariantsMap =
    [&["specter"], &["spectre"], &["spectre"], &["spectre"]];

pub(crate) static ENTRY_SPECTROCOLORIMETRY_1759736892341904212: VariantsMap = [
    &["spectrocolorimetry"],
    &["spectrocolourimetry"],
    &["spectrocolourimetry"],
    &["spectrocolourimetry"],
];

pub(crate) static ENTRY_SPEER_13429671139585207271: VariantsMap =
    [&["speer"], &["spere"], &["spere"], &["spere"]];

pub(crate) static ENTRY_SPELEAN_8367235262898475105: VariantsMap =
    [&["spelean"], &["spelaean"], &["spelaean"], &["spelaean"]];

pub(crate) static ENTRY_SPELEOLOGICAL_11481859540905022703: VariantsMap = [
    &["speleological"],
    &["speleological"],
    &["speleological"],
    &["speleological"],
];

pub(crate) static ENTRY_SPELEOTHEMS_10285341670778918846: VariantsMap = [
    &["speleothems"],
    &["spelaeothems"],
    &["spelaeothems"],
    &["spelaeothems"],
];

pub(crate) static ENTRY_SPELEOTHEM_17324027630005062947: VariantsMap = [
    &["speleothem"],
    &["spelaeothem"],
    &["spelaeothem"],
    &["spelaeothem"],
];

pub(crate) static ENTRY_SPERMATORRHEAS_3208610420634611148: VariantsMap = [
    &["spermatorrheas"],
    &["spermatorrhoeas"],
    &["spermatorrhoeas"],
    &["spermatorrhoeas"],
];

pub(crate) static ENTRY_SPERMATORRHEA_11364148558414858528: VariantsMap = [
    &["spermatorrhea"],
    &["spermatorrhoea"],
    &["spermatorrhoea"],
    &["spermatorrhoea"],
];

pub(crate) static ENTRY_SPERONARES_16134515720540164866: VariantsMap = [
    &["speronares"],
    &["speronaroes"],
    &["speronaroes"],
    &["speronaroes"],
];

pub(crate) static ENTRY_SPHENETHMOIDAL_4192928733742313479: VariantsMap = [
    &["sphenethmoidal"],
    &["sphenoethmoidal"],
    &["sphenoethmoidal"],
    &["sphenoethmoidal"],
];

pub(crate) static ENTRY_SPHENETHMOID_8848939739861600805: VariantsMap = [
    &["sphenethmoid"],
    &["sphenoethmoid"],
    &["sphenoethmoid"],
    &["sphenoethmoid"],
];

pub(crate) static ENTRY_SPHEROCRYSTAL_13381643278818911724: VariantsMap = [
    &["spherocrystal"],
    &["sphaerocrystal"],
    &["sphaerocrystal"],
    &["sphaerocrystal"],
];

pub(crate) static ENTRY_SPHEROIDIZATIONS_780683803829928867: VariantsMap = [
    &["spheroidizations"],
    &["spheroidisations"],
    &["spheroidizations"],
    &["spheroidisations"],
];

pub(crate) static ENTRY_SPHEROIDIZATION_1425186216287202703: VariantsMap = [
    &["spheroidization"],
    &["spheroidisation"],
    &["spheroidization"],
    &["spheroidisation"],
];

pub(crate) static ENTRY_SPHEROIDIZED_3309613407465330972: VariantsMap = [
    &["spheroidized"],
    &["spheroidised"],
    &["spheroidized"],
    &["spheroidised"],
];

pub(crate) static ENTRY_SPHEROIDIZES_6259874484087826697: VariantsMap = [
    &["spheroidizes"],
    &["spheroidises"],
    &["spheroidizes"],
    &["spheroidises"],
];

pub(crate) static ENTRY_SPHEROIDIZE_11471029450807575082: VariantsMap = [
    &["spheroidize"],
    &["spheroidise"],
    &["spheroidize"],
    &["spheroidise"],
];

pub(crate) static ENTRY_SPHEROIDIZING_11358721974863679837: VariantsMap = [
    &["spheroidizing"],
    &["spheroidising"],
    &["spheroidizing"],
    &["spheroidising"],
];

pub(crate) static ENTRY_SPHEROSOME_14408424187868099563: VariantsMap = [
    &["spherosome"],
    &["sphaerosome"],
    &["sphaerosome"],
    &["sphaerosome"],
];

pub(crate) static ENTRY_SPIERS_5515884338097894490: VariantsMap =
    [&["spiers"], &["spires"], &["spires"], &["spires"]];

pub(crate) static ENTRY_SPINULE_17210556472422983066: VariantsMap =
    [&["spinule"], &["spinulae"], &["spinulae"], &["spinulae"]];

pub(crate) static ENTRY_SPIRALED_4583591683626098518: VariantsMap = [
    &["spiraled"],
    &["spiralled"],
    &["spiralled"],
    &["spiralled"],
];

pub(crate) static ENTRY_SPIRALING_4625432215690768886: VariantsMap = [
    &["spiraling"],
    &["spiralling"],
    &["spiralling"],
    &["spiralling"],
];

pub(crate) static ENTRY_SPIRALIZATIONS_2042085502750008288: VariantsMap = [
    &["spiralizations"],
    &["spiralisations"],
    &["spiralizations"],
    &["spiralisations"],
];

pub(crate) static ENTRY_SPIRALIZATION_8541479832578673907: VariantsMap = [
    &["spiralization"],
    &["spiralisation"],
    &["spiralization"],
    &["spiralisation"],
];

pub(crate) static ENTRY_SPIRALIZES_6682564053194995427: VariantsMap = [
    &["spiralizes"],
    &["spiralises"],
    &["spiralizes"],
    &["spiralises"],
];

pub(crate) static ENTRY_SPIRALIZE_16007127051122986788: VariantsMap = [
    &["spiralize"],
    &["spiralise"],
    &["spiralize"],
    &["spiralise"],
];

pub(crate) static ENTRY_SPIREAS_14727691610313704462: VariantsMap =
    [&["spireas"], &["spiraeas"], &["spireas"], &["spiraeas"]];

pub(crate) static ENTRY_SPIREA_16883104999884113279: VariantsMap =
    [&["spirea"], &["spiraea"], &["spirea"], &["spiraea"]];

pub(crate) static ENTRY_SPIRITIZES_6541246359921725745: VariantsMap = [
    &["spiritizes"],
    &["spiritises"],
    &["spiritizes"],
    &["spiritises"],
];

pub(crate) static ENTRY_SPIRITIZE_9378881530105575004: VariantsMap = [
    &["spiritize"],
    &["spiritise"],
    &["spiritize"],
    &["spiritise"],
];

pub(crate) static ENTRY_SPIRITUALIZATIONS_8932729483849010613: VariantsMap = [
    &["spiritualizations"],
    &["spiritualisations"],
    &["spiritualizations"],
    &["spiritualisations"],
];

pub(crate) static ENTRY_SPIRITUALIZATION_10305886720640139033: VariantsMap = [
    &["spiritualization"],
    &["spiritualisation"],
    &["spiritualization"],
    &["spiritualisation"],
];

pub(crate) static ENTRY_SPIRITUALIZED_2725993091146698638: VariantsMap = [
    &["spiritualized"],
    &["spiritualised"],
    &["spiritualized"],
    &["spiritualised"],
];

pub(crate) static ENTRY_SPIRITUALIZERS_3732134443047012330: VariantsMap = [
    &["spiritualizers"],
    &["spiritualisers"],
    &["spiritualizers"],
    &["spiritualisers"],
];

pub(crate) static ENTRY_SPIRITUALIZER_8504978883588201552: VariantsMap = [
    &["spiritualizer"],
    &["spiritualiser"],
    &["spiritualizer"],
    &["spiritualiser"],
];

pub(crate) static ENTRY_SPIRITUALIZES_1639337578015899962: VariantsMap = [
    &["spiritualizes"],
    &["spiritualises"],
    &["spiritualizes"],
    &["spiritualises"],
];

pub(crate) static ENTRY_SPIRITUALIZE_7047180007869852793: VariantsMap = [
    &["spiritualize"],
    &["spiritualise"],
    &["spiritualize"],
    &["spiritualise"],
];

pub(crate) static ENTRY_SPIRITUALIZING_17446854514925186660: VariantsMap = [
    &["spiritualizing"],
    &["spiritualising"],
    &["spiritualizing"],
    &["spiritualising"],
];

pub(crate) static ENTRY_SPIROCHETAL_11634963050010672522: VariantsMap = [
    &["spirochetal"],
    &["spirochaetal"],
    &["spirochaetal"],
    &["spirochaetal"],
];

pub(crate) static ENTRY_SPIROCHETES_13621339480155823661: VariantsMap = [
    &["spirochetes"],
    &["spirochaetes"],
    &["spirochetes"],
    &["spirochaetes"],
];

pub(crate) static ENTRY_SPIROCHETE_5978254499923720079: VariantsMap = [
    &["spirochete"],
    &["spirochaete"],
    &["spirochete"],
    &["spirochaete"],
];

pub(crate) static ENTRY_SPIROCHETOSES_6730304618752518023: VariantsMap = [
    &["spirochetoses"],
    &["spirochaetoses"],
    &["spirochaetoses"],
    &["spirochaetoses"],
];

pub(crate) static ENTRY_SPIROCHETOSIS_13176480837782571985: VariantsMap = [
    &["spirochetosis"],
    &["spirochaetosis"],
    &["spirochaetosis"],
    &["spirochaetosis"],
];

pub(crate) static ENTRY_SPIROCHETOTIC_8684207899956468554: VariantsMap = [
    &["spirochetotic"],
    &["spirochaetotic"],
    &["spirochaetotic"],
    &["spirochaetotic"],
];

pub(crate) static ENTRY_SPLANCHNOCELE_10962826556710463329: VariantsMap = [
    &["splanchnocele"],
    &["splanchnocoele"],
    &["splanchnocoele"],
    &["splanchnocoele"],
];

pub(crate) static ENTRY_SPLENDORPROOF_8961725742582755989: VariantsMap = [
    &["splendorproof"],
    &["splendourproof"],
    &["splendourproof"],
    &["splendourproof"],
];

pub(crate) static ENTRY_SPLENDORS_16829161556225143613: VariantsMap = [
    &["splendors"],
    &["splendours"],
    &["splendours"],
    &["splendours"],
];

pub(crate) static ENTRY_SPLENDOR_698262644085203522: VariantsMap = [
    &["splendor"],
    &["splendour"],
    &["splendour"],
    &["splendour"],
];

pub(crate) static ENTRY_SPLENECTOMIZED_8219804151047161524: VariantsMap = [
    &["splenectomized"],
    &["splenectomised"],
    &["splenectomized"],
    &["splenectomised"],
];

pub(crate) static ENTRY_SPLENIZATIONS_17949623258974597810: VariantsMap = [
    &["splenizations"],
    &["splenisations"],
    &["splenizations"],
    &["splenisations"],
];

pub(crate) static ENTRY_SPLENIZATION_7858507853343431089: VariantsMap = [
    &["splenization"],
    &["splenisation"],
    &["splenization"],
    &["splenisation"],
];

pub(crate) static ENTRY_SPOILED_9946660437827218525: VariantsMap = [
    &["spoiled"],
    &["spoiled", "spoilt"],
    &["spoiled"],
    &["spoiled", "spoilt"],
];

pub(crate) static ENTRY_SPYER_15698237802555201567: VariantsMap =
    [&["spyer"], &["spyre"], &["spyre"], &["spyre"]];

pub(crate) static ENTRY_SQUAME_15183787142740018891: VariantsMap =
    [&["squame"], &["squamae"], &["squamae"], &["squamae"]];

pub(crate) static ENTRY_SQUAMULE_11975141371110576408: VariantsMap = [
    &["squamule"],
    &["squamulae"],
    &["squamulae"],
    &["squamulae"],
];

pub(crate) static ENTRY_SQUIER_16883964174471128452: VariantsMap =
    [&["squier"], &["squire"], &["squire"], &["squire"]];

pub(crate) static ENTRY_SQUIRRELED_11318257635454397551: VariantsMap = [
    &["squirreled"],
    &["squirrelled"],
    &["squirrelled"],
    &["squirrelled"],
];

pub(crate) static ENTRY_SQUIRRELING_17909585620200517283: VariantsMap = [
    &["squirreling"],
    &["squirrelling"],
    &["squirrelling"],
    &["squirrelling"],
];

pub(crate) static ENTRY_STABILIZABLE_7038167747817470196: VariantsMap = [
    &["stabilizable"],
    &["stabilisable"],
    &["stabilizable"],
    &["stabilisable"],
];

pub(crate) static ENTRY_STABILIZATIONS_9746187249939087138: VariantsMap = [
    &["stabilizations"],
    &["stabilisations"],
    &["stabilizations"],
    &["stabilisations"],
];

pub(crate) static ENTRY_STABILIZATION_2391135939043331459: VariantsMap = [
    &["stabilization"],
    &["stabilisation"],
    &["stabilization"],
    &["stabilisation"],
];

pub(crate) static ENTRY_STABILIZATORS_7145810033685180235: VariantsMap = [
    &["stabilizators"],
    &["stabilisators"],
    &["stabilizators"],
    &["stabilisators"],
];

pub(crate) static ENTRY_STABILIZATOR_17741108746142693419: VariantsMap = [
    &["stabilizator"],
    &["stabilisator"],
    &["stabilizator"],
    &["stabilisator"],
];

pub(crate) static ENTRY_STABILIZED_11581917854583003610: VariantsMap = [
    &["stabilized"],
    &["stabilised"],
    &["stabilized"],
    &["stabilised"],
];

pub(crate) static ENTRY_STABILIZERS_16116889764524023645: VariantsMap = [
    &["stabilizers"],
    &["stabilisers"],
    &["stabilizers"],
    &["stabilisers"],
];

pub(crate) static ENTRY_STABILIZER_3382378464960197128: VariantsMap = [
    &["stabilizer"],
    &["stabiliser"],
    &["stabilizer"],
    &["stabiliser"],
];

pub(crate) static ENTRY_STABILIZES_13521081822794596506: VariantsMap = [
    &["stabilizes"],
    &["stabilises"],
    &["stabilizes"],
    &["stabilises"],
];

pub(crate) static ENTRY_STABILIZE_1583006602954926586: VariantsMap = [
    &["stabilize"],
    &["stabilise"],
    &["stabilize"],
    &["stabilise"],
];

pub(crate) static ENTRY_STABILIZING_14660265128274227263: VariantsMap = [
    &["stabilizing"],
    &["stabilising"],
    &["stabilizing"],
    &["stabilising"],
];

pub(crate) static ENTRY_STALLIONIZES_15526567222649873911: VariantsMap = [
    &["stallionizes"],
    &["stallionises"],
    &["stallionizes"],
    &["stallionises"],
];

pub(crate) static ENTRY_STALLIONIZE_4208189765970167174: VariantsMap = [
    &["stallionize"],
    &["stallionise"],
    &["stallionize"],
    &["stallionise"],
];

pub(crate) static ENTRY_STALWARTIZES_10322196274491160190: VariantsMap = [
    &["stalwartizes"],
    &["stalwartises"],
    &["stalwartizes"],
    &["stalwartises"],
];

pub(crate) static ENTRY_STALWARTIZE_5995004425928514778: VariantsMap = [
    &["stalwartize"],
    &["stalwartise"],
    &["stalwartize"],
    &["stalwartise"],
];

pub(crate) static ENTRY_STAMMELCOLOR_3112896012993635952: VariantsMap = [
    &["stammelcolor"],
    &["stammelcolour"],
    &["stammelcolour"],
    &["stammelcolour"],
];

pub(crate) static ENTRY_STANDARDIZABLES_16202726792541011392: VariantsMap = [
    &["standardizables"],
    &["standardisables"],
    &["standardizables"],
    &["standardisables"],
];

pub(crate) static ENTRY_STANDARDIZABLE_17034002894056241852: VariantsMap = [
    &["standardizable"],
    &["standardisable"],
    &["standardizable"],
    &["standardisable"],
];

pub(crate) static ENTRY_STANDARDIZATIONS_4142468637621036850: VariantsMap = [
    &["standardizations"],
    &["standardisations"],
    &["standardizations"],
    &["standardisations"],
];

pub(crate) static ENTRY_STANDARDIZATION_18269374167214565579: VariantsMap = [
    &["standardization"],
    &["standardisation"],
    &["standardization"],
    &["standardisation"],
];

pub(crate) static ENTRY_STANDARDIZED_10576000602438339721: VariantsMap = [
    &["standardized"],
    &["standardised"],
    &["standardized"],
    &["standardised"],
];

pub(crate) static ENTRY_STANDARDIZERS_12514193886547172459: VariantsMap = [
    &["standardizers"],
    &["standardisers"],
    &["standardizers"],
    &["standardisers"],
];

pub(crate) static ENTRY_STANDARDIZER_10177388752556810926: VariantsMap = [
    &["standardizer"],
    &["standardiser"],
    &["standardizer"],
    &["standardiser"],
];

pub(crate) static ENTRY_STANDARDIZES_15875984166067512659: VariantsMap = [
    &["standardizes"],
    &["standardises"],
    &["standardizes"],
    &["standardises"],
];

pub(crate) static ENTRY_STANDARDIZE_13224353253220214220: VariantsMap = [
    &["standardize"],
    &["standardise"],
    &["standardize"],
    &["standardise"],
];

pub(crate) static ENTRY_STANDARDIZING_14529046022304657646: VariantsMap = [
    &["standardizing"],
    &["standardising"],
    &["standardizing"],
    &["standardising"],
];

pub(crate) static ENTRY_STANZES_13092355244299837812: VariantsMap =
    [&["stanzes"], &["stanzoes"], &["stanzoes"], &["stanzoes"]];

pub(crate) static ENTRY_STAPEDECTOMIZED_3532179470450241494: VariantsMap = [
    &["stapedectomized"],
    &["stapedectomised"],
    &["stapedectomized"],
    &["stapedectomised"],
];

pub(crate) static ENTRY_STAPHYLEDEMA_15542876830880978325: VariantsMap = [
    &["staphyledema"],
    &["staphyloedema"],
    &["staphyloedema"],
    &["staphyloedema"],
];

pub(crate) static ENTRY_STATISTICIZES_3777559913591399659: VariantsMap = [
    &["statisticizes"],
    &["statisticises"],
    &["statisticizes"],
    &["statisticises"],
];

pub(crate) static ENTRY_STATISTICIZE_5352173326738036614: VariantsMap = [
    &["statisticize"],
    &["statisticise"],
    &["statisticize"],
    &["statisticise"],
];

pub(crate) static ENTRY_STEARRHEA_595939535574612058: VariantsMap = [
    &["stearrhea"],
    &["stearrhoea"],
    &["stearrhoea"],
    &["stearrhoea"],
];

pub(crate) static ENTRY_STEATORRHEAS_13012158523524663027: VariantsMap = [
    &["steatorrheas"],
    &["steatorrhoeas"],
    &["steatorrhoeas"],
    &["steatorrhoeas"],
];

pub(crate) static ENTRY_STEATORRHEA_7006550897790317338: VariantsMap = [
    &["steatorrhea"],
    &["steatorrhoea"],
    &["steatorrhoea"],
    &["steatorrhoea"],
];

pub(crate) static ENTRY_STELE_2859069730518054769: VariantsMap =
    [&["stele"], &["stelae"], &["stelae"], &["stelae"]];

pub(crate) static ENTRY_STENCILED_5697108428616257678: VariantsMap = [
    &["stenciled"],
    &["stencilled"],
    &["stencilled"],
    &["stencilled"],
];

pub(crate) static ENTRY_STENCILERS_9411797891465728151: VariantsMap = [
    &["stencilers"],
    &["stencillers"],
    &["stencillers"],
    &["stencillers"],
];

pub(crate) static ENTRY_STENCILER_421866534999425286: VariantsMap = [
    &["stenciler"],
    &["stenciller"],
    &["stenciller"],
    &["stenciller"],
];

pub(crate) static ENTRY_STENCILING_2842472389755702411: VariantsMap = [
    &["stenciling"],
    &["stencilling"],
    &["stencilling"],
    &["stencilling"],
];

pub(crate) static ENTRY_STENCILIZE_2966153114254176045: VariantsMap = [
    &["stencilize"],
    &["stencilise"],
    &["stencilize"],
    &["stencilise"],
];

pub(crate) static ENTRY_STENOPEIC_9668625572592229054: VariantsMap = [
    &["stenopeic"],
    &["stenopaeic"],
    &["stenopaeic"],
    &["stenopaeic"],
];

pub(crate) static ENTRY_STENTORS_11519094998749861028: VariantsMap = [
    &["stentors"],
    &["stentours"],
    &["stentours"],
    &["stentours"],
];

pub(crate) static ENTRY_STENTOR_10267053445154488996: VariantsMap =
    [&["stentor"], &["stentour"], &["stentour"], &["stentour"]];

pub(crate) static ENTRY_STERCOREMIA_16211710810263584762: VariantsMap = [
    &["stercoremia"],
    &["stercoraemia"],
    &["stercoraemia"],
    &["stercoraemia"],
];

pub(crate) static ENTRY_STERE_14973674637271689830: VariantsMap =
    [&["stere"], &["stree"], &["stree"], &["stree"]];

pub(crate) static ENTRY_STERILIZABILITIES_6174521207740612143: VariantsMap = [
    &["sterilizabilities"],
    &["sterilisabilities"],
    &["sterilizabilities"],
    &["sterilisabilities"],
];

pub(crate) static ENTRY_STERILIZABILITY_15756429437692504074: VariantsMap = [
    &["sterilizability"],
    &["sterilisability"],
    &["sterilizability"],
    &["sterilisability"],
];

pub(crate) static ENTRY_STERILIZABLER_5396292600348410338: VariantsMap = [
    &["sterilizabler"],
    &["sterilisabler"],
    &["sterilizabler"],
    &["sterilisabler"],
];

pub(crate) static ENTRY_STERILIZABLEST_17116164156498805946: VariantsMap = [
    &["sterilizablest"],
    &["sterilisablest"],
    &["sterilizablest"],
    &["sterilisablest"],
];

pub(crate) static ENTRY_STERILIZABLES_395845848212238864: VariantsMap = [
    &["sterilizables"],
    &["sterilisables"],
    &["sterilizables"],
    &["sterilisables"],
];

pub(crate) static ENTRY_STERILIZABLE_4293244513265424916: VariantsMap = [
    &["sterilizable"],
    &["sterilisable"],
    &["sterilizable"],
    &["sterilisable"],
];

pub(crate) static ENTRY_STERILIZATIONS_5179586981630149963: VariantsMap = [
    &["sterilizations"],
    &["sterilisations"],
    &["sterilizations"],
    &["sterilisations"],
];

pub(crate) static ENTRY_STERILIZATION_12496932581276788803: VariantsMap = [
    &["sterilization"],
    &["sterilisation"],
    &["sterilization"],
    &["sterilisation"],
];

pub(crate) static ENTRY_STERILIZED_5349106414670253614: VariantsMap = [
    &["sterilized"],
    &["sterilised"],
    &["sterilized"],
    &["sterilised"],
];

pub(crate) static ENTRY_STERILIZERS_3242667110144307808: VariantsMap = [
    &["sterilizers"],
    &["sterilisers"],
    &["sterilizers"],
    &["sterilisers"],
];

pub(crate) static ENTRY_STERILIZER_9665607973109051795: VariantsMap = [
    &["sterilizer"],
    &["steriliser"],
    &["sterilizer"],
    &["steriliser"],
];

pub(crate) static ENTRY_STERILIZES_367692529356557376: VariantsMap = [
    &["sterilizes"],
    &["sterilises"],
    &["sterilizes"],
    &["sterilises"],
];

pub(crate) static ENTRY_STERILIZE_12267676068965370103: VariantsMap = [
    &["sterilize"],
    &["sterilise"],
    &["sterilize"],
    &["sterilise"],
];

pub(crate) static ENTRY_STERILIZING_14742234573275089575: VariantsMap = [
    &["sterilizing"],
    &["sterilising"],
    &["sterilizing"],
    &["sterilising"],
];

pub(crate) static ENTRY_STERT_15188513933795764953: VariantsMap =
    [&["stert"], &["stret"], &["stret"], &["stret"]];

pub(crate) static ENTRY_STIGMATIZATIONS_5206308770780618928: VariantsMap = [
    &["stigmatizations"],
    &["stigmatisations"],
    &["stigmatizations"],
    &["stigmatisations"],
];

pub(crate) static ENTRY_STIGMATIZATION_12053258038244177237: VariantsMap = [
    &["stigmatization"],
    &["stigmatisation"],
    &["stigmatization"],
    &["stigmatisation"],
];

pub(crate) static ENTRY_STIGMATIZED_14597283271555524870: VariantsMap = [
    &["stigmatized"],
    &["stigmatised"],
    &["stigmatized"],
    &["stigmatised"],
];

pub(crate) static ENTRY_STIGMATIZERS_14825741166868000953: VariantsMap = [
    &["stigmatizers"],
    &["stigmatisers"],
    &["stigmatizers"],
    &["stigmatisers"],
];

pub(crate) static ENTRY_STIGMATIZER_6119336948691311551: VariantsMap = [
    &["stigmatizer"],
    &["stigmatiser"],
    &["stigmatizer"],
    &["stigmatiser"],
];

pub(crate) static ENTRY_STIGMATIZES_316959479282222637: VariantsMap = [
    &["stigmatizes"],
    &["stigmatises"],
    &["stigmatizes"],
    &["stigmatises"],
];

pub(crate) static ENTRY_STIGMATIZE_11220162708705129731: VariantsMap = [
    &["stigmatize"],
    &["stigmatise"],
    &["stigmatize"],
    &["stigmatise"],
];

pub(crate) static ENTRY_STIGMATIZING_14536679038681789225: VariantsMap = [
    &["stigmatizing"],
    &["stigmatising"],
    &["stigmatizing"],
    &["stigmatising"],
];

pub(crate) static ENTRY_STILBESTROLS_15735220233409139967: VariantsMap = [
    &["stilbestrols"],
    &["stilboestrols"],
    &["stilboestrols"],
    &["stilboestrols"],
];

pub(crate) static ENTRY_STILBESTROL_10324911942394524790: VariantsMap = [
    &["stilbestrol"],
    &["stilboestrol"],
    &["stilboestrol"],
    &["stilboestrol"],
];

pub(crate) static ENTRY_STIPULE_14068580951871446375: VariantsMap =
    [&["stipule"], &["stipulae"], &["stipulae"], &["stipulae"]];

pub(crate) static ENTRY_STOMATODEUM_8741098205949880656: VariantsMap = [
    &["stomatodeum"],
    &["stomatodaeum"],
    &["stomatodaeum"],
    &["stomatodaeum"],
];

pub(crate) static ENTRY_STOMODEAL_862902637399934901: VariantsMap = [
    &["stomodeal"],
    &["stomodaeal"],
    &["stomodaeal"],
    &["stomodaeal"],
];

pub(crate) static ENTRY_STOMODEA_17558438948754879743: VariantsMap = [
    &["stomodea"],
    &["stomodaea"],
    &["stomodaea"],
    &["stomodaea"],
];

pub(crate) static ENTRY_STOMODEUMS_6754518911406029725: VariantsMap = [
    &["stomodeums"],
    &["stomodaeums"],
    &["stomodaeums"],
    &["stomodaeums"],
];

pub(crate) static ENTRY_STOMODEUM_7352107598988685520: VariantsMap = [
    &["stomodeum"],
    &["stomodaeum"],
    &["stomodaeum"],
    &["stomodaeum"],
];

pub(crate) static ENTRY_STORIER_6107744465020666747: VariantsMap =
    [&["storier"], &["stourier"], &["stourier"], &["stourier"]];

pub(crate) static ENTRY_STOR_5667483645094716832: VariantsMap =
    [&["stor"], &["stour"], &["stour"], &["stour"]];

pub(crate) static ENTRY_STOWERS_13406600671717463574: VariantsMap =
    [&["stowers"], &["stowres"], &["stowres"], &["stowres"]];

pub(crate) static ENTRY_STOWER_3427925530344361004: VariantsMap =
    [&["stower"], &["stowre"], &["stowre"], &["stowre"]];

pub(crate) static ENTRY_STROBILE_5462694341161436350: VariantsMap = [
    &["strobile"],
    &["strobilae"],
    &["strobilae"],
    &["strobilae"],
];

pub(crate) static ENTRY_STROBILIZATIONS_6453453949977182110: VariantsMap = [
    &["strobilizations"],
    &["strobilisations"],
    &["strobilizations"],
    &["strobilisations"],
];

pub(crate) static ENTRY_STROBILIZATION_7297298229503744242: VariantsMap = [
    &["strobilization"],
    &["strobilisation"],
    &["strobilization"],
    &["strobilisation"],
];

pub(crate) static ENTRY_STRUCTURALIZATIONS_12686176034416013309: VariantsMap = [
    &["structuralizations"],
    &["structuralisations"],
    &["structuralizations"],
    &["structuralisations"],
];

pub(crate) static ENTRY_STRUCTURALIZATION_16247212527450308015: VariantsMap = [
    &["structuralization"],
    &["structuralisation"],
    &["structuralization"],
    &["structuralisation"],
];

pub(crate) static ENTRY_STRUCTURALIZES_538653414352082587: VariantsMap = [
    &["structuralizes"],
    &["structuralises"],
    &["structuralizes"],
    &["structuralises"],
];

pub(crate) static ENTRY_STRUCTURALIZE_16594415476051004260: VariantsMap = [
    &["structuralize"],
    &["structuralise"],
    &["structuralize"],
    &["structuralise"],
];

pub(crate) static ENTRY_STRYCHNINIZATIONS_565463606315000819: VariantsMap = [
    &["strychninizations"],
    &["strychninisations"],
    &["strychninizations"],
    &["strychninisations"],
];

pub(crate) static ENTRY_STRYCHNINIZATION_4044621013040012415: VariantsMap = [
    &["strychninization"],
    &["strychninisation"],
    &["strychninization"],
    &["strychninisation"],
];

pub(crate) static ENTRY_STRYCHNINIZES_14335926093096659147: VariantsMap = [
    &["strychninizes"],
    &["strychninises"],
    &["strychninizes"],
    &["strychninises"],
];

pub(crate) static ENTRY_STRYCHNINIZE_17273897055193701327: VariantsMap = [
    &["strychninize"],
    &["strychninise"],
    &["strychninize"],
    &["strychninise"],
];

pub(crate) static ENTRY_STUMOR_11469482697863124360: VariantsMap =
    [&["stumor"], &["stumour"], &["stumour"], &["stumour"]];

pub(crate) static ENTRY_STYLIZATIONS_12181517973286032450: VariantsMap = [
    &["stylizations"],
    &["stylisations"],
    &["stylizations"],
    &["stylisations"],
];

pub(crate) static ENTRY_STYLIZATION_15244694173883242713: VariantsMap = [
    &["stylization"],
    &["stylisation"],
    &["stylization"],
    &["stylisation"],
];

pub(crate) static ENTRY_STYLIZED_16020758497839181911: VariantsMap =
    [&["stylized"], &["stylised"], &["stylized"], &["stylised"]];

pub(crate) static ENTRY_STYLIZERS_2371037382842074036: VariantsMap = [
    &["stylizers"],
    &["stylisers"],
    &["stylizers"],
    &["stylisers"],
];

pub(crate) static ENTRY_STYLIZER_13937646289429611798: VariantsMap =
    [&["stylizer"], &["styliser"], &["stylizer"], &["styliser"]];

pub(crate) static ENTRY_STYLIZES_7516779593566935765: VariantsMap =
    [&["stylizes"], &["stylises"], &["stylizes"], &["stylises"]];

pub(crate) static ENTRY_STYLIZE_1535390784645754383: VariantsMap =
    [&["stylize"], &["stylise"], &["stylize"], &["stylise"]];

pub(crate) static ENTRY_STYLIZING_9348895301814219487: VariantsMap = [
    &["stylizing"],
    &["stylising"],
    &["stylizing"],
    &["stylising"],
];

pub(crate) static ENTRY_STYLOPIZED_12957953051597400041: VariantsMap = [
    &["stylopized"],
    &["stylopised"],
    &["stylopized"],
    &["stylopised"],
];

pub(crate) static ENTRY_SUBARMORS_12932609600459968439: VariantsMap = [
    &["subarmors"],
    &["subarmours"],
    &["subarmours"],
    &["subarmours"],
];

pub(crate) static ENTRY_SUBARMOR_10630628688650559346: VariantsMap = [
    &["subarmor"],
    &["subarmour"],
    &["subarmour"],
    &["subarmour"],
];

pub(crate) static ENTRY_SUBCALIBER_16406723248353952807: VariantsMap = [
    &["subcaliber"],
    &["subcalibre"],
    &["subcalibre"],
    &["subcalibre"],
];

pub(crate) static ENTRY_SUBCATEGORIZING_3085156622608452887: VariantsMap = [
    &["subcategorizing"],
    &["subcategorising"],
    &["subcategorizing"],
    &["subcategorising"],
];

pub(crate) static ENTRY_SUBCENTER_9442934379600097289: VariantsMap = [
    &["subcenter"],
    &["subcentre"],
    &["subcentre"],
    &["subcentre"],
];

pub(crate) static ENTRY_SUBDUER_6426022057783382265: VariantsMap =
    [&["subduer"], &["subdure"], &["subdure"], &["subdure"]];

pub(crate) static ENTRY_SUBERATE_2958713859903830046: VariantsMap = [
    &["suberate"],
    &["subaerate"],
    &["subaerate"],
    &["subaerate"],
];

pub(crate) static ENTRY_SUBERIZATIONS_7532836560480717833: VariantsMap = [
    &["suberizations"],
    &["suberisations"],
    &["suberizations"],
    &["suberisations"],
];

pub(crate) static ENTRY_SUBERIZATION_1080833948419911642: VariantsMap = [
    &["suberization"],
    &["suberisation"],
    &["suberization"],
    &["suberisation"],
];

pub(crate) static ENTRY_SUBERIZED_10174332333495953086: VariantsMap = [
    &["suberized"],
    &["suberised"],
    &["suberized"],
    &["suberised"],
];

pub(crate) static ENTRY_SUBERIZES_17776114559373177493: VariantsMap = [
    &["suberizes"],
    &["suberises"],
    &["suberizes"],
    &["suberises"],
];

pub(crate) static ENTRY_SUBERIZE_9965568250579749505: VariantsMap =
    [&["suberize"], &["suberise"], &["suberize"], &["suberise"]];

pub(crate) static ENTRY_SUBERIZING_11515978326235360567: VariantsMap = [
    &["suberizing"],
    &["suberising"],
    &["suberizing"],
    &["suberising"],
];

pub(crate) static ENTRY_SUBESOPHAGEAL_15820663243055824436: VariantsMap = [
    &["subesophageal"],
    &["suboesophageal"],
    &["suboesophageal"],
    &["suboesophageal"],
];

pub(crate) static ENTRY_SUBETHERIC_2596346146616427172: VariantsMap = [
    &["subetheric"],
    &["subaetheric"],
    &["subaetheric"],
    &["subaetheric"],
];

pub(crate) static ENTRY_SUBFLAVORS_14563327931975471334: VariantsMap = [
    &["subflavors"],
    &["subflavours"],
    &["subflavours"],
    &["subflavours"],
];

pub(crate) static ENTRY_SUBFLAVOR_16056956186177727005: VariantsMap = [
    &["subflavor"],
    &["subflavour"],
    &["subflavour"],
    &["subflavour"],
];

pub(crate) static ENTRY_SUBITIZED_2108404178901406655: VariantsMap = [
    &["subitized"],
    &["subitised"],
    &["subitized"],
    &["subitised"],
];

pub(crate) static ENTRY_SUBITIZES_5445288650913572325: VariantsMap = [
    &["subitizes"],
    &["subitises"],
    &["subitizes"],
    &["subitises"],
];

pub(crate) static ENTRY_SUBITIZE_3227874881853303084: VariantsMap =
    [&["subitize"], &["subitise"], &["subitize"], &["subitise"]];

pub(crate) static ENTRY_SUBITIZING_16606524006734697699: VariantsMap = [
    &["subitizing"],
    &["subitising"],
    &["subitizing"],
    &["subitising"],
];

pub(crate) static ENTRY_SUBJECTIVIZATIONS_9264628960015842629: VariantsMap = [
    &["subjectivizations"],
    &["subjectivisations"],
    &["subjectivizations"],
    &["subjectivisations"],
];

pub(crate) static ENTRY_SUBJECTIVIZATION_10907308115440153544: VariantsMap = [
    &["subjectivization"],
    &["subjectivisation"],
    &["subjectivization"],
    &["subjectivisation"],
];

pub(crate) static ENTRY_SUBJECTIVIZED_3246560572891433421: VariantsMap = [
    &["subjectivized"],
    &["subjectivised"],
    &["subjectivized"],
    &["subjectivised"],
];

pub(crate) static ENTRY_SUBJECTIVIZES_7152248194959006615: VariantsMap = [
    &["subjectivizes"],
    &["subjectivises"],
    &["subjectivizes"],
    &["subjectivises"],
];

pub(crate) static ENTRY_SUBJECTIVIZE_2435583356236162378: VariantsMap = [
    &["subjectivize"],
    &["subjectivise"],
    &["subjectivize"],
    &["subjectivise"],
];

pub(crate) static ENTRY_SUBJECTIVIZING_8718502587935622549: VariantsMap = [
    &["subjectivizing"],
    &["subjectivising"],
    &["subjectivizing"],
    &["subjectivising"],
];

pub(crate) static ENTRY_SUBLIMIZED_17602677846775104325: VariantsMap = [
    &["sublimized"],
    &["sublimised"],
    &["sublimized"],
    &["sublimised"],
];

pub(crate) static ENTRY_SUBLIMIZES_430560762252037002: VariantsMap = [
    &["sublimizes"],
    &["sublimises"],
    &["sublimizes"],
    &["sublimises"],
];

pub(crate) static ENTRY_SUBLIMIZE_8185998513196337857: VariantsMap = [
    &["sublimize"],
    &["sublimise"],
    &["sublimize"],
    &["sublimise"],
];

pub(crate) static ENTRY_SUBLIMIZING_12673180625915709564: VariantsMap = [
    &["sublimizing"],
    &["sublimising"],
    &["sublimizing"],
    &["sublimising"],
];

pub(crate) static ENTRY_SUBMINIATURIZATION_14504776542407713912: VariantsMap = [
    &["subminiaturization"],
    &["subminiaturisation"],
    &["subminiaturization"],
    &["subminiaturisation"],
];

pub(crate) static ENTRY_SUBMINIATURIZED_15597111727187376086: VariantsMap = [
    &["subminiaturized"],
    &["subminiaturised"],
    &["subminiaturized"],
    &["subminiaturised"],
];

pub(crate) static ENTRY_SUBMINIATURIZES_17702176303629650188: VariantsMap = [
    &["subminiaturizes"],
    &["subminiaturises"],
    &["subminiaturizes"],
    &["subminiaturises"],
];

pub(crate) static ENTRY_SUBMINIATURIZE_10382800191995124390: VariantsMap = [
    &["subminiaturize"],
    &["subminiaturise"],
    &["subminiaturize"],
    &["subminiaturise"],
];

pub(crate) static ENTRY_SUBMINIATURIZING_14891752532954283444: VariantsMap = [
    &["subminiaturizing"],
    &["subminiaturising"],
    &["subminiaturizing"],
    &["subminiaturising"],
];

pub(crate) static ENTRY_SUBPULVERIZERS_7885747060142039285: VariantsMap = [
    &["subpulverizers"],
    &["subpulverisers"],
    &["subpulverizers"],
    &["subpulverisers"],
];

pub(crate) static ENTRY_SUBPULVERIZER_6713080541658378074: VariantsMap = [
    &["subpulverizer"],
    &["subpulveriser"],
    &["subpulverizer"],
    &["subpulveriser"],
];

pub(crate) static ENTRY_SUBSIDIZABLES_957075676080529205: VariantsMap = [
    &["subsidizables"],
    &["subsidisables"],
    &["subsidizables"],
    &["subsidisables"],
];

pub(crate) static ENTRY_SUBSIDIZABLE_12403609187359696273: VariantsMap = [
    &["subsidizable"],
    &["subsidisable"],
    &["subsidizable"],
    &["subsidisable"],
];

pub(crate) static ENTRY_SUBSIDIZATIONS_13296883432062947981: VariantsMap = [
    &["subsidizations"],
    &["subsidisations"],
    &["subsidizations"],
    &["subsidisations"],
];

pub(crate) static ENTRY_SUBSIDIZATION_4505517696726661884: VariantsMap = [
    &["subsidization"],
    &["subsidisation"],
    &["subsidization"],
    &["subsidisation"],
];

pub(crate) static ENTRY_SUBSIDIZED_12958293246622856287: VariantsMap = [
    &["subsidized"],
    &["subsidised"],
    &["subsidized"],
    &["subsidised"],
];

pub(crate) static ENTRY_SUBSIDIZERS_10377554586473479765: VariantsMap = [
    &["subsidizers"],
    &["subsidisers"],
    &["subsidizers"],
    &["subsidisers"],
];

pub(crate) static ENTRY_SUBSIDIZER_8190087923295833359: VariantsMap = [
    &["subsidizer"],
    &["subsidiser"],
    &["subsidizer"],
    &["subsidiser"],
];

pub(crate) static ENTRY_SUBSIDIZES_5852930110538753767: VariantsMap = [
    &["subsidizes"],
    &["subsidises"],
    &["subsidizes"],
    &["subsidises"],
];

pub(crate) static ENTRY_SUBSIDIZE_9015916516385257628: VariantsMap = [
    &["subsidize"],
    &["subsidise"],
    &["subsidize"],
    &["subsidise"],
];

pub(crate) static ENTRY_SUBSIDIZING_2567121642876801163: VariantsMap = [
    &["subsidizing"],
    &["subsidising"],
    &["subsidizing"],
    &["subsidising"],
];

pub(crate) static ENTRY_SUBSPECIALIZES_14179857379487185513: VariantsMap = [
    &["subspecializes"],
    &["subspecialises"],
    &["subspecializes"],
    &["subspecialises"],
];

pub(crate) static ENTRY_SUBSPECIALIZE_5110123534584151405: VariantsMap = [
    &["subspecialize"],
    &["subspecialise"],
    &["subspecialize"],
    &["subspecialise"],
];

pub(crate) static ENTRY_SUBSPECIALTIES_5856104107956385634: VariantsMap = [
    &["subspecialties"],
    &["subspecialities"],
    &["subspecialities"],
    &["subspecialities"],
];

pub(crate) static ENTRY_SUBSPECIALTY_4476391942712911269: VariantsMap = [
    &["subspecialty"],
    &["subspeciality"],
    &["subspeciality"],
    &["subspeciality"],
];

pub(crate) static ENTRY_SUBSTANDARDIZES_8917636387963391968: VariantsMap = [
    &["substandardizes"],
    &["substandardises"],
    &["substandardizes"],
    &["substandardises"],
];

pub(crate) static ENTRY_SUBSTANDARDIZE_1074329812678020525: VariantsMap = [
    &["substandardize"],
    &["substandardise"],
    &["substandardize"],
    &["substandardise"],
];

pub(crate) static ENTRY_SUBSTANTIALIZED_9495547837171370415: VariantsMap = [
    &["substantialized"],
    &["substantialised"],
    &["substantialized"],
    &["substantialised"],
];

pub(crate) static ENTRY_SUBSTANTIALIZES_2218483493616659856: VariantsMap = [
    &["substantializes"],
    &["substantialises"],
    &["substantializes"],
    &["substantialises"],
];

pub(crate) static ENTRY_SUBSTANTIALIZE_16565480476325052589: VariantsMap = [
    &["substantialize"],
    &["substantialise"],
    &["substantialize"],
    &["substantialise"],
];

pub(crate) static ENTRY_SUBSTANTIALIZING_3618259364403658920: VariantsMap = [
    &["substantializing"],
    &["substantialising"],
    &["substantializing"],
    &["substantialising"],
];

pub(crate) static ENTRY_SUBSTANTIVIZED_4254503445468994674: VariantsMap = [
    &["substantivized"],
    &["substantivised"],
    &["substantivized"],
    &["substantivised"],
];

pub(crate) static ENTRY_SUBSTANTIVIZES_10108249589648833227: VariantsMap = [
    &["substantivizes"],
    &["substantivises"],
    &["substantivizes"],
    &["substantivises"],
];

pub(crate) static ENTRY_SUBSTANTIVIZE_13021735481609078621: VariantsMap = [
    &["substantivize"],
    &["substantivise"],
    &["substantivize"],
    &["substantivise"],
];

pub(crate) static ENTRY_SUBSTANTIVIZING_13322008447748586118: VariantsMap = [
    &["substantivizing"],
    &["substantivising"],
    &["substantivizing"],
    &["substantivising"],
];

pub(crate) static ENTRY_SUBSTERILIZATION_18359467976046569227: VariantsMap = [
    &["substerilization"],
    &["substerilisation"],
    &["substerilization"],
    &["substerilisation"],
];

pub(crate) static ENTRY_SUBTERRANEANIZES_11938427088659999116: VariantsMap = [
    &["subterraneanizes"],
    &["subterraneanises"],
    &["subterraneanizes"],
    &["subterraneanises"],
];

pub(crate) static ENTRY_SUBTERRANEANIZE_16122048142322693644: VariantsMap = [
    &["subterraneanize"],
    &["subterraneanise"],
    &["subterraneanize"],
    &["subterraneanise"],
];

pub(crate) static ENTRY_SUBTILIZATIONS_816218037167588581: VariantsMap = [
    &["subtilizations"],
    &["subtilisations"],
    &["subtilizations"],
    &["subtilisations"],
];

pub(crate) static ENTRY_SUBTILIZATION_16525688905774221339: VariantsMap = [
    &["subtilization"],
    &["subtilisation"],
    &["subtilization"],
    &["subtilisation"],
];

pub(crate) static ENTRY_SUBTILIZED_12953612644850546188: VariantsMap = [
    &["subtilized"],
    &["subtilised"],
    &["subtilized"],
    &["subtilised"],
];

pub(crate) static ENTRY_SUBTILIZERS_5918033439060086128: VariantsMap = [
    &["subtilizers"],
    &["subtilisers"],
    &["subtilizers"],
    &["subtilisers"],
];

pub(crate) static ENTRY_SUBTILIZER_2092624206187190872: VariantsMap = [
    &["subtilizer"],
    &["subtiliser"],
    &["subtilizer"],
    &["subtiliser"],
];

pub(crate) static ENTRY_SUBTILIZES_7637829126901224384: VariantsMap = [
    &["subtilizes"],
    &["subtilises"],
    &["subtilizes"],
    &["subtilises"],
];

pub(crate) static ENTRY_SUBTILIZE_364396766538437717: VariantsMap = [
    &["subtilize"],
    &["subtilise"],
    &["subtilize"],
    &["subtilise"],
];

pub(crate) static ENTRY_SUBTILIZING_4890677210606357966: VariantsMap = [
    &["subtilizing"],
    &["subtilising"],
    &["subtilizing"],
    &["subtilising"],
];

pub(crate) static ENTRY_SUBTOTALED_11251144387232903283: VariantsMap = [
    &["subtotaled"],
    &["subtotalled"],
    &["subtotalled"],
    &["subtotalled"],
];

pub(crate) static ENTRY_SUBTOTALING_7729561682231991509: VariantsMap = [
    &["subtotaling"],
    &["subtotalling"],
    &["subtotalling"],
    &["subtotalling"],
];

pub(crate) static ENTRY_SUBURBANIZATIONS_4594207725356201298: VariantsMap = [
    &["suburbanizations"],
    &["suburbanisations"],
    &["suburbanizations"],
    &["suburbanisations"],
];

pub(crate) static ENTRY_SUBURBANIZATION_5041053547374142641: VariantsMap = [
    &["suburbanization"],
    &["suburbanisation"],
    &["suburbanization"],
    &["suburbanisation"],
];

pub(crate) static ENTRY_SUBURBANIZED_7801039488105724595: VariantsMap = [
    &["suburbanized"],
    &["suburbanised"],
    &["suburbanized"],
    &["suburbanised"],
];

pub(crate) static ENTRY_SUBURBANIZES_3051574588598676729: VariantsMap = [
    &["suburbanizes"],
    &["suburbanises"],
    &["suburbanizes"],
    &["suburbanises"],
];

pub(crate) static ENTRY_SUBURBANIZE_7361825706290430577: VariantsMap = [
    &["suburbanize"],
    &["suburbanise"],
    &["suburbanize"],
    &["suburbanise"],
];

pub(crate) static ENTRY_SUBURBANIZING_16607196382879275433: VariantsMap = [
    &["suburbanizing"],
    &["suburbanising"],
    &["suburbanizing"],
    &["suburbanising"],
];

pub(crate) static ENTRY_SUBVITALIZATION_14104834684189946569: VariantsMap = [
    &["subvitalization"],
    &["subvitalisation"],
    &["subvitalization"],
    &["subvitalisation"],
];

pub(crate) static ENTRY_SUBVITALIZEDDER_6038599483589110897: VariantsMap = [
    &["subvitalizedder"],
    &["subvitalisedder"],
    &["subvitalizedder"],
    &["subvitalisedder"],
];

pub(crate) static ENTRY_SUBVITALIZEDDEST_4531581466325644556: VariantsMap = [
    &["subvitalizeddest"],
    &["subvitaliseddest"],
    &["subvitalizeddest"],
    &["subvitaliseddest"],
];

pub(crate) static ENTRY_SUBVITALIZEDS_319956284183288639: VariantsMap = [
    &["subvitalizeds"],
    &["subvitaliseds"],
    &["subvitalizeds"],
    &["subvitaliseds"],
];

pub(crate) static ENTRY_SUBVITALIZED_12798033182946604207: VariantsMap = [
    &["subvitalized"],
    &["subvitalised"],
    &["subvitalized"],
    &["subvitalised"],
];

pub(crate) static ENTRY_SUCCORABLES_10281575419378237491: VariantsMap = [
    &["succorables"],
    &["succourables"],
    &["succourables"],
    &["succourables"],
];

pub(crate) static ENTRY_SUCCORABLE_7603179383102744178: VariantsMap = [
    &["succorable"],
    &["succourable"],
    &["succourable"],
    &["succourable"],
];

pub(crate) static ENTRY_SUCCORED_12990159801580773138: VariantsMap = [
    &["succored"],
    &["succoured"],
    &["succoured"],
    &["succoured"],
];

pub(crate) static ENTRY_SUCCORERS_6561319313200472359: VariantsMap = [
    &["succorers"],
    &["succourers"],
    &["succourers"],
    &["succourers"],
];

pub(crate) static ENTRY_SUCCORER_16497801407608107954: VariantsMap = [
    &["succorer"],
    &["succourer"],
    &["succourer"],
    &["succourer"],
];

pub(crate) static ENTRY_SUCCORFUL_4180327020165538900: VariantsMap = [
    &["succorful"],
    &["succourful"],
    &["succourful"],
    &["succourful"],
];

pub(crate) static ENTRY_SUCCORING_11411217915173349617: VariantsMap = [
    &["succoring"],
    &["succouring"],
    &["succouring"],
    &["succouring"],
];

pub(crate) static ENTRY_SUCCORLESSES_12939324178963311324: VariantsMap = [
    &["succorlesses"],
    &["succourlesses"],
    &["succourlesses"],
    &["succourlesses"],
];

pub(crate) static ENTRY_SUCCORLESS_7850671832548251866: VariantsMap = [
    &["succorless"],
    &["succourless"],
    &["succourless"],
    &["succourless"],
];

pub(crate) static ENTRY_SUCCORRHEA_1494636851481194334: VariantsMap = [
    &["succorrhea"],
    &["succorrhoea"],
    &["succorrhoea"],
    &["succorrhoea"],
];

pub(crate) static ENTRY_SUCCORS_3531516934857684627: VariantsMap =
    [&["succors"], &["succours"], &["succours"], &["succours"]];

pub(crate) static ENTRY_SUCCOR_15081921561003187015: VariantsMap =
    [&["succor"], &["succour"], &["succour"], &["succour"]];

pub(crate) static ENTRY_SUCCUBE_9791440353781686466: VariantsMap =
    [&["succube"], &["succubae"], &["succubae"], &["succubae"]];

pub(crate) static ENTRY_SUERS_7272934736981736758: VariantsMap =
    [&["suers"], &["sures"], &["sures"], &["sures"]];

pub(crate) static ENTRY_SUGGESTIONIZES_2131192207235128557: VariantsMap = [
    &["suggestionizes"],
    &["suggestionises"],
    &["suggestionizes"],
    &["suggestionises"],
];

pub(crate) static ENTRY_SUGGESTIONIZE_9511065820694117464: VariantsMap = [
    &["suggestionize"],
    &["suggestionise"],
    &["suggestionize"],
    &["suggestionise"],
];

pub(crate) static ENTRY_SULCALIZED_5425406189232692465: VariantsMap = [
    &["sulcalized"],
    &["sulcalised"],
    &["sulcalized"],
    &["sulcalised"],
];

pub(crate) static ENTRY_SULCALIZES_640675964983651986: VariantsMap = [
    &["sulcalizes"],
    &["sulcalises"],
    &["sulcalizes"],
    &["sulcalises"],
];

pub(crate) static ENTRY_SULCALIZE_8378152628296896141: VariantsMap = [
    &["sulcalize"],
    &["sulcalise"],
    &["sulcalize"],
    &["sulcalise"],
];

pub(crate) static ENTRY_SULCALIZING_5886947456402704718: VariantsMap = [
    &["sulcalizing"],
    &["sulcalising"],
    &["sulcalizing"],
    &["sulcalising"],
];

pub(crate) static ENTRY_SULFATES_4402811146604836852: VariantsMap = [
    &["sulfates"],
    &["sulphates"],
    &["sulphates"],
    &["sulphates"],
];

pub(crate) static ENTRY_SULFATE_12734582688668505440: VariantsMap =
    [&["sulfate"], &["sulphate"], &["sulphate"], &["sulphate"]];

pub(crate) static ENTRY_SULFATIZES_6036327854424560867: VariantsMap = [
    &["sulfatizes"],
    &["sulfatises"],
    &["sulfatizes"],
    &["sulfatises"],
];

pub(crate) static ENTRY_SULFATIZE_13333268258610123633: VariantsMap = [
    &["sulfatize"],
    &["sulfatise"],
    &["sulfatize"],
    &["sulfatise"],
];

pub(crate) static ENTRY_SULFIDES_16764216575605816115: VariantsMap = [
    &["sulfides"],
    &["sulphides"],
    &["sulphides"],
    &["sulphides"],
];

pub(crate) static ENTRY_SULFIDE_7304142610351212973: VariantsMap =
    [&["sulfide"], &["sulphide"], &["sulphide"], &["sulphide"]];

pub(crate) static ENTRY_SULFURED_8189776575606765570: VariantsMap = [
    &["sulfured"],
    &["sulphured"],
    &["sulphured"],
    &["sulphured"],
];

pub(crate) static ENTRY_SULFURIC_1017009640623214170: VariantsMap = [
    &["sulfuric"],
    &["sulphuric"],
    &["sulphuric"],
    &["sulphuric"],
];

pub(crate) static ENTRY_SULFURING_13686792585795899810: VariantsMap = [
    &["sulfuring"],
    &["sulphuring"],
    &["sulphuring"],
    &["sulphuring"],
];

pub(crate) static ENTRY_SULFURIZATIONS_5474468829338012124: VariantsMap = [
    &["sulfurizations"],
    &["sulphurisations"],
    &["sulphurizations"],
    &["sulphurisations"],
];

pub(crate) static ENTRY_SULFURIZATION_14439802421211659492: VariantsMap = [
    &["sulfurization"],
    &["sulphurisation"],
    &["sulphurization"],
    &["sulphurisation"],
];

pub(crate) static ENTRY_SULFURIZED_13939604428112304430: VariantsMap = [
    &["sulfurized"],
    &["sulphurised"],
    &["sulphurized"],
    &["sulphurised"],
];

pub(crate) static ENTRY_SULFURIZES_5918702548576518301: VariantsMap = [
    &["sulfurizes"],
    &["sulphurises"],
    &["sulphurizes"],
    &["sulphurises"],
];

pub(crate) static ENTRY_SULFURIZE_6207811143838647915: VariantsMap = [
    &["sulfurize"],
    &["sulphurise"],
    &["sulphurize"],
    &["sulphurise"],
];

pub(crate) static ENTRY_SULFURIZING_8560422491260610461: VariantsMap = [
    &["sulfurizing"],
    &["sulphurising"],
    &["sulphurizing"],
    &["sulphurising"],
];

pub(crate) static ENTRY_SULFUROUS_10926705129400784683: VariantsMap = [
    &["sulfurous"],
    &["sulphurous"],
    &["sulphurous"],
    &["sulphurous"],
];

pub(crate) static ENTRY_SULFURS_750949739916739801: VariantsMap =
    [&["sulfurs"], &["sulphurs"], &["sulphurs"], &["sulphurs"]];

pub(crate) static ENTRY_SULFUR_10049808270063012273: VariantsMap =
    [&["sulfur"], &["sulphur"], &["sulphur"], &["sulphur"]];

pub(crate) static ENTRY_SULTANIZES_9680614734074701263: VariantsMap = [
    &["sultanizes"],
    &["sultanises"],
    &["sultanizes"],
    &["sultanises"],
];

pub(crate) static ENTRY_SULTANIZE_4736867272905083425: VariantsMap = [
    &["sultanize"],
    &["sultanise"],
    &["sultanize"],
    &["sultanise"],
];

pub(crate) static ENTRY_SUMMARIZABLE_8885048172619412441: VariantsMap = [
    &["summarizable"],
    &["summarisable"],
    &["summarizable"],
    &["summarisable"],
];

pub(crate) static ENTRY_SUMMARIZATIONS_6246410965460713485: VariantsMap = [
    &["summarizations"],
    &["summarisations"],
    &["summarizations"],
    &["summarisations"],
];

pub(crate) static ENTRY_SUMMARIZATION_1450117887113919650: VariantsMap = [
    &["summarization"],
    &["summarisation"],
    &["summarization"],
    &["summarisation"],
];

pub(crate) static ENTRY_SUMMARIZED_11820249661747504946: VariantsMap = [
    &["summarized"],
    &["summarised"],
    &["summarized"],
    &["summarised"],
];

pub(crate) static ENTRY_SUMMARIZERS_10721471147508695276: VariantsMap = [
    &["summarizers"],
    &["summarisers"],
    &["summarizers"],
    &["summarisers"],
];

pub(crate) static ENTRY_SUMMARIZER_10384176123331578848: VariantsMap = [
    &["summarizer"],
    &["summariser"],
    &["summarizer"],
    &["summariser"],
];

pub(crate) static ENTRY_SUMMARIZES_14818168405290018071: VariantsMap = [
    &["summarizes"],
    &["summarises"],
    &["summarizes"],
    &["summarises"],
];

pub(crate) static ENTRY_SUMMARIZE_4043965903576683508: VariantsMap = [
    &["summarize"],
    &["summarise"],
    &["summarize"],
    &["summarise"],
];

pub(crate) static ENTRY_SUMMARIZING_4468233879394675836: VariantsMap = [
    &["summarizing"],
    &["summarising"],
    &["summarizing"],
    &["summarising"],
];

pub(crate) static ENTRY_SUMMERIZES_12278244173537641354: VariantsMap = [
    &["summerizes"],
    &["summerises"],
    &["summerizes"],
    &["summerises"],
];

pub(crate) static ENTRY_SUMMERIZE_4051177429594741620: VariantsMap = [
    &["summerize"],
    &["summerise"],
    &["summerize"],
    &["summerise"],
];

pub(crate) static ENTRY_SUPERACKNOWLEDGMENTS_7768783977000239516: VariantsMap = [
    &["superacknowledgments"],
    &["superacknowledgements"],
    &["superacknowledgements"],
    &["superacknowledgements"],
];

pub(crate) static ENTRY_SUPERACKNOWLEDGMENT_18055315220706538962: VariantsMap = [
    &["superacknowledgment"],
    &["superacknowledgement"],
    &["superacknowledgement"],
    &["superacknowledgement"],
];

pub(crate) static ENTRY_SUPERCANONIZATIONS_4755355331109857311: VariantsMap = [
    &["supercanonizations"],
    &["supercanonisations"],
    &["supercanonizations"],
    &["supercanonisations"],
];

pub(crate) static ENTRY_SUPERCANONIZATION_4336218867107151380: VariantsMap = [
    &["supercanonization"],
    &["supercanonisation"],
    &["supercanonization"],
    &["supercanonisation"],
];

pub(crate) static ENTRY_SUPERCARBONIZATIONS_10831679594408466920: VariantsMap = [
    &["supercarbonizations"],
    &["supercarbonisations"],
    &["supercarbonizations"],
    &["supercarbonisations"],
];

pub(crate) static ENTRY_SUPERCARBONIZATION_1217950256825062958: VariantsMap = [
    &["supercarbonization"],
    &["supercarbonisation"],
    &["supercarbonization"],
    &["supercarbonisation"],
];

pub(crate) static ENTRY_SUPERCARBONIZES_683964189361439315: VariantsMap = [
    &["supercarbonizes"],
    &["supercarbonises"],
    &["supercarbonizes"],
    &["supercarbonises"],
];

pub(crate) static ENTRY_SUPERCARBONIZE_7821965803696896835: VariantsMap = [
    &["supercarbonize"],
    &["supercarbonise"],
    &["supercarbonize"],
    &["supercarbonise"],
];

pub(crate) static ENTRY_SUPERCIVILIZATIONS_2634390504398689511: VariantsMap = [
    &["supercivilizations"],
    &["supercivilisations"],
    &["supercivilizations"],
    &["supercivilisations"],
];

pub(crate) static ENTRY_SUPERCIVILIZATION_1458840308729646079: VariantsMap = [
    &["supercivilization"],
    &["supercivilisation"],
    &["supercivilization"],
    &["supercivilisation"],
];

pub(crate) static ENTRY_SUPERCIVILIZEDS_2859106069953321338: VariantsMap = [
    &["supercivilizeds"],
    &["superciviliseds"],
    &["supercivilizeds"],
    &["superciviliseds"],
];

pub(crate) static ENTRY_SUPERCIVILIZED_2238853392228517699: VariantsMap = [
    &["supercivilized"],
    &["supercivilised"],
    &["supercivilized"],
    &["supercivilised"],
];

pub(crate) static ENTRY_SUPEREMPHASIZES_11905195641762477558: VariantsMap = [
    &["superemphasizes"],
    &["superemphasises"],
    &["superemphasizes"],
    &["superemphasises"],
];

pub(crate) static ENTRY_SUPEREMPHASIZE_3382031681661300047: VariantsMap = [
    &["superemphasize"],
    &["superemphasise"],
    &["superemphasize"],
    &["superemphasise"],
];

pub(crate) static ENTRY_SUPERFETATIONS_10292712087384952307: VariantsMap = [
    &["superfetations"],
    &["superfoetations"],
    &["superfoetations"],
    &["superfoetations"],
];

pub(crate) static ENTRY_SUPERFETATION_12600225493156545849: VariantsMap = [
    &["superfetation"],
    &["superfoetation"],
    &["superfoetation"],
    &["superfoetation"],
];

pub(crate) static ENTRY_SUPERFICIALIZED_16789114853240296207: VariantsMap = [
    &["superficialized"],
    &["superficialised"],
    &["superficialized"],
    &["superficialised"],
];

pub(crate) static ENTRY_SUPERFICIALIZES_17549727985126882796: VariantsMap = [
    &["superficializes"],
    &["superficialises"],
    &["superficializes"],
    &["superficialises"],
];

pub(crate) static ENTRY_SUPERFICIALIZE_2738339175970343799: VariantsMap = [
    &["superficialize"],
    &["superficialise"],
    &["superficialize"],
    &["superficialise"],
];

pub(crate) static ENTRY_SUPERFICIALIZING_17334979727341640969: VariantsMap = [
    &["superficializing"],
    &["superficialising"],
    &["superficializing"],
    &["superficialising"],
];

pub(crate) static ENTRY_SUPERHUMANIZED_15608702836101169679: VariantsMap = [
    &["superhumanized"],
    &["superhumanised"],
    &["superhumanized"],
    &["superhumanised"],
];

pub(crate) static ENTRY_SUPERHUMANIZES_10570138598632742368: VariantsMap = [
    &["superhumanizes"],
    &["superhumanises"],
    &["superhumanizes"],
    &["superhumanises"],
];

pub(crate) static ENTRY_SUPERHUMANIZE_15633115389662702814: VariantsMap = [
    &["superhumanize"],
    &["superhumanise"],
    &["superhumanize"],
    &["superhumanise"],
];

pub(crate) static ENTRY_SUPERHUMANIZING_4071636756107716090: VariantsMap = [
    &["superhumanizing"],
    &["superhumanising"],
    &["superhumanizing"],
    &["superhumanising"],
];

pub(crate) static ENTRY_SUPERNATURALIZED_14415170850743090399: VariantsMap = [
    &["supernaturalized"],
    &["supernaturalised"],
    &["supernaturalized"],
    &["supernaturalised"],
];

pub(crate) static ENTRY_SUPERNATURALIZES_16951225069063962411: VariantsMap = [
    &["supernaturalizes"],
    &["supernaturalises"],
    &["supernaturalizes"],
    &["supernaturalises"],
];

pub(crate) static ENTRY_SUPERNATURALIZE_14037531297937878869: VariantsMap = [
    &["supernaturalize"],
    &["supernaturalise"],
    &["supernaturalize"],
    &["supernaturalise"],
];

pub(crate) static ENTRY_SUPERNATURALIZING_8508315994313061480: VariantsMap = [
    &["supernaturalizing"],
    &["supernaturalising"],
    &["supernaturalizing"],
    &["supernaturalising"],
];

pub(crate) static ENTRY_SUPERORGANIZATIONS_10617131285596283213: VariantsMap = [
    &["superorganizations"],
    &["superorganisations"],
    &["superorganizations"],
    &["superorganisations"],
];

pub(crate) static ENTRY_SUPERORGANIZATION_8860022256249649969: VariantsMap = [
    &["superorganization"],
    &["superorganisation"],
    &["superorganization"],
    &["superorganisation"],
];

pub(crate) static ENTRY_SUPERORGANIZES_5444912774808934766: VariantsMap = [
    &["superorganizes"],
    &["superorganises"],
    &["superorganizes"],
    &["superorganises"],
];

pub(crate) static ENTRY_SUPERORGANIZE_8384924288227808894: VariantsMap = [
    &["superorganize"],
    &["superorganise"],
    &["superorganize"],
    &["superorganise"],
];

pub(crate) static ENTRY_SUPERSENSITIZATIONS_17166516002820124032: VariantsMap = [
    &["supersensitizations"],
    &["supersensitisations"],
    &["supersensitizations"],
    &["supersensitisations"],
];

pub(crate) static ENTRY_SUPERSENSITIZATION_13006014246685708385: VariantsMap = [
    &["supersensitization"],
    &["supersensitisation"],
    &["supersensitization"],
    &["supersensitisation"],
];

pub(crate) static ENTRY_SUPERSENSITIZED_1021249000838099530: VariantsMap = [
    &["supersensitized"],
    &["supersensitised"],
    &["supersensitized"],
    &["supersensitised"],
];

pub(crate) static ENTRY_SUPERSENSITIZE_7006527570782329036: VariantsMap = [
    &["supersensitize"],
    &["supersensitise"],
    &["supersensitize"],
    &["supersensitise"],
];

pub(crate) static ENTRY_SUPERSENSITIZING_5029091819363480393: VariantsMap = [
    &["supersensitizing"],
    &["supersensitising"],
    &["supersensitizing"],
    &["supersensitising"],
];

pub(crate) static ENTRY_SUPERSPECIALIZES_4737590243517715555: VariantsMap = [
    &["superspecializes"],
    &["superspecialises"],
    &["superspecializes"],
    &["superspecialises"],
];

pub(crate) static ENTRY_SUPERSPECIALIZE_252058508575789924: VariantsMap = [
    &["superspecialize"],
    &["superspecialise"],
    &["superspecialize"],
    &["superspecialise"],
];

pub(crate) static ENTRY_SUPERSUBTILIZEDS_13560124924918518109: VariantsMap = [
    &["supersubtilizeds"],
    &["supersubtiliseds"],
    &["supersubtilizeds"],
    &["supersubtiliseds"],
];

pub(crate) static ENTRY_SUPERSUBTILIZED_11208309807789263657: VariantsMap = [
    &["supersubtilized"],
    &["supersubtilised"],
    &["supersubtilized"],
    &["supersubtilised"],
];

pub(crate) static ENTRY_SUPERSULPHURIZES_1086828648943519821: VariantsMap = [
    &["supersulphurizes"],
    &["supersulphurises"],
    &["supersulphurizes"],
    &["supersulphurises"],
];

pub(crate) static ENTRY_SUPERSULPHURIZE_3926397118291965214: VariantsMap = [
    &["supersulphurize"],
    &["supersulphurise"],
    &["supersulphurize"],
    &["supersulphurise"],
];

pub(crate) static ENTRY_SURGERIZES_13175724116978873269: VariantsMap = [
    &["surgerizes"],
    &["surgerises"],
    &["surgerizes"],
    &["surgerises"],
];

pub(crate) static ENTRY_SURGERIZE_4983277252612670769: VariantsMap = [
    &["surgerize"],
    &["surgerise"],
    &["surgerize"],
    &["surgerise"],
];

pub(crate) static ENTRY_SURPRIZAL_5281380386605833450: VariantsMap = [
    &["surprizal"],
    &["surprisal"],
    &["surprizal"],
    &["surprisal"],
];

pub(crate) static ENTRY_SURSIZE_3670570722345111046: VariantsMap =
    [&["sursize"], &["sursise"], &["sursize"], &["sursise"]];

pub(crate) static ENTRY_SWIVELED_17790968621944461091: VariantsMap = [
    &["swiveled"],
    &["swivelled"],
    &["swivelled"],
    &["swivelled"],
];

pub(crate) static ENTRY_SWIVELING_11766360434972105410: VariantsMap = [
    &["swiveling"],
    &["swivelling"],
    &["swivelling"],
    &["swivelling"],
];

pub(crate) static ENTRY_SYCOPHANTIZED_2066913815102436404: VariantsMap = [
    &["sycophantized"],
    &["sycophantised"],
    &["sycophantized"],
    &["sycophantised"],
];

pub(crate) static ENTRY_SYCOPHANTIZES_13350123606555790806: VariantsMap = [
    &["sycophantizes"],
    &["sycophantises"],
    &["sycophantizes"],
    &["sycophantises"],
];

pub(crate) static ENTRY_SYCOPHANTIZE_12413841667742806235: VariantsMap = [
    &["sycophantize"],
    &["sycophantise"],
    &["sycophantize"],
    &["sycophantise"],
];

pub(crate) static ENTRY_SYCOPHANTIZING_3707179500919311993: VariantsMap = [
    &["sycophantizing"],
    &["sycophantising"],
    &["sycophantizing"],
    &["sycophantising"],
];

pub(crate) static ENTRY_SYLLABIZED_9081626028680716952: VariantsMap = [
    &["syllabized"],
    &["syllabised"],
    &["syllabized"],
    &["syllabised"],
];

pub(crate) static ENTRY_SYLLABIZES_4355228480284739560: VariantsMap = [
    &["syllabizes"],
    &["syllabises"],
    &["syllabizes"],
    &["syllabises"],
];

pub(crate) static ENTRY_SYLLABIZE_14838824136293204776: VariantsMap = [
    &["syllabize"],
    &["syllabise"],
    &["syllabize"],
    &["syllabise"],
];

pub(crate) static ENTRY_SYLLABIZING_8483234654100117810: VariantsMap = [
    &["syllabizing"],
    &["syllabising"],
    &["syllabizing"],
    &["syllabising"],
];

pub(crate) static ENTRY_SYLLOGIZATIONS_1183019196317532349: VariantsMap = [
    &["syllogizations"],
    &["syllogisations"],
    &["syllogizations"],
    &["syllogisations"],
];

pub(crate) static ENTRY_SYLLOGIZATION_13866539649373728599: VariantsMap = [
    &["syllogization"],
    &["syllogisation"],
    &["syllogization"],
    &["syllogisation"],
];

pub(crate) static ENTRY_SYLLOGIZED_8853526086846614350: VariantsMap = [
    &["syllogized"],
    &["syllogised"],
    &["syllogized"],
    &["syllogised"],
];

pub(crate) static ENTRY_SYLLOGIZERS_16910938558367919539: VariantsMap = [
    &["syllogizers"],
    &["syllogisers"],
    &["syllogizers"],
    &["syllogisers"],
];

pub(crate) static ENTRY_SYLLOGIZER_18106093548206015296: VariantsMap = [
    &["syllogizer"],
    &["syllogiser"],
    &["syllogizer"],
    &["syllogiser"],
];

pub(crate) static ENTRY_SYLLOGIZES_4817593494892630151: VariantsMap = [
    &["syllogizes"],
    &["syllogises"],
    &["syllogizes"],
    &["syllogises"],
];

pub(crate) static ENTRY_SYLLOGIZE_4080740851235947751: VariantsMap = [
    &["syllogize"],
    &["syllogise"],
    &["syllogize"],
    &["syllogise"],
];

pub(crate) static ENTRY_SYLLOGIZING_2067797967245895866: VariantsMap = [
    &["syllogizing"],
    &["syllogising"],
    &["syllogizing"],
    &["syllogising"],
];

pub(crate) static ENTRY_SYLVANIZES_12196473219346057983: VariantsMap = [
    &["sylvanizes"],
    &["sylvanises"],
    &["sylvanizes"],
    &["sylvanises"],
];

pub(crate) static ENTRY_SYLVANIZE_6265985924948097486: VariantsMap = [
    &["sylvanize"],
    &["sylvanise"],
    &["sylvanize"],
    &["sylvanise"],
];

pub(crate) static ENTRY_SYLVIINE_8241338552519015158: VariantsMap = [
    &["sylviine"],
    &["sylviinae"],
    &["sylviinae"],
    &["sylviinae"],
];

pub(crate) static ENTRY_SYMBOLED_11424483443027028085: VariantsMap = [
    &["symboled"],
    &["symbolled"],
    &["symbolled"],
    &["symbolled"],
];

pub(crate) static ENTRY_SYMBOLING_10019336982510109720: VariantsMap = [
    &["symboling"],
    &["symbolling"],
    &["symbolling"],
    &["symbolling"],
];

pub(crate) static ENTRY_SYMBOLIZATIONS_5969166456353671405: VariantsMap = [
    &["symbolizations"],
    &["symbolisations"],
    &["symbolizations"],
    &["symbolisations"],
];

pub(crate) static ENTRY_SYMBOLIZATION_16179533248304689346: VariantsMap = [
    &["symbolization"],
    &["symbolisation"],
    &["symbolization"],
    &["symbolisation"],
];

pub(crate) static ENTRY_SYMBOLIZED_139431671119330705: VariantsMap = [
    &["symbolized"],
    &["symbolised"],
    &["symbolized"],
    &["symbolised"],
];

pub(crate) static ENTRY_SYMBOLIZERS_1983691641725453382: VariantsMap = [
    &["symbolizers"],
    &["symbolisers"],
    &["symbolizers"],
    &["symbolisers"],
];

pub(crate) static ENTRY_SYMBOLIZER_12834461225156804749: VariantsMap = [
    &["symbolizer"],
    &["symboliser"],
    &["symbolizer"],
    &["symboliser"],
];

pub(crate) static ENTRY_SYMBOLIZES_7534842968073056718: VariantsMap = [
    &["symbolizes"],
    &["symbolises"],
    &["symbolizes"],
    &["symbolises"],
];

pub(crate) static ENTRY_SYMBOLIZE_1459836702485298151: VariantsMap = [
    &["symbolize"],
    &["symbolise"],
    &["symbolize"],
    &["symbolise"],
];

pub(crate) static ENTRY_SYMBOLIZING_14319052571837316351: VariantsMap = [
    &["symbolizing"],
    &["symbolising"],
    &["symbolizing"],
    &["symbolising"],
];

pub(crate) static ENTRY_SYMMETRICALLY_11790246473159683276: VariantsMap = [
    &["symmetrically"],
    &["symmetrically"],
    &["symmetrically"],
    &["symmetrically"],
];

pub(crate) static ENTRY_SYMMETRIZATIONS_13298765629243557367: VariantsMap = [
    &["symmetrizations"],
    &["symmetrisations"],
    &["symmetrizations"],
    &["symmetrisations"],
];

pub(crate) static ENTRY_SYMMETRIZATION_485523952999666992: VariantsMap = [
    &["symmetrization"],
    &["symmetrisation"],
    &["symmetrization"],
    &["symmetrisation"],
];

pub(crate) static ENTRY_SYMMETRIZED_13721183907018153188: VariantsMap = [
    &["symmetrized"],
    &["symmetrised"],
    &["symmetrized"],
    &["symmetrised"],
];

pub(crate) static ENTRY_SYMMETRIZES_14737575873723059815: VariantsMap = [
    &["symmetrizes"],
    &["symmetrises"],
    &["symmetrizes"],
    &["symmetrises"],
];

pub(crate) static ENTRY_SYMMETRIZE_17748763142030256395: VariantsMap = [
    &["symmetrize"],
    &["symmetrise"],
    &["symmetrize"],
    &["symmetrise"],
];

pub(crate) static ENTRY_SYMMETRIZING_17834200335648295925: VariantsMap = [
    &["symmetrizing"],
    &["symmetrising"],
    &["symmetrizing"],
    &["symmetrising"],
];

pub(crate) static ENTRY_SYMPATHIZED_9100939682714028608: VariantsMap = [
    &["sympathized"],
    &["sympathised"],
    &["sympathized"],
    &["sympathised"],
];

pub(crate) static ENTRY_SYMPATHIZERS_3558777146047267180: VariantsMap = [
    &["sympathizers"],
    &["sympathisers"],
    &["sympathizers"],
    &["sympathisers"],
];

pub(crate) static ENTRY_SYMPATHIZER_6062465131842187171: VariantsMap = [
    &["sympathizer"],
    &["sympathiser"],
    &["sympathizer"],
    &["sympathiser"],
];

pub(crate) static ENTRY_SYMPATHIZES_18348047905035226610: VariantsMap = [
    &["sympathizes"],
    &["sympathises"],
    &["sympathizes"],
    &["sympathises"],
];

pub(crate) static ENTRY_SYMPATHIZE_2083128667147215284: VariantsMap = [
    &["sympathize"],
    &["sympathise"],
    &["sympathize"],
    &["sympathise"],
];

pub(crate) static ENTRY_SYMPATHIZINGLIER_17003334067553508909: VariantsMap = [
    &["sympathizinglier"],
    &["sympathisinglier"],
    &["sympathizinglier"],
    &["sympathisinglier"],
];

pub(crate) static ENTRY_SYMPATHIZINGLIEST_8990695458438411519: VariantsMap = [
    &["sympathizingliest"],
    &["sympathisingliest"],
    &["sympathizingliest"],
    &["sympathisingliest"],
];

pub(crate) static ENTRY_SYMPATHIZINGLY_18120189054155456947: VariantsMap = [
    &["sympathizingly"],
    &["sympathisingly"],
    &["sympathizingly"],
    &["sympathisingly"],
];

pub(crate) static ENTRY_SYMPATHIZINGS_14242801861585199541: VariantsMap = [
    &["sympathizings"],
    &["sympathisings"],
    &["sympathizings"],
    &["sympathisings"],
];

pub(crate) static ENTRY_SYMPATHIZING_5627262407078518926: VariantsMap = [
    &["sympathizing"],
    &["sympathising"],
    &["sympathizing"],
    &["sympathising"],
];

pub(crate) static ENTRY_SYMPHONIZATION_7458803542727781710: VariantsMap = [
    &["symphonization"],
    &["symphonisation"],
    &["symphonization"],
    &["symphonisation"],
];

pub(crate) static ENTRY_SYMPHONIZED_10820642800496437334: VariantsMap = [
    &["symphonized"],
    &["symphonised"],
    &["symphonized"],
    &["symphonised"],
];

pub(crate) static ENTRY_SYMPHONIZE_14460696128283226931: VariantsMap = [
    &["symphonize"],
    &["symphonise"],
    &["symphonize"],
    &["symphonise"],
];

pub(crate) static ENTRY_SYMPHONIZING_6006748045534915173: VariantsMap = [
    &["symphonizing"],
    &["symphonising"],
    &["symphonizing"],
    &["symphonising"],
];

pub(crate) static ENTRY_SYMPTOMATIZED_13255146815106504892: VariantsMap = [
    &["symptomatized"],
    &["symptomatised"],
    &["symptomatized"],
    &["symptomatised"],
];

pub(crate) static ENTRY_SYMPTOMATIZES_17459302438827356078: VariantsMap = [
    &["symptomatizes"],
    &["symptomatises"],
    &["symptomatizes"],
    &["symptomatises"],
];

pub(crate) static ENTRY_SYMPTOMATIZE_7741807692536744481: VariantsMap = [
    &["symptomatize"],
    &["symptomatise"],
    &["symptomatize"],
    &["symptomatise"],
];

pub(crate) static ENTRY_SYMPTOMATIZING_7075635847781625915: VariantsMap = [
    &["symptomatizing"],
    &["symptomatising"],
    &["symptomatizing"],
    &["symptomatising"],
];

pub(crate) static ENTRY_SYMPTOMIZES_2947814609442326128: VariantsMap = [
    &["symptomizes"],
    &["symptomises"],
    &["symptomizes"],
    &["symptomises"],
];

pub(crate) static ENTRY_SYMPTOMIZE_10180337916709250431: VariantsMap = [
    &["symptomize"],
    &["symptomise"],
    &["symptomize"],
    &["symptomise"],
];

pub(crate) static ENTRY_SYNALEPHAS_15856626290957460889: VariantsMap = [
    &["synalephas"],
    &["synaloephas"],
    &["synaloephas"],
    &["synaloephas"],
];

pub(crate) static ENTRY_SYNALEPHA_7165508884472247255: VariantsMap = [
    &["synalepha"],
    &["synaloepha"],
    &["synaloepha"],
    &["synaloepha"],
];

pub(crate) static ENTRY_SYNALEPHE_7691233255701997232: VariantsMap = [
    &["synalephe"],
    &["synaloephe"],
    &["synaloephe"],
    &["synaloephe"],
];

pub(crate) static ENTRY_SYNCHRONIZABLES_11909224206869588914: VariantsMap = [
    &["synchronizables"],
    &["synchronisables"],
    &["synchronizables"],
    &["synchronisables"],
];

pub(crate) static ENTRY_SYNCHRONIZABLE_3205035752239437919: VariantsMap = [
    &["synchronizable"],
    &["synchronisable"],
    &["synchronizable"],
    &["synchronisable"],
];

pub(crate) static ENTRY_SYNCHRONIZATIONS_17488049115311509779: VariantsMap = [
    &["synchronizations"],
    &["synchronisations"],
    &["synchronizations"],
    &["synchronisations"],
];

pub(crate) static ENTRY_SYNCHRONIZATION_5190235443366915825: VariantsMap = [
    &["synchronization"],
    &["synchronisation"],
    &["synchronization"],
    &["synchronisation"],
];

pub(crate) static ENTRY_SYNCHRONIZED_10463645930849898556: VariantsMap = [
    &["synchronized"],
    &["synchronised"],
    &["synchronized"],
    &["synchronised"],
];

pub(crate) static ENTRY_SYNCHRONIZERS_7212648156840732242: VariantsMap = [
    &["synchronizers"],
    &["synchronisers"],
    &["synchronizers"],
    &["synchronisers"],
];

pub(crate) static ENTRY_SYNCHRONIZER_18217273731132106451: VariantsMap = [
    &["synchronizer"],
    &["synchroniser"],
    &["synchronizer"],
    &["synchroniser"],
];

pub(crate) static ENTRY_SYNCHRONIZES_1300752223538140438: VariantsMap = [
    &["synchronizes"],
    &["synchronises"],
    &["synchronizes"],
    &["synchronises"],
];

pub(crate) static ENTRY_SYNCHRONIZE_15214148970446599589: VariantsMap = [
    &["synchronize"],
    &["synchronise"],
    &["synchronize"],
    &["synchronise"],
];

pub(crate) static ENTRY_SYNCHRONIZING_16424531352538153842: VariantsMap = [
    &["synchronizing"],
    &["synchronising"],
    &["synchronizing"],
    &["synchronising"],
];

pub(crate) static ENTRY_SYNCRETIZED_132756498383462765: VariantsMap = [
    &["syncretized"],
    &["syncretised"],
    &["syncretized"],
    &["syncretised"],
];

pub(crate) static ENTRY_SYNCRETIZES_15427417846092983438: VariantsMap = [
    &["syncretizes"],
    &["syncretises"],
    &["syncretizes"],
    &["syncretises"],
];

pub(crate) static ENTRY_SYNCRETIZE_11946220904942894650: VariantsMap = [
    &["syncretize"],
    &["syncretise"],
    &["syncretize"],
    &["syncretise"],
];

pub(crate) static ENTRY_SYNCRETIZING_16214408936304608287: VariantsMap = [
    &["syncretizing"],
    &["syncretising"],
    &["syncretizing"],
    &["syncretising"],
];

pub(crate) static ENTRY_SYNDICALIZES_7458900059096200056: VariantsMap = [
    &["syndicalizes"],
    &["syndicalises"],
    &["syndicalizes"],
    &["syndicalises"],
];

pub(crate) static ENTRY_SYNDICALIZE_6097714922943684680: VariantsMap = [
    &["syndicalize"],
    &["syndicalise"],
    &["syndicalize"],
    &["syndicalise"],
];

pub(crate) static ENTRY_SYNECIOUS_16097725599665781486: VariantsMap = [
    &["synecious"],
    &["synoecious"],
    &["synoecious"],
    &["synoecious"],
];

pub(crate) static ENTRY_SYNECOLOGIES_6305448968712762615: VariantsMap = [
    &["synecologies"],
    &["synoecologies"],
    &["synoecologies"],
    &["synoecologies"],
];

pub(crate) static ENTRY_SYNECOLOGY_11727520395273669799: VariantsMap = [
    &["synecology"],
    &["synoecology"],
    &["synoecology"],
    &["synoecology"],
];

pub(crate) static ENTRY_SYNERESES_8324225573506584897: VariantsMap = [
    &["synereses"],
    &["synaereses"],
    &["synaereses"],
    &["synaereses"],
];

pub(crate) static ENTRY_SYNERESIS_10899482620726729247: VariantsMap = [
    &["syneresis"],
    &["synaeresis"],
    &["synaeresis"],
    &["synaeresis"],
];

pub(crate) static ENTRY_SYNERGIZED_2939063503049761679: VariantsMap = [
    &["synergized"],
    &["synergised"],
    &["synergized"],
    &["synergised"],
];

pub(crate) static ENTRY_SYNERGIZES_1372737127479711106: VariantsMap = [
    &["synergizes"],
    &["synergises"],
    &["synergizes"],
    &["synergises"],
];

pub(crate) static ENTRY_SYNERGIZE_8702906954167154251: VariantsMap = [
    &["synergize"],
    &["synergise"],
    &["synergize"],
    &["synergise"],
];

pub(crate) static ENTRY_SYNERGIZING_11050376152195270684: VariantsMap = [
    &["synergizing"],
    &["synergising"],
    &["synergizing"],
    &["synergising"],
];

pub(crate) static ENTRY_SYNESTHESIAS_15212694822545420870: VariantsMap = [
    &["synesthesias"],
    &["synaesthesias"],
    &["synaesthesias"],
    &["synaesthesias"],
];

pub(crate) static ENTRY_SYNESTHESIA_16292496210206747868: VariantsMap = [
    &["synesthesia"],
    &["synaesthesia"],
    &["synaesthesia"],
    &["synaesthesia"],
];

pub(crate) static ENTRY_SYNESTHETICER_10910454298234931775: VariantsMap = [
    &["synestheticer"],
    &["synaestheticer"],
    &["synaestheticer"],
    &["synaestheticer"],
];

pub(crate) static ENTRY_SYNESTHETICEST_831211085037853858: VariantsMap = [
    &["synestheticest"],
    &["synaestheticest"],
    &["synaestheticest"],
    &["synaestheticest"],
];

pub(crate) static ENTRY_SYNESTHETIC_3600503920231115312: VariantsMap = [
    &["synesthetic"],
    &["synaesthetic"],
    &["synaesthetic"],
    &["synaesthetic"],
];

pub(crate) static ENTRY_SYNETIC_11062609274567880634: VariantsMap =
    [&["synetic"], &["synoetic"], &["synoetic"], &["synoetic"]];

pub(crate) static ENTRY_SYNOECIZED_1258981145885331765: VariantsMap = [
    &["synoecized"],
    &["synoecised"],
    &["synoecized"],
    &["synoecised"],
];

pub(crate) static ENTRY_SYNOECIZES_14157018111278412405: VariantsMap = [
    &["synoecizes"],
    &["synoecises"],
    &["synoecizes"],
    &["synoecises"],
];

pub(crate) static ENTRY_SYNOECIZE_9903365931663314390: VariantsMap = [
    &["synoecize"],
    &["synoecise"],
    &["synoecize"],
    &["synoecise"],
];

pub(crate) static ENTRY_SYNOECIZING_12619177850029321994: VariantsMap = [
    &["synoecizing"],
    &["synoecising"],
    &["synoecizing"],
    &["synoecising"],
];

pub(crate) static ENTRY_SYNONYMIZED_16655983300964530292: VariantsMap = [
    &["synonymized"],
    &["synonymised"],
    &["synonymized"],
    &["synonymised"],
];

pub(crate) static ENTRY_SYNONYMIZES_5682029261506663420: VariantsMap = [
    &["synonymizes"],
    &["synonymises"],
    &["synonymizes"],
    &["synonymises"],
];

pub(crate) static ENTRY_SYNONYMIZE_3437118653893618787: VariantsMap = [
    &["synonymize"],
    &["synonymise"],
    &["synonymize"],
    &["synonymise"],
];

pub(crate) static ENTRY_SYNONYMIZING_10383839589382127203: VariantsMap = [
    &["synonymizing"],
    &["synonymising"],
    &["synonymizing"],
    &["synonymising"],
];

pub(crate) static ENTRY_SYNOPSIZED_1730636117992196147: VariantsMap = [
    &["synopsized"],
    &["synopsised"],
    &["synopsized"],
    &["synopsised"],
];

pub(crate) static ENTRY_SYNOPSIZES_14967276778682343138: VariantsMap = [
    &["synopsizes"],
    &["synopsises"],
    &["synopsizes"],
    &["synopsises"],
];

pub(crate) static ENTRY_SYNOPSIZE_5009645523556777721: VariantsMap = [
    &["synopsize"],
    &["synopsise"],
    &["synopsize"],
    &["synopsise"],
];

pub(crate) static ENTRY_SYNOPSIZING_8436973275561705386: VariantsMap = [
    &["synopsizing"],
    &["synopsising"],
    &["synopsizing"],
    &["synopsising"],
];

pub(crate) static ENTRY_SYNTHESIZATIONS_6008071763176942923: VariantsMap = [
    &["synthesizations"],
    &["synthesisations"],
    &["synthesizations"],
    &["synthesisations"],
];

pub(crate) static ENTRY_SYNTHESIZATION_7847480716228741176: VariantsMap = [
    &["synthesization"],
    &["synthesisation"],
    &["synthesization"],
    &["synthesisation"],
];

pub(crate) static ENTRY_SYNTHESIZED_10277854444798047575: VariantsMap = [
    &["synthesized"],
    &["synthesised"],
    &["synthesized"],
    &["synthesised"],
];

pub(crate) static ENTRY_SYNTHESIZERS_17412149831785719286: VariantsMap = [
    &["synthesizers"],
    &["synthesizers"],
    &["synthesizers"],
    &["synthesizers"],
];

pub(crate) static ENTRY_SYNTHESIZER_5120597236259656684: VariantsMap = [
    &["synthesizer"],
    &["synthesizer"],
    &["synthesizer"],
    &["synthesizer"],
];

pub(crate) static ENTRY_SYNTHESIZES_16719832496998918898: VariantsMap = [
    &["synthesizes"],
    &["synthesises"],
    &["synthesizes"],
    &["synthesises"],
];

pub(crate) static ENTRY_SYNTHESIZE_12262264416656123255: VariantsMap = [
    &["synthesize"],
    &["synthesise"],
    &["synthesize"],
    &["synthesise"],
];

pub(crate) static ENTRY_SYNTHESIZING_961211694929147125: VariantsMap = [
    &["synthesizing"],
    &["synthesising"],
    &["synthesizing"],
    &["synthesising"],
];

pub(crate) static ENTRY_SYNTHETIZATION_8539269556584261248: VariantsMap = [
    &["synthetization"],
    &["synthetisation"],
    &["synthetization"],
    &["synthetisation"],
];

pub(crate) static ENTRY_SYNTHETIZERS_13381239636453117418: VariantsMap = [
    &["synthetizers"],
    &["synthetisers"],
    &["synthetizers"],
    &["synthetisers"],
];

pub(crate) static ENTRY_SYNTHETIZER_7370135773010889066: VariantsMap = [
    &["synthetizer"],
    &["synthetiser"],
    &["synthetizer"],
    &["synthetiser"],
];

pub(crate) static ENTRY_SYNTONIZATION_14856908759061340234: VariantsMap = [
    &["syntonization"],
    &["syntonisation"],
    &["syntonization"],
    &["syntonisation"],
];

pub(crate) static ENTRY_SYNTONIZED_15041457439325800203: VariantsMap = [
    &["syntonized"],
    &["syntonised"],
    &["syntonized"],
    &["syntonised"],
];

pub(crate) static ENTRY_SYNTONIZES_17498682094763362419: VariantsMap = [
    &["syntonizes"],
    &["syntonises"],
    &["syntonizes"],
    &["syntonises"],
];

pub(crate) static ENTRY_SYNTONIZE_1485992200194358305: VariantsMap = [
    &["syntonize"],
    &["syntonise"],
    &["syntonize"],
    &["syntonise"],
];

pub(crate) static ENTRY_SYNTONIZING_3933548631109004593: VariantsMap = [
    &["syntonizing"],
    &["syntonising"],
    &["syntonizing"],
    &["syntonising"],
];

pub(crate) static ENTRY_SYPHILIZATIONS_6566377490752303452: VariantsMap = [
    &["syphilizations"],
    &["syphilisations"],
    &["syphilizations"],
    &["syphilisations"],
];

pub(crate) static ENTRY_SYPHILIZATION_4055568425962123768: VariantsMap = [
    &["syphilization"],
    &["syphilisation"],
    &["syphilization"],
    &["syphilisation"],
];

pub(crate) static ENTRY_SYPHILIZED_11930486983642777973: VariantsMap = [
    &["syphilized"],
    &["syphilised"],
    &["syphilized"],
    &["syphilised"],
];

pub(crate) static ENTRY_SYPHILIZE_13140711569267519345: VariantsMap = [
    &["syphilize"],
    &["syphilise"],
    &["syphilize"],
    &["syphilise"],
];

pub(crate) static ENTRY_SYPHILIZING_14288192544253600248: VariantsMap = [
    &["syphilizing"],
    &["syphilising"],
    &["syphilizing"],
    &["syphilising"],
];

pub(crate) static ENTRY_SYRIANIZES_15205618974659997671: VariantsMap = [
    &["syrianizes"],
    &["syrianises"],
    &["syrianizes"],
    &["syrianises"],
];

pub(crate) static ENTRY_SYRIANIZE_10187036361030900008: VariantsMap = [
    &["syrianize"],
    &["syrianise"],
    &["syrianize"],
    &["syrianise"],
];

pub(crate) static ENTRY_SYRINGOCELE_11968813307237913697: VariantsMap = [
    &["syringocele"],
    &["syringocoele"],
    &["syringocoele"],
    &["syringocoele"],
];

pub(crate) static ENTRY_SYRUPS_11767508909122317278: VariantsMap =
    [&["syrups"], &["syrups"], &["syrups"], &["syrups"]];

pub(crate) static ENTRY_SYRUP_13414625495147716891: VariantsMap =
    [&["syrup"], &["syrup"], &["syrup"], &["syrup"]];

pub(crate) static ENTRY_SYSTEMATIZATIONS_4980889965627146570: VariantsMap = [
    &["systematizations"],
    &["systematisations"],
    &["systematizations"],
    &["systematisations"],
];

pub(crate) static ENTRY_SYSTEMATIZATION_7949059312574351676: VariantsMap = [
    &["systematization"],
    &["systematisation"],
    &["systematization"],
    &["systematisation"],
];

pub(crate) static ENTRY_SYSTEMATIZED_3960322988302014252: VariantsMap = [
    &["systematized"],
    &["systematised"],
    &["systematized"],
    &["systematised"],
];

pub(crate) static ENTRY_SYSTEMATIZERS_5220548971047734611: VariantsMap = [
    &["systematizers"],
    &["systematisers"],
    &["systematizers"],
    &["systematisers"],
];

pub(crate) static ENTRY_SYSTEMATIZER_12159646041280111468: VariantsMap = [
    &["systematizer"],
    &["systematiser"],
    &["systematizer"],
    &["systematiser"],
];

pub(crate) static ENTRY_SYSTEMATIZES_6130814802973402788: VariantsMap = [
    &["systematizes"],
    &["systematises"],
    &["systematizes"],
    &["systematises"],
];

pub(crate) static ENTRY_SYSTEMATIZE_804615704421462730: VariantsMap = [
    &["systematize"],
    &["systematise"],
    &["systematize"],
    &["systematise"],
];

pub(crate) static ENTRY_SYSTEMATIZING_7548356459201607237: VariantsMap = [
    &["systematizing"],
    &["systematising"],
    &["systematizing"],
    &["systematising"],
];

pub(crate) static ENTRY_SYSTEMIZABLER_3507991058574811537: VariantsMap = [
    &["systemizabler"],
    &["systemisabler"],
    &["systemizabler"],
    &["systemisabler"],
];

pub(crate) static ENTRY_SYSTEMIZABLEST_9881026680576809052: VariantsMap = [
    &["systemizablest"],
    &["systemisablest"],
    &["systemizablest"],
    &["systemisablest"],
];

pub(crate) static ENTRY_SYSTEMIZABLES_1663867473218562178: VariantsMap = [
    &["systemizables"],
    &["systemisables"],
    &["systemizables"],
    &["systemisables"],
];

pub(crate) static ENTRY_SYSTEMIZABLE_6386901091487317898: VariantsMap = [
    &["systemizable"],
    &["systemisable"],
    &["systemizable"],
    &["systemisable"],
];

pub(crate) static ENTRY_SYSTEMIZATIONS_9736157959771706455: VariantsMap = [
    &["systemizations"],
    &["systemisations"],
    &["systemizations"],
    &["systemisations"],
];

pub(crate) static ENTRY_SYSTEMIZATION_7402744491389982261: VariantsMap = [
    &["systemization"],
    &["systemisation"],
    &["systemization"],
    &["systemisation"],
];

pub(crate) static ENTRY_SYSTEMIZED_5994844121926171444: VariantsMap = [
    &["systemized"],
    &["systemised"],
    &["systemized"],
    &["systemised"],
];

pub(crate) static ENTRY_SYSTEMIZERS_9699204790114175286: VariantsMap = [
    &["systemizers"],
    &["systemisers"],
    &["systemizers"],
    &["systemisers"],
];

pub(crate) static ENTRY_SYSTEMIZER_1967185930700519507: VariantsMap = [
    &["systemizer"],
    &["systemiser"],
    &["systemizer"],
    &["systemiser"],
];

pub(crate) static ENTRY_SYSTEMIZES_1513912670035920399: VariantsMap = [
    &["systemizes"],
    &["systemises"],
    &["systemizes"],
    &["systemises"],
];

pub(crate) static ENTRY_SYSTEMIZE_6507154835856335771: VariantsMap = [
    &["systemize"],
    &["systemise"],
    &["systemize"],
    &["systemise"],
];

pub(crate) static ENTRY_SYSTEMIZING_11787131178563974725: VariantsMap = [
    &["systemizing"],
    &["systemising"],
    &["systemizing"],
    &["systemising"],
];

pub(crate) static ENTRY_TABORED_3458012263090109952: VariantsMap =
    [&["tabored"], &["taboured"], &["taboured"], &["taboured"]];

pub(crate) static ENTRY_TABORERS_6060629822354641976: VariantsMap = [
    &["taborers"],
    &["tabourers"],
    &["tabourers"],
    &["tabourers"],
];

pub(crate) static ENTRY_TABORER_259230914231617550: VariantsMap =
    [&["taborer"], &["tabourer"], &["tabourer"], &["tabourer"]];

pub(crate) static ENTRY_TABORETS_12733109459658678516: VariantsMap = [
    &["taborets"],
    &["tabourets"],
    &["tabourets"],
    &["tabourets"],
];

pub(crate) static ENTRY_TABORET_7350560887326673778: VariantsMap =
    [&["taboret"], &["tabouret"], &["tabouret"], &["tabouret"]];

pub(crate) static ENTRY_TABORINE_6438755799910501319: VariantsMap = [
    &["taborine"],
    &["tabourine"],
    &["tabourine"],
    &["tabourine"],
];

pub(crate) static ENTRY_TABORING_10201578819028294847: VariantsMap = [
    &["taboring"],
    &["tabouring"],
    &["tabouring"],
    &["tabouring"],
];

pub(crate) static ENTRY_TABORINS_16033201340157357087: VariantsMap = [
    &["taborins"],
    &["tabourins"],
    &["tabourins"],
    &["tabourins"],
];

pub(crate) static ENTRY_TABORIN_4037230761017031912: VariantsMap =
    [&["taborin"], &["tabourin"], &["tabourin"], &["tabourin"]];

pub(crate) static ENTRY_TABULARIZATIONS_7435992087915599492: VariantsMap = [
    &["tabularizations"],
    &["tabularisations"],
    &["tabularizations"],
    &["tabularisations"],
];

pub(crate) static ENTRY_TABULARIZATION_13918426618250472515: VariantsMap = [
    &["tabularization"],
    &["tabularisation"],
    &["tabularization"],
    &["tabularisation"],
];

pub(crate) static ENTRY_TABULARIZED_7994290726718343521: VariantsMap = [
    &["tabularized"],
    &["tabularised"],
    &["tabularized"],
    &["tabularised"],
];

pub(crate) static ENTRY_TABULARIZES_5785970776539734545: VariantsMap = [
    &["tabularizes"],
    &["tabularises"],
    &["tabularizes"],
    &["tabularises"],
];

pub(crate) static ENTRY_TABULARIZE_4261090986956683891: VariantsMap = [
    &["tabularize"],
    &["tabularise"],
    &["tabularize"],
    &["tabularise"],
];

pub(crate) static ENTRY_TABULARIZING_182464911659236753: VariantsMap = [
    &["tabularizing"],
    &["tabularising"],
    &["tabularizing"],
    &["tabularising"],
];

pub(crate) static ENTRY_TABULE_16853827266028831247: VariantsMap =
    [&["tabule"], &["tabulae"], &["tabulae"], &["tabulae"]];

pub(crate) static ENTRY_TACHYPNEAS_5067707765941922607: VariantsMap = [
    &["tachypneas"],
    &["tachypnoeas"],
    &["tachypnoeas"],
    &["tachypnoeas"],
];

pub(crate) static ENTRY_TACHYPNEA_3166922207303436381: VariantsMap = [
    &["tachypnea"],
    &["tachypnoea"],
    &["tachypnoea"],
    &["tachypnoea"],
];

pub(crate) static ENTRY_TACHYPNEIC_6595193245006460158: VariantsMap = [
    &["tachypneic"],
    &["tachypnoeic"],
    &["tachypnoeic"],
    &["tachypnoeic"],
];

pub(crate) static ENTRY_TAFFETIZED_8007155516688755691: VariantsMap = [
    &["taffetized"],
    &["taffetised"],
    &["taffetized"],
    &["taffetised"],
];

pub(crate) static ENTRY_TAILORIZATIONS_1736724620876472569: VariantsMap = [
    &["tailorizations"],
    &["tailorisations"],
    &["tailorizations"],
    &["tailorisations"],
];

pub(crate) static ENTRY_TAILORIZATION_15045235103886073598: VariantsMap = [
    &["tailorization"],
    &["tailorisation"],
    &["tailorization"],
    &["tailorisation"],
];

pub(crate) static ENTRY_TAILORIZES_6097967392668050636: VariantsMap = [
    &["tailorizes"],
    &["tailorises"],
    &["tailorizes"],
    &["tailorises"],
];

pub(crate) static ENTRY_TAILORIZE_15097975052812336572: VariantsMap = [
    &["tailorize"],
    &["tailorise"],
    &["tailorize"],
    &["tailorise"],
];

pub(crate) static ENTRY_TALMUDIZATIONS_11451589359461499086: VariantsMap = [
    &["talmudizations"],
    &["talmudisations"],
    &["talmudizations"],
    &["talmudisations"],
];

pub(crate) static ENTRY_TALMUDIZATION_15638872772942699916: VariantsMap = [
    &["talmudization"],
    &["talmudisation"],
    &["talmudization"],
    &["talmudisation"],
];

pub(crate) static ENTRY_TALMUDIZES_2392641621064217398: VariantsMap = [
    &["talmudizes"],
    &["talmudises"],
    &["talmudizes"],
    &["talmudises"],
];

pub(crate) static ENTRY_TALMUDIZE_16721620815556202151: VariantsMap = [
    &["talmudize"],
    &["talmudise"],
    &["talmudize"],
    &["talmudise"],
];

pub(crate) static ENTRY_TAMBURAS_14365291061235589624: VariantsMap = [
    &["tamburas"],
    &["tambouras"],
    &["tambouras"],
    &["tambouras"],
];

pub(crate) static ENTRY_TAMBURA_1661928953124890659: VariantsMap =
    [&["tambura"], &["tamboura"], &["tamboura"], &["tamboura"]];

pub(crate) static ENTRY_TAMMANYIZES_17001559242562845912: VariantsMap = [
    &["tammanyizes"],
    &["tammanyises"],
    &["tammanyizes"],
    &["tammanyises"],
];

pub(crate) static ENTRY_TAMMANYIZE_10524041228496510264: VariantsMap = [
    &["tammanyize"],
    &["tammanyise"],
    &["tammanyize"],
    &["tammanyise"],
];

pub(crate) static ENTRY_TANALIZED_9212065894823627745: VariantsMap = [
    &["tanalized"],
    &["tanalised"],
    &["tanalized"],
    &["tanalised"],
];

pub(crate) static ENTRY_TANDEMIZES_16858842567411722496: VariantsMap = [
    &["tandemizes"],
    &["tandemises"],
    &["tandemizes"],
    &["tandemises"],
];

pub(crate) static ENTRY_TANDEMIZE_4594849143604731371: VariantsMap = [
    &["tandemize"],
    &["tandemise"],
    &["tandemize"],
    &["tandemise"],
];

pub(crate) static ENTRY_TANTALIZATIONS_13771654142203624068: VariantsMap = [
    &["tantalizations"],
    &["tantalisations"],
    &["tantalizations"],
    &["tantalisations"],
];

pub(crate) static ENTRY_TANTALIZATION_10133038819327360701: VariantsMap = [
    &["tantalization"],
    &["tantalisation"],
    &["tantalization"],
    &["tantalisation"],
];

pub(crate) static ENTRY_TANTALIZED_6407916214765676747: VariantsMap = [
    &["tantalized"],
    &["tantalised"],
    &["tantalized"],
    &["tantalised"],
];

pub(crate) static ENTRY_TANTALIZERS_15746926120203675469: VariantsMap = [
    &["tantalizers"],
    &["tantalisers"],
    &["tantalizers"],
    &["tantalisers"],
];

pub(crate) static ENTRY_TANTALIZER_3311757807060502289: VariantsMap = [
    &["tantalizer"],
    &["tantaliser"],
    &["tantalizer"],
    &["tantaliser"],
];

pub(crate) static ENTRY_TANTALIZES_7562225734061592970: VariantsMap = [
    &["tantalizes"],
    &["tantalises"],
    &["tantalizes"],
    &["tantalises"],
];

pub(crate) static ENTRY_TANTALIZE_15099675080816392884: VariantsMap = [
    &["tantalize"],
    &["tantalise"],
    &["tantalize"],
    &["tantalise"],
];

pub(crate) static ENTRY_TANTALIZINGLIER_10045132062074784268: VariantsMap = [
    &["tantalizinglier"],
    &["tantalisinglier"],
    &["tantalizinglier"],
    &["tantalisinglier"],
];

pub(crate) static ENTRY_TANTALIZINGLIEST_13318655638322508135: VariantsMap = [
    &["tantalizingliest"],
    &["tantalisingliest"],
    &["tantalizingliest"],
    &["tantalisingliest"],
];

pub(crate) static ENTRY_TANTALIZINGLIES_5104449786998566308: VariantsMap = [
    &["tantalizinglies"],
    &["tantalisinglies"],
    &["tantalizinglies"],
    &["tantalisinglies"],
];

pub(crate) static ENTRY_TANTALIZINGLY_8124924363029560350: VariantsMap = [
    &["tantalizingly"],
    &["tantalisingly"],
    &["tantalizingly"],
    &["tantalisingly"],
];

pub(crate) static ENTRY_TANTALIZINGNESSES_3198907059754343992: VariantsMap = [
    &["tantalizingnesses"],
    &["tantalisingnesses"],
    &["tantalizingnesses"],
    &["tantalisingnesses"],
];

pub(crate) static ENTRY_TANTALIZINGNESS_5920752991593005851: VariantsMap = [
    &["tantalizingness"],
    &["tantalisingness"],
    &["tantalizingness"],
    &["tantalisingness"],
];

pub(crate) static ENTRY_TANTALIZINGS_16838246964261155328: VariantsMap = [
    &["tantalizings"],
    &["tantalisings"],
    &["tantalizings"],
    &["tantalisings"],
];

pub(crate) static ENTRY_TANTALIZING_5979831725565904591: VariantsMap = [
    &["tantalizing"],
    &["tantalising"],
    &["tantalizing"],
    &["tantalising"],
];

pub(crate) static ENTRY_TARIFFIZES_4632513233689174159: VariantsMap = [
    &["tariffizes"],
    &["tariffises"],
    &["tariffizes"],
    &["tariffises"],
];

pub(crate) static ENTRY_TARIFFIZE_18377098253013907822: VariantsMap = [
    &["tariffize"],
    &["tariffise"],
    &["tariffize"],
    &["tariffise"],
];

pub(crate) static ENTRY_TARTARIZATIONS_11628589829012700090: VariantsMap = [
    &["tartarizations"],
    &["tartarisations"],
    &["tartarizations"],
    &["tartarisations"],
];

pub(crate) static ENTRY_TARTARIZATION_1394513065812646894: VariantsMap = [
    &["tartarization"],
    &["tartarisation"],
    &["tartarization"],
    &["tartarisation"],
];

pub(crate) static ENTRY_TARTARIZED_531821600819631957: VariantsMap = [
    &["tartarized"],
    &["tartarised"],
    &["tartarized"],
    &["tartarised"],
];

pub(crate) static ENTRY_TARTARIZES_6665817306686419426: VariantsMap = [
    &["tartarizes"],
    &["tartarises"],
    &["tartarizes"],
    &["tartarises"],
];

pub(crate) static ENTRY_TARTARIZE_11607621879783763771: VariantsMap = [
    &["tartarize"],
    &["tartarise"],
    &["tartarize"],
    &["tartarise"],
];

pub(crate) static ENTRY_TARTARIZING_15412039886176166104: VariantsMap = [
    &["tartarizing"],
    &["tartarising"],
    &["tartarizing"],
    &["tartarising"],
];

pub(crate) static ENTRY_TASSELED_15553878924111115665: VariantsMap = [
    &["tasseled"],
    &["tasselled"],
    &["tasselled"],
    &["tasselled"],
];

pub(crate) static ENTRY_TASSELING_2676198179605847965: VariantsMap = [
    &["tasseling"],
    &["tasselling"],
    &["tasselling"],
    &["tasselling"],
];

pub(crate) static ENTRY_TASSELS_9644147193425846585: VariantsMap =
    [&["tassels"], &["tassels"], &["tassels"], &["tassels"]];

pub(crate) static ENTRY_TAUTOLOGIZED_9842553804886781862: VariantsMap = [
    &["tautologized"],
    &["tautologised"],
    &["tautologized"],
    &["tautologised"],
];

pub(crate) static ENTRY_TAUTOLOGIZES_11146116641412142667: VariantsMap = [
    &["tautologizes"],
    &["tautologises"],
    &["tautologizes"],
    &["tautologises"],
];

pub(crate) static ENTRY_TAUTOLOGIZE_4665592265999186622: VariantsMap = [
    &["tautologize"],
    &["tautologise"],
    &["tautologize"],
    &["tautologise"],
];

pub(crate) static ENTRY_TAUTOLOGIZING_9943163653831588506: VariantsMap = [
    &["tautologizing"],
    &["tautologising"],
    &["tautologizing"],
    &["tautologising"],
];

pub(crate) static ENTRY_TAVERNIZES_6120473175514650417: VariantsMap = [
    &["tavernizes"],
    &["tavernises"],
    &["tavernizes"],
    &["tavernises"],
];

pub(crate) static ENTRY_TAVERNIZE_11412342911846701308: VariantsMap = [
    &["tavernize"],
    &["tavernise"],
    &["tavernize"],
    &["tavernise"],
];

pub(crate) static ENTRY_TAXIDERMIZED_10192910736850674: VariantsMap = [
    &["taxidermized"],
    &["taxidermised"],
    &["taxidermized"],
    &["taxidermised"],
];

pub(crate) static ENTRY_TAXIDERMIZES_4441796755398649754: VariantsMap = [
    &["taxidermizes"],
    &["taxidermises"],
    &["taxidermizes"],
    &["taxidermises"],
];

pub(crate) static ENTRY_TAXIDERMIZE_2374104358744757711: VariantsMap = [
    &["taxidermize"],
    &["taxidermise"],
    &["taxidermize"],
    &["taxidermise"],
];

pub(crate) static ENTRY_TAXIDERMIZING_13017684951259720401: VariantsMap = [
    &["taxidermizing"],
    &["taxidermising"],
    &["taxidermizing"],
    &["taxidermising"],
];

pub(crate) static ENTRY_TAYLORIZES_13244584135122060485: VariantsMap = [
    &["taylorizes"],
    &["taylorises"],
    &["taylorizes"],
    &["taylorises"],
];

pub(crate) static ENTRY_TAYLORIZE_17635648384739575074: VariantsMap = [
    &["taylorize"],
    &["taylorise"],
    &["taylorize"],
    &["taylorise"],
];

pub(crate) static ENTRY_TEASELED_8083609611219835965: VariantsMap =
    [&["teaseled"], &["teaseled"], &["teaseled"], &["teaseled"]];

pub(crate) static ENTRY_TEASELERS_17319562617316313679: VariantsMap = [
    &["teaselers"],
    &["teaselers"],
    &["teaselers"],
    &["teaselers"],
];

pub(crate) static ENTRY_TEASELER_15075482462791394349: VariantsMap =
    [&["teaseler"], &["teaseler"], &["teaseler"], &["teaseler"]];

pub(crate) static ENTRY_TEASELINGS_10604239368842442956: VariantsMap = [
    &["teaselings"],
    &["teaselings"],
    &["teaselings"],
    &["teaselings"],
];

pub(crate) static ENTRY_TEASELING_13695401286288634817: VariantsMap = [
    &["teaseling"],
    &["teaseling"],
    &["teaseling"],
    &["teaseling"],
];

pub(crate) static ENTRY_TEASELING_2241001256394841761: VariantsMap = [
    &["teaseling"],
    &["teaseling"],
    &["teaseling"],
    &["teaseling"],
];

pub(crate) static ENTRY_TEBILIZED_12603919274755080976: VariantsMap = [
    &["tebilized"],
    &["tebilised"],
    &["tebilized"],
    &["tebilised"],
];

pub(crate) static ENTRY_TEBILIZES_2524900190492767802: VariantsMap = [
    &["tebilizes"],
    &["tebilises"],
    &["tebilizes"],
    &["tebilises"],
];

pub(crate) static ENTRY_TEBILIZE_5379298659414145032: VariantsMap =
    [&["tebilize"], &["tebilise"], &["tebilize"], &["tebilise"]];

pub(crate) static ENTRY_TEBILIZING_5956809875127660850: VariantsMap = [
    &["tebilizing"],
    &["tebilising"],
    &["tebilizing"],
    &["tebilising"],
];

pub(crate) static ENTRY_TECHNICALIZATION_3773436217131165599: VariantsMap = [
    &["technicalization"],
    &["technicalisation"],
    &["technicalization"],
    &["technicalisation"],
];

pub(crate) static ENTRY_TECHNICALIZES_5595101189542797653: VariantsMap = [
    &["technicalizes"],
    &["technicalises"],
    &["technicalizes"],
    &["technicalises"],
];

pub(crate) static ENTRY_TECHNICALIZE_13592737048499055793: VariantsMap = [
    &["technicalize"],
    &["technicalise"],
    &["technicalize"],
    &["technicalise"],
];

pub(crate) static ENTRY_TECHNICIZED_3663306080874533270: VariantsMap = [
    &["technicized"],
    &["technicised"],
    &["technicized"],
    &["technicised"],
];

pub(crate) static ENTRY_TECHNICIZES_13211595356574862793: VariantsMap = [
    &["technicizes"],
    &["technicises"],
    &["technicizes"],
    &["technicises"],
];

pub(crate) static ENTRY_TECHNICIZE_8212652477507145699: VariantsMap = [
    &["technicize"],
    &["technicise"],
    &["technicize"],
    &["technicise"],
];

pub(crate) static ENTRY_TECHNICIZING_13378455688370171176: VariantsMap = [
    &["technicizing"],
    &["technicising"],
    &["technicizing"],
    &["technicising"],
];

pub(crate) static ENTRY_TECHNICOLORED_1825328488281394359: VariantsMap = [
    &["technicolored"],
    &["technicolored"],
    &["technicolored"],
    &["technicolored"],
];

pub(crate) static ENTRY_TECHNICOLORS_14860686180490475866: VariantsMap = [
    &["technicolors"],
    &["technicolors"],
    &["technicolors"],
    &["technicolors"],
];

pub(crate) static ENTRY_TECHNICOLOR_13876999640902564556: VariantsMap = [
    &["technicolor"],
    &["technicolor"],
    &["technicolor"],
    &["technicolor"],
];

pub(crate) static ENTRY_TECHNICOLOR_14183677618685504801: VariantsMap = [
    &["technicolor"],
    &["technicolor"],
    &["technicolor"],
    &["technicolor"],
];

pub(crate) static ENTRY_TECHNOLOGIZE_4630575226590934600: VariantsMap = [
    &["technologize"],
    &["technologise"],
    &["technologize"],
    &["technologise"],
];

pub(crate) static ENTRY_TEERS_11547310098132473650: VariantsMap =
    [&["teers"], &["teres"], &["teres"], &["teres"]];

pub(crate) static ENTRY_TEER_1512356504088772276: VariantsMap =
    [&["teer"], &["teaer"], &["teaer"], &["teaer"]];

pub(crate) static ENTRY_TEETOTALED_13601847410093247608: VariantsMap = [
    &["teetotaled"],
    &["teetotalled"],
    &["teetotalled"],
    &["teetotalled"],
];

pub(crate) static ENTRY_TEETOTALERS_7523968922648268459: VariantsMap = [
    &["teetotalers"],
    &["teetotallers"],
    &["teetotallers"],
    &["teetotallers"],
];

pub(crate) static ENTRY_TEETOTALER_4246658529410097511: VariantsMap = [
    &["teetotaler"],
    &["teetotaller"],
    &["teetotaller"],
    &["teetotaller"],
];

pub(crate) static ENTRY_TEETOTALING_14654836145957001388: VariantsMap = [
    &["teetotaling"],
    &["teetotalling"],
    &["teetotalling"],
    &["teetotalling"],
];

pub(crate) static ENTRY_TEGU_17495886448442942906: VariantsMap =
    [&["tegu"], &["taegu"], &["taegu"], &["taegu"]];

pub(crate) static ENTRY_TELEPATHIZED_13030563544943449021: VariantsMap = [
    &["telepathized"],
    &["telepathised"],
    &["telepathized"],
    &["telepathised"],
];

pub(crate) static ENTRY_TELEPATHIZES_13175684465670989018: VariantsMap = [
    &["telepathizes"],
    &["telepathises"],
    &["telepathizes"],
    &["telepathises"],
];

pub(crate) static ENTRY_TELEPATHIZE_4890254755616696887: VariantsMap = [
    &["telepathize"],
    &["telepathise"],
    &["telepathize"],
    &["telepathise"],
];

pub(crate) static ENTRY_TELEPATHIZING_15634779623380965076: VariantsMap = [
    &["telepathizing"],
    &["telepathising"],
    &["telepathizing"],
    &["telepathising"],
];

pub(crate) static ENTRY_TELESTHESIAS_13634253936556894398: VariantsMap = [
    &["telesthesias"],
    &["telaesthesias"],
    &["telaesthesias"],
    &["telaesthesias"],
];

pub(crate) static ENTRY_TELESTHESIA_3729177704184763745: VariantsMap = [
    &["telesthesia"],
    &["telaesthesia"],
    &["telaesthesia"],
    &["telaesthesia"],
];

pub(crate) static ENTRY_TELESTHETICER_15325218410106938805: VariantsMap = [
    &["telestheticer"],
    &["telaestheticer"],
    &["telaestheticer"],
    &["telaestheticer"],
];

pub(crate) static ENTRY_TELESTHETICEST_10500637524144952518: VariantsMap = [
    &["telestheticest"],
    &["telaestheticest"],
    &["telaestheticest"],
    &["telaestheticest"],
];

pub(crate) static ENTRY_TELESTHETIC_2492077632449909509: VariantsMap = [
    &["telesthetic"],
    &["telaesthetic"],
    &["telaesthetic"],
    &["telaesthetic"],
];

pub(crate) static ENTRY_TELE_17660775790618180296: VariantsMap =
    [&["tele"], &["telae"], &["telae"], &["telae"]];

pub(crate) static ENTRY_TELLURIZED_4062571174023013836: VariantsMap = [
    &["tellurized"],
    &["tellurised"],
    &["tellurized"],
    &["tellurised"],
];

pub(crate) static ENTRY_TELLURIZES_14477745285616322945: VariantsMap = [
    &["tellurizes"],
    &["tellurises"],
    &["tellurizes"],
    &["tellurises"],
];

pub(crate) static ENTRY_TELLURIZE_12969876447874663017: VariantsMap = [
    &["tellurize"],
    &["tellurise"],
    &["tellurize"],
    &["tellurise"],
];

pub(crate) static ENTRY_TELLURIZING_15726097355587032776: VariantsMap = [
    &["tellurizing"],
    &["tellurising"],
    &["tellurizing"],
    &["tellurising"],
];

pub(crate) static ENTRY_TELS_3007087834331223229: VariantsMap =
    [&["tels"], &["taels"], &["taels"], &["taels"]];

pub(crate) static ENTRY_TEMPLIZES_8206287182084029425: VariantsMap = [
    &["templizes"],
    &["templises"],
    &["templizes"],
    &["templises"],
];

pub(crate) static ENTRY_TEMPLIZE_3769471964247003706: VariantsMap =
    [&["templize"], &["templise"], &["templize"], &["templise"]];

pub(crate) static ENTRY_TEMPORALIZED_9346139556114175316: VariantsMap = [
    &["temporalized"],
    &["temporalised"],
    &["temporalized"],
    &["temporalised"],
];

pub(crate) static ENTRY_TEMPORALIZES_17569235997419710911: VariantsMap = [
    &["temporalizes"],
    &["temporalises"],
    &["temporalizes"],
    &["temporalises"],
];

pub(crate) static ENTRY_TEMPORALIZE_8976084796595693342: VariantsMap = [
    &["temporalize"],
    &["temporalise"],
    &["temporalize"],
    &["temporalise"],
];

pub(crate) static ENTRY_TEMPORALIZING_10385680194697863891: VariantsMap = [
    &["temporalizing"],
    &["temporalising"],
    &["temporalizing"],
    &["temporalising"],
];

pub(crate) static ENTRY_TEMPORIZATIONS_18395264469348932353: VariantsMap = [
    &["temporizations"],
    &["temporisations"],
    &["temporizations"],
    &["temporisations"],
];

pub(crate) static ENTRY_TEMPORIZATION_9268323585901486943: VariantsMap = [
    &["temporization"],
    &["temporisation"],
    &["temporization"],
    &["temporisation"],
];

pub(crate) static ENTRY_TEMPORIZED_13828183401152117443: VariantsMap = [
    &["temporized"],
    &["temporised"],
    &["temporized"],
    &["temporised"],
];

pub(crate) static ENTRY_TEMPORIZERS_7683732994752843323: VariantsMap = [
    &["temporizers"],
    &["temporisers"],
    &["temporizers"],
    &["temporisers"],
];

pub(crate) static ENTRY_TEMPORIZER_13728915446164211108: VariantsMap = [
    &["temporizer"],
    &["temporiser"],
    &["temporizer"],
    &["temporiser"],
];

pub(crate) static ENTRY_TEMPORIZES_3654086099315586263: VariantsMap = [
    &["temporizes"],
    &["temporises"],
    &["temporizes"],
    &["temporises"],
];

pub(crate) static ENTRY_TEMPORIZE_6008538957350717253: VariantsMap = [
    &["temporize"],
    &["temporise"],
    &["temporize"],
    &["temporise"],
];

pub(crate) static ENTRY_TEMPORIZINGLIER_6355354281150226976: VariantsMap = [
    &["temporizinglier"],
    &["temporisinglier"],
    &["temporizinglier"],
    &["temporisinglier"],
];

pub(crate) static ENTRY_TEMPORIZINGLIEST_9905876624839839389: VariantsMap = [
    &["temporizingliest"],
    &["temporisingliest"],
    &["temporizingliest"],
    &["temporisingliest"],
];

pub(crate) static ENTRY_TEMPORIZINGLY_11640359263718011924: VariantsMap = [
    &["temporizingly"],
    &["temporisingly"],
    &["temporizingly"],
    &["temporisingly"],
];

pub(crate) static ENTRY_TEMPORIZINGS_20261713602325724: VariantsMap = [
    &["temporizings"],
    &["temporisings"],
    &["temporizings"],
    &["temporisings"],
];

pub(crate) static ENTRY_TEMPORIZING_6302462174887770996: VariantsMap = [
    &["temporizing"],
    &["temporising"],
    &["temporizing"],
    &["temporising"],
];

pub(crate) static ENTRY_TENDERIZATIONS_759776932056624247: VariantsMap = [
    &["tenderizations"],
    &["tenderisations"],
    &["tenderizations"],
    &["tenderisations"],
];

pub(crate) static ENTRY_TENDERIZATION_15153457077426481235: VariantsMap = [
    &["tenderization"],
    &["tenderisation"],
    &["tenderization"],
    &["tenderisation"],
];

pub(crate) static ENTRY_TENDERIZED_4549753286584063824: VariantsMap = [
    &["tenderized"],
    &["tenderised"],
    &["tenderized"],
    &["tenderised"],
];

pub(crate) static ENTRY_TENDERIZERS_2243522742396370113: VariantsMap = [
    &["tenderizers"],
    &["tenderisers"],
    &["tenderizers"],
    &["tenderisers"],
];

pub(crate) static ENTRY_TENDERIZER_9543130259232111639: VariantsMap = [
    &["tenderizer"],
    &["tenderiser"],
    &["tenderizer"],
    &["tenderiser"],
];

pub(crate) static ENTRY_TENDERIZES_8106466981215709305: VariantsMap = [
    &["tenderizes"],
    &["tenderises"],
    &["tenderizes"],
    &["tenderises"],
];

pub(crate) static ENTRY_TENDERIZE_14583554302804750450: VariantsMap = [
    &["tenderize"],
    &["tenderise"],
    &["tenderize"],
    &["tenderise"],
];

pub(crate) static ENTRY_TENDERIZING_18364924414460195974: VariantsMap = [
    &["tenderizing"],
    &["tenderising"],
    &["tenderizing"],
    &["tenderising"],
];

pub(crate) static ENTRY_TENDRILED_18038918814565810183: VariantsMap = [
    &["tendriled"],
    &["tendrilled"],
    &["tendrilled"],
    &["tendrilled"],
];

pub(crate) static ENTRY_TENEMENTIZATIONS_3755446656409966534: VariantsMap = [
    &["tenementizations"],
    &["tenementisations"],
    &["tenementizations"],
    &["tenementisations"],
];

pub(crate) static ENTRY_TENEMENTIZATION_14600199269437804256: VariantsMap = [
    &["tenementization"],
    &["tenementisation"],
    &["tenementization"],
    &["tenementisation"],
];

pub(crate) static ENTRY_TENEMENTIZES_2276031239379735921: VariantsMap = [
    &["tenementizes"],
    &["tenementises"],
    &["tenementizes"],
    &["tenementises"],
];

pub(crate) static ENTRY_TENEMENTIZE_17197876287592266522: VariantsMap = [
    &["tenementize"],
    &["tenementise"],
    &["tenementize"],
    &["tenementise"],
];

pub(crate) static ENTRY_TENIACIDAL_11024692641878915165: VariantsMap = [
    &["teniacidal"],
    &["taeniacidal"],
    &["taeniacidal"],
    &["taeniacidal"],
];

pub(crate) static ENTRY_TENIACIDES_9867987590675969789: VariantsMap = [
    &["teniacides"],
    &["taeniacides"],
    &["taeniacides"],
    &["taeniacides"],
];

pub(crate) static ENTRY_TENIACIDE_8144045073011901293: VariantsMap = [
    &["teniacide"],
    &["taeniacide"],
    &["taeniacide"],
    &["taeniacide"],
];

pub(crate) static ENTRY_TENIAE_14899975197394248907: VariantsMap =
    [&["teniae"], &["taeniae"], &["taeniae"], &["taeniae"]];

pub(crate) static ENTRY_TENIAFUGES_5656721164722933651: VariantsMap = [
    &["teniafuges"],
    &["taeniafuges"],
    &["taeniafuges"],
    &["taeniafuges"],
];

pub(crate) static ENTRY_TENIAFUGE_535975770678901901: VariantsMap = [
    &["teniafuge"],
    &["taeniafuge"],
    &["taeniafuge"],
    &["taeniafuge"],
];

pub(crate) static ENTRY_TENIASES_4934007100111357532: VariantsMap = [
    &["teniases"],
    &["taeniases"],
    &["taeniases"],
    &["taeniases"],
];

pub(crate) static ENTRY_TENIASIS_7229408385178515529: VariantsMap = [
    &["teniasis"],
    &["taeniasis"],
    &["taeniasis"],
    &["taeniasis"],
];

pub(crate) static ENTRY_TENIAS_16745934458285507889: VariantsMap =
    [&["tenias"], &["taenias"], &["taenias"], &["taenias"]];

pub(crate) static ENTRY_TENIA_6242231905882591005: VariantsMap =
    [&["tenia"], &["taenia"], &["taenia"], &["taenia"]];

pub(crate) static ENTRY_TENIOID_11942386963829586985: VariantsMap =
    [&["tenioid"], &["taenioid"], &["taenioid"], &["taenioid"]];

pub(crate) static ENTRY_TENTHMETER_17561130154323386893: VariantsMap = [
    &["tenthmeter"],
    &["tenthmetre"],
    &["tenthmetre"],
    &["tenthmetre"],
];

pub(crate) static ENTRY_TERF_3510176223973213714: VariantsMap =
    [&["terf"], &["tref"], &["tref"], &["tref"]];

pub(crate) static ENTRY_TERMATIC_575294056877958757: VariantsMap =
    [&["termatic"], &["trematic"], &["trematic"], &["trematic"]];

pub(crate) static ENTRY_TERMA_12658799001593884461: VariantsMap =
    [&["terma"], &["trema"], &["trema"], &["trema"]];

pub(crate) static ENTRY_TERMINALIZATIONS_654995620005875057: VariantsMap = [
    &["terminalizations"],
    &["terminalisations"],
    &["terminalizations"],
    &["terminalisations"],
];

pub(crate) static ENTRY_TERMINALIZATION_14611052621641252685: VariantsMap = [
    &["terminalization"],
    &["terminalisation"],
    &["terminalization"],
    &["terminalisation"],
];

pub(crate) static ENTRY_TERMINALIZEDS_7787606091951730758: VariantsMap = [
    &["terminalizeds"],
    &["terminaliseds"],
    &["terminalizeds"],
    &["terminaliseds"],
];

pub(crate) static ENTRY_TERMINALIZED_12792925211824477703: VariantsMap = [
    &["terminalized"],
    &["terminalised"],
    &["terminalized"],
    &["terminalised"],
];

pub(crate) static ENTRY_TERNIZES_3262666584819248556: VariantsMap =
    [&["ternizes"], &["ternises"], &["ternizes"], &["ternises"]];

pub(crate) static ENTRY_TERNIZE_2124050956550290721: VariantsMap =
    [&["ternize"], &["ternise"], &["ternize"], &["ternise"]];

pub(crate) static ENTRY_TERRESTRIALIZES_6624949095978395018: VariantsMap = [
    &["terrestrializes"],
    &["terrestrialises"],
    &["terrestrializes"],
    &["terrestrialises"],
];

pub(crate) static ENTRY_TERRESTRIALIZE_6347253160507775588: VariantsMap = [
    &["terrestrialize"],
    &["terrestrialise"],
    &["terrestrialize"],
    &["terrestrialise"],
];

pub(crate) static ENTRY_TERRE_8819349438187415807: VariantsMap =
    [&["terre"], &["terrae"], &["terrae"], &["terrae"]];

pub(crate) static ENTRY_TERRITORIALIZATIONS_3176885729614090958: VariantsMap = [
    &["territorializations"],
    &["territorialisations"],
    &["territorializations"],
    &["territorialisations"],
];

pub(crate) static ENTRY_TERRITORIALIZATION_13612272693653351235: VariantsMap = [
    &["territorialization"],
    &["territorialisation"],
    &["territorialization"],
    &["territorialisation"],
];

pub(crate) static ENTRY_TERRITORIALIZED_18010704841888125903: VariantsMap = [
    &["territorialized"],
    &["territorialised"],
    &["territorialized"],
    &["territorialised"],
];

pub(crate) static ENTRY_TERRITORIALIZES_8896187296510093610: VariantsMap = [
    &["territorializes"],
    &["territorialises"],
    &["territorializes"],
    &["territorialises"],
];

pub(crate) static ENTRY_TERRITORIALIZE_7097746563170584866: VariantsMap = [
    &["territorialize"],
    &["territorialise"],
    &["territorialize"],
    &["territorialise"],
];

pub(crate) static ENTRY_TERRITORIALIZING_7836091817301256528: VariantsMap = [
    &["territorializing"],
    &["territorialising"],
    &["territorializing"],
    &["territorialising"],
];

pub(crate) static ENTRY_TERRORIZATIONS_18287886849231369087: VariantsMap = [
    &["terrorizations"],
    &["terrorisations"],
    &["terrorizations"],
    &["terrorisations"],
];

pub(crate) static ENTRY_TERRORIZATION_12053144759218452192: VariantsMap = [
    &["terrorization"],
    &["terrorisation"],
    &["terrorization"],
    &["terrorisation"],
];

pub(crate) static ENTRY_TERRORIZED_12855863820908113709: VariantsMap = [
    &["terrorized"],
    &["terrorised"],
    &["terrorized"],
    &["terrorised"],
];

pub(crate) static ENTRY_TERRORIZERS_15764303900614300931: VariantsMap = [
    &["terrorizers"],
    &["terrorisers"],
    &["terrorizers"],
    &["terrorisers"],
];

pub(crate) static ENTRY_TERRORIZER_3790900356919417060: VariantsMap = [
    &["terrorizer"],
    &["terroriser"],
    &["terrorizer"],
    &["terroriser"],
];

pub(crate) static ENTRY_TERRORIZES_7590151466698739569: VariantsMap = [
    &["terrorizes"],
    &["terrorises"],
    &["terrorizes"],
    &["terrorises"],
];

pub(crate) static ENTRY_TERRORIZE_2182645348231356537: VariantsMap = [
    &["terrorize"],
    &["terrorise"],
    &["terrorize"],
    &["terrorise"],
];

pub(crate) static ENTRY_TERRORIZING_13104103423474029961: VariantsMap = [
    &["terrorizing"],
    &["terrorising"],
    &["terrorizing"],
    &["terrorising"],
];

pub(crate) static ENTRY_TERTS_15921222583797171907: VariantsMap =
    [&["terts"], &["trets"], &["trets"], &["trets"]];

pub(crate) static ENTRY_TESTE_7681162770005306000: VariantsMap =
    [&["teste"], &["testae"], &["testae"], &["testae"]];

pub(crate) static ENTRY_TESTIMONIALIZATIONS_10414109904662561931: VariantsMap = [
    &["testimonializations"],
    &["testimonialisations"],
    &["testimonializations"],
    &["testimonialisations"],
];

pub(crate) static ENTRY_TESTIMONIALIZATION_1997898483350721704: VariantsMap = [
    &["testimonialization"],
    &["testimonialisation"],
    &["testimonialization"],
    &["testimonialisation"],
];

pub(crate) static ENTRY_TESTIMONIALIZED_12777074233080067891: VariantsMap = [
    &["testimonialized"],
    &["testimonialised"],
    &["testimonialized"],
    &["testimonialised"],
];

pub(crate) static ENTRY_TESTIMONIALIZERS_13860732262187670713: VariantsMap = [
    &["testimonializers"],
    &["testimonialisers"],
    &["testimonializers"],
    &["testimonialisers"],
];

pub(crate) static ENTRY_TESTIMONIALIZER_5001418100017709831: VariantsMap = [
    &["testimonializer"],
    &["testimonialiser"],
    &["testimonializer"],
    &["testimonialiser"],
];

pub(crate) static ENTRY_TESTIMONIALIZES_10551210801248918911: VariantsMap = [
    &["testimonializes"],
    &["testimonialises"],
    &["testimonializes"],
    &["testimonialises"],
];

pub(crate) static ENTRY_TESTIMONIALIZE_18040418696714895280: VariantsMap = [
    &["testimonialize"],
    &["testimonialise"],
    &["testimonialize"],
    &["testimonialise"],
];

pub(crate) static ENTRY_TESTIMONIALIZING_3438847121414565242: VariantsMap = [
    &["testimonializing"],
    &["testimonialising"],
    &["testimonializing"],
    &["testimonialising"],
];

pub(crate) static ENTRY_TES_5634224708893959490: VariantsMap =
    [&["tes"], &["taes"], &["taes"], &["taes"]];

pub(crate) static ENTRY_TETANIZATIONS_9830716338275193986: VariantsMap = [
    &["tetanizations"],
    &["tetanisations"],
    &["tetanizations"],
    &["tetanisations"],
];

pub(crate) static ENTRY_TETANIZATION_577138016465980211: VariantsMap = [
    &["tetanization"],
    &["tetanisation"],
    &["tetanization"],
    &["tetanisation"],
];

pub(crate) static ENTRY_TETANIZED_8313685340295551426: VariantsMap = [
    &["tetanized"],
    &["tetanised"],
    &["tetanized"],
    &["tetanised"],
];

pub(crate) static ENTRY_TETANIZES_18159463373230991034: VariantsMap = [
    &["tetanizes"],
    &["tetanises"],
    &["tetanizes"],
    &["tetanises"],
];

pub(crate) static ENTRY_TETANIZE_13125818857178721563: VariantsMap =
    [&["tetanize"], &["tetanise"], &["tetanize"], &["tetanise"]];

pub(crate) static ENTRY_TETANIZING_3169895590113377680: VariantsMap = [
    &["tetanizing"],
    &["tetanising"],
    &["tetanizing"],
    &["tetanising"],
];

pub(crate) static ENTRY_TETRACHLORETHYLENES_3697002620069360563: VariantsMap = [
    &["tetrachlorethylenes"],
    &["tetrachloroethylenes"],
    &["tetrachloroethylenes"],
    &["tetrachloroethylenes"],
];

pub(crate) static ENTRY_TETRACHLORETHYLENE_12592700145144546851: VariantsMap = [
    &["tetrachlorethylene"],
    &["tetrachloroethylene"],
    &["tetrachloroethylene"],
    &["tetrachloroethylene"],
];

pub(crate) static ENTRY_TEUTONIZATION_15254944975373981632: VariantsMap = [
    &["teutonization"],
    &["teutonisation"],
    &["teutonization"],
    &["teutonisation"],
];

pub(crate) static ENTRY_TEUTONIZED_10064813533808905253: VariantsMap = [
    &["teutonized"],
    &["teutonised"],
    &["teutonized"],
    &["teutonised"],
];

pub(crate) static ENTRY_TEUTONIZES_3149749243463447607: VariantsMap = [
    &["teutonizes"],
    &["teutonises"],
    &["teutonizes"],
    &["teutonises"],
];

pub(crate) static ENTRY_TEUTONIZE_2326197985184920584: VariantsMap = [
    &["teutonize"],
    &["teutonise"],
    &["teutonize"],
    &["teutonise"],
];

pub(crate) static ENTRY_TEUTONIZING_1726928371121949281: VariantsMap = [
    &["teutonizing"],
    &["teutonising"],
    &["teutonizing"],
    &["teutonising"],
];

pub(crate) static ENTRY_TEXTURIZED_13270620706415686595: VariantsMap = [
    &["texturized"],
    &["texturised"],
    &["texturized"],
    &["texturised"],
];

pub(crate) static ENTRY_TEXTURIZES_9031143232768038726: VariantsMap = [
    &["texturizes"],
    &["texturises"],
    &["texturizes"],
    &["texturises"],
];

pub(crate) static ENTRY_TEXTURIZE_2101736980791874876: VariantsMap = [
    &["texturize"],
    &["texturise"],
    &["texturize"],
    &["texturise"],
];

pub(crate) static ENTRY_TEXTURIZING_12707124326299442433: VariantsMap = [
    &["texturizing"],
    &["texturising"],
    &["texturizing"],
    &["texturising"],
];

pub(crate) static ENTRY_TE_16963694388719213938: VariantsMap =
    [&["te"], &["tae"], &["tae"], &["tae"]];

pub(crate) static ENTRY_THALAMOCELE_5766303350223704636: VariantsMap = [
    &["thalamocele"],
    &["thalamocoele"],
    &["thalamocoele"],
    &["thalamocoele"],
];

pub(crate) static ENTRY_THALASSEMIAS_2823805934181113644: VariantsMap = [
    &["thalassemias"],
    &["thalassaemias"],
    &["thalassaemias"],
    &["thalassaemias"],
];

pub(crate) static ENTRY_THALASSEMIA_11647657111797513703: VariantsMap = [
    &["thalassemia"],
    &["thalassaemia"],
    &["thalassaemia"],
    &["thalassaemia"],
];

pub(crate) static ENTRY_THALASSEMIC_4524955441481070676: VariantsMap = [
    &["thalassemic"],
    &["thalassaemic"],
    &["thalassaemic"],
    &["thalassaemic"],
];

pub(crate) static ENTRY_THEATERGOERS_8549242292576792477: VariantsMap = [
    &["theatergoers"],
    &["theatregoers"],
    &["theatregoers"],
    &["theatregoers"],
];

pub(crate) static ENTRY_THEATERGOER_12049893135886436399: VariantsMap = [
    &["theatergoer"],
    &["theatregoer"],
    &["theatregoer"],
    &["theatregoer"],
];

pub(crate) static ENTRY_THEATERGOINGS_6740435645328474541: VariantsMap = [
    &["theatergoings"],
    &["theatregoings"],
    &["theatregoings"],
    &["theatregoings"],
];

pub(crate) static ENTRY_THEATERGOING_9036609633778609239: VariantsMap = [
    &["theatergoing"],
    &["theatregoing"],
    &["theatregoing"],
    &["theatregoing"],
];

pub(crate) static ENTRY_THEATERLESSES_4394383213563812217: VariantsMap = [
    &["theaterlesses"],
    &["theatrelesses"],
    &["theatrelesses"],
    &["theatrelesses"],
];

pub(crate) static ENTRY_THEATERLESS_6418669943810866547: VariantsMap = [
    &["theaterless"],
    &["theatreless"],
    &["theatreless"],
    &["theatreless"],
];

pub(crate) static ENTRY_THEATERLIKES_14410484446681772640: VariantsMap = [
    &["theaterlikes"],
    &["theatrelikes"],
    &["theatrelikes"],
    &["theatrelikes"],
];

pub(crate) static ENTRY_THEATERLIKE_8843571728412345332: VariantsMap = [
    &["theaterlike"],
    &["theatrelike"],
    &["theatrelike"],
    &["theatrelike"],
];

pub(crate) static ENTRY_THEATERS_8074723073047846943: VariantsMap =
    [&["theaters"], &["theatres"], &["theatres"], &["theatres"]];

pub(crate) static ENTRY_THEATER_14872060673613944088: VariantsMap =
    [&["theater"], &["theatre"], &["theatre"], &["theatre"]];

pub(crate) static ENTRY_THEATRICALIZATIONS_568370628365365537: VariantsMap = [
    &["theatricalizations"],
    &["theatricalisations"],
    &["theatricalizations"],
    &["theatricalisations"],
];

pub(crate) static ENTRY_THEATRICALIZATION_8726932104691046566: VariantsMap = [
    &["theatricalization"],
    &["theatricalisation"],
    &["theatricalization"],
    &["theatricalisation"],
];

pub(crate) static ENTRY_THEATRICALIZED_1546831350777799151: VariantsMap = [
    &["theatricalized"],
    &["theatricalised"],
    &["theatricalized"],
    &["theatricalised"],
];

pub(crate) static ENTRY_THEATRICALIZES_16567523932139571310: VariantsMap = [
    &["theatricalizes"],
    &["theatricalises"],
    &["theatricalizes"],
    &["theatricalises"],
];

pub(crate) static ENTRY_THEATRICALIZE_7863949736369468171: VariantsMap = [
    &["theatricalize"],
    &["theatricalise"],
    &["theatricalize"],
    &["theatricalise"],
];

pub(crate) static ENTRY_THEATRICALIZING_4463754121398572674: VariantsMap = [
    &["theatricalizing"],
    &["theatricalising"],
    &["theatricalizing"],
    &["theatricalising"],
];

pub(crate) static ENTRY_THEATRICIZED_14255451360235022416: VariantsMap = [
    &["theatricized"],
    &["theatricised"],
    &["theatricized"],
    &["theatricised"],
];

pub(crate) static ENTRY_THEATRICIZES_6355456595406057113: VariantsMap = [
    &["theatricizes"],
    &["theatricises"],
    &["theatricizes"],
    &["theatricises"],
];

pub(crate) static ENTRY_THEATRICIZE_14394131727190869494: VariantsMap = [
    &["theatricize"],
    &["theatricise"],
    &["theatricize"],
    &["theatricise"],
];

pub(crate) static ENTRY_THEATRICIZING_9815086289375498796: VariantsMap = [
    &["theatricizing"],
    &["theatricising"],
    &["theatricizing"],
    &["theatricising"],
];

pub(crate) static ENTRY_THEOLOGIZATIONS_1637833144071496386: VariantsMap = [
    &["theologizations"],
    &["theologisations"],
    &["theologizations"],
    &["theologisations"],
];

pub(crate) static ENTRY_THEOLOGIZATION_3184169504141390704: VariantsMap = [
    &["theologization"],
    &["theologisation"],
    &["theologization"],
    &["theologisation"],
];

pub(crate) static ENTRY_THEOLOGIZED_15275657420605826847: VariantsMap = [
    &["theologized"],
    &["theologised"],
    &["theologized"],
    &["theologised"],
];

pub(crate) static ENTRY_THEOLOGIZERS_16421415494739610563: VariantsMap = [
    &["theologizers"],
    &["theologisers"],
    &["theologizers"],
    &["theologisers"],
];

pub(crate) static ENTRY_THEOLOGIZER_18105337442480749750: VariantsMap = [
    &["theologizer"],
    &["theologiser"],
    &["theologizer"],
    &["theologiser"],
];

pub(crate) static ENTRY_THEOLOGIZES_6187402845034207250: VariantsMap = [
    &["theologizes"],
    &["theologises"],
    &["theologizes"],
    &["theologises"],
];

pub(crate) static ENTRY_THEOLOGIZE_7414032072871637264: VariantsMap = [
    &["theologize"],
    &["theologise"],
    &["theologize"],
    &["theologise"],
];

pub(crate) static ENTRY_THEOLOGIZING_1522552502275961571: VariantsMap = [
    &["theologizing"],
    &["theologising"],
    &["theologizing"],
    &["theologising"],
];

pub(crate) static ENTRY_THEONE_13907392324350936871: VariantsMap =
    [&["theone"], &["theonoe"], &["theonoe"], &["theonoe"]];

pub(crate) static ENTRY_THEORIZATIONS_1710707944075838400: VariantsMap = [
    &["theorizations"],
    &["theorisations"],
    &["theorizations"],
    &["theorisations"],
];

pub(crate) static ENTRY_THEORIZATION_16280749314428462916: VariantsMap = [
    &["theorization"],
    &["theorisation"],
    &["theorization"],
    &["theorisation"],
];

pub(crate) static ENTRY_THEORIZED_12643356280684289637: VariantsMap = [
    &["theorized"],
    &["theorised"],
    &["theorized"],
    &["theorised"],
];

pub(crate) static ENTRY_THEORIZERS_17644565410392015986: VariantsMap = [
    &["theorizers"],
    &["theorisers"],
    &["theorizers"],
    &["theorisers"],
];

pub(crate) static ENTRY_THEORIZER_11654654415951381825: VariantsMap = [
    &["theorizer"],
    &["theoriser"],
    &["theorizer"],
    &["theoriser"],
];

pub(crate) static ENTRY_THEORIZES_1097471905147904168: VariantsMap = [
    &["theorizes"],
    &["theorises"],
    &["theorizes"],
    &["theorises"],
];

pub(crate) static ENTRY_THEORIZE_16592272841946174715: VariantsMap =
    [&["theorize"], &["theorise"], &["theorize"], &["theorise"]];

pub(crate) static ENTRY_THEORIZING_10670219570353826885: VariantsMap = [
    &["theorizing"],
    &["theorising"],
    &["theorizing"],
    &["theorising"],
];

pub(crate) static ENTRY_THEOSOPHIZED_16449992798183475453: VariantsMap = [
    &["theosophized"],
    &["theosophised"],
    &["theosophized"],
    &["theosophised"],
];

pub(crate) static ENTRY_THEOSOPHIZES_1158826125232789362: VariantsMap = [
    &["theosophizes"],
    &["theosophises"],
    &["theosophizes"],
    &["theosophises"],
];

pub(crate) static ENTRY_THEOSOPHIZE_7321146857183593825: VariantsMap = [
    &["theosophize"],
    &["theosophise"],
    &["theosophize"],
    &["theosophise"],
];

pub(crate) static ENTRY_THEOSOPHIZING_16087803010212187991: VariantsMap = [
    &["theosophizing"],
    &["theosophising"],
    &["theosophizing"],
    &["theosophising"],
];

pub(crate) static ENTRY_THERAP_12439233534474368057: VariantsMap =
    [&["therap"], &["threap"], &["threap"], &["threap"]];

pub(crate) static ENTRY_THERENESSES_12088887261810562814: VariantsMap = [
    &["therenesses"],
    &["threenesses"],
    &["threenesses"],
    &["threenesses"],
];

pub(crate) static ENTRY_THERENESS_15920110764314066574: VariantsMap = [
    &["thereness"],
    &["threeness"],
    &["threeness"],
    &["threeness"],
];

pub(crate) static ENTRY_THERMALIZATIONS_14303369656181821634: VariantsMap = [
    &["thermalizations"],
    &["thermalisations"],
    &["thermalizations"],
    &["thermalisations"],
];

pub(crate) static ENTRY_THERMALIZATION_7024136436456711519: VariantsMap = [
    &["thermalization"],
    &["thermalisation"],
    &["thermalization"],
    &["thermalisation"],
];

pub(crate) static ENTRY_THERMALIZED_691663227486729890: VariantsMap = [
    &["thermalized"],
    &["thermalised"],
    &["thermalized"],
    &["thermalised"],
];

pub(crate) static ENTRY_THERMALIZES_14481137627377672474: VariantsMap = [
    &["thermalizes"],
    &["thermalises"],
    &["thermalizes"],
    &["thermalises"],
];

pub(crate) static ENTRY_THERMALIZE_953829933095771497: VariantsMap = [
    &["thermalize"],
    &["thermalise"],
    &["thermalize"],
    &["thermalise"],
];

pub(crate) static ENTRY_THERMALIZING_8673243577457624256: VariantsMap = [
    &["thermalizing"],
    &["thermalising"],
    &["thermalizing"],
    &["thermalising"],
];

pub(crate) static ENTRY_THERMESTHESIA_11561525220243242262: VariantsMap = [
    &["thermesthesia"],
    &["thermaesthesia"],
    &["thermaesthesia"],
    &["thermaesthesia"],
];

pub(crate) static ENTRY_THERME_8882059819611896240: VariantsMap =
    [&["therme"], &["thermae"], &["thermae"], &["thermae"]];

pub(crate) static ENTRY_THERMOANESTHESIAS_1807836102271064111: VariantsMap = [
    &["thermoanesthesias"],
    &["thermoanaesthesias"],
    &["thermoanaesthesias"],
    &["thermoanaesthesias"],
];

pub(crate) static ENTRY_THERMOANESTHESIA_4092307643640683807: VariantsMap = [
    &["thermoanesthesia"],
    &["thermoanaesthesia"],
    &["thermoanaesthesia"],
    &["thermoanaesthesia"],
];

pub(crate) static ENTRY_THERMOMETERIZES_10840283776322209379: VariantsMap = [
    &["thermometerizes"],
    &["thermometerises"],
    &["thermometerizes"],
    &["thermometerises"],
];

pub(crate) static ENTRY_THERMOMETERIZE_15998653899602520685: VariantsMap = [
    &["thermometerize"],
    &["thermometerise"],
    &["thermometerize"],
    &["thermometerise"],
];

pub(crate) static ENTRY_THERMOPOLYMERIZATIONS_3651245684619525553: VariantsMap = [
    &["thermopolymerizations"],
    &["thermopolymerisations"],
    &["thermopolymerizations"],
    &["thermopolymerisations"],
];

pub(crate) static ENTRY_THERMOPOLYMERIZATION_10433431029598912285: VariantsMap = [
    &["thermopolymerization"],
    &["thermopolymerisation"],
    &["thermopolymerization"],
    &["thermopolymerisation"],
];

pub(crate) static ENTRY_THERMOSIPHONS_179083683317180105: VariantsMap = [
    &["thermosiphons"],
    &["thermosyphons"],
    &["thermosyphons"],
    &["thermosyphons"],
];

pub(crate) static ENTRY_THERMOSIPHON_9621111130028620625: VariantsMap = [
    &["thermosiphon"],
    &["thermosyphon"],
    &["thermosyphon"],
    &["thermosyphon"],
];

pub(crate) static ENTRY_THESMOTHETE_5962250708932328706: VariantsMap = [
    &["thesmothete"],
    &["thesmothetae"],
    &["thesmothetae"],
    &["thesmothetae"],
];

pub(crate) static ENTRY_THRONIZES_12549201774820221034: VariantsMap = [
    &["thronizes"],
    &["thronises"],
    &["thronizes"],
    &["thronises"],
];

pub(crate) static ENTRY_THRONIZE_6821227400136957234: VariantsMap =
    [&["thronize"], &["thronise"], &["thronize"], &["thronise"]];

pub(crate) static ENTRY_THROUGH_13450103710029067577: VariantsMap =
    [&["through"], &["through"], &["through"], &["through"]];

pub(crate) static ENTRY_THRUWAYS_949399170587990036: VariantsMap = [
    &["thruways"],
    &["throughways"],
    &["throughways"],
    &["throughways"],
];

pub(crate) static ENTRY_THRUWAY_8791794387715289057: VariantsMap = [
    &["thruway"],
    &["throughway"],
    &["throughway"],
    &["throughway"],
];

pub(crate) static ENTRY_THYMECTOMIZE_9188848309665571694: VariantsMap = [
    &["thymectomize"],
    &["thymectomise"],
    &["thymectomize"],
    &["thymectomise"],
];

pub(crate) static ENTRY_THYROIDECTOMIZED_18037313633331374041: VariantsMap = [
    &["thyroidectomized"],
    &["thyroidectomised"],
    &["thyroidectomized"],
    &["thyroidectomised"],
];

pub(crate) static ENTRY_THYROIDIZATIONS_15147067345688634277: VariantsMap = [
    &["thyroidizations"],
    &["thyroidisations"],
    &["thyroidizations"],
    &["thyroidisations"],
];

pub(crate) static ENTRY_THYROIDIZATION_6148181864988263565: VariantsMap = [
    &["thyroidization"],
    &["thyroidisation"],
    &["thyroidization"],
    &["thyroidisation"],
];

pub(crate) static ENTRY_TIDBITS_8862313789168390887: VariantsMap =
    [&["tidbits"], &["titbits"], &["tidbits"], &["titbits"]];

pub(crate) static ENTRY_TIDBIT_14858433395468188521: VariantsMap =
    [&["tidbit"], &["titbit"], &["tidbit"], &["titbit"]];

pub(crate) static ENTRY_TILLFORD_13927963203563990910: VariantsMap = [
    &["tillford"],
    &["tillfourd"],
    &["tillfourd"],
    &["tillfourd"],
];

pub(crate) static ENTRY_TIMONIZED_3807325960951210177: VariantsMap = [
    &["timonized"],
    &["timonised"],
    &["timonized"],
    &["timonised"],
];

pub(crate) static ENTRY_TIMONIZES_16589660513575137498: VariantsMap = [
    &["timonizes"],
    &["timonises"],
    &["timonizes"],
    &["timonises"],
];

pub(crate) static ENTRY_TIMONIZE_4384316048230541265: VariantsMap =
    [&["timonize"], &["timonise"], &["timonize"], &["timonise"]];

pub(crate) static ENTRY_TIMONIZING_13953660282542190706: VariantsMap = [
    &["timonizing"],
    &["timonising"],
    &["timonizing"],
    &["timonising"],
];

pub(crate) static ENTRY_TIMOR_2867687196301196005: VariantsMap =
    [&["timor"], &["timour"], &["timour"], &["timour"]];

pub(crate) static ENTRY_TINSELED_9574695065168366382: VariantsMap = [
    &["tinseled"],
    &["tinselled"],
    &["tinselled"],
    &["tinselled"],
];

pub(crate) static ENTRY_TINSELIER_17862744387346717732: VariantsMap = [
    &["tinselier"],
    &["tinsellier"],
    &["tinsellier"],
    &["tinsellier"],
];

pub(crate) static ENTRY_TINSELIEST_10796385662191046623: VariantsMap = [
    &["tinseliest"],
    &["tinselliest"],
    &["tinselliest"],
    &["tinselliest"],
];

pub(crate) static ENTRY_TINSELING_15422200188036739484: VariantsMap = [
    &["tinseling"],
    &["tinselling"],
    &["tinselling"],
    &["tinselling"],
];

pub(crate) static ENTRY_TIRES_13233982026064511360: VariantsMap =
    [&["tires"], &["tyres"], &["tires"], &["tyres"]];

pub(crate) static ENTRY_TIRE_17853768187298953050: VariantsMap =
    [&["tire"], &["tyre"], &["tire"], &["tyre"]];

pub(crate) static ENTRY_TITERS_16256818623137143269: VariantsMap =
    [&["titers"], &["titres"], &["titres"], &["titres"]];

pub(crate) static ENTRY_TITER_3432959079810131995: VariantsMap =
    [&["titer"], &["titre"], &["titre"], &["titre"]];

pub(crate) static ENTRY_TITTUPED_18032143166294150502: VariantsMap = [
    &["tittuped"],
    &["tittupped"],
    &["tittupped"],
    &["tittupped"],
];

pub(crate) static ENTRY_TITTUPING_5945965916177916410: VariantsMap = [
    &["tittuping"],
    &["tittupping"],
    &["tittupping"],
    &["tittupping"],
];

pub(crate) static ENTRY_TITTUPY_1440027282222835899: VariantsMap =
    [&["tittupy"], &["tittuppy"], &["tittuppy"], &["tittuppy"]];

pub(crate) static ENTRY_TONICIZES_17805405285162444673: VariantsMap = [
    &["tonicizes"],
    &["tonicises"],
    &["tonicizes"],
    &["tonicises"],
];

pub(crate) static ENTRY_TONICIZE_2289940295082319741: VariantsMap =
    [&["tonicize"], &["tonicise"], &["tonicize"], &["tonicise"]];

pub(crate) static ENTRY_TOPESTHESIA_9952864993680466403: VariantsMap = [
    &["topesthesia"],
    &["topaesthesia"],
    &["topaesthesia"],
    &["topaesthesia"],
];

pub(crate) static ENTRY_TORET_14642122393715101008: VariantsMap =
    [&["toret"], &["touret"], &["touret"], &["touret"]];

pub(crate) static ENTRY_TORPORIZES_7515131355757541341: VariantsMap = [
    &["torporizes"],
    &["torporises"],
    &["torporizes"],
    &["torporises"],
];

pub(crate) static ENTRY_TORPORIZE_18297824631247427015: VariantsMap = [
    &["torporize"],
    &["torporise"],
    &["torporize"],
    &["torporise"],
];

pub(crate) static ENTRY_TORYIZES_2714307057530869042: VariantsMap =
    [&["toryizes"], &["toryises"], &["toryizes"], &["toryises"]];

pub(crate) static ENTRY_TORYIZE_10210463142410101593: VariantsMap =
    [&["toryize"], &["toryise"], &["toryize"], &["toryise"]];

pub(crate) static ENTRY_TOTALED_6013017983757467705: VariantsMap =
    [&["totaled"], &["totalled"], &["totalled"], &["totalled"]];

pub(crate) static ENTRY_TOTALERS_3867797254055796802: VariantsMap = [
    &["totalers"],
    &["totallers"],
    &["totallers"],
    &["totallers"],
];

pub(crate) static ENTRY_TOTALER_10727979907060022636: VariantsMap =
    [&["totaler"], &["totaller"], &["totaller"], &["totaller"]];

pub(crate) static ENTRY_TOTALING_9913720993762819432: VariantsMap = [
    &["totaling"],
    &["totalling"],
    &["totalling"],
    &["totalling"],
];

pub(crate) static ENTRY_TOTALITARIANIZE_8599233737485608940: VariantsMap = [
    &["totalitarianize"],
    &["totalitarianise"],
    &["totalitarianize"],
    &["totalitarianise"],
];

pub(crate) static ENTRY_TOTALIZATIONS_16093531371594133063: VariantsMap = [
    &["totalizations"],
    &["totalisations"],
    &["totalizations"],
    &["totalisations"],
];

pub(crate) static ENTRY_TOTALIZATION_3221716119411894800: VariantsMap = [
    &["totalization"],
    &["totalisation"],
    &["totalization"],
    &["totalisation"],
];

pub(crate) static ENTRY_TOTALIZATORS_8640164609623735800: VariantsMap = [
    &["totalizators"],
    &["totalisators"],
    &["totalisators"],
    &["totalisators"],
];

pub(crate) static ENTRY_TOTALIZATOR_8226180587584060233: VariantsMap = [
    &["totalizator"],
    &["totalisator"],
    &["totalisator"],
    &["totalisator"],
];

pub(crate) static ENTRY_TOTALIZED_13767793031901840125: VariantsMap = [
    &["totalized"],
    &["totalised"],
    &["totalized"],
    &["totalised"],
];

pub(crate) static ENTRY_TOTALIZERS_15548921713961085912: VariantsMap = [
    &["totalizers"],
    &["totalisers"],
    &["totalizers"],
    &["totalisers"],
];

pub(crate) static ENTRY_TOTALIZER_10517738673224079027: VariantsMap = [
    &["totalizer"],
    &["totaliser"],
    &["totalizer"],
    &["totaliser"],
];

pub(crate) static ENTRY_TOTALIZES_6721705970426925276: VariantsMap = [
    &["totalizes"],
    &["totalises"],
    &["totalizes"],
    &["totalises"],
];

pub(crate) static ENTRY_TOTALIZE_2473362082375699734: VariantsMap =
    [&["totalize"], &["totalise"], &["totalize"], &["totalise"]];

pub(crate) static ENTRY_TOTALIZING_11500628009269088151: VariantsMap = [
    &["totalizing"],
    &["totalising"],
    &["totalizing"],
    &["totalising"],
];

pub(crate) static ENTRY_TOTEMIZATIONS_4524480269908097645: VariantsMap = [
    &["totemizations"],
    &["totemisations"],
    &["totemizations"],
    &["totemisations"],
];

pub(crate) static ENTRY_TOTEMIZATION_17547511589554648221: VariantsMap = [
    &["totemization"],
    &["totemisation"],
    &["totemization"],
    &["totemisation"],
];

pub(crate) static ENTRY_TOURIZES_16287459104895480818: VariantsMap =
    [&["tourizes"], &["tourises"], &["tourizes"], &["tourises"]];

pub(crate) static ENTRY_TOURIZE_4416339355326535837: VariantsMap =
    [&["tourize"], &["tourise"], &["tourize"], &["tourise"]];

pub(crate) static ENTRY_TOWELED_15166488210792177793: VariantsMap =
    [&["toweled"], &["towelled"], &["towelled"], &["towelled"]];

pub(crate) static ENTRY_TOWELINGS_6911217900542580416: VariantsMap = [
    &["towelings"],
    &["towellings"],
    &["towellings"],
    &["towellings"],
];

pub(crate) static ENTRY_TOWELING_4481362776063713769: VariantsMap = [
    &["toweling"],
    &["towelling"],
    &["towelling"],
    &["towelling"],
];

pub(crate) static ENTRY_TOXANEMIA_5092978943692773401: VariantsMap = [
    &["toxanemia"],
    &["toxanaemia"],
    &["toxanaemia"],
    &["toxanaemia"],
];

pub(crate) static ENTRY_TOXEMIAS_16145092731975598632: VariantsMap =
    [&["toxemias"], &["toxaemias"], &["toxemias"], &["toxaemias"]];

pub(crate) static ENTRY_TOXEMIA_13728114455609378495: VariantsMap =
    [&["toxemia"], &["toxaemia"], &["toxemia"], &["toxaemia"]];

pub(crate) static ENTRY_TOXEMIC_3847368103673580332: VariantsMap =
    [&["toxemic"], &["toxaemic"], &["toxemic"], &["toxaemic"]];

pub(crate) static ENTRY_TOXICEMIA_3221713968588738388: VariantsMap = [
    &["toxicemia"],
    &["toxicaemia"],
    &["toxicaemia"],
    &["toxicaemia"],
];

pub(crate) static ENTRY_TOXICOHEMIA_1510663382315935096: VariantsMap = [
    &["toxicohemia"],
    &["toxicohaemia"],
    &["toxicohaemia"],
    &["toxicohaemia"],
];

pub(crate) static ENTRY_TOXIHEMIA_17949081455236710796: VariantsMap = [
    &["toxihemia"],
    &["toxihaemia"],
    &["toxihaemia"],
    &["toxihaemia"],
];

pub(crate) static ENTRY_TOXINEMIA_4067816496926950076: VariantsMap = [
    &["toxinemia"],
    &["toxinaemia"],
    &["toxinaemia"],
    &["toxinaemia"],
];

pub(crate) static ENTRY_TRABEATE_475272284513241921: VariantsMap = [
    &["trabeate"],
    &["trabeatae"],
    &["trabeatae"],
    &["trabeatae"],
];

pub(crate) static ENTRY_TRABECULE_4746018401275580221: VariantsMap = [
    &["trabecule"],
    &["trabeculae"],
    &["trabeculae"],
    &["trabeculae"],
];

pub(crate) static ENTRY_TRACTORIZATIONS_18210642849375336921: VariantsMap = [
    &["tractorizations"],
    &["tractorisations"],
    &["tractorizations"],
    &["tractorisations"],
];

pub(crate) static ENTRY_TRACTORIZATION_3823073726188841416: VariantsMap = [
    &["tractorization"],
    &["tractorisation"],
    &["tractorization"],
    &["tractorisation"],
];

pub(crate) static ENTRY_TRACTORIZES_5631147609434218207: VariantsMap = [
    &["tractorizes"],
    &["tractorises"],
    &["tractorizes"],
    &["tractorises"],
];

pub(crate) static ENTRY_TRACTORIZE_12965430895282931565: VariantsMap = [
    &["tractorize"],
    &["tractorise"],
    &["tractorize"],
    &["tractorise"],
];

pub(crate) static ENTRY_TRADITIONALIZED_2635338649308214147: VariantsMap = [
    &["traditionalized"],
    &["traditionalised"],
    &["traditionalized"],
    &["traditionalised"],
];

pub(crate) static ENTRY_TRADITIONALIZES_17884375175492170718: VariantsMap = [
    &["traditionalizes"],
    &["traditionalises"],
    &["traditionalizes"],
    &["traditionalises"],
];

pub(crate) static ENTRY_TRADITIONALIZE_4898176225220743845: VariantsMap = [
    &["traditionalize"],
    &["traditionalise"],
    &["traditionalize"],
    &["traditionalise"],
];

pub(crate) static ENTRY_TRADITIONIZES_18011235531342430501: VariantsMap = [
    &["traditionizes"],
    &["traditionises"],
    &["traditionizes"],
    &["traditionises"],
];

pub(crate) static ENTRY_TRADITIONIZE_11047234467125040571: VariantsMap = [
    &["traditionize"],
    &["traditionise"],
    &["traditionize"],
    &["traditionise"],
];

pub(crate) static ENTRY_TRAGICIZES_17519202874941904760: VariantsMap = [
    &["tragicizes"],
    &["tragicises"],
    &["tragicizes"],
    &["tragicises"],
];

pub(crate) static ENTRY_TRAGICIZE_957780290072315119: VariantsMap = [
    &["tragicize"],
    &["tragicise"],
    &["tragicize"],
    &["tragicise"],
];

pub(crate) static ENTRY_TRAGICOLORED_13278772284942211165: VariantsMap = [
    &["tragicolored"],
    &["tragicoloured"],
    &["tragicoloured"],
    &["tragicoloured"],
];

pub(crate) static ENTRY_TRAITORIZES_16161164434011189838: VariantsMap = [
    &["traitorizes"],
    &["traitorises"],
    &["traitorizes"],
    &["traitorises"],
];

pub(crate) static ENTRY_TRAITORIZE_551131030474656423: VariantsMap = [
    &["traitorize"],
    &["traitorise"],
    &["traitorize"],
    &["traitorise"],
];

pub(crate) static ENTRY_TRAMMELED_7321238481699131765: VariantsMap = [
    &["trammeled"],
    &["trammelled"],
    &["trammelled"],
    &["trammelled"],
];

pub(crate) static ENTRY_TRAMMELERS_8202463777486458185: VariantsMap = [
    &["trammelers"],
    &["trammellers"],
    &["trammellers"],
    &["trammellers"],
];

pub(crate) static ENTRY_TRAMMELER_1286061836358212954: VariantsMap = [
    &["trammeler"],
    &["trammeller"],
    &["trammeller"],
    &["trammeller"],
];

pub(crate) static ENTRY_TRAMMELING_2641971254351085893: VariantsMap = [
    &["trammeling"],
    &["trammelling"],
    &["trammelling"],
    &["trammelling"],
];

pub(crate) static ENTRY_TRANQUILITIES_16195163391619170068: VariantsMap = [
    &["tranquilities"],
    &["tranquillities"],
    &["tranquilities"],
    &["tranquillities"],
];

pub(crate) static ENTRY_TRANQUILITY_8540551709960885595: VariantsMap = [
    &["tranquility"],
    &["tranquillity"],
    &["tranquility"],
    &["tranquillity"],
];

pub(crate) static ENTRY_TRANQUILIZATIONS_17619573841316216935: VariantsMap = [
    &["tranquilizations"],
    &["tranquilisations"],
    &["tranquilizations"],
    &["tranquilisations"],
];

pub(crate) static ENTRY_TRANQUILIZATION_14846255753979813760: VariantsMap = [
    &["tranquilization"],
    &["tranquilisation"],
    &["tranquilization"],
    &["tranquilisation"],
];

pub(crate) static ENTRY_TRANQUILIZED_8802666398177881938: VariantsMap = [
    &["tranquilized"],
    &["tranquillised"],
    &["tranquilized"],
    &["tranquillised"],
];

pub(crate) static ENTRY_TRANQUILIZERS_17103334183302096096: VariantsMap = [
    &["tranquilizers"],
    &["tranquillisers"],
    &["tranquilizers"],
    &["tranquillisers"],
];

pub(crate) static ENTRY_TRANQUILIZER_2761665163152313094: VariantsMap = [
    &["tranquilizer"],
    &["tranquilliser"],
    &["tranquilizer"],
    &["tranquilliser"],
];

pub(crate) static ENTRY_TRANQUILIZES_59757620788033573: VariantsMap = [
    &["tranquilizes"],
    &["tranquillises"],
    &["tranquilizes"],
    &["tranquillises"],
];

pub(crate) static ENTRY_TRANQUILIZE_10282286664857910461: VariantsMap = [
    &["tranquilize"],
    &["tranquillise"],
    &["tranquilize"],
    &["tranquillise"],
];

pub(crate) static ENTRY_TRANQUILIZINGLY_556670129841874355: VariantsMap = [
    &["tranquilizingly"],
    &["tranquilisingly"],
    &["tranquilizingly"],
    &["tranquilisingly"],
];

pub(crate) static ENTRY_TRANQUILIZINGS_2266773302059369088: VariantsMap = [
    &["tranquilizings"],
    &["tranquillisings"],
    &["tranquilizings"],
    &["tranquillisings"],
];

pub(crate) static ENTRY_TRANQUILIZING_13850716228820534198: VariantsMap = [
    &["tranquilizing"],
    &["tranquillising"],
    &["tranquilizing"],
    &["tranquillising"],
];

pub(crate) static ENTRY_TRANQUILLIZATIONS_4263826721380617410: VariantsMap = [
    &["tranquillizations"],
    &["tranquillisations"],
    &["tranquillizations"],
    &["tranquillisations"],
];

pub(crate) static ENTRY_TRANQUILLIZATION_11946857030526310268: VariantsMap = [
    &["tranquillization"],
    &["tranquillisation"],
    &["tranquillization"],
    &["tranquillisation"],
];

pub(crate) static ENTRY_TRANQUILLIZINGLY_14381964317822750722: VariantsMap = [
    &["tranquillizingly"],
    &["tranquillisingly"],
    &["tranquillizingly"],
    &["tranquillisingly"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZATION_16279978221157892606: VariantsMap = [
    &["transcendentalization"],
    &["transcendentalisation"],
    &["transcendentalization"],
    &["transcendentalisation"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZED_1811227647892991582: VariantsMap = [
    &["transcendentalized"],
    &["transcendentalised"],
    &["transcendentalized"],
    &["transcendentalised"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZES_256586495310370731: VariantsMap = [
    &["transcendentalizes"],
    &["transcendentalises"],
    &["transcendentalizes"],
    &["transcendentalises"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZE_12477449740073762039: VariantsMap = [
    &["transcendentalize"],
    &["transcendentalise"],
    &["transcendentalize"],
    &["transcendentalise"],
];

pub(crate) static ENTRY_TRANSCENDENTALIZING_1803732975904952155: VariantsMap = [
    &["transcendentalizing"],
    &["transcendentalising"],
    &["transcendentalizing"],
    &["transcendentalising"],
];

pub(crate) static ENTRY_TRANSCOLORATIONS_16758395443174056843: VariantsMap = [
    &["transcolorations"],
    &["transcolourations"],
    &["transcolourations"],
    &["transcolourations"],
];

pub(crate) static ENTRY_TRANSCOLORATION_343129450671874835: VariantsMap = [
    &["transcoloration"],
    &["transcolouration"],
    &["transcolouration"],
    &["transcolouration"],
];

pub(crate) static ENTRY_TRANSCOLORRER_4795645889162012189: VariantsMap = [
    &["transcolorrer"],
    &["transcolourer"],
    &["transcolourer"],
    &["transcolourer"],
];

pub(crate) static ENTRY_TRANSCOLORREST_13178604266626958240: VariantsMap = [
    &["transcolorrest"],
    &["transcolourest"],
    &["transcolourest"],
    &["transcolourest"],
];

pub(crate) static ENTRY_TRANSCOLOR_3566969815815539331: VariantsMap = [
    &["transcolor"],
    &["transcolour"],
    &["transcolour"],
    &["transcolour"],
];

pub(crate) static ENTRY_TRANSISTORIZATIONS_15440922126340456777: VariantsMap = [
    &["transistorizations"],
    &["transistorisations"],
    &["transistorizations"],
    &["transistorisations"],
];

pub(crate) static ENTRY_TRANSISTORIZATION_1936290593265769427: VariantsMap = [
    &["transistorization"],
    &["transistorisation"],
    &["transistorization"],
    &["transistorisation"],
];

pub(crate) static ENTRY_TRANSISTORIZED_15135482287551822492: VariantsMap = [
    &["transistorized"],
    &["transistorised"],
    &["transistorized"],
    &["transistorised"],
];

pub(crate) static ENTRY_TRANSISTORIZES_1343939411237171803: VariantsMap = [
    &["transistorizes"],
    &["transistorises"],
    &["transistorizes"],
    &["transistorises"],
];

pub(crate) static ENTRY_TRANSISTORIZE_14955480539617938425: VariantsMap = [
    &["transistorize"],
    &["transistorise"],
    &["transistorize"],
    &["transistorise"],
];

pub(crate) static ENTRY_TRANSISTORIZING_10767950521341986252: VariantsMap = [
    &["transistorizing"],
    &["transistorising"],
    &["transistorizing"],
    &["transistorising"],
];

pub(crate) static ENTRY_TRANSPARENTIZES_9410899145545451286: VariantsMap = [
    &["transparentizes"],
    &["transparentises"],
    &["transparentizes"],
    &["transparentises"],
];

pub(crate) static ENTRY_TRANSPARENTIZE_1817106363462334768: VariantsMap = [
    &["transparentize"],
    &["transparentise"],
    &["transparentize"],
    &["transparentise"],
];

pub(crate) static ENTRY_TRAUMATIZATIONS_7417106584297477223: VariantsMap = [
    &["traumatizations"],
    &["traumatisations"],
    &["traumatizations"],
    &["traumatisations"],
];

pub(crate) static ENTRY_TRAUMATIZATION_3746681776679931423: VariantsMap = [
    &["traumatization"],
    &["traumatisation"],
    &["traumatization"],
    &["traumatisation"],
];

pub(crate) static ENTRY_TRAUMATIZED_7431966359976446213: VariantsMap = [
    &["traumatized"],
    &["traumatised"],
    &["traumatized"],
    &["traumatised"],
];

pub(crate) static ENTRY_TRAUMATIZES_4330104088006808909: VariantsMap = [
    &["traumatizes"],
    &["traumatises"],
    &["traumatizes"],
    &["traumatises"],
];

pub(crate) static ENTRY_TRAUMATIZE_8649856127609129608: VariantsMap = [
    &["traumatize"],
    &["traumatise"],
    &["traumatize"],
    &["traumatise"],
];

pub(crate) static ENTRY_TRAUMATIZING_2918929651955345564: VariantsMap = [
    &["traumatizing"],
    &["traumatising"],
    &["traumatizing"],
    &["traumatising"],
];

pub(crate) static ENTRY_TRAVELED_7471204723840738059: VariantsMap = [
    &["traveled"],
    &["travelled"],
    &["travelled"],
    &["travelled"],
];

pub(crate) static ENTRY_TRAVELERS_534480827925386728: VariantsMap = [
    &["travelers"],
    &["travellers"],
    &["travellers"],
    &["travellers"],
];

pub(crate) static ENTRY_TRAVELER_13674641254214006714: VariantsMap = [
    &["traveler"],
    &["traveller"],
    &["traveller"],
    &["traveller"],
];

pub(crate) static ENTRY_TRAVELINGS_4473114144843360272: VariantsMap = [
    &["travelings"],
    &["travellings"],
    &["travellings"],
    &["travellings"],
];

pub(crate) static ENTRY_TRAVELING_15330546315886302191: VariantsMap = [
    &["traveling"],
    &["travelling"],
    &["travelling"],
    &["travelling"],
];

pub(crate) static ENTRY_TRAVELOGUES_4261693774497596751: VariantsMap = [
    &["travelogues"],
    &["travelogues"],
    &["travelogues"],
    &["travelogues"],
];

pub(crate) static ENTRY_TRAVELOGUE_9832945069166970827: VariantsMap = [
    &["travelogue"],
    &["travelogue"],
    &["travelogue"],
    &["travelogue"],
];

pub(crate) static ENTRY_TRIALED_10113550628054960808: VariantsMap =
    [&["trialed"], &["trialled"], &["trialled"], &["trialled"]];

pub(crate) static ENTRY_TRIALING_6397065983321001404: VariantsMap = [
    &["trialing"],
    &["trialling"],
    &["trialling"],
    &["trialling"],
];

pub(crate) static ENTRY_TRIALIZATION_15902543461546982351: VariantsMap = [
    &["trialization"],
    &["trialisation"],
    &["trialization"],
    &["trialisation"],
];

pub(crate) static ENTRY_TRIANGULARIZATIONS_9175876927610339412: VariantsMap = [
    &["triangularizations"],
    &["triangularisations"],
    &["triangularizations"],
    &["triangularisations"],
];

pub(crate) static ENTRY_TRIANGULARIZATION_5170297502596499934: VariantsMap = [
    &["triangularization"],
    &["triangularisation"],
    &["triangularization"],
    &["triangularisation"],
];

pub(crate) static ENTRY_TRIANGULARIZED_8399601922283134135: VariantsMap = [
    &["triangularized"],
    &["triangularised"],
    &["triangularized"],
    &["triangularised"],
];

pub(crate) static ENTRY_TRIANGULARIZES_2309859741267387471: VariantsMap = [
    &["triangularizes"],
    &["triangularises"],
    &["triangularizes"],
    &["triangularises"],
];

pub(crate) static ENTRY_TRIANGULARIZE_6075796262826371207: VariantsMap = [
    &["triangularize"],
    &["triangularise"],
    &["triangularize"],
    &["triangularise"],
];

pub(crate) static ENTRY_TRIANGULARIZING_6298865978999024428: VariantsMap = [
    &["triangularizing"],
    &["triangularising"],
    &["triangularizing"],
    &["triangularising"],
];

pub(crate) static ENTRY_TRICHINIZATIONS_12374290002608454472: VariantsMap = [
    &["trichinizations"],
    &["trichinisations"],
    &["trichinizations"],
    &["trichinisations"],
];

pub(crate) static ENTRY_TRICHINIZATION_17095496984757617228: VariantsMap = [
    &["trichinization"],
    &["trichinisation"],
    &["trichinization"],
    &["trichinisation"],
];

pub(crate) static ENTRY_TRICHINIZED_17644488673613289890: VariantsMap = [
    &["trichinized"],
    &["trichinised"],
    &["trichinized"],
    &["trichinised"],
];

pub(crate) static ENTRY_TRICHINIZES_1344045113327285956: VariantsMap = [
    &["trichinizes"],
    &["trichinises"],
    &["trichinizes"],
    &["trichinises"],
];

pub(crate) static ENTRY_TRICHINIZE_5574846251210958831: VariantsMap = [
    &["trichinize"],
    &["trichinise"],
    &["trichinize"],
    &["trichinise"],
];

pub(crate) static ENTRY_TRICHINIZING_3545688560394153529: VariantsMap = [
    &["trichinizing"],
    &["trichinising"],
    &["trichinizing"],
    &["trichinising"],
];

pub(crate) static ENTRY_TRICHLORETHYLENES_15772099121722073798: VariantsMap = [
    &["trichlorethylenes"],
    &["trichloroethylenes"],
    &["trichloroethylenes"],
    &["trichloroethylenes"],
];

pub(crate) static ENTRY_TRICHLORETHYLENE_9901005590441640862: VariantsMap = [
    &["trichlorethylene"],
    &["trichloroethylene"],
    &["trichloroethylene"],
    &["trichloroethylene"],
];

pub(crate) static ENTRY_TRICHOTOMIZED_3347768583083276490: VariantsMap = [
    &["trichotomized"],
    &["trichotomised"],
    &["trichotomized"],
    &["trichotomised"],
];

pub(crate) static ENTRY_TRICHOTOMIZES_17276637113087926760: VariantsMap = [
    &["trichotomizes"],
    &["trichotomises"],
    &["trichotomizes"],
    &["trichotomises"],
];

pub(crate) static ENTRY_TRICHOTOMIZE_854533418810743207: VariantsMap = [
    &["trichotomize"],
    &["trichotomise"],
    &["trichotomize"],
    &["trichotomise"],
];

pub(crate) static ENTRY_TRICHOTOMIZING_4094867634668496821: VariantsMap = [
    &["trichotomizing"],
    &["trichotomising"],
    &["trichotomizing"],
    &["trichotomising"],
];

pub(crate) static ENTRY_TRICOLORED_14625827355822839152: VariantsMap = [
    &["tricolored"],
    &["tricoloured"],
    &["tricoloured"],
    &["tricoloured"],
];

pub(crate) static ENTRY_TRICOLORS_5653354569553256367: VariantsMap = [
    &["tricolors"],
    &["tricolours"],
    &["tricolours"],
    &["tricolours"],
];

pub(crate) static ENTRY_TRICOLOR_29934386578088381: VariantsMap = [
    &["tricolor"],
    &["tricolour"],
    &["tricolour"],
    &["tricolour"],
];

pub(crate) static ENTRY_TRIECIOUSLY_8350175444262968317: VariantsMap = [
    &["trieciously"],
    &["trioeciously"],
    &["trioeciously"],
    &["trioeciously"],
];

pub(crate) static ENTRY_TRIECIOUS_13315610863197702350: VariantsMap = [
    &["triecious"],
    &["trioecious"],
    &["trioecious"],
    &["trioecious"],
];

pub(crate) static ENTRY_TRIENE_15794998642666208471: VariantsMap =
    [&["triene"], &["triaene"], &["triaene"], &["triaene"]];

pub(crate) static ENTRY_TRIFLUORIDE_7068061211011145761: VariantsMap = [
    &["trifluoride"],
    &["trifluouride"],
    &["trifluouride"],
    &["trifluouride"],
];

pub(crate) static ENTRY_TRILLIONIZES_10650478618693827922: VariantsMap = [
    &["trillionizes"],
    &["trillionises"],
    &["trillionizes"],
    &["trillionises"],
];

pub(crate) static ENTRY_TRILLIONIZE_2061247672357509542: VariantsMap = [
    &["trillionize"],
    &["trillionise"],
    &["trillionize"],
    &["trillionise"],
];

pub(crate) static ENTRY_TRIMERIZATIONS_1022726125043168815: VariantsMap = [
    &["trimerizations"],
    &["trimerisations"],
    &["trimerizations"],
    &["trimerisations"],
];

pub(crate) static ENTRY_TRIMERIZATION_12375953829418021021: VariantsMap = [
    &["trimerization"],
    &["trimerisation"],
    &["trimerization"],
    &["trimerisation"],
];

pub(crate) static ENTRY_TRIPYLEAN_10875065225907680531: VariantsMap = [
    &["tripylean"],
    &["tripylaean"],
    &["tripylaean"],
    &["tripylaean"],
];

pub(crate) static ENTRY_TRIVIALIZATIONS_7001355469538203417: VariantsMap = [
    &["trivializations"],
    &["trivialisations"],
    &["trivializations"],
    &["trivialisations"],
];

pub(crate) static ENTRY_TRIVIALIZATION_15415473767815002378: VariantsMap = [
    &["trivialization"],
    &["trivialisation"],
    &["trivialization"],
    &["trivialisation"],
];

pub(crate) static ENTRY_TRIVIALIZED_7658877615119170597: VariantsMap = [
    &["trivialized"],
    &["trivialised"],
    &["trivialized"],
    &["trivialised"],
];

pub(crate) static ENTRY_TRIVIALIZES_12098662311152290426: VariantsMap = [
    &["trivializes"],
    &["trivialises"],
    &["trivializes"],
    &["trivialises"],
];

pub(crate) static ENTRY_TRIVIALIZE_18242589362817679930: VariantsMap = [
    &["trivialize"],
    &["trivialise"],
    &["trivialize"],
    &["trivialise"],
];

pub(crate) static ENTRY_TRIVIALIZING_11202764572056711533: VariantsMap = [
    &["trivializing"],
    &["trivialising"],
    &["trivializing"],
    &["trivialising"],
];

pub(crate) static ENTRY_TROLLEYED_16320990397285120378: VariantsMap = [
    &["trolleyed"],
    &["trolleyed"],
    &["trolleyed"],
    &["trolleyed"],
];

pub(crate) static ENTRY_TROLLEYING_637696503258459274: VariantsMap = [
    &["trolleying"],
    &["trolleying"],
    &["trolleying"],
    &["trolleying"],
];

pub(crate) static ENTRY_TROLLEYS_18263143595174364530: VariantsMap =
    [&["trolleys"], &["trolleys"], &["trolleys"], &["trolleys"]];

pub(crate) static ENTRY_TROLLEY_1793317771282721854: VariantsMap =
    [&["trolley"], &["trolley"], &["trolley"], &["trolley"]];

pub(crate) static ENTRY_TROPEOLIN_13501077771486427288: VariantsMap = [
    &["tropeolin"],
    &["tropaeolin"],
    &["tropaeolin"],
    &["tropaeolin"],
];

pub(crate) static ENTRY_TROPICALIZATIONS_11359261593866683979: VariantsMap = [
    &["tropicalizations"],
    &["tropicalisations"],
    &["tropicalizations"],
    &["tropicalisations"],
];

pub(crate) static ENTRY_TROPICALIZATION_280149473467881406: VariantsMap = [
    &["tropicalization"],
    &["tropicalisation"],
    &["tropicalization"],
    &["tropicalisation"],
];

pub(crate) static ENTRY_TROPICALIZED_12626126161696724783: VariantsMap = [
    &["tropicalized"],
    &["tropicalised"],
    &["tropicalized"],
    &["tropicalised"],
];

pub(crate) static ENTRY_TROPICALIZES_10180779904224473997: VariantsMap = [
    &["tropicalizes"],
    &["tropicalises"],
    &["tropicalizes"],
    &["tropicalises"],
];

pub(crate) static ENTRY_TROPICALIZE_12627151915334844007: VariantsMap = [
    &["tropicalize"],
    &["tropicalise"],
    &["tropicalize"],
    &["tropicalise"],
];

pub(crate) static ENTRY_TROPICALIZING_17779530954870328562: VariantsMap = [
    &["tropicalizing"],
    &["tropicalising"],
    &["tropicalizing"],
    &["tropicalising"],
];

pub(crate) static ENTRY_TROWELED_4799678352682284187: VariantsMap = [
    &["troweled"],
    &["trowelled"],
    &["trowelled"],
    &["trowelled"],
];

pub(crate) static ENTRY_TROWELERS_3014176820808259829: VariantsMap = [
    &["trowelers"],
    &["trowellers"],
    &["trowellers"],
    &["trowellers"],
];

pub(crate) static ENTRY_TROWELER_16575642105606421144: VariantsMap = [
    &["troweler"],
    &["troweller"],
    &["troweller"],
    &["troweller"],
];

pub(crate) static ENTRY_TROWELING_15187396834118954225: VariantsMap = [
    &["troweling"],
    &["trowelling"],
    &["trowelling"],
    &["trowelling"],
];

pub(crate) static ENTRY_TRUBENIZED_12138523136394636595: VariantsMap = [
    &["trubenized"],
    &["trubenised"],
    &["trubenized"],
    &["trubenised"],
];

pub(crate) static ENTRY_TRUBENIZES_11904727106928842123: VariantsMap = [
    &["trubenizes"],
    &["trubenises"],
    &["trubenizes"],
    &["trubenises"],
];

pub(crate) static ENTRY_TRUBENIZE_1720084137174182623: VariantsMap = [
    &["trubenize"],
    &["trubenise"],
    &["trubenize"],
    &["trubenise"],
];

pub(crate) static ENTRY_TRUBENIZING_6752069478438390648: VariantsMap = [
    &["trubenizing"],
    &["trubenising"],
    &["trubenizing"],
    &["trubenising"],
];

pub(crate) static ENTRY_TRYPSINIZES_9989364682025433845: VariantsMap = [
    &["trypsinizes"],
    &["trypsinises"],
    &["trypsinizes"],
    &["trypsinises"],
];

pub(crate) static ENTRY_TRYPSINIZE_11310311969110258138: VariantsMap = [
    &["trypsinize"],
    &["trypsinise"],
    &["trypsinize"],
    &["trypsinise"],
];

pub(crate) static ENTRY_TSORIS_14425139026522279430: VariantsMap =
    [&["tsoris"], &["tsouris"], &["tsouris"], &["tsouris"]];

pub(crate) static ENTRY_TUBERCULARIZATION_15542666046560010756: VariantsMap = [
    &["tubercularization"],
    &["tubercularisation"],
    &["tubercularization"],
    &["tubercularisation"],
];

pub(crate) static ENTRY_TUBERCULARIZED_12286997214844537953: VariantsMap = [
    &["tubercularized"],
    &["tubercularised"],
    &["tubercularized"],
    &["tubercularised"],
];

pub(crate) static ENTRY_TUBERCULARIZE_2157217058313355699: VariantsMap = [
    &["tubercularize"],
    &["tubercularise"],
    &["tubercularize"],
    &["tubercularise"],
];

pub(crate) static ENTRY_TUBERCULARIZING_3929944679702207874: VariantsMap = [
    &["tubercularizing"],
    &["tubercularising"],
    &["tubercularizing"],
    &["tubercularising"],
];

pub(crate) static ENTRY_TUBERCULINIZATIONS_10141244678936649951: VariantsMap = [
    &["tuberculinizations"],
    &["tuberculinisations"],
    &["tuberculinizations"],
    &["tuberculinisations"],
];

pub(crate) static ENTRY_TUBERCULINIZATION_11797962637301639092: VariantsMap = [
    &["tuberculinization"],
    &["tuberculinisation"],
    &["tuberculinization"],
    &["tuberculinisation"],
];

pub(crate) static ENTRY_TUBERCULINIZED_10816352629411587290: VariantsMap = [
    &["tuberculinized"],
    &["tuberculinised"],
    &["tuberculinized"],
    &["tuberculinised"],
];

pub(crate) static ENTRY_TUBERCULINIZES_13921009254488053820: VariantsMap = [
    &["tuberculinizes"],
    &["tuberculinises"],
    &["tuberculinizes"],
    &["tuberculinises"],
];

pub(crate) static ENTRY_TUBERCULINIZE_15333531702912733903: VariantsMap = [
    &["tuberculinize"],
    &["tuberculinise"],
    &["tuberculinize"],
    &["tuberculinise"],
];

pub(crate) static ENTRY_TUBERCULINIZING_8221476597985863464: VariantsMap = [
    &["tuberculinizing"],
    &["tuberculinising"],
    &["tuberculinizing"],
    &["tuberculinising"],
];

pub(crate) static ENTRY_TUBERCULIZATIONS_14781828629520022038: VariantsMap = [
    &["tuberculizations"],
    &["tuberculisations"],
    &["tuberculizations"],
    &["tuberculisations"],
];

pub(crate) static ENTRY_TUBERCULIZATION_12296149150456268539: VariantsMap = [
    &["tuberculization"],
    &["tuberculisation"],
    &["tuberculization"],
    &["tuberculisation"],
];

pub(crate) static ENTRY_TUBERCULIZED_10329102836270681912: VariantsMap = [
    &["tuberculized"],
    &["tuberculised"],
    &["tuberculized"],
    &["tuberculised"],
];

pub(crate) static ENTRY_TUBERCULIZES_1677879746778356818: VariantsMap = [
    &["tuberculizes"],
    &["tuberculises"],
    &["tuberculizes"],
    &["tuberculises"],
];

pub(crate) static ENTRY_TUBERCULIZE_3450991821098593135: VariantsMap = [
    &["tuberculize"],
    &["tuberculise"],
    &["tuberculize"],
    &["tuberculise"],
];

pub(crate) static ENTRY_TUBERCULIZING_2357271713174376242: VariantsMap = [
    &["tuberculizing"],
    &["tuberculising"],
    &["tuberculizing"],
    &["tuberculising"],
];

pub(crate) static ENTRY_TUBERIZATIONS_215616275751404145: VariantsMap = [
    &["tuberizations"],
    &["tuberisations"],
    &["tuberizations"],
    &["tuberisations"],
];

pub(crate) static ENTRY_TUBERIZATION_10556809563684052487: VariantsMap = [
    &["tuberization"],
    &["tuberisation"],
    &["tuberization"],
    &["tuberisation"],
];

pub(crate) static ENTRY_TUBERIZES_15708878588683938276: VariantsMap = [
    &["tuberizes"],
    &["tuberises"],
    &["tuberizes"],
    &["tuberises"],
];

pub(crate) static ENTRY_TUBERIZE_865480950163325912: VariantsMap =
    [&["tuberize"], &["tuberise"], &["tuberize"], &["tuberise"]];

pub(crate) static ENTRY_TUBULIZATIONS_10015790438190867364: VariantsMap = [
    &["tubulizations"],
    &["tubulisations"],
    &["tubulizations"],
    &["tubulisations"],
];

pub(crate) static ENTRY_TUBULIZATION_12430780901128768431: VariantsMap = [
    &["tubulization"],
    &["tubulisation"],
    &["tubulization"],
    &["tubulisation"],
];

pub(crate) static ENTRY_TULAREMIAS_14187869169219863030: VariantsMap = [
    &["tularemias"],
    &["tularaemias"],
    &["tularemias"],
    &["tularaemias"],
];

pub(crate) static ENTRY_TULAREMIA_111069766982320509: VariantsMap = [
    &["tularemia"],
    &["tularaemia"],
    &["tularemia"],
    &["tularaemia"],
];

pub(crate) static ENTRY_TULAREMIC_7746109038589986442: VariantsMap = [
    &["tularemic"],
    &["tularaemic"],
    &["tularaemic"],
    &["tularaemic"],
];

pub(crate) static ENTRY_TUMORED_9530760269255205454: VariantsMap =
    [&["tumored"], &["tumoured"], &["tumoured"], &["tumoured"]];

pub(crate) static ENTRY_TUMORS_4506585513408357434: VariantsMap =
    [&["tumors"], &["tumours"], &["tumours"], &["tumours"]];

pub(crate) static ENTRY_TUMOR_15198008231736842579: VariantsMap =
    [&["tumor"], &["tumour"], &["tumour"], &["tumour"]];

pub(crate) static ENTRY_TUNNELED_886730683006426004: VariantsMap = [
    &["tunneled"],
    &["tunnelled"],
    &["tunnelled"],
    &["tunnelled"],
];

pub(crate) static ENTRY_TUNNELERS_3199139734449894765: VariantsMap = [
    &["tunnelers"],
    &["tunnellers"],
    &["tunnellers"],
    &["tunnellers"],
];

pub(crate) static ENTRY_TUNNELER_6084737649073030916: VariantsMap = [
    &["tunneler"],
    &["tunneller"],
    &["tunneller"],
    &["tunneller"],
];

pub(crate) static ENTRY_TUNNELINGS_14762533053987563131: VariantsMap = [
    &["tunnelings"],
    &["tunnellings"],
    &["tunnellings"],
    &["tunnellings"],
];

pub(crate) static ENTRY_TUNNELING_155358793735796240: VariantsMap = [
    &["tunneling"],
    &["tunnelling"],
    &["tunnelling"],
    &["tunnelling"],
];

pub(crate) static ENTRY_TURDINE_8495216946259189004: VariantsMap =
    [&["turdine"], &["turdinae"], &["turdinae"], &["turdinae"]];

pub(crate) static ENTRY_TURKICIZED_16551093534484123400: VariantsMap = [
    &["turkicized"],
    &["turkicised"],
    &["turkicized"],
    &["turkicised"],
];

pub(crate) static ENTRY_TURKICIZES_4184526349077657623: VariantsMap = [
    &["turkicizes"],
    &["turkicises"],
    &["turkicizes"],
    &["turkicises"],
];

pub(crate) static ENTRY_TURKICIZE_12952219324449295324: VariantsMap = [
    &["turkicize"],
    &["turkicise"],
    &["turkicize"],
    &["turkicise"],
];

pub(crate) static ENTRY_TURKICIZING_11437686965760445130: VariantsMap = [
    &["turkicizing"],
    &["turkicising"],
    &["turkicizing"],
    &["turkicising"],
];

pub(crate) static ENTRY_TURKIZES_3728749434026795951: VariantsMap =
    [&["turkizes"], &["turkises"], &["turkizes"], &["turkises"]];

pub(crate) static ENTRY_TURKIZE_8515585059262136896: VariantsMap =
    [&["turkize"], &["turkise"], &["turkize"], &["turkise"]];

pub(crate) static ENTRY_TUSCANIZES_9646687590900186948: VariantsMap = [
    &["tuscanizes"],
    &["tuscanises"],
    &["tuscanizes"],
    &["tuscanises"],
];

pub(crate) static ENTRY_TUSCANIZE_7918803889059096084: VariantsMap = [
    &["tuscanize"],
    &["tuscanise"],
    &["tuscanize"],
    &["tuscanise"],
];

pub(crate) static ENTRY_TUTELE_16207284368064157603: VariantsMap =
    [&["tutele"], &["tutelae"], &["tutelae"], &["tutelae"]];

pub(crate) static ENTRY_TUTORIZATIONS_8014516646889352337: VariantsMap = [
    &["tutorizations"],
    &["tutorisations"],
    &["tutorizations"],
    &["tutorisations"],
];

pub(crate) static ENTRY_TUTORIZATION_7186477482613526154: VariantsMap = [
    &["tutorization"],
    &["tutorisation"],
    &["tutorization"],
    &["tutorisation"],
];

pub(crate) static ENTRY_TUTORIZED_14661527617907051055: VariantsMap = [
    &["tutorized"],
    &["tutorised"],
    &["tutorized"],
    &["tutorised"],
];

pub(crate) static ENTRY_TUTORIZES_5000989116733816697: VariantsMap = [
    &["tutorizes"],
    &["tutorises"],
    &["tutorizes"],
    &["tutorises"],
];

pub(crate) static ENTRY_TUTORIZE_5415313587641112365: VariantsMap =
    [&["tutorize"], &["tutorise"], &["tutorize"], &["tutorise"]];

pub(crate) static ENTRY_TUTORIZING_17098833328892189609: VariantsMap = [
    &["tutorizing"],
    &["tutorising"],
    &["tutorizing"],
    &["tutorising"],
];

pub(crate) static ENTRY_TWIERS_466316859651799693: VariantsMap =
    [&["twiers"], &["twires"], &["twires"], &["twires"]];

pub(crate) static ENTRY_TWIER_17943274413772224375: VariantsMap =
    [&["twier"], &["twire"], &["twire"], &["twire"]];

pub(crate) static ENTRY_TYLERIZES_3930431350093885314: VariantsMap = [
    &["tylerizes"],
    &["tylerises"],
    &["tylerizes"],
    &["tylerises"],
];

pub(crate) static ENTRY_TYLERIZE_6772047772391841205: VariantsMap =
    [&["tylerize"], &["tylerise"], &["tylerize"], &["tylerise"]];

pub(crate) static ENTRY_TYPHEMIA_3949405273592839759: VariantsMap = [
    &["typhemia"],
    &["typhaemia"],
    &["typhaemia"],
    &["typhaemia"],
];

pub(crate) static ENTRY_TYPHEMIA_436328357437921093: VariantsMap = [
    &["typhemia"],
    &["typhoemia"],
    &["typhoemia"],
    &["typhoemia"],
];

pub(crate) static ENTRY_TYPHLENTERITIS_16701047769348734014: VariantsMap = [
    &["typhlenteritis"],
    &["typhloenteritis"],
    &["typhloenteritis"],
    &["typhloenteritis"],
];

pub(crate) static ENTRY_TYPHOEMIA_16341888230675161250: VariantsMap = [
    &["typhoemia"],
    &["typhoaemia"],
    &["typhoaemia"],
    &["typhoaemia"],
];

pub(crate) static ENTRY_TYRANNIZED_1941892499943366434: VariantsMap = [
    &["tyrannized"],
    &["tyrannised"],
    &["tyrannized"],
    &["tyrannised"],
];

pub(crate) static ENTRY_TYRANNIZERS_13060284352391993246: VariantsMap = [
    &["tyrannizers"],
    &["tyrannisers"],
    &["tyrannizers"],
    &["tyrannisers"],
];

pub(crate) static ENTRY_TYRANNIZER_1371535188483909389: VariantsMap = [
    &["tyrannizer"],
    &["tyranniser"],
    &["tyrannizer"],
    &["tyranniser"],
];

pub(crate) static ENTRY_TYRANNIZES_10925886797003891936: VariantsMap = [
    &["tyrannizes"],
    &["tyrannises"],
    &["tyrannizes"],
    &["tyrannises"],
];

pub(crate) static ENTRY_TYRANNIZE_402218976726854223: VariantsMap = [
    &["tyrannize"],
    &["tyrannise"],
    &["tyrannize"],
    &["tyrannise"],
];

pub(crate) static ENTRY_TYRANNIZINGLIER_7411912687837897273: VariantsMap = [
    &["tyrannizinglier"],
    &["tyrannisinglier"],
    &["tyrannizinglier"],
    &["tyrannisinglier"],
];

pub(crate) static ENTRY_TYRANNIZINGLIEST_13299239458699844336: VariantsMap = [
    &["tyrannizingliest"],
    &["tyrannisingliest"],
    &["tyrannizingliest"],
    &["tyrannisingliest"],
];

pub(crate) static ENTRY_TYRANNIZINGLY_387905432645898165: VariantsMap = [
    &["tyrannizingly"],
    &["tyrannisingly"],
    &["tyrannizingly"],
    &["tyrannisingly"],
];

pub(crate) static ENTRY_TYRANNIZINGS_8912279495006406317: VariantsMap = [
    &["tyrannizings"],
    &["tyrannisings"],
    &["tyrannizings"],
    &["tyrannisings"],
];

pub(crate) static ENTRY_TYRANNIZING_18363984835873871108: VariantsMap = [
    &["tyrannizing"],
    &["tyrannising"],
    &["tyrannizing"],
    &["tyrannising"],
];

pub(crate) static ENTRY_TYROS_4063138644213636346: VariantsMap =
    [&["tyros"], &["tyros"], &["tyros"], &["tyros"]];

pub(crate) static ENTRY_TYRO_1396628122702945602: VariantsMap =
    [&["tyro"], &["tyro"], &["tyro"], &["tyro"]];

pub(crate) static ENTRY_ULTRACENTRALIZERS_15801856694895216516: VariantsMap = [
    &["ultracentralizers"],
    &["ultracentralisers"],
    &["ultracentralizers"],
    &["ultracentralisers"],
];

pub(crate) static ENTRY_ULTRACENTRALIZER_1386087884281857470: VariantsMap = [
    &["ultracentralizer"],
    &["ultracentraliser"],
    &["ultracentralizer"],
    &["ultracentraliser"],
];

pub(crate) static ENTRY_ULTRAHONORABLES_9342789915681610564: VariantsMap = [
    &["ultrahonorables"],
    &["ultrahonourables"],
    &["ultrahonourables"],
    &["ultrahonourables"],
];

pub(crate) static ENTRY_ULTRAHONORABLE_17802324312727593194: VariantsMap = [
    &["ultrahonorable"],
    &["ultrahonourable"],
    &["ultrahonourable"],
    &["ultrahonourable"],
];

pub(crate) static ENTRY_ULTRASPECIALIZATIONS_14936216708962453732: VariantsMap = [
    &["ultraspecializations"],
    &["ultraspecialisations"],
    &["ultraspecializations"],
    &["ultraspecialisations"],
];

pub(crate) static ENTRY_ULTRASPECIALIZATION_14780888503862218576: VariantsMap = [
    &["ultraspecialization"],
    &["ultraspecialisation"],
    &["ultraspecialization"],
    &["ultraspecialisation"],
];

pub(crate) static ENTRY_ULTRASTANDARDIZATIONS_12958573872619861416: VariantsMap = [
    &["ultrastandardizations"],
    &["ultrastandardisations"],
    &["ultrastandardizations"],
    &["ultrastandardisations"],
];

pub(crate) static ENTRY_ULTRASTANDARDIZATION_7616606161431137542: VariantsMap = [
    &["ultrastandardization"],
    &["ultrastandardisation"],
    &["ultrastandardization"],
    &["ultrastandardisation"],
];

pub(crate) static ENTRY_UNACCLIMATIZED_1969571864517774602: VariantsMap = [
    &["unacclimatized"],
    &["unacclimatised"],
    &["unacclimatized"],
    &["unacclimatised"],
];

pub(crate) static ENTRY_UNAGONIZE_6084501682979547918: VariantsMap = [
    &["unagonize"],
    &["unagonise"],
    &["unagonize"],
    &["unagonise"],
];

pub(crate) static ENTRY_UNALCOHOLIZEDDER_7254338354970976974: VariantsMap = [
    &["unalcoholizedder"],
    &["unalcoholisedder"],
    &["unalcoholizedder"],
    &["unalcoholisedder"],
];

pub(crate) static ENTRY_UNALCOHOLIZEDDEST_3929868538999714538: VariantsMap = [
    &["unalcoholizeddest"],
    &["unalcoholiseddest"],
    &["unalcoholizeddest"],
    &["unalcoholiseddest"],
];

pub(crate) static ENTRY_UNALCOHOLIZEDS_3779587450961636557: VariantsMap = [
    &["unalcoholizeds"],
    &["unalcoholiseds"],
    &["unalcoholizeds"],
    &["unalcoholiseds"],
];

pub(crate) static ENTRY_UNALCOHOLIZED_12462545574552694750: VariantsMap = [
    &["unalcoholized"],
    &["unalcoholised"],
    &["unalcoholized"],
    &["unalcoholised"],
];

pub(crate) static ENTRY_UNALPHABETIZED_785154054192050580: VariantsMap = [
    &["unalphabetized"],
    &["unalphabetised"],
    &["unalphabetized"],
    &["unalphabetised"],
];

pub(crate) static ENTRY_UNAMORTIZATIONS_11801391438115116167: VariantsMap = [
    &["unamortizations"],
    &["unamortisations"],
    &["unamortizations"],
    &["unamortisations"],
];

pub(crate) static ENTRY_UNAMORTIZATION_12146076887735696880: VariantsMap = [
    &["unamortization"],
    &["unamortisation"],
    &["unamortization"],
    &["unamortisation"],
];

pub(crate) static ENTRY_UNAMORTIZED_13451896776472967546: VariantsMap = [
    &["unamortized"],
    &["unamortised"],
    &["unamortized"],
    &["unamortised"],
];

pub(crate) static ENTRY_UNANALYZABLE_10015139257021178435: VariantsMap = [
    &["unanalyzable"],
    &["unanalysable"],
    &["unanalyzable"],
    &["unanalysable"],
];

pub(crate) static ENTRY_UNANALYZED_16500188544214906359: VariantsMap = [
    &["unanalyzed"],
    &["unanalysed"],
    &["unanalyzed"],
    &["unanalysed"],
];

pub(crate) static ENTRY_UNANATOMIZABLE_12621927696529831665: VariantsMap = [
    &["unanatomizable"],
    &["unanatomisable"],
    &["unanatomizable"],
    &["unanatomisable"],
];

pub(crate) static ENTRY_UNANATOMIZED_6061766559393631360: VariantsMap = [
    &["unanatomized"],
    &["unanatomised"],
    &["unanatomized"],
    &["unanatomised"],
];

pub(crate) static ENTRY_UNANEMIC_6804040153460031597: VariantsMap = [
    &["unanemic"],
    &["unanaemic"],
    &["unanaemic"],
    &["unanaemic"],
];

pub(crate) static ENTRY_UNANIMALIZEDS_12083863725694904084: VariantsMap = [
    &["unanimalizeds"],
    &["unanimaliseds"],
    &["unanimalizeds"],
    &["unanimaliseds"],
];

pub(crate) static ENTRY_UNANIMALIZED_2409683454989613456: VariantsMap = [
    &["unanimalized"],
    &["unanimalised"],
    &["unanimalized"],
    &["unanimalised"],
];

pub(crate) static ENTRY_UNANTAGONIZABLER_341535602186309075: VariantsMap = [
    &["unantagonizabler"],
    &["unantagonisabler"],
    &["unantagonizabler"],
    &["unantagonisabler"],
];

pub(crate) static ENTRY_UNANTAGONIZABLEST_17345953185101673573: VariantsMap = [
    &["unantagonizablest"],
    &["unantagonisablest"],
    &["unantagonizablest"],
    &["unantagonisablest"],
];

pub(crate) static ENTRY_UNANTAGONIZABLES_2731043692553771550: VariantsMap = [
    &["unantagonizables"],
    &["unantagonisables"],
    &["unantagonizables"],
    &["unantagonisables"],
];

pub(crate) static ENTRY_UNANTAGONIZABLE_8940938838594676762: VariantsMap = [
    &["unantagonizable"],
    &["unantagonisable"],
    &["unantagonizable"],
    &["unantagonisable"],
];

pub(crate) static ENTRY_UNANTAGONIZEDDER_17407737658502114220: VariantsMap = [
    &["unantagonizedder"],
    &["unantagonisedder"],
    &["unantagonizedder"],
    &["unantagonisedder"],
];

pub(crate) static ENTRY_UNANTAGONIZEDDEST_15019402780215712074: VariantsMap = [
    &["unantagonizeddest"],
    &["unantagoniseddest"],
    &["unantagonizeddest"],
    &["unantagoniseddest"],
];

pub(crate) static ENTRY_UNANTAGONIZED_3298227429647689925: VariantsMap = [
    &["unantagonized"],
    &["unantagonised"],
    &["unantagonized"],
    &["unantagonised"],
];

pub(crate) static ENTRY_UNANTAGONIZINGER_15671658988108179272: VariantsMap = [
    &["unantagonizinger"],
    &["unantagonisinger"],
    &["unantagonizinger"],
    &["unantagonisinger"],
];

pub(crate) static ENTRY_UNANTAGONIZINGEST_5785945012122373004: VariantsMap = [
    &["unantagonizingest"],
    &["unantagonisingest"],
    &["unantagonizingest"],
    &["unantagonisingest"],
];

pub(crate) static ENTRY_UNANTAGONIZING_3465462232208147407: VariantsMap = [
    &["unantagonizing"],
    &["unantagonising"],
    &["unantagonizing"],
    &["unantagonising"],
];

pub(crate) static ENTRY_UNAPOLOGIZING_8820499902965244314: VariantsMap = [
    &["unapologizing"],
    &["unapologising"],
    &["unapologizing"],
    &["unapologising"],
];

pub(crate) static ENTRY_UNAPOSTATIZEDS_14669408928414139662: VariantsMap = [
    &["unapostatizeds"],
    &["unapostatiseds"],
    &["unapostatizeds"],
    &["unapostatiseds"],
];

pub(crate) static ENTRY_UNAPOSTATIZED_8707752890756536689: VariantsMap = [
    &["unapostatized"],
    &["unapostatised"],
    &["unapostatized"],
    &["unapostatised"],
];

pub(crate) static ENTRY_UNAPPETIZINGER_11663943688244312711: VariantsMap = [
    &["unappetizinger"],
    &["unappetisinger"],
    &["unappetizinger"],
    &["unappetisinger"],
];

pub(crate) static ENTRY_UNAPPETIZINGEST_15811327206418622113: VariantsMap = [
    &["unappetizingest"],
    &["unappetisingest"],
    &["unappetizingest"],
    &["unappetisingest"],
];

pub(crate) static ENTRY_UNAPPETIZINGLIER_5194460014263105886: VariantsMap = [
    &["unappetizinglier"],
    &["unappetisinglier"],
    &["unappetizinglier"],
    &["unappetisinglier"],
];

pub(crate) static ENTRY_UNAPPETIZINGLIEST_13095442457868536397: VariantsMap = [
    &["unappetizingliest"],
    &["unappetisingliest"],
    &["unappetizingliest"],
    &["unappetisingliest"],
];

pub(crate) static ENTRY_UNAPPETIZINGLY_4396083271756728101: VariantsMap = [
    &["unappetizingly"],
    &["unappetisingly"],
    &["unappetizingly"],
    &["unappetisingly"],
];

pub(crate) static ENTRY_UNAPPETIZING_12749343422231568734: VariantsMap = [
    &["unappetizing"],
    &["unappetising"],
    &["unappetizing"],
    &["unappetising"],
];

pub(crate) static ENTRY_UNAPPRIZED_6119477476012909356: VariantsMap = [
    &["unapprized"],
    &["unapprised"],
    &["unapprized"],
    &["unapprised"],
];

pub(crate) static ENTRY_UNARBORED_10962513521010356596: VariantsMap = [
    &["unarbored"],
    &["unarboured"],
    &["unarboured"],
    &["unarboured"],
];

pub(crate) static ENTRY_UNARMOREDDER_4175485372914136238: VariantsMap = [
    &["unarmoredder"],
    &["unarmouredder"],
    &["unarmouredder"],
    &["unarmouredder"],
];

pub(crate) static ENTRY_UNARMOREDDEST_3012270770178515043: VariantsMap = [
    &["unarmoreddest"],
    &["unarmoureddest"],
    &["unarmoureddest"],
    &["unarmoureddest"],
];

pub(crate) static ENTRY_UNARMORED_4540020611443646355: VariantsMap = [
    &["unarmored"],
    &["unarmoured"],
    &["unarmoured"],
    &["unarmoured"],
];

pub(crate) static ENTRY_UNAUTHORIZEDDER_4146956705318297921: VariantsMap = [
    &["unauthorizedder"],
    &["unauthorisedder"],
    &["unauthorizedder"],
    &["unauthorisedder"],
];

pub(crate) static ENTRY_UNAUTHORIZEDDEST_5230199240119912096: VariantsMap = [
    &["unauthorizeddest"],
    &["unauthoriseddest"],
    &["unauthorizeddest"],
    &["unauthoriseddest"],
];

pub(crate) static ENTRY_UNAUTHORIZEDLY_1756944536540360350: VariantsMap = [
    &["unauthorizedly"],
    &["unauthorisedly"],
    &["unauthorizedly"],
    &["unauthorisedly"],
];

pub(crate) static ENTRY_UNAUTHORIZEDNESS_13848901931254124796: VariantsMap = [
    &["unauthorizedness"],
    &["unauthorisedness"],
    &["unauthorizedness"],
    &["unauthorisedness"],
];

pub(crate) static ENTRY_UNAUTHORIZED_18330969128189680958: VariantsMap = [
    &["unauthorized"],
    &["unauthorised"],
    &["unauthorized"],
    &["unauthorised"],
];

pub(crate) static ENTRY_UNAUTHORIZES_15223481987545098919: VariantsMap = [
    &["unauthorizes"],
    &["unauthorises"],
    &["unauthorizes"],
    &["unauthorises"],
];

pub(crate) static ENTRY_UNAUTHORIZE_17373059611637260636: VariantsMap = [
    &["unauthorize"],
    &["unauthorise"],
    &["unauthorize"],
    &["unauthorise"],
];

pub(crate) static ENTRY_UNBAPTIZED_2750609897609115804: VariantsMap = [
    &["unbaptized"],
    &["unbaptised"],
    &["unbaptized"],
    &["unbaptised"],
];

pub(crate) static ENTRY_UNBAPTIZES_5860001137786586819: VariantsMap = [
    &["unbaptizes"],
    &["unbaptises"],
    &["unbaptizes"],
    &["unbaptises"],
];

pub(crate) static ENTRY_UNBAPTIZE_18045749488616509181: VariantsMap = [
    &["unbaptize"],
    &["unbaptise"],
    &["unbaptize"],
    &["unbaptise"],
];

pub(crate) static ENTRY_UNBAPTIZING_369890182023136394: VariantsMap = [
    &["unbaptizing"],
    &["unbaptising"],
    &["unbaptizing"],
    &["unbaptising"],
];

pub(crate) static ENTRY_UNBARBARIZED_4163251566640502972: VariantsMap = [
    &["unbarbarized"],
    &["unbarbarised"],
    &["unbarbarized"],
    &["unbarbarised"],
];

pub(crate) static ENTRY_UNBARBARIZE_85759814966596838: VariantsMap = [
    &["unbarbarize"],
    &["unbarbarise"],
    &["unbarbarize"],
    &["unbarbarise"],
];

pub(crate) static ENTRY_UNBARBARIZING_10525570028182827286: VariantsMap = [
    &["unbarbarizing"],
    &["unbarbarising"],
    &["unbarbarizing"],
    &["unbarbarising"],
];

pub(crate) static ENTRY_UNBARRICADED_12195279117302305039: VariantsMap = [
    &["unbarricaded"],
    &["unbarricadoed"],
    &["unbarricadoed"],
    &["unbarricadoed"],
];

pub(crate) static ENTRY_UNBASTARDIZEDDER_6714666111533384003: VariantsMap = [
    &["unbastardizedder"],
    &["unbastardisedder"],
    &["unbastardizedder"],
    &["unbastardisedder"],
];

pub(crate) static ENTRY_UNBASTARDIZEDDEST_5748524649962490826: VariantsMap = [
    &["unbastardizeddest"],
    &["unbastardiseddest"],
    &["unbastardizeddest"],
    &["unbastardiseddest"],
];

pub(crate) static ENTRY_UNBASTARDIZED_13342112361958904470: VariantsMap = [
    &["unbastardized"],
    &["unbastardised"],
    &["unbastardized"],
    &["unbastardised"],
];

pub(crate) static ENTRY_UNBRUTALIZED_6338937456842490293: VariantsMap = [
    &["unbrutalized"],
    &["unbrutalised"],
    &["unbrutalized"],
    &["unbrutalised"],
];

pub(crate) static ENTRY_UNBRUTALIZES_4127817782461372270: VariantsMap = [
    &["unbrutalizes"],
    &["unbrutalises"],
    &["unbrutalizes"],
    &["unbrutalises"],
];

pub(crate) static ENTRY_UNBRUTALIZE_18223840863792260272: VariantsMap = [
    &["unbrutalize"],
    &["unbrutalise"],
    &["unbrutalize"],
    &["unbrutalise"],
];

pub(crate) static ENTRY_UNBRUTALIZING_12933117214333059837: VariantsMap = [
    &["unbrutalizing"],
    &["unbrutalising"],
    &["unbrutalizing"],
    &["unbrutalising"],
];

pub(crate) static ENTRY_UNBRUTIZED_18292720994739659985: VariantsMap = [
    &["unbrutized"],
    &["unbrutised"],
    &["unbrutized"],
    &["unbrutised"],
];

pub(crate) static ENTRY_UNBRUTIZES_12365008004715490849: VariantsMap = [
    &["unbrutizes"],
    &["unbrutises"],
    &["unbrutizes"],
    &["unbrutises"],
];

pub(crate) static ENTRY_UNBRUTIZE_10482956505266389513: VariantsMap = [
    &["unbrutize"],
    &["unbrutise"],
    &["unbrutize"],
    &["unbrutise"],
];

pub(crate) static ENTRY_UNBRUTIZING_8068018278771694293: VariantsMap = [
    &["unbrutizing"],
    &["unbrutising"],
    &["unbrutizing"],
    &["unbrutising"],
];

pub(crate) static ENTRY_UNCANCELEDDER_846969059949847342: VariantsMap = [
    &["uncanceledder"],
    &["uncancelledder"],
    &["uncancelledder"],
    &["uncancelledder"],
];

pub(crate) static ENTRY_UNCANCELEDDEST_16688600251952129306: VariantsMap = [
    &["uncanceleddest"],
    &["uncancelleddest"],
    &["uncancelleddest"],
    &["uncancelleddest"],
];

pub(crate) static ENTRY_UNCANCELED_14881575187258887119: VariantsMap = [
    &["uncanceled"],
    &["uncancelled"],
    &["uncancelled"],
    &["uncancelled"],
];

pub(crate) static ENTRY_UNCANDOR_1117487908276698433: VariantsMap = [
    &["uncandor"],
    &["uncandour"],
    &["uncandour"],
    &["uncandour"],
];

pub(crate) static ENTRY_UNCANONIZATION_17424198936114457720: VariantsMap = [
    &["uncanonization"],
    &["uncanonisation"],
    &["uncanonization"],
    &["uncanonisation"],
];

pub(crate) static ENTRY_UNCANONIZED_5538989722513762511: VariantsMap = [
    &["uncanonized"],
    &["uncanonised"],
    &["uncanonized"],
    &["uncanonised"],
];

pub(crate) static ENTRY_UNCANONIZES_12153715475418673041: VariantsMap = [
    &["uncanonizes"],
    &["uncanonises"],
    &["uncanonizes"],
    &["uncanonises"],
];

pub(crate) static ENTRY_UNCANONIZE_8078618209055157420: VariantsMap = [
    &["uncanonize"],
    &["uncanonise"],
    &["uncanonize"],
    &["uncanonise"],
];

pub(crate) static ENTRY_UNCANONIZING_3397483964901532622: VariantsMap = [
    &["uncanonizing"],
    &["uncanonising"],
    &["uncanonizing"],
    &["uncanonising"],
];

pub(crate) static ENTRY_UNCANTONIZEDS_8748104113894653041: VariantsMap = [
    &["uncantonizeds"],
    &["uncantoniseds"],
    &["uncantonizeds"],
    &["uncantoniseds"],
];

pub(crate) static ENTRY_UNCANTONIZED_13456997538693547290: VariantsMap = [
    &["uncantonized"],
    &["uncantonised"],
    &["uncantonized"],
    &["uncantonised"],
];

pub(crate) static ENTRY_UNCAPITALIZEDDER_11516986249977719685: VariantsMap = [
    &["uncapitalizedder"],
    &["uncapitalisedder"],
    &["uncapitalizedder"],
    &["uncapitalisedder"],
];

pub(crate) static ENTRY_UNCAPITALIZEDDEST_3372925540955398768: VariantsMap = [
    &["uncapitalizeddest"],
    &["uncapitaliseddest"],
    &["uncapitalizeddest"],
    &["uncapitaliseddest"],
];

pub(crate) static ENTRY_UNCAPITALIZED_15771287396524776391: VariantsMap = [
    &["uncapitalized"],
    &["uncapitalised"],
    &["uncapitalized"],
    &["uncapitalised"],
];

pub(crate) static ENTRY_UNCARAMELIZED_14866858801643238047: VariantsMap = [
    &["uncaramelized"],
    &["uncaramelised"],
    &["uncaramelized"],
    &["uncaramelised"],
];

pub(crate) static ENTRY_UNCATECHIZEDNESS_15422372585260862674: VariantsMap = [
    &["uncatechizedness"],
    &["uncatechisedness"],
    &["uncatechizedness"],
    &["uncatechisedness"],
];

pub(crate) static ENTRY_UNCATECHIZEDS_13859045064739112709: VariantsMap = [
    &["uncatechizeds"],
    &["uncatechiseds"],
    &["uncatechizeds"],
    &["uncatechiseds"],
];

pub(crate) static ENTRY_UNCATECHIZED_12604807844777819037: VariantsMap = [
    &["uncatechized"],
    &["uncatechised"],
    &["uncatechized"],
    &["uncatechised"],
];

pub(crate) static ENTRY_UNCATEGORIZEDDER_15434842518722062137: VariantsMap = [
    &["uncategorizedder"],
    &["uncategorisedder"],
    &["uncategorizedder"],
    &["uncategorisedder"],
];

pub(crate) static ENTRY_UNCATEGORIZEDDEST_1757102059002802404: VariantsMap = [
    &["uncategorizeddest"],
    &["uncategoriseddest"],
    &["uncategorizeddest"],
    &["uncategoriseddest"],
];

pub(crate) static ENTRY_UNCATEGORIZED_12671663981711527617: VariantsMap = [
    &["uncategorized"],
    &["uncategorised"],
    &["uncategorized"],
    &["uncategorised"],
];

pub(crate) static ENTRY_UNCATHOLICIZED_17722391494998523342: VariantsMap = [
    &["uncatholicized"],
    &["uncatholicised"],
    &["uncatholicized"],
    &["uncatholicised"],
];

pub(crate) static ENTRY_UNCATHOLICIZES_8958496403317373578: VariantsMap = [
    &["uncatholicizes"],
    &["uncatholicises"],
    &["uncatholicizes"],
    &["uncatholicises"],
];

pub(crate) static ENTRY_UNCATHOLICIZE_8425737943401304561: VariantsMap = [
    &["uncatholicize"],
    &["uncatholicise"],
    &["uncatholicize"],
    &["uncatholicise"],
];

pub(crate) static ENTRY_UNCATHOLICIZING_9453674520447775815: VariantsMap = [
    &["uncatholicizing"],
    &["uncatholicising"],
    &["uncatholicizing"],
    &["uncatholicising"],
];

pub(crate) static ENTRY_UNCAUTERIZEDS_10677799308952420016: VariantsMap = [
    &["uncauterizeds"],
    &["uncauteriseds"],
    &["uncauterizeds"],
    &["uncauteriseds"],
];

pub(crate) static ENTRY_UNCAUTERIZED_13512404213504423195: VariantsMap = [
    &["uncauterized"],
    &["uncauterised"],
    &["uncauterized"],
    &["uncauterised"],
];

pub(crate) static ENTRY_UNCELESTIALIZEDS_2449557772093094129: VariantsMap = [
    &["uncelestializeds"],
    &["uncelestialiseds"],
    &["uncelestializeds"],
    &["uncelestialiseds"],
];

pub(crate) static ENTRY_UNCELESTIALIZED_17943151837268803496: VariantsMap = [
    &["uncelestialized"],
    &["uncelestialised"],
    &["uncelestialized"],
    &["uncelestialised"],
];

pub(crate) static ENTRY_UNCENTER_15807123308053109883: VariantsMap =
    [&["uncenter"], &["uncentre"], &["uncentre"], &["uncentre"]];

pub(crate) static ENTRY_UNCENTRALIZED_3375219947813958573: VariantsMap = [
    &["uncentralized"],
    &["uncentralised"],
    &["uncentralized"],
    &["uncentralised"],
];

pub(crate) static ENTRY_UNCHARACTERIZEDDER_9630905361449944494: VariantsMap = [
    &["uncharacterizedder"],
    &["uncharacterisedder"],
    &["uncharacterizedder"],
    &["uncharacterisedder"],
];

pub(crate) static ENTRY_UNCHARACTERIZEDDEST_12996144895873850714: VariantsMap = [
    &["uncharacterizeddest"],
    &["uncharacteriseddest"],
    &["uncharacterizeddest"],
    &["uncharacteriseddest"],
];

pub(crate) static ENTRY_UNCHARACTERIZED_16956353213909858293: VariantsMap = [
    &["uncharacterized"],
    &["uncharacterised"],
    &["uncharacterized"],
    &["uncharacterised"],
];

pub(crate) static ENTRY_UNCHASTIZABLE_9875729189061084670: VariantsMap = [
    &["unchastizable"],
    &["unchastisable"],
    &["unchastizable"],
    &["unchastisable"],
];

pub(crate) static ENTRY_UNCHASTIZED_4193981014376295283: VariantsMap = [
    &["unchastized"],
    &["unchastised"],
    &["unchastized"],
    &["unchastised"],
];

pub(crate) static ENTRY_UNCHLORIDIZEDS_14218178409370978541: VariantsMap = [
    &["unchloridizeds"],
    &["unchloridiseds"],
    &["unchloridizeds"],
    &["unchloridiseds"],
];

pub(crate) static ENTRY_UNCHLORIDIZED_16671439068894580937: VariantsMap = [
    &["unchloridized"],
    &["unchloridised"],
    &["unchloridized"],
    &["unchloridised"],
];

pub(crate) static ENTRY_UNCHRISTIANIZED_13080855627488192760: VariantsMap = [
    &["unchristianized"],
    &["unchristianised"],
    &["unchristianized"],
    &["unchristianised"],
];

pub(crate) static ENTRY_UNCHRISTIANIZES_9247340614604210077: VariantsMap = [
    &["unchristianizes"],
    &["unchristianises"],
    &["unchristianizes"],
    &["unchristianises"],
];

pub(crate) static ENTRY_UNCHRISTIANIZE_60148917993740076: VariantsMap = [
    &["unchristianize"],
    &["unchristianise"],
    &["unchristianize"],
    &["unchristianise"],
];

pub(crate) static ENTRY_UNCHRISTIANIZING_16239590731316126727: VariantsMap = [
    &["unchristianizing"],
    &["unchristianising"],
    &["unchristianizing"],
    &["unchristianising"],
];

pub(crate) static ENTRY_UNCIRCULARIZEDDER_13401377351716086368: VariantsMap = [
    &["uncircularizedder"],
    &["uncircularisedder"],
    &["uncircularizedder"],
    &["uncircularisedder"],
];

pub(crate) static ENTRY_UNCIRCULARIZEDDEST_9951597685170363487: VariantsMap = [
    &["uncircularizeddest"],
    &["uncirculariseddest"],
    &["uncircularizeddest"],
    &["uncirculariseddest"],
];

pub(crate) static ENTRY_UNCIRCULARIZEDS_1250844431562273063: VariantsMap = [
    &["uncircularizeds"],
    &["uncirculariseds"],
    &["uncircularizeds"],
    &["uncirculariseds"],
];

pub(crate) static ENTRY_UNCIRCULARIZED_1673876733486569108: VariantsMap = [
    &["uncircularized"],
    &["uncircularised"],
    &["uncircularized"],
    &["uncircularised"],
];

pub(crate) static ENTRY_UNCIVILIZABLER_5349352586984667487: VariantsMap = [
    &["uncivilizabler"],
    &["uncivilisabler"],
    &["uncivilizabler"],
    &["uncivilisabler"],
];

pub(crate) static ENTRY_UNCIVILIZABLEST_7329790362151161087: VariantsMap = [
    &["uncivilizablest"],
    &["uncivilisablest"],
    &["uncivilizablest"],
    &["uncivilisablest"],
];

pub(crate) static ENTRY_UNCIVILIZABLES_5534726098220309871: VariantsMap = [
    &["uncivilizables"],
    &["uncivilisables"],
    &["uncivilizables"],
    &["uncivilisables"],
];

pub(crate) static ENTRY_UNCIVILIZABLE_5359864439117880170: VariantsMap = [
    &["uncivilizable"],
    &["uncivilisable"],
    &["uncivilizable"],
    &["uncivilisable"],
];

pub(crate) static ENTRY_UNCIVILIZEDLY_13183249970870160815: VariantsMap = [
    &["uncivilizedly"],
    &["uncivilisedly"],
    &["uncivilizedly"],
    &["uncivilisedly"],
];

pub(crate) static ENTRY_UNCIVILIZEDNESS_13286745087730550691: VariantsMap = [
    &["uncivilizedness"],
    &["uncivilisedness"],
    &["uncivilizedness"],
    &["uncivilisedness"],
];

pub(crate) static ENTRY_UNCIVILIZED_7166539918987564819: VariantsMap = [
    &["uncivilized"],
    &["uncivilised"],
    &["uncivilized"],
    &["uncivilised"],
];

pub(crate) static ENTRY_UNCIVILIZES_4114315705302110845: VariantsMap = [
    &["uncivilizes"],
    &["uncivilises"],
    &["uncivilizes"],
    &["uncivilises"],
];

pub(crate) static ENTRY_UNCIVILIZE_16379895937239654425: VariantsMap = [
    &["uncivilize"],
    &["uncivilise"],
    &["uncivilize"],
    &["uncivilise"],
];

pub(crate) static ENTRY_UNCLERICALIZES_8000982562629252294: VariantsMap = [
    &["unclericalizes"],
    &["unclericalises"],
    &["unclericalizes"],
    &["unclericalises"],
];

pub(crate) static ENTRY_UNCLERICALIZE_5058403399765937609: VariantsMap = [
    &["unclericalize"],
    &["unclericalise"],
    &["unclericalize"],
    &["unclericalise"],
];

pub(crate) static ENTRY_UNCOGNIZABLE_8427011542426523053: VariantsMap = [
    &["uncognizable"],
    &["uncognisable"],
    &["uncognizable"],
    &["uncognisable"],
];

pub(crate) static ENTRY_UNCOLONIZED_14464259688836318286: VariantsMap = [
    &["uncolonized"],
    &["uncolonised"],
    &["uncolonized"],
    &["uncolonised"],
];

pub(crate) static ENTRY_UNCOLONIZES_9719326327721062003: VariantsMap = [
    &["uncolonizes"],
    &["uncolonises"],
    &["uncolonizes"],
    &["uncolonises"],
];

pub(crate) static ENTRY_UNCOLONIZE_4719662676234790116: VariantsMap = [
    &["uncolonize"],
    &["uncolonise"],
    &["uncolonize"],
    &["uncolonise"],
];

pub(crate) static ENTRY_UNCOLONIZING_15664887216370082580: VariantsMap = [
    &["uncolonizing"],
    &["uncolonising"],
    &["uncolonizing"],
    &["uncolonising"],
];

pub(crate) static ENTRY_UNCOLORABLER_1677263340221600893: VariantsMap = [
    &["uncolorabler"],
    &["uncolourabler"],
    &["uncolourabler"],
    &["uncolourabler"],
];

pub(crate) static ENTRY_UNCOLORABLEST_7640890717461053308: VariantsMap = [
    &["uncolorablest"],
    &["uncolourablest"],
    &["uncolourablest"],
    &["uncolourablest"],
];

pub(crate) static ENTRY_UNCOLORABLES_3510625143099969360: VariantsMap = [
    &["uncolorables"],
    &["uncolourables"],
    &["uncolourables"],
    &["uncolourables"],
];

pub(crate) static ENTRY_UNCOLORABLE_16859002938981914415: VariantsMap = [
    &["uncolorable"],
    &["uncolourable"],
    &["uncolourable"],
    &["uncolourable"],
];

pub(crate) static ENTRY_UNCOLORABLIER_15894133128738876679: VariantsMap = [
    &["uncolorablier"],
    &["uncolourablier"],
    &["uncolourablier"],
    &["uncolourablier"],
];

pub(crate) static ENTRY_UNCOLORABLIEST_11422798475250273761: VariantsMap = [
    &["uncolorabliest"],
    &["uncolourabliest"],
    &["uncolourabliest"],
    &["uncolourabliest"],
];

pub(crate) static ENTRY_UNCOLORABLIES_11097679658499545820: VariantsMap = [
    &["uncolorablies"],
    &["uncolourablies"],
    &["uncolourablies"],
    &["uncolourablies"],
];

pub(crate) static ENTRY_UNCOLORABLY_6941577112469631446: VariantsMap = [
    &["uncolorably"],
    &["uncolourably"],
    &["uncolourably"],
    &["uncolourably"],
];

pub(crate) static ENTRY_UNCOLOREDDER_44322368202115976: VariantsMap = [
    &["uncoloredder"],
    &["uncolouredder"],
    &["uncolouredder"],
    &["uncolouredder"],
];

pub(crate) static ENTRY_UNCOLOREDDEST_15878875459057574341: VariantsMap = [
    &["uncoloreddest"],
    &["uncoloureddest"],
    &["uncoloureddest"],
    &["uncoloureddest"],
];

pub(crate) static ENTRY_UNCOLOREDLIER_6703103262670401501: VariantsMap = [
    &["uncoloredlier"],
    &["uncolouredlier"],
    &["uncolouredlier"],
    &["uncolouredlier"],
];

pub(crate) static ENTRY_UNCOLOREDLIEST_12675741818469230732: VariantsMap = [
    &["uncoloredliest"],
    &["uncolouredliest"],
    &["uncolouredliest"],
    &["uncolouredliest"],
];

pub(crate) static ENTRY_UNCOLOREDLY_16713739233776863755: VariantsMap = [
    &["uncoloredly"],
    &["uncolouredly"],
    &["uncolouredly"],
    &["uncolouredly"],
];

pub(crate) static ENTRY_UNCOLOREDNESSES_7712224291050878796: VariantsMap = [
    &["uncolorednesses"],
    &["uncolourednesses"],
    &["uncolourednesses"],
    &["uncolourednesses"],
];

pub(crate) static ENTRY_UNCOLOREDNESS_16507195530617886306: VariantsMap = [
    &["uncoloredness"],
    &["uncolouredness"],
    &["uncolouredness"],
    &["uncolouredness"],
];

pub(crate) static ENTRY_UNCOLOREDS_8597280883372836480: VariantsMap = [
    &["uncoloreds"],
    &["uncoloureds"],
    &["uncoloureds"],
    &["uncoloureds"],
];

pub(crate) static ENTRY_UNCOLORED_11161437304186875893: VariantsMap = [
    &["uncolored"],
    &["uncoloured"],
    &["uncoloured"],
    &["uncoloured"],
];

pub(crate) static ENTRY_UNCONCERTED_6095497230856593489: VariantsMap = [
    &["unconcerted"],
    &["unconcreted"],
    &["unconcreted"],
    &["unconcreted"],
];

pub(crate) static ENTRY_UNCONVENTIONALIZES_1804902019330246754: VariantsMap = [
    &["unconventionalizes"],
    &["unconventionalises"],
    &["unconventionalizes"],
    &["unconventionalises"],
];

pub(crate) static ENTRY_UNCONVENTIONALIZE_7485202036270814256: VariantsMap = [
    &["unconventionalize"],
    &["unconventionalise"],
    &["unconventionalize"],
    &["unconventionalise"],
];

pub(crate) static ENTRY_UNCRITICIZABLER_12547491203255935586: VariantsMap = [
    &["uncriticizabler"],
    &["uncriticisabler"],
    &["uncriticizabler"],
    &["uncriticisabler"],
];

pub(crate) static ENTRY_UNCRITICIZABLEST_4607318644536802423: VariantsMap = [
    &["uncriticizablest"],
    &["uncriticisablest"],
    &["uncriticizablest"],
    &["uncriticisablest"],
];

pub(crate) static ENTRY_UNCRITICIZABLES_12700073615320281916: VariantsMap = [
    &["uncriticizables"],
    &["uncriticisables"],
    &["uncriticizables"],
    &["uncriticisables"],
];

pub(crate) static ENTRY_UNCRITICIZABLE_11373327800791333419: VariantsMap = [
    &["uncriticizable"],
    &["uncriticisable"],
    &["uncriticizable"],
    &["uncriticisable"],
];

pub(crate) static ENTRY_UNCRITICIZABLY_5679899333014793182: VariantsMap = [
    &["uncriticizably"],
    &["uncriticisably"],
    &["uncriticizably"],
    &["uncriticisably"],
];

pub(crate) static ENTRY_UNCRITICIZED_2911120484028704139: VariantsMap = [
    &["uncriticized"],
    &["uncriticised"],
    &["uncriticized"],
    &["uncriticised"],
];

pub(crate) static ENTRY_UNCRITICIZINGLY_8633111293350941138: VariantsMap = [
    &["uncriticizingly"],
    &["uncriticisingly"],
    &["uncriticizingly"],
    &["uncriticisingly"],
];

pub(crate) static ENTRY_UNCRITICIZING_11997178515445821682: VariantsMap = [
    &["uncriticizing"],
    &["uncriticising"],
    &["uncriticizing"],
    &["uncriticising"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABILITIES_17690728856956585473: VariantsMap = [
    &["uncrystallizabilities"],
    &["uncrystallisabilities"],
    &["uncrystallizabilities"],
    &["uncrystallisabilities"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABILITY_11525239910591863121: VariantsMap = [
    &["uncrystallizability"],
    &["uncrystallisability"],
    &["uncrystallizability"],
    &["uncrystallisability"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABLER_16849085510473534176: VariantsMap = [
    &["uncrystallizabler"],
    &["uncrystallisabler"],
    &["uncrystallizabler"],
    &["uncrystallisabler"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABLEST_5988044069876666615: VariantsMap = [
    &["uncrystallizablest"],
    &["uncrystallisablest"],
    &["uncrystallizablest"],
    &["uncrystallisablest"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABLES_5618943405184002759: VariantsMap = [
    &["uncrystallizables"],
    &["uncrystallisables"],
    &["uncrystallizables"],
    &["uncrystallisables"],
];

pub(crate) static ENTRY_UNCRYSTALLIZABLE_896206698167723642: VariantsMap = [
    &["uncrystallizable"],
    &["uncrystallisable"],
    &["uncrystallizable"],
    &["uncrystallisable"],
];

pub(crate) static ENTRY_UNCRYSTALLIZED_2777096876542409868: VariantsMap = [
    &["uncrystallized"],
    &["uncrystallised"],
    &["uncrystallized"],
    &["uncrystallised"],
];

pub(crate) static ENTRY_UNCURRICULARIZEDS_8615810342283576503: VariantsMap = [
    &["uncurricularizeds"],
    &["uncurriculariseds"],
    &["uncurricularizeds"],
    &["uncurriculariseds"],
];

pub(crate) static ENTRY_UNCURRICULARIZED_1510394198207258931: VariantsMap = [
    &["uncurricularized"],
    &["uncurricularised"],
    &["uncurricularized"],
    &["uncurricularised"],
];

pub(crate) static ENTRY_UNDEFENSES_5387761130135332933: VariantsMap = [
    &["undefenses"],
    &["undefences"],
    &["undefences"],
    &["undefences"],
];

pub(crate) static ENTRY_UNDEFENSE_1506818606399848606: VariantsMap = [
    &["undefense"],
    &["undefence"],
    &["undefence"],
    &["undefence"],
];

pub(crate) static ENTRY_UNDEMAGNETIZABLES_5686795504114325763: VariantsMap = [
    &["undemagnetizables"],
    &["undemagnetisables"],
    &["undemagnetizables"],
    &["undemagnetisables"],
];

pub(crate) static ENTRY_UNDEMAGNETIZABLE_15252782349141238446: VariantsMap = [
    &["undemagnetizable"],
    &["undemagnetisable"],
    &["undemagnetizable"],
    &["undemagnetisable"],
];

pub(crate) static ENTRY_UNDEMOCRATIZATION_1985548670847944255: VariantsMap = [
    &["undemocratization"],
    &["undemocratisation"],
    &["undemocratization"],
    &["undemocratisation"],
];

pub(crate) static ENTRY_UNDEMOCRATIZED_2117183159769210163: VariantsMap = [
    &["undemocratized"],
    &["undemocratised"],
    &["undemocratized"],
    &["undemocratised"],
];

pub(crate) static ENTRY_UNDEMOCRATIZES_5725888909225905299: VariantsMap = [
    &["undemocratizes"],
    &["undemocratises"],
    &["undemocratizes"],
    &["undemocratises"],
];

pub(crate) static ENTRY_UNDEMOCRATIZE_1034629020769539043: VariantsMap = [
    &["undemocratize"],
    &["undemocratise"],
    &["undemocratize"],
    &["undemocratise"],
];

pub(crate) static ENTRY_UNDEMOCRATIZING_4527096256498077472: VariantsMap = [
    &["undemocratizing"],
    &["undemocratising"],
    &["undemocratizing"],
    &["undemocratising"],
];

pub(crate) static ENTRY_UNDENOMINATIONALIZES_3120796019381704993: VariantsMap = [
    &["undenominationalizes"],
    &["undenominationalises"],
    &["undenominationalizes"],
    &["undenominationalises"],
];

pub(crate) static ENTRY_UNDENOMINATIONALIZE_6740738141836952680: VariantsMap = [
    &["undenominationalize"],
    &["undenominationalise"],
    &["undenominationalize"],
    &["undenominationalise"],
];

pub(crate) static ENTRY_UNDERCAPITALIZATIONS_15182325328537661657: VariantsMap = [
    &["undercapitalizations"],
    &["undercapitalisations"],
    &["undercapitalizations"],
    &["undercapitalisations"],
];

pub(crate) static ENTRY_UNDERCAPITALIZATION_10660193274275293366: VariantsMap = [
    &["undercapitalization"],
    &["undercapitalisation"],
    &["undercapitalization"],
    &["undercapitalisation"],
];

pub(crate) static ENTRY_UNDERCAPITALIZED_4628390293054794377: VariantsMap = [
    &["undercapitalized"],
    &["undercapitalised"],
    &["undercapitalized"],
    &["undercapitalised"],
];

pub(crate) static ENTRY_UNDERCAPITALIZES_3303618473551057315: VariantsMap = [
    &["undercapitalizes"],
    &["undercapitalises"],
    &["undercapitalizes"],
    &["undercapitalises"],
];

pub(crate) static ENTRY_UNDERCAPITALIZE_16023499620792084738: VariantsMap = [
    &["undercapitalize"],
    &["undercapitalise"],
    &["undercapitalize"],
    &["undercapitalise"],
];

pub(crate) static ENTRY_UNDERCAPITALIZING_16232808968195990904: VariantsMap = [
    &["undercapitalizing"],
    &["undercapitalising"],
    &["undercapitalizing"],
    &["undercapitalising"],
];

pub(crate) static ENTRY_UNDERCOLORED_17422644742945532202: VariantsMap = [
    &["undercolored"],
    &["undercoloured"],
    &["undercoloured"],
    &["undercoloured"],
];

pub(crate) static ENTRY_UNDERCOLORINGS_10087184255355441121: VariantsMap = [
    &["undercolorings"],
    &["undercolourings"],
    &["undercolourings"],
    &["undercolourings"],
];

pub(crate) static ENTRY_UNDERCOLORING_7781389003709580079: VariantsMap = [
    &["undercoloring"],
    &["undercolouring"],
    &["undercolouring"],
    &["undercolouring"],
];

pub(crate) static ENTRY_UNDERCOLORS_6190629777654495448: VariantsMap = [
    &["undercolors"],
    &["undercolours"],
    &["undercolours"],
    &["undercolours"],
];

pub(crate) static ENTRY_UNDERCOLOR_8519534420778344085: VariantsMap = [
    &["undercolor"],
    &["undercolour"],
    &["undercolour"],
    &["undercolour"],
];

pub(crate) static ENTRY_UNDEREMPHASIZED_13287064872491391347: VariantsMap = [
    &["underemphasized"],
    &["underemphasised"],
    &["underemphasized"],
    &["underemphasised"],
];

pub(crate) static ENTRY_UNDEREMPHASIZES_12584850145350891996: VariantsMap = [
    &["underemphasizes"],
    &["underemphasises"],
    &["underemphasizes"],
    &["underemphasises"],
];

pub(crate) static ENTRY_UNDEREMPHASIZE_16005848787441654782: VariantsMap = [
    &["underemphasize"],
    &["underemphasise"],
    &["underemphasize"],
    &["underemphasise"],
];

pub(crate) static ENTRY_UNDEREMPHASIZING_6499426514394882956: VariantsMap = [
    &["underemphasizing"],
    &["underemphasising"],
    &["underemphasizing"],
    &["underemphasising"],
];

pub(crate) static ENTRY_UNDERGOER_9429829714211980631: VariantsMap = [
    &["undergoer"],
    &["undergore"],
    &["undergore"],
    &["undergore"],
];

pub(crate) static ENTRY_UNDERLABORERS_9021923481724217322: VariantsMap = [
    &["underlaborers"],
    &["underlabourers"],
    &["underlabourers"],
    &["underlabourers"],
];

pub(crate) static ENTRY_UNDERLABORER_3694933881204703688: VariantsMap = [
    &["underlaborer"],
    &["underlabourer"],
    &["underlabourer"],
    &["underlabourer"],
];

pub(crate) static ENTRY_UNDERORGANIZATIONS_10335581416606425325: VariantsMap = [
    &["underorganizations"],
    &["underorganisations"],
    &["underorganizations"],
    &["underorganisations"],
];

pub(crate) static ENTRY_UNDERORGANIZATION_7400455363911340000: VariantsMap = [
    &["underorganization"],
    &["underorganisation"],
    &["underorganization"],
    &["underorganisation"],
];

pub(crate) static ENTRY_UNDEROXIDIZED_9530283666542091132: VariantsMap = [
    &["underoxidized"],
    &["underoxidised"],
    &["underoxidized"],
    &["underoxidised"],
];

pub(crate) static ENTRY_UNDEROXIDIZES_11400908621570551704: VariantsMap = [
    &["underoxidizes"],
    &["underoxidises"],
    &["underoxidizes"],
    &["underoxidises"],
];

pub(crate) static ENTRY_UNDEROXIDIZE_6485083535977243452: VariantsMap = [
    &["underoxidize"],
    &["underoxidise"],
    &["underoxidize"],
    &["underoxidise"],
];

pub(crate) static ENTRY_UNDEROXIDIZING_7229227794588570973: VariantsMap = [
    &["underoxidizing"],
    &["underoxidising"],
    &["underoxidizing"],
    &["underoxidising"],
];

pub(crate) static ENTRY_UNDERPRIZED_10416331611131826895: VariantsMap = [
    &["underprized"],
    &["underprised"],
    &["underprized"],
    &["underprised"],
];

pub(crate) static ENTRY_UNDERPRIZES_6377465244834486670: VariantsMap = [
    &["underprizes"],
    &["underprises"],
    &["underprizes"],
    &["underprises"],
];

pub(crate) static ENTRY_UNDERPRIZE_5508380942697361246: VariantsMap = [
    &["underprize"],
    &["underprise"],
    &["underprize"],
    &["underprise"],
];

pub(crate) static ENTRY_UNDERPRIZING_17802343668144879352: VariantsMap = [
    &["underprizing"],
    &["underprising"],
    &["underprizing"],
    &["underprising"],
];

pub(crate) static ENTRY_UNDERREALIZED_18033081021006552359: VariantsMap = [
    &["underrealized"],
    &["underrealised"],
    &["underrealized"],
    &["underrealised"],
];

pub(crate) static ENTRY_UNDERREALIZES_2029819726682856248: VariantsMap = [
    &["underrealizes"],
    &["underrealises"],
    &["underrealizes"],
    &["underrealises"],
];

pub(crate) static ENTRY_UNDERREALIZE_7092158884515094974: VariantsMap = [
    &["underrealize"],
    &["underrealise"],
    &["underrealize"],
    &["underrealise"],
];

pub(crate) static ENTRY_UNDERREALIZING_17755667674781640335: VariantsMap = [
    &["underrealizing"],
    &["underrealising"],
    &["underrealizing"],
    &["underrealising"],
];

pub(crate) static ENTRY_UNDERSAVIORS_10984132115349151011: VariantsMap = [
    &["undersaviors"],
    &["undersaviours"],
    &["undersaviours"],
    &["undersaviours"],
];

pub(crate) static ENTRY_UNDERSAVIOR_7434958491263890564: VariantsMap = [
    &["undersavior"],
    &["undersaviour"],
    &["undersaviour"],
    &["undersaviour"],
];

pub(crate) static ENTRY_UNDERUTILIZATIONS_2736156761561305874: VariantsMap = [
    &["underutilizations"],
    &["underutilisations"],
    &["underutilizations"],
    &["underutilisations"],
];

pub(crate) static ENTRY_UNDERUTILIZATION_5223118652036751167: VariantsMap = [
    &["underutilization"],
    &["underutilisation"],
    &["underutilization"],
    &["underutilisation"],
];

pub(crate) static ENTRY_UNDERUTILIZED_6777172924330394476: VariantsMap = [
    &["underutilized"],
    &["underutilised"],
    &["underutilized"],
    &["underutilised"],
];

pub(crate) static ENTRY_UNDERUTILIZES_3826812380680667876: VariantsMap = [
    &["underutilizes"],
    &["underutilises"],
    &["underutilizes"],
    &["underutilises"],
];

pub(crate) static ENTRY_UNDERUTILIZE_1115904263636509242: VariantsMap = [
    &["underutilize"],
    &["underutilise"],
    &["underutilize"],
    &["underutilise"],
];

pub(crate) static ENTRY_UNDERUTILIZING_13709312952006497089: VariantsMap = [
    &["underutilizing"],
    &["underutilising"],
    &["underutilizing"],
    &["underutilising"],
];

pub(crate) static ENTRY_UNDERVITALIZEDS_7837775855116374233: VariantsMap = [
    &["undervitalizeds"],
    &["undervitaliseds"],
    &["undervitalizeds"],
    &["undervitaliseds"],
];

pub(crate) static ENTRY_UNDERVITALIZED_15030486633106066661: VariantsMap = [
    &["undervitalized"],
    &["undervitalised"],
    &["undervitalized"],
    &["undervitalised"],
];

pub(crate) static ENTRY_UNDIALYZEDS_15673303853485275568: VariantsMap = [
    &["undialyzeds"],
    &["undialyseds"],
    &["undialyseds"],
    &["undialyseds"],
];

pub(crate) static ENTRY_UNDIALYZED_4239031886129441255: VariantsMap = [
    &["undialyzed"],
    &["undialysed"],
    &["undialysed"],
    &["undialysed"],
];

pub(crate) static ENTRY_UNDIPHTHONGIZES_919729037221686149: VariantsMap = [
    &["undiphthongizes"],
    &["undiphthongises"],
    &["undiphthongizes"],
    &["undiphthongises"],
];

pub(crate) static ENTRY_UNDIPHTHONGIZE_2160275447408384699: VariantsMap = [
    &["undiphthongize"],
    &["undiphthongise"],
    &["undiphthongize"],
    &["undiphthongise"],
];

pub(crate) static ENTRY_UNDISCOLOREDDER_12948233388857516182: VariantsMap = [
    &["undiscoloredder"],
    &["undiscolouredder"],
    &["undiscolouredder"],
    &["undiscolouredder"],
];

pub(crate) static ENTRY_UNDISCOLOREDDEST_588122864294200189: VariantsMap = [
    &["undiscoloreddest"],
    &["undiscoloureddest"],
    &["undiscoloureddest"],
    &["undiscoloureddest"],
];

pub(crate) static ENTRY_UNDISCOLOREDS_10674456259381646580: VariantsMap = [
    &["undiscoloreds"],
    &["undiscoloureds"],
    &["undiscoloureds"],
    &["undiscoloureds"],
];

pub(crate) static ENTRY_UNDISCOLORED_16617222672466412819: VariantsMap = [
    &["undiscolored"],
    &["undiscoloured"],
    &["undiscoloured"],
    &["undiscoloured"],
];

pub(crate) static ENTRY_UNDISHONORED_10570919707421545123: VariantsMap = [
    &["undishonored"],
    &["undishonoured"],
    &["undishonoured"],
    &["undishonoured"],
];

pub(crate) static ENTRY_UNDISORGANIZED_2987622726902566022: VariantsMap = [
    &["undisorganized"],
    &["undisorganised"],
    &["undisorganized"],
    &["undisorganised"],
];

pub(crate) static ENTRY_UNDRAMATIZABLER_17183761443356610462: VariantsMap = [
    &["undramatizabler"],
    &["undramatisabler"],
    &["undramatizabler"],
    &["undramatisabler"],
];

pub(crate) static ENTRY_UNDRAMATIZABLEST_10351333071010784123: VariantsMap = [
    &["undramatizablest"],
    &["undramatisablest"],
    &["undramatizablest"],
    &["undramatisablest"],
];

pub(crate) static ENTRY_UNDRAMATIZABLES_1761059456444333869: VariantsMap = [
    &["undramatizables"],
    &["undramatisables"],
    &["undramatizables"],
    &["undramatisables"],
];

pub(crate) static ENTRY_UNDRAMATIZABLE_16417239684975540746: VariantsMap = [
    &["undramatizable"],
    &["undramatisable"],
    &["undramatizable"],
    &["undramatisable"],
];

pub(crate) static ENTRY_UNDRAMATIZEDS_12222872129614232202: VariantsMap = [
    &["undramatizeds"],
    &["undramatiseds"],
    &["undramatizeds"],
    &["undramatiseds"],
];

pub(crate) static ENTRY_UNDRAMATIZED_10630343306514025585: VariantsMap = [
    &["undramatized"],
    &["undramatised"],
    &["undramatized"],
    &["undramatised"],
];

pub(crate) static ENTRY_UNDUALIZES_16398535363456366813: VariantsMap = [
    &["undualizes"],
    &["undualises"],
    &["undualizes"],
    &["undualises"],
];

pub(crate) static ENTRY_UNDUALIZE_12388450838585691212: VariantsMap = [
    &["undualize"],
    &["undualise"],
    &["undualize"],
    &["undualise"],
];

pub(crate) static ENTRY_UNECONOMIZING_15613959143050410767: VariantsMap = [
    &["uneconomizing"],
    &["uneconomising"],
    &["uneconomizing"],
    &["uneconomising"],
];

pub(crate) static ENTRY_UNENAMOREDDER_5033547920430041938: VariantsMap = [
    &["unenamoredder"],
    &["unenamouredder"],
    &["unenamouredder"],
    &["unenamouredder"],
];

pub(crate) static ENTRY_UNENAMOREDDEST_5114505485270249696: VariantsMap = [
    &["unenamoreddest"],
    &["unenamoureddest"],
    &["unenamoureddest"],
    &["unenamoureddest"],
];

pub(crate) static ENTRY_UNENAMOREDS_16806991213706982613: VariantsMap = [
    &["unenamoreds"],
    &["unenamoureds"],
    &["unenamoureds"],
    &["unenamoureds"],
];

pub(crate) static ENTRY_UNENAMORED_8361050364159923006: VariantsMap = [
    &["unenamored"],
    &["unenamoured"],
    &["unenamoured"],
    &["unenamoured"],
];

pub(crate) static ENTRY_UNENDEAVORED_7066291353915558991: VariantsMap = [
    &["unendeavored"],
    &["unendeavoured"],
    &["unendeavoured"],
    &["unendeavoured"],
];

pub(crate) static ENTRY_UNENERGIZEDS_9257032612298922872: VariantsMap = [
    &["unenergizeds"],
    &["unenergiseds"],
    &["unenergizeds"],
    &["unenergiseds"],
];

pub(crate) static ENTRY_UNENERGIZED_1765957718558496954: VariantsMap = [
    &["unenergized"],
    &["unenergised"],
    &["unenergized"],
    &["unenergised"],
];

pub(crate) static ENTRY_UNEPITOMIZEDDER_14282657736379387619: VariantsMap = [
    &["unepitomizedder"],
    &["unepitomisedder"],
    &["unepitomizedder"],
    &["unepitomisedder"],
];

pub(crate) static ENTRY_UNEPITOMIZEDDEST_17830262776297478282: VariantsMap = [
    &["unepitomizeddest"],
    &["unepitomiseddest"],
    &["unepitomizeddest"],
    &["unepitomiseddest"],
];

pub(crate) static ENTRY_UNEPITOMIZED_14848321193589314772: VariantsMap = [
    &["unepitomized"],
    &["unepitomised"],
    &["unepitomized"],
    &["unepitomised"],
];

pub(crate) static ENTRY_UNEQUALEDDER_8399677671352964156: VariantsMap = [
    &["unequaledder"],
    &["unequalledder"],
    &["unequalledder"],
    &["unequalledder"],
];

pub(crate) static ENTRY_UNEQUALEDDEST_12126395105891544493: VariantsMap = [
    &["unequaleddest"],
    &["unequalleddest"],
    &["unequalleddest"],
    &["unequalleddest"],
];

pub(crate) static ENTRY_UNEQUALED_10272049179921241581: VariantsMap = [
    &["unequaled"],
    &["unequalled"],
    &["unequalled"],
    &["unequalled"],
];

pub(crate) static ENTRY_UNEQUALIZED_11229527678135642111: VariantsMap = [
    &["unequalized"],
    &["unequalised"],
    &["unequalized"],
    &["unequalised"],
];

pub(crate) static ENTRY_UNEQUALIZES_11516811173212612864: VariantsMap = [
    &["unequalizes"],
    &["unequalises"],
    &["unequalizes"],
    &["unequalises"],
];

pub(crate) static ENTRY_UNEQUALIZE_12397832983269467070: VariantsMap = [
    &["unequalize"],
    &["unequalise"],
    &["unequalize"],
    &["unequalise"],
];

pub(crate) static ENTRY_UNEQUALIZING_7314201456915686327: VariantsMap = [
    &["unequalizing"],
    &["unequalising"],
    &["unequalizing"],
    &["unequalising"],
];

pub(crate) static ENTRY_UNEULOGIZEDDER_500502998937424952: VariantsMap = [
    &["uneulogizedder"],
    &["uneulogisedder"],
    &["uneulogizedder"],
    &["uneulogisedder"],
];

pub(crate) static ENTRY_UNEULOGIZEDDEST_15902188274770789074: VariantsMap = [
    &["uneulogizeddest"],
    &["uneulogiseddest"],
    &["uneulogizeddest"],
    &["uneulogiseddest"],
];

pub(crate) static ENTRY_UNEULOGIZEDS_9618091862575439629: VariantsMap = [
    &["uneulogizeds"],
    &["uneulogiseds"],
    &["uneulogizeds"],
    &["uneulogiseds"],
];

pub(crate) static ENTRY_UNEULOGIZED_8625593682318183902: VariantsMap = [
    &["uneulogized"],
    &["uneulogised"],
    &["uneulogized"],
    &["uneulogised"],
];

pub(crate) static ENTRY_UNEVANGELIZEDDER_14389146019253414049: VariantsMap = [
    &["unevangelizedder"],
    &["unevangelisedder"],
    &["unevangelizedder"],
    &["unevangelisedder"],
];

pub(crate) static ENTRY_UNEVANGELIZEDDEST_11919291498979551119: VariantsMap = [
    &["unevangelizeddest"],
    &["unevangeliseddest"],
    &["unevangelizeddest"],
    &["unevangeliseddest"],
];

pub(crate) static ENTRY_UNEVANGELIZEDS_4997587800538848322: VariantsMap = [
    &["unevangelizeds"],
    &["unevangeliseds"],
    &["unevangelizeds"],
    &["unevangeliseds"],
];

pub(crate) static ENTRY_UNEVANGELIZED_17902646883952932702: VariantsMap = [
    &["unevangelized"],
    &["unevangelised"],
    &["unevangelized"],
    &["unevangelised"],
];

pub(crate) static ENTRY_UNFAMILIARIZEDDER_13089042195024096822: VariantsMap = [
    &["unfamiliarizedder"],
    &["unfamiliarisedder"],
    &["unfamiliarizedder"],
    &["unfamiliarisedder"],
];

pub(crate) static ENTRY_UNFAMILIARIZEDDEST_4018673522303778898: VariantsMap = [
    &["unfamiliarizeddest"],
    &["unfamiliariseddest"],
    &["unfamiliarizeddest"],
    &["unfamiliariseddest"],
];

pub(crate) static ENTRY_UNFAMILIARIZED_8539267182006341403: VariantsMap = [
    &["unfamiliarized"],
    &["unfamiliarised"],
    &["unfamiliarized"],
    &["unfamiliarised"],
];

pub(crate) static ENTRY_UNFAVORABLENESSES_6196655711715423789: VariantsMap = [
    &["unfavorablenesses"],
    &["unfavourablenesses"],
    &["unfavourablenesses"],
    &["unfavourablenesses"],
];

pub(crate) static ENTRY_UNFAVORABLENESS_11828384935093784234: VariantsMap = [
    &["unfavorableness"],
    &["unfavourableness"],
    &["unfavourableness"],
    &["unfavourableness"],
];

pub(crate) static ENTRY_UNFAVORABLER_7526512460280153322: VariantsMap = [
    &["unfavorabler"],
    &["unfavourabler"],
    &["unfavourabler"],
    &["unfavourabler"],
];

pub(crate) static ENTRY_UNFAVORABLEST_10537368209740978427: VariantsMap = [
    &["unfavorablest"],
    &["unfavourablest"],
    &["unfavourablest"],
    &["unfavourablest"],
];

pub(crate) static ENTRY_UNFAVORABLES_6371240244863361092: VariantsMap = [
    &["unfavorables"],
    &["unfavourables"],
    &["unfavourables"],
    &["unfavourables"],
];

pub(crate) static ENTRY_UNFAVORABLE_8233532032007631727: VariantsMap = [
    &["unfavorable"],
    &["unfavourable"],
    &["unfavourable"],
    &["unfavourable"],
];

pub(crate) static ENTRY_UNFAVORABLIER_9564967346867026046: VariantsMap = [
    &["unfavorablier"],
    &["unfavourablier"],
    &["unfavourablier"],
    &["unfavourablier"],
];

pub(crate) static ENTRY_UNFAVORABLIEST_17311907542528170719: VariantsMap = [
    &["unfavorabliest"],
    &["unfavourabliest"],
    &["unfavourabliest"],
    &["unfavourabliest"],
];

pub(crate) static ENTRY_UNFAVORABLY_13214726587411166355: VariantsMap = [
    &["unfavorably"],
    &["unfavourably"],
    &["unfavourably"],
    &["unfavourably"],
];

pub(crate) static ENTRY_UNFAVOREDDER_6939782924396346672: VariantsMap = [
    &["unfavoredder"],
    &["unfavouredder"],
    &["unfavouredder"],
    &["unfavouredder"],
];

pub(crate) static ENTRY_UNFAVOREDDEST_9219340201172922449: VariantsMap = [
    &["unfavoreddest"],
    &["unfavoureddest"],
    &["unfavoureddest"],
    &["unfavoureddest"],
];

pub(crate) static ENTRY_UNFAVORED_8089880807159401110: VariantsMap = [
    &["unfavored"],
    &["unfavoured"],
    &["unfavoured"],
    &["unfavoured"],
];

pub(crate) static ENTRY_UNFAVORINGER_3557197515106588733: VariantsMap = [
    &["unfavoringer"],
    &["unfavouringer"],
    &["unfavouringer"],
    &["unfavouringer"],
];

pub(crate) static ENTRY_UNFAVORINGEST_12052226034286952177: VariantsMap = [
    &["unfavoringest"],
    &["unfavouringest"],
    &["unfavouringest"],
    &["unfavouringest"],
];

pub(crate) static ENTRY_UNFAVORINGS_16058515457408679487: VariantsMap = [
    &["unfavorings"],
    &["unfavourings"],
    &["unfavourings"],
    &["unfavourings"],
];

pub(crate) static ENTRY_UNFAVORING_14241568587543696910: VariantsMap = [
    &["unfavoring"],
    &["unfavouring"],
    &["unfavouring"],
    &["unfavouring"],
];

pub(crate) static ENTRY_UNFAVORITER_3433053368739550354: VariantsMap = [
    &["unfavoriter"],
    &["unfavouriter"],
    &["unfavouriter"],
    &["unfavouriter"],
];

pub(crate) static ENTRY_UNFAVORITEST_5653472480878764002: VariantsMap = [
    &["unfavoritest"],
    &["unfavouritest"],
    &["unfavouritest"],
    &["unfavouritest"],
];

pub(crate) static ENTRY_UNFAVORITES_8192113054989661952: VariantsMap = [
    &["unfavorites"],
    &["unfavourites"],
    &["unfavourites"],
    &["unfavourites"],
];

pub(crate) static ENTRY_UNFAVORITE_9275402982305749708: VariantsMap = [
    &["unfavorite"],
    &["unfavourite"],
    &["unfavourite"],
    &["unfavourite"],
];

pub(crate) static ENTRY_UNFEMINIZED_3027631822761516755: VariantsMap = [
    &["unfeminized"],
    &["unfeminised"],
    &["unfeminized"],
    &["unfeminised"],
];

pub(crate) static ENTRY_UNFEMINIZE_17213280328995954348: VariantsMap = [
    &["unfeminize"],
    &["unfeminise"],
    &["unfeminize"],
    &["unfeminise"],
];

pub(crate) static ENTRY_UNFEMINIZING_16839714662136031968: VariantsMap = [
    &["unfeminizing"],
    &["unfeminising"],
    &["unfeminizing"],
    &["unfeminising"],
];

pub(crate) static ENTRY_UNFERTILIZABLER_7824528564028868183: VariantsMap = [
    &["unfertilizabler"],
    &["unfertilisabler"],
    &["unfertilizabler"],
    &["unfertilisabler"],
];

pub(crate) static ENTRY_UNFERTILIZABLEST_13686866561865228741: VariantsMap = [
    &["unfertilizablest"],
    &["unfertilisablest"],
    &["unfertilizablest"],
    &["unfertilisablest"],
];

pub(crate) static ENTRY_UNFERTILIZABLES_2276591821562054261: VariantsMap = [
    &["unfertilizables"],
    &["unfertilisables"],
    &["unfertilizables"],
    &["unfertilisables"],
];

pub(crate) static ENTRY_UNFERTILIZABLE_17486342932318545605: VariantsMap = [
    &["unfertilizable"],
    &["unfertilisable"],
    &["unfertilizable"],
    &["unfertilisable"],
];

pub(crate) static ENTRY_UNFERTILIZEDDER_8970939762495254103: VariantsMap = [
    &["unfertilizedder"],
    &["unfertilisedder"],
    &["unfertilizedder"],
    &["unfertilisedder"],
];

pub(crate) static ENTRY_UNFERTILIZEDDEST_3987712837886027136: VariantsMap = [
    &["unfertilizeddest"],
    &["unfertiliseddest"],
    &["unfertilizeddest"],
    &["unfertiliseddest"],
];

pub(crate) static ENTRY_UNFERTILIZED_8536659073895846486: VariantsMap = [
    &["unfertilized"],
    &["unfertilised"],
    &["unfertilized"],
    &["unfertilised"],
];

pub(crate) static ENTRY_UNFERTILIZING_18219334417771825481: VariantsMap = [
    &["unfertilizing"],
    &["unfertilising"],
    &["unfertilizing"],
    &["unfertilising"],
];

pub(crate) static ENTRY_UNFEUDALIZED_11117493394291645590: VariantsMap = [
    &["unfeudalized"],
    &["unfeudalised"],
    &["unfeudalized"],
    &["unfeudalised"],
];

pub(crate) static ENTRY_UNFEUDALIZES_5103523048575728973: VariantsMap = [
    &["unfeudalizes"],
    &["unfeudalises"],
    &["unfeudalizes"],
    &["unfeudalises"],
];

pub(crate) static ENTRY_UNFEUDALIZE_14691232336692814883: VariantsMap = [
    &["unfeudalize"],
    &["unfeudalise"],
    &["unfeudalize"],
    &["unfeudalise"],
];

pub(crate) static ENTRY_UNFEUDALIZING_3182932192190349634: VariantsMap = [
    &["unfeudalizing"],
    &["unfeudalising"],
    &["unfeudalizing"],
    &["unfeudalising"],
];

pub(crate) static ENTRY_UNFLAVOREDDER_10493652523700310738: VariantsMap = [
    &["unflavoredder"],
    &["unflavouredder"],
    &["unflavouredder"],
    &["unflavouredder"],
];

pub(crate) static ENTRY_UNFLAVOREDDEST_1414059801540499482: VariantsMap = [
    &["unflavoreddest"],
    &["unflavoureddest"],
    &["unflavoureddest"],
    &["unflavoureddest"],
];

pub(crate) static ENTRY_UNFLAVORED_7704639512615468125: VariantsMap = [
    &["unflavored"],
    &["unflavoured"],
    &["unflavoured"],
    &["unflavoured"],
];

pub(crate) static ENTRY_UNFLAVOROUS_16935211748591593605: VariantsMap = [
    &["unflavorous"],
    &["unflavourous"],
    &["unflavourous"],
    &["unflavourous"],
];

pub(crate) static ENTRY_UNFORMALIZEDDER_16826016574168323811: VariantsMap = [
    &["unformalizedder"],
    &["unformalisedder"],
    &["unformalizedder"],
    &["unformalisedder"],
];

pub(crate) static ENTRY_UNFORMALIZEDDEST_14745966789505381148: VariantsMap = [
    &["unformalizeddest"],
    &["unformaliseddest"],
    &["unformalizeddest"],
    &["unformaliseddest"],
];

pub(crate) static ENTRY_UNFORMALIZED_10947362983293799260: VariantsMap = [
    &["unformalized"],
    &["unformalised"],
    &["unformalized"],
    &["unformalised"],
];

pub(crate) static ENTRY_UNFOSSILIZEDDER_9873397475242687877: VariantsMap = [
    &["unfossilizedder"],
    &["unfossilisedder"],
    &["unfossilizedder"],
    &["unfossilisedder"],
];

pub(crate) static ENTRY_UNFOSSILIZEDDEST_11985032009736222005: VariantsMap = [
    &["unfossilizeddest"],
    &["unfossiliseddest"],
    &["unfossilizeddest"],
    &["unfossiliseddest"],
];

pub(crate) static ENTRY_UNFOSSILIZEDS_11821803111813998857: VariantsMap = [
    &["unfossilizeds"],
    &["unfossiliseds"],
    &["unfossilizeds"],
    &["unfossiliseds"],
];

pub(crate) static ENTRY_UNFOSSILIZED_1644345316811460331: VariantsMap = [
    &["unfossilized"],
    &["unfossilised"],
    &["unfossilized"],
    &["unfossilised"],
];

pub(crate) static ENTRY_UNFRATERNIZED_15391653689494557711: VariantsMap = [
    &["unfraternized"],
    &["unfraternised"],
    &["unfraternized"],
    &["unfraternised"],
];

pub(crate) static ENTRY_UNFRATERNIZINGS_443815508621461535: VariantsMap = [
    &["unfraternizings"],
    &["unfraternisings"],
    &["unfraternizings"],
    &["unfraternisings"],
];

pub(crate) static ENTRY_UNFRATERNIZING_11945792457598246703: VariantsMap = [
    &["unfraternizing"],
    &["unfraternising"],
    &["unfraternizing"],
    &["unfraternising"],
];

pub(crate) static ENTRY_UNGALVANIZEDS_4906872843938668122: VariantsMap = [
    &["ungalvanizeds"],
    &["ungalvaniseds"],
    &["ungalvanizeds"],
    &["ungalvaniseds"],
];

pub(crate) static ENTRY_UNGALVANIZED_3840316573651324942: VariantsMap = [
    &["ungalvanized"],
    &["ungalvanised"],
    &["ungalvanized"],
    &["ungalvanised"],
];

pub(crate) static ENTRY_UNGELATINIZABLES_4045588807998071406: VariantsMap = [
    &["ungelatinizables"],
    &["ungelatinisables"],
    &["ungelatinizables"],
    &["ungelatinisables"],
];

pub(crate) static ENTRY_UNGELATINIZABLE_429611291989316452: VariantsMap = [
    &["ungelatinizable"],
    &["ungelatinisable"],
    &["ungelatinizable"],
    &["ungelatinisable"],
];

pub(crate) static ENTRY_UNGELATINIZEDS_16589417897484720231: VariantsMap = [
    &["ungelatinizeds"],
    &["ungelatiniseds"],
    &["ungelatinizeds"],
    &["ungelatiniseds"],
];

pub(crate) static ENTRY_UNGELATINIZED_9064237700681920871: VariantsMap = [
    &["ungelatinized"],
    &["ungelatinised"],
    &["ungelatinized"],
    &["ungelatinised"],
];

pub(crate) static ENTRY_UNGENERALIZEDDER_9404932562611412518: VariantsMap = [
    &["ungeneralizedder"],
    &["ungeneralisedder"],
    &["ungeneralizedder"],
    &["ungeneralisedder"],
];

pub(crate) static ENTRY_UNGENERALIZEDDEST_10234603051627457134: VariantsMap = [
    &["ungeneralizeddest"],
    &["ungeneraliseddest"],
    &["ungeneralizeddest"],
    &["ungeneraliseddest"],
];

pub(crate) static ENTRY_UNGENERALIZED_304645846605712294: VariantsMap = [
    &["ungeneralized"],
    &["ungeneralised"],
    &["ungeneralized"],
    &["ungeneralised"],
];

pub(crate) static ENTRY_UNGENERALIZING_3627958036075317148: VariantsMap = [
    &["ungeneralizing"],
    &["ungeneralising"],
    &["ungeneralizing"],
    &["ungeneralising"],
];

pub(crate) static ENTRY_UNGENTILIZES_1989929300659612547: VariantsMap = [
    &["ungentilizes"],
    &["ungentilises"],
    &["ungentilizes"],
    &["ungentilises"],
];

pub(crate) static ENTRY_UNGENTILIZE_1682666321562915658: VariantsMap = [
    &["ungentilize"],
    &["ungentilise"],
    &["ungentilize"],
    &["ungentilise"],
];

pub(crate) static ENTRY_UNGENTLEMANIZES_5000225273049339991: VariantsMap = [
    &["ungentlemanizes"],
    &["ungentlemanises"],
    &["ungentlemanizes"],
    &["ungentlemanises"],
];

pub(crate) static ENTRY_UNGENTLEMANIZE_6616841421363856905: VariantsMap = [
    &["ungentlemanize"],
    &["ungentlemanise"],
    &["ungentlemanize"],
    &["ungentlemanise"],
];

pub(crate) static ENTRY_UNGLAMOROUSLY_12722711669948552620: VariantsMap = [
    &["unglamorously"],
    &["unglamorously"],
    &["unglamorously"],
    &["unglamorously"],
];

pub(crate) static ENTRY_UNGLAMOROUS_11551883381104018739: VariantsMap = [
    &["unglamorous"],
    &["unglamorous"],
    &["unglamorous"],
    &["unglamorous"],
];

pub(crate) static ENTRY_UNGOSPELIZEDS_12370376811231680007: VariantsMap = [
    &["ungospelizeds"],
    &["ungospeliseds"],
    &["ungospelizeds"],
    &["ungospeliseds"],
];

pub(crate) static ENTRY_UNGOSPELIZED_7916023896723661075: VariantsMap = [
    &["ungospelized"],
    &["ungospelised"],
    &["ungospelized"],
    &["ungospelised"],
];

pub(crate) static ENTRY_UNGRAPHITIZEDS_17567383968087162591: VariantsMap = [
    &["ungraphitizeds"],
    &["ungraphitiseds"],
    &["ungraphitizeds"],
    &["ungraphitiseds"],
];

pub(crate) static ENTRY_UNGRAPHITIZED_9140840362551120713: VariantsMap = [
    &["ungraphitized"],
    &["ungraphitised"],
    &["ungraphitized"],
    &["ungraphitised"],
];

pub(crate) static ENTRY_UNHARBORED_15652861429904710912: VariantsMap = [
    &["unharbored"],
    &["unharboured"],
    &["unharboured"],
    &["unharboured"],
];

pub(crate) static ENTRY_UNHARBOR_1889127797014206122: VariantsMap = [
    &["unharbor"],
    &["unharbour"],
    &["unharbour"],
    &["unharbour"],
];

pub(crate) static ENTRY_UNHARMONIZED_3681921261857978250: VariantsMap = [
    &["unharmonized"],
    &["unharmonised"],
    &["unharmonized"],
    &["unharmonised"],
];

pub(crate) static ENTRY_UNHARMONIZES_13473655128913265796: VariantsMap = [
    &["unharmonizes"],
    &["unharmonises"],
    &["unharmonizes"],
    &["unharmonises"],
];

pub(crate) static ENTRY_UNHARMONIZE_14159372496346198461: VariantsMap = [
    &["unharmonize"],
    &["unharmonise"],
    &["unharmonize"],
    &["unharmonise"],
];

pub(crate) static ENTRY_UNHARMONIZING_3698746930961588812: VariantsMap = [
    &["unharmonizing"],
    &["unharmonising"],
    &["unharmonizing"],
    &["unharmonising"],
];

pub(crate) static ENTRY_UNHEROIZES_18067699959238416206: VariantsMap = [
    &["unheroizes"],
    &["unheroises"],
    &["unheroizes"],
    &["unheroises"],
];

pub(crate) static ENTRY_UNHEROIZE_16852054084869741483: VariantsMap = [
    &["unheroize"],
    &["unheroise"],
    &["unheroize"],
    &["unheroise"],
];

pub(crate) static ENTRY_UNHONORABLES_5002839830632485659: VariantsMap = [
    &["unhonorables"],
    &["unhonourables"],
    &["unhonourables"],
    &["unhonourables"],
];

pub(crate) static ENTRY_UNHONORABLE_1330850809715602086: VariantsMap = [
    &["unhonorable"],
    &["unhonourable"],
    &["unhonourable"],
    &["unhonourable"],
];

pub(crate) static ENTRY_UNHONORABLIES_7582286055767508232: VariantsMap = [
    &["unhonorablies"],
    &["unhonourablies"],
    &["unhonourablies"],
    &["unhonourablies"],
];

pub(crate) static ENTRY_UNHONORABLY_18210830341929676608: VariantsMap = [
    &["unhonorably"],
    &["unhonourably"],
    &["unhonourably"],
    &["unhonourably"],
];

pub(crate) static ENTRY_UNHONOREDDER_1452869734187004448: VariantsMap = [
    &["unhonoredder"],
    &["unhonouredder"],
    &["unhonouredder"],
    &["unhonouredder"],
];

pub(crate) static ENTRY_UNHONOREDDEST_6950228220672261606: VariantsMap = [
    &["unhonoreddest"],
    &["unhonoureddest"],
    &["unhonoureddest"],
    &["unhonoureddest"],
];

pub(crate) static ENTRY_UNHONORED_5460665573065748506: VariantsMap = [
    &["unhonored"],
    &["unhonoured"],
    &["unhonoured"],
    &["unhonoured"],
];

pub(crate) static ENTRY_UNHOUSELED_8799017796220250092: VariantsMap = [
    &["unhouseled"],
    &["unhouselled"],
    &["unhouselled"],
    &["unhouselled"],
];

pub(crate) static ENTRY_UNHUMANIZED_17662506078275203924: VariantsMap = [
    &["unhumanized"],
    &["unhumanised"],
    &["unhumanized"],
    &["unhumanised"],
];

pub(crate) static ENTRY_UNHUMANIZES_17954053753304169532: VariantsMap = [
    &["unhumanizes"],
    &["unhumanises"],
    &["unhumanizes"],
    &["unhumanises"],
];

pub(crate) static ENTRY_UNHUMANIZE_12854121833055078969: VariantsMap = [
    &["unhumanize"],
    &["unhumanise"],
    &["unhumanize"],
    &["unhumanise"],
];

pub(crate) static ENTRY_UNHUMANIZING_9429149451831438072: VariantsMap = [
    &["unhumanizing"],
    &["unhumanising"],
    &["unhumanizing"],
    &["unhumanising"],
];

pub(crate) static ENTRY_UNHUMOREDDER_18307311026638177281: VariantsMap = [
    &["unhumoredder"],
    &["unhumouredder"],
    &["unhumouredder"],
    &["unhumouredder"],
];

pub(crate) static ENTRY_UNHUMOREDDEST_7064789414378776056: VariantsMap = [
    &["unhumoreddest"],
    &["unhumoureddest"],
    &["unhumoureddest"],
    &["unhumoureddest"],
];

pub(crate) static ENTRY_UNHUMORED_18084787621051692653: VariantsMap = [
    &["unhumored"],
    &["unhumoured"],
    &["unhumoured"],
    &["unhumoured"],
];

pub(crate) static ENTRY_UNHUMOROUSLY_16491216367858199459: VariantsMap = [
    &["unhumorously"],
    &["unhumourously"],
    &["unhumourously"],
    &["unhumourously"],
];

pub(crate) static ENTRY_UNHUMOROUS_2057333796189652890: VariantsMap = [
    &["unhumorous"],
    &["unhumourous"],
    &["unhumourous"],
    &["unhumourous"],
];

pub(crate) static ENTRY_UNHYDROLYZEDS_13681238840583454957: VariantsMap = [
    &["unhydrolyzeds"],
    &["unhydrolyseds"],
    &["unhydrolyseds"],
    &["unhydrolyseds"],
];

pub(crate) static ENTRY_UNHYDROLYZED_1605839220238398471: VariantsMap = [
    &["unhydrolyzed"],
    &["unhydrolysed"],
    &["unhydrolysed"],
    &["unhydrolysed"],
];

pub(crate) static ENTRY_UNHYPNOTIZABLER_8308231553591337285: VariantsMap = [
    &["unhypnotizabler"],
    &["unhypnotisabler"],
    &["unhypnotizabler"],
    &["unhypnotisabler"],
];

pub(crate) static ENTRY_UNHYPNOTIZABLEST_18105363756532886213: VariantsMap = [
    &["unhypnotizablest"],
    &["unhypnotisablest"],
    &["unhypnotizablest"],
    &["unhypnotisablest"],
];

pub(crate) static ENTRY_UNHYPNOTIZABLES_2781823676708254865: VariantsMap = [
    &["unhypnotizables"],
    &["unhypnotisables"],
    &["unhypnotizables"],
    &["unhypnotisables"],
];

pub(crate) static ENTRY_UNHYPNOTIZABLE_12677113158391463458: VariantsMap = [
    &["unhypnotizable"],
    &["unhypnotisable"],
    &["unhypnotizable"],
    &["unhypnotisable"],
];

pub(crate) static ENTRY_UNHYPNOTIZED_6987621846242827839: VariantsMap = [
    &["unhypnotized"],
    &["unhypnotised"],
    &["unhypnotized"],
    &["unhypnotised"],
];

pub(crate) static ENTRY_UNHYPNOTIZES_11386726980321406907: VariantsMap = [
    &["unhypnotizes"],
    &["unhypnotises"],
    &["unhypnotizes"],
    &["unhypnotises"],
];

pub(crate) static ENTRY_UNHYPNOTIZE_3076842320349928553: VariantsMap = [
    &["unhypnotize"],
    &["unhypnotise"],
    &["unhypnotize"],
    &["unhypnotise"],
];

pub(crate) static ENTRY_UNHYPNOTIZING_14708134202663666466: VariantsMap = [
    &["unhypnotizing"],
    &["unhypnotising"],
    &["unhypnotizing"],
    &["unhypnotising"],
];

pub(crate) static ENTRY_UNICOLORATE_7320982531251878580: VariantsMap = [
    &["unicolorate"],
    &["unicolourate"],
    &["unicolourate"],
    &["unicolourate"],
];

pub(crate) static ENTRY_UNICOLORED_15371219763539897842: VariantsMap = [
    &["unicolored"],
    &["unicoloured"],
    &["unicoloured"],
    &["unicoloured"],
];

pub(crate) static ENTRY_UNICOLOROUS_9217819624867642093: VariantsMap = [
    &["unicolorous"],
    &["unicolourous"],
    &["unicolourous"],
    &["unicolourous"],
];

pub(crate) static ENTRY_UNICOLOR_17123726217698406043: VariantsMap = [
    &["unicolor"],
    &["unicolour"],
    &["unicolour"],
    &["unicolour"],
];

pub(crate) static ENTRY_UNIDEALIZEDDER_15335158507099491677: VariantsMap = [
    &["unidealizedder"],
    &["unidealisedder"],
    &["unidealizedder"],
    &["unidealisedder"],
];

pub(crate) static ENTRY_UNIDEALIZEDDEST_9073505704713365354: VariantsMap = [
    &["unidealizeddest"],
    &["unidealiseddest"],
    &["unidealizeddest"],
    &["unidealiseddest"],
];

pub(crate) static ENTRY_UNIDEALIZED_11116714704594641479: VariantsMap = [
    &["unidealized"],
    &["unidealised"],
    &["unidealized"],
    &["unidealised"],
];

pub(crate) static ENTRY_UNIDOLIZEDDER_9054539920726947230: VariantsMap = [
    &["unidolizedder"],
    &["unidolisedder"],
    &["unidolizedder"],
    &["unidolisedder"],
];

pub(crate) static ENTRY_UNIDOLIZEDDEST_11902819922448078654: VariantsMap = [
    &["unidolizeddest"],
    &["unidoliseddest"],
    &["unidolizeddest"],
    &["unidoliseddest"],
];

pub(crate) static ENTRY_UNIDOLIZEDS_6305662893482523010: VariantsMap = [
    &["unidolizeds"],
    &["unidoliseds"],
    &["unidolizeds"],
    &["unidoliseds"],
];

pub(crate) static ENTRY_UNIDOLIZED_7746581993758703110: VariantsMap = [
    &["unidolized"],
    &["unidolised"],
    &["unidolized"],
    &["unidolised"],
];

pub(crate) static ENTRY_UNIFORMIZATIONS_5553647000162520280: VariantsMap = [
    &["uniformizations"],
    &["uniformisations"],
    &["uniformizations"],
    &["uniformisations"],
];

pub(crate) static ENTRY_UNIFORMIZATION_6928779719483130632: VariantsMap = [
    &["uniformization"],
    &["uniformisation"],
    &["uniformization"],
    &["uniformisation"],
];

pub(crate) static ENTRY_UNIFORMIZED_14730906052407110280: VariantsMap = [
    &["uniformized"],
    &["uniformised"],
    &["uniformized"],
    &["uniformised"],
];

pub(crate) static ENTRY_UNIFORMIZES_5570715002596396628: VariantsMap = [
    &["uniformizes"],
    &["uniformises"],
    &["uniformizes"],
    &["uniformises"],
];

pub(crate) static ENTRY_UNIFORMIZE_3224156171185377609: VariantsMap = [
    &["uniformize"],
    &["uniformise"],
    &["uniformize"],
    &["uniformise"],
];

pub(crate) static ENTRY_UNIFORMIZING_9818028196564001512: VariantsMap = [
    &["uniformizing"],
    &["uniformising"],
    &["uniformizing"],
    &["uniformising"],
];

pub(crate) static ENTRY_UNILATERALIZATIONS_3537291387881487266: VariantsMap = [
    &["unilateralizations"],
    &["unilateralisations"],
    &["unilateralizations"],
    &["unilateralisations"],
];

pub(crate) static ENTRY_UNILATERALIZATION_7642348548145928002: VariantsMap = [
    &["unilateralization"],
    &["unilateralisation"],
    &["unilateralization"],
    &["unilateralisation"],
];

pub(crate) static ENTRY_UNILATERALIZES_13328450924130846629: VariantsMap = [
    &["unilateralizes"],
    &["unilateralises"],
    &["unilateralizes"],
    &["unilateralises"],
];

pub(crate) static ENTRY_UNILATERALIZE_4208361192869727001: VariantsMap = [
    &["unilateralize"],
    &["unilateralise"],
    &["unilateralize"],
    &["unilateralise"],
];

pub(crate) static ENTRY_UNIMMORTALIZED_13628471993003828487: VariantsMap = [
    &["unimmortalized"],
    &["unimmortalised"],
    &["unimmortalized"],
    &["unimmortalised"],
];

pub(crate) static ENTRY_UNIMMORTALIZES_16459195990493376386: VariantsMap = [
    &["unimmortalizes"],
    &["unimmortalises"],
    &["unimmortalizes"],
    &["unimmortalises"],
];

pub(crate) static ENTRY_UNIMMORTALIZE_3846660396067631341: VariantsMap = [
    &["unimmortalize"],
    &["unimmortalise"],
    &["unimmortalize"],
    &["unimmortalise"],
];

pub(crate) static ENTRY_UNIMMUNIZED_15421817966409765637: VariantsMap = [
    &["unimmunized"],
    &["unimmunised"],
    &["unimmunized"],
    &["unimmunised"],
];

pub(crate) static ENTRY_UNINDIVIDUALIZED_10177440970236663663: VariantsMap = [
    &["unindividualized"],
    &["unindividualised"],
    &["unindividualized"],
    &["unindividualised"],
];

pub(crate) static ENTRY_UNINDIVIDUALIZES_4576420283626985656: VariantsMap = [
    &["unindividualizes"],
    &["unindividualises"],
    &["unindividualizes"],
    &["unindividualises"],
];

pub(crate) static ENTRY_UNINDIVIDUALIZE_2549502263365684965: VariantsMap = [
    &["unindividualize"],
    &["unindividualise"],
    &["unindividualize"],
    &["unindividualise"],
];

pub(crate) static ENTRY_UNINDUSTRIALIZEDS_11481755961805717216: VariantsMap = [
    &["unindustrializeds"],
    &["unindustrialiseds"],
    &["unindustrializeds"],
    &["unindustrialiseds"],
];

pub(crate) static ENTRY_UNINDUSTRIALIZED_11443997120471272739: VariantsMap = [
    &["unindustrialized"],
    &["unindustrialised"],
    &["unindustrialized"],
    &["unindustrialised"],
];

pub(crate) static ENTRY_UNINITIALIZABLE_11628725753710848165: VariantsMap = [
    &["uninitializable"],
    &["uninitialisable"],
    &["uninitializable"],
    &["uninitialisable"],
];

pub(crate) static ENTRY_UNINITIALIZED_7444780362077778288: VariantsMap = [
    &["uninitialized"],
    &["uninitialised"],
    &["uninitialized"],
    &["uninitialised"],
];

pub(crate) static ENTRY_UNIONIZATIONS_14252170992346338262: VariantsMap = [
    &["unionizations"],
    &["unionisations"],
    &["unionizations"],
    &["unionisations"],
];

pub(crate) static ENTRY_UNIONIZATION_7581063025295044509: VariantsMap = [
    &["unionization"],
    &["unionisation"],
    &["unionization"],
    &["unionisation"],
];

pub(crate) static ENTRY_UNIONIZED_15115860277830672338: VariantsMap = [
    &["unionized"],
    &["unionised"],
    &["unionized"],
    &["unionised"],
];

pub(crate) static ENTRY_UNIONIZERS_5139286031818390886: VariantsMap = [
    &["unionizers"],
    &["unionisers"],
    &["unionizers"],
    &["unionisers"],
];

pub(crate) static ENTRY_UNIONIZER_7597490110750505710: VariantsMap = [
    &["unionizer"],
    &["unioniser"],
    &["unionizer"],
    &["unioniser"],
];

pub(crate) static ENTRY_UNIONIZES_15451870011342312257: VariantsMap = [
    &["unionizes"],
    &["unionises"],
    &["unionizes"],
    &["unionises"],
];

pub(crate) static ENTRY_UNIONIZE_5473899911122601155: VariantsMap =
    [&["unionize"], &["unionise"], &["unionize"], &["unionise"]];

pub(crate) static ENTRY_UNIONIZING_13986959004042777567: VariantsMap = [
    &["unionizing"],
    &["unionising"],
    &["unionizing"],
    &["unionising"],
];

pub(crate) static ENTRY_UNITALICIZED_4803411370795702968: VariantsMap = [
    &["unitalicized"],
    &["unitalicised"],
    &["unitalicized"],
    &["unitalicised"],
];

pub(crate) static ENTRY_UNITARIANIZES_3299086072898342977: VariantsMap = [
    &["unitarianizes"],
    &["unitarianises"],
    &["unitarianizes"],
    &["unitarianises"],
];

pub(crate) static ENTRY_UNITARIANIZE_11972012307902630006: VariantsMap = [
    &["unitarianize"],
    &["unitarianise"],
    &["unitarianize"],
    &["unitarianise"],
];

pub(crate) static ENTRY_UNITEMIZED_4057716424445166287: VariantsMap = [
    &["unitemized"],
    &["unitemised"],
    &["unitemized"],
    &["unitemised"],
];

pub(crate) static ENTRY_UNITIZATIONS_11931524709956438375: VariantsMap = [
    &["unitizations"],
    &["unitisations"],
    &["unitizations"],
    &["unitisations"],
];

pub(crate) static ENTRY_UNITIZATION_18446645945229573845: VariantsMap = [
    &["unitization"],
    &["unitisation"],
    &["unitization"],
    &["unitisation"],
];

pub(crate) static ENTRY_UNITIZED_3014655947841823471: VariantsMap =
    [&["unitized"], &["unitised"], &["unitized"], &["unitised"]];

pub(crate) static ENTRY_UNITIZES_11137940003038331316: VariantsMap =
    [&["unitizes"], &["unitises"], &["unitizes"], &["unitises"]];

pub(crate) static ENTRY_UNITIZE_15650295066694421044: VariantsMap =
    [&["unitize"], &["unitise"], &["unitize"], &["unitise"]];

pub(crate) static ENTRY_UNITIZING_14503461086641416326: VariantsMap = [
    &["unitizing"],
    &["unitising"],
    &["unitizing"],
    &["unitising"],
];

pub(crate) static ENTRY_UNIVERSALIZATIONS_18379991359571582461: VariantsMap = [
    &["universalizations"],
    &["universalisations"],
    &["universalizations"],
    &["universalisations"],
];

pub(crate) static ENTRY_UNIVERSALIZATION_9796721220313365644: VariantsMap = [
    &["universalization"],
    &["universalisation"],
    &["universalization"],
    &["universalisation"],
];

pub(crate) static ENTRY_UNIVERSALIZED_3359716000611655342: VariantsMap = [
    &["universalized"],
    &["universalised"],
    &["universalized"],
    &["universalised"],
];

pub(crate) static ENTRY_UNIVERSALIZERS_10160828143436328394: VariantsMap = [
    &["universalizers"],
    &["universalisers"],
    &["universalizers"],
    &["universalisers"],
];

pub(crate) static ENTRY_UNIVERSALIZER_15363421758448558519: VariantsMap = [
    &["universalizer"],
    &["universaliser"],
    &["universalizer"],
    &["universaliser"],
];

pub(crate) static ENTRY_UNIVERSALIZES_5744703348821395274: VariantsMap = [
    &["universalizes"],
    &["universalises"],
    &["universalizes"],
    &["universalises"],
];

pub(crate) static ENTRY_UNIVERSALIZE_3144285012366914544: VariantsMap = [
    &["universalize"],
    &["universalise"],
    &["universalize"],
    &["universalise"],
];

pub(crate) static ENTRY_UNIVERSALIZING_3081768953979402863: VariantsMap = [
    &["universalizing"],
    &["universalising"],
    &["universalizing"],
    &["universalising"],
];

pub(crate) static ENTRY_UNJEOPARDIZED_13875602294611166238: VariantsMap = [
    &["unjeopardized"],
    &["unjeopardised"],
    &["unjeopardized"],
    &["unjeopardised"],
];

pub(crate) static ENTRY_UNJOURNALIZED_7826187459873218620: VariantsMap = [
    &["unjournalized"],
    &["unjournalised"],
    &["unjournalized"],
    &["unjournalised"],
];

pub(crate) static ENTRY_UNKENNELED_3312308653646352421: VariantsMap = [
    &["unkenneled"],
    &["unkennelled"],
    &["unkennelled"],
    &["unkennelled"],
];

pub(crate) static ENTRY_UNKENNELING_10813411767613768190: VariantsMap = [
    &["unkenneling"],
    &["unkennelling"],
    &["unkennelling"],
    &["unkennelling"],
];

pub(crate) static ENTRY_UNLABELEDDER_12664387197615721853: VariantsMap = [
    &["unlabeledder"],
    &["unlabelledder"],
    &["unlabelledder"],
    &["unlabelledder"],
];

pub(crate) static ENTRY_UNLABELEDDEST_10069015802563086742: VariantsMap = [
    &["unlabeleddest"],
    &["unlabelleddest"],
    &["unlabelleddest"],
    &["unlabelleddest"],
];

pub(crate) static ENTRY_UNLABELED_11329682996906852666: VariantsMap = [
    &["unlabeled"],
    &["unlabelled"],
    &["unlabelled"],
    &["unlabelled"],
];

pub(crate) static ENTRY_UNLABIALIZED_3984566951140164532: VariantsMap = [
    &["unlabialized"],
    &["unlabialised"],
    &["unlabialized"],
    &["unlabialised"],
];

pub(crate) static ENTRY_UNLABIALIZES_5567127362436352005: VariantsMap = [
    &["unlabializes"],
    &["unlabialises"],
    &["unlabializes"],
    &["unlabialises"],
];

pub(crate) static ENTRY_UNLABIALIZE_217736053462734651: VariantsMap = [
    &["unlabialize"],
    &["unlabialise"],
    &["unlabialize"],
    &["unlabialise"],
];

pub(crate) static ENTRY_UNLABIALIZING_6104103553465648864: VariantsMap = [
    &["unlabializing"],
    &["unlabialising"],
    &["unlabializing"],
    &["unlabialising"],
];

pub(crate) static ENTRY_UNLABORABLES_6698240791463419426: VariantsMap = [
    &["unlaborables"],
    &["unlabourables"],
    &["unlabourables"],
    &["unlabourables"],
];

pub(crate) static ENTRY_UNLABORABLE_917849914005923474: VariantsMap = [
    &["unlaborable"],
    &["unlabourable"],
    &["unlabourable"],
    &["unlabourable"],
];

pub(crate) static ENTRY_UNLABOREDDER_11699946147571417125: VariantsMap = [
    &["unlaboredder"],
    &["unlabouredder"],
    &["unlabouredder"],
    &["unlabouredder"],
];

pub(crate) static ENTRY_UNLABOREDDEST_1362587359789372781: VariantsMap = [
    &["unlaboreddest"],
    &["unlaboureddest"],
    &["unlaboureddest"],
    &["unlaboureddest"],
];

pub(crate) static ENTRY_UNLABORED_16469902531770188672: VariantsMap = [
    &["unlabored"],
    &["unlaboured"],
    &["unlaboured"],
    &["unlaboured"],
];

pub(crate) static ENTRY_UNLABORINGER_6365954446709867985: VariantsMap = [
    &["unlaboringer"],
    &["unlabouringer"],
    &["unlabouringer"],
    &["unlabouringer"],
];

pub(crate) static ENTRY_UNLABORINGEST_1473791691960115175: VariantsMap = [
    &["unlaboringest"],
    &["unlabouringest"],
    &["unlabouringest"],
    &["unlabouringest"],
];

pub(crate) static ENTRY_UNLABORINGS_4425858704820356556: VariantsMap = [
    &["unlaborings"],
    &["unlabourings"],
    &["unlabourings"],
    &["unlabourings"],
];

pub(crate) static ENTRY_UNLABORING_4591372183864637896: VariantsMap = [
    &["unlaboring"],
    &["unlabouring"],
    &["unlabouring"],
    &["unlabouring"],
];

pub(crate) static ENTRY_UNLEARNED_9662354567541580896: VariantsMap = [
    &["unlearned"],
    &["unlearned", "unlearnt"],
    &["unlearned"],
    &["unlearned", "unlearnt"],
];

pub(crate) static ENTRY_UNLEGALIZEDDER_6121814624457190630: VariantsMap = [
    &["unlegalizedder"],
    &["unlegalisedder"],
    &["unlegalizedder"],
    &["unlegalisedder"],
];

pub(crate) static ENTRY_UNLEGALIZEDDEST_1908746545075061751: VariantsMap = [
    &["unlegalizeddest"],
    &["unlegaliseddest"],
    &["unlegalizeddest"],
    &["unlegaliseddest"],
];

pub(crate) static ENTRY_UNLEGALIZED_11280366291234483355: VariantsMap = [
    &["unlegalized"],
    &["unlegalised"],
    &["unlegalized"],
    &["unlegalised"],
];

pub(crate) static ENTRY_UNLEVELED_13198441829918947958: VariantsMap = [
    &["unleveled"],
    &["unlevelled"],
    &["unlevelled"],
    &["unlevelled"],
];

pub(crate) static ENTRY_UNLEVELING_8030863631176281003: VariantsMap = [
    &["unleveling"],
    &["unlevelling"],
    &["unlevelling"],
    &["unlevelling"],
];

pub(crate) static ENTRY_UNLIBERALIZEDDER_15315614160099270434: VariantsMap = [
    &["unliberalizedder"],
    &["unliberalisedder"],
    &["unliberalizedder"],
    &["unliberalisedder"],
];

pub(crate) static ENTRY_UNLIBERALIZEDDEST_13889596379187644396: VariantsMap = [
    &["unliberalizeddest"],
    &["unliberaliseddest"],
    &["unliberalizeddest"],
    &["unliberaliseddest"],
];

pub(crate) static ENTRY_UNLIBERALIZED_10969839816283449452: VariantsMap = [
    &["unliberalized"],
    &["unliberalised"],
    &["unliberalized"],
    &["unliberalised"],
];

pub(crate) static ENTRY_UNLIONIZED_16819690612045451722: VariantsMap = [
    &["unlionized"],
    &["unlionised"],
    &["unlionized"],
    &["unlionised"],
];

pub(crate) static ENTRY_UNLITERALIZED_5582864502376513867: VariantsMap = [
    &["unliteralized"],
    &["unliteralised"],
    &["unliteralized"],
    &["unliteralised"],
];

pub(crate) static ENTRY_UNLOCALIZABLER_1057258441085295588: VariantsMap = [
    &["unlocalizabler"],
    &["unlocalisabler"],
    &["unlocalizabler"],
    &["unlocalisabler"],
];

pub(crate) static ENTRY_UNLOCALIZABLEST_15276491984146533505: VariantsMap = [
    &["unlocalizablest"],
    &["unlocalisablest"],
    &["unlocalizablest"],
    &["unlocalisablest"],
];

pub(crate) static ENTRY_UNLOCALIZABLES_11709528533561573241: VariantsMap = [
    &["unlocalizables"],
    &["unlocalisables"],
    &["unlocalizables"],
    &["unlocalisables"],
];

pub(crate) static ENTRY_UNLOCALIZABLE_9968738969162630281: VariantsMap = [
    &["unlocalizable"],
    &["unlocalisable"],
    &["unlocalizable"],
    &["unlocalisable"],
];

pub(crate) static ENTRY_UNLOCALIZED_13119882870487585082: VariantsMap = [
    &["unlocalized"],
    &["unlocalised"],
    &["unlocalized"],
    &["unlocalised"],
];

pub(crate) static ENTRY_UNLOCALIZES_3658083138206741140: VariantsMap = [
    &["unlocalizes"],
    &["unlocalises"],
    &["unlocalizes"],
    &["unlocalises"],
];

pub(crate) static ENTRY_UNLOCALIZE_13492036293954003927: VariantsMap = [
    &["unlocalize"],
    &["unlocalise"],
    &["unlocalize"],
    &["unlocalise"],
];

pub(crate) static ENTRY_UNLOCALIZING_11595539427192644971: VariantsMap = [
    &["unlocalizing"],
    &["unlocalising"],
    &["unlocalizing"],
    &["unlocalising"],
];

pub(crate) static ENTRY_UNMACADAMIZED_17474698526570727920: VariantsMap = [
    &["unmacadamized"],
    &["unmacadamised"],
    &["unmacadamized"],
    &["unmacadamised"],
];

pub(crate) static ENTRY_UNMAGNETIZEDDER_15921026948300347060: VariantsMap = [
    &["unmagnetizedder"],
    &["unmagnetisedder"],
    &["unmagnetizedder"],
    &["unmagnetisedder"],
];

pub(crate) static ENTRY_UNMAGNETIZEDDEST_9811017267349487901: VariantsMap = [
    &["unmagnetizeddest"],
    &["unmagnetiseddest"],
    &["unmagnetizeddest"],
    &["unmagnetiseddest"],
];

pub(crate) static ENTRY_UNMAGNETIZEDS_18035379637239565234: VariantsMap = [
    &["unmagnetizeds"],
    &["unmagnetiseds"],
    &["unmagnetizeds"],
    &["unmagnetiseds"],
];

pub(crate) static ENTRY_UNMAGNETIZED_15659278602348180756: VariantsMap = [
    &["unmagnetized"],
    &["unmagnetised"],
    &["unmagnetized"],
    &["unmagnetised"],
];

pub(crate) static ENTRY_UNMATERIALIZED_2222039272937406727: VariantsMap = [
    &["unmaterialized"],
    &["unmaterialised"],
    &["unmaterialized"],
    &["unmaterialised"],
];

pub(crate) static ENTRY_UNMECHANIZED_4269395601940403385: VariantsMap = [
    &["unmechanized"],
    &["unmechanised"],
    &["unmechanized"],
    &["unmechanised"],
];

pub(crate) static ENTRY_UNMECHANIZES_165760147883759220: VariantsMap = [
    &["unmechanizes"],
    &["unmechanises"],
    &["unmechanizes"],
    &["unmechanises"],
];

pub(crate) static ENTRY_UNMECHANIZE_11190176714541551865: VariantsMap = [
    &["unmechanize"],
    &["unmechanise"],
    &["unmechanize"],
    &["unmechanise"],
];

pub(crate) static ENTRY_UNMECHANIZING_506881294102189838: VariantsMap = [
    &["unmechanizing"],
    &["unmechanising"],
    &["unmechanizing"],
    &["unmechanising"],
];

pub(crate) static ENTRY_UNMEDIATIZEDS_1136374808671187759: VariantsMap = [
    &["unmediatizeds"],
    &["unmediatiseds"],
    &["unmediatizeds"],
    &["unmediatiseds"],
];

pub(crate) static ENTRY_UNMEDIATIZED_2290392514230277768: VariantsMap = [
    &["unmediatized"],
    &["unmediatised"],
    &["unmediatized"],
    &["unmediatised"],
];

pub(crate) static ENTRY_UNMEDIEVAL_15136839068156180300: VariantsMap = [
    &["unmedieval"],
    &["unmediaeval"],
    &["unmediaeval"],
    &["unmediaeval"],
];

pub(crate) static ENTRY_UNMELODIZED_6500550653004535054: VariantsMap = [
    &["unmelodized"],
    &["unmelodised"],
    &["unmelodized"],
    &["unmelodised"],
];

pub(crate) static ENTRY_UNMEMORIALIZEDDER_10743801469581680168: VariantsMap = [
    &["unmemorializedder"],
    &["unmemorialisedder"],
    &["unmemorializedder"],
    &["unmemorialisedder"],
];

pub(crate) static ENTRY_UNMEMORIALIZEDDEST_13083723319671530750: VariantsMap = [
    &["unmemorializeddest"],
    &["unmemorialiseddest"],
    &["unmemorializeddest"],
    &["unmemorialiseddest"],
];

pub(crate) static ENTRY_UNMEMORIALIZEDS_14410279063249438063: VariantsMap = [
    &["unmemorializeds"],
    &["unmemorialiseds"],
    &["unmemorializeds"],
    &["unmemorialiseds"],
];

pub(crate) static ENTRY_UNMEMORIALIZED_6600017525226329095: VariantsMap = [
    &["unmemorialized"],
    &["unmemorialised"],
    &["unmemorialized"],
    &["unmemorialised"],
];

pub(crate) static ENTRY_UNMEMORIZED_14626006795396178705: VariantsMap = [
    &["unmemorized"],
    &["unmemorised"],
    &["unmemorized"],
    &["unmemorised"],
];

pub(crate) static ENTRY_UNMERCERIZEDS_401622175139065596: VariantsMap = [
    &["unmercerizeds"],
    &["unmerceriseds"],
    &["unmercerizeds"],
    &["unmerceriseds"],
];

pub(crate) static ENTRY_UNMERCERIZED_5852682934764830097: VariantsMap = [
    &["unmercerized"],
    &["unmercerised"],
    &["unmercerized"],
    &["unmercerised"],
];

pub(crate) static ENTRY_UNMESMERIZEDDER_2203744214809621680: VariantsMap = [
    &["unmesmerizedder"],
    &["unmesmerisedder"],
    &["unmesmerizedder"],
    &["unmesmerisedder"],
];

pub(crate) static ENTRY_UNMESMERIZEDDEST_6656931439181344486: VariantsMap = [
    &["unmesmerizeddest"],
    &["unmesmeriseddest"],
    &["unmesmerizeddest"],
    &["unmesmeriseddest"],
];

pub(crate) static ENTRY_UNMESMERIZED_15728753808617264765: VariantsMap = [
    &["unmesmerized"],
    &["unmesmerised"],
    &["unmesmerized"],
    &["unmesmerised"],
];

pub(crate) static ENTRY_UNMESMERIZES_18225538558952151368: VariantsMap = [
    &["unmesmerizes"],
    &["unmesmerises"],
    &["unmesmerizes"],
    &["unmesmerises"],
];

pub(crate) static ENTRY_UNMESMERIZE_14813961012908823827: VariantsMap = [
    &["unmesmerize"],
    &["unmesmerise"],
    &["unmesmerize"],
    &["unmesmerise"],
];

pub(crate) static ENTRY_UNMETALIZEDS_3049138545470459904: VariantsMap = [
    &["unmetalizeds"],
    &["unmetalliseds"],
    &["unmetallizeds"],
    &["unmetalliseds"],
];

pub(crate) static ENTRY_UNMETALIZED_14653098959762201949: VariantsMap = [
    &["unmetalized"],
    &["unmetallised"],
    &["unmetallized"],
    &["unmetallised"],
];

pub(crate) static ENTRY_UNMETHODIZEDDER_14167275580698305003: VariantsMap = [
    &["unmethodizedder"],
    &["unmethodisedder"],
    &["unmethodizedder"],
    &["unmethodisedder"],
];

pub(crate) static ENTRY_UNMETHODIZEDDEST_5772600382723646544: VariantsMap = [
    &["unmethodizeddest"],
    &["unmethodiseddest"],
    &["unmethodizeddest"],
    &["unmethodiseddest"],
];

pub(crate) static ENTRY_UNMETHODIZEDS_10683531682808152372: VariantsMap = [
    &["unmethodizeds"],
    &["unmethodiseds"],
    &["unmethodizeds"],
    &["unmethodiseds"],
];

pub(crate) static ENTRY_UNMETHODIZED_2715309362450077299: VariantsMap = [
    &["unmethodized"],
    &["unmethodised"],
    &["unmethodized"],
    &["unmethodised"],
];

pub(crate) static ENTRY_UNMETHODIZINGER_3360650520164951225: VariantsMap = [
    &["unmethodizinger"],
    &["unmethodisinger"],
    &["unmethodizinger"],
    &["unmethodisinger"],
];

pub(crate) static ENTRY_UNMETHODIZINGEST_7025390942240350340: VariantsMap = [
    &["unmethodizingest"],
    &["unmethodisingest"],
    &["unmethodizingest"],
    &["unmethodisingest"],
];

pub(crate) static ENTRY_UNMETHODIZINGS_15327848455170179924: VariantsMap = [
    &["unmethodizings"],
    &["unmethodisings"],
    &["unmethodizings"],
    &["unmethodisings"],
];

pub(crate) static ENTRY_UNMETHODIZING_4738341700288635217: VariantsMap = [
    &["unmethodizing"],
    &["unmethodising"],
    &["unmethodizing"],
    &["unmethodising"],
];

pub(crate) static ENTRY_UNMILITARIZED_583903044185013301: VariantsMap = [
    &["unmilitarized"],
    &["unmilitarised"],
    &["unmilitarized"],
    &["unmilitarised"],
];

pub(crate) static ENTRY_UNMINERALIZEDDER_15629225524896238795: VariantsMap = [
    &["unmineralizedder"],
    &["unmineralisedder"],
    &["unmineralizedder"],
    &["unmineralisedder"],
];

pub(crate) static ENTRY_UNMINERALIZEDDEST_9301755093437071771: VariantsMap = [
    &["unmineralizeddest"],
    &["unmineraliseddest"],
    &["unmineralizeddest"],
    &["unmineraliseddest"],
];

pub(crate) static ENTRY_UNMINERALIZEDS_14328671455943502679: VariantsMap = [
    &["unmineralizeds"],
    &["unmineraliseds"],
    &["unmineralizeds"],
    &["unmineraliseds"],
];

pub(crate) static ENTRY_UNMINERALIZED_13805636642989384132: VariantsMap = [
    &["unmineralized"],
    &["unmineralised"],
    &["unmineralized"],
    &["unmineralised"],
];

pub(crate) static ENTRY_UNMINIMIZEDDER_10273703457324240806: VariantsMap = [
    &["unminimizedder"],
    &["unminimisedder"],
    &["unminimizedder"],
    &["unminimisedder"],
];

pub(crate) static ENTRY_UNMINIMIZEDDEST_2442440839355809588: VariantsMap = [
    &["unminimizeddest"],
    &["unminimiseddest"],
    &["unminimizeddest"],
    &["unminimiseddest"],
];

pub(crate) static ENTRY_UNMINIMIZED_2413573858255300069: VariantsMap = [
    &["unminimized"],
    &["unminimised"],
    &["unminimized"],
    &["unminimised"],
];

pub(crate) static ENTRY_UNMINIMIZING_14406353280475862221: VariantsMap = [
    &["unminimizing"],
    &["unminimising"],
    &["unminimizing"],
    &["unminimising"],
];

pub(crate) static ENTRY_UNMISSIONIZEDS_10090086707555908231: VariantsMap = [
    &["unmissionizeds"],
    &["unmissioniseds"],
    &["unmissionizeds"],
    &["unmissioniseds"],
];

pub(crate) static ENTRY_UNMISSIONIZED_8479883138336012141: VariantsMap = [
    &["unmissionized"],
    &["unmissionised"],
    &["unmissionized"],
    &["unmissionised"],
];

pub(crate) static ENTRY_UNMITERS_8651507553417273017: VariantsMap =
    [&["unmiters"], &["unmitres"], &["unmitres"], &["unmitres"]];

pub(crate) static ENTRY_UNMITER_1266556994873335198: VariantsMap =
    [&["unmiter"], &["unmitre"], &["unmitre"], &["unmitre"]];

pub(crate) static ENTRY_UNMOBILIZEDDER_13885990523982700388: VariantsMap = [
    &["unmobilizedder"],
    &["unmobilisedder"],
    &["unmobilizedder"],
    &["unmobilisedder"],
];

pub(crate) static ENTRY_UNMOBILIZEDDEST_16430132456615956501: VariantsMap = [
    &["unmobilizeddest"],
    &["unmobiliseddest"],
    &["unmobilizeddest"],
    &["unmobiliseddest"],
];

pub(crate) static ENTRY_UNMOBILIZEDS_2823498892381128223: VariantsMap = [
    &["unmobilizeds"],
    &["unmobiliseds"],
    &["unmobilizeds"],
    &["unmobiliseds"],
];

pub(crate) static ENTRY_UNMOBILIZED_8792915223828792882: VariantsMap = [
    &["unmobilized"],
    &["unmobilised"],
    &["unmobilized"],
    &["unmobilised"],
];

pub(crate) static ENTRY_UNMODERNIZEDDER_17177773102034890156: VariantsMap = [
    &["unmodernizedder"],
    &["unmodernisedder"],
    &["unmodernizedder"],
    &["unmodernisedder"],
];

pub(crate) static ENTRY_UNMODERNIZEDDEST_6107579015702829368: VariantsMap = [
    &["unmodernizeddest"],
    &["unmoderniseddest"],
    &["unmodernizeddest"],
    &["unmoderniseddest"],
];

pub(crate) static ENTRY_UNMODERNIZED_12442385813229323597: VariantsMap = [
    &["unmodernized"],
    &["unmodernised"],
    &["unmodernized"],
    &["unmodernised"],
];

pub(crate) static ENTRY_UNMODERNIZES_16814040681635851958: VariantsMap = [
    &["unmodernizes"],
    &["unmodernises"],
    &["unmodernizes"],
    &["unmodernises"],
];

pub(crate) static ENTRY_UNMODERNIZE_12047442119533678951: VariantsMap = [
    &["unmodernize"],
    &["unmodernise"],
    &["unmodernize"],
    &["unmodernise"],
];

pub(crate) static ENTRY_UNMONOPOLIZEDDER_367444066669166581: VariantsMap = [
    &["unmonopolizedder"],
    &["unmonopolisedder"],
    &["unmonopolizedder"],
    &["unmonopolisedder"],
];

pub(crate) static ENTRY_UNMONOPOLIZEDDEST_11036465831290540300: VariantsMap = [
    &["unmonopolizeddest"],
    &["unmonopoliseddest"],
    &["unmonopolizeddest"],
    &["unmonopoliseddest"],
];

pub(crate) static ENTRY_UNMONOPOLIZED_15103252142985776491: VariantsMap = [
    &["unmonopolized"],
    &["unmonopolised"],
    &["unmonopolized"],
    &["unmonopolised"],
];

pub(crate) static ENTRY_UNMONOPOLIZES_8604670551607021504: VariantsMap = [
    &["unmonopolizes"],
    &["unmonopolises"],
    &["unmonopolizes"],
    &["unmonopolises"],
];

pub(crate) static ENTRY_UNMONOPOLIZE_8209609104862396740: VariantsMap = [
    &["unmonopolize"],
    &["unmonopolise"],
    &["unmonopolize"],
    &["unmonopolise"],
];

pub(crate) static ENTRY_UNMONOPOLIZINGER_8082734413560432137: VariantsMap = [
    &["unmonopolizinger"],
    &["unmonopolisinger"],
    &["unmonopolizinger"],
    &["unmonopolisinger"],
];

pub(crate) static ENTRY_UNMONOPOLIZINGEST_16940303846507911638: VariantsMap = [
    &["unmonopolizingest"],
    &["unmonopolisingest"],
    &["unmonopolizingest"],
    &["unmonopolisingest"],
];

pub(crate) static ENTRY_UNMONOPOLIZINGS_2368394829208842158: VariantsMap = [
    &["unmonopolizings"],
    &["unmonopolisings"],
    &["unmonopolizings"],
    &["unmonopolisings"],
];

pub(crate) static ENTRY_UNMONOPOLIZING_780658382091540167: VariantsMap = [
    &["unmonopolizing"],
    &["unmonopolising"],
    &["unmonopolizing"],
    &["unmonopolising"],
];

pub(crate) static ENTRY_UNMORALIZED_1809019658766145871: VariantsMap = [
    &["unmoralized"],
    &["unmoralised"],
    &["unmoralized"],
    &["unmoralised"],
];

pub(crate) static ENTRY_UNMORALIZES_2054617732298010888: VariantsMap = [
    &["unmoralizes"],
    &["unmoralises"],
    &["unmoralizes"],
    &["unmoralises"],
];

pub(crate) static ENTRY_UNMORALIZE_5811178603962947867: VariantsMap = [
    &["unmoralize"],
    &["unmoralise"],
    &["unmoralize"],
    &["unmoralise"],
];

pub(crate) static ENTRY_UNMORALIZINGER_2630621700200103097: VariantsMap = [
    &["unmoralizinger"],
    &["unmoralisinger"],
    &["unmoralizinger"],
    &["unmoralisinger"],
];

pub(crate) static ENTRY_UNMORALIZINGEST_10371338958162242360: VariantsMap = [
    &["unmoralizingest"],
    &["unmoralisingest"],
    &["unmoralizingest"],
    &["unmoralisingest"],
];

pub(crate) static ENTRY_UNMORALIZINGS_13530220804505456674: VariantsMap = [
    &["unmoralizings"],
    &["unmoralisings"],
    &["unmoralizings"],
    &["unmoralisings"],
];

pub(crate) static ENTRY_UNMORALIZING_1635343207643393146: VariantsMap = [
    &["unmoralizing"],
    &["unmoralising"],
    &["unmoralizing"],
    &["unmoralising"],
];

pub(crate) static ENTRY_UNMOTORIZEDDER_4737848326164812310: VariantsMap = [
    &["unmotorizedder"],
    &["unmotorisedder"],
    &["unmotorizedder"],
    &["unmotorisedder"],
];

pub(crate) static ENTRY_UNMOTORIZEDDEST_15245325937655928512: VariantsMap = [
    &["unmotorizeddest"],
    &["unmotoriseddest"],
    &["unmotorizeddest"],
    &["unmotoriseddest"],
];

pub(crate) static ENTRY_UNMOTORIZED_6782143677493579372: VariantsMap = [
    &["unmotorized"],
    &["unmotorised"],
    &["unmotorized"],
    &["unmotorised"],
];

pub(crate) static ENTRY_UNMUNICIPALIZEDDER_308188906530115010: VariantsMap = [
    &["unmunicipalizedder"],
    &["unmunicipalisedder"],
    &["unmunicipalizedder"],
    &["unmunicipalisedder"],
];

pub(crate) static ENTRY_UNMUNICIPALIZEDDEST_17406856610278064067: VariantsMap = [
    &["unmunicipalizeddest"],
    &["unmunicipaliseddest"],
    &["unmunicipalizeddest"],
    &["unmunicipaliseddest"],
];

pub(crate) static ENTRY_UNMUNICIPALIZEDS_10306483843849279865: VariantsMap = [
    &["unmunicipalizeds"],
    &["unmunicipaliseds"],
    &["unmunicipalizeds"],
    &["unmunicipaliseds"],
];

pub(crate) static ENTRY_UNMUNICIPALIZED_11558570840724190274: VariantsMap = [
    &["unmunicipalized"],
    &["unmunicipalised"],
    &["unmunicipalized"],
    &["unmunicipalised"],
];

pub(crate) static ENTRY_UNMUTUALIZEDDER_15475671606898414830: VariantsMap = [
    &["unmutualizedder"],
    &["unmutualisedder"],
    &["unmutualizedder"],
    &["unmutualisedder"],
];

pub(crate) static ENTRY_UNMUTUALIZEDDEST_9840735398085807516: VariantsMap = [
    &["unmutualizeddest"],
    &["unmutualiseddest"],
    &["unmutualizeddest"],
    &["unmutualiseddest"],
];

pub(crate) static ENTRY_UNMUTUALIZEDS_11478246322803926821: VariantsMap = [
    &["unmutualizeds"],
    &["unmutualiseds"],
    &["unmutualizeds"],
    &["unmutualiseds"],
];

pub(crate) static ENTRY_UNMUTUALIZED_3987921361376909408: VariantsMap = [
    &["unmutualized"],
    &["unmutualised"],
    &["unmutualized"],
    &["unmutualised"],
];

pub(crate) static ENTRY_UNMYSTICIZED_3871960656463594608: VariantsMap = [
    &["unmysticized"],
    &["unmysticised"],
    &["unmysticized"],
    &["unmysticised"],
];

pub(crate) static ENTRY_UNMYSTICIZES_593169946783893980: VariantsMap = [
    &["unmysticizes"],
    &["unmysticises"],
    &["unmysticizes"],
    &["unmysticises"],
];

pub(crate) static ENTRY_UNMYSTICIZE_6752614279344741289: VariantsMap = [
    &["unmysticize"],
    &["unmysticise"],
    &["unmysticize"],
    &["unmysticise"],
];

pub(crate) static ENTRY_UNMYSTICIZING_7832774330196959394: VariantsMap = [
    &["unmysticizing"],
    &["unmysticising"],
    &["unmysticizing"],
    &["unmysticising"],
];

pub(crate) static ENTRY_UNNATIONALIZEDDER_16819534566496048883: VariantsMap = [
    &["unnationalizedder"],
    &["unnationalisedder"],
    &["unnationalizedder"],
    &["unnationalisedder"],
];

pub(crate) static ENTRY_UNNATIONALIZEDDEST_6627375631914479221: VariantsMap = [
    &["unnationalizeddest"],
    &["unnationaliseddest"],
    &["unnationalizeddest"],
    &["unnationaliseddest"],
];

pub(crate) static ENTRY_UNNATIONALIZED_17413125925681224817: VariantsMap = [
    &["unnationalized"],
    &["unnationalised"],
    &["unnationalized"],
    &["unnationalised"],
];

pub(crate) static ENTRY_UNNATURALIZABLES_15331368327954336002: VariantsMap = [
    &["unnaturalizables"],
    &["unnaturalisables"],
    &["unnaturalizables"],
    &["unnaturalisables"],
];

pub(crate) static ENTRY_UNNATURALIZABLE_11245054765720939783: VariantsMap = [
    &["unnaturalizable"],
    &["unnaturalisable"],
    &["unnaturalizable"],
    &["unnaturalisable"],
];

pub(crate) static ENTRY_UNNATURALIZED_12904128484572003805: VariantsMap = [
    &["unnaturalized"],
    &["unnaturalised"],
    &["unnaturalized"],
    &["unnaturalised"],
];

pub(crate) static ENTRY_UNNATURALIZES_15417405462560090882: VariantsMap = [
    &["unnaturalizes"],
    &["unnaturalises"],
    &["unnaturalizes"],
    &["unnaturalises"],
];

pub(crate) static ENTRY_UNNATURALIZE_8515448021724973747: VariantsMap = [
    &["unnaturalize"],
    &["unnaturalise"],
    &["unnaturalize"],
    &["unnaturalise"],
];

pub(crate) static ENTRY_UNNATURALIZING_8059644534756052716: VariantsMap = [
    &["unnaturalizing"],
    &["unnaturalising"],
    &["unnaturalizing"],
    &["unnaturalising"],
];

pub(crate) static ENTRY_UNNEIGHBORED_17137517992514420389: VariantsMap = [
    &["unneighbored"],
    &["unneighboured"],
    &["unneighboured"],
    &["unneighboured"],
];

pub(crate) static ENTRY_UNNEIGHBORLIER_16702491867279586093: VariantsMap = [
    &["unneighborlier"],
    &["unneighbourlier"],
    &["unneighbourlier"],
    &["unneighbourlier"],
];

pub(crate) static ENTRY_UNNEIGHBORLIEST_12419433861097517248: VariantsMap = [
    &["unneighborliest"],
    &["unneighbourliest"],
    &["unneighbourliest"],
    &["unneighbourliest"],
];

pub(crate) static ENTRY_UNNEIGHBORLIKES_4354261620124645883: VariantsMap = [
    &["unneighborlikes"],
    &["unneighbourlikes"],
    &["unneighbourlikes"],
    &["unneighbourlikes"],
];

pub(crate) static ENTRY_UNNEIGHBORLIKE_10218446635184503929: VariantsMap = [
    &["unneighborlike"],
    &["unneighbourlike"],
    &["unneighbourlike"],
    &["unneighbourlike"],
];

pub(crate) static ENTRY_UNNEIGHBORLINESSES_10829695068225729738: VariantsMap = [
    &["unneighborlinesses"],
    &["unneighbourlinesses"],
    &["unneighbourlinesses"],
    &["unneighbourlinesses"],
];

pub(crate) static ENTRY_UNNEIGHBORLINESS_1038976996631322927: VariantsMap = [
    &["unneighborliness"],
    &["unneighbourliness"],
    &["unneighbourliness"],
    &["unneighbourliness"],
];

pub(crate) static ENTRY_UNNEIGHBORLY_14423135391726748415: VariantsMap = [
    &["unneighborly"],
    &["unneighbourly"],
    &["unneighbourly"],
    &["unneighbourly"],
];

pub(crate) static ENTRY_UNNEUTRALIZED_10386359248112453405: VariantsMap = [
    &["unneutralized"],
    &["unneutralised"],
    &["unneutralized"],
    &["unneutralised"],
];

pub(crate) static ENTRY_UNNEUTRALIZE_4698429815634199128: VariantsMap = [
    &["unneutralize"],
    &["unneutralise"],
    &["unneutralize"],
    &["unneutralise"],
];

pub(crate) static ENTRY_UNNEUTRALIZING_4249099403406146838: VariantsMap = [
    &["unneutralizing"],
    &["unneutralising"],
    &["unneutralizing"],
    &["unneutralising"],
];

pub(crate) static ENTRY_UNNITROGENIZEDDER_15494417655163954478: VariantsMap = [
    &["unnitrogenizedder"],
    &["unnitrogenisedder"],
    &["unnitrogenizedder"],
    &["unnitrogenisedder"],
];

pub(crate) static ENTRY_UNNITROGENIZEDDEST_14262521068869718443: VariantsMap = [
    &["unnitrogenizeddest"],
    &["unnitrogeniseddest"],
    &["unnitrogenizeddest"],
    &["unnitrogeniseddest"],
];

pub(crate) static ENTRY_UNNITROGENIZEDS_16716966430076186540: VariantsMap = [
    &["unnitrogenizeds"],
    &["unnitrogeniseds"],
    &["unnitrogenizeds"],
    &["unnitrogeniseds"],
];

pub(crate) static ENTRY_UNNITROGENIZED_9970825803449823138: VariantsMap = [
    &["unnitrogenized"],
    &["unnitrogenised"],
    &["unnitrogenized"],
    &["unnitrogenised"],
];

pub(crate) static ENTRY_UNNONCOLORABLES_11603706591378503372: VariantsMap = [
    &["unnoncolorables"],
    &["unnoncolourables"],
    &["unnoncolourables"],
    &["unnoncolourables"],
];

pub(crate) static ENTRY_UNNONCOLORABLIES_9150435717670160252: VariantsMap = [
    &["unnoncolorablies"],
    &["unnoncolourablies"],
    &["unnoncolourablies"],
    &["unnoncolourablies"],
];

pub(crate) static ENTRY_UNNONCOLORABLY_5346203888294556991: VariantsMap = [
    &["unnoncolorably"],
    &["unnoncolourably"],
    &["unnoncolourably"],
    &["unnoncolourably"],
];

pub(crate) static ENTRY_UNNORMALIZEDDER_6088928097619406702: VariantsMap = [
    &["unnormalizedder"],
    &["unnormalisedder"],
    &["unnormalizedder"],
    &["unnormalisedder"],
];

pub(crate) static ENTRY_UNNORMALIZEDDEST_11709516950586687994: VariantsMap = [
    &["unnormalizeddest"],
    &["unnormaliseddest"],
    &["unnormalizeddest"],
    &["unnormaliseddest"],
];

pub(crate) static ENTRY_UNNORMALIZED_17182616854570086003: VariantsMap = [
    &["unnormalized"],
    &["unnormalised"],
    &["unnormalized"],
    &["unnormalised"],
];

pub(crate) static ENTRY_UNNORMALIZES_10633086048818529153: VariantsMap = [
    &["unnormalizes"],
    &["unnormalises"],
    &["unnormalizes"],
    &["unnormalises"],
];

pub(crate) static ENTRY_UNNORMALIZE_14634692936439819346: VariantsMap = [
    &["unnormalize"],
    &["unnormalise"],
    &["unnormalize"],
    &["unnormalise"],
];

pub(crate) static ENTRY_UNNORMALIZINGER_15099376100231731467: VariantsMap = [
    &["unnormalizinger"],
    &["unnormalisinger"],
    &["unnormalizinger"],
    &["unnormalisinger"],
];

pub(crate) static ENTRY_UNNORMALIZINGEST_247021487053357560: VariantsMap = [
    &["unnormalizingest"],
    &["unnormalisingest"],
    &["unnormalizingest"],
    &["unnormalisingest"],
];

pub(crate) static ENTRY_UNNORMALIZING_1754876569648213763: VariantsMap = [
    &["unnormalizing"],
    &["unnormalising"],
    &["unnormalizing"],
    &["unnormalising"],
];

pub(crate) static ENTRY_UNOPTIMIZED_16059827780503939479: VariantsMap = [
    &["unoptimized"],
    &["unoptimised"],
    &["unoptimized"],
    &["unoptimised"],
];

pub(crate) static ENTRY_UNOPTIMIZES_5417054465029431224: VariantsMap = [
    &["unoptimizes"],
    &["unoptimises"],
    &["unoptimizes"],
    &["unoptimises"],
];

pub(crate) static ENTRY_UNOPTIMIZE_8337218810202803852: VariantsMap = [
    &["unoptimize"],
    &["unoptimise"],
    &["unoptimize"],
    &["unoptimise"],
];

pub(crate) static ENTRY_UNOPTIMIZING_3167927648308310550: VariantsMap = [
    &["unoptimizing"],
    &["unoptimising"],
    &["unoptimizing"],
    &["unoptimising"],
];

pub(crate) static ENTRY_UNORGANIZABLER_2651332250209161850: VariantsMap = [
    &["unorganizabler"],
    &["unorganisabler"],
    &["unorganizabler"],
    &["unorganisabler"],
];

pub(crate) static ENTRY_UNORGANIZABLEST_13952098891985641540: VariantsMap = [
    &["unorganizablest"],
    &["unorganisablest"],
    &["unorganizablest"],
    &["unorganisablest"],
];

pub(crate) static ENTRY_UNORGANIZABLES_14263543529684744487: VariantsMap = [
    &["unorganizables"],
    &["unorganisables"],
    &["unorganizables"],
    &["unorganisables"],
];

pub(crate) static ENTRY_UNORGANIZABLE_11245437451639231261: VariantsMap = [
    &["unorganizable"],
    &["unorganisable"],
    &["unorganizable"],
    &["unorganisable"],
];

pub(crate) static ENTRY_UNORGANIZEDLY_17706812563099018840: VariantsMap = [
    &["unorganizedly"],
    &["unorganisedly"],
    &["unorganizedly"],
    &["unorganisedly"],
];

pub(crate) static ENTRY_UNORGANIZEDNESS_5163887181546451097: VariantsMap = [
    &["unorganizedness"],
    &["unorganisedness"],
    &["unorganizedness"],
    &["unorganisedness"],
];

pub(crate) static ENTRY_UNORGANIZED_8287041392290100911: VariantsMap = [
    &["unorganized"],
    &["unorganised"],
    &["unorganized"],
    &["unorganised"],
];

pub(crate) static ENTRY_UNORGANIZE_16055712748344908044: VariantsMap = [
    &["unorganize"],
    &["unorganise"],
    &["unorganize"],
    &["unorganise"],
];

pub(crate) static ENTRY_UNOXIDIZABLER_5359355858057190803: VariantsMap = [
    &["unoxidizabler"],
    &["unoxidisabler"],
    &["unoxidizabler"],
    &["unoxidisabler"],
];

pub(crate) static ENTRY_UNOXIDIZABLEST_6591525985530653060: VariantsMap = [
    &["unoxidizablest"],
    &["unoxidisablest"],
    &["unoxidizablest"],
    &["unoxidisablest"],
];

pub(crate) static ENTRY_UNOXIDIZABLES_17595850679261895025: VariantsMap = [
    &["unoxidizables"],
    &["unoxidisables"],
    &["unoxidizables"],
    &["unoxidisables"],
];

pub(crate) static ENTRY_UNOXIDIZABLE_16109933882822047402: VariantsMap = [
    &["unoxidizable"],
    &["unoxidisable"],
    &["unoxidizable"],
    &["unoxidisable"],
];

pub(crate) static ENTRY_UNOXIDIZEDDER_6144115144136830447: VariantsMap = [
    &["unoxidizedder"],
    &["unoxidisedder"],
    &["unoxidizedder"],
    &["unoxidisedder"],
];

pub(crate) static ENTRY_UNOXIDIZEDDEST_14507693636430734653: VariantsMap = [
    &["unoxidizeddest"],
    &["unoxidiseddest"],
    &["unoxidizeddest"],
    &["unoxidiseddest"],
];

pub(crate) static ENTRY_UNOXIDIZED_9470542236784645015: VariantsMap = [
    &["unoxidized"],
    &["unoxidised"],
    &["unoxidized"],
    &["unoxidised"],
];

pub(crate) static ENTRY_UNOXYGENIZEDS_14660262551929716023: VariantsMap = [
    &["unoxygenizeds"],
    &["unoxygeniseds"],
    &["unoxygenizeds"],
    &["unoxygeniseds"],
];

pub(crate) static ENTRY_UNOXYGENIZED_6875578357957209997: VariantsMap = [
    &["unoxygenized"],
    &["unoxygenised"],
    &["unoxygenized"],
    &["unoxygenised"],
];

pub(crate) static ENTRY_UNPAGANIZES_1814932462765931021: VariantsMap = [
    &["unpaganizes"],
    &["unpaganises"],
    &["unpaganizes"],
    &["unpaganises"],
];

pub(crate) static ENTRY_UNPAGANIZE_10797468704092625272: VariantsMap = [
    &["unpaganize"],
    &["unpaganise"],
    &["unpaganize"],
    &["unpaganise"],
];

pub(crate) static ENTRY_UNPALISADED_1035644440444378203: VariantsMap = [
    &["unpalisaded"],
    &["unpalisadoed"],
    &["unpalisadoed"],
    &["unpalisadoed"],
];

pub(crate) static ENTRY_UNPANEGYRIZED_12330222380120284751: VariantsMap = [
    &["unpanegyrized"],
    &["unpanegyrised"],
    &["unpanegyrized"],
    &["unpanegyrised"],
];

pub(crate) static ENTRY_UNPARAGONIZEDS_8828912894163008040: VariantsMap = [
    &["unparagonizeds"],
    &["unparagoniseds"],
    &["unparagonizeds"],
    &["unparagoniseds"],
];

pub(crate) static ENTRY_UNPARAGONIZED_11641249067400700762: VariantsMap = [
    &["unparagonized"],
    &["unparagonised"],
    &["unparagonized"],
    &["unparagonised"],
];

pub(crate) static ENTRY_UNPARALYZEDDER_10074788125617493696: VariantsMap = [
    &["unparalyzedder"],
    &["unparalysedder"],
    &["unparalysedder"],
    &["unparalysedder"],
];

pub(crate) static ENTRY_UNPARALYZEDDEST_8559985515751356281: VariantsMap = [
    &["unparalyzeddest"],
    &["unparalyseddest"],
    &["unparalyseddest"],
    &["unparalyseddest"],
];

pub(crate) static ENTRY_UNPARALYZEDS_17113201865707449563: VariantsMap = [
    &["unparalyzeds"],
    &["unparalyseds"],
    &["unparalyseds"],
    &["unparalyseds"],
];

pub(crate) static ENTRY_UNPARALYZED_14384393398387787974: VariantsMap = [
    &["unparalyzed"],
    &["unparalysed"],
    &["unparalysed"],
    &["unparalysed"],
];

pub(crate) static ENTRY_UNPARAMETERIZED_10261143125001624802: VariantsMap = [
    &["unparameterized"],
    &["unparameterised"],
    &["unparameterized"],
    &["unparameterised"],
];

pub(crate) static ENTRY_UNPARAMETRIZED_37046481284940289: VariantsMap = [
    &["unparametrized"],
    &["unparametrised"],
    &["unparametrized"],
    &["unparametrised"],
];

pub(crate) static ENTRY_UNPARCELEDDER_3319549837550214831: VariantsMap = [
    &["unparceledder"],
    &["unparcelledder"],
    &["unparcelledder"],
    &["unparcelledder"],
];

pub(crate) static ENTRY_UNPARCELEDDEST_4383492122712518630: VariantsMap = [
    &["unparceleddest"],
    &["unparcelleddest"],
    &["unparcelleddest"],
    &["unparcelleddest"],
];

pub(crate) static ENTRY_UNPARCELED_1373494415685202599: VariantsMap = [
    &["unparceled"],
    &["unparcelled"],
    &["unparcelled"],
    &["unparcelled"],
];

pub(crate) static ENTRY_UNPARENTHESIZED_18235036996914091846: VariantsMap = [
    &["unparenthesized"],
    &["unparenthesised"],
    &["unparenthesized"],
    &["unparenthesised"],
];

pub(crate) static ENTRY_UNPARTICULARIZEDDER_14810130530234822946: VariantsMap = [
    &["unparticularizedder"],
    &["unparticularisedder"],
    &["unparticularizedder"],
    &["unparticularisedder"],
];

pub(crate) static ENTRY_UNPARTICULARIZEDDEST_12461674155327065922: VariantsMap = [
    &["unparticularizeddest"],
    &["unparticulariseddest"],
    &["unparticularizeddest"],
    &["unparticulariseddest"],
];

pub(crate) static ENTRY_UNPARTICULARIZEDS_7009295388737864374: VariantsMap = [
    &["unparticularizeds"],
    &["unparticulariseds"],
    &["unparticularizeds"],
    &["unparticulariseds"],
];

pub(crate) static ENTRY_UNPARTICULARIZED_10369241482954824333: VariantsMap = [
    &["unparticularized"],
    &["unparticularised"],
    &["unparticularized"],
    &["unparticularised"],
];

pub(crate) static ENTRY_UNPARTICULARIZINGER_1405745460438104009: VariantsMap = [
    &["unparticularizinger"],
    &["unparticularisinger"],
    &["unparticularizinger"],
    &["unparticularisinger"],
];

pub(crate) static ENTRY_UNPARTICULARIZINGEST_12469995634183150832: VariantsMap = [
    &["unparticularizingest"],
    &["unparticularisingest"],
    &["unparticularizingest"],
    &["unparticularisingest"],
];

pub(crate) static ENTRY_UNPARTICULARIZINGS_12061998009550281971: VariantsMap = [
    &["unparticularizings"],
    &["unparticularisings"],
    &["unparticularizings"],
    &["unparticularisings"],
];

pub(crate) static ENTRY_UNPARTICULARIZING_17075351876595992224: VariantsMap = [
    &["unparticularizing"],
    &["unparticularising"],
    &["unparticularizing"],
    &["unparticularising"],
];

pub(crate) static ENTRY_UNPARTIZAN_4088887390151350638: VariantsMap = [
    &["unpartizan"],
    &["unpartisan"],
    &["unpartizan"],
    &["unpartisan"],
];

pub(crate) static ENTRY_UNPASTEURIZED_6016657477118674821: VariantsMap = [
    &["unpasteurized"],
    &["unpasteurised"],
    &["unpasteurized"],
    &["unpasteurised"],
];

pub(crate) static ENTRY_UNPATRONIZABLER_14355011026327328507: VariantsMap = [
    &["unpatronizabler"],
    &["unpatronisabler"],
    &["unpatronizabler"],
    &["unpatronisabler"],
];

pub(crate) static ENTRY_UNPATRONIZABLEST_16700885895853046350: VariantsMap = [
    &["unpatronizablest"],
    &["unpatronisablest"],
    &["unpatronizablest"],
    &["unpatronisablest"],
];

pub(crate) static ENTRY_UNPATRONIZABLES_5259054875641739571: VariantsMap = [
    &["unpatronizables"],
    &["unpatronisables"],
    &["unpatronizables"],
    &["unpatronisables"],
];

pub(crate) static ENTRY_UNPATRONIZABLE_1362396864066933771: VariantsMap = [
    &["unpatronizable"],
    &["unpatronisable"],
    &["unpatronizable"],
    &["unpatronisable"],
];

pub(crate) static ENTRY_UNPATRONIZED_6212197640341804006: VariantsMap = [
    &["unpatronized"],
    &["unpatronised"],
    &["unpatronized"],
    &["unpatronised"],
];

pub(crate) static ENTRY_UNPATRONIZING_315514134828674594: VariantsMap = [
    &["unpatronizing"],
    &["unpatronising"],
    &["unpatronizing"],
    &["unpatronising"],
];

pub(crate) static ENTRY_UNPAUPERIZEDS_13074066262081440105: VariantsMap = [
    &["unpauperizeds"],
    &["unpauperiseds"],
    &["unpauperizeds"],
    &["unpauperiseds"],
];

pub(crate) static ENTRY_UNPAUPERIZED_9404943598594952727: VariantsMap = [
    &["unpauperized"],
    &["unpauperised"],
    &["unpauperized"],
    &["unpauperised"],
];

pub(crate) static ENTRY_UNPENALIZEDDER_8199987065212676092: VariantsMap = [
    &["unpenalizedder"],
    &["unpenalisedder"],
    &["unpenalizedder"],
    &["unpenalisedder"],
];

pub(crate) static ENTRY_UNPENALIZEDDEST_9469524353322915881: VariantsMap = [
    &["unpenalizeddest"],
    &["unpenaliseddest"],
    &["unpenalizeddest"],
    &["unpenaliseddest"],
];

pub(crate) static ENTRY_UNPENALIZED_2142967108305186126: VariantsMap = [
    &["unpenalized"],
    &["unpenalised"],
    &["unpenalized"],
    &["unpenalised"],
];

pub(crate) static ENTRY_UNPERCEPTIVELY_16674495345486986764: VariantsMap = [
    &["unperceptively"],
    &["unpreceptively"],
    &["unpreceptively"],
    &["unpreceptively"],
];

pub(crate) static ENTRY_UNPERSONALIZED_10430124302522011652: VariantsMap = [
    &["unpersonalized"],
    &["unpersonalised"],
    &["unpersonalized"],
    &["unpersonalised"],
];

pub(crate) static ENTRY_UNPERSONALIZING_15562446084747354495: VariantsMap = [
    &["unpersonalizing"],
    &["unpersonalising"],
    &["unpersonalizing"],
    &["unpersonalising"],
];

pub(crate) static ENTRY_UNPHILOSOPHIZED_4478449938288203539: VariantsMap = [
    &["unphilosophized"],
    &["unphilosophised"],
    &["unphilosophized"],
    &["unphilosophised"],
];

pub(crate) static ENTRY_UNPHILOSOPHIZES_9638452344711758586: VariantsMap = [
    &["unphilosophizes"],
    &["unphilosophises"],
    &["unphilosophizes"],
    &["unphilosophises"],
];

pub(crate) static ENTRY_UNPHILOSOPHIZE_15409606515006527524: VariantsMap = [
    &["unphilosophize"],
    &["unphilosophise"],
    &["unphilosophize"],
    &["unphilosophise"],
];

pub(crate) static ENTRY_UNPHOSPHATIZEDDER_8344177484520626925: VariantsMap = [
    &["unphosphatizedder"],
    &["unphosphatisedder"],
    &["unphosphatizedder"],
    &["unphosphatisedder"],
];

pub(crate) static ENTRY_UNPHOSPHATIZEDDEST_7712221667803666231: VariantsMap = [
    &["unphosphatizeddest"],
    &["unphosphatiseddest"],
    &["unphosphatizeddest"],
    &["unphosphatiseddest"],
];

pub(crate) static ENTRY_UNPHOSPHATIZEDS_14190092196126111453: VariantsMap = [
    &["unphosphatizeds"],
    &["unphosphatiseds"],
    &["unphosphatizeds"],
    &["unphosphatiseds"],
];

pub(crate) static ENTRY_UNPHOSPHATIZED_6698185802257295415: VariantsMap = [
    &["unphosphatized"],
    &["unphosphatised"],
    &["unphosphatized"],
    &["unphosphatised"],
];

pub(crate) static ENTRY_UNPICTORIALIZED_4786628385029481651: VariantsMap = [
    &["unpictorialized"],
    &["unpictorialised"],
    &["unpictorialized"],
    &["unpictorialised"],
];

pub(crate) static ENTRY_UNPICTORIALIZE_8534139020030241947: VariantsMap = [
    &["unpictorialize"],
    &["unpictorialise"],
    &["unpictorialize"],
    &["unpictorialise"],
];

pub(crate) static ENTRY_UNPICTORIALIZING_13381639932561913300: VariantsMap = [
    &["unpictorializing"],
    &["unpictorialising"],
    &["unpictorializing"],
    &["unpictorialising"],
];

pub(crate) static ENTRY_UNPLAGIARIZEDDER_2962770941163506588: VariantsMap = [
    &["unplagiarizedder"],
    &["unplagiarisedder"],
    &["unplagiarizedder"],
    &["unplagiarisedder"],
];

pub(crate) static ENTRY_UNPLAGIARIZEDDEST_3104273454326165318: VariantsMap = [
    &["unplagiarizeddest"],
    &["unplagiariseddest"],
    &["unplagiarizeddest"],
    &["unplagiariseddest"],
];

pub(crate) static ENTRY_UNPLAGIARIZEDS_17313414421594015377: VariantsMap = [
    &["unplagiarizeds"],
    &["unplagiariseds"],
    &["unplagiarizeds"],
    &["unplagiariseds"],
];

pub(crate) static ENTRY_UNPLAGIARIZED_9590657773070630082: VariantsMap = [
    &["unplagiarized"],
    &["unplagiarised"],
    &["unplagiarized"],
    &["unplagiarised"],
];

pub(crate) static ENTRY_UNPLURALIZED_5984694540050844180: VariantsMap = [
    &["unpluralized"],
    &["unpluralised"],
    &["unpluralized"],
    &["unpluralised"],
];

pub(crate) static ENTRY_UNPOETICIZEDDER_12735195907627961200: VariantsMap = [
    &["unpoeticizedder"],
    &["unpoeticisedder"],
    &["unpoeticizedder"],
    &["unpoeticisedder"],
];

pub(crate) static ENTRY_UNPOETICIZEDDEST_7053597514693691953: VariantsMap = [
    &["unpoeticizeddest"],
    &["unpoeticiseddest"],
    &["unpoeticizeddest"],
    &["unpoeticiseddest"],
];

pub(crate) static ENTRY_UNPOETICIZEDS_16917648203731599677: VariantsMap = [
    &["unpoeticizeds"],
    &["unpoeticiseds"],
    &["unpoeticizeds"],
    &["unpoeticiseds"],
];

pub(crate) static ENTRY_UNPOETICIZED_15341478924184758286: VariantsMap = [
    &["unpoeticized"],
    &["unpoeticised"],
    &["unpoeticized"],
    &["unpoeticised"],
];

pub(crate) static ENTRY_UNPOETIZED_2934206354212163480: VariantsMap = [
    &["unpoetized"],
    &["unpoetised"],
    &["unpoetized"],
    &["unpoetised"],
];

pub(crate) static ENTRY_UNPOETIZES_11474052031789009067: VariantsMap = [
    &["unpoetizes"],
    &["unpoetises"],
    &["unpoetizes"],
    &["unpoetises"],
];

pub(crate) static ENTRY_UNPOETIZE_14681941329003224540: VariantsMap = [
    &["unpoetize"],
    &["unpoetise"],
    &["unpoetize"],
    &["unpoetise"],
];

pub(crate) static ENTRY_UNPOLARIZABLES_4705929238062186499: VariantsMap = [
    &["unpolarizables"],
    &["unpolarisables"],
    &["unpolarizables"],
    &["unpolarisables"],
];

pub(crate) static ENTRY_UNPOLARIZABLE_2655531584986495323: VariantsMap = [
    &["unpolarizable"],
    &["unpolarisable"],
    &["unpolarizable"],
    &["unpolarisable"],
];

pub(crate) static ENTRY_UNPOLARIZEDDER_1873291145002664328: VariantsMap = [
    &["unpolarizedder"],
    &["unpolarisedder"],
    &["unpolarizedder"],
    &["unpolarisedder"],
];

pub(crate) static ENTRY_UNPOLARIZEDDEST_6022870955853565151: VariantsMap = [
    &["unpolarizeddest"],
    &["unpolariseddest"],
    &["unpolarizeddest"],
    &["unpolariseddest"],
];

pub(crate) static ENTRY_UNPOLARIZEDS_12480635500313856290: VariantsMap = [
    &["unpolarizeds"],
    &["unpolariseds"],
    &["unpolarizeds"],
    &["unpolariseds"],
];

pub(crate) static ENTRY_UNPOLARIZED_1673168216555793217: VariantsMap = [
    &["unpolarized"],
    &["unpolarised"],
    &["unpolarized"],
    &["unpolarised"],
];

pub(crate) static ENTRY_UNPOLYMERIZEDDER_17288114785409523400: VariantsMap = [
    &["unpolymerizedder"],
    &["unpolymerisedder"],
    &["unpolymerizedder"],
    &["unpolymerisedder"],
];

pub(crate) static ENTRY_UNPOLYMERIZEDDEST_16854986311676403228: VariantsMap = [
    &["unpolymerizeddest"],
    &["unpolymeriseddest"],
    &["unpolymerizeddest"],
    &["unpolymeriseddest"],
];

pub(crate) static ENTRY_UNPOLYMERIZEDS_9720144018872629191: VariantsMap = [
    &["unpolymerizeds"],
    &["unpolymeriseds"],
    &["unpolymerizeds"],
    &["unpolymeriseds"],
];

pub(crate) static ENTRY_UNPOLYMERIZED_13019897518101040085: VariantsMap = [
    &["unpolymerized"],
    &["unpolymerised"],
    &["unpolymerized"],
    &["unpolymerised"],
];

pub(crate) static ENTRY_UNPOPULARIZED_76466767521665438: VariantsMap = [
    &["unpopularized"],
    &["unpopularised"],
    &["unpopularized"],
    &["unpopularised"],
];

pub(crate) static ENTRY_UNPOPULARIZES_1388212767604412165: VariantsMap = [
    &["unpopularizes"],
    &["unpopularises"],
    &["unpopularizes"],
    &["unpopularises"],
];

pub(crate) static ENTRY_UNPOPULARIZE_14649336472865355252: VariantsMap = [
    &["unpopularize"],
    &["unpopularise"],
    &["unpopularize"],
    &["unpopularise"],
];

pub(crate) static ENTRY_UNPRACTICEDDER_6992033786330144479: VariantsMap = [
    &["unpracticedder"],
    &["unpractisedder"],
    &["unpractisedder"],
    &["unpractisedder"],
];

pub(crate) static ENTRY_UNPRACTICEDDEST_15053947325497824834: VariantsMap = [
    &["unpracticeddest"],
    &["unpractiseddest"],
    &["unpractiseddest"],
    &["unpractiseddest"],
];

pub(crate) static ENTRY_UNPRACTICED_9353245174446259318: VariantsMap = [
    &["unpracticed"],
    &["unpractised"],
    &["unpractised"],
    &["unpractised"],
];

pub(crate) static ENTRY_UNPRESSURIZED_1643527799717908100: VariantsMap = [
    &["unpressurized"],
    &["unpressurised"],
    &["unpressurized"],
    &["unpressurised"],
];

pub(crate) static ENTRY_UNPROTESTANTIZED_6820017680334554701: VariantsMap = [
    &["unprotestantized"],
    &["unprotestantised"],
    &["unprotestantized"],
    &["unprotestantised"],
];

pub(crate) static ENTRY_UNPROTESTANTIZES_5207108080017394469: VariantsMap = [
    &["unprotestantizes"],
    &["unprotestantises"],
    &["unprotestantizes"],
    &["unprotestantises"],
];

pub(crate) static ENTRY_UNPROTESTANTIZE_5090310073731327645: VariantsMap = [
    &["unprotestantize"],
    &["unprotestantise"],
    &["unprotestantize"],
    &["unprotestantise"],
];

pub(crate) static ENTRY_UNPROTESTANTIZING_2472019232653798522: VariantsMap = [
    &["unprotestantizing"],
    &["unprotestantising"],
    &["unprotestantizing"],
    &["unprotestantising"],
];

pub(crate) static ENTRY_UNPUBLICIZED_2598075486221782263: VariantsMap = [
    &["unpublicized"],
    &["unpublicised"],
    &["unpublicized"],
    &["unpublicised"],
];

pub(crate) static ENTRY_UNPULVERIZEDDER_54420185367589206: VariantsMap = [
    &["unpulverizedder"],
    &["unpulverisedder"],
    &["unpulverizedder"],
    &["unpulverisedder"],
];

pub(crate) static ENTRY_UNPULVERIZEDDEST_9757737756185024283: VariantsMap = [
    &["unpulverizeddest"],
    &["unpulveriseddest"],
    &["unpulverizeddest"],
    &["unpulveriseddest"],
];

pub(crate) static ENTRY_UNPULVERIZED_14085892621205036357: VariantsMap = [
    &["unpulverized"],
    &["unpulverised"],
    &["unpulverized"],
    &["unpulverised"],
];

pub(crate) static ENTRY_UNPULVERIZES_36833523357457577: VariantsMap = [
    &["unpulverizes"],
    &["unpulverises"],
    &["unpulverizes"],
    &["unpulverises"],
];

pub(crate) static ENTRY_UNPULVERIZE_1829206909657688086: VariantsMap = [
    &["unpulverize"],
    &["unpulverise"],
    &["unpulverize"],
    &["unpulverise"],
];

pub(crate) static ENTRY_UNQUANTIZED_11052817945473923658: VariantsMap = [
    &["unquantized"],
    &["unquantised"],
    &["unquantized"],
    &["unquantised"],
];

pub(crate) static ENTRY_UNRADICALIZES_16426285436597116329: VariantsMap = [
    &["unradicalizes"],
    &["unradicalises"],
    &["unradicalizes"],
    &["unradicalises"],
];

pub(crate) static ENTRY_UNRADICALIZE_2815754936703483818: VariantsMap = [
    &["unradicalize"],
    &["unradicalise"],
    &["unradicalize"],
    &["unradicalise"],
];

pub(crate) static ENTRY_UNRANCOREDDER_6348621930598869186: VariantsMap = [
    &["unrancoredder"],
    &["unrancouredder"],
    &["unrancouredder"],
    &["unrancouredder"],
];

pub(crate) static ENTRY_UNRANCOREDDEST_16686379430125720872: VariantsMap = [
    &["unrancoreddest"],
    &["unrancoureddest"],
    &["unrancoureddest"],
    &["unrancoureddest"],
];

pub(crate) static ENTRY_UNRANCOREDS_12103687684487901758: VariantsMap = [
    &["unrancoreds"],
    &["unrancoureds"],
    &["unrancoureds"],
    &["unrancoureds"],
];

pub(crate) static ENTRY_UNRANCORED_9184272533577547039: VariantsMap = [
    &["unrancored"],
    &["unrancoured"],
    &["unrancoured"],
    &["unrancoured"],
];

pub(crate) static ENTRY_UNRANCOROUS_18064074306523619211: VariantsMap = [
    &["unrancorous"],
    &["unrancourous"],
    &["unrancourous"],
    &["unrancourous"],
];

pub(crate) static ENTRY_UNRATIONALIZED_16144188304714101879: VariantsMap = [
    &["unrationalized"],
    &["unrationalised"],
    &["unrationalized"],
    &["unrationalised"],
];

pub(crate) static ENTRY_UNRATIONALIZING_10416615276147328253: VariantsMap = [
    &["unrationalizing"],
    &["unrationalising"],
    &["unrationalizing"],
    &["unrationalising"],
];

pub(crate) static ENTRY_UNRAVELED_8531790293658379223: VariantsMap = [
    &["unraveled"],
    &["unravelled"],
    &["unravelled"],
    &["unravelled"],
];

pub(crate) static ENTRY_UNRAVELERS_9836540518095344389: VariantsMap = [
    &["unravelers"],
    &["unravellers"],
    &["unravellers"],
    &["unravellers"],
];

pub(crate) static ENTRY_UNRAVELER_4944599394654130396: VariantsMap = [
    &["unraveler"],
    &["unraveller"],
    &["unraveller"],
    &["unraveller"],
];

pub(crate) static ENTRY_UNRAVELING_17073861557040957443: VariantsMap = [
    &["unraveling"],
    &["unravelling"],
    &["unravelling"],
    &["unravelling"],
];

pub(crate) static ENTRY_UNREALIZABLES_9314641022749638380: VariantsMap = [
    &["unrealizables"],
    &["unrealisables"],
    &["unrealizables"],
    &["unrealisables"],
];

pub(crate) static ENTRY_UNREALIZABLE_7427131823977755851: VariantsMap = [
    &["unrealizable"],
    &["unrealisable"],
    &["unrealizable"],
    &["unrealisable"],
];

pub(crate) static ENTRY_UNREALIZED_17404817653704661257: VariantsMap = [
    &["unrealized"],
    &["unrealised"],
    &["unrealized"],
    &["unrealised"],
];

pub(crate) static ENTRY_UNREALIZES_5730139003901729864: VariantsMap = [
    &["unrealizes"],
    &["unrealises"],
    &["unrealizes"],
    &["unrealises"],
];

pub(crate) static ENTRY_UNREALIZE_13658903213229006471: VariantsMap = [
    &["unrealize"],
    &["unrealise"],
    &["unrealize"],
    &["unrealise"],
];

pub(crate) static ENTRY_UNREALIZINGS_15326868678672664338: VariantsMap = [
    &["unrealizings"],
    &["unrealisings"],
    &["unrealizings"],
    &["unrealisings"],
];

pub(crate) static ENTRY_UNREALIZING_16148636932622971777: VariantsMap = [
    &["unrealizing"],
    &["unrealising"],
    &["unrealizing"],
    &["unrealising"],
];

pub(crate) static ENTRY_UNRECOGNIZABLER_15443328521804403575: VariantsMap = [
    &["unrecognizabler"],
    &["unrecognisabler"],
    &["unrecognizabler"],
    &["unrecognisabler"],
];

pub(crate) static ENTRY_UNRECOGNIZABLEST_11700300065072913162: VariantsMap = [
    &["unrecognizablest"],
    &["unrecognisablest"],
    &["unrecognizablest"],
    &["unrecognisablest"],
];

pub(crate) static ENTRY_UNRECOGNIZABLE_13177594232205592621: VariantsMap = [
    &["unrecognizable"],
    &["unrecognisable"],
    &["unrecognizable"],
    &["unrecognisable"],
];

pub(crate) static ENTRY_UNRECOGNIZABLY_12498741757123655980: VariantsMap = [
    &["unrecognizably"],
    &["unrecognisably"],
    &["unrecognizably"],
    &["unrecognisably"],
];

pub(crate) static ENTRY_UNRECOGNIZED_15339742215625954957: VariantsMap = [
    &["unrecognized"],
    &["unrecognised"],
    &["unrecognized"],
    &["unrecognised"],
];

pub(crate) static ENTRY_UNRECOGNIZINGLY_2227023476747181630: VariantsMap = [
    &["unrecognizingly"],
    &["unrecognisingly"],
    &["unrecognizingly"],
    &["unrecognisingly"],
];

pub(crate) static ENTRY_UNRECOGNIZING_15165523388753258920: VariantsMap = [
    &["unrecognizing"],
    &["unrecognising"],
    &["unrecognizing"],
    &["unrecognising"],
];

pub(crate) static ENTRY_UNRECONNOITEREDDER_6824132526297537617: VariantsMap = [
    &["unreconnoiteredder"],
    &["unreconnoitredder"],
    &["unreconnoitredder"],
    &["unreconnoitredder"],
];

pub(crate) static ENTRY_UNRECONNOITEREDDEST_14662375144067296424: VariantsMap = [
    &["unreconnoitereddest"],
    &["unreconnoitreddest"],
    &["unreconnoitreddest"],
    &["unreconnoitreddest"],
];

pub(crate) static ENTRY_UNRECONNOITEREDS_10144374598602641365: VariantsMap = [
    &["unreconnoitereds"],
    &["unreconnoitreds"],
    &["unreconnoitreds"],
    &["unreconnoitreds"],
];

pub(crate) static ENTRY_UNRECONNOITERED_7020570262194740993: VariantsMap = [
    &["unreconnoitered"],
    &["unreconnoitred"],
    &["unreconnoitred"],
    &["unreconnoitred"],
];

pub(crate) static ENTRY_UNREGULARIZED_8237418541509267985: VariantsMap = [
    &["unregularized"],
    &["unregularised"],
    &["unregularized"],
    &["unregularised"],
];

pub(crate) static ENTRY_UNREORGANIZEDDER_6817535441462629186: VariantsMap = [
    &["unreorganizedder"],
    &["unreorganisedder"],
    &["unreorganizedder"],
    &["unreorganisedder"],
];

pub(crate) static ENTRY_UNREORGANIZEDDEST_16921729744186143176: VariantsMap = [
    &["unreorganizeddest"],
    &["unreorganiseddest"],
    &["unreorganizeddest"],
    &["unreorganiseddest"],
];

pub(crate) static ENTRY_UNREORGANIZED_15237002088977221645: VariantsMap = [
    &["unreorganized"],
    &["unreorganised"],
    &["unreorganized"],
    &["unreorganised"],
];

pub(crate) static ENTRY_UNREVELATIONIZES_8974203434399731612: VariantsMap = [
    &["unrevelationizes"],
    &["unrevelationises"],
    &["unrevelationizes"],
    &["unrevelationises"],
];

pub(crate) static ENTRY_UNREVELATIONIZE_17021292236492045263: VariantsMap = [
    &["unrevelationize"],
    &["unrevelationise"],
    &["unrevelationize"],
    &["unrevelationise"],
];

pub(crate) static ENTRY_UNRIVALEDDER_4770647244445881329: VariantsMap = [
    &["unrivaledder"],
    &["unrivalledder"],
    &["unrivalledder"],
    &["unrivalledder"],
];

pub(crate) static ENTRY_UNRIVALEDDEST_6685390969368773151: VariantsMap = [
    &["unrivaleddest"],
    &["unrivalleddest"],
    &["unrivalleddest"],
    &["unrivalleddest"],
];

pub(crate) static ENTRY_UNRIVALED_7117684569657820456: VariantsMap = [
    &["unrivaled"],
    &["unrivalled"],
    &["unrivalled"],
    &["unrivalled"],
];

pub(crate) static ENTRY_UNROMANIZED_3332586790919173959: VariantsMap = [
    &["unromanized"],
    &["unromanised"],
    &["unromanized"],
    &["unromanised"],
];

pub(crate) static ENTRY_UNROMANTICIZEDDER_7880803665433466684: VariantsMap = [
    &["unromanticizedder"],
    &["unromanticisedder"],
    &["unromanticizedder"],
    &["unromanticisedder"],
];

pub(crate) static ENTRY_UNROMANTICIZEDDEST_4366413467561211143: VariantsMap = [
    &["unromanticizeddest"],
    &["unromanticiseddest"],
    &["unromanticizeddest"],
    &["unromanticiseddest"],
];

pub(crate) static ENTRY_UNROMANTICIZEDS_6905411968539131627: VariantsMap = [
    &["unromanticizeds"],
    &["unromanticiseds"],
    &["unromanticizeds"],
    &["unromanticiseds"],
];

pub(crate) static ENTRY_UNROMANTICIZED_12323250999848162828: VariantsMap = [
    &["unromanticized"],
    &["unromanticised"],
    &["unromanticized"],
    &["unromanticised"],
];

pub(crate) static ENTRY_UNROYALIZEDS_18166484644206892914: VariantsMap = [
    &["unroyalizeds"],
    &["unroyaliseds"],
    &["unroyalizeds"],
    &["unroyaliseds"],
];

pub(crate) static ENTRY_UNROYALIZED_463331773464183743: VariantsMap = [
    &["unroyalized"],
    &["unroyalised"],
    &["unroyalized"],
    &["unroyalised"],
];

pub(crate) static ENTRY_UNRUMOREDDER_1235386211719339229: VariantsMap = [
    &["unrumoredder"],
    &["unrumouredder"],
    &["unrumouredder"],
    &["unrumouredder"],
];

pub(crate) static ENTRY_UNRUMOREDDEST_10653958198865026338: VariantsMap = [
    &["unrumoreddest"],
    &["unrumoureddest"],
    &["unrumoureddest"],
    &["unrumoureddest"],
];

pub(crate) static ENTRY_UNRUMORED_11945081100528914083: VariantsMap = [
    &["unrumored"],
    &["unrumoured"],
    &["unrumoured"],
    &["unrumoured"],
];

pub(crate) static ENTRY_UNSABEREDDER_1732672318778523343: VariantsMap = [
    &["unsaberedder"],
    &["unsabredder"],
    &["unsabredder"],
    &["unsabredder"],
];

pub(crate) static ENTRY_UNSABEREDDEST_4361858810448422047: VariantsMap = [
    &["unsabereddest"],
    &["unsabreddest"],
    &["unsabreddest"],
    &["unsabreddest"],
];

pub(crate) static ENTRY_UNSABERED_7177981977292168575: VariantsMap =
    [&["unsabered"], &["unsabred"], &["unsabred"], &["unsabred"]];

pub(crate) static ENTRY_UNSATIRIZABLE_11743121723677468480: VariantsMap = [
    &["unsatirizable"],
    &["unsatirisable"],
    &["unsatirizable"],
    &["unsatirisable"],
];

pub(crate) static ENTRY_UNSATIRIZEDDER_11457550322600274631: VariantsMap = [
    &["unsatirizedder"],
    &["unsatirisedder"],
    &["unsatirizedder"],
    &["unsatirisedder"],
];

pub(crate) static ENTRY_UNSATIRIZEDDEST_4126847310419402743: VariantsMap = [
    &["unsatirizeddest"],
    &["unsatiriseddest"],
    &["unsatirizeddest"],
    &["unsatiriseddest"],
];

pub(crate) static ENTRY_UNSATIRIZED_13793588944367095442: VariantsMap = [
    &["unsatirized"],
    &["unsatirised"],
    &["unsatirized"],
    &["unsatirised"],
];

pub(crate) static ENTRY_UNSATIRIZES_13382097901467533418: VariantsMap = [
    &["unsatirizes"],
    &["unsatirises"],
    &["unsatirizes"],
    &["unsatirises"],
];

pub(crate) static ENTRY_UNSATIRIZE_34395718428272863: VariantsMap = [
    &["unsatirize"],
    &["unsatirise"],
    &["unsatirize"],
    &["unsatirise"],
];

pub(crate) static ENTRY_UNSAVOREDDER_9689868158053003438: VariantsMap = [
    &["unsavoredder"],
    &["unsavouredder"],
    &["unsavouredder"],
    &["unsavouredder"],
];

pub(crate) static ENTRY_UNSAVOREDDEST_9031970620246286024: VariantsMap = [
    &["unsavoreddest"],
    &["unsavoureddest"],
    &["unsavoureddest"],
    &["unsavoureddest"],
];

pub(crate) static ENTRY_UNSAVOREDLY_8889339578327024203: VariantsMap = [
    &["unsavoredly"],
    &["unsavouredly"],
    &["unsavouredly"],
    &["unsavouredly"],
];

pub(crate) static ENTRY_UNSAVOREDNESS_8894397023697955452: VariantsMap = [
    &["unsavoredness"],
    &["unsavouredness"],
    &["unsavouredness"],
    &["unsavouredness"],
];

pub(crate) static ENTRY_UNSAVORED_835718759607657454: VariantsMap = [
    &["unsavored"],
    &["unsavoured"],
    &["unsavoured"],
    &["unsavoured"],
];

pub(crate) static ENTRY_UNSAVORIER_11499851903563622390: VariantsMap = [
    &["unsavorier"],
    &["unsavourier"],
    &["unsavourier"],
    &["unsavourier"],
];

pub(crate) static ENTRY_UNSAVORIEST_4272222949170545033: VariantsMap = [
    &["unsavoriest"],
    &["unsavouriest"],
    &["unsavouriest"],
    &["unsavouriest"],
];

pub(crate) static ENTRY_UNSAVORIES_564856304299168322: VariantsMap = [
    &["unsavories"],
    &["unsavouries"],
    &["unsavouries"],
    &["unsavouries"],
];

pub(crate) static ENTRY_UNSAVORILIER_17795073319281436965: VariantsMap = [
    &["unsavorilier"],
    &["unsavourilier"],
    &["unsavourilier"],
    &["unsavourilier"],
];

pub(crate) static ENTRY_UNSAVORILIEST_10649069445986118122: VariantsMap = [
    &["unsavoriliest"],
    &["unsavouriliest"],
    &["unsavouriliest"],
    &["unsavouriliest"],
];

pub(crate) static ENTRY_UNSAVORILIES_2379987631293155666: VariantsMap = [
    &["unsavorilies"],
    &["unsavourilies"],
    &["unsavourilies"],
    &["unsavourilies"],
];

pub(crate) static ENTRY_UNSAVORILY_10670667337623880247: VariantsMap = [
    &["unsavorily"],
    &["unsavourily"],
    &["unsavourily"],
    &["unsavourily"],
];

pub(crate) static ENTRY_UNSAVORINESSES_8712909678084814914: VariantsMap = [
    &["unsavorinesses"],
    &["unsavourinesses"],
    &["unsavourinesses"],
    &["unsavourinesses"],
];

pub(crate) static ENTRY_UNSAVORINESS_16734401353949800250: VariantsMap = [
    &["unsavoriness"],
    &["unsavouriness"],
    &["unsavouriness"],
    &["unsavouriness"],
];

pub(crate) static ENTRY_UNSAVORY_5814802780012802033: VariantsMap = [
    &["unsavory"],
    &["unsavoury"],
    &["unsavoury"],
    &["unsavoury"],
];

pub(crate) static ENTRY_UNSCANDALIZEDDER_16598075610375338334: VariantsMap = [
    &["unscandalizedder"],
    &["unscandalisedder"],
    &["unscandalizedder"],
    &["unscandalisedder"],
];

pub(crate) static ENTRY_UNSCANDALIZEDDEST_10751215903020225937: VariantsMap = [
    &["unscandalizeddest"],
    &["unscandaliseddest"],
    &["unscandalizeddest"],
    &["unscandaliseddest"],
];

pub(crate) static ENTRY_UNSCANDALIZED_8152094708030261523: VariantsMap = [
    &["unscandalized"],
    &["unscandalised"],
    &["unscandalized"],
    &["unscandalised"],
];

pub(crate) static ENTRY_UNSCANDALIZES_17840125261680020227: VariantsMap = [
    &["unscandalizes"],
    &["unscandalises"],
    &["unscandalizes"],
    &["unscandalises"],
];

pub(crate) static ENTRY_UNSCANDALIZE_520505661327966431: VariantsMap = [
    &["unscandalize"],
    &["unscandalise"],
    &["unscandalize"],
    &["unscandalise"],
];

pub(crate) static ENTRY_UNSCEPTEREDDER_2376849210254288587: VariantsMap = [
    &["unscepteredder"],
    &["unsceptredder"],
    &["unsceptredder"],
    &["unsceptredder"],
];

pub(crate) static ENTRY_UNSCEPTEREDDEST_13269872785173189124: VariantsMap = [
    &["unsceptereddest"],
    &["unsceptreddest"],
    &["unsceptreddest"],
    &["unsceptreddest"],
];

pub(crate) static ENTRY_UNSCEPTERED_13340295677500887608: VariantsMap = [
    &["unsceptered"],
    &["unsceptred"],
    &["unsceptred"],
    &["unsceptred"],
];

pub(crate) static ENTRY_UNSCEPTERS_3877189759939193522: VariantsMap = [
    &["unscepters"],
    &["unsceptres"],
    &["unsceptres"],
    &["unsceptres"],
];

pub(crate) static ENTRY_UNSCEPTER_12310705858970392134: VariantsMap = [
    &["unscepter"],
    &["unsceptre"],
    &["unsceptre"],
    &["unsceptre"],
];

pub(crate) static ENTRY_UNSCHEMATIZEDDER_4716532793392136205: VariantsMap = [
    &["unschematizedder"],
    &["unschematisedder"],
    &["unschematizedder"],
    &["unschematisedder"],
];

pub(crate) static ENTRY_UNSCHEMATIZEDDEST_12088700656751368211: VariantsMap = [
    &["unschematizeddest"],
    &["unschematiseddest"],
    &["unschematizeddest"],
    &["unschematiseddest"],
];

pub(crate) static ENTRY_UNSCHEMATIZEDS_298126258475951987: VariantsMap = [
    &["unschematizeds"],
    &["unschematiseds"],
    &["unschematizeds"],
    &["unschematiseds"],
];

pub(crate) static ENTRY_UNSCHEMATIZED_15829880150892985637: VariantsMap = [
    &["unschematized"],
    &["unschematised"],
    &["unschematized"],
    &["unschematised"],
];

pub(crate) static ENTRY_UNSCORED_14510217564861462498: VariantsMap = [
    &["unscored"],
    &["unscoured"],
    &["unscoured"],
    &["unscoured"],
];

pub(crate) static ENTRY_UNSCORING_7857262218542359235: VariantsMap = [
    &["unscoring"],
    &["unscouring"],
    &["unscouring"],
    &["unscouring"],
];

pub(crate) static ENTRY_UNSCRUTINIZEDDER_14564478170521424195: VariantsMap = [
    &["unscrutinizedder"],
    &["unscrutinisedder"],
    &["unscrutinizedder"],
    &["unscrutinisedder"],
];

pub(crate) static ENTRY_UNSCRUTINIZEDDEST_16503621375052442349: VariantsMap = [
    &["unscrutinizeddest"],
    &["unscrutiniseddest"],
    &["unscrutinizeddest"],
    &["unscrutiniseddest"],
];

pub(crate) static ENTRY_UNSCRUTINIZED_4499174384647942184: VariantsMap = [
    &["unscrutinized"],
    &["unscrutinised"],
    &["unscrutinized"],
    &["unscrutinised"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGER_4340449043412100187: VariantsMap = [
    &["unscrutinizinger"],
    &["unscrutinisinger"],
    &["unscrutinizinger"],
    &["unscrutinisinger"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGEST_9456217512411188422: VariantsMap = [
    &["unscrutinizingest"],
    &["unscrutinisingest"],
    &["unscrutinizingest"],
    &["unscrutinisingest"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGLIER_16918089062255487129: VariantsMap = [
    &["unscrutinizinglier"],
    &["unscrutinisinglier"],
    &["unscrutinizinglier"],
    &["unscrutinisinglier"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGLIEST_4936819005717689952: VariantsMap = [
    &["unscrutinizingliest"],
    &["unscrutinisingliest"],
    &["unscrutinizingliest"],
    &["unscrutinisingliest"],
];

pub(crate) static ENTRY_UNSCRUTINIZINGLY_5893546295582674444: VariantsMap = [
    &["unscrutinizingly"],
    &["unscrutinisingly"],
    &["unscrutinizingly"],
    &["unscrutinisingly"],
];

pub(crate) static ENTRY_UNSCRUTINIZING_12963862895980253271: VariantsMap = [
    &["unscrutinizing"],
    &["unscrutinising"],
    &["unscrutinizing"],
    &["unscrutinising"],
];

pub(crate) static ENTRY_UNSECTARIANIZES_17346999740171237029: VariantsMap = [
    &["unsectarianizes"],
    &["unsectarianises"],
    &["unsectarianizes"],
    &["unsectarianises"],
];

pub(crate) static ENTRY_UNSECTARIANIZE_8896277406677200944: VariantsMap = [
    &["unsectarianize"],
    &["unsectarianise"],
    &["unsectarianize"],
    &["unsectarianise"],
];

pub(crate) static ENTRY_UNSECTIONALIZED_5425065226264728201: VariantsMap = [
    &["unsectionalized"],
    &["unsectionalised"],
    &["unsectionalized"],
    &["unsectionalised"],
];

pub(crate) static ENTRY_UNSECULARIZEDDER_11676957079943780409: VariantsMap = [
    &["unsecularizedder"],
    &["unsecularisedder"],
    &["unsecularizedder"],
    &["unsecularisedder"],
];

pub(crate) static ENTRY_UNSECULARIZEDDEST_2864881942285944778: VariantsMap = [
    &["unsecularizeddest"],
    &["unseculariseddest"],
    &["unsecularizeddest"],
    &["unseculariseddest"],
];

pub(crate) static ENTRY_UNSECULARIZED_14903658695506748830: VariantsMap = [
    &["unsecularized"],
    &["unsecularised"],
    &["unsecularized"],
    &["unsecularised"],
];

pub(crate) static ENTRY_UNSECULARIZES_9891479802659859412: VariantsMap = [
    &["unsecularizes"],
    &["unsecularises"],
    &["unsecularizes"],
    &["unsecularises"],
];

pub(crate) static ENTRY_UNSECULARIZE_5214216027332443223: VariantsMap = [
    &["unsecularize"],
    &["unsecularise"],
    &["unsecularize"],
    &["unsecularise"],
];

pub(crate) static ENTRY_UNSENSITIZED_7794134976310825921: VariantsMap = [
    &["unsensitized"],
    &["unsensitised"],
    &["unsensitized"],
    &["unsensitised"],
];

pub(crate) static ENTRY_UNSENSITIZES_5803069635824140326: VariantsMap = [
    &["unsensitizes"],
    &["unsensitises"],
    &["unsensitizes"],
    &["unsensitises"],
];

pub(crate) static ENTRY_UNSENSITIZE_10205463848604074076: VariantsMap = [
    &["unsensitize"],
    &["unsensitise"],
    &["unsensitize"],
    &["unsensitise"],
];

pub(crate) static ENTRY_UNSENSITIZING_5882427315960709496: VariantsMap = [
    &["unsensitizing"],
    &["unsensitising"],
    &["unsensitizing"],
    &["unsensitising"],
];

pub(crate) static ENTRY_UNSENSUALIZED_32054534269141140: VariantsMap = [
    &["unsensualized"],
    &["unsensualised"],
    &["unsensualized"],
    &["unsensualised"],
];

pub(crate) static ENTRY_UNSENSUALIZES_12397866517645397490: VariantsMap = [
    &["unsensualizes"],
    &["unsensualises"],
    &["unsensualizes"],
    &["unsensualises"],
];

pub(crate) static ENTRY_UNSENSUALIZE_15769041899106603358: VariantsMap = [
    &["unsensualize"],
    &["unsensualise"],
    &["unsensualize"],
    &["unsensualise"],
];

pub(crate) static ENTRY_UNSENSUALIZING_1812813256933634221: VariantsMap = [
    &["unsensualizing"],
    &["unsensualising"],
    &["unsensualizing"],
    &["unsensualising"],
];

pub(crate) static ENTRY_UNSENTIMENTALIZED_6565195653528439940: VariantsMap = [
    &["unsentimentalized"],
    &["unsentimentalised"],
    &["unsentimentalized"],
    &["unsentimentalised"],
];

pub(crate) static ENTRY_UNSENTIMENTALIZES_9475174647404255643: VariantsMap = [
    &["unsentimentalizes"],
    &["unsentimentalises"],
    &["unsentimentalizes"],
    &["unsentimentalises"],
];

pub(crate) static ENTRY_UNSENTIMENTALIZE_5597748571008194983: VariantsMap = [
    &["unsentimentalize"],
    &["unsentimentalise"],
    &["unsentimentalize"],
    &["unsentimentalise"],
];

pub(crate) static ENTRY_UNSEPULCHERED_728988728789570667: VariantsMap = [
    &["unsepulchered"],
    &["unsepulchred"],
    &["unsepulchred"],
    &["unsepulchred"],
];

pub(crate) static ENTRY_UNSEPULCHERS_1679319036273540108: VariantsMap = [
    &["unsepulchers"],
    &["unsepulchres"],
    &["unsepulchres"],
    &["unsepulchres"],
];

pub(crate) static ENTRY_UNSEPULCHER_3660018467990610478: VariantsMap = [
    &["unsepulcher"],
    &["unsepulchre"],
    &["unsepulchre"],
    &["unsepulchre"],
];

pub(crate) static ENTRY_UNSERIALIZED_14154792643266589843: VariantsMap = [
    &["unserialized"],
    &["unserialised"],
    &["unserialized"],
    &["unserialised"],
];

pub(crate) static ENTRY_UNSHED_1748678126240642191: VariantsMap =
    [&["unshed"], &["unshoed"], &["unshoed"], &["unshoed"]];

pub(crate) static ENTRY_UNSIGNALIZEDDER_2263217046824972534: VariantsMap = [
    &["unsignalizedder"],
    &["unsignalisedder"],
    &["unsignalizedder"],
    &["unsignalisedder"],
];

pub(crate) static ENTRY_UNSIGNALIZEDDEST_14758681485610426786: VariantsMap = [
    &["unsignalizeddest"],
    &["unsignaliseddest"],
    &["unsignalizeddest"],
    &["unsignaliseddest"],
];

pub(crate) static ENTRY_UNSIGNALIZEDS_8158537188065551521: VariantsMap = [
    &["unsignalizeds"],
    &["unsignaliseds"],
    &["unsignalizeds"],
    &["unsignaliseds"],
];

pub(crate) static ENTRY_UNSIGNALIZED_18072380712584870147: VariantsMap = [
    &["unsignalized"],
    &["unsignalised"],
    &["unsignalized"],
    &["unsignalised"],
];

pub(crate) static ENTRY_UNSIPHONS_6487069638314844152: VariantsMap = [
    &["unsiphons"],
    &["unsyphons"],
    &["unsyphons"],
    &["unsyphons"],
];

pub(crate) static ENTRY_UNSIPHON_8751298592164441841: VariantsMap =
    [&["unsiphon"], &["unsyphon"], &["unsyphon"], &["unsyphon"]];

pub(crate) static ENTRY_UNSOCIALIZEDDER_10880141521153969743: VariantsMap = [
    &["unsocializedder"],
    &["unsocialisedder"],
    &["unsocializedder"],
    &["unsocialisedder"],
];

pub(crate) static ENTRY_UNSOCIALIZEDDEST_4448774529600758329: VariantsMap = [
    &["unsocializeddest"],
    &["unsocialiseddest"],
    &["unsocializeddest"],
    &["unsocialiseddest"],
];

pub(crate) static ENTRY_UNSOCIALIZED_3496138542165260759: VariantsMap = [
    &["unsocialized"],
    &["unsocialised"],
    &["unsocialized"],
    &["unsocialised"],
];

pub(crate) static ENTRY_UNSOCIALIZING_8509052272131880502: VariantsMap = [
    &["unsocializing"],
    &["unsocialising"],
    &["unsocializing"],
    &["unsocialising"],
];

pub(crate) static ENTRY_UNSOLEMNIZEDDER_12639019762331536413: VariantsMap = [
    &["unsolemnizedder"],
    &["unsolemnisedder"],
    &["unsolemnizedder"],
    &["unsolemnisedder"],
];

pub(crate) static ENTRY_UNSOLEMNIZEDDEST_9414390961190285845: VariantsMap = [
    &["unsolemnizeddest"],
    &["unsolemniseddest"],
    &["unsolemnizeddest"],
    &["unsolemniseddest"],
];

pub(crate) static ENTRY_UNSOLEMNIZED_13405781150896516414: VariantsMap = [
    &["unsolemnized"],
    &["unsolemnised"],
    &["unsolemnized"],
    &["unsolemnised"],
];

pub(crate) static ENTRY_UNSOLEMNIZES_3236564255173918334: VariantsMap = [
    &["unsolemnizes"],
    &["unsolemnises"],
    &["unsolemnizes"],
    &["unsolemnises"],
];

pub(crate) static ENTRY_UNSOLEMNIZE_17754689905088315837: VariantsMap = [
    &["unsolemnize"],
    &["unsolemnise"],
    &["unsolemnize"],
    &["unsolemnise"],
];

pub(crate) static ENTRY_UNSOMBERLY_3720066922443442116: VariantsMap = [
    &["unsomberly"],
    &["unsombrely"],
    &["unsombrely"],
    &["unsombrely"],
];

pub(crate) static ENTRY_UNSOMBERNESS_5229571241405215642: VariantsMap = [
    &["unsomberness"],
    &["unsombreness"],
    &["unsombreness"],
    &["unsombreness"],
];

pub(crate) static ENTRY_UNSOMBER_9849015273292267538: VariantsMap =
    [&["unsomber"], &["unsombre"], &["unsombre"], &["unsombre"]];

pub(crate) static ENTRY_UNSPECIALIZEDDER_14482979627473921525: VariantsMap = [
    &["unspecializedder"],
    &["unspecialisedder"],
    &["unspecializedder"],
    &["unspecialisedder"],
];

pub(crate) static ENTRY_UNSPECIALIZEDDEST_7579806759888561816: VariantsMap = [
    &["unspecializeddest"],
    &["unspecialiseddest"],
    &["unspecializeddest"],
    &["unspecialiseddest"],
];

pub(crate) static ENTRY_UNSPECIALIZED_16921915094468110795: VariantsMap = [
    &["unspecialized"],
    &["unspecialised"],
    &["unspecialized"],
    &["unspecialised"],
];

pub(crate) static ENTRY_UNSPECIALIZINGER_10541176028877396187: VariantsMap = [
    &["unspecializinger"],
    &["unspecialisinger"],
    &["unspecializinger"],
    &["unspecialisinger"],
];

pub(crate) static ENTRY_UNSPECIALIZINGEST_13963040120295765584: VariantsMap = [
    &["unspecializingest"],
    &["unspecialisingest"],
    &["unspecializingest"],
    &["unspecialisingest"],
];

pub(crate) static ENTRY_UNSPECIALIZING_870209529926883549: VariantsMap = [
    &["unspecializing"],
    &["unspecialising"],
    &["unspecializing"],
    &["unspecialising"],
];

pub(crate) static ENTRY_UNSPECTERLIKES_12569940984145654311: VariantsMap = [
    &["unspecterlikes"],
    &["unspectrelikes"],
    &["unspectrelikes"],
    &["unspectrelikes"],
];

pub(crate) static ENTRY_UNSPECTERLIKE_15729881691571605322: VariantsMap = [
    &["unspecterlike"],
    &["unspectrelike"],
    &["unspectrelike"],
    &["unspectrelike"],
];

pub(crate) static ENTRY_UNSPIRITUALIZED_13793878683851952015: VariantsMap = [
    &["unspiritualized"],
    &["unspiritualised"],
    &["unspiritualized"],
    &["unspiritualised"],
];

pub(crate) static ENTRY_UNSPIRITUALIZES_13159558072175914180: VariantsMap = [
    &["unspiritualizes"],
    &["unspiritualises"],
    &["unspiritualizes"],
    &["unspiritualises"],
];

pub(crate) static ENTRY_UNSPIRITUALIZE_5916555052861323400: VariantsMap = [
    &["unspiritualize"],
    &["unspiritualise"],
    &["unspiritualize"],
    &["unspiritualise"],
];

pub(crate) static ENTRY_UNSPIRITUALIZING_17178897114095131956: VariantsMap = [
    &["unspiritualizing"],
    &["unspiritualising"],
    &["unspiritualizing"],
    &["unspiritualising"],
];

pub(crate) static ENTRY_UNSPLENDOROUSLY_11800106086712842867: VariantsMap = [
    &["unsplendorously"],
    &["unsplendourously"],
    &["unsplendourously"],
    &["unsplendourously"],
];

pub(crate) static ENTRY_UNSPLENDOROUS_15638368483821854285: VariantsMap = [
    &["unsplendorous"],
    &["unsplendourous"],
    &["unsplendourous"],
    &["unsplendourous"],
];

pub(crate) static ENTRY_UNSTABILIZED_1384046979087471144: VariantsMap = [
    &["unstabilized"],
    &["unstabilised"],
    &["unstabilized"],
    &["unstabilised"],
];

pub(crate) static ENTRY_UNSTABILIZING_9105210657283981291: VariantsMap = [
    &["unstabilizing"],
    &["unstabilising"],
    &["unstabilizing"],
    &["unstabilising"],
];

pub(crate) static ENTRY_UNSTANDARDIZABLE_3986051184822450887: VariantsMap = [
    &["unstandardizable"],
    &["unstandardisable"],
    &["unstandardizable"],
    &["unstandardisable"],
];

pub(crate) static ENTRY_UNSTANDARDIZEDDER_3995682174766736068: VariantsMap = [
    &["unstandardizedder"],
    &["unstandardisedder"],
    &["unstandardizedder"],
    &["unstandardisedder"],
];

pub(crate) static ENTRY_UNSTANDARDIZEDDEST_11035827645803141662: VariantsMap = [
    &["unstandardizeddest"],
    &["unstandardiseddest"],
    &["unstandardizeddest"],
    &["unstandardiseddest"],
];

pub(crate) static ENTRY_UNSTANDARDIZED_1272352641434012090: VariantsMap = [
    &["unstandardized"],
    &["unstandardised"],
    &["unstandardized"],
    &["unstandardised"],
];

pub(crate) static ENTRY_UNSTERILIZED_13156342258367971107: VariantsMap = [
    &["unsterilized"],
    &["unsterilised"],
    &["unsterilized"],
    &["unsterilised"],
];

pub(crate) static ENTRY_UNSTIGMATIZEDDER_12103644335044897212: VariantsMap = [
    &["unstigmatizedder"],
    &["unstigmatisedder"],
    &["unstigmatizedder"],
    &["unstigmatisedder"],
];

pub(crate) static ENTRY_UNSTIGMATIZEDDEST_5756983753240929122: VariantsMap = [
    &["unstigmatizeddest"],
    &["unstigmatiseddest"],
    &["unstigmatizeddest"],
    &["unstigmatiseddest"],
];

pub(crate) static ENTRY_UNSTIGMATIZEDS_179009940195529442: VariantsMap = [
    &["unstigmatizeds"],
    &["unstigmatiseds"],
    &["unstigmatizeds"],
    &["unstigmatiseds"],
];

pub(crate) static ENTRY_UNSTIGMATIZED_8147628030660872313: VariantsMap = [
    &["unstigmatized"],
    &["unstigmatised"],
    &["unstigmatized"],
    &["unstigmatised"],
];

pub(crate) static ENTRY_UNSTOICIZES_3633881140952142304: VariantsMap = [
    &["unstoicizes"],
    &["unstoicises"],
    &["unstoicizes"],
    &["unstoicises"],
];

pub(crate) static ENTRY_UNSTOICIZE_15130563685517702536: VariantsMap = [
    &["unstoicize"],
    &["unstoicise"],
    &["unstoicize"],
    &["unstoicise"],
];

pub(crate) static ENTRY_UNSUBSIDIZED_8506816544552198394: VariantsMap = [
    &["unsubsidized"],
    &["unsubsidised"],
    &["unsubsidized"],
    &["unsubsidised"],
];

pub(crate) static ENTRY_UNSUBSTANTIALIZED_16036110466855036195: VariantsMap = [
    &["unsubstantialized"],
    &["unsubstantialised"],
    &["unsubstantialized"],
    &["unsubstantialised"],
];

pub(crate) static ENTRY_UNSUBSTANTIALIZES_16871510027185551366: VariantsMap = [
    &["unsubstantializes"],
    &["unsubstantialises"],
    &["unsubstantializes"],
    &["unsubstantialises"],
];

pub(crate) static ENTRY_UNSUBSTANTIALIZE_18383570451437119535: VariantsMap = [
    &["unsubstantialize"],
    &["unsubstantialise"],
    &["unsubstantialize"],
    &["unsubstantialise"],
];

pub(crate) static ENTRY_UNSUBSTANTIALIZING_2121724985901297893: VariantsMap = [
    &["unsubstantializing"],
    &["unsubstantialising"],
    &["unsubstantializing"],
    &["unsubstantialising"],
];

pub(crate) static ENTRY_UNSUCCORABLES_739989955870419064: VariantsMap = [
    &["unsuccorables"],
    &["unsuccourables"],
    &["unsuccourables"],
    &["unsuccourables"],
];

pub(crate) static ENTRY_UNSUCCORABLE_12673763242696709684: VariantsMap = [
    &["unsuccorable"],
    &["unsuccourable"],
    &["unsuccourable"],
    &["unsuccourable"],
];

pub(crate) static ENTRY_UNSUCCORED_2160594171074318544: VariantsMap = [
    &["unsuccored"],
    &["unsuccoured"],
    &["unsuccoured"],
    &["unsuccoured"],
];

pub(crate) static ENTRY_UNSULPHURIZEDS_10925557470603907058: VariantsMap = [
    &["unsulphurizeds"],
    &["unsulphuriseds"],
    &["unsulphurizeds"],
    &["unsulphuriseds"],
];

pub(crate) static ENTRY_UNSULPHURIZED_4398458517942042949: VariantsMap = [
    &["unsulphurized"],
    &["unsulphurised"],
    &["unsulphurized"],
    &["unsulphurised"],
];

pub(crate) static ENTRY_UNSUMMARIZABLE_4893860010982930453: VariantsMap = [
    &["unsummarizable"],
    &["unsummarisable"],
    &["unsummarizable"],
    &["unsummarisable"],
];

pub(crate) static ENTRY_UNSUMMARIZEDDER_17857459577512226536: VariantsMap = [
    &["unsummarizedder"],
    &["unsummarisedder"],
    &["unsummarizedder"],
    &["unsummarisedder"],
];

pub(crate) static ENTRY_UNSUMMARIZEDDEST_13958313582918609397: VariantsMap = [
    &["unsummarizeddest"],
    &["unsummariseddest"],
    &["unsummarizeddest"],
    &["unsummariseddest"],
];

pub(crate) static ENTRY_UNSUMMARIZED_836436980612704819: VariantsMap = [
    &["unsummarized"],
    &["unsummarised"],
    &["unsummarized"],
    &["unsummarised"],
];

pub(crate) static ENTRY_UNSUPERNATURALIZED_13742104250862639914: VariantsMap = [
    &["unsupernaturalized"],
    &["unsupernaturalised"],
    &["unsupernaturalized"],
    &["unsupernaturalised"],
];

pub(crate) static ENTRY_UNSUPERNATURALIZES_11514791653627540421: VariantsMap = [
    &["unsupernaturalizes"],
    &["unsupernaturalises"],
    &["unsupernaturalizes"],
    &["unsupernaturalises"],
];

pub(crate) static ENTRY_UNSUPERNATURALIZE_11379677666614455606: VariantsMap = [
    &["unsupernaturalize"],
    &["unsupernaturalise"],
    &["unsupernaturalize"],
    &["unsupernaturalise"],
];

pub(crate) static ENTRY_UNSYMBOLIZEDDER_2693121694591055898: VariantsMap = [
    &["unsymbolizedder"],
    &["unsymbolisedder"],
    &["unsymbolizedder"],
    &["unsymbolisedder"],
];

pub(crate) static ENTRY_UNSYMBOLIZEDDEST_5688633199932414339: VariantsMap = [
    &["unsymbolizeddest"],
    &["unsymboliseddest"],
    &["unsymbolizeddest"],
    &["unsymboliseddest"],
];

pub(crate) static ENTRY_UNSYMBOLIZED_4998866146418175348: VariantsMap = [
    &["unsymbolized"],
    &["unsymbolised"],
    &["unsymbolized"],
    &["unsymbolised"],
];

pub(crate) static ENTRY_UNSYMMETRIZEDS_17526612862547781039: VariantsMap = [
    &["unsymmetrizeds"],
    &["unsymmetriseds"],
    &["unsymmetrizeds"],
    &["unsymmetriseds"],
];

pub(crate) static ENTRY_UNSYMMETRIZED_2416221991577506354: VariantsMap = [
    &["unsymmetrized"],
    &["unsymmetrised"],
    &["unsymmetrized"],
    &["unsymmetrised"],
];

pub(crate) static ENTRY_UNSYMPATHIZABILITIES_5599344496922194828: VariantsMap = [
    &["unsympathizabilities"],
    &["unsympathisabilities"],
    &["unsympathizabilities"],
    &["unsympathisabilities"],
];

pub(crate) static ENTRY_UNSYMPATHIZABILITY_15552727085219653687: VariantsMap = [
    &["unsympathizability"],
    &["unsympathisability"],
    &["unsympathizability"],
    &["unsympathisability"],
];

pub(crate) static ENTRY_UNSYMPATHIZABLES_6750873272065181147: VariantsMap = [
    &["unsympathizables"],
    &["unsympathisables"],
    &["unsympathizables"],
    &["unsympathisables"],
];

pub(crate) static ENTRY_UNSYMPATHIZABLE_6116127447209370164: VariantsMap = [
    &["unsympathizable"],
    &["unsympathisable"],
    &["unsympathizable"],
    &["unsympathisable"],
];

pub(crate) static ENTRY_UNSYMPATHIZEDDER_12857460593078230378: VariantsMap = [
    &["unsympathizedder"],
    &["unsympathisedder"],
    &["unsympathizedder"],
    &["unsympathisedder"],
];

pub(crate) static ENTRY_UNSYMPATHIZEDDEST_11795335826469372906: VariantsMap = [
    &["unsympathizeddest"],
    &["unsympathiseddest"],
    &["unsympathizeddest"],
    &["unsympathiseddest"],
];

pub(crate) static ENTRY_UNSYMPATHIZED_7172788372988396436: VariantsMap = [
    &["unsympathized"],
    &["unsympathised"],
    &["unsympathized"],
    &["unsympathised"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGER_4506075109833611910: VariantsMap = [
    &["unsympathizinger"],
    &["unsympathisinger"],
    &["unsympathizinger"],
    &["unsympathisinger"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGEST_13474971300491840553: VariantsMap = [
    &["unsympathizingest"],
    &["unsympathisingest"],
    &["unsympathizingest"],
    &["unsympathisingest"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGLIER_7139683093102134643: VariantsMap = [
    &["unsympathizinglier"],
    &["unsympathisinglier"],
    &["unsympathizinglier"],
    &["unsympathisinglier"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGLIEST_6904483674657551040: VariantsMap = [
    &["unsympathizingliest"],
    &["unsympathisingliest"],
    &["unsympathizingliest"],
    &["unsympathisingliest"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGLY_10367834800272884249: VariantsMap = [
    &["unsympathizingly"],
    &["unsympathisingly"],
    &["unsympathizingly"],
    &["unsympathisingly"],
];

pub(crate) static ENTRY_UNSYMPATHIZINGS_4389760301799797231: VariantsMap = [
    &["unsympathizings"],
    &["unsympathisings"],
    &["unsympathizings"],
    &["unsympathisings"],
];

pub(crate) static ENTRY_UNSYMPATHIZING_8602889408813208422: VariantsMap = [
    &["unsympathizing"],
    &["unsympathising"],
    &["unsympathizing"],
    &["unsympathising"],
];

pub(crate) static ENTRY_UNSYNCHRONIZEDDER_17711872826708633465: VariantsMap = [
    &["unsynchronizedder"],
    &["unsynchronisedder"],
    &["unsynchronizedder"],
    &["unsynchronisedder"],
];

pub(crate) static ENTRY_UNSYNCHRONIZEDDEST_8914833530283816809: VariantsMap = [
    &["unsynchronizeddest"],
    &["unsynchroniseddest"],
    &["unsynchronizeddest"],
    &["unsynchroniseddest"],
];

pub(crate) static ENTRY_UNSYNCHRONIZED_15906225482447601414: VariantsMap = [
    &["unsynchronized"],
    &["unsynchronised"],
    &["unsynchronized"],
    &["unsynchronised"],
];

pub(crate) static ENTRY_UNSYNTHESIZEDDER_47988453461239108: VariantsMap = [
    &["unsynthesizedder"],
    &["unsynthesisedder"],
    &["unsynthesizedder"],
    &["unsynthesisedder"],
];

pub(crate) static ENTRY_UNSYNTHESIZEDDEST_7437594407505325426: VariantsMap = [
    &["unsynthesizeddest"],
    &["unsynthesiseddest"],
    &["unsynthesizeddest"],
    &["unsynthesiseddest"],
];

pub(crate) static ENTRY_UNSYNTHESIZED_873390520484748283: VariantsMap = [
    &["unsynthesized"],
    &["unsynthesised"],
    &["unsynthesized"],
    &["unsynthesised"],
];

pub(crate) static ENTRY_UNSYSTEMATIZEDDER_9189788093098370830: VariantsMap = [
    &["unsystematizedder"],
    &["unsystematisedder"],
    &["unsystematizedder"],
    &["unsystematisedder"],
];

pub(crate) static ENTRY_UNSYSTEMATIZEDDEST_1207211808530410942: VariantsMap = [
    &["unsystematizeddest"],
    &["unsystematiseddest"],
    &["unsystematizeddest"],
    &["unsystematiseddest"],
];

pub(crate) static ENTRY_UNSYSTEMATIZEDLY_4862881584760401398: VariantsMap = [
    &["unsystematizedly"],
    &["unsystematisedly"],
    &["unsystematizedly"],
    &["unsystematisedly"],
];

pub(crate) static ENTRY_UNSYSTEMATIZED_14502428691598864878: VariantsMap = [
    &["unsystematized"],
    &["unsystematised"],
    &["unsystematized"],
    &["unsystematised"],
];

pub(crate) static ENTRY_UNSYSTEMATIZINGER_15925085597038328684: VariantsMap = [
    &["unsystematizinger"],
    &["unsystematisinger"],
    &["unsystematizinger"],
    &["unsystematisinger"],
];

pub(crate) static ENTRY_UNSYSTEMATIZINGEST_5589507975482695103: VariantsMap = [
    &["unsystematizingest"],
    &["unsystematisingest"],
    &["unsystematizingest"],
    &["unsystematisingest"],
];

pub(crate) static ENTRY_UNSYSTEMATIZING_14753078560276504217: VariantsMap = [
    &["unsystematizing"],
    &["unsystematising"],
    &["unsystematizing"],
    &["unsystematising"],
];

pub(crate) static ENTRY_UNSYSTEMIZABLES_11770476614828889053: VariantsMap = [
    &["unsystemizables"],
    &["unsystemisables"],
    &["unsystemizables"],
    &["unsystemisables"],
];

pub(crate) static ENTRY_UNSYSTEMIZABLE_6445655941220298236: VariantsMap = [
    &["unsystemizable"],
    &["unsystemisable"],
    &["unsystemizable"],
    &["unsystemisable"],
];

pub(crate) static ENTRY_UNTANTALIZEDDER_4818289569312071640: VariantsMap = [
    &["untantalizedder"],
    &["untantalisedder"],
    &["untantalizedder"],
    &["untantalisedder"],
];

pub(crate) static ENTRY_UNTANTALIZEDDEST_17808161070361053815: VariantsMap = [
    &["untantalizeddest"],
    &["untantaliseddest"],
    &["untantalizeddest"],
    &["untantaliseddest"],
];

pub(crate) static ENTRY_UNTANTALIZED_6826245574739736260: VariantsMap = [
    &["untantalized"],
    &["untantalised"],
    &["untantalized"],
    &["untantalised"],
];

pub(crate) static ENTRY_UNTANTALIZINGER_434726785421024269: VariantsMap = [
    &["untantalizinger"],
    &["untantalisinger"],
    &["untantalizinger"],
    &["untantalisinger"],
];

pub(crate) static ENTRY_UNTANTALIZINGEST_14310803913056649148: VariantsMap = [
    &["untantalizingest"],
    &["untantalisingest"],
    &["untantalizingest"],
    &["untantalisingest"],
];

pub(crate) static ENTRY_UNTANTALIZINGS_16007088557356417459: VariantsMap = [
    &["untantalizings"],
    &["untantalisings"],
    &["untantalizings"],
    &["untantalisings"],
];

pub(crate) static ENTRY_UNTANTALIZING_9378536861335914621: VariantsMap = [
    &["untantalizing"],
    &["untantalising"],
    &["untantalizing"],
    &["untantalising"],
];

pub(crate) static ENTRY_UNTARTARIZEDS_2508207556036622208: VariantsMap = [
    &["untartarizeds"],
    &["untartariseds"],
    &["untartarizeds"],
    &["untartariseds"],
];

pub(crate) static ENTRY_UNTARTARIZED_9979924217571095451: VariantsMap = [
    &["untartarized"],
    &["untartarised"],
    &["untartarized"],
    &["untartarised"],
];

pub(crate) static ENTRY_UNTECHNICALIZES_12316354131512359: VariantsMap = [
    &["untechnicalizes"],
    &["untechnicalises"],
    &["untechnicalizes"],
    &["untechnicalises"],
];

pub(crate) static ENTRY_UNTECHNICALIZE_7661502502654407908: VariantsMap = [
    &["untechnicalize"],
    &["untechnicalise"],
    &["untechnicalize"],
    &["untechnicalise"],
];

pub(crate) static ENTRY_UNTEMPORIZINGS_10863617418556326800: VariantsMap = [
    &["untemporizings"],
    &["untemporisings"],
    &["untemporizings"],
    &["untemporisings"],
];

pub(crate) static ENTRY_UNTEMPORIZING_10262279498666537398: VariantsMap = [
    &["untemporizing"],
    &["untemporising"],
    &["untemporizing"],
    &["untemporising"],
];

pub(crate) static ENTRY_UNTERRORIZED_11223502884976171489: VariantsMap = [
    &["unterrorized"],
    &["unterrorised"],
    &["unterrorized"],
    &["unterrorised"],
];

pub(crate) static ENTRY_UNTHEORIZABLES_13870769123827938921: VariantsMap = [
    &["untheorizables"],
    &["untheorisables"],
    &["untheorizables"],
    &["untheorisables"],
];

pub(crate) static ENTRY_UNTHEORIZABLE_240618649580760361: VariantsMap = [
    &["untheorizable"],
    &["untheorisable"],
    &["untheorizable"],
    &["untheorisable"],
];

pub(crate) static ENTRY_UNTRAMMELEDDER_378198885203754532: VariantsMap = [
    &["untrammeledder"],
    &["untrammelledder"],
    &["untrammelledder"],
    &["untrammelledder"],
];

pub(crate) static ENTRY_UNTRAMMELEDDEST_15285162208707661637: VariantsMap = [
    &["untrammeleddest"],
    &["untrammelleddest"],
    &["untrammelleddest"],
    &["untrammelleddest"],
];

pub(crate) static ENTRY_UNTRAMMELED_549579090643891681: VariantsMap = [
    &["untrammeled"],
    &["untrammelled"],
    &["untrammelled"],
    &["untrammelled"],
];

pub(crate) static ENTRY_UNTRANQUILIZED_14631448086878067814: VariantsMap = [
    &["untranquilized"],
    &["untranquilised"],
    &["untranquilized"],
    &["untranquilised"],
];

pub(crate) static ENTRY_UNTRANQUILLIZED_3970525452077680048: VariantsMap = [
    &["untranquillized"],
    &["untranquillised"],
    &["untranquillized"],
    &["untranquillised"],
];

pub(crate) static ENTRY_UNTRANQUILLIZE_528996477809981689: VariantsMap = [
    &["untranquillize"],
    &["untranquillise"],
    &["untranquillize"],
    &["untranquillise"],
];

pub(crate) static ENTRY_UNTYRANNIZED_8862669867305834720: VariantsMap = [
    &["untyrannized"],
    &["untyrannised"],
    &["untyrannized"],
    &["untyrannised"],
];

pub(crate) static ENTRY_UNUTILIZABLES_12203087951077580837: VariantsMap = [
    &["unutilizables"],
    &["unutilisables"],
    &["unutilizables"],
    &["unutilisables"],
];

pub(crate) static ENTRY_UNUTILIZABLE_9039802547895734958: VariantsMap = [
    &["unutilizable"],
    &["unutilisable"],
    &["unutilizable"],
    &["unutilisable"],
];

pub(crate) static ENTRY_UNUTILIZED_6004715330369766853: VariantsMap = [
    &["unutilized"],
    &["unutilised"],
    &["unutilized"],
    &["unutilised"],
];

pub(crate) static ENTRY_UNVAPORIZEDS_986543555659572827: VariantsMap = [
    &["unvaporizeds"],
    &["unvaporiseds"],
    &["unvaporizeds"],
    &["unvaporiseds"],
];

pub(crate) static ENTRY_UNVAPORIZED_16545025727542113291: VariantsMap = [
    &["unvaporized"],
    &["unvaporised"],
    &["unvaporized"],
    &["unvaporised"],
];

pub(crate) static ENTRY_UNVECTORIZABLE_18305744060207565163: VariantsMap = [
    &["unvectorizable"],
    &["unvectorisable"],
    &["unvectorizable"],
    &["unvectorisable"],
];

pub(crate) static ENTRY_UNVERBALIZED_16856369756877096411: VariantsMap = [
    &["unverbalized"],
    &["unverbalised"],
    &["unverbalized"],
    &["unverbalised"],
];

pub(crate) static ENTRY_UNVICTIMIZED_13829704510461931485: VariantsMap = [
    &["unvictimized"],
    &["unvictimised"],
    &["unvictimized"],
    &["unvictimised"],
];

pub(crate) static ENTRY_UNVISUALIZEDDER_13256531491156210059: VariantsMap = [
    &["unvisualizedder"],
    &["unvisualisedder"],
    &["unvisualizedder"],
    &["unvisualisedder"],
];

pub(crate) static ENTRY_UNVISUALIZEDDEST_6777836850065797871: VariantsMap = [
    &["unvisualizeddest"],
    &["unvisualiseddest"],
    &["unvisualizeddest"],
    &["unvisualiseddest"],
];

pub(crate) static ENTRY_UNVISUALIZED_2776258560824841456: VariantsMap = [
    &["unvisualized"],
    &["unvisualised"],
    &["unvisualized"],
    &["unvisualised"],
];

pub(crate) static ENTRY_UNVITALIZEDS_10697536110994369157: VariantsMap = [
    &["unvitalizeds"],
    &["unvitaliseds"],
    &["unvitalizeds"],
    &["unvitaliseds"],
];

pub(crate) static ENTRY_UNVITALIZED_11823193045588642198: VariantsMap = [
    &["unvitalized"],
    &["unvitalised"],
    &["unvitalized"],
    &["unvitalised"],
];

pub(crate) static ENTRY_UNVITRIOLIZEDS_12617332440469592487: VariantsMap = [
    &["unvitriolizeds"],
    &["unvitrioliseds"],
    &["unvitriolizeds"],
    &["unvitrioliseds"],
];

pub(crate) static ENTRY_UNVITRIOLIZED_15668418284843563695: VariantsMap = [
    &["unvitriolized"],
    &["unvitriolised"],
    &["unvitriolized"],
    &["unvitriolised"],
];

pub(crate) static ENTRY_UNVOCALIZEDDER_8782052029072763726: VariantsMap = [
    &["unvocalizedder"],
    &["unvocalisedder"],
    &["unvocalizedder"],
    &["unvocalisedder"],
];

pub(crate) static ENTRY_UNVOCALIZEDDEST_16264288867545903555: VariantsMap = [
    &["unvocalizeddest"],
    &["unvocaliseddest"],
    &["unvocalizeddest"],
    &["unvocaliseddest"],
];

pub(crate) static ENTRY_UNVOCALIZEDS_16873526062784100267: VariantsMap = [
    &["unvocalizeds"],
    &["unvocaliseds"],
    &["unvocalizeds"],
    &["unvocaliseds"],
];

pub(crate) static ENTRY_UNVOCALIZED_14849265082296142302: VariantsMap = [
    &["unvocalized"],
    &["unvocalised"],
    &["unvocalized"],
    &["unvocalised"],
];

pub(crate) static ENTRY_UNVOLATILIZEDDER_17937975853559322294: VariantsMap = [
    &["unvolatilizedder"],
    &["unvolatilisedder"],
    &["unvolatilizedder"],
    &["unvolatilisedder"],
];

pub(crate) static ENTRY_UNVOLATILIZEDDEST_14571877913455730099: VariantsMap = [
    &["unvolatilizeddest"],
    &["unvolatiliseddest"],
    &["unvolatilizeddest"],
    &["unvolatiliseddest"],
];

pub(crate) static ENTRY_UNVOLATILIZED_7055569159550394451: VariantsMap = [
    &["unvolatilized"],
    &["unvolatilised"],
    &["unvolatilized"],
    &["unvolatilised"],
];

pub(crate) static ENTRY_UNVOLATILIZES_11043825585956014572: VariantsMap = [
    &["unvolatilizes"],
    &["unvolatilises"],
    &["unvolatilizes"],
    &["unvolatilises"],
];

pub(crate) static ENTRY_UNVOLATILIZE_5958705215773329402: VariantsMap = [
    &["unvolatilize"],
    &["unvolatilise"],
    &["unvolatilize"],
    &["unvolatilise"],
];

pub(crate) static ENTRY_UNVULCANIZEDDER_15357474347454753550: VariantsMap = [
    &["unvulcanizedder"],
    &["unvulcanisedder"],
    &["unvulcanizedder"],
    &["unvulcanisedder"],
];

pub(crate) static ENTRY_UNVULCANIZEDDEST_3232274294131053531: VariantsMap = [
    &["unvulcanizeddest"],
    &["unvulcaniseddest"],
    &["unvulcanizeddest"],
    &["unvulcaniseddest"],
];

pub(crate) static ENTRY_UNVULCANIZEDS_1169880674497437033: VariantsMap = [
    &["unvulcanizeds"],
    &["unvulcaniseds"],
    &["unvulcanizeds"],
    &["unvulcaniseds"],
];

pub(crate) static ENTRY_UNVULCANIZED_8687515356006252413: VariantsMap = [
    &["unvulcanized"],
    &["unvulcanised"],
    &["unvulcanized"],
    &["unvulcanised"],
];

pub(crate) static ENTRY_UNVULGARIZED_501333356952951895: VariantsMap = [
    &["unvulgarized"],
    &["unvulgarised"],
    &["unvulgarized"],
    &["unvulgarised"],
];

pub(crate) static ENTRY_UNVULGARIZES_4085302381557242262: VariantsMap = [
    &["unvulgarizes"],
    &["unvulgarises"],
    &["unvulgarizes"],
    &["unvulgarises"],
];

pub(crate) static ENTRY_UNVULGARIZE_3818104634120863405: VariantsMap = [
    &["unvulgarize"],
    &["unvulgarise"],
    &["unvulgarize"],
    &["unvulgarise"],
];

pub(crate) static ENTRY_UNVULGARIZING_6203485172128713465: VariantsMap = [
    &["unvulgarizing"],
    &["unvulgarising"],
    &["unvulgarizing"],
    &["unvulgarising"],
];

pub(crate) static ENTRY_UNWESTERNIZEDS_8372650994230810456: VariantsMap = [
    &["unwesternizeds"],
    &["unwesterniseds"],
    &["unwesternizeds"],
    &["unwesterniseds"],
];

pub(crate) static ENTRY_UNWESTERNIZED_2338020082584820680: VariantsMap = [
    &["unwesternized"],
    &["unwesternised"],
    &["unwesternized"],
    &["unwesternised"],
];

pub(crate) static ENTRY_UNWOMANIZED_9669879163918865323: VariantsMap = [
    &["unwomanized"],
    &["unwomanised"],
    &["unwomanized"],
    &["unwomanised"],
];

pub(crate) static ENTRY_UNWOMANIZES_6959542966143151702: VariantsMap = [
    &["unwomanizes"],
    &["unwomanises"],
    &["unwomanizes"],
    &["unwomanises"],
];

pub(crate) static ENTRY_UNWOMANIZE_11304497579761163173: VariantsMap = [
    &["unwomanize"],
    &["unwomanise"],
    &["unwomanize"],
    &["unwomanise"],
];

pub(crate) static ENTRY_UPDRAFTS_15724500159329907899: VariantsMap = [
    &["updrafts"],
    &["updraughts"],
    &["updrafts"],
    &["updraughts"],
];

pub(crate) static ENTRY_UPDRAFT_14478591919041764288: VariantsMap =
    [&["updraft"], &["updraught"], &["updraft"], &["updraught"]];

pub(crate) static ENTRY_URALITIZATIONS_4694547628568956579: VariantsMap = [
    &["uralitizations"],
    &["uralitisations"],
    &["uralitizations"],
    &["uralitisations"],
];

pub(crate) static ENTRY_URALITIZATION_9224301311774971881: VariantsMap = [
    &["uralitization"],
    &["uralitisation"],
    &["uralitization"],
    &["uralitisation"],
];

pub(crate) static ENTRY_URALITIZED_7976389324622529761: VariantsMap = [
    &["uralitized"],
    &["uralitised"],
    &["uralitized"],
    &["uralitised"],
];

pub(crate) static ENTRY_URALITIZES_2908475727458579535: VariantsMap = [
    &["uralitizes"],
    &["uralitises"],
    &["uralitizes"],
    &["uralitises"],
];

pub(crate) static ENTRY_URALITIZE_16749000206864918007: VariantsMap = [
    &["uralitize"],
    &["uralitise"],
    &["uralitize"],
    &["uralitise"],
];

pub(crate) static ENTRY_URALITIZING_1776329728839479360: VariantsMap = [
    &["uralitizing"],
    &["uralitising"],
    &["uralitizing"],
    &["uralitising"],
];

pub(crate) static ENTRY_URATEMIA_5405625611324090705: VariantsMap = [
    &["uratemia"],
    &["urataemia"],
    &["urataemia"],
    &["urataemia"],
];

pub(crate) static ENTRY_URBANIZATIONS_714857663098149035: VariantsMap = [
    &["urbanizations"],
    &["urbanisations"],
    &["urbanizations"],
    &["urbanisations"],
];

pub(crate) static ENTRY_URBANIZATION_13167682870250962044: VariantsMap = [
    &["urbanization"],
    &["urbanisation"],
    &["urbanization"],
    &["urbanisation"],
];

pub(crate) static ENTRY_URBANIZED_14020698925707626324: VariantsMap = [
    &["urbanized"],
    &["urbanised"],
    &["urbanized"],
    &["urbanised"],
];

pub(crate) static ENTRY_URBANIZES_3740663614137143534: VariantsMap = [
    &["urbanizes"],
    &["urbanises"],
    &["urbanizes"],
    &["urbanises"],
];

pub(crate) static ENTRY_URBANIZE_13821147474427946226: VariantsMap =
    [&["urbanize"], &["urbanise"], &["urbanize"], &["urbanise"]];

pub(crate) static ENTRY_URBANIZING_6731820196250704237: VariantsMap = [
    &["urbanizing"],
    &["urbanising"],
    &["urbanizing"],
    &["urbanising"],
];

pub(crate) static ENTRY_UREDEMA_959978479087452280: VariantsMap =
    [&["uredema"], &["uroedema"], &["uroedema"], &["uroedema"]];

pub(crate) static ENTRY_UREMIAS_922769604822503284: VariantsMap =
    [&["uremias"], &["uraemias"], &["uremias"], &["uraemias"]];

pub(crate) static ENTRY_UREMIA_5689969777449555427: VariantsMap =
    [&["uremia"], &["uraemia"], &["uremia"], &["uraemia"]];

pub(crate) static ENTRY_UREMIC_16730857995062547325: VariantsMap =
    [&["uremic"], &["uraemic"], &["uremic"], &["uraemic"]];

pub(crate) static ENTRY_URETHRORRHEA_465812257833285712: VariantsMap = [
    &["urethrorrhea"],
    &["urethrorrhoea"],
    &["urethrorrhoea"],
    &["urethrorrhoea"],
];

pub(crate) static ENTRY_URICEMIA_735304459969707353: VariantsMap = [
    &["uricemia"],
    &["uricaemia"],
    &["uricaemia"],
    &["uricaemia"],
];

pub(crate) static ENTRY_URICEMIC_4538463089231912762: VariantsMap = [
    &["uricemic"],
    &["uricaemic"],
    &["uricaemic"],
    &["uricaemic"],
];

pub(crate) static ENTRY_URINEMIA_14477903106053677801: VariantsMap = [
    &["urinemia"],
    &["urinaemia"],
    &["urinaemia"],
    &["urinaemia"],
];

pub(crate) static ENTRY_URINEMIC_3826715010964749488: VariantsMap = [
    &["urinemic"],
    &["urinaemic"],
    &["urinaemic"],
    &["urinaemic"],
];

pub(crate) static ENTRY_UROHEMATIN_18414252065450864526: VariantsMap = [
    &["urohematin"],
    &["urohaematin"],
    &["urohaematin"],
    &["urohaematin"],
];

pub(crate) static ENTRY_UROPHEIN_4036494320759732075: VariantsMap = [
    &["urophein"],
    &["urophaein"],
    &["urophaein"],
    &["urophaein"],
];

pub(crate) static ENTRY_USABILITY_2409309504889002778: VariantsMap = [
    &["usability"],
    &["usability"],
    &["usability"],
    &["usability"],
];

pub(crate) static ENTRY_UTILITARIANIZED_17327794031594514233: VariantsMap = [
    &["utilitarianized"],
    &["utilitarianised"],
    &["utilitarianized"],
    &["utilitarianised"],
];

pub(crate) static ENTRY_UTILITARIANIZES_2918689411948086849: VariantsMap = [
    &["utilitarianizes"],
    &["utilitarianises"],
    &["utilitarianizes"],
    &["utilitarianises"],
];

pub(crate) static ENTRY_UTILITARIANIZE_8297351043834511620: VariantsMap = [
    &["utilitarianize"],
    &["utilitarianise"],
    &["utilitarianize"],
    &["utilitarianise"],
];

pub(crate) static ENTRY_UTILITARIANIZING_11871648364295177065: VariantsMap = [
    &["utilitarianizing"],
    &["utilitarianising"],
    &["utilitarianizing"],
    &["utilitarianising"],
];

pub(crate) static ENTRY_UTILIZABILITIES_2397151207630807999: VariantsMap = [
    &["utilizabilities"],
    &["utilisabilities"],
    &["utilizabilities"],
    &["utilisabilities"],
];

pub(crate) static ENTRY_UTILIZABILITY_8225222995731560442: VariantsMap = [
    &["utilizability"],
    &["utilisability"],
    &["utilizability"],
    &["utilisability"],
];

pub(crate) static ENTRY_UTILIZABLES_2699823619654292368: VariantsMap = [
    &["utilizables"],
    &["utilisables"],
    &["utilizables"],
    &["utilisables"],
];

pub(crate) static ENTRY_UTILIZABLE_657706566869914036: VariantsMap = [
    &["utilizable"],
    &["utilisable"],
    &["utilizable"],
    &["utilisable"],
];

pub(crate) static ENTRY_UTILIZATIONS_4724972587409135598: VariantsMap = [
    &["utilizations"],
    &["utilisations"],
    &["utilizations"],
    &["utilisations"],
];

pub(crate) static ENTRY_UTILIZATION_10923497997585510620: VariantsMap = [
    &["utilization"],
    &["utilisation"],
    &["utilization"],
    &["utilisation"],
];

pub(crate) static ENTRY_UTILIZED_2804070747550195319: VariantsMap =
    [&["utilized"], &["utilised"], &["utilized"], &["utilised"]];

pub(crate) static ENTRY_UTILIZERS_7682889880042432556: VariantsMap = [
    &["utilizers"],
    &["utilisers"],
    &["utilizers"],
    &["utilisers"],
];

pub(crate) static ENTRY_UTILIZER_15218673503685600046: VariantsMap =
    [&["utilizer"], &["utiliser"], &["utilizer"], &["utiliser"]];

pub(crate) static ENTRY_UTILIZES_10186051414736400981: VariantsMap =
    [&["utilizes"], &["utilises"], &["utilizes"], &["utilises"]];

pub(crate) static ENTRY_UTILIZE_1012773511652592330: VariantsMap =
    [&["utilize"], &["utilise"], &["utilize"], &["utilise"]];

pub(crate) static ENTRY_UTILIZING_14247990373114335405: VariantsMap = [
    &["utilizing"],
    &["utilising"],
    &["utilizing"],
    &["utilising"],
];

pub(crate) static ENTRY_UTOPIANIZED_13362099296694661562: VariantsMap = [
    &["utopianized"],
    &["utopianised"],
    &["utopianized"],
    &["utopianised"],
];

pub(crate) static ENTRY_UTOPIANIZERS_17092121582482431024: VariantsMap = [
    &["utopianizers"],
    &["utopianisers"],
    &["utopianizers"],
    &["utopianisers"],
];

pub(crate) static ENTRY_UTOPIANIZER_810034931952875575: VariantsMap = [
    &["utopianizer"],
    &["utopianiser"],
    &["utopianizer"],
    &["utopianiser"],
];

pub(crate) static ENTRY_UTOPIANIZES_17399145312143334553: VariantsMap = [
    &["utopianizes"],
    &["utopianises"],
    &["utopianizes"],
    &["utopianises"],
];

pub(crate) static ENTRY_UTOPIANIZE_15231068506782111828: VariantsMap = [
    &["utopianize"],
    &["utopianise"],
    &["utopianize"],
    &["utopianise"],
];

pub(crate) static ENTRY_UTOPIANIZING_4126566720003715520: VariantsMap = [
    &["utopianizing"],
    &["utopianising"],
    &["utopianizing"],
    &["utopianising"],
];

pub(crate) static ENTRY_VAAGMER_9352026066170753042: VariantsMap =
    [&["vaagmer"], &["vaagmaer"], &["vaagmaer"], &["vaagmaer"]];

pub(crate) static ENTRY_VACCINIZATIONS_7439925486752573538: VariantsMap = [
    &["vaccinizations"],
    &["vaccinisations"],
    &["vaccinizations"],
    &["vaccinisations"],
];

pub(crate) static ENTRY_VACCINIZATION_14920485206127408398: VariantsMap = [
    &["vaccinization"],
    &["vaccinisation"],
    &["vaccinization"],
    &["vaccinisation"],
];

pub(crate) static ENTRY_VACUOLIZATIONS_2613605802168870716: VariantsMap = [
    &["vacuolizations"],
    &["vacuolisations"],
    &["vacuolizations"],
    &["vacuolisations"],
];

pub(crate) static ENTRY_VACUOLIZATION_13858163343008163773: VariantsMap = [
    &["vacuolization"],
    &["vacuolisation"],
    &["vacuolization"],
    &["vacuolisation"],
];

pub(crate) static ENTRY_VACUUMIZED_694297391266218663: VariantsMap = [
    &["vacuumized"],
    &["vacuumised"],
    &["vacuumized"],
    &["vacuumised"],
];

pub(crate) static ENTRY_VACUUMIZES_3651190374182064680: VariantsMap = [
    &["vacuumizes"],
    &["vacuumises"],
    &["vacuumizes"],
    &["vacuumises"],
];

pub(crate) static ENTRY_VACUUMIZE_14138660867202341090: VariantsMap = [
    &["vacuumize"],
    &["vacuumise"],
    &["vacuumize"],
    &["vacuumise"],
];

pub(crate) static ENTRY_VACUUMIZING_16587783276915840565: VariantsMap = [
    &["vacuumizing"],
    &["vacuumising"],
    &["vacuumizing"],
    &["vacuumising"],
];

pub(crate) static ENTRY_VAGABONDIZED_8460203338144902596: VariantsMap = [
    &["vagabondized"],
    &["vagabondised"],
    &["vagabondized"],
    &["vagabondised"],
];

pub(crate) static ENTRY_VAGABONDIZERS_14944892011725033494: VariantsMap = [
    &["vagabondizers"],
    &["vagabondisers"],
    &["vagabondizers"],
    &["vagabondisers"],
];

pub(crate) static ENTRY_VAGABONDIZER_3037058975526630888: VariantsMap = [
    &["vagabondizer"],
    &["vagabondiser"],
    &["vagabondizer"],
    &["vagabondiser"],
];

pub(crate) static ENTRY_VAGABONDIZES_15618104026782170568: VariantsMap = [
    &["vagabondizes"],
    &["vagabondises"],
    &["vagabondizes"],
    &["vagabondises"],
];

pub(crate) static ENTRY_VAGABONDIZE_11652184056860982029: VariantsMap = [
    &["vagabondize"],
    &["vagabondise"],
    &["vagabondize"],
    &["vagabondise"],
];

pub(crate) static ENTRY_VAGABONDIZING_14715875291944757403: VariantsMap = [
    &["vagabondizing"],
    &["vagabondising"],
    &["vagabondizing"],
    &["vagabondising"],
];

pub(crate) static ENTRY_VAGINULE_15009785862152351808: VariantsMap = [
    &["vaginule"],
    &["vaginulae"],
    &["vaginulae"],
    &["vaginulae"],
];

pub(crate) static ENTRY_VAGRANTIZES_9039456281230433333: VariantsMap = [
    &["vagrantizes"],
    &["vagrantises"],
    &["vagrantizes"],
    &["vagrantises"],
];

pub(crate) static ENTRY_VAGRANTIZE_18388633313665953145: VariantsMap = [
    &["vagrantize"],
    &["vagrantise"],
    &["vagrantize"],
    &["vagrantise"],
];

pub(crate) static ENTRY_VALORIZATIONS_5550580571650748675: VariantsMap = [
    &["valorizations"],
    &["valorisations"],
    &["valorizations"],
    &["valorisations"],
];

pub(crate) static ENTRY_VALORIZATION_10419740603004179298: VariantsMap = [
    &["valorization"],
    &["valorisation"],
    &["valorization"],
    &["valorisation"],
];

pub(crate) static ENTRY_VALORIZED_16812452574506000724: VariantsMap = [
    &["valorized"],
    &["valorised"],
    &["valorized"],
    &["valorised"],
];

pub(crate) static ENTRY_VALORIZES_12702735390304257487: VariantsMap = [
    &["valorizes"],
    &["valorises"],
    &["valorizes"],
    &["valorises"],
];

pub(crate) static ENTRY_VALORIZE_18286588028207921541: VariantsMap =
    [&["valorize"], &["valorise"], &["valorize"], &["valorise"]];

pub(crate) static ENTRY_VALORIZING_6868515530721861819: VariantsMap = [
    &["valorizing"],
    &["valorising"],
    &["valorizing"],
    &["valorising"],
];

pub(crate) static ENTRY_VALOROUSNESS_4012556260769975737: VariantsMap = [
    &["valorousness"],
    &["valourousness"],
    &["valourousness"],
    &["valourousness"],
];

pub(crate) static ENTRY_VALORS_12937983727743095167: VariantsMap =
    [&["valors"], &["valours"], &["valours"], &["valours"]];

pub(crate) static ENTRY_VALOR_10559677046210656064: VariantsMap =
    [&["valor"], &["valour"], &["valour"], &["valour"]];

pub(crate) static ENTRY_VALVULE_7068032189967732165: VariantsMap =
    [&["valvule"], &["valvulae"], &["valvulae"], &["valvulae"]];

pub(crate) static ENTRY_VAMPIRIZED_1331377974704440897: VariantsMap = [
    &["vampirized"],
    &["vampirised"],
    &["vampirized"],
    &["vampirised"],
];

pub(crate) static ENTRY_VAMPIRIZES_15605173529611826568: VariantsMap = [
    &["vampirizes"],
    &["vampirises"],
    &["vampirizes"],
    &["vampirises"],
];

pub(crate) static ENTRY_VAMPIRIZE_2148156304906706014: VariantsMap = [
    &["vampirize"],
    &["vampirise"],
    &["vampirize"],
    &["vampirise"],
];

pub(crate) static ENTRY_VAMPIRIZING_5067863975594369914: VariantsMap = [
    &["vampirizing"],
    &["vampirising"],
    &["vampirizing"],
    &["vampirising"],
];

pub(crate) static ENTRY_VANDALIZATIONS_12533411033790274385: VariantsMap = [
    &["vandalizations"],
    &["vandalisations"],
    &["vandalizations"],
    &["vandalisations"],
];

pub(crate) static ENTRY_VANDALIZATION_321326720704663358: VariantsMap = [
    &["vandalization"],
    &["vandalisation"],
    &["vandalization"],
    &["vandalisation"],
];

pub(crate) static ENTRY_VANDALIZED_6584048774266312596: VariantsMap = [
    &["vandalized"],
    &["vandalised"],
    &["vandalized"],
    &["vandalised"],
];

pub(crate) static ENTRY_VANDALIZES_950444592106680495: VariantsMap = [
    &["vandalizes"],
    &["vandalises"],
    &["vandalizes"],
    &["vandalises"],
];

pub(crate) static ENTRY_VANDALIZE_13852377148508595432: VariantsMap = [
    &["vandalize"],
    &["vandalise"],
    &["vandalize"],
    &["vandalise"],
];

pub(crate) static ENTRY_VANDALIZING_15674911687333824137: VariantsMap = [
    &["vandalizing"],
    &["vandalising"],
    &["vandalizing"],
    &["vandalising"],
];

pub(crate) static ENTRY_VAPORABILITIES_2583412300863683415: VariantsMap = [
    &["vaporabilities"],
    &["vapourabilities"],
    &["vapourabilities"],
    &["vapourabilities"],
];

pub(crate) static ENTRY_VAPORABILITY_11761050574300823550: VariantsMap = [
    &["vaporability"],
    &["vapourability"],
    &["vapourability"],
    &["vapourability"],
];

pub(crate) static ENTRY_VAPORABLES_8806153105556416814: VariantsMap = [
    &["vaporables"],
    &["vapourables"],
    &["vapourables"],
    &["vapourables"],
];

pub(crate) static ENTRY_VAPORABLE_9307386414591158227: VariantsMap = [
    &["vaporable"],
    &["vapourable"],
    &["vapourable"],
    &["vapourable"],
];

pub(crate) static ENTRY_VAPORED_9964696878149356362: VariantsMap =
    [&["vapored"], &["vapoured"], &["vapoured"], &["vapoured"]];

pub(crate) static ENTRY_VAPORERS_9040022998985997095: VariantsMap = [
    &["vaporers"],
    &["vapourers"],
    &["vapourers"],
    &["vapourers"],
];

pub(crate) static ENTRY_VAPORER_1067720005826649650: VariantsMap =
    [&["vaporer"], &["vapourer"], &["vapourer"], &["vapourer"]];

pub(crate) static ENTRY_VAPORESCENT_811521758895005989: VariantsMap = [
    &["vaporescent"],
    &["vapourescent"],
    &["vapourescent"],
    &["vapourescent"],
];

pub(crate) static ENTRY_VAPORIER_5924457613655889706: VariantsMap = [
    &["vaporier"],
    &["vapourier"],
    &["vapourier"],
    &["vapourier"],
];

pub(crate) static ENTRY_VAPORIEST_16771875045269754013: VariantsMap = [
    &["vaporiest"],
    &["vapouriest"],
    &["vapouriest"],
    &["vapouriest"],
];

pub(crate) static ENTRY_VAPORIFIC_16729671073785623946: VariantsMap = [
    &["vaporific"],
    &["vapourific"],
    &["vapourific"],
    &["vapourific"],
];

pub(crate) static ENTRY_VAPORIMETER_12463044510053318843: VariantsMap = [
    &["vaporimeter"],
    &["vapourimeter"],
    &["vapourimeter"],
    &["vapourimeter"],
];

pub(crate) static ENTRY_VAPORINGLY_18193996619433734220: VariantsMap = [
    &["vaporingly"],
    &["vapouringly"],
    &["vapouringly"],
    &["vapouringly"],
];

pub(crate) static ENTRY_VAPORINGS_4745851328181075614: VariantsMap = [
    &["vaporings"],
    &["vapourings"],
    &["vapourings"],
    &["vapourings"],
];

pub(crate) static ENTRY_VAPORING_5632349647366369914: VariantsMap = [
    &["vaporing"],
    &["vapouring"],
    &["vapouring"],
    &["vapouring"],
];

pub(crate) static ENTRY_VAPORISHER_7217019342243877633: VariantsMap = [
    &["vaporisher"],
    &["vapourisher"],
    &["vapourisher"],
    &["vapourisher"],
];

pub(crate) static ENTRY_VAPORISHEST_12551478444608603779: VariantsMap = [
    &["vaporishest"],
    &["vapourishest"],
    &["vapourishest"],
    &["vapourishest"],
];

pub(crate) static ENTRY_VAPORISHNESSES_3346265753722413365: VariantsMap = [
    &["vaporishnesses"],
    &["vapourishnesses"],
    &["vapourishnesses"],
    &["vapourishnesses"],
];

pub(crate) static ENTRY_VAPORISHNESS_18298682645615478389: VariantsMap = [
    &["vaporishness"],
    &["vapourishness"],
    &["vapourishness"],
    &["vapourishness"],
];

pub(crate) static ENTRY_VAPORISH_4151648633909268593: VariantsMap = [
    &["vaporish"],
    &["vapourish"],
    &["vapourish"],
    &["vapourish"],
];

pub(crate) static ENTRY_VAPORIZABLER_330384219459697531: VariantsMap = [
    &["vaporizabler"],
    &["vaporisabler"],
    &["vaporizabler"],
    &["vaporisabler"],
];

pub(crate) static ENTRY_VAPORIZABLEST_16063759849633059522: VariantsMap = [
    &["vaporizablest"],
    &["vaporisablest"],
    &["vaporizablest"],
    &["vaporisablest"],
];

pub(crate) static ENTRY_VAPORIZABLES_8570559686466416467: VariantsMap = [
    &["vaporizables"],
    &["vaporisables"],
    &["vaporizables"],
    &["vaporisables"],
];

pub(crate) static ENTRY_VAPORIZABLE_1284750919722519568: VariantsMap = [
    &["vaporizable"],
    &["vaporisable"],
    &["vaporizable"],
    &["vaporisable"],
];

pub(crate) static ENTRY_VAPORIZATIONS_3616017509956798175: VariantsMap = [
    &["vaporizations"],
    &["vaporisations"],
    &["vaporizations"],
    &["vaporisations"],
];

pub(crate) static ENTRY_VAPORIZATION_6624016776962610799: VariantsMap = [
    &["vaporization"],
    &["vaporisation"],
    &["vaporization"],
    &["vaporisation"],
];

pub(crate) static ENTRY_VAPORIZED_4100382952590684636: VariantsMap = [
    &["vaporized"],
    &["vaporised"],
    &["vaporized"],
    &["vaporised"],
];

pub(crate) static ENTRY_VAPORIZERS_9656279687545559604: VariantsMap = [
    &["vaporizers"],
    &["vaporisers"],
    &["vaporizers"],
    &["vaporisers"],
];

pub(crate) static ENTRY_VAPORIZER_8052635902096901156: VariantsMap = [
    &["vaporizer"],
    &["vaporiser"],
    &["vaporizer"],
    &["vaporiser"],
];

pub(crate) static ENTRY_VAPORIZES_12186280109418449105: VariantsMap = [
    &["vaporizes"],
    &["vaporises"],
    &["vaporizes"],
    &["vaporises"],
];

pub(crate) static ENTRY_VAPORIZE_7074947866923787432: VariantsMap =
    [&["vaporize"], &["vaporise"], &["vaporize"], &["vaporise"]];

pub(crate) static ENTRY_VAPORIZING_11720449073985132085: VariantsMap = [
    &["vaporizing"],
    &["vaporising"],
    &["vaporizing"],
    &["vaporising"],
];

pub(crate) static ENTRY_VAPORLESSES_9449123748147448331: VariantsMap = [
    &["vaporlesses"],
    &["vapourlesses"],
    &["vapourlesses"],
    &["vapourlesses"],
];

pub(crate) static ENTRY_VAPORLESS_9180001548778190890: VariantsMap = [
    &["vaporless"],
    &["vapourless"],
    &["vapourless"],
    &["vapourless"],
];

pub(crate) static ENTRY_VAPORLIKES_17513958557622792273: VariantsMap = [
    &["vaporlikes"],
    &["vapourlikes"],
    &["vapourlikes"],
    &["vapourlikes"],
];

pub(crate) static ENTRY_VAPORLIKE_4304234079758020864: VariantsMap = [
    &["vaporlike"],
    &["vapourlike"],
    &["vapourlike"],
    &["vapourlike"],
];

pub(crate) static ENTRY_VAPOROSE_941229128135609892: VariantsMap = [
    &["vaporose"],
    &["vapourose"],
    &["vapourose"],
    &["vapourose"],
];

pub(crate) static ENTRY_VAPOROUSLY_10099688633493703963: VariantsMap = [
    &["vaporously"],
    &["vapourously"],
    &["vapourously"],
    &["vapourously"],
];

pub(crate) static ENTRY_VAPORS_9486200942177396366: VariantsMap =
    [&["vapors"], &["vapours"], &["vapours"], &["vapours"]];

pub(crate) static ENTRY_VAPORWARE_2722248098855884375: VariantsMap = [
    &["vaporware"],
    &["vapourware"],
    &["vapourware"],
    &["vapourware"],
];

pub(crate) static ENTRY_VAPORY_5997890858470358305: VariantsMap =
    [&["vapory"], &["vapoury"], &["vapoury"], &["vapoury"]];

pub(crate) static ENTRY_VAPOR_15613919849286651309: VariantsMap =
    [&["vapor"], &["vapour"], &["vapour"], &["vapour"]];

pub(crate) static ENTRY_VARICOLOREDDER_9075851730556261800: VariantsMap = [
    &["varicoloredder"],
    &["varicolouredder"],
    &["varicolouredder"],
    &["varicolouredder"],
];

pub(crate) static ENTRY_VARICOLOREDDEST_1560912123897475014: VariantsMap = [
    &["varicoloreddest"],
    &["varicoloureddest"],
    &["varicoloureddest"],
    &["varicoloureddest"],
];

pub(crate) static ENTRY_VARICOLOREDS_5399234029222855053: VariantsMap = [
    &["varicoloreds"],
    &["varicoloureds"],
    &["varicoloureds"],
    &["varicoloureds"],
];

pub(crate) static ENTRY_VARICOLORED_1171542226285534602: VariantsMap = [
    &["varicolored"],
    &["varicoloured"],
    &["varicoloured"],
    &["varicoloured"],
];

pub(crate) static ENTRY_VARICOLOROUS_2090604475004912852: VariantsMap = [
    &["varicolorous"],
    &["varicolourous"],
    &["varicolourous"],
    &["varicolourous"],
];

pub(crate) static ENTRY_VASCULARIZATIONS_8910282637625326095: VariantsMap = [
    &["vascularizations"],
    &["vascularisations"],
    &["vascularizations"],
    &["vascularisations"],
];

pub(crate) static ENTRY_VASCULARIZATION_7798251772115817237: VariantsMap = [
    &["vascularization"],
    &["vascularisation"],
    &["vascularization"],
    &["vascularisation"],
];

pub(crate) static ENTRY_VASCULARIZED_207387324778454868: VariantsMap = [
    &["vascularized"],
    &["vascularised"],
    &["vascularized"],
    &["vascularised"],
];

pub(crate) static ENTRY_VASCULARIZES_8060078253096737319: VariantsMap = [
    &["vascularizes"],
    &["vascularises"],
    &["vascularizes"],
    &["vascularises"],
];

pub(crate) static ENTRY_VASCULARIZE_5629782517352109818: VariantsMap = [
    &["vascularize"],
    &["vascularise"],
    &["vascularize"],
    &["vascularise"],
];

pub(crate) static ENTRY_VASCULARIZING_13278299349432868928: VariantsMap = [
    &["vascularizing"],
    &["vascularising"],
    &["vascularizing"],
    &["vascularising"],
];

pub(crate) static ENTRY_VASECTOMIZED_8925568978830732205: VariantsMap = [
    &["vasectomized"],
    &["vasectomised"],
    &["vasectomized"],
    &["vasectomised"],
];

pub(crate) static ENTRY_VASECTOMIZE_15454430706811576633: VariantsMap = [
    &["vasectomize"],
    &["vasectomise"],
    &["vasectomize"],
    &["vasectomise"],
];

pub(crate) static ENTRY_VASECTOMIZING_8116057054186241693: VariantsMap = [
    &["vasectomizing"],
    &["vasectomising"],
    &["vasectomizing"],
    &["vasectomising"],
];

pub(crate) static ENTRY_VASSALIZATION_7460874923683642348: VariantsMap = [
    &["vassalization"],
    &["vassalisation"],
    &["vassalization"],
    &["vassalisation"],
];

pub(crate) static ENTRY_VASSALIZED_10083471569803078316: VariantsMap = [
    &["vassalized"],
    &["vassalised"],
    &["vassalized"],
    &["vassalised"],
];

pub(crate) static ENTRY_VASSALIZES_4617029144268849855: VariantsMap = [
    &["vassalizes"],
    &["vassalises"],
    &["vassalizes"],
    &["vassalises"],
];

pub(crate) static ENTRY_VASSALIZE_8451924336001983191: VariantsMap = [
    &["vassalize"],
    &["vassalise"],
    &["vassalize"],
    &["vassalise"],
];

pub(crate) static ENTRY_VASSALIZING_12622050688866231311: VariantsMap = [
    &["vassalizing"],
    &["vassalising"],
    &["vassalizing"],
    &["vassalising"],
];

pub(crate) static ENTRY_VATICANIZATIONS_15982356743750740824: VariantsMap = [
    &["vaticanizations"],
    &["vaticanisations"],
    &["vaticanizations"],
    &["vaticanisations"],
];

pub(crate) static ENTRY_VATICANIZATION_12565515839826698578: VariantsMap = [
    &["vaticanization"],
    &["vaticanisation"],
    &["vaticanization"],
    &["vaticanisation"],
];

pub(crate) static ENTRY_VATICANIZES_16071718452803582750: VariantsMap = [
    &["vaticanizes"],
    &["vaticanises"],
    &["vaticanizes"],
    &["vaticanises"],
];

pub(crate) static ENTRY_VATICANIZE_13749277718192631537: VariantsMap = [
    &["vaticanize"],
    &["vaticanise"],
    &["vaticanize"],
    &["vaticanise"],
];

pub(crate) static ENTRY_VAVASORS_10746634756989528594: VariantsMap = [
    &["vavasors"],
    &["vavasours"],
    &["vavasours"],
    &["vavasours"],
];

pub(crate) static ENTRY_VAVASOR_6555930671551149776: VariantsMap =
    [&["vavasor"], &["vavasour"], &["vavasour"], &["vavasour"]];

pub(crate) static ENTRY_VECTORIZABLE_4166695678492588499: VariantsMap = [
    &["vectorizable"],
    &["vectorisable"],
    &["vectorizable"],
    &["vectorisable"],
];

pub(crate) static ENTRY_VECTORIZATIONS_465401059387640876: VariantsMap = [
    &["vectorizations"],
    &["vectorisations"],
    &["vectorizations"],
    &["vectorisations"],
];

pub(crate) static ENTRY_VECTORIZATION_9106141310054062019: VariantsMap = [
    &["vectorization"],
    &["vectorisation"],
    &["vectorization"],
    &["vectorisation"],
];

pub(crate) static ENTRY_VECTORIZED_13224707387286509209: VariantsMap = [
    &["vectorized"],
    &["vectorised"],
    &["vectorized"],
    &["vectorised"],
];

pub(crate) static ENTRY_VECTORIZERED_9703684870141080163: VariantsMap = [
    &["vectorizered"],
    &["vectorisered"],
    &["vectorizered"],
    &["vectorisered"],
];

pub(crate) static ENTRY_VECTORIZERING_15878663610053146444: VariantsMap = [
    &["vectorizering"],
    &["vectorisering"],
    &["vectorizering"],
    &["vectorisering"],
];

pub(crate) static ENTRY_VECTORIZERS_9835891468155617: VariantsMap = [
    &["vectorizers"],
    &["vectorisers"],
    &["vectorizers"],
    &["vectorisers"],
];

pub(crate) static ENTRY_VECTORIZER_12091376211856766051: VariantsMap = [
    &["vectorizer"],
    &["vectoriser"],
    &["vectorizer"],
    &["vectoriser"],
];

pub(crate) static ENTRY_VECTORIZES_7917294144821648305: VariantsMap = [
    &["vectorizes"],
    &["vectorises"],
    &["vectorizes"],
    &["vectorises"],
];

pub(crate) static ENTRY_VECTORIZE_13096018160775133343: VariantsMap = [
    &["vectorize"],
    &["vectorise"],
    &["vectorize"],
    &["vectorise"],
];

pub(crate) static ENTRY_VECTORIZING_9538566325910673128: VariantsMap = [
    &["vectorizing"],
    &["vectorising"],
    &["vectorizing"],
    &["vectorising"],
];

pub(crate) static ENTRY_VEERY_7871806231150043123: VariantsMap =
    [&["veery"], &["verey"], &["verey"], &["verey"]];

pub(crate) static ENTRY_VEGETABLIZES_6567628138079375237: VariantsMap = [
    &["vegetablizes"],
    &["vegetablises"],
    &["vegetablizes"],
    &["vegetablises"],
];

pub(crate) static ENTRY_VEGETABLIZE_15652329865549979869: VariantsMap = [
    &["vegetablize"],
    &["vegetablise"],
    &["vegetablize"],
    &["vegetablise"],
];

pub(crate) static ENTRY_VELARIZATIONS_14651119125598343114: VariantsMap = [
    &["velarizations"],
    &["velarisations"],
    &["velarizations"],
    &["velarisations"],
];

pub(crate) static ENTRY_VELARIZATION_1403990956820502853: VariantsMap = [
    &["velarization"],
    &["velarisation"],
    &["velarization"],
    &["velarisation"],
];

pub(crate) static ENTRY_VELARIZED_17587151593626429889: VariantsMap = [
    &["velarized"],
    &["velarised"],
    &["velarized"],
    &["velarised"],
];

pub(crate) static ENTRY_VELARIZES_7541885077312241167: VariantsMap = [
    &["velarizes"],
    &["velarises"],
    &["velarizes"],
    &["velarises"],
];

pub(crate) static ENTRY_VELARIZE_4143880025810776209: VariantsMap =
    [&["velarize"], &["velarise"], &["velarize"], &["velarise"]];

pub(crate) static ENTRY_VELARIZING_10043182753015176040: VariantsMap = [
    &["velarizing"],
    &["velarising"],
    &["velarizing"],
    &["velarising"],
];

pub(crate) static ENTRY_VENALIZATIONS_2118690871234046077: VariantsMap = [
    &["venalizations"],
    &["venalisations"],
    &["venalizations"],
    &["venalisations"],
];

pub(crate) static ENTRY_VENALIZATION_2122570152538799298: VariantsMap = [
    &["venalization"],
    &["venalisation"],
    &["venalization"],
    &["venalisation"],
];

pub(crate) static ENTRY_VENALIZES_17850293216838309236: VariantsMap = [
    &["venalizes"],
    &["venalises"],
    &["venalizes"],
    &["venalises"],
];

pub(crate) static ENTRY_VENALIZE_17116259915286472347: VariantsMap =
    [&["venalize"], &["venalise"], &["venalize"], &["venalise"]];

pub(crate) static ENTRY_VENDORS_995846644620124863: VariantsMap =
    [&["vendors"], &["vendors"], &["vendors"], &["vendors"]];

pub(crate) static ENTRY_VENDOR_2662061828917411576: VariantsMap =
    [&["vendor"], &["vendor"], &["vendor"], &["vendor"]];

pub(crate) static ENTRY_VENOMIZATIONS_15701983704376518542: VariantsMap = [
    &["venomizations"],
    &["venomisations"],
    &["venomizations"],
    &["venomisations"],
];

pub(crate) static ENTRY_VENOMIZATION_15358943620485615148: VariantsMap = [
    &["venomization"],
    &["venomisation"],
    &["venomization"],
    &["venomisation"],
];

pub(crate) static ENTRY_VENOMIZES_16197925629249240457: VariantsMap = [
    &["venomizes"],
    &["venomises"],
    &["venomizes"],
    &["venomises"],
];

pub(crate) static ENTRY_VENOMIZE_18257057476761108930: VariantsMap =
    [&["venomize"], &["venomise"], &["venomize"], &["venomise"]];

pub(crate) static ENTRY_VENTERS_5205786364593283296: VariantsMap =
    [&["venters"], &["ventres"], &["ventres"], &["ventres"]];

pub(crate) static ENTRY_VENTER_10510516635110887923: VariantsMap =
    [&["venter"], &["ventre"], &["ventre"], &["ventre"]];

pub(crate) static ENTRY_VENTRILOQUIZED_17464849051904807365: VariantsMap = [
    &["ventriloquized"],
    &["ventriloquised"],
    &["ventriloquized"],
    &["ventriloquised"],
];

pub(crate) static ENTRY_VENTRILOQUIZES_7366719022132000191: VariantsMap = [
    &["ventriloquizes"],
    &["ventriloquises"],
    &["ventriloquizes"],
    &["ventriloquises"],
];

pub(crate) static ENTRY_VENTRILOQUIZE_7278912386074535832: VariantsMap = [
    &["ventriloquize"],
    &["ventriloquise"],
    &["ventriloquize"],
    &["ventriloquise"],
];

pub(crate) static ENTRY_VENTRILOQUIZING_16373058130648158850: VariantsMap = [
    &["ventriloquizing"],
    &["ventriloquising"],
    &["ventriloquizing"],
    &["ventriloquising"],
];

pub(crate) static ENTRY_VENULE_16081436179391149786: VariantsMap =
    [&["venule"], &["venulae"], &["venulae"], &["venulae"]];

pub(crate) static ENTRY_VERBALIZATIONS_10614435035631184613: VariantsMap = [
    &["verbalizations"],
    &["verbalisations"],
    &["verbalizations"],
    &["verbalisations"],
];

pub(crate) static ENTRY_VERBALIZATION_1606887602703040047: VariantsMap = [
    &["verbalization"],
    &["verbalisation"],
    &["verbalization"],
    &["verbalisation"],
];

pub(crate) static ENTRY_VERBALIZED_3584116992871405343: VariantsMap = [
    &["verbalized"],
    &["verbalised"],
    &["verbalized"],
    &["verbalised"],
];

pub(crate) static ENTRY_VERBALIZERS_13686674633988019779: VariantsMap = [
    &["verbalizers"],
    &["verbalisers"],
    &["verbalizers"],
    &["verbalisers"],
];

pub(crate) static ENTRY_VERBALIZER_5476531062608223227: VariantsMap = [
    &["verbalizer"],
    &["verbaliser"],
    &["verbalizer"],
    &["verbaliser"],
];

pub(crate) static ENTRY_VERBALIZES_9773922676702933955: VariantsMap = [
    &["verbalizes"],
    &["verbalises"],
    &["verbalizes"],
    &["verbalises"],
];

pub(crate) static ENTRY_VERBALIZE_8914927163486915483: VariantsMap = [
    &["verbalize"],
    &["verbalise"],
    &["verbalize"],
    &["verbalise"],
];

pub(crate) static ENTRY_VERBALIZING_4674155461307593201: VariantsMap = [
    &["verbalizing"],
    &["verbalising"],
    &["verbalizing"],
    &["verbalising"],
];

pub(crate) static ENTRY_VERMEILED_3870685009631656496: VariantsMap = [
    &["vermeiled"],
    &["vermeilled"],
    &["vermeilled"],
    &["vermeilled"],
];

pub(crate) static ENTRY_VERMEILES_6091101275731102631: VariantsMap = [
    &["vermeiles"],
    &["vermeilles"],
    &["vermeilles"],
    &["vermeilles"],
];

pub(crate) static ENTRY_VERMEILING_16263718376783682636: VariantsMap = [
    &["vermeiling"],
    &["vermeilling"],
    &["vermeilling"],
    &["vermeilling"],
];

pub(crate) static ENTRY_VERMILIONIZES_12599262771675475462: VariantsMap = [
    &["vermilionizes"],
    &["vermilionises"],
    &["vermilionizes"],
    &["vermilionises"],
];

pub(crate) static ENTRY_VERMILIONIZE_1285328019998267214: VariantsMap = [
    &["vermilionize"],
    &["vermilionise"],
    &["vermilionize"],
    &["vermilionise"],
];

pub(crate) static ENTRY_VERNACULARIZATIONS_14415525320546941498: VariantsMap = [
    &["vernacularizations"],
    &["vernacularisations"],
    &["vernacularizations"],
    &["vernacularisations"],
];

pub(crate) static ENTRY_VERNACULARIZATION_8027917640062920182: VariantsMap = [
    &["vernacularization"],
    &["vernacularisation"],
    &["vernacularization"],
    &["vernacularisation"],
];

pub(crate) static ENTRY_VERNACULARIZED_12492141793786233950: VariantsMap = [
    &["vernacularized"],
    &["vernacularised"],
    &["vernacularized"],
    &["vernacularised"],
];

pub(crate) static ENTRY_VERNACULARIZES_15960776775823268746: VariantsMap = [
    &["vernacularizes"],
    &["vernacularises"],
    &["vernacularizes"],
    &["vernacularises"],
];

pub(crate) static ENTRY_VERNACULARIZE_12667767946887279081: VariantsMap = [
    &["vernacularize"],
    &["vernacularise"],
    &["vernacularize"],
    &["vernacularise"],
];

pub(crate) static ENTRY_VERNACULARIZING_10081295290347631824: VariantsMap = [
    &["vernacularizing"],
    &["vernacularising"],
    &["vernacularizing"],
    &["vernacularising"],
];

pub(crate) static ENTRY_VERNALIZATIONS_4660850075716999699: VariantsMap = [
    &["vernalizations"],
    &["vernalisations"],
    &["vernalizations"],
    &["vernalisations"],
];

pub(crate) static ENTRY_VERNALIZATION_11355184477337865623: VariantsMap = [
    &["vernalization"],
    &["vernalisation"],
    &["vernalization"],
    &["vernalisation"],
];

pub(crate) static ENTRY_VERNALIZED_10973377624262151914: VariantsMap = [
    &["vernalized"],
    &["vernalised"],
    &["vernalized"],
    &["vernalised"],
];

pub(crate) static ENTRY_VERNALIZES_5256099709798243477: VariantsMap = [
    &["vernalizes"],
    &["vernalises"],
    &["vernalizes"],
    &["vernalises"],
];

pub(crate) static ENTRY_VERNALIZE_12962724599289195261: VariantsMap = [
    &["vernalize"],
    &["vernalise"],
    &["vernalize"],
    &["vernalise"],
];

pub(crate) static ENTRY_VERNALIZING_10128158728667959931: VariantsMap = [
    &["vernalizing"],
    &["vernalising"],
    &["vernalizing"],
    &["vernalising"],
];

pub(crate) static ENTRY_VERSICOLORATE_1213108598258359303: VariantsMap = [
    &["versicolorate"],
    &["versicolourate"],
    &["versicolourate"],
    &["versicolourate"],
];

pub(crate) static ENTRY_VERSICOLORED_8698649720277268404: VariantsMap = [
    &["versicolored"],
    &["versicoloured"],
    &["versicoloured"],
    &["versicoloured"],
];

pub(crate) static ENTRY_VERSICOLOROUS_17729000221904743199: VariantsMap = [
    &["versicolorous"],
    &["versicolourous"],
    &["versicolourous"],
    &["versicolourous"],
];

pub(crate) static ENTRY_VERSICOLOR_1583338907759165683: VariantsMap = [
    &["versicolor"],
    &["versicolour"],
    &["versicolour"],
    &["versicolour"],
];

pub(crate) static ENTRY_VERSIONIZES_14825603837161816590: VariantsMap = [
    &["versionizes"],
    &["versionises"],
    &["versionizes"],
    &["versionises"],
];

pub(crate) static ENTRY_VERSIONIZE_13036102572385152608: VariantsMap = [
    &["versionize"],
    &["versionise"],
    &["versionize"],
    &["versionise"],
];

pub(crate) static ENTRY_VESICULE_13319860871922937249: VariantsMap = [
    &["vesicule"],
    &["vesiculae"],
    &["vesiculae"],
    &["vesiculae"],
];

pub(crate) static ENTRY_VESTRYIZES_2842047993646822066: VariantsMap = [
    &["vestryizes"],
    &["vestryises"],
    &["vestryizes"],
    &["vestryises"],
];

pub(crate) static ENTRY_VESTRYIZE_2427050586639943215: VariantsMap = [
    &["vestryize"],
    &["vestryise"],
    &["vestryize"],
    &["vestryise"],
];

pub(crate) static ENTRY_VETERANIZES_11256585660882985870: VariantsMap = [
    &["veteranizes"],
    &["veteranises"],
    &["veteranizes"],
    &["veteranises"],
];

pub(crate) static ENTRY_VETERANIZE_9438252469704632209: VariantsMap = [
    &["veteranize"],
    &["veteranise"],
    &["veteranize"],
    &["veteranise"],
];

pub(crate) static ENTRY_VETER_13843276293183836593: VariantsMap =
    [&["veter"], &["vetoer"], &["vetoer"], &["vetoer"]];

pub(crate) static ENTRY_VE_18321759983148480762: VariantsMap =
    [&["ve"], &["voe"], &["voe"], &["voe"]];

pub(crate) static ENTRY_VIALED_9232052728666801517: VariantsMap =
    [&["vialed"], &["vialled"], &["vialled"], &["vialled"]];

pub(crate) static ENTRY_VIALING_4586545000054977864: VariantsMap =
    [&["vialing"], &["vialling"], &["vialling"], &["vialling"]];

pub(crate) static ENTRY_VICTIMIZABLES_1207522680409246759: VariantsMap = [
    &["victimizables"],
    &["victimisables"],
    &["victimizables"],
    &["victimisables"],
];

pub(crate) static ENTRY_VICTIMIZABLE_17859456941815780193: VariantsMap = [
    &["victimizable"],
    &["victimisable"],
    &["victimizable"],
    &["victimisable"],
];

pub(crate) static ENTRY_VICTIMIZATIONS_14899906545794033733: VariantsMap = [
    &["victimizations"],
    &["victimisations"],
    &["victimizations"],
    &["victimisations"],
];

pub(crate) static ENTRY_VICTIMIZATION_13826269504308493839: VariantsMap = [
    &["victimization"],
    &["victimisation"],
    &["victimization"],
    &["victimisation"],
];

pub(crate) static ENTRY_VICTIMIZED_12606813743201188153: VariantsMap = [
    &["victimized"],
    &["victimised"],
    &["victimized"],
    &["victimised"],
];

pub(crate) static ENTRY_VICTIMIZERS_13260960052208526566: VariantsMap = [
    &["victimizers"],
    &["victimisers"],
    &["victimizers"],
    &["victimisers"],
];

pub(crate) static ENTRY_VICTIMIZER_13906638213650914285: VariantsMap = [
    &["victimizer"],
    &["victimiser"],
    &["victimizer"],
    &["victimiser"],
];

pub(crate) static ENTRY_VICTIMIZES_7043365108562081976: VariantsMap = [
    &["victimizes"],
    &["victimises"],
    &["victimizes"],
    &["victimises"],
];

pub(crate) static ENTRY_VICTIMIZE_14299551425382354965: VariantsMap = [
    &["victimize"],
    &["victimise"],
    &["victimize"],
    &["victimise"],
];

pub(crate) static ENTRY_VICTIMIZING_2146280365921517894: VariantsMap = [
    &["victimizing"],
    &["victimising"],
    &["victimizing"],
    &["victimising"],
];

pub(crate) static ENTRY_VICTORIANIZES_10077169725694243555: VariantsMap = [
    &["victorianizes"],
    &["victorianises"],
    &["victorianizes"],
    &["victorianises"],
];

pub(crate) static ENTRY_VICTORIANIZE_6350658122976337243: VariantsMap = [
    &["victorianize"],
    &["victorianise"],
    &["victorianize"],
    &["victorianise"],
];

pub(crate) static ENTRY_VICTUALAGES_1602498729217236921: VariantsMap = [
    &["victualages"],
    &["victuallages"],
    &["victuallages"],
    &["victuallages"],
];

pub(crate) static ENTRY_VICTUALAGE_11748837061098354479: VariantsMap = [
    &["victualage"],
    &["victuallage"],
    &["victuallage"],
    &["victuallage"],
];

pub(crate) static ENTRY_VICTUALED_3906018588064117729: VariantsMap = [
    &["victualed"],
    &["victualled"],
    &["victualled"],
    &["victualled"],
];

pub(crate) static ENTRY_VICTUALERS_3647699329720955367: VariantsMap = [
    &["victualers"],
    &["victuallers"],
    &["victuallers"],
    &["victuallers"],
];

pub(crate) static ENTRY_VICTUALER_6754560860965136910: VariantsMap = [
    &["victualer"],
    &["victualler"],
    &["victualler"],
    &["victualler"],
];

pub(crate) static ENTRY_VICTUALESS_4554391893102998851: VariantsMap = [
    &["victualess"],
    &["victualless"],
    &["victualless"],
    &["victualless"],
];

pub(crate) static ENTRY_VICTUALING_14956768953788562589: VariantsMap = [
    &["victualing"],
    &["victualling"],
    &["victualling"],
    &["victualling"],
];

pub(crate) static ENTRY_VIDEODISCS_8893076495672262384: VariantsMap = [
    &["videodiscs"],
    &["videodiscs"],
    &["videodiscs"],
    &["videodiscs"],
];

pub(crate) static ENTRY_VIDEODISC_4085471265875741194: VariantsMap = [
    &["videodisc"],
    &["videodisc"],
    &["videodisc"],
    &["videodisc"],
];

pub(crate) static ENTRY_VIERS_10473285009744197700: VariantsMap =
    [&["viers"], &["vires"], &["vires"], &["vires"]];

pub(crate) static ENTRY_VIER_10758602254813181277: VariantsMap =
    [&["vier"], &["vire"], &["vire"], &["vire"]];

pub(crate) static ENTRY_VIETNAMIZATION_4722543635437789217: VariantsMap = [
    &["vietnamization"],
    &["vietnamisation"],
    &["vietnamization"],
    &["vietnamisation"],
];

pub(crate) static ENTRY_VIETNAMIZED_4541312385379938819: VariantsMap = [
    &["vietnamized"],
    &["vietnamised"],
    &["vietnamized"],
    &["vietnamised"],
];

pub(crate) static ENTRY_VIETNAMIZES_8386876976890033192: VariantsMap = [
    &["vietnamizes"],
    &["vietnamises"],
    &["vietnamizes"],
    &["vietnamises"],
];

pub(crate) static ENTRY_VIETNAMIZE_14928666003292211538: VariantsMap = [
    &["vietnamize"],
    &["vietnamise"],
    &["vietnamize"],
    &["vietnamise"],
];

pub(crate) static ENTRY_VIETNAMIZING_9657833441293397796: VariantsMap = [
    &["vietnamizing"],
    &["vietnamising"],
    &["vietnamizing"],
    &["vietnamising"],
];

pub(crate) static ENTRY_VIGORLESS_8298894391042086723: VariantsMap = [
    &["vigorless"],
    &["vigourless"],
    &["vigourless"],
    &["vigourless"],
];

pub(crate) static ENTRY_VIGORS_7078003063773531029: VariantsMap =
    [&["vigors"], &["vigours"], &["vigours"], &["vigours"]];

pub(crate) static ENTRY_VIGOR_4255508283031723378: VariantsMap =
    [&["vigor"], &["vigour"], &["vigour"], &["vigour"]];

pub(crate) static ENTRY_VILLAGIZATIONS_11494631120078954743: VariantsMap = [
    &["villagizations"],
    &["villagisations"],
    &["villagizations"],
    &["villagisations"],
];

pub(crate) static ENTRY_VILLAGIZATION_3904516988221777458: VariantsMap = [
    &["villagization"],
    &["villagisation"],
    &["villagization"],
    &["villagisation"],
];

pub(crate) static ENTRY_VIREMIAS_7267662670115422503: VariantsMap = [
    &["viremias"],
    &["viraemias"],
    &["viraemias"],
    &["viraemias"],
];

pub(crate) static ENTRY_VIREMIA_1841488076881209053: VariantsMap =
    [&["viremia"], &["viraemia"], &["viraemia"], &["viraemia"]];

pub(crate) static ENTRY_VIREMIC_6601391614385695738: VariantsMap =
    [&["viremic"], &["viraemic"], &["viraemic"], &["viraemic"]];

pub(crate) static ENTRY_VIRILIZATIONS_2259339284050725137: VariantsMap = [
    &["virilizations"],
    &["virilisations"],
    &["virilizations"],
    &["virilisations"],
];

pub(crate) static ENTRY_VIRILIZATION_17984148691371003559: VariantsMap = [
    &["virilization"],
    &["virilisation"],
    &["virilization"],
    &["virilisation"],
];

pub(crate) static ENTRY_VIRILIZED_14042124459396072676: VariantsMap = [
    &["virilized"],
    &["virilised"],
    &["virilized"],
    &["virilised"],
];

pub(crate) static ENTRY_VIRILIZING_3864311870427123549: VariantsMap = [
    &["virilizing"],
    &["virilising"],
    &["virilizing"],
    &["virilising"],
];

pub(crate) static ENTRY_VIRTUALIZATION_8096145334874168940: VariantsMap = [
    &["virtualization"],
    &["virtualisation"],
    &["virtualisation"],
    &["virtualisation"],
];

pub(crate) static ENTRY_VIRTUALIZES_1664114726545811102: VariantsMap = [
    &["virtualizes"],
    &["virtualises"],
    &["virtualizes"],
    &["virtualises"],
];

pub(crate) static ENTRY_VIRTUALIZE_5037242355249715652: VariantsMap = [
    &["virtualize"],
    &["virtualise"],
    &["virtualize"],
    &["virtualise"],
];

pub(crate) static ENTRY_VIRTUOSI_6032024204705561293: VariantsMap =
    [&["virtuosi"], &["virtuosi"], &["virtuosi"], &["virtuosi"]];

pub(crate) static ENTRY_VISIONIZES_18286863748296097590: VariantsMap = [
    &["visionizes"],
    &["visionises"],
    &["visionizes"],
    &["visionises"],
];

pub(crate) static ENTRY_VISIONIZE_3799273824415270214: VariantsMap = [
    &["visionize"],
    &["visionise"],
    &["visionize"],
    &["visionise"],
];

pub(crate) static ENTRY_VISORS_161131917315397622: VariantsMap =
    [&["visors"], &["visors"], &["visors"], &["visors"]];

pub(crate) static ENTRY_VISOR_11952253766687812439: VariantsMap =
    [&["visor"], &["visor"], &["visor"], &["visor"]];

pub(crate) static ENTRY_VISUALIZABLE_7962038464582692957: VariantsMap = [
    &["visualizable"],
    &["visualisable"],
    &["visualizable"],
    &["visualisable"],
];

pub(crate) static ENTRY_VISUALIZATIONS_14330999670741801492: VariantsMap = [
    &["visualizations"],
    &["visualisations"],
    &["visualizations"],
    &["visualisations"],
];

pub(crate) static ENTRY_VISUALIZATION_18445006641756380637: VariantsMap = [
    &["visualization"],
    &["visualisation"],
    &["visualization"],
    &["visualisation"],
];

pub(crate) static ENTRY_VISUALIZED_4913836830057768977: VariantsMap = [
    &["visualized"],
    &["visualised"],
    &["visualized"],
    &["visualised"],
];

pub(crate) static ENTRY_VISUALIZERS_5162859868708280179: VariantsMap = [
    &["visualizers"],
    &["visualisers"],
    &["visualizers"],
    &["visualisers"],
];

pub(crate) static ENTRY_VISUALIZER_6771531166983832662: VariantsMap = [
    &["visualizer"],
    &["visualiser"],
    &["visualizer"],
    &["visualiser"],
];

pub(crate) static ENTRY_VISUALIZES_1129887224614498129: VariantsMap = [
    &["visualizes"],
    &["visualises"],
    &["visualizes"],
    &["visualises"],
];

pub(crate) static ENTRY_VISUALIZE_14218254075459395624: VariantsMap = [
    &["visualize"],
    &["visualise"],
    &["visualize"],
    &["visualise"],
];

pub(crate) static ENTRY_VISUALIZING_8411182104988658747: VariantsMap = [
    &["visualizing"],
    &["visualising"],
    &["visualizing"],
    &["visualising"],
];

pub(crate) static ENTRY_VITALIZATIONS_18199586670931656342: VariantsMap = [
    &["vitalizations"],
    &["vitalisations"],
    &["vitalizations"],
    &["vitalisations"],
];

pub(crate) static ENTRY_VITALIZATION_11563378875657312422: VariantsMap = [
    &["vitalization"],
    &["vitalisation"],
    &["vitalization"],
    &["vitalisation"],
];

pub(crate) static ENTRY_VITALIZED_5879957138765444190: VariantsMap = [
    &["vitalized"],
    &["vitalised"],
    &["vitalized"],
    &["vitalised"],
];

pub(crate) static ENTRY_VITALIZERS_4676040118864720970: VariantsMap = [
    &["vitalizers"],
    &["vitalisers"],
    &["vitalizers"],
    &["vitalisers"],
];

pub(crate) static ENTRY_VITALIZER_11015449244036225995: VariantsMap = [
    &["vitalizer"],
    &["vitaliser"],
    &["vitalizer"],
    &["vitaliser"],
];

pub(crate) static ENTRY_VITALIZES_6574062411877117887: VariantsMap = [
    &["vitalizes"],
    &["vitalises"],
    &["vitalizes"],
    &["vitalises"],
];

pub(crate) static ENTRY_VITALIZE_14767623916291210585: VariantsMap =
    [&["vitalize"], &["vitalise"], &["vitalize"], &["vitalise"]];

pub(crate) static ENTRY_VITALIZINGLY_17977921766837363551: VariantsMap = [
    &["vitalizingly"],
    &["vitalisingly"],
    &["vitalizingly"],
    &["vitalisingly"],
];

pub(crate) static ENTRY_VITALIZINGS_7993175705382773400: VariantsMap = [
    &["vitalizings"],
    &["vitalisings"],
    &["vitalizings"],
    &["vitalisings"],
];

pub(crate) static ENTRY_VITALIZING_1172441218463801200: VariantsMap = [
    &["vitalizing"],
    &["vitalising"],
    &["vitalizing"],
    &["vitalising"],
];

pub(crate) static ENTRY_VITAMINIZATION_4345576685277511178: VariantsMap = [
    &["vitaminization"],
    &["vitaminisation"],
    &["vitaminization"],
    &["vitaminisation"],
];

pub(crate) static ENTRY_VITAMINIZED_11070966012909977792: VariantsMap = [
    &["vitaminized"],
    &["vitaminised"],
    &["vitaminized"],
    &["vitaminised"],
];

pub(crate) static ENTRY_VITAMINIZES_11610615403175719091: VariantsMap = [
    &["vitaminizes"],
    &["vitaminises"],
    &["vitaminizes"],
    &["vitaminises"],
];

pub(crate) static ENTRY_VITAMINIZE_3815155023809780843: VariantsMap = [
    &["vitaminize"],
    &["vitaminise"],
    &["vitaminize"],
    &["vitaminise"],
];

pub(crate) static ENTRY_VITAMINIZING_14433390025156461290: VariantsMap = [
    &["vitaminizing"],
    &["vitaminising"],
    &["vitaminizing"],
    &["vitaminising"],
];

pub(crate) static ENTRY_VITRIOLIZABLES_6495066641769157690: VariantsMap = [
    &["vitriolizables"],
    &["vitriolisables"],
    &["vitriolizables"],
    &["vitriolisables"],
];

pub(crate) static ENTRY_VITRIOLIZABLE_10128808547473444732: VariantsMap = [
    &["vitriolizable"],
    &["vitriolisable"],
    &["vitriolizable"],
    &["vitriolisable"],
];

pub(crate) static ENTRY_VITRIOLIZATIONS_12059310110149895869: VariantsMap = [
    &["vitriolizations"],
    &["vitriolisations"],
    &["vitriolizations"],
    &["vitriolisations"],
];

pub(crate) static ENTRY_VITRIOLIZATION_12177216141601047223: VariantsMap = [
    &["vitriolization"],
    &["vitriolisation"],
    &["vitriolization"],
    &["vitriolisation"],
];

pub(crate) static ENTRY_VITRIOLIZED_726289364433095774: VariantsMap = [
    &["vitriolized"],
    &["vitriolised"],
    &["vitriolized"],
    &["vitriolised"],
];

pub(crate) static ENTRY_VITRIOLIZERS_1786300307817004832: VariantsMap = [
    &["vitriolizers"],
    &["vitriolisers"],
    &["vitriolizers"],
    &["vitriolisers"],
];

pub(crate) static ENTRY_VITRIOLIZER_1822506942241343764: VariantsMap = [
    &["vitriolizer"],
    &["vitrioliser"],
    &["vitriolizer"],
    &["vitrioliser"],
];

pub(crate) static ENTRY_VITRIOLIZES_12629386703569894013: VariantsMap = [
    &["vitriolizes"],
    &["vitriolises"],
    &["vitriolizes"],
    &["vitriolises"],
];

pub(crate) static ENTRY_VITRIOLIZE_16677616817185174970: VariantsMap = [
    &["vitriolize"],
    &["vitriolise"],
    &["vitriolize"],
    &["vitriolise"],
];

pub(crate) static ENTRY_VITRIOLIZING_9645904006126235201: VariantsMap = [
    &["vitriolizing"],
    &["vitriolising"],
    &["vitriolizing"],
    &["vitriolising"],
];

pub(crate) static ENTRY_VIVANDIER_12659384511325353809: VariantsMap = [
    &["vivandier"],
    &["vivandire"],
    &["vivandire"],
    &["vivandire"],
];

pub(crate) static ENTRY_VIVERRINE_4631118611455296151: VariantsMap = [
    &["viverrine"],
    &["viverrinae"],
    &["viverrinae"],
    &["viverrinae"],
];

pub(crate) static ENTRY_VIVERS_1304906869884388477: VariantsMap =
    [&["vivers"], &["vivres"], &["vivres"], &["vivres"]];

pub(crate) static ENTRY_VIVER_3159459969980561998: VariantsMap =
    [&["viver"], &["vivre"], &["vivre"], &["vivre"]];

pub(crate) static ENTRY_VIZARDS_6967258731291371717: VariantsMap =
    [&["vizards"], &["visards"], &["vizards"], &["visards"]];

pub(crate) static ENTRY_VIZARD_10999789749375739354: VariantsMap =
    [&["vizard"], &["visard"], &["vizard"], &["visard"]];

pub(crate) static ENTRY_VIZIED_7049215544631748789: VariantsMap =
    [&["vizied"], &["visied"], &["vizied"], &["visied"]];

pub(crate) static ENTRY_VIZIES_2932586557445870650: VariantsMap =
    [&["vizies"], &["visies"], &["vizies"], &["visies"]];

pub(crate) static ENTRY_VOCALIZATIONS_6540912521590792850: VariantsMap = [
    &["vocalizations"],
    &["vocalisations"],
    &["vocalizations"],
    &["vocalisations"],
];

pub(crate) static ENTRY_VOCALIZATION_16299156444456516020: VariantsMap = [
    &["vocalization"],
    &["vocalisation"],
    &["vocalization"],
    &["vocalisation"],
];

pub(crate) static ENTRY_VOCALIZED_18024346592150936448: VariantsMap = [
    &["vocalized"],
    &["vocalised"],
    &["vocalized"],
    &["vocalised"],
];

pub(crate) static ENTRY_VOCALIZERS_5083157038348945833: VariantsMap = [
    &["vocalizers"],
    &["vocalisers"],
    &["vocalizers"],
    &["vocalisers"],
];

pub(crate) static ENTRY_VOCALIZER_12799422523009315217: VariantsMap = [
    &["vocalizer"],
    &["vocaliser"],
    &["vocalizer"],
    &["vocaliser"],
];

pub(crate) static ENTRY_VOCALIZES_1880412935306735877: VariantsMap = [
    &["vocalizes"],
    &["vocalises"],
    &["vocalizes"],
    &["vocalises"],
];

pub(crate) static ENTRY_VOCALIZE_1522162759221483083: VariantsMap =
    [&["vocalize"], &["vocalise"], &["vocalize"], &["vocalise"]];

pub(crate) static ENTRY_VOCALIZING_6361847323758753459: VariantsMap = [
    &["vocalizing"],
    &["vocalising"],
    &["vocalizing"],
    &["vocalising"],
];

pub(crate) static ENTRY_VOCATIONALIZATIONS_12760103465092649332: VariantsMap = [
    &["vocationalizations"],
    &["vocationalisations"],
    &["vocationalizations"],
    &["vocationalisations"],
];

pub(crate) static ENTRY_VOCATIONALIZATION_5843882192252215451: VariantsMap = [
    &["vocationalization"],
    &["vocationalisation"],
    &["vocationalization"],
    &["vocationalisation"],
];

pub(crate) static ENTRY_VOCATIONALIZES_9469137790249815859: VariantsMap = [
    &["vocationalizes"],
    &["vocationalises"],
    &["vocationalizes"],
    &["vocationalises"],
];

pub(crate) static ENTRY_VOCATIONALIZE_11565960507105247770: VariantsMap = [
    &["vocationalize"],
    &["vocationalise"],
    &["vocationalize"],
    &["vocationalise"],
];

pub(crate) static ENTRY_VOLATILIZABLER_10970801449329037349: VariantsMap = [
    &["volatilizabler"],
    &["volatilisabler"],
    &["volatilizabler"],
    &["volatilisabler"],
];

pub(crate) static ENTRY_VOLATILIZABLEST_9951102031117910204: VariantsMap = [
    &["volatilizablest"],
    &["volatilisablest"],
    &["volatilizablest"],
    &["volatilisablest"],
];

pub(crate) static ENTRY_VOLATILIZABLES_3387142756898266550: VariantsMap = [
    &["volatilizables"],
    &["volatilisables"],
    &["volatilizables"],
    &["volatilisables"],
];

pub(crate) static ENTRY_VOLATILIZABLE_14191734210917893484: VariantsMap = [
    &["volatilizable"],
    &["volatilisable"],
    &["volatilizable"],
    &["volatilisable"],
];

pub(crate) static ENTRY_VOLATILIZATIONS_2738963093881521684: VariantsMap = [
    &["volatilizations"],
    &["volatilisations"],
    &["volatilizations"],
    &["volatilisations"],
];

pub(crate) static ENTRY_VOLATILIZATION_2524869946541654890: VariantsMap = [
    &["volatilization"],
    &["volatilisation"],
    &["volatilization"],
    &["volatilisation"],
];

pub(crate) static ENTRY_VOLATILIZED_162413967292134988: VariantsMap = [
    &["volatilized"],
    &["volatilised"],
    &["volatilized"],
    &["volatilised"],
];

pub(crate) static ENTRY_VOLATILIZERS_8351703320828050913: VariantsMap = [
    &["volatilizers"],
    &["volatilisers"],
    &["volatilizers"],
    &["volatilisers"],
];

pub(crate) static ENTRY_VOLATILIZER_15355427557723391751: VariantsMap = [
    &["volatilizer"],
    &["volatiliser"],
    &["volatilizer"],
    &["volatiliser"],
];

pub(crate) static ENTRY_VOLATILIZES_1469470071448453292: VariantsMap = [
    &["volatilizes"],
    &["volatilises"],
    &["volatilizes"],
    &["volatilises"],
];

pub(crate) static ENTRY_VOLATILIZE_12701439457008031789: VariantsMap = [
    &["volatilize"],
    &["volatilise"],
    &["volatilize"],
    &["volatilise"],
];

pub(crate) static ENTRY_VOLATILIZING_4582472073708524953: VariantsMap = [
    &["volatilizing"],
    &["volatilising"],
    &["volatilizing"],
    &["volatilising"],
];

pub(crate) static ENTRY_VOLCANIZATIONS_11922563203603211916: VariantsMap = [
    &["volcanizations"],
    &["volcanisations"],
    &["volcanizations"],
    &["volcanisations"],
];

pub(crate) static ENTRY_VOLCANIZATION_15208079623603218405: VariantsMap = [
    &["volcanization"],
    &["volcanisation"],
    &["volcanization"],
    &["volcanisation"],
];

pub(crate) static ENTRY_VOLCANIZED_7340807631500965062: VariantsMap = [
    &["volcanized"],
    &["volcanised"],
    &["volcanized"],
    &["volcanised"],
];

pub(crate) static ENTRY_VOLCANIZES_8125520318354745094: VariantsMap = [
    &["volcanizes"],
    &["volcanises"],
    &["volcanizes"],
    &["volcanises"],
];

pub(crate) static ENTRY_VOLCANIZE_5966901671703511868: VariantsMap = [
    &["volcanize"],
    &["volcanise"],
    &["volcanize"],
    &["volcanise"],
];

pub(crate) static ENTRY_VOLCANIZING_17170908759013088769: VariantsMap = [
    &["volcanizing"],
    &["volcanising"],
    &["volcanizing"],
    &["volcanising"],
];

pub(crate) static ENTRY_VOLTIZES_16866957908997653386: VariantsMap =
    [&["voltizes"], &["voltises"], &["voltizes"], &["voltises"]];

pub(crate) static ENTRY_VOLTIZE_7549036914115473442: VariantsMap =
    [&["voltize"], &["voltise"], &["voltize"], &["voltise"]];

pub(crate) static ENTRY_VOWELIZATIONS_5803231980451353684: VariantsMap = [
    &["vowelizations"],
    &["vowelisations"],
    &["vowelizations"],
    &["vowelisations"],
];

pub(crate) static ENTRY_VOWELIZATION_989128645335163882: VariantsMap = [
    &["vowelization"],
    &["vowelisation"],
    &["vowelization"],
    &["vowelisation"],
];

pub(crate) static ENTRY_VOWELIZED_10046225650144601473: VariantsMap = [
    &["vowelized"],
    &["vowelised"],
    &["vowelized"],
    &["vowelised"],
];

pub(crate) static ENTRY_VOWELIZES_10478314626294200903: VariantsMap = [
    &["vowelizes"],
    &["vowelises"],
    &["vowelizes"],
    &["vowelises"],
];

pub(crate) static ENTRY_VOWELIZE_18108634882497063258: VariantsMap =
    [&["vowelize"], &["vowelise"], &["vowelize"], &["vowelise"]];

pub(crate) static ENTRY_VOWELIZING_1774578233754681336: VariantsMap = [
    &["vowelizing"],
    &["vowelising"],
    &["vowelizing"],
    &["vowelising"],
];

pub(crate) static ENTRY_VULCANIZABLER_4054424358397582656: VariantsMap = [
    &["vulcanizabler"],
    &["vulcanisabler"],
    &["vulcanizabler"],
    &["vulcanisabler"],
];

pub(crate) static ENTRY_VULCANIZABLEST_6459505877444949673: VariantsMap = [
    &["vulcanizablest"],
    &["vulcanisablest"],
    &["vulcanizablest"],
    &["vulcanisablest"],
];

pub(crate) static ENTRY_VULCANIZABLES_8379629917557167700: VariantsMap = [
    &["vulcanizables"],
    &["vulcanisables"],
    &["vulcanizables"],
    &["vulcanisables"],
];

pub(crate) static ENTRY_VULCANIZABLE_3568502198024878932: VariantsMap = [
    &["vulcanizable"],
    &["vulcanisable"],
    &["vulcanizable"],
    &["vulcanisable"],
];

pub(crate) static ENTRY_VULCANIZATES_16942202816352460180: VariantsMap = [
    &["vulcanizates"],
    &["vulcanisates"],
    &["vulcanizates"],
    &["vulcanisates"],
];

pub(crate) static ENTRY_VULCANIZATE_4795671622025524378: VariantsMap = [
    &["vulcanizate"],
    &["vulcanisate"],
    &["vulcanizate"],
    &["vulcanisate"],
];

pub(crate) static ENTRY_VULCANIZATIONS_12614859722986396332: VariantsMap = [
    &["vulcanizations"],
    &["vulcanisations"],
    &["vulcanizations"],
    &["vulcanisations"],
];

pub(crate) static ENTRY_VULCANIZATION_3258864381780829761: VariantsMap = [
    &["vulcanization"],
    &["vulcanisation"],
    &["vulcanization"],
    &["vulcanisation"],
];

pub(crate) static ENTRY_VULCANIZED_15788444725575758612: VariantsMap = [
    &["vulcanized"],
    &["vulcanised"],
    &["vulcanized"],
    &["vulcanised"],
];

pub(crate) static ENTRY_VULCANIZERS_4164062164915178108: VariantsMap = [
    &["vulcanizers"],
    &["vulcanisers"],
    &["vulcanizers"],
    &["vulcanisers"],
];

pub(crate) static ENTRY_VULCANIZER_3777087061043675341: VariantsMap = [
    &["vulcanizer"],
    &["vulcaniser"],
    &["vulcanizer"],
    &["vulcaniser"],
];

pub(crate) static ENTRY_VULCANIZES_18094247566727839218: VariantsMap = [
    &["vulcanizes"],
    &["vulcanises"],
    &["vulcanizes"],
    &["vulcanises"],
];

pub(crate) static ENTRY_VULCANIZE_977902884734413931: VariantsMap = [
    &["vulcanize"],
    &["vulcanise"],
    &["vulcanize"],
    &["vulcanise"],
];

pub(crate) static ENTRY_VULCANIZING_16179329893471043275: VariantsMap = [
    &["vulcanizing"],
    &["vulcanising"],
    &["vulcanizing"],
    &["vulcanising"],
];

pub(crate) static ENTRY_VULGARIZATIONS_17269033887487645821: VariantsMap = [
    &["vulgarizations"],
    &["vulgarisations"],
    &["vulgarizations"],
    &["vulgarisations"],
];

pub(crate) static ENTRY_VULGARIZATION_9399086175034751352: VariantsMap = [
    &["vulgarization"],
    &["vulgarisation"],
    &["vulgarization"],
    &["vulgarisation"],
];

pub(crate) static ENTRY_VULGARIZED_16682935641229034184: VariantsMap = [
    &["vulgarized"],
    &["vulgarised"],
    &["vulgarized"],
    &["vulgarised"],
];

pub(crate) static ENTRY_VULGARIZERS_1013773146928265577: VariantsMap = [
    &["vulgarizers"],
    &["vulgarisers"],
    &["vulgarizers"],
    &["vulgarisers"],
];

pub(crate) static ENTRY_VULGARIZER_11079564505577982456: VariantsMap = [
    &["vulgarizer"],
    &["vulgariser"],
    &["vulgarizer"],
    &["vulgariser"],
];

pub(crate) static ENTRY_VULGARIZES_1421269681767890441: VariantsMap = [
    &["vulgarizes"],
    &["vulgarises"],
    &["vulgarizes"],
    &["vulgarises"],
];

pub(crate) static ENTRY_VULGARIZE_3593216075985714450: VariantsMap = [
    &["vulgarize"],
    &["vulgarise"],
    &["vulgarize"],
    &["vulgarise"],
];

pub(crate) static ENTRY_VULGARIZING_8957250676888139808: VariantsMap = [
    &["vulgarizing"],
    &["vulgarising"],
    &["vulgarizing"],
    &["vulgarising"],
];

pub(crate) static ENTRY_WACKES_12738481748744727840: VariantsMap =
    [&["wackes"], &["wackoes"], &["wackoes"], &["wackoes"]];

pub(crate) static ENTRY_WAGNERIZES_8895003839461059816: VariantsMap = [
    &["wagnerizes"],
    &["wagnerises"],
    &["wagnerizes"],
    &["wagnerises"],
];

pub(crate) static ENTRY_WAGNERIZE_6840934791092236521: VariantsMap = [
    &["wagnerize"],
    &["wagnerise"],
    &["wagnerize"],
    &["wagnerise"],
];

pub(crate) static ENTRY_WAGONED_11373672045286783138: VariantsMap =
    [&["wagoned"], &["wagoned"], &["wagoned"], &["wagoned"]];

pub(crate) static ENTRY_WAGONEER_17408093464143438026: VariantsMap =
    [&["wagoneer"], &["wagoneer"], &["wagoneer"], &["wagoneer"]];

pub(crate) static ENTRY_WAGONERS_8328342185970927143: VariantsMap =
    [&["wagoners"], &["wagoners"], &["wagoners"], &["wagoners"]];

pub(crate) static ENTRY_WAGONER_7174401894558856152: VariantsMap =
    [&["wagoner"], &["wagoner"], &["wagoner"], &["wagoner"]];

pub(crate) static ENTRY_WAGONETTES_18300454369865577574: VariantsMap = [
    &["wagonettes"],
    &["wagonettes"],
    &["wagonettes"],
    &["wagonettes"],
];

pub(crate) static ENTRY_WAGONETTE_10106097158675362196: VariantsMap = [
    &["wagonette"],
    &["wagonette"],
    &["wagonette"],
    &["wagonette"],
];

pub(crate) static ENTRY_WAGONING_6834423535434103369: VariantsMap =
    [&["wagoning"], &["wagoning"], &["wagoning"], &["wagoning"]];

pub(crate) static ENTRY_WAGONS_16296021619075314226: VariantsMap =
    [&["wagons"], &["wagons"], &["wagons"], &["wagons"]];

pub(crate) static ENTRY_WAGON_9175179404225633205: VariantsMap =
    [&["wagon"], &["wagon"], &["wagon"], &["wagon"]];

pub(crate) static ENTRY_WANTONIZED_15092244368516355065: VariantsMap = [
    &["wantonized"],
    &["wantonised"],
    &["wantonized"],
    &["wantonised"],
];

pub(crate) static ENTRY_WANTONIZES_8102013437087314845: VariantsMap = [
    &["wantonizes"],
    &["wantonises"],
    &["wantonizes"],
    &["wantonises"],
];

pub(crate) static ENTRY_WANTONIZE_14427284173321750170: VariantsMap = [
    &["wantonize"],
    &["wantonise"],
    &["wantonize"],
    &["wantonise"],
];

pub(crate) static ENTRY_WANTONIZING_11612419212222365365: VariantsMap = [
    &["wantonizing"],
    &["wantonising"],
    &["wantonizing"],
    &["wantonising"],
];

pub(crate) static ENTRY_WARER_124002938733117158: VariantsMap =
    [&["warer"], &["warre"], &["warre"], &["warre"]];

pub(crate) static ENTRY_WARFORD_9070503211126736019: VariantsMap =
    [&["warford"], &["warfourd"], &["warfourd"], &["warfourd"]];

pub(crate) static ENTRY_WARRANTIZE_12531974386933132943: VariantsMap = [
    &["warrantize"],
    &["warrantise"],
    &["warrantize"],
    &["warrantise"],
];

pub(crate) static ENTRY_WATERCOLORED_6965422467906206000: VariantsMap = [
    &["watercolored"],
    &["watercoloured"],
    &["watercoloured"],
    &["watercoloured"],
];

pub(crate) static ENTRY_WATERCOLORING_10355406009413574616: VariantsMap = [
    &["watercoloring"],
    &["watercolouring"],
    &["watercolouring"],
    &["watercolouring"],
];

pub(crate) static ENTRY_WATERCOLORISTS_8716481806936659758: VariantsMap = [
    &["watercolorists"],
    &["watercolourists"],
    &["watercolourists"],
    &["watercolourists"],
];

pub(crate) static ENTRY_WATERCOLORIST_98941858503965450: VariantsMap = [
    &["watercolorist"],
    &["watercolourist"],
    &["watercolourist"],
    &["watercolourist"],
];

pub(crate) static ENTRY_WATERCOLORS_8321231076259173473: VariantsMap = [
    &["watercolors"],
    &["watercolours"],
    &["watercolours"],
    &["watercolours"],
];

pub(crate) static ENTRY_WATERCOLOR_14626819058358461476: VariantsMap = [
    &["watercolor"],
    &["watercolour"],
    &["watercolour"],
    &["watercolour"],
];

pub(crate) static ENTRY_WEASELED_11570315947714387529: VariantsMap =
    [&["weaseled"], &["weaselled"], &["weaseled"], &["weaselled"]];

pub(crate) static ENTRY_WEASELING_15286296280087806597: VariantsMap = [
    &["weaseling"],
    &["weaselling"],
    &["weaseling"],
    &["weaselling"],
];

pub(crate) static ENTRY_WEATHERIZED_7468196884834492189: VariantsMap = [
    &["weatherized"],
    &["weatherised"],
    &["weatherized"],
    &["weatherised"],
];

pub(crate) static ENTRY_WEATHERIZES_9985373291367274228: VariantsMap = [
    &["weatherizes"],
    &["weatherises"],
    &["weatherizes"],
    &["weatherises"],
];

pub(crate) static ENTRY_WEATHERIZE_2192670928369527010: VariantsMap = [
    &["weatherize"],
    &["weatherise"],
    &["weatherize"],
    &["weatherise"],
];

pub(crate) static ENTRY_WEATHERIZING_15974867536961027368: VariantsMap = [
    &["weatherizing"],
    &["weatherising"],
    &["weatherizing"],
    &["weatherising"],
];

pub(crate) static ENTRY_WEEVILED_9823853063466769617: VariantsMap = [
    &["weeviled"],
    &["weevilled"],
    &["weevilled"],
    &["weevilled"],
];

pub(crate) static ENTRY_WEFTWIZE_11468980171486281071: VariantsMap =
    [&["weftwize"], &["weftwise"], &["weftwize"], &["weftwise"]];

pub(crate) static ENTRY_WEIZED_15084246244422353791: VariantsMap =
    [&["weized"], &["weised"], &["weized"], &["weised"]];

pub(crate) static ENTRY_WEIZES_7320958225089246727: VariantsMap =
    [&["weizes"], &["weises"], &["weizes"], &["weises"]];

pub(crate) static ENTRY_WEIZE_8174776964340050680: VariantsMap =
    [&["weize"], &["weise"], &["weize"], &["weise"]];

pub(crate) static ENTRY_WEIZING_16099137944736271359: VariantsMap =
    [&["weizing"], &["weising"], &["weizing"], &["weising"]];

pub(crate) static ENTRY_WER_15853599801760131986: VariantsMap =
    [&["wer"], &["waer"], &["waer"], &["waer"]];

pub(crate) static ENTRY_WESTERNIZATIONS_13759633497928659151: VariantsMap = [
    &["westernizations"],
    &["westernisations"],
    &["westernizations"],
    &["westernisations"],
];

pub(crate) static ENTRY_WESTERNIZATION_9450693683308242701: VariantsMap = [
    &["westernization"],
    &["westernisation"],
    &["westernization"],
    &["westernisation"],
];

pub(crate) static ENTRY_WESTERNIZED_4777853943475506918: VariantsMap = [
    &["westernized"],
    &["westernised"],
    &["westernized"],
    &["westernised"],
];

pub(crate) static ENTRY_WESTERNIZES_359511446272047498: VariantsMap = [
    &["westernizes"],
    &["westernises"],
    &["westernizes"],
    &["westernises"],
];

pub(crate) static ENTRY_WESTERNIZE_18201376901512962153: VariantsMap = [
    &["westernize"],
    &["westernise"],
    &["westernize"],
    &["westernise"],
];

pub(crate) static ENTRY_WESTERNIZING_6658385047324066874: VariantsMap = [
    &["westernizing"],
    &["westernising"],
    &["westernizing"],
    &["westernising"],
];

pub(crate) static ENTRY_WHISKEYS_17211820182326956376: VariantsMap =
    [&["whiskeys"], &["whiskies"], &["whiskies"], &["whiskies"]];

pub(crate) static ENTRY_WHITMANIZES_2277386686370449672: VariantsMap = [
    &["whitmanizes"],
    &["whitmanises"],
    &["whitmanizes"],
    &["whitmanises"],
];

pub(crate) static ENTRY_WHITMANIZE_17709805677202222665: VariantsMap = [
    &["whitmanize"],
    &["whitmanise"],
    &["whitmanize"],
    &["whitmanise"],
];

pub(crate) static ENTRY_WILLFULER_9723393434882898265: VariantsMap =
    [&["willfuler"], &["wilfuler"], &["wilfuler"], &["wilfuler"]];

pub(crate) static ENTRY_WILLFULEST_1356703166632625612: VariantsMap = [
    &["willfulest"],
    &["wilfulest"],
    &["wilfulest"],
    &["wilfulest"],
];

pub(crate) static ENTRY_WILLFULLIER_2697017026114247086: VariantsMap = [
    &["willfullier"],
    &["wilfullier"],
    &["wilfullier"],
    &["wilfullier"],
];

pub(crate) static ENTRY_WILLFULLIEST_15153395951969058577: VariantsMap = [
    &["willfulliest"],
    &["wilfulliest"],
    &["wilfulliest"],
    &["wilfulliest"],
];

pub(crate) static ENTRY_WILLFULLY_17551532991278844610: VariantsMap =
    [&["willfully"], &["wilfully"], &["wilfully"], &["wilfully"]];

pub(crate) static ENTRY_WILLFULNESS_13563375725271959262: VariantsMap = [
    &["willfulness"],
    &["wilfulness"],
    &["wilfulness"],
    &["wilfulness"],
];

pub(crate) static ENTRY_WILLFUL_7624543375604831885: VariantsMap =
    [&["willful"], &["wilful"], &["wilful"], &["wilful"]];

pub(crate) static ENTRY_WINTERIZATIONS_13592272727744097379: VariantsMap = [
    &["winterizations"],
    &["winterisations"],
    &["winterizations"],
    &["winterisations"],
];

pub(crate) static ENTRY_WINTERIZATION_7645598477678155456: VariantsMap = [
    &["winterization"],
    &["winterisation"],
    &["winterization"],
    &["winterisation"],
];

pub(crate) static ENTRY_WINTERIZED_9857678671877956604: VariantsMap = [
    &["winterized"],
    &["winterised"],
    &["winterized"],
    &["winterised"],
];

pub(crate) static ENTRY_WINTERIZES_158574474219766318: VariantsMap = [
    &["winterizes"],
    &["winterises"],
    &["winterizes"],
    &["winterises"],
];

pub(crate) static ENTRY_WINTERIZE_3955752504931726030: VariantsMap = [
    &["winterize"],
    &["winterise"],
    &["winterize"],
    &["winterise"],
];

pub(crate) static ENTRY_WINTERIZING_11041236811279192392: VariantsMap = [
    &["winterizing"],
    &["winterising"],
    &["winterizing"],
    &["winterising"],
];

pub(crate) static ENTRY_WIZEN_287155720416603669: VariantsMap =
    [&["wizen"], &["wisen"], &["wizen"], &["wisen"]];

pub(crate) static ENTRY_WOMANIZATIONS_13952845861350174066: VariantsMap = [
    &["womanizations"],
    &["womanisations"],
    &["womanizations"],
    &["womanisations"],
];

pub(crate) static ENTRY_WOMANIZATION_8388350880273651311: VariantsMap = [
    &["womanization"],
    &["womanisation"],
    &["womanization"],
    &["womanisation"],
];

pub(crate) static ENTRY_WOMANIZED_13265813200914382776: VariantsMap = [
    &["womanized"],
    &["womanised"],
    &["womanized"],
    &["womanised"],
];

pub(crate) static ENTRY_WOMANIZERS_9259673447489824653: VariantsMap = [
    &["womanizers"],
    &["womanisers"],
    &["womanizers"],
    &["womanisers"],
];

pub(crate) static ENTRY_WOMANIZER_17770185505558084902: VariantsMap = [
    &["womanizer"],
    &["womaniser"],
    &["womanizer"],
    &["womaniser"],
];

pub(crate) static ENTRY_WOMANIZES_14963203568866144583: VariantsMap = [
    &["womanizes"],
    &["womanises"],
    &["womanizes"],
    &["womanises"],
];

pub(crate) static ENTRY_WOMANIZE_13239637807089654458: VariantsMap =
    [&["womanize"], &["womanise"], &["womanize"], &["womanise"]];

pub(crate) static ENTRY_WOMANIZING_18027895621894995913: VariantsMap = [
    &["womanizing"],
    &["womanising"],
    &["womanizing"],
    &["womanising"],
];

pub(crate) static ENTRY_WOODCOCKIZES_12391053488008876606: VariantsMap = [
    &["woodcockizes"],
    &["woodcockises"],
    &["woodcockizes"],
    &["woodcockises"],
];

pub(crate) static ENTRY_WOODCOCKIZE_12359995033224465169: VariantsMap = [
    &["woodcockize"],
    &["woodcockise"],
    &["woodcockize"],
    &["woodcockise"],
];

pub(crate) static ENTRY_WOOLENIZATIONS_18413526449670419815: VariantsMap = [
    &["woolenizations"],
    &["woollenisations"],
    &["woollenizations"],
    &["woollenisations"],
];

pub(crate) static ENTRY_WOOLENIZATION_2116233406109851879: VariantsMap = [
    &["woolenization"],
    &["woollenisation"],
    &["woollenization"],
    &["woollenisation"],
];

pub(crate) static ENTRY_WOOLENIZES_10986368507483676931: VariantsMap = [
    &["woolenizes"],
    &["woollenises"],
    &["woollenizes"],
    &["woollenises"],
];

pub(crate) static ENTRY_WOOLENIZE_3109266446842903533: VariantsMap = [
    &["woolenize"],
    &["woollenise"],
    &["woollenize"],
    &["woollenise"],
];

pub(crate) static ENTRY_WOOLENNER_17842051069153830315: VariantsMap = [
    &["woolenner"],
    &["woollenner"],
    &["woollenner"],
    &["woollenner"],
];

pub(crate) static ENTRY_WOOLENNEST_10863079266692878959: VariantsMap = [
    &["woolennest"],
    &["woollennest"],
    &["woollennest"],
    &["woollennest"],
];

pub(crate) static ENTRY_WOOLENS_12209882553973827060: VariantsMap =
    [&["woolens"], &["woollens"], &["woollens"], &["woollens"]];

pub(crate) static ENTRY_WOOLEN_15717013546287576656: VariantsMap =
    [&["woolen"], &["woollen"], &["woollen"], &["woollen"]];

pub(crate) static ENTRY_WORNIL_7106321021868280403: VariantsMap =
    [&["wornil"], &["wournil"], &["wournil"], &["wournil"]];

pub(crate) static ENTRY_WORSHIPED_10866326533617664853: VariantsMap = [
    &["worshiped"],
    &["worshipped"],
    &["worshipped"],
    &["worshipped"],
];

pub(crate) static ENTRY_WORSHIPERS_10535090980834134943: VariantsMap = [
    &["worshipers"],
    &["worshippers"],
    &["worshippers"],
    &["worshippers"],
];

pub(crate) static ENTRY_WORSHIPER_4363374512340886503: VariantsMap = [
    &["worshiper"],
    &["worshipper"],
    &["worshipper"],
    &["worshipper"],
];

pub(crate) static ENTRY_WORSHIPING_7066968947382158195: VariantsMap = [
    &["worshiping"],
    &["worshipping"],
    &["worshipping"],
    &["worshipping"],
];

pub(crate) static ENTRY_YODELED_9356406298399519334: VariantsMap =
    [&["yodeled"], &["yodelled"], &["yodelled"], &["yodelled"]];

pub(crate) static ENTRY_YODELERS_2440942956900301409: VariantsMap = [
    &["yodelers"],
    &["yodellers"],
    &["yodellers"],
    &["yodellers"],
];

pub(crate) static ENTRY_YODELER_285878482199218584: VariantsMap =
    [&["yodeler"], &["yodeller"], &["yodeller"], &["yodeller"]];

pub(crate) static ENTRY_YODELING_14921433313912990218: VariantsMap = [
    &["yodeling"],
    &["yodelling"],
    &["yodelling"],
    &["yodelling"],
];

pub(crate) static ENTRY_YOGURTS_14006847350082938741: VariantsMap =
    [&["yogurts"], &["yogurts"], &["yogourts"], &["yoghurts"]];

pub(crate) static ENTRY_YOGURT_14795287461115589482: VariantsMap =
    [&["yogurt"], &["yogurt"], &["yogourt"], &["yoghurt"]];

pub(crate) static ENTRY_ZAFFERS_2686771360880865447: VariantsMap =
    [&["zaffers"], &["zaffres"], &["zaffres"], &["zaffres"]];

pub(crate) static ENTRY_ZAFFER_10527776117983596564: VariantsMap =
    [&["zaffer"], &["zaffre"], &["zaffre"], &["zaffre"]];

pub(crate) static ENTRY_ZEAS_16079098418850825523: VariantsMap =
    [&["zeas"], &["zoeas"], &["zoeas"], &["zoeas"]];

pub(crate) static ENTRY_ZEA_11106235456645827388: VariantsMap =
    [&["zea"], &["zoea"], &["zoea"], &["zoea"]];

pub(crate) static ENTRY_ZEROIZED_17059959399940465949: VariantsMap =
    [&["zeroized"], &["zeroised"], &["zeroized"], &["zeroised"]];

pub(crate) static ENTRY_ZEROIZES_451395537748100839: VariantsMap =
    [&["zeroizes"], &["zeroises"], &["zeroizes"], &["zeroises"]];

pub(crate) static ENTRY_ZEROIZE_5851814204224675995: VariantsMap =
    [&["zeroize"], &["zeroise"], &["zeroize"], &["zeroise"]];

pub(crate) static ENTRY_ZEROIZING_17764051118899638643: VariantsMap = [
    &["zeroizing"],
    &["zeroising"],
    &["zeroizing"],
    &["zeroising"],
];

pub(crate) static ENTRY_ZOEAE_16777813522281751943: VariantsMap =
    [&["zoeae"], &["zooeae"], &["zooeae"], &["zooeae"]];

pub(crate) static ENTRY_ZOEAL_11452762743124231237: VariantsMap =
    [&["zoeal"], &["zooeal"], &["zooeal"], &["zooeal"]];

pub(crate) static ENTRY_ZOEAS_265178227546758074: VariantsMap =
    [&["zoeas"], &["zooeas"], &["zooeas"], &["zooeas"]];

pub(crate) static ENTRY_ZOEA_17148924521763695652: VariantsMap =
    [&["zoea"], &["zoaea"], &["zoaea"], &["zoaea"]];

pub(crate) static ENTRY_ZOEA_9209140367896697417: VariantsMap =
    [&["zoea"], &["zooea"], &["zooea"], &["zooea"]];

pub(crate) static ENTRY_ZOECIA_8904526004070274154: VariantsMap =
    [&["zoecia"], &["zooecia"], &["zooecia"], &["zooecia"]];

pub(crate) static ENTRY_ZOECIUM_16562741580002996142: VariantsMap =
    [&["zoecium"], &["zooecium"], &["zooecium"], &["zooecium"]];

pub(crate) static ENTRY_ZONESTHESIA_3100074848208687922: VariantsMap = [
    &["zonesthesia"],
    &["zonaesthesia"],
    &["zonaesthesia"],
    &["zonaesthesia"],
];

pub(crate) static ENTRY_ZONULE_1425795093078962568: VariantsMap =
    [&["zonule"], &["zonulae"], &["zonulae"], &["zonulae"]];

pub(crate) static ENTRY_ZOOGLEAE_8257944936060167006: VariantsMap = [
    &["zoogleae"],
    &["zoogloeae"],
    &["zoogloeae"],
    &["zoogloeae"],
];

pub(crate) static ENTRY_ZOOGLEAL_12531107528650388160: VariantsMap = [
    &["zoogleal"],
    &["zoogloeal"],
    &["zoogloeal"],
    &["zoogloeal"],
];

pub(crate) static ENTRY_ZOOGLEAS_1142556719691697396: VariantsMap = [
    &["zoogleas"],
    &["zoogloeas"],
    &["zoogloeas"],
    &["zoogloeas"],
];

pub(crate) static ENTRY_ZOOGLEA_5239592471376961231: VariantsMap =
    [&["zooglea"], &["zoogloea"], &["zoogloea"], &["zoogloea"]];

pub(crate) static ENTRY_ZYGENID_18294614842044047958: VariantsMap =
    [&["zygenid"], &["zygaenid"], &["zygaenid"], &["zygaenid"]];
